use strict;
use Test::More tests => 23390;

use_ok('Number::ZipCode::JP', 'company');

my $zip = Number::ZipCode::JP->new;
ok($zip->set_number('0018501')->is_valid_number, '学校法人 創成学園 札幌創成高等学校');
ok($zip->set_number('0018511')->is_valid_number, '全国健康保険協会北海道支部');
ok($zip->set_number('0018521')->is_valid_number, '札幌私書箱センター');
ok($zip->set_number('0018555')->is_valid_number, '北海道ホルスタイン農業協同組合');
ok($zip->set_number('0018577')->is_valid_number, 'ダイハツ北海道販売 株式会社');
ok($zip->set_number('0018588')->is_valid_number, '北海道 札幌道税事務所 自動車税部');
ok($zip->set_number('0018612')->is_valid_number, '札幌市北区役所');
ok($zip->set_number('0028501')->is_valid_number, '北海道教育大学 本部');
ok($zip->set_number('0028502')->is_valid_number, '北海道教育大学 札幌校');
ok($zip->set_number('0028503')->is_valid_number, '北海道教育大学 附属図書館');
ok($zip->set_number('0028504')->is_valid_number, '北海道 有朋高等学校');
ok($zip->set_number('0038501')->is_valid_number, '三菱ふそうトラック・バス 株式会社 北海道ふそう');
ok($zip->set_number('0038502')->is_valid_number, '大丸 株式会社');
ok($zip->set_number('0038503')->is_valid_number, 'ブリヂストンタイヤ北海道販売 (株)');
ok($zip->set_number('0038504')->is_valid_number, '大丸 株式会社');
ok($zip->set_number('0038505')->is_valid_number, '札幌市 衛生研究所');
ok($zip->set_number('0038510')->is_valid_number, '勤医協 札幌病院');
ok($zip->set_number('0038511')->is_valid_number, '(株) クワザワ工業');
ok($zip->set_number('0038515')->is_valid_number, '(株) アレフ');
ok($zip->set_number('0038519')->is_valid_number, '株式会社 東光ストア');
ok($zip->set_number('0038520')->is_valid_number, '札幌河辺石油 (株)');
ok($zip->set_number('0038530')->is_valid_number, '日本年金機構 札幌東年金事務所');
ok($zip->set_number('0038531')->is_valid_number, '北海電気工事 株式会社');
ok($zip->set_number('0038558')->is_valid_number, 'ミサワホーム北海道 株式会社');
ok($zip->set_number('0038566')->is_valid_number, '株式会社 RJオグラ');
ok($zip->set_number('0038567')->is_valid_number, '(株) 恵和ビジネス');
ok($zip->set_number('0038577')->is_valid_number, 'ユアサ商事 株式会社 北海道支社');
ok($zip->set_number('0038580')->is_valid_number, '三菱食品 株式会社 北海道支社');
ok($zip->set_number('0038581')->is_valid_number, '株式会社 リョーショクリカー 北海道支社');
ok($zip->set_number('0038582')->is_valid_number, '株式会社 北海道リョーショク');
ok($zip->set_number('0038585')->is_valid_number, '医療法人 東札幌病院');
ok($zip->set_number('0038588')->is_valid_number, '株式会社 札幌パリ');
ok($zip->set_number('0038601')->is_valid_number, '日本通運 株式会社 札幌支店');
ok($zip->set_number('0038610')->is_valid_number, '株式会社 宮川建設');
ok($zip->set_number('0038612')->is_valid_number, '札幌市白石区役所');
ok($zip->set_number('0038620')->is_valid_number, '北海道いすゞ自動車 株式会社');
ok($zip->set_number('0038630')->is_valid_number, 'イオン北海道 株式会社');
ok($zip->set_number('0038631')->is_valid_number, '株式会社 北海道観光物産興社');
ok($zip->set_number('0038639')->is_valid_number, '株式会社 ナニワ');
ok($zip->set_number('0038640')->is_valid_number, 'ダイハツ北海道販売 株式会社');
ok($zip->set_number('0038668')->is_valid_number, '独立行政法人 国際協力機構 北海道センター (札幌)');
ok($zip->set_number('0038701')->is_valid_number, '西山製麺 株式会社');
ok($zip->set_number('0038702')->is_valid_number, '北海道銀行 事務センター');
ok($zip->set_number('0048502')->is_valid_number, '丸善雄松堂 (株) 札幌支店');
ok($zip->set_number('0048503')->is_valid_number, '北海道札幌清田高等学校');
ok($zip->set_number('0048510')->is_valid_number, '(株) 松井');
ok($zip->set_number('0048512')->is_valid_number, '東日本高速道路 株式会社 北海道支社');
ok($zip->set_number('0048518')->is_valid_number, '札幌東労働基準監督署');
ok($zip->set_number('0048523')->is_valid_number, 'UDトラックス北海道 株式会社');
ok($zip->set_number('0048530')->is_valid_number, '株式会社 弁釜');
ok($zip->set_number('0048531')->is_valid_number, '雪印種苗 株式会社');
ok($zip->set_number('0048532')->is_valid_number, '一般財団法人 札幌市交通事業振興公社');
ok($zip->set_number('0048533')->is_valid_number, '北星学園大学図書館');
ok($zip->set_number('0048555')->is_valid_number, '札幌市交通局');
ok($zip->set_number('0048558')->is_valid_number, '日本年金機構 新さっぽろ年金事務所');
ok($zip->set_number('0048567')->is_valid_number, '創価学会 北海道方面事務局');
ok($zip->set_number('0048577')->is_valid_number, 'イオンモール 株式会社 イオンカテプリ新さっぽろ');
ok($zip->set_number('0048585')->is_valid_number, '(株) ドーコン');
ok($zip->set_number('0048588')->is_valid_number, '北海道コカ・コーラボトリング(株)');
ok($zip->set_number('0048602')->is_valid_number, '札幌国際大学');
ok($zip->set_number('0048603')->is_valid_number, '札幌国際大学短期大学部');
ok($zip->set_number('0048610')->is_valid_number, '三菱電機住環境システムズ 株式会社 北海道社');
ok($zip->set_number('0048611')->is_valid_number, 'ホーマック 株式会社');
ok($zip->set_number('0048612')->is_valid_number, '札幌市厚別区役所');
ok($zip->set_number('0048613')->is_valid_number, '札幌市清田区役所');
ok($zip->set_number('0048616')->is_valid_number, '清田区 土木センター');
ok($zip->set_number('0048618')->is_valid_number, '札幌北辰病院');
ok($zip->set_number('0048629')->is_valid_number, '北海道プリマハム 株式会社');
ok($zip->set_number('0048631')->is_valid_number, '北星学園大学');
ok($zip->set_number('0048641')->is_valid_number, '札幌市東部市税事務所');
ok($zip->set_number('0048666')->is_valid_number, '学校法人 札幌学院大学 新札幌キャンパス');
ok($zip->set_number('0048686')->is_valid_number, '学校法人 滋慶学園 札幌看護医療専門学校');
ok($zip->set_number('0058501')->is_valid_number, '医療法人 愛全会 愛全病院');
ok($zip->set_number('0058543')->is_valid_number, '自衛隊札幌病院');
ok($zip->set_number('0058543')->is_valid_number, '陸上自衛隊 真駒内駐屯地');
ok($zip->set_number('0058555')->is_valid_number, '医療法人 医仁会 中村記念南病院');
ok($zip->set_number('0058585')->is_valid_number, '岡本興業 株式会社');
ok($zip->set_number('0058601')->is_valid_number, '東海大学 札幌校舎');
ok($zip->set_number('0058602')->is_valid_number, '東海大学付属札幌高等学校');
ok($zip->set_number('0058612')->is_valid_number, '札幌市南区役所');
ok($zip->set_number('0058798')->is_valid_number, '札幌逓信病院');
ok($zip->set_number('0068555')->is_valid_number, '医療法人 渓仁会 手稲渓仁会病院');
ok($zip->set_number('0068561')->is_valid_number, '株式会社 ムトウ SPDセンター');
ok($zip->set_number('0068585')->is_valid_number, '北海道科学大学');
ok($zip->set_number('0068612')->is_valid_number, '札幌市手稲区役所');
ok($zip->set_number('0078501')->is_valid_number, 'オリヒロ (株) 札幌営業所');
ok($zip->set_number('0078503')->is_valid_number, '丘珠駐屯地');
ok($zip->set_number('0078505')->is_valid_number, '勤医協 中央病院');
ok($zip->set_number('0078507')->is_valid_number, '北海道日野自動車 (株)');
ok($zip->set_number('0078508')->is_valid_number, '泉州電業 株式会社 札幌支店');
ok($zip->set_number('0078511')->is_valid_number, 'サツラク農業協同組合 市乳事業部');
ok($zip->set_number('0078553')->is_valid_number, 'トラスコ中山 株式会社');
ok($zip->set_number('0078585')->is_valid_number, '北海道札幌東陵高等学校');
ok($zip->set_number('0078632')->is_valid_number, '札幌日産自動車 株式会社 東苗穂店');
ok($zip->set_number('0078733')->is_valid_number, '北ガスジェネックス 株式会社');
ok($zip->set_number('0100195')->is_valid_number, '公立大学法人 秋田県立大学');
ok($zip->set_number('0100492')->is_valid_number, 'あきたこまち生産者協会');
ok($zip->set_number('0100493')->is_valid_number, '秋田県男鹿市役所若美庁舎');
ok($zip->set_number('0100494')->is_valid_number, '大潟村役場');
ok($zip->set_number('0100595')->is_valid_number, '男鹿市役所');
ok($zip->set_number('0101292')->is_valid_number, '公立大学法人 国際教養大学');
ok($zip->set_number('0101492')->is_valid_number, '日本赤十字秋田短期大学');
ok($zip->set_number('0101493')->is_valid_number, '日本赤十字秋田看護大学');
ok($zip->set_number('0108501')->is_valid_number, '日本放送協会 秋田放送局');
ok($zip->set_number('0108502')->is_valid_number, '国立大学法人 秋田大学');
ok($zip->set_number('0108504')->is_valid_number, '秋田地方・家庭・簡易裁判所');
ok($zip->set_number('0108505')->is_valid_number, '株式会社 そごう・西武 西武秋田店');
ok($zip->set_number('0108506')->is_valid_number, '秋田拠点センターアルヴェ');
ok($zip->set_number('0108507')->is_valid_number, '全国健康保険協会 秋田支部');
ok($zip->set_number('0108511')->is_valid_number, '株式会社 メディセオ');
ok($zip->set_number('0108515')->is_valid_number, '学校法人 ノースアジア大学');
ok($zip->set_number('0108518')->is_valid_number, '株式会社 秋田ト一屋');
ok($zip->set_number('0108520')->is_valid_number, '株式会社 相場商店');
ok($zip->set_number('0108525')->is_valid_number, '明桜高等学校');
ok($zip->set_number('0108530')->is_valid_number, '秋田ステーションビル 株式会社');
ok($zip->set_number('0108533')->is_valid_number, '学校法人 聖霊学園');
ok($zip->set_number('0108543')->is_valid_number, '秋田大学医学部附属病院');
ok($zip->set_number('0108550')->is_valid_number, '東北森林管理局');
ok($zip->set_number('0108558')->is_valid_number, '全国農業協同組合連合会 秋田県本部');
ok($zip->set_number('0108560')->is_valid_number, '秋田市役所');
ok($zip->set_number('0108564')->is_valid_number, '(株) シグマ ソリューションズ');
ok($zip->set_number('0108565')->is_valid_number, '日本年金機構 秋田年金事務所');
ok($zip->set_number('0108570')->is_valid_number, '秋田県庁');
ok($zip->set_number('0108572')->is_valid_number, '秋田県庁 第二庁舎');
ok($zip->set_number('0108574')->is_valid_number, '東日本電信電話 株式会社 秋田支店');
ok($zip->set_number('0108577')->is_valid_number, '医療法人 明和会 中通総合病院');
ok($zip->set_number('0108580')->is_valid_number, '秋田県教育委員会 秋田県教育庁');
ok($zip->set_number('0108588')->is_valid_number, '東北電力ネットワーク 株式会社 秋田電力センター');
ok($zip->set_number('0108601')->is_valid_number, '株式会社 秋田魁新報社');
ok($zip->set_number('0108611')->is_valid_number, '株式会社 秋田放送');
ok($zip->set_number('0108622')->is_valid_number, '秋田南税務署');
ok($zip->set_number('0108633')->is_valid_number, '商工組合 中央金庫 秋田支店');
ok($zip->set_number('0108655')->is_valid_number, '株式会社 秋田銀行');
ok($zip->set_number('0108668')->is_valid_number, '秋田テレビ 株式会社');
ok($zip->set_number('0108677')->is_valid_number, '株式会社 北都銀行');
ok($zip->set_number('0108678')->is_valid_number, '富士フイルムBI秋田 株式会社');
ok($zip->set_number('0108794')->is_valid_number, '株式会社 ゆうちょ銀行 秋田地域センター');
ok($zip->set_number('0118501')->is_valid_number, '株式会社 ホテル大和');
ok($zip->set_number('0118510')->is_valid_number, '秋田住友ベーク 株式会社');
ok($zip->set_number('0118511')->is_valid_number, '秋田工業高等専門学校');
ok($zip->set_number('0118520')->is_valid_number, '誠文社');
ok($zip->set_number('0118555')->is_valid_number, '秋田製錬 株式会社');
ok($zip->set_number('0118577')->is_valid_number, '秋田北税務署');
ok($zip->set_number('0118585')->is_valid_number, '秋田海陸運送 株式会社');
ok($zip->set_number('0118605')->is_valid_number, '株式会社 北都銀行 土崎支店');
ok($zip->set_number('0118611')->is_valid_number, '陸上自衛隊 秋田駐屯地');
ok($zip->set_number('0118686')->is_valid_number, '株式会社 秋田銀行 土崎支店');
ok($zip->set_number('0128501')->is_valid_number, '湯沢市役所');
ok($zip->set_number('0128502')->is_valid_number, '湯沢 税務署');
ok($zip->set_number('0128511')->is_valid_number, '秋田県醗酵工業 株式会社');
ok($zip->set_number('0128601')->is_valid_number, '株式会社 皆常商店');
ok($zip->set_number('0128604')->is_valid_number, '株式会社 秋田銀行 湯沢支店');
ok($zip->set_number('0128651')->is_valid_number, '株式会社 丸大工機商会');
ok($zip->set_number('0130498')->is_valid_number, '秋田睦合成 株式会社');
ok($zip->set_number('0138501')->is_valid_number, '日本電信電話 株式会社 横手支店');
ok($zip->set_number('0138502')->is_valid_number, '秋田県平鹿地域振興局');
ok($zip->set_number('0138503')->is_valid_number, '秋田県平鹿地域振興局 福祉環境部');
ok($zip->set_number('0138504')->is_valid_number, '横手税務署');
ok($zip->set_number('0138592')->is_valid_number, 'ユニシアジェーケーシーステアリングシステム 株式会社 秋田工場');
ok($zip->set_number('0138601')->is_valid_number, '横手市役所');
ok($zip->set_number('0138602')->is_valid_number, '市立 横手病院');
ok($zip->set_number('0138609')->is_valid_number, '横手公共職業安定所');
ok($zip->set_number('0140292')->is_valid_number, '大仙市役所 中仙総合支所');
ok($zip->set_number('0140392')->is_valid_number, '仙北市役所 角館庁舎');
ok($zip->set_number('0140393')->is_valid_number, '秋田県立 角館高等学校');
ok($zip->set_number('0140394')->is_valid_number, '仙北市立 角館総合病院');
ok($zip->set_number('0140592')->is_valid_number, '仙北市役所 西木庁舎');
ok($zip->set_number('0141192')->is_valid_number, '株式会社 わらび座');
ok($zip->set_number('0141298')->is_valid_number, '仙北市役所 田沢湖庁舎');
ok($zip->set_number('0148501')->is_valid_number, '株式会社 タニタ秋田');
ok($zip->set_number('0148601')->is_valid_number, '大仙市役所');
ok($zip->set_number('0148611')->is_valid_number, '大曲税務署');
ok($zip->set_number('0150295')->is_valid_number, '由利本荘市 東由利総合支所');
ok($zip->set_number('0158501')->is_valid_number, '由利本荘市役所');
ok($zip->set_number('0158505')->is_valid_number, '秋田社会保険事務局 本荘事務所');
ok($zip->set_number('0158510')->is_valid_number, '秋田プリマ食品 株式会社');
ok($zip->set_number('0158511')->is_valid_number, '由利組合総合病院');
ok($zip->set_number('0158515')->is_valid_number, '由利地域振興局');
ok($zip->set_number('0158530')->is_valid_number, '秋田県立由利工業高等学校');
ok($zip->set_number('0158543')->is_valid_number, '秋田県立 由利高等学校');
ok($zip->set_number('0158555')->is_valid_number, '佐藤病院');
ok($zip->set_number('0158558')->is_valid_number, '株式会社 秋田新電元本社 大浦工場');
ok($zip->set_number('0158567')->is_valid_number, '医療法人 青嵐会 (本荘第一病院)');
ok($zip->set_number('0158585')->is_valid_number, '秋田県立 本荘高等学校');
ok($zip->set_number('0158601')->is_valid_number, '羽後信用金庫');
ok($zip->set_number('0158602')->is_valid_number, '株式会社 北都銀行 本荘支店');
ok($zip->set_number('0158611')->is_valid_number, '株式会社 秋田銀行 本荘支店');
ok($zip->set_number('0158622')->is_valid_number, '本荘税務署');
ok($zip->set_number('0158630')->is_valid_number, '村岡建設工業 株式会社');
ok($zip->set_number('0158642')->is_valid_number, '由利本荘市ガス水道局');
ok($zip->set_number('0158666')->is_valid_number, '医療法人 荘和会(菅原病院・老人保険施設荘和)');
ok($zip->set_number('0158686')->is_valid_number, '小林工業 株式会社');
ok($zip->set_number('0158688')->is_valid_number, '長田建設 株式会社');
ok($zip->set_number('0168501')->is_valid_number, '能代市役所');
ok($zip->set_number('0168555')->is_valid_number, '山本地方部 県民室');
ok($zip->set_number('0168601')->is_valid_number, '能代税務署');
ok($zip->set_number('0168602')->is_valid_number, '株式会社 秋田銀行 能代駅前支店');
ok($zip->set_number('0170292')->is_valid_number, '小坂町役場');
ok($zip->set_number('0170293')->is_valid_number, 'タナックス (株)');
ok($zip->set_number('0178510')->is_valid_number, 'いとく大館ショッピングセンター');
ok($zip->set_number('0178550')->is_valid_number, '大館市立総合病院');
ok($zip->set_number('0178555')->is_valid_number, '大館市役所');
ok($zip->set_number('0178567')->is_valid_number, '日本政策金融公庫 大館支店');
ok($zip->set_number('0178585')->is_valid_number, '秋北バス 株式会社');
ok($zip->set_number('0178686')->is_valid_number, '大館 税務署');
ok($zip->set_number('0180192')->is_valid_number, 'にかほ市役所 象潟庁舎');
ok($zip->set_number('0180492')->is_valid_number, 'にかほ市役所 仁賀保庁舎');
ok($zip->set_number('0180493')->is_valid_number, 'TDK 株式会社 秋田地区');
ok($zip->set_number('0180692')->is_valid_number, '由利本荘市役所 西目総合支所');
ok($zip->set_number('0180795')->is_valid_number, '由利本荘市役所 大内総合支所');
ok($zip->set_number('0181392')->is_valid_number, '由利本荘市 岩城総合支所');
ok($zip->set_number('0181393')->is_valid_number, '独立行政法人 国立病院機構 あきた病院');
ok($zip->set_number('0181595')->is_valid_number, '潟上市役所 飯田川庁舎');
ok($zip->set_number('0181596')->is_valid_number, '井川町役場');
ok($zip->set_number('0181692')->is_valid_number, '八郎潟町役場');
ok($zip->set_number('0181792')->is_valid_number, '五城目町役場');
ok($zip->set_number('0181793')->is_valid_number, '秋田信用金庫 五城目支店');
ok($zip->set_number('0182498')->is_valid_number, '三種町役場');
ok($zip->set_number('0183192')->is_valid_number, '能代市役所 二ツ井町庁舎');
ok($zip->set_number('0183392')->is_valid_number, '北秋田市役所');
ok($zip->set_number('0183393')->is_valid_number, '秋田県 北秋田地域振興局');
ok($zip->set_number('0183592')->is_valid_number, '株式会社 日本オート電子工業');
ok($zip->set_number('0183593')->is_valid_number, '株式会社 田代製作所');
ok($zip->set_number('0183595')->is_valid_number, '大館市役所 田代総合支所');
ok($zip->set_number('0183596')->is_valid_number, '秋田共同乳業 株式会社');
ok($zip->set_number('0184392')->is_valid_number, '北秋田市役所 森吉支所');
ok($zip->set_number('0184494')->is_valid_number, '上小阿仁村役場');
ok($zip->set_number('0184692')->is_valid_number, '北秋田市役所 阿仁支所');
ok($zip->set_number('0184693')->is_valid_number, '阿仁スキー場');
ok($zip->set_number('0185292')->is_valid_number, '鹿角市役所');
ok($zip->set_number('0185792')->is_valid_number, '大館市役所 比内総合支所');
ok($zip->set_number('0185793')->is_valid_number, '大館市立 扇田病院');
ok($zip->set_number('0190792')->is_valid_number, '横手市役所 増田地域局');
ok($zip->set_number('0190793')->is_valid_number, 'JUKI電子工業 株式会社');
ok($zip->set_number('0191397')->is_valid_number, '株式会社 ヤマダフーズ');
ok($zip->set_number('0191692')->is_valid_number, '大仙市 太田総合支所');
ok($zip->set_number('0192192')->is_valid_number, '大仙市役所 西仙北総合支所');
ok($zip->set_number('0192492')->is_valid_number, '秋田県立リハビリテーション・精神医療センター');
ok($zip->set_number('0192692')->is_valid_number, '秋田市河辺市民センター');
ok($zip->set_number('0200182')->is_valid_number, '株式会社 赤澤紙業');
ok($zip->set_number('0200184')->is_valid_number, '山口北州印刷 株式会社');
ok($zip->set_number('0200185')->is_valid_number, '株式会社 石田商会');
ok($zip->set_number('0200187')->is_valid_number, '菱和建設 株式会社');
ok($zip->set_number('0200196')->is_valid_number, '財団法人 岩手県青少年会館');
ok($zip->set_number('0200198')->is_valid_number, '独立行政法人 農業・食品産業技術総合研究機構 東北農業研究センター');
ok($zip->set_number('0200495')->is_valid_number, '白石食品工業 株式会社');
ok($zip->set_number('0200496')->is_valid_number, '株式会社 ベルジョイス乙部センター');
ok($zip->set_number('0200592')->is_valid_number, '新岩手農業協同組合 雫石中央支所');
ok($zip->set_number('0200593')->is_valid_number, '株式会社 プリンスホテル 雫石プリンスホテル');
ok($zip->set_number('0200595')->is_valid_number, '雫石町役場');
ok($zip->set_number('0200596')->is_valid_number, '盛岡セイコー工業 株式会社');
ok($zip->set_number('0200690')->is_valid_number, 'いわて生活 協同組合');
ok($zip->set_number('0200691')->is_valid_number, '岩手県学校生活 協同組合');
ok($zip->set_number('0200692')->is_valid_number, '滝沢市役所');
ok($zip->set_number('0200693')->is_valid_number, '岩手県立大学');
ok($zip->set_number('0200694')->is_valid_number, '盛岡大学');
ok($zip->set_number('0200698')->is_valid_number, '株式会社 ミクニ');
ok($zip->set_number('0208501')->is_valid_number, '盛岡グランドホテル');
ok($zip->set_number('0208502')->is_valid_number, 'ホーマック 株式会社 盛岡事務所');
ok($zip->set_number('0208504')->is_valid_number, '仙台国税局業務センター 盛岡分室');
ok($zip->set_number('0208505')->is_valid_number, '岩手医科大学附属 内丸メディカルセンター');
ok($zip->set_number('0208507')->is_valid_number, '盛岡商工会議所');
ok($zip->set_number('0208508')->is_valid_number, '全国健康保険協会 岩手支部');
ok($zip->set_number('0208510')->is_valid_number, '岩手県自治会館');
ok($zip->set_number('0208511')->is_valid_number, '盛岡社会保険事務所');
ok($zip->set_number('0208512')->is_valid_number, '株式会社 エフエム岩手');
ok($zip->set_number('0208513')->is_valid_number, '株式会社 東山堂');
ok($zip->set_number('0208515')->is_valid_number, '岩手県立 盛岡第一高等学校');
ok($zip->set_number('0208518')->is_valid_number, '盛岡ターミナルビル 株式会社');
ok($zip->set_number('0208520')->is_valid_number, '盛岡地方裁判所');
ok($zip->set_number('0208521')->is_valid_number, '東北電力 株式会社 岩手支店');
ok($zip->set_number('0208522')->is_valid_number, '岩手労働局');
ok($zip->set_number('0208523')->is_valid_number, '盛岡労働基準監督署');
ok($zip->set_number('0208525')->is_valid_number, 'JTB 盛岡支店');
ok($zip->set_number('0208526')->is_valid_number, '東北電力ネットワーク 株式会社 岩手支社');
ok($zip->set_number('0208527')->is_valid_number, '東北電力ネットワーク 株式会社 盛岡電力センター');
ok($zip->set_number('0208530')->is_valid_number, '盛岡市役所');
ok($zip->set_number('0208531')->is_valid_number, '盛岡市役所 若園町分庁舎');
ok($zip->set_number('0208532')->is_valid_number, '盛岡市役所 都南総合支所');
ok($zip->set_number('0208533')->is_valid_number, '東日本旅客鉄道 株式会社 盛岡支社');
ok($zip->set_number('0208538')->is_valid_number, '東北農政局 盛岡地域センター');
ok($zip->set_number('0208540')->is_valid_number, '岩手県 警察本部');
ok($zip->set_number('0208543')->is_valid_number, '岩手県立 杜陵高等学校');
ok($zip->set_number('0208544')->is_valid_number, '株式会社 アイシーエス');
ok($zip->set_number('0208550')->is_valid_number, '岩手大学 (本部関係)');
ok($zip->set_number('0208551')->is_valid_number, '岩手大学 工学部');
ok($zip->set_number('0208553')->is_valid_number, '協同組合 日専連盛岡');
ok($zip->set_number('0208555')->is_valid_number, '日本放送協会 盛岡放送局');
ok($zip->set_number('0208557')->is_valid_number, '株式会社 日専連パートナーズ');
ok($zip->set_number('0208558')->is_valid_number, '東日本電信電話 株式会社 岩手支店');
ok($zip->set_number('0208560')->is_valid_number, '盛岡赤十字病院');
ok($zip->set_number('0208561')->is_valid_number, '株式会社 木津屋本店');
ok($zip->set_number('0208566')->is_valid_number, '株式会社 IBC岩手放送');
ok($zip->set_number('0208567')->is_valid_number, '盛岡市中央御売市場');
ok($zip->set_number('0208570')->is_valid_number, '岩手県庁');
ok($zip->set_number('0208573')->is_valid_number, 'ななっく 株式会社');
ok($zip->set_number('0208575')->is_valid_number, '株式会社 ワイズマン');
ok($zip->set_number('0208577')->is_valid_number, '岩手県衛生研究所');
ok($zip->set_number('0208580')->is_valid_number, '東京海上日動火災保険 株式会社 盛岡支店');
ok($zip->set_number('0208584')->is_valid_number, '一般社団法人 岩手県医師会');
ok($zip->set_number('0208585')->is_valid_number, '公益財団法人 岩手県予防医学協会');
ok($zip->set_number('0208586')->is_valid_number, '東日本ハウス 株式会社');
ok($zip->set_number('0208588')->is_valid_number, '株式会社 タカヤ');
ok($zip->set_number('0208601')->is_valid_number, '東北労働金庫 岩手県本部');
ok($zip->set_number('0208602')->is_valid_number, '日本生命保険 相互会社 盛岡支社');
ok($zip->set_number('0208605')->is_valid_number, '全国農業協同組合連合会 岩手県本部');
ok($zip->set_number('0208606')->is_valid_number, '株式会社 東北銀行');
ok($zip->set_number('0208610')->is_valid_number, '国民生活金融公庫 盛岡支店');
ok($zip->set_number('0208611')->is_valid_number, '岩手繊維 株式会社');
ok($zip->set_number('0208612')->is_valid_number, 'エビー 株式会社');
ok($zip->set_number('0208620')->is_valid_number, '株式会社 三田商店');
ok($zip->set_number('0208622')->is_valid_number, '岩手日報社');
ok($zip->set_number('0208633')->is_valid_number, '株式会社 岩手めんこいテレビ');
ok($zip->set_number('0208641')->is_valid_number, '盛岡信用金庫');
ok($zip->set_number('0208650')->is_valid_number, '株式会社 テレビ岩手');
ok($zip->set_number('0208655')->is_valid_number, '株式会社 川徳');
ok($zip->set_number('0208661')->is_valid_number, '株式会社 木津屋本店');
ok($zip->set_number('0208666')->is_valid_number, '株式会社 北日本銀行');
ok($zip->set_number('0208667')->is_valid_number, '株式会社 熊善商店');
ok($zip->set_number('0208672')->is_valid_number, '第一開明 株式会社');
ok($zip->set_number('0208677')->is_valid_number, '盛岡税務署');
ok($zip->set_number('0208678')->is_valid_number, '東北住建 株式会社');
ok($zip->set_number('0208686')->is_valid_number, '株式会社 東流社 北東北支店 盛岡営業所');
ok($zip->set_number('0208688')->is_valid_number, '株式会社 岩手銀行');
ok($zip->set_number('0208794')->is_valid_number, '岩手地域センター');
ok($zip->set_number('0218501')->is_valid_number, '一関市役所');
ok($zip->set_number('0218502')->is_valid_number, '一関社会保険事務所');
ok($zip->set_number('0218503')->is_valid_number, '県南広域振興局 一関総合支局');
ok($zip->set_number('0218504')->is_valid_number, '一関教育事務所');
ok($zip->set_number('0218506')->is_valid_number, '一関保健所');
ok($zip->set_number('0218511')->is_valid_number, '国立一関工業高等専門学校');
ok($zip->set_number('0218544')->is_valid_number, '株式会社 佐原');
ok($zip->set_number('0218555')->is_valid_number, '株式会社 平野組');
ok($zip->set_number('0218566')->is_valid_number, '日本電産コパル 株式会社 一関工場');
ok($zip->set_number('0218577')->is_valid_number, 'おりお 株式会社');
ok($zip->set_number('0218604')->is_valid_number, '一関税務署');
ok($zip->set_number('0218611')->is_valid_number, '東北日本電気 株式会社');
ok($zip->set_number('0218633')->is_valid_number, '株式会社 佐々木組');
ok($zip->set_number('0218687')->is_valid_number, '岩手日日新聞社 東台センター');
ok($zip->set_number('0228501')->is_valid_number, '大船渡市役所');
ok($zip->set_number('0228502')->is_valid_number, '大船渡地方振興局');
ok($zip->set_number('0228503')->is_valid_number, '(株) マイヤ');
ok($zip->set_number('0228504')->is_valid_number, '株式会社 アマタケ');
ok($zip->set_number('0228505')->is_valid_number, '大船渡水産物商業協同組合');
ok($zip->set_number('0228507')->is_valid_number, '大船渡市農業協同組合');
ok($zip->set_number('0228508')->is_valid_number, '鎌田水産 株式会社');
ok($zip->set_number('0228512')->is_valid_number, '岩手県立 大船渡病院');
ok($zip->set_number('0228602')->is_valid_number, '橋爪商事 (株)');
ok($zip->set_number('0230492')->is_valid_number, '奥州市 胆沢総合支所');
ok($zip->set_number('0230493')->is_valid_number, '(株) 小山製麺');
ok($zip->set_number('0231192')->is_valid_number, '奥州市 江刺総合支所');
ok($zip->set_number('0238501')->is_valid_number, '奥州市役所');
ok($zip->set_number('0240192')->is_valid_number, 'スリーエムジャパンプロダクツ 株式会社 岩手事業所');
ok($zip->set_number('0240193')->is_valid_number, '明治製菓 株式会社 北上工場');
ok($zip->set_number('0240194')->is_valid_number, '株式会社 鈴木商館 岩手事業所');
ok($zip->set_number('0240195')->is_valid_number, 'グリンクス 株式会社');
ok($zip->set_number('0240392')->is_valid_number, '北上市役所 和賀庁舎');
ok($zip->set_number('0248501')->is_valid_number, '北上市役所');
ok($zip->set_number('0248505')->is_valid_number, '花巻農業共同組合 北上支店');
ok($zip->set_number('0248506')->is_valid_number, '北上済生会病院');
ok($zip->set_number('0248507')->is_valid_number, '岩手県立 中部病院');
ok($zip->set_number('0248510')->is_valid_number, '株式会社 ジャパンセミコンダクター');
ok($zip->set_number('0248511')->is_valid_number, 'さくら野百貨店 北上店');
ok($zip->set_number('0248513')->is_valid_number, '専修大学 北上福祉教育専門学校');
ok($zip->set_number('0248518')->is_valid_number, '岩手県立 黒沢尻工業高等学校');
ok($zip->set_number('0248520')->is_valid_number, '県南広域振興局');
ok($zip->set_number('0248555')->is_valid_number, 'キオクシア岩手 株式会社');
ok($zip->set_number('0250392')->is_valid_number, '花巻温泉 株式会社');
ok($zip->set_number('0250393')->is_valid_number, '株式会社 小田島');
ok($zip->set_number('0250394')->is_valid_number, 'リコーインダストリアルソリューションズ 株式会社 花巻事業所');
ok($zip->set_number('0250395')->is_valid_number, '岩手県立 総合教育センター');
ok($zip->set_number('0258501')->is_valid_number, '学校法人 富士大学');
ok($zip->set_number('0258601')->is_valid_number, '花巻市役所');
ok($zip->set_number('0258602')->is_valid_number, '花巻 税務署');
ok($zip->set_number('0268550')->is_valid_number, '岩手県立 釜石病院');
ok($zip->set_number('0268567')->is_valid_number, '新日本製鐵 株式会社 釜石製鐵所');
ok($zip->set_number('0268686')->is_valid_number, '釜石市役所');
ok($zip->set_number('0270595')->is_valid_number, '岩泉町役場');
ok($zip->set_number('0278501')->is_valid_number, '宮古市役所');
ok($zip->set_number('0278502')->is_valid_number, '岩手県立 宮古病院');
ok($zip->set_number('0278503')->is_valid_number, '宮古社会保険事務所');
ok($zip->set_number('0280192')->is_valid_number, '花巻市 東和総合支所');
ok($zip->set_number('0280392')->is_valid_number, '遠野市 宮守総合支所');
ok($zip->set_number('0280592')->is_valid_number, '遠野市役所');
ok($zip->set_number('0281192')->is_valid_number, '大槌町役場');
ok($zip->set_number('0281392')->is_valid_number, '山田町役場');
ok($zip->set_number('0283392')->is_valid_number, '紫波町役場');
ok($zip->set_number('0283692')->is_valid_number, '矢巾町役場');
ok($zip->set_number('0283694')->is_valid_number, '学校法人 岩手医科大学');
ok($zip->set_number('0283695')->is_valid_number, '岩手医科大学 附属病院');
ok($zip->set_number('0283697')->is_valid_number, '株式会社 昆松');
ok($zip->set_number('0284193')->is_valid_number, '北日本機械 株式会社');
ok($zip->set_number('0284195')->is_valid_number, '盛岡市役所 玉山総合事務所');
ok($zip->set_number('0284393')->is_valid_number, '岩手警察署');
ok($zip->set_number('0284395')->is_valid_number, '岩手町役場');
ok($zip->set_number('0284398')->is_valid_number, '岩手県立 沼宮内高等学校');
ok($zip->set_number('0285495')->is_valid_number, '葛巻町役場');
ok($zip->set_number('0286192')->is_valid_number, '二戸市役所');
ok($zip->set_number('0286193')->is_valid_number, '岩手県立 二戸病院');
ok($zip->set_number('0286195')->is_valid_number, '株式会社 菅文');
ok($zip->set_number('0286196')->is_valid_number, '二戸社会保険事務所');
ok($zip->set_number('0286198')->is_valid_number, '二戸市総合福祉センター');
ok($zip->set_number('0286892')->is_valid_number, '二戸市役所 浄法寺総合支所');
ok($zip->set_number('0287192')->is_valid_number, '八幡平市役所');
ok($zip->set_number('0287392')->is_valid_number, '八幡平市 松尾総合支所');
ok($zip->set_number('0287393')->is_valid_number, '安比高原ゴルフクラブ');
ok($zip->set_number('0287394')->is_valid_number, '八幡平ロイヤルホテル');
ok($zip->set_number('0287395')->is_valid_number, '株式会社 岩手ホテル&リゾート');
ok($zip->set_number('0287396')->is_valid_number, 'ホテル安比グランド');
ok($zip->set_number('0287397')->is_valid_number, '八幡平市役所');
ok($zip->set_number('0287592')->is_valid_number, '八幡平市 安代総合支所');
ok($zip->set_number('0287995')->is_valid_number, '洋野町役場');
ok($zip->set_number('0288030')->is_valid_number, '久慈市役所');
ok($zip->set_number('0288031')->is_valid_number, '宮城建設 株式会社');
ok($zip->set_number('0288040')->is_valid_number, '岩手県立 久慈病院');
ok($zip->set_number('0288042')->is_valid_number, '県北広域振興局');
ok($zip->set_number('0288392')->is_valid_number, '普代村役場');
ok($zip->set_number('0288696')->is_valid_number, '久慈市役所 山形総合支所');
ok($zip->set_number('0290192')->is_valid_number, '岩手県立 磐井病院');
ok($zip->set_number('0292292')->is_valid_number, '陸前高田市役所');
ok($zip->set_number('0292293')->is_valid_number, '陸前高田市 農業協合組合');
ok($zip->set_number('0292396')->is_valid_number, '住田町役場');
ok($zip->set_number('0294192')->is_valid_number, '平泉町役場');
ok($zip->set_number('0294194')->is_valid_number, '川嶋印刷 株式会社');
ok($zip->set_number('0294195')->is_valid_number, '中尊寺');
ok($zip->set_number('0294292')->is_valid_number, '奥州市 前沢総合支所');
ok($zip->set_number('0294293')->is_valid_number, 'ジャスコ 株式会社 前沢店');
ok($zip->set_number('0294592')->is_valid_number, '金ケ崎町役場');
ok($zip->set_number('0294593')->is_valid_number, '株式会社 デンソー 岩手');
ok($zip->set_number('0295692')->is_valid_number, '西和賀町役場 沢内庁舎');
ok($zip->set_number('0300180')->is_valid_number, '株式会社 東奥日報社');
ok($zip->set_number('0300181')->is_valid_number, '青森朝日放送 株式会社');
ok($zip->set_number('0300183')->is_valid_number, '中水青森中央水産 株式会社');
ok($zip->set_number('0300184')->is_valid_number, '青森県立図書館');
ok($zip->set_number('0300185')->is_valid_number, '青森魚類 株式会社');
ok($zip->set_number('0300186')->is_valid_number, '丸大堀内 株式会社');
ok($zip->set_number('0300188')->is_valid_number, '八甲田ロープウェー 株式会社');
ok($zip->set_number('0300192')->is_valid_number, '富士通 株式会社 青森システムラボラトリ');
ok($zip->set_number('0300196')->is_valid_number, '青森公立大学');
ok($zip->set_number('0300197')->is_valid_number, '酸ヶ湯温泉');
ok($zip->set_number('0300198')->is_valid_number, '八甲田ホテル');
ok($zip->set_number('0301393')->is_valid_number, '外ヶ浜町役場');
ok($zip->set_number('0301492')->is_valid_number, '外ヶ浜町役場 平舘支所');
ok($zip->set_number('0301496')->is_valid_number, '社会福祉法人 平舘福祉会 かもめ苑');
ok($zip->set_number('0301798')->is_valid_number, '外ヶ浜町役場 三厩支所');
ok($zip->set_number('0308502')->is_valid_number, '青森県 社会保険診療報酬支払基金');
ok($zip->set_number('0308503')->is_valid_number, '株式会社 中三 本店');
ok($zip->set_number('0308505')->is_valid_number, '青森県立 保健大学');
ok($zip->set_number('0308510')->is_valid_number, '協同組合 日専連青森');
ok($zip->set_number('0308511')->is_valid_number, '青森地方法務局');
ok($zip->set_number('0308513')->is_valid_number, '東日本電信電話 株式会社 青森支店');
ok($zip->set_number('0308515')->is_valid_number, '青森商工会議所');
ok($zip->set_number('0308520')->is_valid_number, '青森山田高等学校');
ok($zip->set_number('0308521')->is_valid_number, '株式会社 奥村工務店');
ok($zip->set_number('0308522')->is_valid_number, '青森地方裁判所');
ok($zip->set_number('0308523')->is_valid_number, '青森家庭裁判所');
ok($zip->set_number('0308524')->is_valid_number, '青森簡易裁判所');
ok($zip->set_number('0308530')->is_valid_number, '青森県税事務所');
ok($zip->set_number('0308533')->is_valid_number, '協同組合 サンロード青森');
ok($zip->set_number('0308540')->is_valid_number, '青森県教育庁');
ok($zip->set_number('0308541')->is_valid_number, '青森県 信用保証協会');
ok($zip->set_number('0308543')->is_valid_number, '株式会社 角弘');
ok($zip->set_number('0308545')->is_valid_number, '青森地方検察庁');
ok($zip->set_number('0308550')->is_valid_number, '株式会社 オリエントコーポレーション 青森支店');
ok($zip->set_number('0308552')->is_valid_number, '全国健康保険協会 青森支部');
ok($zip->set_number('0308553')->is_valid_number, '青森県立 中央病院');
ok($zip->set_number('0308554')->is_valid_number, '日本年金機構 青森年金事務所');
ok($zip->set_number('0308555')->is_valid_number, '青森市役所');
ok($zip->set_number('0308556')->is_valid_number, '日本年金機構 青森事務センター');
ok($zip->set_number('0308557')->is_valid_number, '株式会社 オカムラ食品工業');
ok($zip->set_number('0308558')->is_valid_number, '青森労働局');
ok($zip->set_number('0308560')->is_valid_number, '東北電力 株式会社 青森支店');
ok($zip->set_number('0308561')->is_valid_number, '東北電力ネットワーク 株式会社 青森支社');
ok($zip->set_number('0308566')->is_valid_number, '青森県 環境保健センター');
ok($zip->set_number('0308567')->is_valid_number, '青森県 市町村職員共済組合');
ok($zip->set_number('0308570')->is_valid_number, '青森県庁');
ok($zip->set_number('0308574')->is_valid_number, 'さくら野東北 株式会社 青森店');
ok($zip->set_number('0308577')->is_valid_number, '財務省 東北財務局 青森財務事務所');
ok($zip->set_number('0308580')->is_valid_number, '東北電力ネットワーク 株式会社 青森電力センター');
ok($zip->set_number('0308585')->is_valid_number, '株式会社 みちのく銀行 事務集中室');
ok($zip->set_number('0308588')->is_valid_number, '株式会社 成田本店');
ok($zip->set_number('0308604')->is_valid_number, '日本生命保険 相互会社 青森支社');
ok($zip->set_number('0308610')->is_valid_number, '株式会社 みちのく銀行事務センター');
ok($zip->set_number('0308611')->is_valid_number, '大和證券 株式会社 青森支店');
ok($zip->set_number('0308622')->is_valid_number, '株式会社 みちのく銀行');
ok($zip->set_number('0308649')->is_valid_number, '青森県信用組合');
ok($zip->set_number('0308655')->is_valid_number, '青森放送 株式会社');
ok($zip->set_number('0308667')->is_valid_number, '商工組合中央金庫 青森支店');
ok($zip->set_number('0308668')->is_valid_number, '株式会社 青森銀行');
ok($zip->set_number('0308677')->is_valid_number, '日本銀行 青森支店');
ok($zip->set_number('0308686')->is_valid_number, '株式会社 青森テレビ');
ok($zip->set_number('0318501')->is_valid_number, '八戸工業大学');
ok($zip->set_number('0318504')->is_valid_number, 'マルヨ水産 株式会社');
ok($zip->set_number('0318505')->is_valid_number, '八戸工業大学第二高等学校');
ok($zip->set_number('0318507')->is_valid_number, '光星学院高等学校');
ok($zip->set_number('0318510')->is_valid_number, '八戸警察署');
ok($zip->set_number('0318511')->is_valid_number, '八戸商工会議所');
ok($zip->set_number('0318520')->is_valid_number, '株式会社 帝国データバンク 八戸支店');
ok($zip->set_number('0318533')->is_valid_number, '株式会社 三春屋');
ok($zip->set_number('0318538')->is_valid_number, '長崎屋 八戸店');
ok($zip->set_number('0318543')->is_valid_number, '有限会社 ヴィアノヴァ');
ok($zip->set_number('0318544')->is_valid_number, '学校法人 光星学院 本部事務局');
ok($zip->set_number('0318545')->is_valid_number, '医療法人 平成会');
ok($zip->set_number('0318550')->is_valid_number, '東北電力 株式会社 八戸営業所');
ok($zip->set_number('0318551')->is_valid_number, '青森労災病院');
ok($zip->set_number('0318555')->is_valid_number, '八戸市立 市民病院');
ok($zip->set_number('0318558')->is_valid_number, '株式会社 ヒグチ');
ok($zip->set_number('0318570')->is_valid_number, '株式会社 八戸パークホテル');
ok($zip->set_number('0318577')->is_valid_number, '株式会社 ヤマヨ');
ok($zip->set_number('0318585')->is_valid_number, 'ラピア (八戸ショッピングセンター)');
ok($zip->set_number('0318588')->is_valid_number, '八戸大学');
ok($zip->set_number('0318601')->is_valid_number, '株式会社 デーリー東北新聞社');
ok($zip->set_number('0318608')->is_valid_number, '八戸港湾運送 株式会社');
ok($zip->set_number('0318611')->is_valid_number, '八戸税務署');
ok($zip->set_number('0318612')->is_valid_number, '八戸信用金庫');
ok($zip->set_number('0318617')->is_valid_number, '大平洋金属 株式会社 八戸製造所');
ok($zip->set_number('0318655')->is_valid_number, '株式会社 吉田産業');
ok($zip->set_number('0318686')->is_valid_number, '八戸市役所');
ok($zip->set_number('0338604')->is_valid_number, '航空自衛隊 三沢基地');
ok($zip->set_number('0338666')->is_valid_number, '三沢市役所');
ok($zip->set_number('0338688')->is_valid_number, '株式会社 三沢奥入瀬観光開発');
ok($zip->set_number('0340392')->is_valid_number, '十和田市役所 十和田湖支所');
ok($zip->set_number('0340393')->is_valid_number, '八甲田農業協同組合 十和田湖支店');
ok($zip->set_number('0340398')->is_valid_number, '奥入瀬渓流グランドホテル');
ok($zip->set_number('0348565')->is_valid_number, '東北電力ネットワーク 株式会社 十和田電力センター');
ok($zip->set_number('0348578')->is_valid_number, '青森県立 三本木農業高等学校');
ok($zip->set_number('0348605')->is_valid_number, '株式会社 青森銀行 十和田支店');
ok($zip->set_number('0348613')->is_valid_number, '十和田税務署');
ok($zip->set_number('0348615')->is_valid_number, '十和田市役所');
ok($zip->set_number('0348618')->is_valid_number, '株式会社 ササキコーポレーション');
ok($zip->set_number('0348628')->is_valid_number, '北里大学 獣医畜産学部');
ok($zip->set_number('0358686')->is_valid_number, 'むつ市役所');
ok($zip->set_number('0360392')->is_valid_number, '株式会社 キョーエイ');
ok($zip->set_number('0360396')->is_valid_number, '黒石市役所');
ok($zip->set_number('0361393')->is_valid_number, '弘前市 岩木庁舎');
ok($zip->set_number('0361492')->is_valid_number, '西目屋村役場');
ok($zip->set_number('0361592')->is_valid_number, '弘前市 相馬庁舎');
ok($zip->set_number('0361593')->is_valid_number, '相馬村 農業協同組合');
ok($zip->set_number('0368501')->is_valid_number, '株式会社 サイキ');
ok($zip->set_number('0368502')->is_valid_number, 'ハローワーク弘前・弘前公共職業安定所');
ok($zip->set_number('0368503')->is_valid_number, '東北女子短期大学');
ok($zip->set_number('0368511')->is_valid_number, '津軽保険生活協同組合 健生病院');
ok($zip->set_number('0368522')->is_valid_number, 'つがる弘前農業協同組合');
ok($zip->set_number('0368530')->is_valid_number, '東北女子大学');
ok($zip->set_number('0368533')->is_valid_number, '陸上自衛隊 弘前駐屯地');
ok($zip->set_number('0368538')->is_valid_number, '日本年金機構 弘前年金事務所');
ok($zip->set_number('0368545')->is_valid_number, '独立行政法人 国立病院機構 弘前病院');
ok($zip->set_number('0368550')->is_valid_number, '弘前中央高等学校');
ok($zip->set_number('0368551')->is_valid_number, '弘前市役所');
ok($zip->set_number('0368555')->is_valid_number, '東北電力 株式会社 弘前営業所');
ok($zip->set_number('0368558')->is_valid_number, '弘前高等学校');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学 (本部)');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学 学生部');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学 教育学部');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学 生涯学習教育研究センター');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学 人文学部');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学 附属図書館');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学 保健管理センター');
ok($zip->set_number('0368560')->is_valid_number, '弘前大学事務局 (本部)');
ok($zip->set_number('0368561')->is_valid_number, '弘前大学 遺伝子実験施設');
ok($zip->set_number('0368561')->is_valid_number, '弘前大学 総合情報処理センター');
ok($zip->set_number('0368561')->is_valid_number, '弘前大学 理工学部');
ok($zip->set_number('0368561')->is_valid_number, '弘前大学農学生命科学部');
ok($zip->set_number('0368562')->is_valid_number, '弘前大学 (医学部)');
ok($zip->set_number('0368563')->is_valid_number, '弘前大学 医学部附属病院');
ok($zip->set_number('0368564')->is_valid_number, '弘前大学大学院 保健学研究科');
ok($zip->set_number('0368567')->is_valid_number, '弘前商工会議所');
ok($zip->set_number('0368577')->is_valid_number, '弘前学院大学');
ok($zip->set_number('0368585')->is_valid_number, '弘前工業高等学校');
ok($zip->set_number('0368588')->is_valid_number, '社団法人 弘前観光コンベンション協会');
ok($zip->set_number('0368601')->is_valid_number, '弘果弘前中央青果 株式会社');
ok($zip->set_number('0368642')->is_valid_number, '有限会社 鎌田屋商店');
ok($zip->set_number('0368655')->is_valid_number, '東北化学薬品 株式会社');
ok($zip->set_number('0368666')->is_valid_number, '弘前航空電子 株式会社');
ok($zip->set_number('0368686')->is_valid_number, '株式会社 青森銀行 弘前支店');
ok($zip->set_number('0368688')->is_valid_number, 'キタエアップル 株式会社');
ok($zip->set_number('0368689')->is_valid_number, '弘前 税務署');
ok($zip->set_number('0368777')->is_valid_number, '東北電力ネットワーク 株式会社 弘前電力センター');
ok($zip->set_number('0368788')->is_valid_number, 'アップルウェーブ 株式会社');
ok($zip->set_number('0370392')->is_valid_number, '中泊町役場');
ok($zip->set_number('0378601')->is_valid_number, '株式会社 五所川原エフエム');
ok($zip->set_number('0378655')->is_valid_number, '青森地方法務局 五所川原支局');
ok($zip->set_number('0378686')->is_valid_number, '五所川原市役所');
ok($zip->set_number('0380192')->is_valid_number, '平川市役所 碇ケ関総合支所');
ok($zip->set_number('0380194')->is_valid_number, '財団法人 黎明郷');
ok($zip->set_number('0380292')->is_valid_number, '大鰐町役場');
ok($zip->set_number('0381392')->is_valid_number, '青森市役所 浪岡事務所');
ok($zip->set_number('0381393')->is_valid_number, 'イトーヨーカドー青森IDC');
ok($zip->set_number('0382792')->is_valid_number, '鰺ケ沢町役場');
ok($zip->set_number('0382793')->is_valid_number, 'ナクア白神ホテル&リゾート');
ok($zip->set_number('0383192')->is_valid_number, 'つがる市役所');
ok($zip->set_number('0383193')->is_valid_number, '県立木造高校');
ok($zip->set_number('0383194')->is_valid_number, '誠仁会 尾野病院');
ok($zip->set_number('0383195')->is_valid_number, '木造町農業協同組合');
ok($zip->set_number('0383392')->is_valid_number, 'つがる市役所 車力出張所');
ok($zip->set_number('0383393')->is_valid_number, '航空自衛隊 車力分屯基地');
ok($zip->set_number('0383394')->is_valid_number, '高山稲荷神社');
ok($zip->set_number('0383595')->is_valid_number, '鶴田町役場');
ok($zip->set_number('0383692')->is_valid_number, '板柳町役場');
ok($zip->set_number('0383892')->is_valid_number, '藤崎町役場');
ok($zip->set_number('0388505')->is_valid_number, '青森市役所 柳川庁舎');
ok($zip->set_number('0388550')->is_valid_number, '青い森鉄道 株式会社');
ok($zip->set_number('0388560')->is_valid_number, '青森ヤクルト販売 株式会社');
ok($zip->set_number('0388585')->is_valid_number, '青森県 視覚障害者情報センター');
ok($zip->set_number('0390195')->is_valid_number, '南部支所');
ok($zip->set_number('0390198')->is_valid_number, '三戸町役場');
ok($zip->set_number('0390292')->is_valid_number, '田子町役場');
ok($zip->set_number('0390592')->is_valid_number, '南部町役場');
ok($zip->set_number('0390892')->is_valid_number, '福地支所');
ok($zip->set_number('0391180')->is_valid_number, '海上自衛隊 八戸航空基地隊');
ok($zip->set_number('0391181')->is_valid_number, '青森地方法務局 八戸支局');
ok($zip->set_number('0391185')->is_valid_number, '株式会社 ユニバース');
ok($zip->set_number('0391189')->is_valid_number, '三八五流通 株式会社');
ok($zip->set_number('0391192')->is_valid_number, '八戸工業高等専門学校');
ok($zip->set_number('0391193')->is_valid_number, 'カメイ 株式会社 八戸支店');
ok($zip->set_number('0391197')->is_valid_number, '三菱製紙 株式会社 八戸工場');
ok($zip->set_number('0392192')->is_valid_number, 'おいらせ町役場');
ok($zip->set_number('0392280')->is_valid_number, 'アルバック東北 株式会社');
ok($zip->set_number('0392281')->is_valid_number, 'アルバックマテリアル 株式会社 東北事業所');
ok($zip->set_number('0392282')->is_valid_number, 'アクセスケーブル 株式会社 八戸工場');
ok($zip->set_number('0392283')->is_valid_number, '八戸東洋 株式会社');
ok($zip->set_number('0392285')->is_valid_number, '東北容器工業 株式会社');
ok($zip->set_number('0392286')->is_valid_number, '日本フードパッカー 株式会社 青森工場');
ok($zip->set_number('0392287')->is_valid_number, '八戸協和水産 株式会社');
ok($zip->set_number('0392289')->is_valid_number, 'おいらせ町役場 分庁舎');
ok($zip->set_number('0392292')->is_valid_number, 'アンデス電気 株式会社 八戸工場');
ok($zip->set_number('0392293')->is_valid_number, '桃川 株式会社');
ok($zip->set_number('0392392')->is_valid_number, '六戸町役場');
ok($zip->set_number('0392492')->is_valid_number, '東北町役場');
ok($zip->set_number('0392493')->is_valid_number, '八甲田農業協同組合');
ok($zip->set_number('0392592')->is_valid_number, '七戸町役場 七戸庁舎');
ok($zip->set_number('0392593')->is_valid_number, '上北教育事務所');
ok($zip->set_number('0392594')->is_valid_number, '上北地方福祉事務所');
ok($zip->set_number('0392595')->is_valid_number, '公立七戸病院');
ok($zip->set_number('0392597')->is_valid_number, '青森県立 七戸養護学校');
ok($zip->set_number('0392598')->is_valid_number, '青森県営農大学校');
ok($zip->set_number('0392696')->is_valid_number, '東北町役場 東北分庁舎');
ok($zip->set_number('0392792')->is_valid_number, '七戸町役場');
ok($zip->set_number('0392793')->is_valid_number, 'とうほく天間農業協同組合 天間林支所');
ok($zip->set_number('0393393')->is_valid_number, '平内町役場');
ok($zip->set_number('0394292')->is_valid_number, '東通村役場');
ok($zip->set_number('0394293')->is_valid_number, '東北電力 株式会社 東通原子力発電所');
ok($zip->set_number('0394495')->is_valid_number, 'むつ市役所 大畑庁舎');
ok($zip->set_number('0394692')->is_valid_number, '大間町役場');
ok($zip->set_number('0408501')->is_valid_number, '北海道開発局 函館開発建設部');
ok($zip->set_number('0408502')->is_valid_number, '函館市 消防本部');
ok($zip->set_number('0408505')->is_valid_number, '札幌国税局業務センター 函館分室');
ok($zip->set_number('0408510')->is_valid_number, '函館練成会');
ok($zip->set_number('0408511')->is_valid_number, '北海道警察 函館方面本部');
ok($zip->set_number('0408512')->is_valid_number, '株式会社 アドバンスド・デパートメントストアーズオブジャパン 棒二森屋店');
ok($zip->set_number('0408520')->is_valid_number, '株式会社 函館アポロ商会');
ok($zip->set_number('0408522')->is_valid_number, '大槻食材 株式会社');
ok($zip->set_number('0408530')->is_valid_number, '(株) 魚長食品');
ok($zip->set_number('0408533')->is_valid_number, '函館地方法務局');
ok($zip->set_number('0408541')->is_valid_number, '函館市水道局');
ok($zip->set_number('0408543')->is_valid_number, '遺愛女子中学高等学校');
ok($zip->set_number('0408550')->is_valid_number, '函館保護観察所');
ok($zip->set_number('0408551')->is_valid_number, '(株) 弘報社 函館支社');
ok($zip->set_number('0408552')->is_valid_number, '北海道函館児童相談所');
ok($zip->set_number('0408555')->is_valid_number, '日本年金機構 函館年金事務所');
ok($zip->set_number('0408558')->is_valid_number, '北海道旅客鉄道 株式会社 函館支社');
ok($zip->set_number('0408560')->is_valid_number, '(株) JTB 函館支店');
ok($zip->set_number('0408561')->is_valid_number, '函館税関');
ok($zip->set_number('0408567')->is_valid_number, '北海道教育大学 教育学部 函館校');
ok($zip->set_number('0408577')->is_valid_number, '社会福祉法人 函館共愛会 共愛会病院');
ok($zip->set_number('0408580')->is_valid_number, 'サッポロビール 株式会社 函館支店');
ok($zip->set_number('0408581')->is_valid_number, '函館米穀 (株)');
ok($zip->set_number('0408585')->is_valid_number, '函館中央病院');
ok($zip->set_number('0408588')->is_valid_number, '明光産業 株式会社');
ok($zip->set_number('0408601')->is_valid_number, '函館地方裁判所');
ok($zip->set_number('0408602')->is_valid_number, '函館家庭裁判所');
ok($zip->set_number('0408603')->is_valid_number, '函館簡易裁判所');
ok($zip->set_number('0408605')->is_valid_number, '函館どつく 株式会社 函館造船所');
ok($zip->set_number('0408609')->is_valid_number, '函館公共職業安定所');
ok($zip->set_number('0408610')->is_valid_number, '株式会社 テーオーデパート');
ok($zip->set_number('0408611')->is_valid_number, '函館五稜郭病院');
ok($zip->set_number('0408616')->is_valid_number, '北海道放送 株式会社 函館放送局');
ok($zip->set_number('0408631')->is_valid_number, '函館赤十字病院');
ok($zip->set_number('0408632')->is_valid_number, '(株) エスイーシー');
ok($zip->set_number('0408640')->is_valid_number, '(株) 森川組');
ok($zip->set_number('0408642')->is_valid_number, '海上自衛隊 函館基地隊');
ok($zip->set_number('0408655')->is_valid_number, '日本生命相互会社 函館支店');
ok($zip->set_number('0408660')->is_valid_number, '前側石油 株式会社');
ok($zip->set_number('0408666')->is_valid_number, '函館市役所');
ok($zip->set_number('0408668')->is_valid_number, '(株) 北海道銀行 函館支店');
ok($zip->set_number('0408670')->is_valid_number, '北海道電力 (株) 函館支店');
ok($zip->set_number('0408680')->is_valid_number, '日本放送協会 函館放送局');
ok($zip->set_number('0408686')->is_valid_number, '商工中金 函館支店');
ok($zip->set_number('0408688')->is_valid_number, '(株) 北海道新聞社 函館支社');
ok($zip->set_number('0408710')->is_valid_number, '日本銀行 函館支店');
ok($zip->set_number('0408717')->is_valid_number, '(株) 北洋銀行 函館中央支店');
ok($zip->set_number('0408720')->is_valid_number, '道南うみ街信用金庫');
ok($zip->set_number('0408727')->is_valid_number, '(株) 北陸銀行 函館支店');
ok($zip->set_number('0411192')->is_valid_number, '七飯町役場');
ok($zip->set_number('0411193')->is_valid_number, '七飯町教育委員会');
ok($zip->set_number('0411194')->is_valid_number, '七飯町農業協同組合');
ok($zip->set_number('0411195')->is_valid_number, '函館厚生院 ななえ新病院');
ok($zip->set_number('0411196')->is_valid_number, '株式会社 アムコー・テクノロジー・ジャパン 函館地区');
ok($zip->set_number('0411392')->is_valid_number, '株式会社 プリンスホテル 函館大沼プリンスホテル');
ok($zip->set_number('0411496')->is_valid_number, '鹿部ロイヤルホテル');
ok($zip->set_number('0411497')->is_valid_number, '鹿部カントリー倶楽部');
ok($zip->set_number('0411498')->is_valid_number, '鹿部町役場');
ok($zip->set_number('0411692')->is_valid_number, '函館市役所南茅部支所');
ok($zip->set_number('0418501')->is_valid_number, '(株) イトーヨーカドー 函館店');
ok($zip->set_number('0418510')->is_valid_number, '大丸 株式会社 道南支店');
ok($zip->set_number('0418511')->is_valid_number, '大一興業 株式会社');
ok($zip->set_number('0418512')->is_valid_number, '独立行政法人 国立病院機構 函館病院');
ok($zip->set_number('0418515')->is_valid_number, '大興電機 株式会社');
ok($zip->set_number('0418522')->is_valid_number, '社団法人 函館市医師会 函館市医師会病院');
ok($zip->set_number('0418523')->is_valid_number, '函館日産自動車 株式会社');
ok($zip->set_number('0418540')->is_valid_number, '(株) 函館新聞社');
ok($zip->set_number('0418551')->is_valid_number, '北海道渡島保健所');
ok($zip->set_number('0418552')->is_valid_number, '北海道教育庁 実習船管理局');
ok($zip->set_number('0418553')->is_valid_number, '北海道計量検定所 函館支所');
ok($zip->set_number('0418554')->is_valid_number, '函館土木現業所');
ok($zip->set_number('0418555')->is_valid_number, '医療法人社団 仁生会 西堀病院');
ok($zip->set_number('0418556')->is_valid_number, '渡島中部地区 水産技術普及指導所');
ok($zip->set_number('0418557')->is_valid_number, '北海道教育庁 渡島教育局');
ok($zip->set_number('0418558')->is_valid_number, '北海道 渡島支庁');
ok($zip->set_number('0418560')->is_valid_number, '函館白百合学園 中学高等学校');
ok($zip->set_number('0418567')->is_valid_number, '(株) ヤマツ');
ok($zip->set_number('0418577')->is_valid_number, 'ネッツトヨタ道南 株式会社');
ok($zip->set_number('0418588')->is_valid_number, '函館運送 (株)');
ok($zip->set_number('0418589')->is_valid_number, '(株) 不二屋本店');
ok($zip->set_number('0418610')->is_valid_number, '株式会社 テーオーホールディングス');
ok($zip->set_number('0418611')->is_valid_number, '北海道大学 水産学部');
ok($zip->set_number('0418623')->is_valid_number, '函館日産自動車 株式会社 神山店');
ok($zip->set_number('0418633')->is_valid_number, '第二物産 (株)');
ok($zip->set_number('0418648')->is_valid_number, '(株) クワザワ 函館支店');
ok($zip->set_number('0418655')->is_valid_number, '公立はこだて未来大学');
ok($zip->set_number('0418680')->is_valid_number, '函館市病院局');
ok($zip->set_number('0418711')->is_valid_number, '函館トヨペット 株式会社');
ok($zip->set_number('0428501')->is_valid_number, '函館工業高等専門学校');
ok($zip->set_number('0428511')->is_valid_number, '医療法人 富田病院');
ok($zip->set_number('0428555')->is_valid_number, '函館環境衛生 株式会社');
ok($zip->set_number('0428567')->is_valid_number, '陸上自衛隊 函館駐屯地');
ok($zip->set_number('0428585')->is_valid_number, '日本中央競馬会 函館競馬場');
ok($zip->set_number('0428588')->is_valid_number, '函館大学 付属有斗高等学校');
ok($zip->set_number('0428639')->is_valid_number, '函館少年刑務所');
ok($zip->set_number('0428642')->is_valid_number, '(株) 北洋銀行 湯川支店');
ok($zip->set_number('0428678')->is_valid_number, '医療法人 函館渡辺病院');
ok($zip->set_number('0430495')->is_valid_number, '八雲町 熊石総合支所');
ok($zip->set_number('0430595')->is_valid_number, 'せたな町役場 大成支所');
ok($zip->set_number('0431498')->is_valid_number, '奥尻町役場');
ok($zip->set_number('0438558')->is_valid_number, '北海道 桧山支庁');
ok($zip->set_number('0438560')->is_valid_number, '江差町役場');
ok($zip->set_number('0438609')->is_valid_number, '函館公共職業安定所 江差出張所');
ok($zip->set_number('0438651')->is_valid_number, '江差信用金庫');
ok($zip->set_number('0440292')->is_valid_number, '喜茂別町役場');
ok($zip->set_number('0440295')->is_valid_number, 'クレードル興農 株式会社 喜茂別工場');
ok($zip->set_number('0440296')->is_valid_number, '喜茂別町商工会');
ok($zip->set_number('0448544')->is_valid_number, '北海道教育庁 後志教育局');
ok($zip->set_number('0448588')->is_valid_number, '北海道 後志支庁');
ok($zip->set_number('0458555')->is_valid_number, '岩内町役場');
ok($zip->set_number('0458609')->is_valid_number, '岩内公共職業安定所');
ok($zip->set_number('0460192')->is_valid_number, '古平町役場');
ok($zip->set_number('0460194')->is_valid_number, '社会福祉法人 古平福祉会');
ok($zip->set_number('0460292')->is_valid_number, '積丹町役場');
ok($zip->set_number('0460592')->is_valid_number, '赤井川村役場');
ok($zip->set_number('0460593')->is_valid_number, '(株) キロロアソシエイツ');
ok($zip->set_number('0460594')->is_valid_number, '小樽赤井川ゴルフクラブ');
ok($zip->set_number('0468546')->is_valid_number, '余市町役場');
ok($zip->set_number('0468555')->is_valid_number, '北海道立 中央水産試験場');
ok($zip->set_number('0468686')->is_valid_number, '北海信用金庫');
ok($zip->set_number('0470192')->is_valid_number, '小樽簡易保険加入者ホーム');
ok($zip->set_number('0470292')->is_valid_number, '独立行政法人 雇用・能力開発機構 北海道職業能力開発大学校');
ok($zip->set_number('0470298')->is_valid_number, '合同化成 株式会社');
ok($zip->set_number('0478501')->is_valid_number, '小樽商科大学');
ok($zip->set_number('0478502')->is_valid_number, '小樽商科大学 附属図書館');
ok($zip->set_number('0478503')->is_valid_number, '小樽商科大学 生活協同組合');
ok($zip->set_number('0478519')->is_valid_number, 'NTT東日本 小樽支店');
ok($zip->set_number('0478520')->is_valid_number, '小樽商工会議所');
ok($zip->set_number('0478550')->is_valid_number, '小樽市立病院');
ok($zip->set_number('0478555')->is_valid_number, '小樽開発建設部');
ok($zip->set_number('0478558')->is_valid_number, '学校法人 北照高等学校');
ok($zip->set_number('0478560')->is_valid_number, '第一管区 海上保安本部');
ok($zip->set_number('0478585')->is_valid_number, '医療法人 北仁会 石橋病院');
ok($zip->set_number('0478588')->is_valid_number, '申告書等集中処理担当部署');
ok($zip->set_number('0478601')->is_valid_number, '北海道中央バス (株)');
ok($zip->set_number('0478609')->is_valid_number, '小樽公共職業安定所');
ok($zip->set_number('0478660')->is_valid_number, '小樽市役所');
ok($zip->set_number('0478663')->is_valid_number, '株式会社 新宮商行');
ok($zip->set_number('0478666')->is_valid_number, '日本年金機構 小樽年金事務所');
ok($zip->set_number('0478677')->is_valid_number, '北海道ワイン (株)');
ok($zip->set_number('0478686')->is_valid_number, '株式会社 光合金製作所');
ok($zip->set_number('0478794')->is_valid_number, '小樽貯金事務センター');
ok($zip->set_number('0480192')->is_valid_number, '黒松内町役場');
ok($zip->set_number('0481392')->is_valid_number, '蘭越町役場');
ok($zip->set_number('0481393')->is_valid_number, 'ようてい農業協同組合 蘭越支所');
ok($zip->set_number('0481394')->is_valid_number, '(株) 熊谷本店');
ok($zip->set_number('0481395')->is_valid_number, '北海信用金庫 蘭越支店');
ok($zip->set_number('0481396')->is_valid_number, '室野建設工業 (株)');
ok($zip->set_number('0481592')->is_valid_number, 'ヒルトンニセコビレッジ');
ok($zip->set_number('0481595')->is_valid_number, 'ニセコ町役場');
ok($zip->set_number('0482292')->is_valid_number, '共和町役場');
ok($zip->set_number('0482492')->is_valid_number, '仁木町役場');
ok($zip->set_number('0482493')->is_valid_number, '新おたる農業協同組合');
ok($zip->set_number('0490192')->is_valid_number, '北斗市役所');
ok($zip->set_number('0490193')->is_valid_number, '日本セメント (株)');
ok($zip->set_number('0490692')->is_valid_number, '江差信用金庫 上ノ国支店');
ok($zip->set_number('0490693')->is_valid_number, '株式会社 カイト');
ok($zip->set_number('0490695')->is_valid_number, '北海道上ノ国高等学校');
ok($zip->set_number('0490697')->is_valid_number, '新函館農業協同組合 上ノ国支店');
ok($zip->set_number('0490698')->is_valid_number, '上ノ国町役場');
ok($zip->set_number('0491392')->is_valid_number, '福島町役場');
ok($zip->set_number('0491592')->is_valid_number, '松前町役場');
ok($zip->set_number('0491593')->is_valid_number, '松前町立松前病院');
ok($zip->set_number('0491594')->is_valid_number, '松前町教育委員会');
ok($zip->set_number('0492192')->is_valid_number, 'グリーンピア大沼');
ok($zip->set_number('0492392')->is_valid_number, '渡島信用金庫');
ok($zip->set_number('0492393')->is_valid_number, '森町役場');
ok($zip->set_number('0492394')->is_valid_number, '北海道森高等学校');
ok($zip->set_number('0493192')->is_valid_number, '八雲町役場');
ok($zip->set_number('0493197')->is_valid_number, '八雲総合病院');
ok($zip->set_number('0493198')->is_valid_number, '独立行政法人 国立病院機構 八雲病院');
ok($zip->set_number('0493592')->is_valid_number, '長万部町役場');
ok($zip->set_number('0494393')->is_valid_number, '今金町役場');
ok($zip->set_number('0494397')->is_valid_number, '今金町農業協同組合');
ok($zip->set_number('0494592')->is_valid_number, 'せたな町役場');
ok($zip->set_number('0494595')->is_valid_number, '北檜山町農業協同組合');
ok($zip->set_number('0495492')->is_valid_number, '豊浦町役場');
ok($zip->set_number('0495692')->is_valid_number, '洞爺湖町役場');
ok($zip->set_number('0495892')->is_valid_number, '洞爺温泉病院');
ok($zip->set_number('0508510')->is_valid_number, '日鐵セメント 株式会社');
ok($zip->set_number('0508511')->is_valid_number, '(株) NTT東日本 北海道 室蘭支店');
ok($zip->set_number('0508518')->is_valid_number, '(株) 北洋銀行 中島町支店');
ok($zip->set_number('0508550')->is_valid_number, '新日本製鉄 (株) 室蘭製鉄所');
ok($zip->set_number('0508570')->is_valid_number, '株式会社 楢崎製作所');
ok($zip->set_number('0508582')->is_valid_number, 'トヨタカローラ室蘭 (株)');
ok($zip->set_number('0508585')->is_valid_number, '室蘭工業大学');
ok($zip->set_number('0508588')->is_valid_number, '株式会社 モロオ 室蘭営業所');
ok($zip->set_number('0508725')->is_valid_number, '室蘭信用金庫');
ok($zip->set_number('0518501')->is_valid_number, '医療法人社団 日鋼記念病院');
ok($zip->set_number('0518505')->is_valid_number, '日本製鋼所M&E 株式会社');
ok($zip->set_number('0518511')->is_valid_number, '室蘭市役所');
ok($zip->set_number('0518512')->is_valid_number, '市立室蘭総合病院');
ok($zip->set_number('0518524')->is_valid_number, '室蘭開発建設部');
ok($zip->set_number('0518530')->is_valid_number, '室蘭市役所 広域センタービル庁舎');
ok($zip->set_number('0518546')->is_valid_number, '日鋼協力会');
ok($zip->set_number('0518550')->is_valid_number, '株式会社 室蘭民報社');
ok($zip->set_number('0518555')->is_valid_number, '北海道胆振総合振興局 保健環境部 保健行政室');
ok($zip->set_number('0518558')->is_valid_number, '北海道胆振総合振興局');
ok($zip->set_number('0518585')->is_valid_number, '室蘭社会保険事務所');
ok($zip->set_number('0518588')->is_valid_number, '吉沢商事 (株)');
ok($zip->set_number('0528511')->is_valid_number, '総合病院 伊達赤十字病院');
ok($zip->set_number('0528585')->is_valid_number, '北海道社会福祉事業団 太陽の園');
ok($zip->set_number('0528586')->is_valid_number, '伊達市立通勤センター事務所');
ok($zip->set_number('0528650')->is_valid_number, '伊達信用金庫');
ok($zip->set_number('0528666')->is_valid_number, '伊達市農業協同組合');
ok($zip->set_number('0528686')->is_valid_number, '商業協同組合 日専連だて');
ok($zip->set_number('0538505')->is_valid_number, '光陽商事 (株)');
ok($zip->set_number('0538506')->is_valid_number, '医療法人 王子総合病院');
ok($zip->set_number('0538511')->is_valid_number, '苫小牧埠頭 株式会社');
ok($zip->set_number('0538522')->is_valid_number, 'ナラサキスタックス (株)');
ok($zip->set_number('0538533')->is_valid_number, '(株) 三星');
ok($zip->set_number('0538540')->is_valid_number, '苫小牧労働基準監督署');
ok($zip->set_number('0538541')->is_valid_number, '駒澤大学附属 苫小牧高等学校');
ok($zip->set_number('0538555')->is_valid_number, '北海道苫小牧東高等学校');
ok($zip->set_number('0538570')->is_valid_number, '社団法人 苫小牧市医師会');
ok($zip->set_number('0538588')->is_valid_number, '苫小牧年金事務所');
ok($zip->set_number('0538609')->is_valid_number, '苫小牧公共職業安定所');
ok($zip->set_number('0538611')->is_valid_number, '(株) 苫小牧民報社');
ok($zip->set_number('0538619')->is_valid_number, '日本電信電話 (株) 苫小牧支店');
ok($zip->set_number('0538653')->is_valid_number, 'ホクレン農業協同組合連合会 苫小牧支所');
ok($zip->set_number('0538654')->is_valid_number, '苫小牧信用金庫');
ok($zip->set_number('0538666')->is_valid_number, '日本生命保険 相互会社 苫小牧支社');
ok($zip->set_number('0538711')->is_valid_number, '王子製紙 株式会社 苫小牧工場');
ok($zip->set_number('0538722')->is_valid_number, '苫小牧市役所');
ok($zip->set_number('0548660')->is_valid_number, 'むかわ町役場');
ok($zip->set_number('0550192')->is_valid_number, '平取町役場');
ok($zip->set_number('0550193')->is_valid_number, 'びらとり農業協同組合');
ok($zip->set_number('0550195')->is_valid_number, 'ふれあいセンターびらとり');
ok($zip->set_number('0568650')->is_valid_number, '新ひだか町役場');
ok($zip->set_number('0578511')->is_valid_number, '浦河町役場');
ok($zip->set_number('0578558')->is_valid_number, '北海道 日高振興局');
ok($zip->set_number('0580292')->is_valid_number, 'えりも町役場');
ok($zip->set_number('0588501')->is_valid_number, '様似町役場');
ok($zip->set_number('0590492')->is_valid_number, '株式会社 北海道マリンパーク');
ok($zip->set_number('0590493')->is_valid_number, '医療法人社団 千寿会 三愛病院');
ok($zip->set_number('0590496')->is_valid_number, 'マルヒラ 渡辺水産 株式会社');
ok($zip->set_number('0590592')->is_valid_number, '株式会社 登別グランドホテル');
ok($zip->set_number('0590595')->is_valid_number, '株式会社 第一滝本館');
ok($zip->set_number('0590596')->is_valid_number, '登別プリンスホテル 石水亭');
ok($zip->set_number('0590598')->is_valid_number, '独立行政法人 地域医療機能推進機構 登別病院');
ok($zip->set_number('0590993')->is_valid_number, '日本製紙 株式会社 白老工場');
ok($zip->set_number('0590995')->is_valid_number, '白老町役場');
ok($zip->set_number('0590997')->is_valid_number, '白老町消防本部');
ok($zip->set_number('0590998')->is_valid_number, '北海道栄高等学校');
ok($zip->set_number('0591292')->is_valid_number, '苫小牧駒澤大学');
ok($zip->set_number('0591392')->is_valid_number, '出光興産 (株) 北海道製油所');
ok($zip->set_number('0591393')->is_valid_number, 'トヨタ自動車北海道 株式会社');
ok($zip->set_number('0591394')->is_valid_number, '株式会社 イワクラ');
ok($zip->set_number('0591395')->is_valid_number, '日本製紙 (株) 勇払工場');
ok($zip->set_number('0591396')->is_valid_number, '豊田通商 株式会社 北海道支店');
ok($zip->set_number('0591592')->is_valid_number, '北央信用組合 早来支店');
ok($zip->set_number('0591593')->is_valid_number, 'とまこまい広域農業協同組合 早来支所');
ok($zip->set_number('0591594')->is_valid_number, '株式会社 北海道銀行 早来支店');
ok($zip->set_number('0591595')->is_valid_number, '安平町役場');
ok($zip->set_number('0591596')->is_valid_number, '早来町商工会');
ok($zip->set_number('0591692')->is_valid_number, '厚真町役場');
ok($zip->set_number('0591693')->is_valid_number, 'とまこまい広域農業協同組合 厚真支所');
ok($zip->set_number('0592192')->is_valid_number, '日高町役場');
ok($zip->set_number('0592492')->is_valid_number, '新冠町役場');
ok($zip->set_number('0592598')->is_valid_number, '陸上自衛隊 静内駐屯地');
ok($zip->set_number('0593195')->is_valid_number, '新ひだか町役場 三石総合支所');
ok($zip->set_number('0598601')->is_valid_number, '日本工学院北海道専門学校');
ok($zip->set_number('0598701')->is_valid_number, '登別市役所');
ok($zip->set_number('0608406')->is_valid_number, '北海道テレビ放送 株式会社');
ok($zip->set_number('0608501')->is_valid_number, '北海道放送 株式会社 (HBC)');
ok($zip->set_number('0608502')->is_valid_number, '株式会社 パルコ 札幌店');
ok($zip->set_number('0608503')->is_valid_number, 'メディカルプラザ札幌');
ok($zip->set_number('0608504')->is_valid_number, '富士通 株式会社 北海道支社');
ok($zip->set_number('0608505')->is_valid_number, '丸水札幌中央水産 (株)');
ok($zip->set_number('0608506')->is_valid_number, '北海道開発局 札幌開発建設部');
ok($zip->set_number('0608508')->is_valid_number, '株式会社 ニッセンレンエスコート');
ok($zip->set_number('0608510')->is_valid_number, '札幌国税局業務センター');
ok($zip->set_number('0608511')->is_valid_number, '北海道開発局');
ok($zip->set_number('0608512')->is_valid_number, '(株) ソワン・エフ');
ok($zip->set_number('0608512')->is_valid_number, '株式会社 フヨウサキナ');
ok($zip->set_number('0608512')->is_valid_number, '扶洋エステート (株)');
ok($zip->set_number('0608512')->is_valid_number, '扶洋マネージメントサービス (株)');
ok($zip->set_number('0608512')->is_valid_number, '扶洋薬品 株式会社');
ok($zip->set_number('0608513')->is_valid_number, '札幌中央信用組合');
ok($zip->set_number('0608515')->is_valid_number, '(株) 東急コミュニティー 北海道支店');
ok($zip->set_number('0608516')->is_valid_number, '新日本法規出版 (株) 札幌支社');
ok($zip->set_number('0608517')->is_valid_number, '株式会社 テレビ北海道 (TVh)');
ok($zip->set_number('0608518')->is_valid_number, '(社) 北海道退職公務員連盟開発局 退職者支部');
ok($zip->set_number('0608519')->is_valid_number, '東日本電信電話 株式会社 北海道支店');
ok($zip->set_number('0608520')->is_valid_number, '北海道警察本部');
ok($zip->set_number('0608521')->is_valid_number, '株式会社 北海道日刊スポーツ新聞社');
ok($zip->set_number('0608522')->is_valid_number, 'キヤノンマーケティングジャパン 株式会社 札幌支店');
ok($zip->set_number('0608523')->is_valid_number, '札幌日産自動車 株式会社');
ok($zip->set_number('0608525')->is_valid_number, '株式会社 モロオ');
ok($zip->set_number('0608526')->is_valid_number, '札幌公共職業安定所 札幌わかものハローワーク');
ok($zip->set_number('0608527')->is_valid_number, '北海道文化放送 株式会社 (UHB)');
ok($zip->set_number('0608528')->is_valid_number, '住友生命保険 相互会社 札幌支社');
ok($zip->set_number('0608529')->is_valid_number, '株式会社 ニップン 札幌支店');
ok($zip->set_number('0608530')->is_valid_number, '北海道瓦斯 株式会社');
ok($zip->set_number('0608531')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('0608532')->is_valid_number, '(株) エフエム北海道');
ok($zip->set_number('0608533')->is_valid_number, '株式会社 スズケン');
ok($zip->set_number('0608534')->is_valid_number, '株式会社 かんぽ生命保険 北海道エリア本部・札幌支店・札幌ヘルプデスク');
ok($zip->set_number('0608535')->is_valid_number, '戸田建設 株式会社 札幌支店');
ok($zip->set_number('0608536')->is_valid_number, '(株) 帝国データバンク 札幌支店');
ok($zip->set_number('0608537')->is_valid_number, 'エムエムエス マンションマネージメントサービス (株)');
ok($zip->set_number('0608538')->is_valid_number, '北海道住宅供給公社');
ok($zip->set_number('0608539')->is_valid_number, '中道リース 株式会社');
ok($zip->set_number('0608541')->is_valid_number, '北海道開発局 石狩川開発建設部');
ok($zip->set_number('0608542')->is_valid_number, '自衛隊札幌地方協力本部');
ok($zip->set_number('0608543')->is_valid_number, '札幌医科大学付属病院');
ok($zip->set_number('0608544')->is_valid_number, '北海道教育庁');
ok($zip->set_number('0608545')->is_valid_number, '株式会社 電通北海道');
ok($zip->set_number('0608546')->is_valid_number, 'サッポロ不動産開発 株式会社 北海道事業本部');
ok($zip->set_number('0608547')->is_valid_number, '伊藤忠商事 株式会社 北海道支社');
ok($zip->set_number('0608548')->is_valid_number, '三井不動産リアルティ札幌 株式会社');
ok($zip->set_number('0608549')->is_valid_number, '北海道教育庁 石狩教育局');
ok($zip->set_number('0608550')->is_valid_number, '株式会社 ホクレン商事');
ok($zip->set_number('0608551')->is_valid_number, '北海道社会保険診療報酬支払基金');
ok($zip->set_number('0608552')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('0608553')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('0608554')->is_valid_number, '伊藤組土建 (株)');
ok($zip->set_number('0608556')->is_valid_number, '札幌医科大学');
ok($zip->set_number('0608557')->is_valid_number, '(株) エフエム・ノースウエーブ');
ok($zip->set_number('0608558')->is_valid_number, '北海道 石狩支庁');
ok($zip->set_number('0608559')->is_valid_number, 'セカンドポスト');
ok($zip->set_number('0608560')->is_valid_number, '財団法人 北海道公立学校教職員互助会');
ok($zip->set_number('0608561')->is_valid_number, '北海道瓦斯 株式会社');
ok($zip->set_number('0608563')->is_valid_number, '綜合警備保障 (株) 北海道支社');
ok($zip->set_number('0608565')->is_valid_number, '株式会社 ほくせん');
ok($zip->set_number('0608566')->is_valid_number, '北海道労働局');
ok($zip->set_number('0608567')->is_valid_number, '財団法人 ポスタルサービスセンター 北海道地方本部');
ok($zip->set_number('0608568')->is_valid_number, '株式会社 小宮山屋');
ok($zip->set_number('0608569')->is_valid_number, '株式会社 丹波屋');
ok($zip->set_number('0608570')->is_valid_number, '医療法人 医仁会 中村記念病院');
ok($zip->set_number('0608572')->is_valid_number, '札幌市中央市税事務所');
ok($zip->set_number('0608573')->is_valid_number, '社団法人 北海道歯科医師会');
ok($zip->set_number('0608574')->is_valid_number, '北海道社会保険事務局 事務センター');
ok($zip->set_number('0608575')->is_valid_number, '西松建設 株式会社 札幌支店');
ok($zip->set_number('0608576')->is_valid_number, '株式会社 キムラ');
ok($zip->set_number('0608577')->is_valid_number, '株式会社 ジャックス 札幌支社');
ok($zip->set_number('0608578')->is_valid_number, '北海道市町村職員共済組合');
ok($zip->set_number('0608579')->is_valid_number, '北海道財務局');
ok($zip->set_number('0608580')->is_valid_number, '株式会社 ニトリパブリック');
ok($zip->set_number('0608581')->is_valid_number, '社団法人 札幌市医師会');
ok($zip->set_number('0608582')->is_valid_number, '(株) りんゆう観光');
ok($zip->set_number('0608583')->is_valid_number, '北海道電力 株式会社 ほくでん契約センター');
ok($zip->set_number('0608584')->is_valid_number, '札幌ビジネスオンデマンド スマイルポスト');
ok($zip->set_number('0608585')->is_valid_number, '日本年金機構 札幌西年金事務所');
ok($zip->set_number('0608586')->is_valid_number, '北海道大学 歯学部');
ok($zip->set_number('0608587')->is_valid_number, '札幌中央労働基準監督署');
ok($zip->set_number('0608588')->is_valid_number, '北海道庁');
ok($zip->set_number('0608589')->is_valid_number, '北海道大学 農学部');
ok($zip->set_number('0608601')->is_valid_number, '大和証券 株式会社 札幌支店');
ok($zip->set_number('0608602')->is_valid_number, '株式会社 朝日新聞社 北海道支社');
ok($zip->set_number('0608603')->is_valid_number, '財団法人 消防試験研究センター 北海道支部');
ok($zip->set_number('0608604')->is_valid_number, '市立札幌病院');
ok($zip->set_number('0608605')->is_valid_number, '株式会社 インテリジェンス');
ok($zip->set_number('0608606')->is_valid_number, 'サッポロビール 株式会社 北海道本社');
ok($zip->set_number('0608606')->is_valid_number, 'サッポロビール 株式会社 北海道本部');
ok($zip->set_number('0608607')->is_valid_number, '北海道商工会連合会');
ok($zip->set_number('0608608')->is_valid_number, '道銀カード 株式会社');
ok($zip->set_number('0608609')->is_valid_number, '三井住友海上火災保険 (株)');
ok($zip->set_number('0608610')->is_valid_number, '札幌商工会議所');
ok($zip->set_number('0608611')->is_valid_number, '札幌市役所');
ok($zip->set_number('0608612')->is_valid_number, '札幌市中央区役所');
ok($zip->set_number('0608613')->is_valid_number, 'AIGエジソン生命保険 株式会社 北海道事務センター');
ok($zip->set_number('0608614')->is_valid_number, '一般財団法人 札幌市交通事業振興公社');
ok($zip->set_number('0608615')->is_valid_number, '札幌プリンスホテル');
ok($zip->set_number('0608616')->is_valid_number, '日本労働組合 総連合会 北海道連合会');
ok($zip->set_number('0608617')->is_valid_number, '清水建設 (株) 北海道支店');
ok($zip->set_number('0608618')->is_valid_number, '中道機械 (株)');
ok($zip->set_number('0608619')->is_valid_number, '株式会社 東急百貨店 札幌店');
ok($zip->set_number('0608621')->is_valid_number, '株式会社 日本経済新聞社 札幌支社');
ok($zip->set_number('0608622')->is_valid_number, '第一三共 株式会社 札幌支店');
ok($zip->set_number('0608622')->is_valid_number, '第一三共ヘルスケア 株式会社 東日本支店 札幌オフィス');
ok($zip->set_number('0608623')->is_valid_number, '株式会社 ジェーシービー 北海道支社');
ok($zip->set_number('0608624')->is_valid_number, '日立キャピタル (株) 北海道営業本部');
ok($zip->set_number('0608625')->is_valid_number, 'UFJニコス 株式会社');
ok($zip->set_number('0608627')->is_valid_number, '社団法人 北海道医師会');
ok($zip->set_number('0608628')->is_valid_number, '北海道大学大学院 工学研究科工学部');
ok($zip->set_number('0608629')->is_valid_number, '札幌らーめん共和国');
ok($zip->set_number('0608630')->is_valid_number, '岩田地崎建設 株式会社');
ok($zip->set_number('0608631')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('0608632')->is_valid_number, '前田建設工業 株式会社 北海道支店');
ok($zip->set_number('0608634')->is_valid_number, '北海道社会保険事務局 事務センター');
ok($zip->set_number('0608635')->is_valid_number, '富士火災海上保険 (株) 北海道本部');
ok($zip->set_number('0608636')->is_valid_number, '丸紅 (株) 北海道支社');
ok($zip->set_number('0608637')->is_valid_number, '(株) 亜璃西社');
ok($zip->set_number('0608638')->is_valid_number, '北海道大学 医学部');
ok($zip->set_number('0608639')->is_valid_number, '北海道電力 株式会社 札幌支店');
ok($zip->set_number('0608640')->is_valid_number, '株式会社 北海道二十一世紀総合研究所');
ok($zip->set_number('0608641')->is_valid_number, '札幌市北部市税事務所');
ok($zip->set_number('0608642')->is_valid_number, '株式会社 リクルート北海道じゃらん');
ok($zip->set_number('0608643')->is_valid_number, '(株) 毎日新聞社 北海道支社');
ok($zip->set_number('0608644')->is_valid_number, '北海道旅客鉄道 株式会社');
ok($zip->set_number('0608646')->is_valid_number, '株式会社 ロイズコンフェクト');
ok($zip->set_number('0608647')->is_valid_number, '(株) 北海道アルバイト情報社');
ok($zip->set_number('0608648')->is_valid_number, '北海道大学病院');
ok($zip->set_number('0608649')->is_valid_number, '札幌市中央市税事務所 市民税課');
ok($zip->set_number('0608651')->is_valid_number, 'ホクレン 農業協同組合連合会');
ok($zip->set_number('0608654')->is_valid_number, '三菱商事 株式会社 北海道支社');
ok($zip->set_number('0608655')->is_valid_number, '道栄紙業 株式会社 (コアレックス)');
ok($zip->set_number('0608656')->is_valid_number, '(株) 読売新聞 東京本社 北海道支社');
ok($zip->set_number('0608658')->is_valid_number, '株式会社 北海道建設新聞社');
ok($zip->set_number('0608661')->is_valid_number, '株式会社 北洋銀行 本店');
ok($zip->set_number('0608666')->is_valid_number, '株式会社 札幌丸井三越 札幌三越');
ok($zip->set_number('0608667')->is_valid_number, '株式会社 札幌丸井三越 丸井今井札幌本店');
ok($zip->set_number('0608668')->is_valid_number, '株式会社 丸ヨ池内');
ok($zip->set_number('0608670')->is_valid_number, '北海道信用保証協会');
ok($zip->set_number('0608671')->is_valid_number, '高橋水産 (株)');
ok($zip->set_number('0608676')->is_valid_number, '株式会社 北海道銀行');
ok($zip->set_number('0608677')->is_valid_number, '北海道電力 株式会社');
ok($zip->set_number('0608678')->is_valid_number, '日本生命保険 相互会社 札幌支社');
ok($zip->set_number('0608686')->is_valid_number, '(株) ベネッセコーポレーション 北海道事業所');
ok($zip->set_number('0608687')->is_valid_number, '(株) ベネッセコーポレーション 北海道事業所');
ok($zip->set_number('0608688')->is_valid_number, '(株) ベネッセコーポレーション 北海道事業所');
ok($zip->set_number('0608703')->is_valid_number, 'NHK札幌拠点放送局');
ok($zip->set_number('0608705')->is_valid_number, '札幌テレビ放送 株式会社 (STV)');
ok($zip->set_number('0608706')->is_valid_number, '札幌テレビ放送 株式会社 (STV)');
ok($zip->set_number('0608707')->is_valid_number, '札幌テレビ放送 株式会社 (STV) どさんこワイド212');
ok($zip->set_number('0608711')->is_valid_number, '株式会社 北海道新聞社');
ok($zip->set_number('0608720')->is_valid_number, '野村證券 株式会社 札幌支店');
ok($zip->set_number('0608721')->is_valid_number, '大丸 株式会社 紙包材営業本部');
ok($zip->set_number('0608725')->is_valid_number, '北海道労働金庫 本部');
ok($zip->set_number('0608767')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('0608774')->is_valid_number, '日本郵便 株式会社 本社郵便物流営業部 販売所担当(株式会社ベルシステム24)');
ok($zip->set_number('0608776')->is_valid_number, '道新ぶんぶんクラブ「フレーっ!フレーっ!キャンペーン」事務局');
ok($zip->set_number('0608795')->is_valid_number, '北海道総合通信局');
ok($zip->set_number('0608796')->is_valid_number, '札幌監査室');
ok($zip->set_number('0608797')->is_valid_number, '株式会社 ゆうちょ銀行 札幌支店');
ok($zip->set_number('0608797')->is_valid_number, '株式会社 かんぽ生命 札幌支店');
ok($zip->set_number('0608797')->is_valid_number, '株式会社 ゆうちょ銀行 道央地域センター');
ok($zip->set_number('0608797')->is_valid_number, '日本郵便 株式会社 北海道支社');
ok($zip->set_number('0610292')->is_valid_number, '当別町役場');
ok($zip->set_number('0610293')->is_valid_number, '学校法人 東日本学園北海道医療大学');
ok($zip->set_number('0610295')->is_valid_number, '当別町農業協同組合');
ok($zip->set_number('0610296')->is_valid_number, '北海道当別高等学校');
ok($zip->set_number('0610592')->is_valid_number, '月形町役場');
ok($zip->set_number('0610595')->is_valid_number, '月形刑務所');
ok($zip->set_number('0610692')->is_valid_number, '浦臼町役場');
ok($zip->set_number('0611192')->is_valid_number, '北広島市役所');
ok($zip->set_number('0611195')->is_valid_number, '社会福祉法人 北海道リハビリー');
ok($zip->set_number('0611196')->is_valid_number, '北海道櫻井産業学園');
ok($zip->set_number('0611392')->is_valid_number, '道央農業協同組合 恵庭支所');
ok($zip->set_number('0611393')->is_valid_number, '陸上自衛隊 北海道補給処');
ok($zip->set_number('0611394')->is_valid_number, '中央コンピューターサービス 株式会社');
ok($zip->set_number('0611395')->is_valid_number, '医療法人 北晨会 恵み野病院');
ok($zip->set_number('0611396')->is_valid_number, '北海道ハイテクノロジー専門学校');
ok($zip->set_number('0611492')->is_valid_number, '合同容器 株式会社');
ok($zip->set_number('0611493')->is_valid_number, '株式会社 堀川 北海道事業部');
ok($zip->set_number('0611496')->is_valid_number, '三和シャッター工業 株式会社 札幌工場');
ok($zip->set_number('0611497')->is_valid_number, 'ニチレキ 株式会社 北海道支店');
ok($zip->set_number('0611498')->is_valid_number, '恵庭市役所');
ok($zip->set_number('0612292')->is_valid_number, '北海道札幌南陵高等学校');
ok($zip->set_number('0613197')->is_valid_number, '石狩市役所 浜益支所');
ok($zip->set_number('0613292')->is_valid_number, '石狩市役所');
ok($zip->set_number('0613293')->is_valid_number, 'エコートレーディング 株式会社 札幌支店');
ok($zip->set_number('0613294')->is_valid_number, '株式会社 モロオ 石狩物流センター');
ok($zip->set_number('0613295')->is_valid_number, 'ピップトウキョウ 株式会社 札幌センター');
ok($zip->set_number('0613296')->is_valid_number, 'YKK AP (株) 北海道工場');
ok($zip->set_number('0613692')->is_valid_number, '石狩市役所 厚田支所');
ok($zip->set_number('0618501')->is_valid_number, 'アマゾン札幌フルフィルメントセンター');
ok($zip->set_number('0628501')->is_valid_number, '北海道テレビ放送 株式会社 (HTB)');
ok($zip->set_number('0628510')->is_valid_number, '日糧製パン 株式会社');
ok($zip->set_number('0628511')->is_valid_number, '札幌開発建設部 札幌道路事務所');
ok($zip->set_number('0628513')->is_valid_number, '医療法人 柏葉脳神経外科病院');
ok($zip->set_number('0628514')->is_valid_number, '株式会社 ヤナセ 札幌支店');
ok($zip->set_number('0628516')->is_valid_number, '森林総合研究所 北海道支所');
ok($zip->set_number('0628517')->is_valid_number, '国立研究開発法人 産業技術総合研究所 北海道センター');
ok($zip->set_number('0628520')->is_valid_number, '札幌大学');
ok($zip->set_number('0628530')->is_valid_number, '北海道信用農業協同組合連合会 事務センター');
ok($zip->set_number('0628532')->is_valid_number, '矢崎総業北海道販売 株式会社');
ok($zip->set_number('0628539')->is_valid_number, '株式会社 シージーシー 北海道本部');
ok($zip->set_number('0628555')->is_valid_number, '独立行政法人 農業・食品産業技術総合研究機構 北海道農業研究センター');
ok($zip->set_number('0628558')->is_valid_number, '札幌トヨペット 株式会社');
ok($zip->set_number('0628570')->is_valid_number, '札幌市下水道局');
ok($zip->set_number('0628572')->is_valid_number, '財団法人 北海道体育協会');
ok($zip->set_number('0628575')->is_valid_number, '(株) エフエムとよひら');
ok($zip->set_number('0628601')->is_valid_number, '北海高等学校');
ok($zip->set_number('0628602')->is_valid_number, '独立行政法人 土木研究所 寒地土木研究所');
ok($zip->set_number('0628603')->is_valid_number, '北海学園札幌高等学校');
ok($zip->set_number('0628605')->is_valid_number, '北海学園大学');
ok($zip->set_number('0628607')->is_valid_number, '北海商科大学');
ok($zip->set_number('0628608')->is_valid_number, '岩倉建材 株式会社');
ok($zip->set_number('0628609')->is_valid_number, '札幌東公共職業安定所');
ok($zip->set_number('0628612')->is_valid_number, '札幌市豊平区役所');
ok($zip->set_number('0628617')->is_valid_number, '丸彦渡辺建設 株式会社');
ok($zip->set_number('0628618')->is_valid_number, '独立行政法人 地域医療機能推進機構北海道病院');
ok($zip->set_number('0628622')->is_valid_number, '株式会社 コナミデジタルエンタテインメント');
ok($zip->set_number('0628624')->is_valid_number, '株式会社 ジェイコム札幌');
ok($zip->set_number('0628630')->is_valid_number, '日本道路 株式会社 北海道支店');
ok($zip->set_number('0628631')->is_valid_number, '財団法人 北海道薬剤師会');
ok($zip->set_number('0628633')->is_valid_number, 'イワクラホーム 株式会社');
ok($zip->set_number('0628635')->is_valid_number, '株式会社 ベルコ');
ok($zip->set_number('0628641')->is_valid_number, '札幌市南部市税事務所');
ok($zip->set_number('0628642')->is_valid_number, '株式会社 本の店 岩本');
ok($zip->set_number('0628666')->is_valid_number, 'トヨタカローラ札幌 (株)');
ok($zip->set_number('0628668')->is_valid_number, 'ヤナセオートモーティブ 株式会社 札幌支店(アウディ月寒)');
ok($zip->set_number('0628686')->is_valid_number, '(株) JA北海道情報センター');
ok($zip->set_number('0638501')->is_valid_number, '生活協同組合 コープさっぽろ');
ok($zip->set_number('0638507')->is_valid_number, '和光技研 株式会社');
ok($zip->set_number('0638510')->is_valid_number, 'ニチロ畜産 株式会社');
ok($zip->set_number('0638515')->is_valid_number, '株式会社 西友 西町店');
ok($zip->set_number('0638522')->is_valid_number, '潮物産 株式会社');
ok($zip->set_number('0638555')->is_valid_number, '凸版印刷 株式会社');
ok($zip->set_number('0638558')->is_valid_number, '株式会社 エス・エス・ソリューションズ');
ok($zip->set_number('0638580')->is_valid_number, '岩橋印刷 株式会社');
ok($zip->set_number('0638585')->is_valid_number, 'イオン札幌発寒ショッピングセンター');
ok($zip->set_number('0638601')->is_valid_number, '株式会社 札幌銀行 事務センター');
ok($zip->set_number('0638602')->is_valid_number, '(株) ウエス');
ok($zip->set_number('0638603')->is_valid_number, '株式会社 須田製版');
ok($zip->set_number('0638606')->is_valid_number, '丸高水産 株式会社');
ok($zip->set_number('0638607')->is_valid_number, 'JFE条鋼 株式会社 豊平製造所');
ok($zip->set_number('0638608')->is_valid_number, '大丸藤井 株式会社 紙包材営業部');
ok($zip->set_number('0638611')->is_valid_number, '株式会社 アマネセルR&Dセンター');
ok($zip->set_number('0638612')->is_valid_number, '札幌市西区役所');
ok($zip->set_number('0638641')->is_valid_number, '札幌市西部市税事務所');
ok($zip->set_number('0638645')->is_valid_number, '札幌国税局 郵送申告書集中処理センター');
ok($zip->set_number('0648502')->is_valid_number, '北海商銀信用組合');
ok($zip->set_number('0648503')->is_valid_number, '渥美工業 (株)');
ok($zip->set_number('0648505')->is_valid_number, '北海道神宮');
ok($zip->set_number('0648506')->is_valid_number, '財団法人 北海道難病連');
ok($zip->set_number('0648509')->is_valid_number, '(株) 札幌東急イン');
ok($zip->set_number('0648510')->is_valid_number, '陸上自衛隊 北部方面総監部');
ok($zip->set_number('0648512')->is_valid_number, '三井道路 (株) 北海道支社');
ok($zip->set_number('0648514')->is_valid_number, '北海道札幌伏見支援学校');
ok($zip->set_number('0648515')->is_valid_number, '北海道換気 株式会社');
ok($zip->set_number('0648516')->is_valid_number, '札幌市 中央図書館');
ok($zip->set_number('0648518')->is_valid_number, '農林水産省 北海道農政事務所');
ok($zip->set_number('0648519')->is_valid_number, 'NTTテレワイズ・ワイドサービスセンター');
ok($zip->set_number('0648521')->is_valid_number, '清水勧業 (株)');
ok($zip->set_number('0648522')->is_valid_number, '(有) 日本書道評論社 北海道書道協会');
ok($zip->set_number('0648523')->is_valid_number, '北星学園 女子中学校高等学校');
ok($zip->set_number('0648524')->is_valid_number, '北星学園 女子短期大学');
ok($zip->set_number('0648526')->is_valid_number, '(株) サミットインターナショナル');
ok($zip->set_number('0648533')->is_valid_number, 'ジャスマックプラザ 株式会社');
ok($zip->set_number('0648535')->is_valid_number, '北海道 札幌旭丘高等学校');
ok($zip->set_number('0648536')->is_valid_number, '医療法人社団 慈藻会 平松病院');
ok($zip->set_number('0648537')->is_valid_number, '北海道森林管理局');
ok($zip->set_number('0648540')->is_valid_number, '学校法人 聖心女子学院 札幌聖心女子学院');
ok($zip->set_number('0648541')->is_valid_number, 'ネッツトヨタ道都 株式会社');
ok($zip->set_number('0648542')->is_valid_number, '(株) 日本商工振興会');
ok($zip->set_number('0648543')->is_valid_number, 'ヤマハ (株) 北海道支店');
ok($zip->set_number('0648545')->is_valid_number, '(株) 日商物産 札幌支店');
ok($zip->set_number('0648546')->is_valid_number, 'ロッテ商事 (株) 北海道統轄支店');
ok($zip->set_number('0648550')->is_valid_number, '(株) 財界さっぽろ');
ok($zip->set_number('0648551')->is_valid_number, '株式会社 福本商店');
ok($zip->set_number('0648554')->is_valid_number, '税理士法人 池脇会計事務所');
ok($zip->set_number('0648555')->is_valid_number, '財団法人 日本気象協会 北海道本部');
ok($zip->set_number('0648556')->is_valid_number, '日本ビジネス綜合専門学校');
ok($zip->set_number('0648557')->is_valid_number, '医療法人 渓仁会 札幌西円山病院');
ok($zip->set_number('0648558')->is_valid_number, '株式会社 エス・ビー・シー');
ok($zip->set_number('0648560')->is_valid_number, '道路工業 (株)');
ok($zip->set_number('0648561')->is_valid_number, 'プレミアホテル中島公園札幌');
ok($zip->set_number('0648562')->is_valid_number, '株式会社 USEN 北海道支社');
ok($zip->set_number('0648563')->is_valid_number, '(株) アンフィニアクト札幌');
ok($zip->set_number('0648564')->is_valid_number, '北海道 中央児童相談所');
ok($zip->set_number('0648565')->is_valid_number, '北海道トラック交通共済協同組合');
ok($zip->set_number('0648566')->is_valid_number, '北海道立 教職員検診センター');
ok($zip->set_number('0648567')->is_valid_number, '医療法人 シオン');
ok($zip->set_number('0648570')->is_valid_number, '医療法人 讃生会 宮の森記念病院');
ok($zip->set_number('0648571')->is_valid_number, '大正製薬 株式会社 北日本支店 札幌事業所');
ok($zip->set_number('0648575')->is_valid_number, '社会福祉法人 札幌慈啓会 慈啓会病院');
ok($zip->set_number('0648577')->is_valid_number, '北海道いすゞ自動車 株式会社');
ok($zip->set_number('0648581')->is_valid_number, '(株) 太陽');
ok($zip->set_number('0648586')->is_valid_number, '札幌市消防局');
ok($zip->set_number('0648589')->is_valid_number, '株式会社 グランビスタ ホテル&リゾート 札幌パークホテル');
ok($zip->set_number('0648609')->is_valid_number, '札幌公共職業安定所');
ok($zip->set_number('0648610')->is_valid_number, '株式会社 アークス');
ok($zip->set_number('0648611')->is_valid_number, '北海道札幌南高等学校');
ok($zip->set_number('0648620')->is_valid_number, '(株) セイコーマート');
ok($zip->set_number('0648621')->is_valid_number, '株式会社 ラルズ');
ok($zip->set_number('0648622')->is_valid_number, '北海道循環器病院');
ok($zip->set_number('0648624')->is_valid_number, '北海道 札幌西高等学校');
ok($zip->set_number('0648628')->is_valid_number, '(株) 銭高組 北海道支店');
ok($zip->set_number('0648629')->is_valid_number, '北海道札幌視覚支援学校');
ok($zip->set_number('0648630')->is_valid_number, '株式会社 ダブルス');
ok($zip->set_number('0648633')->is_valid_number, '株式会社 ビッグ');
ok($zip->set_number('0648639')->is_valid_number, '北海道 税理士会');
ok($zip->set_number('0648644')->is_valid_number, 'サザエ食品 (株)');
ok($zip->set_number('0648645')->is_valid_number, '北海道 都市職員共済組合');
ok($zip->set_number('0648648')->is_valid_number, '(株) 村住経営');
ok($zip->set_number('0648649')->is_valid_number, '(財)札幌市芸術文化財団 札幌コンサートホール');
ok($zip->set_number('0648798')->is_valid_number, '北海道郵政研修センター');
ok($zip->set_number('0658501')->is_valid_number, '関販テクノ 株式会社');
ok($zip->set_number('0658508')->is_valid_number, '(株) 北海道アマダ');
ok($zip->set_number('0658510')->is_valid_number, '(株) 構研エンジニアリング');
ok($zip->set_number('0658511')->is_valid_number, '(株) さつでん');
ok($zip->set_number('0658518')->is_valid_number, 'アリオ札幌ショッピングセンター');
ok($zip->set_number('0658522')->is_valid_number, '日本アクセス北海道 (株)');
ok($zip->set_number('0658533')->is_valid_number, '財団法人 北海道対がん協会');
ok($zip->set_number('0658543')->is_valid_number, '北海道 青果商業協同組合');
ok($zip->set_number('0658550')->is_valid_number, '大和ハウス工業 株式会社 札幌支店');
ok($zip->set_number('0658555')->is_valid_number, '医療法人社団 道都病院');
ok($zip->set_number('0658558')->is_valid_number, '北海道 札幌開成高等学校');
ok($zip->set_number('0658567')->is_valid_number, '札幌大谷短期大学');
ok($zip->set_number('0658578')->is_valid_number, '学校法人 札幌北斗学園');
ok($zip->set_number('0658601')->is_valid_number, 'ネッツトヨタ札幌 株式会社');
ok($zip->set_number('0658609')->is_valid_number, '札幌北公共職業安定所');
ok($zip->set_number('0658610')->is_valid_number, '株式会社 中山組');
ok($zip->set_number('0658611')->is_valid_number, '社会医療法人 母恋 天使病院');
ok($zip->set_number('0658612')->is_valid_number, '札幌市東区役所');
ok($zip->set_number('0658631')->is_valid_number, 'SATO社会保険労務士法人');
ok($zip->set_number('0658633')->is_valid_number, 'サッポロビール (株) 北海道本社');
ok($zip->set_number('0658639')->is_valid_number, 'サツラク農業協同組合');
ok($zip->set_number('0668501')->is_valid_number, '北海道千歳高等学校');
ok($zip->set_number('0668502')->is_valid_number, 'パナソニック (株) 回路部品事業部');
ok($zip->set_number('0668504')->is_valid_number, '国土交通省 東京航空局 新千歳空港事務所');
ok($zip->set_number('0668508')->is_valid_number, '千歳市商店街振興組合連合会');
ok($zip->set_number('0668510')->is_valid_number, '航空自衛隊 千歳基地');
ok($zip->set_number('0668512')->is_valid_number, '北海道森紙業 株式会社 札幌事業所千歳工場');
ok($zip->set_number('0668515')->is_valid_number, '道央農協協同組合 千歳支所');
ok($zip->set_number('0668520')->is_valid_number, '千歳国際ホテル 株式会社');
ok($zip->set_number('0668533')->is_valid_number, 'ミツミ電機 株式会社 千歳事業所');
ok($zip->set_number('0668550')->is_valid_number, '市立千歳市民病院');
ok($zip->set_number('0668555')->is_valid_number, '株式会社 IHIスター');
ok($zip->set_number('0668557')->is_valid_number, 'イオン北海道 株式会社 イオン千歳店');
ok($zip->set_number('0668558')->is_valid_number, '千歳商工会議所');
ok($zip->set_number('0668566')->is_valid_number, '国際電気 株式会社 千歳工場');
ok($zip->set_number('0668567')->is_valid_number, 'カルビー 株式会社 千歳工場');
ok($zip->set_number('0668570')->is_valid_number, '東洋製罐 株式会社 千歳工場');
ok($zip->set_number('0668577')->is_valid_number, '陸上自衛隊 東千歳駐屯地');
ok($zip->set_number('0668585')->is_valid_number, '株式会社 ダイナックス');
ok($zip->set_number('0668588')->is_valid_number, 'フランスベット 株式会社 北海道工場');
ok($zip->set_number('0668601')->is_valid_number, '千歳印刷 株式会社');
ok($zip->set_number('0668610')->is_valid_number, '一般社団法人 日本血液製剤機構 千歳工場');
ok($zip->set_number('0668611')->is_valid_number, '北海道千歳北陽高等学校');
ok($zip->set_number('0668622')->is_valid_number, '日本航空専門学校');
ok($zip->set_number('0668633')->is_valid_number, '北海道電力 株式会社 千歳支社');
ok($zip->set_number('0668637')->is_valid_number, '千歳全日空ホテル');
ok($zip->set_number('0668639')->is_valid_number, '北央三菱自動車販売 株式会社');
ok($zip->set_number('0668649')->is_valid_number, '全日本空輸 株式会社 千歳空港支店');
ok($zip->set_number('0668655')->is_valid_number, '学校法人 千歳科学技術大学');
ok($zip->set_number('0668660')->is_valid_number, '株式会社 山三ふじや');
ok($zip->set_number('0668666')->is_valid_number, '北海道石狩保険福祉事務所 千歳地域保健部');
ok($zip->set_number('0668668')->is_valid_number, '陸上自衛隊 北千歳駐屯地');
ok($zip->set_number('0668686')->is_valid_number, '千歳市役所');
ok($zip->set_number('0668711')->is_valid_number, 'キリンビール 株式会社 北海道千歳工場');
ok($zip->set_number('0668765')->is_valid_number, '千歳アウトレットモール・レラ');
ok($zip->set_number('0668787')->is_valid_number, 'セイコーエプソン (株) 千歳事業所');
ok($zip->set_number('0678501')->is_valid_number, '株式会社 ペイロール 北海道BPOセンター');
ok($zip->set_number('0678547')->is_valid_number, '江別商工会議所');
ok($zip->set_number('0678551')->is_valid_number, '(株) 菊水');
ok($zip->set_number('0678564')->is_valid_number, '江別高等学校');
ok($zip->set_number('0678565')->is_valid_number, '北海鋼機 (株)');
ok($zip->set_number('0678585')->is_valid_number, '江別市立病院');
ok($zip->set_number('0678674')->is_valid_number, '江別市役所');
ok($zip->set_number('0680194')->is_valid_number, '岩見市役所 栗沢支所');
ok($zip->set_number('0680492')->is_valid_number, '夕張市役所');
ok($zip->set_number('0681192')->is_valid_number, '新篠津村役場');
ok($zip->set_number('0681193')->is_valid_number, '新篠津村農業協同組合');
ok($zip->set_number('0681194')->is_valid_number, '北海道新篠津高等養護学校');
ok($zip->set_number('0681195')->is_valid_number, '社会福祉法人 新篠津福祉会');
ok($zip->set_number('0681292')->is_valid_number, '岩見沢市役所 北村支所');
ok($zip->set_number('0682192')->is_valid_number, '三笠市役所');
ok($zip->set_number('0682193')->is_valid_number, '三笠市教育委員会');
ok($zip->set_number('0682194')->is_valid_number, '市立三笠総合病院');
ok($zip->set_number('0688511')->is_valid_number, '及川産業 株式会社');
ok($zip->set_number('0688550')->is_valid_number, '北海道 教育庁空知教育局');
ok($zip->set_number('0688555')->is_valid_number, '岩見沢市立総合病院');
ok($zip->set_number('0688558')->is_valid_number, '北海道空知総合振興局');
ok($zip->set_number('0688588')->is_valid_number, '(株) きたいち');
ok($zip->set_number('0688609')->is_valid_number, '岩見沢公共職業安定所');
ok($zip->set_number('0688639')->is_valid_number, '株式会社 コミュニティエフエムはまなす');
ok($zip->set_number('0688642')->is_valid_number, '北海道教育大学 教育学部 岩見沢校');
ok($zip->set_number('0688650')->is_valid_number, '株式会社 いわせき');
ok($zip->set_number('0688660')->is_valid_number, '空知信用金庫');
ok($zip->set_number('0688666')->is_valid_number, '北燃商事 株式会社');
ok($zip->set_number('0688668')->is_valid_number, '積水化学北海道 株式会社');
ok($zip->set_number('0688686')->is_valid_number, '岩見沢市役所');
ok($zip->set_number('0688688')->is_valid_number, '岩見沢ガス (株)');
ok($zip->set_number('0690292')->is_valid_number, '南幌町役場');
ok($zip->set_number('0690293')->is_valid_number, '南幌町農業協同組合');
ok($zip->set_number('0691292')->is_valid_number, '由仁町役場');
ok($zip->set_number('0691293')->is_valid_number, '由仁町立由仁中学校');
ok($zip->set_number('0691296')->is_valid_number, 'そらち南農業協同組合 由仁支所');
ok($zip->set_number('0691297')->is_valid_number, '空知信用金庫 由仁支店');
ok($zip->set_number('0691298')->is_valid_number, '由仁町商工会');
ok($zip->set_number('0691392')->is_valid_number, '長沼町役場');
ok($zip->set_number('0691393')->is_valid_number, 'ながぬま農業協同組合');
ok($zip->set_number('0691394')->is_valid_number, '航空自衛隊長沼分屯基地');
ok($zip->set_number('0691395')->is_valid_number, '地方独立行政法人 北海道立総合研究機構農業研究本部 中央試験場');
ok($zip->set_number('0698501')->is_valid_number, '酪農学園大学');
ok($zip->set_number('0698511')->is_valid_number, '北翔大学・北翔大学短期大学部');
ok($zip->set_number('0698533')->is_valid_number, 'とわの森三愛高等学校');
ok($zip->set_number('0698555')->is_valid_number, '札幌学院大学');
ok($zip->set_number('0698585')->is_valid_number, '北海道情報大学');
ok($zip->set_number('0708502')->is_valid_number, '株式会社 湯浅');
ok($zip->set_number('0708503')->is_valid_number, '株式会社 丸善三番館');
ok($zip->set_number('0708505')->is_valid_number, '日本年金機構 旭川年金事務所');
ok($zip->set_number('0708507')->is_valid_number, '株式会社 そごう・西武 西武旭川店');
ok($zip->set_number('0708510')->is_valid_number, '(株) NTT東日本北海道 116旭川センター');
ok($zip->set_number('0708515')->is_valid_number, '旭川ガス (株)');
ok($zip->set_number('0708520')->is_valid_number, '(株) NTT東日本北海道 旭川支店');
ok($zip->set_number('0708521')->is_valid_number, '旭川中央警察署');
ok($zip->set_number('0708525')->is_valid_number, '旭川市役所');
ok($zip->set_number('0708530')->is_valid_number, '総合病院 旭川赤十字病院');
ok($zip->set_number('0708540')->is_valid_number, '旭川商工会議所');
ok($zip->set_number('0708541')->is_valid_number, '旭川市水道局');
ok($zip->set_number('0708550')->is_valid_number, '北海道森林管理局 旭川事務所');
ok($zip->set_number('0708560')->is_valid_number, '旭川トヨペット 株式会社');
ok($zip->set_number('0708567')->is_valid_number, '(株) 北海道伝統美術工芸村');
ok($zip->set_number('0708601')->is_valid_number, '北海道東海大学 旭川校舎');
ok($zip->set_number('0708610')->is_valid_number, '市立旭川病院');
ok($zip->set_number('0708611')->is_valid_number, '日本製紙 株式会社 旭川工場');
ok($zip->set_number('0708612')->is_valid_number, '株式会社 アーバンライフ 建築総合研究所');
ok($zip->set_number('0708616')->is_valid_number, '北海道旭川土木現業所');
ok($zip->set_number('0708621')->is_valid_number, '北海道教育大学 教育学部 旭川校');
ok($zip->set_number('0708630')->is_valid_number, '陸上自衛隊 旭川駐屯地');
ok($zip->set_number('0708636')->is_valid_number, '旭川地方検察庁');
ok($zip->set_number('0708639')->is_valid_number, 'イオン北海道 株式会社 イオン旭川春光店');
ok($zip->set_number('0708640')->is_valid_number, '旭川地方裁判所');
ok($zip->set_number('0708641')->is_valid_number, '旭川家庭裁判所');
ok($zip->set_number('0708642')->is_valid_number, '旭川簡易裁判所');
ok($zip->set_number('0708644')->is_valid_number, '独立行政法人 国立病院機構 旭川医療センター');
ok($zip->set_number('0708650')->is_valid_number, '山室繊維 株式会社');
ok($zip->set_number('0708651')->is_valid_number, '日本生命保険 相互会社 旭川支社');
ok($zip->set_number('0708653')->is_valid_number, '上川生産連農業会館 管理協議会');
ok($zip->set_number('0708660')->is_valid_number, '旭川信用金庫');
ok($zip->set_number('0708666')->is_valid_number, '株式会社 キシイ');
ok($zip->set_number('0708670')->is_valid_number, '株式会社 北陸銀行 旭川支店');
ok($zip->set_number('0708676')->is_valid_number, '旭川日産自動車 株式会社');
ok($zip->set_number('0708680')->is_valid_number, '日本放送協会 旭川放送局');
ok($zip->set_number('0708686')->is_valid_number, '北海道労働金庫 旭川支店');
ok($zip->set_number('0708688')->is_valid_number, '株式会社 谷内');
ok($zip->set_number('0708701')->is_valid_number, '協同組合 日専連旭川');
ok($zip->set_number('0708710')->is_valid_number, '(株) 北洋銀行 旭川中央支店');
ok($zip->set_number('0708711')->is_valid_number, '旭川トヨタ自動車 株式会社');
ok($zip->set_number('0708720')->is_valid_number, '株式会社 北海道新聞 旭川支社');
ok($zip->set_number('0708722')->is_valid_number, '旭陽電機 株式会社');
ok($zip->set_number('0708770')->is_valid_number, 'ネッツトヨタたいせつ 株式会社 神居オフィス');
ok($zip->set_number('0710192')->is_valid_number, '東神楽農業協同組合 西神楽支店');
ok($zip->set_number('0710198')->is_valid_number, '北海道立 林産試験場');
ok($zip->set_number('0710292')->is_valid_number, '美瑛町役場');
ok($zip->set_number('0710298')->is_valid_number, '美瑛町農業協同組合');
ok($zip->set_number('0710596')->is_valid_number, '上富良野町役場');
ok($zip->set_number('0710597')->is_valid_number, 'ふらの農業協同組合 上富良野支所');
ok($zip->set_number('0710795')->is_valid_number, '中富良野町役場');
ok($zip->set_number('0710798')->is_valid_number, '株式会社 西條スーパーセンターBESTOM 中富良野店');
ok($zip->set_number('0711292')->is_valid_number, '鷹栖町役場');
ok($zip->set_number('0711293')->is_valid_number, 'たいせつ農業協同組合 鷹栖支所');
ok($zip->set_number('0711295')->is_valid_number, '株式会社 ヘルス');
ok($zip->set_number('0711298')->is_valid_number, '株式会社 みらいプリンティング');
ok($zip->set_number('0711492')->is_valid_number, '東川町役場');
ok($zip->set_number('0711493')->is_valid_number, '東川町教育委員会');
ok($zip->set_number('0711494')->is_valid_number, '株式会社 天人閣');
ok($zip->set_number('0711495')->is_valid_number, '東川町農業協同組合');
ok($zip->set_number('0711496')->is_valid_number, '北工学園旭川福祉専門学校');
ok($zip->set_number('0711497')->is_valid_number, '北海道理工福祉専門学校');
ok($zip->set_number('0711592')->is_valid_number, '東神楽町役場');
ok($zip->set_number('0711593')->is_valid_number, '東神楽農業協同組合');
ok($zip->set_number('0711596')->is_valid_number, '株式会社 ヨコマク');
ok($zip->set_number('0728660')->is_valid_number, '美唄市役所');
ok($zip->set_number('0730192')->is_valid_number, '砂川社会保険事務所');
ok($zip->set_number('0730195')->is_valid_number, '砂川市役所');
ok($zip->set_number('0730196')->is_valid_number, '砂川市立病院');
ok($zip->set_number('0730197')->is_valid_number, '株式会社 北菓楼');
ok($zip->set_number('0730198')->is_valid_number, '株式会社 ホリ');
ok($zip->set_number('0730292')->is_valid_number, '上砂川町役場');
ok($zip->set_number('0730492')->is_valid_number, '歌志内市役所');
ok($zip->set_number('0738501')->is_valid_number, '中山組');
ok($zip->set_number('0738502')->is_valid_number, '滝川労働基準監督署');
ok($zip->set_number('0738510')->is_valid_number, '陸上自衛隊 滝川駐屯地');
ok($zip->set_number('0738511')->is_valid_number, '滝川商工会議所');
ok($zip->set_number('0738585')->is_valid_number, '札幌法務局 滝川支局');
ok($zip->set_number('0738686')->is_valid_number, '滝川市役所');
ok($zip->set_number('0738688')->is_valid_number, '北門信用金庫');
ok($zip->set_number('0740492')->is_valid_number, '幌加内町役場');
ok($zip->set_number('0740493')->is_valid_number, '幌加内町農業協同組合');
ok($zip->set_number('0740494')->is_valid_number, '幌加内営林署');
ok($zip->set_number('0740495')->is_valid_number, '幌加内高等学校');
ok($zip->set_number('0748585')->is_valid_number, '拓殖大学 北海道短期大学');
ok($zip->set_number('0748650')->is_valid_number, '深川市役所');
ok($zip->set_number('0748686')->is_valid_number, '北空知信用金庫');
ok($zip->set_number('0758501')->is_valid_number, '芦別市立病院');
ok($zip->set_number('0758711')->is_valid_number, '芦別市役所');
ok($zip->set_number('0768511')->is_valid_number, '株式会社 プリンスホテル 新富良野プリンスホテル');
ok($zip->set_number('0768555')->is_valid_number, '富良野市役所');
ok($zip->set_number('0768609')->is_valid_number, '旭川公共職業安定所 富良野出張所');
ok($zip->set_number('0768666')->is_valid_number, 'ふらの農業協同組合');
ok($zip->set_number('0768765')->is_valid_number, '社会福祉法人 北海道社会事業協会 富良野病院');
ok($zip->set_number('0770292')->is_valid_number, '増毛町役場');
ok($zip->set_number('0770293')->is_valid_number, '増毛漁業協同組合');
ok($zip->set_number('0770295')->is_valid_number, '増毛町教育委員会');
ok($zip->set_number('0770296')->is_valid_number, '増毛町立増毛中学校');
ok($zip->set_number('0778501')->is_valid_number, '留萌開発建設部');
ok($zip->set_number('0778511')->is_valid_number, '留萌市立総合病院');
ok($zip->set_number('0778601')->is_valid_number, '留萌市役所');
ok($zip->set_number('0778660')->is_valid_number, '留萌地区農業団体連絡協議会');
ok($zip->set_number('0778686')->is_valid_number, '留萌信用金庫');
ok($zip->set_number('0780392')->is_valid_number, '比布町役場');
ok($zip->set_number('0780397')->is_valid_number, '北海道立 上川農業試験場');
ok($zip->set_number('0781393')->is_valid_number, '当麻町役場');
ok($zip->set_number('0781395')->is_valid_number, '当麻農業協同組合');
ok($zip->set_number('0781492')->is_valid_number, '愛別町役場');
ok($zip->set_number('0781493')->is_valid_number, '愛別町教育委員会');
ok($zip->set_number('0781495')->is_valid_number, '愛別町農業協同組合');
ok($zip->set_number('0781792')->is_valid_number, '(株) 層雲閣グランドホテル');
ok($zip->set_number('0781793')->is_valid_number, '西野目産業 (株) ホテル大雪');
ok($zip->set_number('0781795')->is_valid_number, '層雲峡プリンスホテル朝陽亭');
ok($zip->set_number('0781796')->is_valid_number, 'ホテル層雲');
ok($zip->set_number('0781797')->is_valid_number, '大友観光開発 (株) 層雲峡観光ホテル');
ok($zip->set_number('0782192')->is_valid_number, '秩父別町役場');
ok($zip->set_number('0782193')->is_valid_number, '北いぶき農業協同組合');
ok($zip->set_number('0782692')->is_valid_number, '雨竜町役場');
ok($zip->set_number('0783392')->is_valid_number, '小平町役場');
ok($zip->set_number('0783393')->is_valid_number, '小平町教育委員会');
ok($zip->set_number('0783394')->is_valid_number, 'るもい農協協同組合 小平支所');
ok($zip->set_number('0783792')->is_valid_number, '苫前町役場');
ok($zip->set_number('0784193')->is_valid_number, '留萌信用金庫 羽幌支店');
ok($zip->set_number('0784194')->is_valid_number, '北海道羽幌高等学校');
ok($zip->set_number('0784196')->is_valid_number, '(株) 北海道銀行 羽幌支店');
ok($zip->set_number('0784197')->is_valid_number, '北海道立羽幌病院');
ok($zip->set_number('0784198')->is_valid_number, '羽幌町役場');
ok($zip->set_number('0784492')->is_valid_number, '初山別村役場');
ok($zip->set_number('0788501')->is_valid_number, '旭川行政評価分室');
ok($zip->set_number('0788502')->is_valid_number, '旭川地方法務局');
ok($zip->set_number('0788503')->is_valid_number, '旭川財務事務所');
ok($zip->set_number('0788504')->is_valid_number, '旭川中税務署');
ok($zip->set_number('0788505')->is_valid_number, '旭川労働基準監督署');
ok($zip->set_number('0788506')->is_valid_number, '農林水産省 北海道農政事務所 旭川地域拠点');
ok($zip->set_number('0788507')->is_valid_number, '札幌国税局業務センター 旭川分室');
ok($zip->set_number('0788510')->is_valid_number, '旭川医科大学');
ok($zip->set_number('0788511')->is_valid_number, '北海道警察旭川方面本部');
ok($zip->set_number('0788513')->is_valid_number, '旭川開発建設部');
ok($zip->set_number('0788555')->is_valid_number, '中小企業大学校旭川校');
ok($zip->set_number('0790192')->is_valid_number, 'JAみねのぶ');
ok($zip->set_number('0790197')->is_valid_number, '専修大学北海道短期大学');
ok($zip->set_number('0790198')->is_valid_number, '北海道立 林業試験場');
ok($zip->set_number('0790392')->is_valid_number, '奈井江町役場');
ok($zip->set_number('0790393')->is_valid_number, '新砂川農業協同組合 奈井江支所');
ok($zip->set_number('0790394')->is_valid_number, '株式会社 砂子組');
ok($zip->set_number('0790397')->is_valid_number, '釜屋電機 株式会社 北海道奈井江工場');
ok($zip->set_number('0790592')->is_valid_number, '妹背牛町役場');
ok($zip->set_number('0790593')->is_valid_number, '北いぶき農業協同組合 妹背牛支所');
ok($zip->set_number('0790595')->is_valid_number, '妻神工業 株式会社');
ok($zip->set_number('0791192')->is_valid_number, '赤平市役所');
ok($zip->set_number('0791393')->is_valid_number, '株式会社 オプトエレクトロニクス 芦別工場');
ok($zip->set_number('0791396')->is_valid_number, '滝沢ベニヤ 株式会社');
ok($zip->set_number('0791397')->is_valid_number, '北日本精機 株式会社');
ok($zip->set_number('0798501')->is_valid_number, '旭川市立大学・旭川市立大学短期大学部');
ok($zip->set_number('0798503')->is_valid_number, '株式会社 トワニ 旭川店');
ok($zip->set_number('0798505')->is_valid_number, '学校法人 旭川志峯学院・旭川志峯高等学校');
ok($zip->set_number('0798507')->is_valid_number, '株式会社 スハラ食品');
ok($zip->set_number('0798508')->is_valid_number, '北海道旭川永嶺高等学校');
ok($zip->set_number('0798509')->is_valid_number, '株式会社 カンディハウス');
ok($zip->set_number('0798511')->is_valid_number, '株式会社 中野銘木店');
ok($zip->set_number('0798513')->is_valid_number, '株式会社 ほくやく 旭川支店');
ok($zip->set_number('0798516')->is_valid_number, 'ジャパン建材 (株) 旭川営業所');
ok($zip->set_number('0798550')->is_valid_number, 'ネッツトヨタたいせつ 株式会社');
ok($zip->set_number('0798555')->is_valid_number, '株式会社 コハタ');
ok($zip->set_number('0798585')->is_valid_number, '株式会社 ふじ');
ok($zip->set_number('0798610')->is_valid_number, '北海道上川総合振興局');
ok($zip->set_number('0798611')->is_valid_number, '北海道上川保健所');
ok($zip->set_number('0798612')->is_valid_number, '北海道教育庁 上川教育局');
ok($zip->set_number('0798613')->is_valid_number, '北海道上川総合振興局 旭川建設管理部');
ok($zip->set_number('0798650')->is_valid_number, '株式会社 キョクイチ');
ok($zip->set_number('0798651')->is_valid_number, '丸果 旭川青果卸売市場 株式会社');
ok($zip->set_number('0798652')->is_valid_number, '株式会社 一印 旭川魚卸売市場');
ok($zip->set_number('0798656')->is_valid_number, '(株) ホクレン油機サービス 旭川支店');
ok($zip->set_number('0800196')->is_valid_number, '株式会社 柳月');
ok($zip->set_number('0800197')->is_valid_number, '十勝川温泉 第一ホテル');
ok($zip->set_number('0800198')->is_valid_number, '音更町役場');
ok($zip->set_number('0801292')->is_valid_number, '士幌町役場');
ok($zip->set_number('0801492')->is_valid_number, '上士幌町役場');
ok($zip->set_number('0801493')->is_valid_number, '上士幌町農業協同組合');
ok($zip->set_number('0802492')->is_valid_number, '帯広地方卸売市場 株式会社');
ok($zip->set_number('0802493')->is_valid_number, 'パナソニックデバイス帯広 (株)');
ok($zip->set_number('0802495')->is_valid_number, '帯広三菱ふそう自動車販売 (株)');
ok($zip->set_number('0802496')->is_valid_number, '六花亭製菓 株式会社');
ok($zip->set_number('0802497')->is_valid_number, '東北海道日野自動車 株式会社');
ok($zip->set_number('0802498')->is_valid_number, '(株) 福原');
ok($zip->set_number('0808501')->is_valid_number, '株式会社 イトーヨーカ堂 帯広店');
ok($zip->set_number('0808502')->is_valid_number, '厚生連総合病院 帯広厚生病院');
ok($zip->set_number('0808503')->is_valid_number, '北海道帯広柏葉高等学校');
ok($zip->set_number('0808510')->is_valid_number, '釧路地方法務局 帯広支局');
ok($zip->set_number('0808511')->is_valid_number, '株式会社 北海道ホテル');
ok($zip->set_number('0808515')->is_valid_number, '札幌国税局業務センター帯広分室');
ok($zip->set_number('0808518')->is_valid_number, '独立行政法人 国立病院機構 帯広病院');
ok($zip->set_number('0808531')->is_valid_number, 'イオン北海道 株式会社 イオン帯広店');
ok($zip->set_number('0808538')->is_valid_number, '株式会社 長崎屋 帯広店');
ok($zip->set_number('0808550')->is_valid_number, '株式会社 NTT東日本-北海道 北海道東支店');
ok($zip->set_number('0808555')->is_valid_number, '帯広畜産大学');
ok($zip->set_number('0808560')->is_valid_number, '北海道放送 帯広放送局');
ok($zip->set_number('0808570')->is_valid_number, 'トータルフーズ 株式会社');
ok($zip->set_number('0808585')->is_valid_number, '帯広開発建設部');
ok($zip->set_number('0808588')->is_valid_number, '北海道 十勝総合振興局');
ok($zip->set_number('0808601')->is_valid_number, '丸越 株式会社');
ok($zip->set_number('0808609')->is_valid_number, '帯広公共職業安定所');
ok($zip->set_number('0808623')->is_valid_number, '帯広日産自動車 株式会社');
ok($zip->set_number('0808639')->is_valid_number, '陸上自衛隊 帯広駐屯地');
ok($zip->set_number('0808642')->is_valid_number, '帯広市民生活協同組合');
ok($zip->set_number('0808655')->is_valid_number, '北海道新聞 帯広支社');
ok($zip->set_number('0808660')->is_valid_number, '北海道電力 株式会社 帯広支店');
ok($zip->set_number('0808666')->is_valid_number, '山田機械工業 株式会社 西7条店舗');
ok($zip->set_number('0808670')->is_valid_number, '帯広市役所');
ok($zip->set_number('0808677')->is_valid_number, '株式会社 藤丸');
ok($zip->set_number('0808680')->is_valid_number, '(株) 北洋銀行 帯広中央支店');
ok($zip->set_number('0808686')->is_valid_number, '株式会社 日専連ジェミス');
ok($zip->set_number('0808688')->is_valid_number, '株式会社 十勝毎日新聞社');
ok($zip->set_number('0808701')->is_valid_number, '帯広信用金庫');
ok($zip->set_number('0808708')->is_valid_number, '株式会社 エヌシーおびひろ');
ok($zip->set_number('0808711')->is_valid_number, '帯広商工会議所');
ok($zip->set_number('0808718')->is_valid_number, 'ホクレン農業協同組合連合会 帯広支所');
ok($zip->set_number('0810292')->is_valid_number, '鹿追町役場');
ok($zip->set_number('0810293')->is_valid_number, '鹿追町農業協同組合');
ok($zip->set_number('0810294')->is_valid_number, '陸上自衛隊 鹿追駐屯地業務隊');
ok($zip->set_number('0810295')->is_valid_number, '鹿追町国民健康保険病院');
ok($zip->set_number('0818501')->is_valid_number, '新得町役場');
ok($zip->set_number('0828650')->is_valid_number, '芽室町農業協同組合');
ok($zip->set_number('0828651')->is_valid_number, '芽室町役場');
ok($zip->set_number('0838585')->is_valid_number, '(有) ノース・ドリーム');
ok($zip->set_number('0838650')->is_valid_number, '池田町役場');
ok($zip->set_number('0848501')->is_valid_number, '道東国分 株式会社');
ok($zip->set_number('0848511')->is_valid_number, '釧路運転免許試験場');
ok($zip->set_number('0848555')->is_valid_number, '釧路スバル自動車 株式会社');
ok($zip->set_number('0848567')->is_valid_number, '株式会社 スハラ食品 釧路支店');
ok($zip->set_number('0848670')->is_valid_number, '大丸藤井 株式会社 釧路支店');
ok($zip->set_number('0848686')->is_valid_number, 'サンエス電気通信 株式会社');
ok($zip->set_number('0850292')->is_valid_number, '釧路市阿寒町行政センター');
ok($zip->set_number('0850293')->is_valid_number, '阿寒農業協同組合');
ok($zip->set_number('0858501')->is_valid_number, '株式会社 NTT東日本-北海道 釧路支店');
ok($zip->set_number('0858502')->is_valid_number, '日本年金機構 釧路年金事務所');
ok($zip->set_number('0858505')->is_valid_number, '釧路市役所');
ok($zip->set_number('0858510')->is_valid_number, '釧路労働基準監督署');
ok($zip->set_number('0858511')->is_valid_number, '北海道警察 釧路方面本部');
ok($zip->set_number('0858512')->is_valid_number, '総合病院 釧路赤十字病院');
ok($zip->set_number('0858515')->is_valid_number, '釧路税務署');
ok($zip->set_number('0858522')->is_valid_number, '釧路地方法務局');
ok($zip->set_number('0858527')->is_valid_number, '株式会社 日専連釧路');
ok($zip->set_number('0858533')->is_valid_number, '独立行政法人 労働者健康福祉機構 釧路労災病院');
ok($zip->set_number('0858535')->is_valid_number, '釧路保護観察所');
ok($zip->set_number('0858550')->is_valid_number, '金井漁業 (株)');
ok($zip->set_number('0858551')->is_valid_number, '釧路開発建設部');
ok($zip->set_number('0858555')->is_valid_number, '釧路ガス (株)');
ok($zip->set_number('0858557')->is_valid_number, '釧路地方検察庁');
ok($zip->set_number('0858558')->is_valid_number, '市立釧路総合病院');
ok($zip->set_number('0858567')->is_valid_number, '釧路刑務所');
ok($zip->set_number('0858580')->is_valid_number, '北海道教育大学 教育学部 釧路校');
ok($zip->set_number('0858581')->is_valid_number, '釧路プリンスホテル');
ok($zip->set_number('0858585')->is_valid_number, '釧路公立大学');
ok($zip->set_number('0858586')->is_valid_number, '釧路地方気象台');
ok($zip->set_number('0858588')->is_valid_number, '北海道釧路総合振興局');
ok($zip->set_number('0858639')->is_valid_number, '北海道地方環境事務所 釧路自然環境事務所');
ok($zip->set_number('0858649')->is_valid_number, '釧路財務事務所');
ok($zip->set_number('0858650')->is_valid_number, '(株) 釧路新聞社');
ok($zip->set_number('0858655')->is_valid_number, '(株) 北海道新聞社 釧路支社');
ok($zip->set_number('0858660')->is_valid_number, '日本放送協会 釧路放送局');
ok($zip->set_number('0858668')->is_valid_number, '北海道電力 (株) 釧路支店');
ok($zip->set_number('0858677')->is_valid_number, '日本生命保険 相互会社 釧路支社');
ok($zip->set_number('0861197')->is_valid_number, '中標津町役場');
ok($zip->set_number('0861892')->is_valid_number, '羅臼町役場');
ok($zip->set_number('0861893')->is_valid_number, '羅臼漁業協同組合');
ok($zip->set_number('0870192')->is_valid_number, '歯舞漁業協同組合');
ok($zip->set_number('0878555')->is_valid_number, '航空自衛隊 根室分屯基地');
ok($zip->set_number('0878588')->is_valid_number, '北海道根室振興局');
ok($zip->set_number('0878609')->is_valid_number, '根室公共職業安定所');
ok($zip->set_number('0878686')->is_valid_number, '市立根室病院');
ok($zip->set_number('0878711')->is_valid_number, '根室市役所');
ok($zip->set_number('0880192')->is_valid_number, '釧路市音別町行政センター');
ok($zip->set_number('0880193')->is_valid_number, '株式会社 大塚製薬工場 釧路工場');
ok($zip->set_number('0880392')->is_valid_number, '白糠町役場');
ok($zip->set_number('0880393')->is_valid_number, '白糠町農業 協同組合');
ok($zip->set_number('0880394')->is_valid_number, '白糠町漁業 協同組合');
ok($zip->set_number('0880395')->is_valid_number, '白糠町商工会');
ok($zip->set_number('0880592')->is_valid_number, '東和食品 株式会社');
ok($zip->set_number('0880595')->is_valid_number, '株式会社 釧路丸水');
ok($zip->set_number('0880598')->is_valid_number, '広洋水産 株式会社');
ok($zip->set_number('0880692')->is_valid_number, '釧路町役場');
ok($zip->set_number('0881192')->is_valid_number, '厚岸町役場');
ok($zip->set_number('0881193')->is_valid_number, '大地みらい信用金庫 厚岸支店');
ok($zip->set_number('0881195')->is_valid_number, '町立厚岸病院');
ok($zip->set_number('0881592')->is_valid_number, '浜中町役場');
ok($zip->set_number('0882592')->is_valid_number, '道東あさひ農業協同組合 西春別支所');
ok($zip->set_number('0882593')->is_valid_number, '陸上自衛隊 別海駐屯地');
ok($zip->set_number('0883292')->is_valid_number, '弟子屈町');
ok($zip->set_number('0883293')->is_valid_number, '薬学検定事務局 細見');
ok($zip->set_number('0883395')->is_valid_number, '屈斜路プリンスホテル');
ok($zip->set_number('0890192')->is_valid_number, '清水町役場');
ok($zip->set_number('0890195')->is_valid_number, '清水赤十字病院');
ok($zip->set_number('0890198')->is_valid_number, '十勝清水町農業協同組合');
ok($zip->set_number('0890592')->is_valid_number, '札内農業協同組合');
ok($zip->set_number('0890595')->is_valid_number, '(株) 十勝正直村');
ok($zip->set_number('0890598')->is_valid_number, '札内砕石砂利 株式会社');
ok($zip->set_number('0890692')->is_valid_number, '幕別町役場');
ok($zip->set_number('0890693')->is_valid_number, '幕別町農業協同組合');
ok($zip->set_number('0891192')->is_valid_number, '帯広刑務所');
ok($zip->set_number('0891198')->is_valid_number, '帯広市川西農業協同組合');
ok($zip->set_number('0891392')->is_valid_number, '中札内村役場');
ok($zip->set_number('0891395')->is_valid_number, '中札内村農業協同組合');
ok($zip->set_number('0891592')->is_valid_number, '更別村農業協同組合');
ok($zip->set_number('0891595')->is_valid_number, '更別村役場');
ok($zip->set_number('0891795')->is_valid_number, '幕別町役場 忠類総合支所');
ok($zip->set_number('0892195')->is_valid_number, '大樹町役場');
ok($zip->set_number('0892492')->is_valid_number, '広尾町農業協同組合');
ok($zip->set_number('0892692')->is_valid_number, '広尾町');
ok($zip->set_number('0892693')->is_valid_number, '広尾サンタランド事務局');
ok($zip->set_number('0892695')->is_valid_number, '帯広信用金庫 広尾支店');
ok($zip->set_number('0892696')->is_valid_number, '株式会社 北海道銀行 広尾支店');
ok($zip->set_number('0892697')->is_valid_number, '日高信用金庫 広尾支店');
ok($zip->set_number('0893392')->is_valid_number, '本別町役場');
ok($zip->set_number('0893797')->is_valid_number, '足寄町役場');
ok($zip->set_number('0895392')->is_valid_number, '豊頃町役場');
ok($zip->set_number('0895393')->is_valid_number, '豊頃町農業協同組合');
ok($zip->set_number('0895692')->is_valid_number, '浦幌町役場');
ok($zip->set_number('0895695')->is_valid_number, '浦幌町農業協同組合');
ok($zip->set_number('0908501')->is_valid_number, '北見市役所');
ok($zip->set_number('0908502')->is_valid_number, '株式会社 トワニ 北見店');
ok($zip->set_number('0908503')->is_valid_number, '北見バス (株)');
ok($zip->set_number('0908507')->is_valid_number, '北見工業大学');
ok($zip->set_number('0908509')->is_valid_number, '(株) きたみ東急百貨店');
ok($zip->set_number('0908511')->is_valid_number, '北海道警察 北見方面本部');
ok($zip->set_number('0908518')->is_valid_number, '北海道 北見保健所');
ok($zip->set_number('0908519')->is_valid_number, '株式会社 北見東急イン');
ok($zip->set_number('0908532')->is_valid_number, '北海道労働金庫 北見支店');
ok($zip->set_number('0908533')->is_valid_number, '北海道北見柏陽高等学校');
ok($zip->set_number('0908540')->is_valid_number, '北見労働基準監督署');
ok($zip->set_number('0908550')->is_valid_number, '大丸 株式会社 道北支店北見出張所');
ok($zip->set_number('0908555')->is_valid_number, '学校法人 北海学園北見校地');
ok($zip->set_number('0908558')->is_valid_number, '北海道 北見緑陵高等学校');
ok($zip->set_number('0908560')->is_valid_number, '株式会社 マルモ');
ok($zip->set_number('0908567')->is_valid_number, '小林病院');
ok($zip->set_number('0908580')->is_valid_number, '株式会社 ノースウインド');
ok($zip->set_number('0908585')->is_valid_number, '北見社会保険事務所');
ok($zip->set_number('0908588')->is_valid_number, '北海道森林管理局 北見事務所');
ok($zip->set_number('0908610')->is_valid_number, '有限会社 勉強屋本部');
ok($zip->set_number('0908642')->is_valid_number, '北見藤女子高等学校');
ok($zip->set_number('0908650')->is_valid_number, '北見農業会館管理運営委員会');
ok($zip->set_number('0908652')->is_valid_number, '北見トヨペット (株)');
ok($zip->set_number('0908655')->is_valid_number, '北海道新聞 北見支社');
ok($zip->set_number('0908666')->is_valid_number, '総合病院 北見赤十字病院');
ok($zip->set_number('0908680')->is_valid_number, '(株) 帝国データバンク 北見支店');
ok($zip->set_number('0908701')->is_valid_number, '北見市上下水道局');
ok($zip->set_number('0908710')->is_valid_number, '北見商工会議所');
ok($zip->set_number('0908711')->is_valid_number, '北見信用金庫');
ok($zip->set_number('0908722')->is_valid_number, '住友生命保険 相互会社 北見支店');
ok($zip->set_number('0908723')->is_valid_number, '北見日産自動車 株式会社');
ok($zip->set_number('0908729')->is_valid_number, '(株) 日専連ニックコーポレーション');
ok($zip->set_number('0910192')->is_valid_number, 'きたみらい農業協同組合 温根湯支所');
ok($zip->set_number('0910193')->is_valid_number, '(株) 大江本家');
ok($zip->set_number('0910194')->is_valid_number, 'オホーツク観光 (株) 温根湯ホテル');
ok($zip->set_number('0918666')->is_valid_number, '北見市役所 留辺蘂総合支所');
ok($zip->set_number('0920292')->is_valid_number, '津別町役場');
ok($zip->set_number('0928501')->is_valid_number, '陸上自衛隊 美幌駐屯地');
ok($zip->set_number('0928650')->is_valid_number, '美幌町役場');
ok($zip->set_number('0928651')->is_valid_number, '美幌町農業協同組合');
ok($zip->set_number('0930292')->is_valid_number, '北見市役所 常呂総合支所');
ok($zip->set_number('0930592')->is_valid_number, '佐呂間町役場');
ok($zip->set_number('0930593')->is_valid_number, '佐呂間町農業協同組合');
ok($zip->set_number('0930594')->is_valid_number, '佐呂間漁業協同組合');
ok($zip->set_number('0938544')->is_valid_number, '北海道開発局 網走開発建設部');
ok($zip->set_number('0938555')->is_valid_number, '網走市役所');
ok($zip->set_number('0938585')->is_valid_number, '北海道オホーツク総合振興局');
ok($zip->set_number('0938609')->is_valid_number, '網走公共職業安定所');
ok($zip->set_number('0938619')->is_valid_number, '北海道教育庁網走教育局');
ok($zip->set_number('0938650')->is_valid_number, '網走信用金庫 本店');
ok($zip->set_number('0938670')->is_valid_number, '北海道オホーツク総合振興局 網走建設管理部');
ok($zip->set_number('0938680')->is_valid_number, '(株) 北洋銀行 網走支店');
ok($zip->set_number('0938686')->is_valid_number, '釧路信用組合 網走支店');
ok($zip->set_number('0938710')->is_valid_number, '(株) 光和');
ok($zip->set_number('0938711')->is_valid_number, '島田建設 (株)');
ok($zip->set_number('0938728')->is_valid_number, 'オホーツク網走農業協同組合');
ok($zip->set_number('0948551')->is_valid_number, 'みゆき観光開発 株式会社');
ok($zip->set_number('0948553')->is_valid_number, '北方建設産業 株式会社');
ok($zip->set_number('0948554')->is_valid_number, '北海道オホーツク総合振興局 紋別道税事務所');
ok($zip->set_number('0948601')->is_valid_number, '紋別漁業協同組合');
ok($zip->set_number('0948602')->is_valid_number, '北海道信用漁業協同組合連合会 北見支店');
ok($zip->set_number('0948609')->is_valid_number, '紋別公共職業安定所');
ok($zip->set_number('0948641')->is_valid_number, '紋別警察署');
ok($zip->set_number('0948642')->is_valid_number, '北海道 紋別保健所');
ok($zip->set_number('0948643')->is_valid_number, '北海道紋別高等学校');
ok($zip->set_number('0948644')->is_valid_number, 'マルカイチ水産 株式会社');
ok($zip->set_number('0948645')->is_valid_number, 'イオン北海道 株式会社 紋別店');
ok($zip->set_number('0948646')->is_valid_number, '北海道立 紋別高等看護学院');
ok($zip->set_number('0948701')->is_valid_number, '紋別商工会議所');
ok($zip->set_number('0948702')->is_valid_number, '株式会社 丸三 岩倉商店');
ok($zip->set_number('0948703')->is_valid_number, '(株) 北洋銀行 紋別中央支店');
ok($zip->set_number('0948704')->is_valid_number, '大安サービス 株式会社');
ok($zip->set_number('0948705')->is_valid_number, '株式会社 三幸');
ok($zip->set_number('0948706')->is_valid_number, '北見信用金庫 紋別支店');
ok($zip->set_number('0948707')->is_valid_number, '紋別市役所');
ok($zip->set_number('0948708')->is_valid_number, '東海倉庫 株式会社');
ok($zip->set_number('0948709')->is_valid_number, '広域紋別病院企業団');
ok($zip->set_number('0948710')->is_valid_number, 'オホーツクはまなす農協');
ok($zip->set_number('0948712')->is_valid_number, '株式会社 民友商事');
ok($zip->set_number('0948713')->is_valid_number, '株式会社 北海道銀行 紋別支店');
ok($zip->set_number('0948714')->is_valid_number, '大原病院');
ok($zip->set_number('0948715')->is_valid_number, '株式会社 西村組 紋別支店');
ok($zip->set_number('0948716')->is_valid_number, '紋別医師会');
ok($zip->set_number('0948717')->is_valid_number, '株式会社 藤川水産');
ok($zip->set_number('0950492')->is_valid_number, '士別市 朝日総合支所');
ok($zip->set_number('0958609')->is_valid_number, '名寄公共職業安定所 士別出張所');
ok($zip->set_number('0958686')->is_valid_number, '士別市役所');
ok($zip->set_number('0968501')->is_valid_number, '株式会社 西條');
ok($zip->set_number('0968508')->is_valid_number, '株式会社 西厚商事');
ok($zip->set_number('0968511')->is_valid_number, '名寄市立総合病院');
ok($zip->set_number('0968555')->is_valid_number, '北陽製紙 (株)');
ok($zip->set_number('0968558')->is_valid_number, '(株) 西條本部');
ok($zip->set_number('0968584')->is_valid_number, '陸上自衛隊 名寄駐屯地');
ok($zip->set_number('0968585')->is_valid_number, '吉田病院');
ok($zip->set_number('0968609')->is_valid_number, '名寄公共職業安定所');
ok($zip->set_number('0968641')->is_valid_number, '名寄市立大学');
ok($zip->set_number('0968666')->is_valid_number, '名寄信用金庫');
ok($zip->set_number('0968686')->is_valid_number, '名寄市役所');
ok($zip->set_number('0978510')->is_valid_number, '稚内年金事務所');
ok($zip->set_number('0978525')->is_valid_number, '北海道 稚内保健所');
ok($zip->set_number('0978527')->is_valid_number, '稚内開発建設部');
ok($zip->set_number('0978555')->is_valid_number, '市立稚内病院');
ok($zip->set_number('0978558')->is_valid_number, '北海道 宗谷総合振興局');
ok($zip->set_number('0978585')->is_valid_number, '稚内土木現業所');
ok($zip->set_number('0978609')->is_valid_number, '稚内公共職業安定所');
ok($zip->set_number('0978639')->is_valid_number, '北海道教育庁 宗谷教育局');
ok($zip->set_number('0978666')->is_valid_number, '稚内信用金庫 本店');
ok($zip->set_number('0978678')->is_valid_number, '北海道稚内高等学校');
ok($zip->set_number('0978686')->is_valid_number, '稚内市役所');
ok($zip->set_number('0980192')->is_valid_number, '和寒町役場');
ok($zip->set_number('0980392')->is_valid_number, '剣淵町役場');
ok($zip->set_number('0981692')->is_valid_number, '興部町役場');
ok($zip->set_number('0981693')->is_valid_number, '北オホーツク農業協同組合');
ok($zip->set_number('0981792')->is_valid_number, '雄武町役場');
ok($zip->set_number('0982892')->is_valid_number, '中川町役場');
ok($zip->set_number('0983392')->is_valid_number, '留萌北部森林管理署');
ok($zip->set_number('0983393')->is_valid_number, '北海道天塩高等学校');
ok($zip->set_number('0983395')->is_valid_number, 'るもい農協協同組合 天塩支所');
ok($zip->set_number('0983396')->is_valid_number, '留萌保健福祉事務所 天塩支所');
ok($zip->set_number('0983398')->is_valid_number, '天塩町役場');
ok($zip->set_number('0985298')->is_valid_number, '枝幸町役場 歌登総合支所');
ok($zip->set_number('0985595')->is_valid_number, '中頓別町役場');
ok($zip->set_number('0985792')->is_valid_number, '浜頓別町役場');
ok($zip->set_number('0985892')->is_valid_number, '枝幸町役場');
ok($zip->set_number('0986292')->is_valid_number, '猿払村役場');
ok($zip->set_number('0990492')->is_valid_number, '遠軽町役場');
ok($zip->set_number('0990494')->is_valid_number, '遠軽厚生病院');
ok($zip->set_number('0990495')->is_valid_number, '遠軽信用金庫');
ok($zip->set_number('0991197')->is_valid_number, 'きたみらい農業協同組合 置戸支所');
ok($zip->set_number('0991198')->is_valid_number, '置戸町役場');
ok($zip->set_number('0991492')->is_valid_number, 'きたみらい農業協同組合 訓子府支所');
ok($zip->set_number('0991495')->is_valid_number, '北海道クノール食品 (株)');
ok($zip->set_number('0991496')->is_valid_number, '北海道北見農業試験場');
ok($zip->set_number('0991498')->is_valid_number, '訓子府町役場');
ok($zip->set_number('0991595')->is_valid_number, '京セラ 株式会社 北海道北見工場');
ok($zip->set_number('0992192')->is_valid_number, '北見市役所 端野総合支所');
ok($zip->set_number('0992193')->is_valid_number, 'きたみらい農業協同組合 端野支所');
ok($zip->set_number('0992194')->is_valid_number, '北見市教育委員会');
ok($zip->set_number('0992195')->is_valid_number, '東武端野店');
ok($zip->set_number('0992196')->is_valid_number, 'オホーツク観光 株式会社');
ok($zip->set_number('0992197')->is_valid_number, '網走水産 株式会社');
ok($zip->set_number('0992198')->is_valid_number, '北海道北見商業高等学校');
ok($zip->set_number('0992392')->is_valid_number, '大空町役場');
ok($zip->set_number('0992492')->is_valid_number, '株式会社 網走観光ホテル');
ok($zip->set_number('0992493')->is_valid_number, '東京農業大学 生物産業学部');
ok($zip->set_number('0992495')->is_valid_number, '株式会社 ホテルビューパーク');
ok($zip->set_number('0993292')->is_valid_number, '東藻琴村農業協同組合');
ok($zip->set_number('0993293')->is_valid_number, '大空町 東藻琴総合支所');
ok($zip->set_number('0993697')->is_valid_number, '小清水町農業協同組合');
ok($zip->set_number('0993698')->is_valid_number, '小清水町役場');
ok($zip->set_number('0994192')->is_valid_number, '斜里町役場');
ok($zip->set_number('0994195')->is_valid_number, '斜里町農業協同組合');
ok($zip->set_number('0994196')->is_valid_number, 'ホクレン農業協同組合連合会 中斜里製糖工場');
ok($zip->set_number('0994492')->is_valid_number, '清里町役場');
ok($zip->set_number('0995692')->is_valid_number, '滝上町役場');
ok($zip->set_number('0996592')->is_valid_number, '湧別町役場');
ok($zip->set_number('1001492')->is_valid_number, '東京都八丈支庁');
ok($zip->set_number('1001498')->is_valid_number, '八丈町役場');
ok($zip->set_number('1006051')->is_valid_number, '株式会社 JTB法人東京 霞が関営業部');
ok($zip->set_number('1006066')->is_valid_number, '森六 株式会社');
ok($zip->set_number('1006080')->is_valid_number, '伊藤忠テクノソリューションズ 株式会社');
ok($zip->set_number('1006150')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ');
ok($zip->set_number('1006151')->is_valid_number, '株式会社 ユーズパートナーサービス');
ok($zip->set_number('1006152')->is_valid_number, 'U\'s音楽出版 株式会社');
ok($zip->set_number('1006162')->is_valid_number, 'ディ・エグゼクティブ・センター・ジャパン 株式会社');
ok($zip->set_number('1006170')->is_valid_number, 'ドイツ銀行 東京支店');
ok($zip->set_number('1006171')->is_valid_number, 'ドイツ証券 株式会社');
ok($zip->set_number('1006172')->is_valid_number, 'DB信託 株式会社');
ok($zip->set_number('1006173')->is_valid_number, 'ドイチェ・アセット・マネジメント 株式会社');
ok($zip->set_number('1006174')->is_valid_number, 'ドイツ・リアルエステイト・コンサルティング 有限会社');
ok($zip->set_number('1006175')->is_valid_number, 'ドイツ銀キャピタル・パートナーズ 株式会社');
ok($zip->set_number('1006177')->is_valid_number, '消費者委員会');
ok($zip->set_number('1006255')->is_valid_number, 'エヌエスパーソネルサービス 株式会社');
ok($zip->set_number('1006260')->is_valid_number, '株式会社 クラスト');
ok($zip->set_number('1006262')->is_valid_number, 'メールボックス・エトセトラ 東京駅店');
ok($zip->set_number('1006277')->is_valid_number, 'フォーシーズンズホテル丸の内 東京');
ok($zip->set_number('1006751')->is_valid_number, '株式会社 大和証券グループ 本社');
ok($zip->set_number('1006752')->is_valid_number, '大和証券 株式会社');
ok($zip->set_number('1006753')->is_valid_number, '大和証券投資信託委託 株式会社');
ok($zip->set_number('1006754')->is_valid_number, '大和証券エスエムビーシープリンシパル・インベストメンツ 株式会社');
ok($zip->set_number('1006755')->is_valid_number, '大和証券 株式会社 本店');
ok($zip->set_number('1006756')->is_valid_number, '株式会社 大和ネクスト銀行');
ok($zip->set_number('1008019')->is_valid_number, 'エヌ・ティ・ティ・コミュニケーションズ 株式会社');
ok($zip->set_number('1008050')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('1008051')->is_valid_number, '株式会社 毎日新聞社 東京本社');
ok($zip->set_number('1008055')->is_valid_number, '株式会社 読売新聞 東京本社');
ok($zip->set_number('1008065')->is_valid_number, '株式会社 日本経済新聞社');
ok($zip->set_number('1008066')->is_valid_number, '株式会社 日本経済新聞社');
ok($zip->set_number('1008070')->is_valid_number, 'JFE商事 株式会社');
ok($zip->set_number('1008077')->is_valid_number, '株式会社 産業経済新聞社');
ok($zip->set_number('1008078')->is_valid_number, '株式会社 産業経済新聞社');
ok($zip->set_number('1008079')->is_valid_number, '株式会社 産業経済新聞社');
ok($zip->set_number('1008080')->is_valid_number, '一般社団法人 読売調査研究機構');
ok($zip->set_number('1008086')->is_valid_number, '三菱商事 株式会社');
ok($zip->set_number('1008088')->is_valid_number, '丸紅 株式会社');
ok($zip->set_number('1008101')->is_valid_number, '株式会社 クニエ');
ok($zip->set_number('1008102')->is_valid_number, '東京国税局');
ok($zip->set_number('1008103')->is_valid_number, '朝日生命保険 相互会社');
ok($zip->set_number('1008104')->is_valid_number, 'モルガン・スタンレーMUFG証券 株式会社');
ok($zip->set_number('1008105')->is_valid_number, 'チッソ 株式会社');
ok($zip->set_number('1008107')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('1008108')->is_valid_number, 'NSユナイテッド海運 株式会社');
ok($zip->set_number('1008109')->is_valid_number, 'モルガン・スタンレー・グループ');
ok($zip->set_number('1008110')->is_valid_number, '株式会社 産経デジタル');
ok($zip->set_number('1008111')->is_valid_number, '宮内庁');
ok($zip->set_number('1008113')->is_valid_number, '三菱地所リアルエステートサービス 株式会社');
ok($zip->set_number('1008117')->is_valid_number, '三菱マテリアル 株式会社');
ok($zip->set_number('1008118')->is_valid_number, '電気事業連合会');
ok($zip->set_number('1008119')->is_valid_number, '東京消防庁');
ok($zip->set_number('1008120')->is_valid_number, '農林中央金庫');
ok($zip->set_number('1008121')->is_valid_number, '日立造船 株式会社 東京支社');
ok($zip->set_number('1008123')->is_valid_number, '三井生命保険 株式会社');
ok($zip->set_number('1008124')->is_valid_number, '西村あさひ法律事務所');
ok($zip->set_number('1008125')->is_valid_number, '株式会社 日本工業新聞社');
ok($zip->set_number('1008126')->is_valid_number, '一般財団法人 電力中央研究所');
ok($zip->set_number('1008127')->is_valid_number, '三菱UFJモルガン・スタンレー証券 株式会社');
ok($zip->set_number('1008128')->is_valid_number, 'NTTコミュニケーションズ 株式会社');
ok($zip->set_number('1008130')->is_valid_number, '野村證券 株式会社');
ok($zip->set_number('1008131')->is_valid_number, '株式会社 HS情報システムズ');
ok($zip->set_number('1008132')->is_valid_number, 'シティグループ・サービス・ジャパン 株式会社');
ok($zip->set_number('1008132')->is_valid_number, 'シティグループ・ジャパン・ホールディングス 合同会社');
ok($zip->set_number('1008132')->is_valid_number, 'シティグループ証券 株式会社');
ok($zip->set_number('1008132')->is_valid_number, 'シティバンク、エヌ・エイ 東京支店');
ok($zip->set_number('1008133')->is_valid_number, '三菱地所 株式会社');
ok($zip->set_number('1008134')->is_valid_number, '株式会社 ベネフィット・ワン');
ok($zip->set_number('1008135')->is_valid_number, '財団法人 国語作文教育研究所');
ok($zip->set_number('1008136')->is_valid_number, 'アンダーソン・毛利・友常法律事務所外国法共同事業');
ok($zip->set_number('1008139')->is_valid_number, '財団法人 逓信協会');
ok($zip->set_number('1008140')->is_valid_number, '株式会社 産業経済新聞社サンケイスポーツ');
ok($zip->set_number('1008141')->is_valid_number, '株式会社 三菱総合研究所');
ok($zip->set_number('1008142')->is_valid_number, '長瀬産業 株式会社 東京本社');
ok($zip->set_number('1008144')->is_valid_number, '株式会社 国際協力銀行');
ok($zip->set_number('1008150')->is_valid_number, 'ウシオ電機 株式会社');
ok($zip->set_number('1008151')->is_valid_number, '株式会社 読売巨人軍');
ok($zip->set_number('1008152')->is_valid_number, '株式会社 中央公論新社');
ok($zip->set_number('1008154')->is_valid_number, '三愛石油 株式会社');
ok($zip->set_number('1008155')->is_valid_number, '農林中央金庫');
ok($zip->set_number('1008158')->is_valid_number, '日本紙通商 株式会社');
ok($zip->set_number('1008159')->is_valid_number, 'デル・テクノロジーズ 株式会社');
ok($zip->set_number('1008160')->is_valid_number, '株式会社 産業経済新聞社夕刊フジ');
ok($zip->set_number('1008165')->is_valid_number, '日本曹達 株式会社');
ok($zip->set_number('1008166')->is_valid_number, '日立電線 株式会社');
ok($zip->set_number('1008168')->is_valid_number, '新日石トレーディング 株式会社');
ok($zip->set_number('1008169')->is_valid_number, '新日石プラスト 株式会社');
ok($zip->set_number('1008172')->is_valid_number, '有限責任 あずさ監査法人');
ok($zip->set_number('1008174')->is_valid_number, '有限責任 あずさ監査法人');
ok($zip->set_number('1008176')->is_valid_number, '株式会社 みずほ銀行 本店');
ok($zip->set_number('1008176')->is_valid_number, '株式会社 みずほフィナンシャルグループ');
ok($zip->set_number('1008178')->is_valid_number, '株式会社 日本政策投資銀行');
ok($zip->set_number('1008181')->is_valid_number, '株式会社 ユーエフジェイカード');
ok($zip->set_number('1008182')->is_valid_number, '石川島播磨重工業 株式会社');
ok($zip->set_number('1008184')->is_valid_number, '日本橋税務署');
ok($zip->set_number('1008185')->is_valid_number, '協和発酵キリン 株式会社');
ok($zip->set_number('1008186')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('1008187')->is_valid_number, '一般社団法人 経団連事業サービス');
ok($zip->set_number('1008188')->is_valid_number, '社団法人 日本経済団体連合会');
ok($zip->set_number('1008189')->is_valid_number, '三菱地所レジデンス 株式会社');
ok($zip->set_number('1008201')->is_valid_number, '株式会社 三井住友銀行');
ok($zip->set_number('1008203')->is_valid_number, '丸善 丸の内本店');
ok($zip->set_number('1008205')->is_valid_number, '田辺三菱製薬 株式会社 東京本社');
ok($zip->set_number('1008207')->is_valid_number, '東邦亜鉛 株式会社');
ok($zip->set_number('1008214')->is_valid_number, 'UFJ信託銀行 株式会社');
ok($zip->set_number('1008215')->is_valid_number, 'ランクセス 株式会社');
ok($zip->set_number('1008216')->is_valid_number, '一般社団法人 全国銀行協会');
ok($zip->set_number('1008219')->is_valid_number, 'ニッセイアセットマネジメント 株式会社');
ok($zip->set_number('1008228')->is_valid_number, '株式会社 パソナ');
ok($zip->set_number('1008232')->is_valid_number, '三井住友信託銀行 株式会社');
ok($zip->set_number('1008233')->is_valid_number, '三井住友信託銀行 株式会社');
ok($zip->set_number('1008234')->is_valid_number, 'AIU損害保険 株式会社');
ok($zip->set_number('1008235')->is_valid_number, '株式会社 丸和運輸機関');
ok($zip->set_number('1008241')->is_valid_number, '株式会社 みずほ銀行');
ok($zip->set_number('1008241')->is_valid_number, '株式会社 みずほフィナンシャルグループ');
ok($zip->set_number('1008241')->is_valid_number, 'みずほ証券 株式会社');
ok($zip->set_number('1008241')->is_valid_number, 'みずほ信託銀行 株式会社');
ok($zip->set_number('1008245')->is_valid_number, 'SMFLみらいパートナーズ 株式会社');
ok($zip->set_number('1008246')->is_valid_number, '日本ゼオン 株式会社');
ok($zip->set_number('1008251')->is_valid_number, '三菱ケミカル 株式会社');
ok($zip->set_number('1008260')->is_valid_number, '宇宙航空研究開発機構');
ok($zip->set_number('1008262')->is_valid_number, 'バイエルクロップサイエンス 株式会社');
ok($zip->set_number('1008265')->is_valid_number, 'バイエル薬品 株式会社');
ok($zip->set_number('1008268')->is_valid_number, 'バイエルホールディング 株式会社');
ok($zip->set_number('1008270')->is_valid_number, '住友林業 株式会社');
ok($zip->set_number('1008282')->is_valid_number, '同和鉱業 株式会社');
ok($zip->set_number('1008283')->is_valid_number, 'シャングリ・ラホテル東京');
ok($zip->set_number('1008285')->is_valid_number, '佐藤商事 株式会社');
ok($zip->set_number('1008288')->is_valid_number, '日本生命保険 相互会社');
ok($zip->set_number('1008302')->is_valid_number, '白銅 株式会社');
ok($zip->set_number('1008303')->is_valid_number, '三菱電線工業 株式会社');
ok($zip->set_number('1008306')->is_valid_number, '株式会社 フジクラ・ダイヤケーブル');
ok($zip->set_number('1008307')->is_valid_number, 'アコム 株式会社');
ok($zip->set_number('1008310')->is_valid_number, '三菱電機 株式会社');
ok($zip->set_number('1008311')->is_valid_number, '明和産業 株式会社');
ok($zip->set_number('1008321')->is_valid_number, '出光興産 株式会社');
ok($zip->set_number('1008322')->is_valid_number, '古河電気工業 株式会社');
ok($zip->set_number('1008324')->is_valid_number, '三菱ガス化学 株式会社');
ok($zip->set_number('1008325')->is_valid_number, 'SMBC日興証券 株式会社');
ok($zip->set_number('1008331')->is_valid_number, '株式会社 ニコン');
ok($zip->set_number('1008332')->is_valid_number, '三菱重工業 株式会社');
ok($zip->set_number('1008333')->is_valid_number, 'ELCジャパン 株式会社');
ok($zip->set_number('1008335')->is_valid_number, '三菱電機ビルソリューションズ 株式会社');
ok($zip->set_number('1008338')->is_valid_number, '三菱マテリアル 株式会社');
ok($zip->set_number('1008341')->is_valid_number, '株式会社 JECC');
ok($zip->set_number('1008345')->is_valid_number, '日本ロレックス 株式会社');
ok($zip->set_number('1008350')->is_valid_number, '三菱商事プラスチック 株式会社');
ok($zip->set_number('1008351')->is_valid_number, 'グリーンスタンプ 株式会社');
ok($zip->set_number('1008355')->is_valid_number, '中村合同特許法律事務所');
ok($zip->set_number('1008370')->is_valid_number, '古河運輸 株式会社 東京営業所');
ok($zip->set_number('1008370')->is_valid_number, '古河機械金属 株式会社');
ok($zip->set_number('1008370')->is_valid_number, '古河キャステック 株式会社 東京支店');
ok($zip->set_number('1008370')->is_valid_number, '古河健康保険組合');
ok($zip->set_number('1008370')->is_valid_number, '古河産機システムズ 株式会社');
ok($zip->set_number('1008370')->is_valid_number, '古河電子 株式会社 営業部');
ok($zip->set_number('1008370')->is_valid_number, '古河ビジネスサービス 株式会社');
ok($zip->set_number('1008370')->is_valid_number, '古河メタルリソース 株式会社');
ok($zip->set_number('1008370')->is_valid_number, '古河ユニック 株式会社');
ok($zip->set_number('1008370')->is_valid_number, '古河ロックドリル 株式会社');
ok($zip->set_number('1008380')->is_valid_number, '東京商工会議所');
ok($zip->set_number('1008383')->is_valid_number, '新東亜交易 株式会社 本店 (SHINTOA CORPORATION)and(SHINTOA KOEKI KAISHA.LTD.)');
ok($zip->set_number('1008388')->is_valid_number, '株式会社 三菱UFJ銀行');
ok($zip->set_number('1008402')->is_valid_number, '財団法人 企業経営通信学院');
ok($zip->set_number('1008410')->is_valid_number, '休暇村東京センター');
ok($zip->set_number('1008411')->is_valid_number, '第一生命保険 株式会社');
ok($zip->set_number('1008415')->is_valid_number, '東宝 株式会社');
ok($zip->set_number('1008421')->is_valid_number, 'TOHOシネマズ 株式会社');
ok($zip->set_number('1008424')->is_valid_number, 'パーク24 株式会社');
ok($zip->set_number('1008427')->is_valid_number, '株式会社 関電工 中央支社');
ok($zip->set_number('1008430')->is_valid_number, '株式会社 サンケイリビング新聞社');
ok($zip->set_number('1008439')->is_valid_number, '株式会社 ニッポン放送');
ok($zip->set_number('1008444')->is_valid_number, '日本生命保険 相互会社');
ok($zip->set_number('1008448')->is_valid_number, '財団法人 企業経営通信学院');
ok($zip->set_number('1008450')->is_valid_number, '日本映画放送 株式会社');
ok($zip->set_number('1008456')->is_valid_number, '株式会社 日本製鋼所');
ok($zip->set_number('1008484')->is_valid_number, '三機工業 株式会社');
ok($zip->set_number('1008488')->is_valid_number, '株式会社 阪急百貨店 有楽町阪急');
ok($zip->set_number('1008502')->is_valid_number, '株式会社 中日新聞社 日比谷分室');
ok($zip->set_number('1008503')->is_valid_number, '東芝機械 株式会社');
ok($zip->set_number('1008505')->is_valid_number, '中日新聞社 東京本社');
ok($zip->set_number('1008506')->is_valid_number, '飯野海運 株式会社');
ok($zip->set_number('1008507')->is_valid_number, '日比谷中日ビルディング');
ok($zip->set_number('1008511')->is_valid_number, '石油公団');
ok($zip->set_number('1008520')->is_valid_number, '富国生命保険 相互会社');
ok($zip->set_number('1008521')->is_valid_number, 'UBE三菱セメント 株式会社');
ok($zip->set_number('1008522')->is_valid_number, '東洋製罐 株式会社');
ok($zip->set_number('1008533')->is_valid_number, '中越パルプ工業 株式会社');
ok($zip->set_number('1008540')->is_valid_number, '川崎汽船 株式会社');
ok($zip->set_number('1008543')->is_valid_number, '社団法人 日本新聞協会');
ok($zip->set_number('1008550')->is_valid_number, '旭化成工業 株式会社');
ok($zip->set_number('1008555')->is_valid_number, 'ティ・アンド・ディ・フィナンシャル生命保険 株式会社');
ok($zip->set_number('1008558')->is_valid_number, '株式会社 帝国ホテル');
ok($zip->set_number('1008560')->is_valid_number, '東京電力ホールディングス 株式会社');
ok($zip->set_number('1008567')->is_valid_number, '九州石油 株式会社');
ok($zip->set_number('1008575')->is_valid_number, 'プラチナ・ギルド・インターナショナル 株式会社');
ok($zip->set_number('1008577')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構 東京事務所');
ok($zip->set_number('1008585')->is_valid_number, '帝人 株式会社 東京本社');
ok($zip->set_number('1008588')->is_valid_number, '株式会社 コスモスイニシア');
ok($zip->set_number('1008601')->is_valid_number, '住友商事 株式会社');
ok($zip->set_number('1008602')->is_valid_number, 'ユーシーカード 株式会社');
ok($zip->set_number('1008606')->is_valid_number, '株式会社 主婦と生活社');
ok($zip->set_number('1008610')->is_valid_number, '株式会社 ディーエムエス');
ok($zip->set_number('1008617')->is_valid_number, '株式会社 デック');
ok($zip->set_number('1008620')->is_valid_number, '株式会社 トッパンコミュニケーションプロダクツ');
ok($zip->set_number('1008621')->is_valid_number, '株式会社 プランニングオフィス トライ・アングル');
ok($zip->set_number('1008629')->is_valid_number, '株式会社 サミット');
ok($zip->set_number('1008631')->is_valid_number, '三井物産 株式会社');
ok($zip->set_number('1008639')->is_valid_number, '株式会社 メールハウス');
ok($zip->set_number('1008640')->is_valid_number, '東京セールス・プロデュース 株式会社');
ok($zip->set_number('1008644')->is_valid_number, '株式会社 産業経済新聞社');
ok($zip->set_number('1008649')->is_valid_number, '株式会社 産業経済新聞社');
ok($zip->set_number('1008655')->is_valid_number, 'セイコー ウオッチ 株式会社');
ok($zip->set_number('1008663')->is_valid_number, 'アイアンドエス・ビービーディオー');
ok($zip->set_number('1008665')->is_valid_number, '産業経済新聞社');
ok($zip->set_number('1008666')->is_valid_number, '株式会社 スポーツニッポン新聞社');
ok($zip->set_number('1008676')->is_valid_number, '株式会社 興伸');
ok($zip->set_number('1008677')->is_valid_number, '株式会社 ベターサービス');
ok($zip->set_number('1008791')->is_valid_number, '日本郵政 株式会社');
ok($zip->set_number('1008792')->is_valid_number, '日本郵便 株式会社');
ok($zip->set_number('1008793')->is_valid_number, '株式会社 ゆうちょ銀行');
ok($zip->set_number('1008794')->is_valid_number, '株式会社 かんぽ生命保険');
ok($zip->set_number('1008901')->is_valid_number, '経済産業省');
ok($zip->set_number('1008902')->is_valid_number, '経済産業省 大臣官房調査統計グループ');
ok($zip->set_number('1008903')->is_valid_number, '東京地方検察庁');
ok($zip->set_number('1008904')->is_valid_number, '東京高等検察庁');
ok($zip->set_number('1008905')->is_valid_number, '公認会計士・監査審査会');
ok($zip->set_number('1008907')->is_valid_number, '水産庁');
ok($zip->set_number('1008909')->is_valid_number, '社会民主党全国連合');
ok($zip->set_number('1008910')->is_valid_number, '自由民主党本部');
ok($zip->set_number('1008912')->is_valid_number, '中小企業庁');
ok($zip->set_number('1008913')->is_valid_number, '人事院 事務総局');
ok($zip->set_number('1008914')->is_valid_number, '内閣府');
ok($zip->set_number('1008915')->is_valid_number, '特許庁');
ok($zip->set_number('1008916')->is_valid_number, '厚生労働省');
ok($zip->set_number('1008917')->is_valid_number, '財団法人 全国老人クラブ連合会');
ok($zip->set_number('1008918')->is_valid_number, '国土交通省');
ok($zip->set_number('1008919')->is_valid_number, '外務省');
ok($zip->set_number('1008920')->is_valid_number, '東京地方裁判所');
ok($zip->set_number('1008921')->is_valid_number, '国立研究開発法人 産業技術総合研究所');
ok($zip->set_number('1008922')->is_valid_number, '証券取引等監視委員会');
ok($zip->set_number('1008924')->is_valid_number, '国立国会図書館');
ok($zip->set_number('1008926')->is_valid_number, '総務省');
ok($zip->set_number('1008927')->is_valid_number, '消防庁');
ok($zip->set_number('1008929')->is_valid_number, '警視庁');
ok($zip->set_number('1008930')->is_valid_number, '首都高速道路 株式会社');
ok($zip->set_number('1008931')->is_valid_number, '資源エネルギー庁');
ok($zip->set_number('1008932')->is_valid_number, '海上保安庁 海洋情報部');
ok($zip->set_number('1008933')->is_valid_number, '東京高等裁判所');
ok($zip->set_number('1008937')->is_valid_number, '日本金属工業 株式会社');
ok($zip->set_number('1008940')->is_valid_number, '財務省');
ok($zip->set_number('1008941')->is_valid_number, '会計検査院');
ok($zip->set_number('1008945')->is_valid_number, '社会保険庁');
ok($zip->set_number('1008950')->is_valid_number, '農林水産省');
ok($zip->set_number('1008951')->is_valid_number, '国立教育政策研究所');
ok($zip->set_number('1008952')->is_valid_number, '林野庁');
ok($zip->set_number('1008953')->is_valid_number, 'ジブラルタ生命保険 株式会社');
ok($zip->set_number('1008955')->is_valid_number, '公益社団法人 日本道路協会');
ok($zip->set_number('1008956')->is_valid_number, '東京家庭裁判所');
ok($zip->set_number('1008958')->is_valid_number, '消費者庁');
ok($zip->set_number('1008959')->is_valid_number, '文部科学省');
ok($zip->set_number('1008960')->is_valid_number, '衆議院');
ok($zip->set_number('1008961')->is_valid_number, '参議院');
ok($zip->set_number('1008962')->is_valid_number, '参議院議員会館');
ok($zip->set_number('1008964')->is_valid_number, 'プルデンシャル ジブラルタ ファイナンシャル 生命保険 株式会社');
ok($zip->set_number('1008965')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('1008967')->is_valid_number, '金融庁');
ok($zip->set_number('1008968')->is_valid_number, '内閣官房');
ok($zip->set_number('1008969')->is_valid_number, '内閣府');
ok($zip->set_number('1008970')->is_valid_number, '内閣府');
ok($zip->set_number('1008971')->is_valid_number, '東京簡易裁判所');
ok($zip->set_number('1008973')->is_valid_number, '出入国在留管理庁');
ok($zip->set_number('1008974')->is_valid_number, '警察庁');
ok($zip->set_number('1008975')->is_valid_number, '環境省');
ok($zip->set_number('1008976')->is_valid_number, '海上保安庁');
ok($zip->set_number('1008977')->is_valid_number, '法務省');
ok($zip->set_number('1008978')->is_valid_number, '国税庁');
ok($zip->set_number('1008979')->is_valid_number, '日本道路公団');
ok($zip->set_number('1008980')->is_valid_number, '社会福祉法人 全国社会福祉協議会');
ok($zip->set_number('1008981')->is_valid_number, '衆議院第一議員会館');
ok($zip->set_number('1008982')->is_valid_number, '衆議院第二議員会館');
ok($zip->set_number('1008983')->is_valid_number, '株式会社 トクヤマ');
ok($zip->set_number('1008986')->is_valid_number, '原子力・安全保安院');
ok($zip->set_number('1008987')->is_valid_number, '公正取引委員会 事務総局');
ok($zip->set_number('1008989')->is_valid_number, '内閣府 食品安全委員会');
ok($zip->set_number('1008994')->is_valid_number, '東京中央郵便局');
ok($zip->set_number('1008996')->is_valid_number, '株式会社 ゆうちょ銀行 本店');
ok($zip->set_number('1018001')->is_valid_number, '株式会社 小学館');
ok($zip->set_number('1018002')->is_valid_number, '株式会社 岩波書店');
ok($zip->set_number('1018008')->is_valid_number, '独立行政法人 宇宙航空研究開発機構');
ok($zip->set_number('1018011')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('1018050')->is_valid_number, '株式会社 集英社');
ok($zip->set_number('1018054')->is_valid_number, '株式会社 集英社 私書箱19号');
ok($zip->set_number('1018101')->is_valid_number, '旭化成ホームズ 株式会社');
ok($zip->set_number('1018189')->is_valid_number, '株式会社 富士薬品');
ok($zip->set_number('1018201')->is_valid_number, '株式会社 インテージ');
ok($zip->set_number('1018204')->is_valid_number, '株式会社 インテージ・アソシエイツ');
ok($zip->set_number('1018210')->is_valid_number, '日本紙通商 株式会社');
ok($zip->set_number('1018213')->is_valid_number, '日本製紙木材 株式会社');
ok($zip->set_number('1018215')->is_valid_number, '日本製紙クレシア 株式会社');
ok($zip->set_number('1018219')->is_valid_number, 'みずほ証券 株式会社');
ok($zip->set_number('1018228')->is_valid_number, '大林道路 株式会社');
ok($zip->set_number('1018301')->is_valid_number, '学校法人 明治大学');
ok($zip->set_number('1018307')->is_valid_number, '公益社団法人 日本化学会');
ok($zip->set_number('1018308')->is_valid_number, '日本大学 理工学部');
ok($zip->set_number('1018309')->is_valid_number, '日本大学病院');
ok($zip->set_number('1018310')->is_valid_number, '日本大学 歯学部');
ok($zip->set_number('1018311')->is_valid_number, '杏林製薬 株式会社');
ok($zip->set_number('1018313')->is_valid_number, '学校法人 駿河台学園 駿台予備学校');
ok($zip->set_number('1018318')->is_valid_number, 'ADEKAクリーンエイド 株式会社');
ok($zip->set_number('1018323')->is_valid_number, '株式会社 日本経済広告社');
ok($zip->set_number('1018324')->is_valid_number, '中央大学 駿河台キャンパス');
ok($zip->set_number('1018325')->is_valid_number, '管工業健康保険組合');
ok($zip->set_number('1018326')->is_valid_number, '社団法人 東京都教職員互助会 三楽病院');
ok($zip->set_number('1018329')->is_valid_number, '日新火災海上保険 株式会社');
ok($zip->set_number('1018333')->is_valid_number, '一般財団法人 産業経理協会');
ok($zip->set_number('1018335')->is_valid_number, '株式会社 損保會舘');
ok($zip->set_number('1018336')->is_valid_number, 'リケンテクノス 株式会社');
ok($zip->set_number('1018338')->is_valid_number, '三菱マテリアル 株式会社');
ok($zip->set_number('1018343')->is_valid_number, 'トヨタ・コニック・プロ 株式会社');
ok($zip->set_number('1018346')->is_valid_number, '財団法人 日本眼科学会');
ok($zip->set_number('1018347')->is_valid_number, 'NTTコムソリューションズ 株式会社');
ok($zip->set_number('1018350')->is_valid_number, '東光電気工事 株式会社');
ok($zip->set_number('1018351')->is_valid_number, '学校法人 大原学園');
ok($zip->set_number('1018353')->is_valid_number, '大原法律専門学校');
ok($zip->set_number('1018354')->is_valid_number, '日本大学 通信教育部');
ok($zip->set_number('1018355')->is_valid_number, '株式会社 朝日出版社');
ok($zip->set_number('1018358')->is_valid_number, '財団法人 日本書道教育学会');
ok($zip->set_number('1018359')->is_valid_number, '株式会社 日本貿易保険');
ok($zip->set_number('1018362')->is_valid_number, 'NECトーキン (株)');
ok($zip->set_number('1018366')->is_valid_number, '鉄建建設 (株)');
ok($zip->set_number('1018372')->is_valid_number, '公益財団法人 結核予防会 総合健診推進センター');
ok($zip->set_number('1018375')->is_valid_number, '日本大学 法学部');
ok($zip->set_number('1018378')->is_valid_number, '公益社団法人 全日本病院協会');
ok($zip->set_number('1018383')->is_valid_number, 'TAC 株式会社');
ok($zip->set_number('1018388')->is_valid_number, '株式会社 少年画報社');
ok($zip->set_number('1018405')->is_valid_number, '株式会社 二見書房');
ok($zip->set_number('1018408')->is_valid_number, '株式会社 つり人社');
ok($zip->set_number('1018410')->is_valid_number, '株式会社 シノテスト');
ok($zip->set_number('1018415')->is_valid_number, '株式会社 小学館集英社プロダクション');
ok($zip->set_number('1018416')->is_valid_number, '太平電業 株式会社');
ok($zip->set_number('1018418')->is_valid_number, '株式会社 ゼンリン');
ok($zip->set_number('1018421')->is_valid_number, '株式会社 じほう');
ok($zip->set_number('1018422')->is_valid_number, '郵船トラベル (株)');
ok($zip->set_number('1018423')->is_valid_number, '株式会社 放送出版エージェンシー');
ok($zip->set_number('1018424')->is_valid_number, '株式会社 放送出版プロモーション 日本アマチュア歌謡連盟 本部事務局');
ok($zip->set_number('1018425')->is_valid_number, '学校法人 専修大学');
ok($zip->set_number('1018429')->is_valid_number, '三谷産業 株式会社');
ok($zip->set_number('1018430')->is_valid_number, '情報・システム研究機構 国立情報学研究所');
ok($zip->set_number('1018433')->is_valid_number, '学校法人 共立女子学園');
ok($zip->set_number('1018437')->is_valid_number, '共立女子大学');
ok($zip->set_number('1018439')->is_valid_number, '一橋大学 千代田キャンパス事務室');
ok($zip->set_number('1018441')->is_valid_number, '日清製粉 株式会社');
ok($zip->set_number('1018443')->is_valid_number, 'みずほリサーチ&テクノロジーズ 株式会社');
ok($zip->set_number('1018444')->is_valid_number, '大鵬薬品工業 株式会社');
ok($zip->set_number('1018445')->is_valid_number, 'イオンクレジットサービス (株)');
ok($zip->set_number('1018446')->is_valid_number, '菱栄 株式会社');
ok($zip->set_number('1018448')->is_valid_number, '株式会社 島津製作所 東京支社');
ok($zip->set_number('1018450')->is_valid_number, '株式会社 シンコーミュージック・エンタテイメント');
ok($zip->set_number('1018451')->is_valid_number, '新生紙パルプ商事 株式会社');
ok($zip->set_number('1018456')->is_valid_number, '学校法人 正則学園');
ok($zip->set_number('1018459')->is_valid_number, '一般社団法人 学士会');
ok($zip->set_number('1018460')->is_valid_number, '株式会社 オーム社');
ok($zip->set_number('1018461')->is_valid_number, '株式会社 宙出版');
ok($zip->set_number('1018462')->is_valid_number, 'パシフィックコンサルタンツ 株式会社');
ok($zip->set_number('1018464')->is_valid_number, '神田税務署');
ok($zip->set_number('1018466')->is_valid_number, '株式会社 大修館書店');
ok($zip->set_number('1018470')->is_valid_number, '株式会社 ディーエムエス');
ok($zip->set_number('1018475')->is_valid_number, '株式会社 シンコーミュージック・エンタテイメント');
ok($zip->set_number('1018477')->is_valid_number, 'ミズノ 株式会社');
ok($zip->set_number('1018480')->is_valid_number, '旭化成アミダス 株式会社');
ok($zip->set_number('1018485')->is_valid_number, '三井化学東セロ 株式会社');
ok($zip->set_number('1018502')->is_valid_number, '全農物流 株式会社');
ok($zip->set_number('1018504')->is_valid_number, 'オザックス 株式会社');
ok($zip->set_number('1018509')->is_valid_number, '一般社団法人 全国地方銀行協会');
ok($zip->set_number('1018512')->is_valid_number, 'アルフレッサ 株式会社');
ok($zip->set_number('1018515')->is_valid_number, '東京ロイヤルプラザ 管理組合');
ok($zip->set_number('1018520')->is_valid_number, '東京都千代田都税事務所');
ok($zip->set_number('1018521')->is_valid_number, '昭和産業 株式会社');
ok($zip->set_number('1018522')->is_valid_number, '株式会社 社会保険研究所');
ok($zip->set_number('1018523')->is_valid_number, '東京都水道局 千代田営業所');
ok($zip->set_number('1018524')->is_valid_number, '株式会社 ユニ・プランニング');
ok($zip->set_number('1018525')->is_valid_number, '専門学校 神田外語学院(学校法人 佐野学園)');
ok($zip->set_number('1018527')->is_valid_number, '東京都職業能力開発協会');
ok($zip->set_number('1018528')->is_valid_number, 'ピップ 株式会社');
ok($zip->set_number('1018530')->is_valid_number, '東亜商事 株式会社');
ok($zip->set_number('1018531')->is_valid_number, '有限会社 科学評論社');
ok($zip->set_number('1018532')->is_valid_number, 'NECプラットフォームズ 株式会社');
ok($zip->set_number('1018534')->is_valid_number, '一般社団法人 全国信用保証協会連合会');
ok($zip->set_number('1018535')->is_valid_number, '大塚製薬 株式会社');
ok($zip->set_number('1018542')->is_valid_number, 'フジパン (株) 関東事業部');
ok($zip->set_number('1018548')->is_valid_number, '株式会社 徳力本店');
ok($zip->set_number('1018552')->is_valid_number, '社団法人 ジャパンケネルクラブ');
ok($zip->set_number('1018554')->is_valid_number, 'メタウォーター 株式会社');
ok($zip->set_number('1018555')->is_valid_number, '一般財団法人 日本品質保証機構');
ok($zip->set_number('1018558')->is_valid_number, '株式会社 イワキ');
ok($zip->set_number('1018559')->is_valid_number, '佐藤金属 株式会社');
ok($zip->set_number('1018561')->is_valid_number, '株式会社 日本マンパワー');
ok($zip->set_number('1018562')->is_valid_number, '株式会社 東日本銀行 事務センター');
ok($zip->set_number('1018565')->is_valid_number, '株式会社 東日本銀行 神田支店');
ok($zip->set_number('1018568')->is_valid_number, '株式会社 コクゴ');
ok($zip->set_number('1018575')->is_valid_number, '田島ルーフィング 株式会社');
ok($zip->set_number('1018579')->is_valid_number, '田島ルーフィング 株式会社');
ok($zip->set_number('1018580')->is_valid_number, 'ユアサ商事 株式会社');
ok($zip->set_number('1018585')->is_valid_number, '山崎製パン 株式会社');
ok($zip->set_number('1018586')->is_valid_number, '貝印 株式会社');
ok($zip->set_number('1018589')->is_valid_number, '株式会社 極東商会/株式会社 カパス');
ok($zip->set_number('1018603')->is_valid_number, '新生フィナンシャル 株式会社');
ok($zip->set_number('1018605')->is_valid_number, '橋本産業 (株)');
ok($zip->set_number('1018606')->is_valid_number, 'フマキラー 株式会社');
ok($zip->set_number('1018610')->is_valid_number, '株式会社 ソフマップ');
ok($zip->set_number('1018611')->is_valid_number, '一般社団法人 東京都交友会');
ok($zip->set_number('1018616')->is_valid_number, '新生パーソナルローン 株式会社');
ok($zip->set_number('1018617')->is_valid_number, '同和鉱業 株式会社');
ok($zip->set_number('1018619')->is_valid_number, '株式会社 ダイドーリミテッド');
ok($zip->set_number('1018621')->is_valid_number, '(株) 共立メンテナンス');
ok($zip->set_number('1018624')->is_valid_number, '株式会社 かんそうしん');
ok($zip->set_number('1018626')->is_valid_number, 'ヤマキ 株式会社');
ok($zip->set_number('1018627')->is_valid_number, '加賀電子 株式会社 技術統括部');
ok($zip->set_number('1018628')->is_valid_number, '加賀電子 株式会社 電子事業部、通信事業部、オートモーティブ事業部');
ok($zip->set_number('1018629')->is_valid_number, '加賀電子 株式会社 管理本部、秘書・広報室');
ok($zip->set_number('1018630')->is_valid_number, '東浴 信用組合');
ok($zip->set_number('1018631')->is_valid_number, '株式会社 東和エンジニアリング');
ok($zip->set_number('1018633')->is_valid_number, 'スガツネ工業 株式会社');
ok($zip->set_number('1018636')->is_valid_number, '株式会社 スズケン');
ok($zip->set_number('1018637')->is_valid_number, '三菱UFJファクター 株式会社');
ok($zip->set_number('1018642')->is_valid_number, 'YKK 株式会社');
ok($zip->set_number('1018643')->is_valid_number, '社会福祉法人 三井記念病院');
ok($zip->set_number('1018645')->is_valid_number, 'キリンビバレッジ 株式会社');
ok($zip->set_number('1018646')->is_valid_number, '鶴岡 株式会社');
ok($zip->set_number('1018647')->is_valid_number, '日本通運 株式会社');
ok($zip->set_number('1018648')->is_valid_number, '株式会社 薬事日報社');
ok($zip->set_number('1018651')->is_valid_number, '丸高興業 株式会社');
ok($zip->set_number('1018654')->is_valid_number, '石福金属興業 株式会社');
ok($zip->set_number('1018656')->is_valid_number, '小学館プロダクション');
ok($zip->set_number('1018665')->is_valid_number, '株式会社 デック');
ok($zip->set_number('1018667')->is_valid_number, '株式会社 デック');
ok($zip->set_number('1018668')->is_valid_number, '株式会社 主婦の友社');
ok($zip->set_number('1018670')->is_valid_number, '東京セールスプロデュース 株式会社');
ok($zip->set_number('1018672')->is_valid_number, '株式会社 極東書店');
ok($zip->set_number('1018676')->is_valid_number, '(株) 武蔵野銀行 東京支店');
ok($zip->set_number('1018682')->is_valid_number, '三洋貿易 (株)');
ok($zip->set_number('1018688')->is_valid_number, '(株) ニチイ学館');
ok($zip->set_number('1018701')->is_valid_number, '株式会社 祥伝社');
ok($zip->set_number('1018703')->is_valid_number, 'トーア再保険 株式会社');
ok($zip->set_number('1018707')->is_valid_number, '(株) 日本パーソナルセンター');
ok($zip->set_number('1018710')->is_valid_number, '日本出版販売 (株)');
ok($zip->set_number('1018711')->is_valid_number, '(株) 白泉社');
ok($zip->set_number('1018712')->is_valid_number, '神田物産 (株)');
ok($zip->set_number('1018715')->is_valid_number, '全日本書芸文化院');
ok($zip->set_number('1018716')->is_valid_number, '株式会社 主婦と生活社');
ok($zip->set_number('1018717')->is_valid_number, '明治乳業 株式会社');
ok($zip->set_number('1018718')->is_valid_number, '株式会社 日本醫事新報社');
ok($zip->set_number('1018941')->is_valid_number, '株式会社 日立ビルシステム');
ok($zip->set_number('1018950')->is_valid_number, '大建工業 株式会社');
ok($zip->set_number('1018973')->is_valid_number, '株式会社 アクセル');
ok($zip->set_number('1018977')->is_valid_number, 'グローリー 株式会社 東京本部');
ok($zip->set_number('1018983')->is_valid_number, '財団法人 母子衛生研究会');
ok($zip->set_number('1018986')->is_valid_number, '一般財団法人 日本建築センター');
ok($zip->set_number('1028005')->is_valid_number, '日本大学 通信教育部');
ok($zip->set_number('1028008')->is_valid_number, '株式会社 文藝春秋');
ok($zip->set_number('1028011')->is_valid_number, '財団法人 JKA');
ok($zip->set_number('1028012')->is_valid_number, '独立行政法人 国際協力機構');
ok($zip->set_number('1028015')->is_valid_number, 'プルデンシャル ジブラルタ ファイナンシャル生命保険 株式会社');
ok($zip->set_number('1028016')->is_valid_number, '全国健康保険協会 船員保険部');
ok($zip->set_number('1028018')->is_valid_number, 'ダイヤル・サービス 株式会社');
ok($zip->set_number('1028019')->is_valid_number, '株式会社 マッグガーデン');
ok($zip->set_number('1028022')->is_valid_number, 'SAPジャパン 株式会社');
ok($zip->set_number('1028025')->is_valid_number, '株式会社 オズマピーアール');
ok($zip->set_number('1028026')->is_valid_number, '株式会社 美術出版社');
ok($zip->set_number('1028030')->is_valid_number, '丸三証券 株式会社');
ok($zip->set_number('1028050')->is_valid_number, 'ネイチャーケア・ジャパン 株式会社');
ok($zip->set_number('1028055')->is_valid_number, '赤坂プリンスクラシックハウス');
ok($zip->set_number('1028077')->is_valid_number, '株式会社 KADOKAWA');
ok($zip->set_number('1028080')->is_valid_number, '株式会社 エフエム東京');
ok($zip->set_number('1028081')->is_valid_number, '国家公務員 共済組合連合会 (連合会代表)');
ok($zip->set_number('1028082')->is_valid_number, '国家公務員 共済組合連合会 (年金部)');
ok($zip->set_number('1028083')->is_valid_number, '国家公務員 共済組合連合会 (旧令年金部)');
ok($zip->set_number('1028085')->is_valid_number, '中央労働基準監督署');
ok($zip->set_number('1028088')->is_valid_number, 'JP損保サービス 株式会社');
ok($zip->set_number('1028101')->is_valid_number, '株式会社 秋田書店');
ok($zip->set_number('1028102')->is_valid_number, '古久根建設 株式会社');
ok($zip->set_number('1028103')->is_valid_number, '株式会社 アイ・イーシー');
ok($zip->set_number('1028109')->is_valid_number, '株式会社 アシスト');
ok($zip->set_number('1028110')->is_valid_number, '株式会社 潮出版社');
ok($zip->set_number('1028111')->is_valid_number, '昭和アルミニウム 株式会社');
ok($zip->set_number('1028112')->is_valid_number, '大和ハウス工業 株式会社');
ok($zip->set_number('1028115')->is_valid_number, 'オンワード商事 株式会社');
ok($zip->set_number('1028117')->is_valid_number, '株式会社 日建設計');
ok($zip->set_number('1028118')->is_valid_number, '新村印刷 株式会社');
ok($zip->set_number('1028119')->is_valid_number, '一般財団法人 全国消防協会');
ok($zip->set_number('1028120')->is_valid_number, 'ゼネラルエレクトリックキャピタルカーシステム 株式会社');
ok($zip->set_number('1028122')->is_valid_number, '東亜販売 株式会社');
ok($zip->set_number('1028123')->is_valid_number, '日販アイ・ピー・エス 株式会社');
ok($zip->set_number('1028124')->is_valid_number, '株式会社 IDCフロンティア');
ok($zip->set_number('1028125')->is_valid_number, 'セントラル総合開発 株式会社');
ok($zip->set_number('1028128')->is_valid_number, 'アコム 株式会社');
ok($zip->set_number('1028130')->is_valid_number, '株式会社 ホテルエドモント');
ok($zip->set_number('1028131')->is_valid_number, 'トッパン・フォームズ 株式会社');
ok($zip->set_number('1028132')->is_valid_number, '法政大学 (保健体育部)');
ok($zip->set_number('1028138')->is_valid_number, '在日本朝鮮人総聯合会 中央本部 (朝鮮総聯中央本部)');
ok($zip->set_number('1028139')->is_valid_number, '株式会社 田中歯科器械店');
ok($zip->set_number('1028140')->is_valid_number, '三和電気工業 株式会社 営業本部');
ok($zip->set_number('1028141')->is_valid_number, '株式会社 IDGコミュニケーションズ');
ok($zip->set_number('1028142')->is_valid_number, '株式会社 鐵原');
ok($zip->set_number('1028144')->is_valid_number, '株式会社 富士見書房');
ok($zip->set_number('1028150')->is_valid_number, 'アコム 株式会社');
ok($zip->set_number('1028151')->is_valid_number, '前田建設工業 株式会社');
ok($zip->set_number('1028152')->is_valid_number, '株式会社 研究社本社');
ok($zip->set_number('1028155')->is_valid_number, '株式会社 保健同人社');
ok($zip->set_number('1028160')->is_valid_number, '法政大学');
ok($zip->set_number('1028161')->is_valid_number, '東京警察病院');
ok($zip->set_number('1028166')->is_valid_number, '伊藤忠テクノソリューションズ 株式会社');
ok($zip->set_number('1028170')->is_valid_number, '高山工業 株式会社');
ok($zip->set_number('1028171')->is_valid_number, 'ピー・シー・エー 株式会社');
ok($zip->set_number('1028172')->is_valid_number, '日本化薬 株式会社');
ok($zip->set_number('1028175')->is_valid_number, 'ダイダン 株式会社 東京本社');
ok($zip->set_number('1028176')->is_valid_number, 'ミシュランタイヤグループ');
ok($zip->set_number('1028177')->is_valid_number, '株式会社 KADOKAWA');
ok($zip->set_number('1028178')->is_valid_number, '学校法人 嘉悦学園');
ok($zip->set_number('1028181')->is_valid_number, '株式会社 日刊工業新聞社');
ok($zip->set_number('1028182')->is_valid_number, '常盤工業 株式会社');
ok($zip->set_number('1028184')->is_valid_number, '社団法人 日本アイスクリーム協会');
ok($zip->set_number('1028185')->is_valid_number, '学校法人 白百合学園');
ok($zip->set_number('1028186')->is_valid_number, '株式会社 椿本チエイン 東京支社');
ok($zip->set_number('1028187')->is_valid_number, '株式会社 世界文化社');
ok($zip->set_number('1028188')->is_valid_number, '日本地所 株式会社');
ok($zip->set_number('1028190')->is_valid_number, '株式会社 Begin');
ok($zip->set_number('1028191')->is_valid_number, '株式会社 家庭画報ビジネスパートナーズ');
ok($zip->set_number('1028192')->is_valid_number, '株式会社 世界文化ワンダーグループ');
ok($zip->set_number('1028193')->is_valid_number, '株式会社 ワンダーネットワーク');
ok($zip->set_number('1028194')->is_valid_number, '株式会社 ワンダーウェルネス');
ok($zip->set_number('1028195')->is_valid_number, '株式会社 世界文化ブックス');
ok($zip->set_number('1028201')->is_valid_number, '住宅・都市整備公団');
ok($zip->set_number('1028205')->is_valid_number, '株式会社 テクノ大手');
ok($zip->set_number('1028211')->is_valid_number, '株式会社 千修');
ok($zip->set_number('1028215')->is_valid_number, '前田建設工業 株式会社 関東支社・東京支店');
ok($zip->set_number('1028221')->is_valid_number, '株式会社 Jコミックテラス');
ok($zip->set_number('1028222')->is_valid_number, 'ニチレキ 株式会社');
ok($zip->set_number('1028223')->is_valid_number, 'ワイジェイFX 株式会社');
ok($zip->set_number('1028224')->is_valid_number, 'ワイズ・インシュアランス 株式会社');
ok($zip->set_number('1028225')->is_valid_number, '東京法務局');
ok($zip->set_number('1028226')->is_valid_number, '東京法務局');
ok($zip->set_number('1028228')->is_valid_number, '株式会社 カントー');
ok($zip->set_number('1028230')->is_valid_number, '株式会社 コーエーテクモゲームス');
ok($zip->set_number('1028231')->is_valid_number, '石垣食品 株式会社');
ok($zip->set_number('1028232')->is_valid_number, '株式会社 少年写真新聞社');
ok($zip->set_number('1028234')->is_valid_number, '社団法人 建設荷役車両安全技術協会');
ok($zip->set_number('1028235')->is_valid_number, '日本電子計算 株式会社');
ok($zip->set_number('1028236')->is_valid_number, 'ライト工業 株式会社');
ok($zip->set_number('1028238')->is_valid_number, '株式会社 昭文社');
ok($zip->set_number('1028240')->is_valid_number, '法政大学 就職部');
ok($zip->set_number('1028241')->is_valid_number, '社団法人 東京都歯科医師会');
ok($zip->set_number('1028246')->is_valid_number, '靖国神社');
ok($zip->set_number('1028250')->is_valid_number, '丸紅メタル 株式会社');
ok($zip->set_number('1028251')->is_valid_number, '日本大学大学院総合科学研究科');
ok($zip->set_number('1028255')->is_valid_number, '富士通 株式会社');
ok($zip->set_number('1028260')->is_valid_number, '株式会社 培風館');
ok($zip->set_number('1028264')->is_valid_number, '日本公認会計士協会');
ok($zip->set_number('1028265')->is_valid_number, '東京乗用旅客自動車厚生年金基金');
ok($zip->set_number('1028272')->is_valid_number, '日本鉄鋼建材リース 株式会社');
ok($zip->set_number('1028273')->is_valid_number, 'UAゼンセン');
ok($zip->set_number('1028275')->is_valid_number, '日本大学 本部');
ok($zip->set_number('1028277')->is_valid_number, '能美防災 株式会社');
ok($zip->set_number('1028282')->is_valid_number, 'ヤフー 株式会社');
ok($zip->set_number('1028288')->is_valid_number, '財団法人 東京顕微鏡院');
ok($zip->set_number('1028301')->is_valid_number, '株式会社 カー・アンド・ドライバー');
ok($zip->set_number('1028303')->is_valid_number, '株式会社 プレゼントハウス');
ok($zip->set_number('1028305')->is_valid_number, '厚生労働省 東京労働局');
ok($zip->set_number('1028309')->is_valid_number, '厚生労働省 関東信越厚生局 麻薬取締部');
ok($zip->set_number('1028310')->is_valid_number, '朝日エティック 株式会社');
ok($zip->set_number('1028311')->is_valid_number, '麹町税務署');
ok($zip->set_number('1028313')->is_valid_number, '角川シネプレックス 株式会社');
ok($zip->set_number('1028314')->is_valid_number, '丸紅インフォテック 株式会社');
ok($zip->set_number('1028321')->is_valid_number, '財団法人 日本武道館');
ok($zip->set_number('1028322')->is_valid_number, '東京国立近代美術館');
ok($zip->set_number('1028324')->is_valid_number, '株式会社 リビングくらしHOW研究所');
ok($zip->set_number('1028331')->is_valid_number, '株式会社 PHP研究所');
ok($zip->set_number('1028332')->is_valid_number, '飛島建設 株式会社');
ok($zip->set_number('1028333')->is_valid_number, '三喜商事 株式会社');
ok($zip->set_number('1028336')->is_valid_number, '学校法人 二松学舎');
ok($zip->set_number('1028341')->is_valid_number, '学校法人 東京家政学院');
ok($zip->set_number('1028343')->is_valid_number, '株式会社 ミスミ カスタマー・サービス・センター');
ok($zip->set_number('1028349')->is_valid_number, '株式会社 オークネット');
ok($zip->set_number('1028350')->is_valid_number, '株式会社 日新');
ok($zip->set_number('1028353')->is_valid_number, '(株) ソニー・ミュージックエンタテインメント');
ok($zip->set_number('1028356')->is_valid_number, '社団法人 第二地方銀行協会');
ok($zip->set_number('1028357')->is_valid_number, '学校法人 大妻学院 大妻女子大学 大妻女子大学短期大学部 大妻中学校 大妻高等学校');
ok($zip->set_number('1028362')->is_valid_number, '東工コーセン 株式会社');
ok($zip->set_number('1028364')->is_valid_number, '九段PFIサービス (株)');
ok($zip->set_number('1028370')->is_valid_number, '株式会社 伊勢半');
ok($zip->set_number('1028371')->is_valid_number, '株式会社 三省堂');
ok($zip->set_number('1028372')->is_valid_number, '株式会社 明光商会');
ok($zip->set_number('1028373')->is_valid_number, '冨士機材 (株)');
ok($zip->set_number('1028377')->is_valid_number, '実教出版 株式会社');
ok($zip->set_number('1028381')->is_valid_number, '英国大使館');
ok($zip->set_number('1028382')->is_valid_number, '東京硝子 株式会社');
ok($zip->set_number('1028383')->is_valid_number, 'コープケミカル 株式会社');
ok($zip->set_number('1028388')->is_valid_number, '株式会社 宝島社');
ok($zip->set_number('1028401')->is_valid_number, '株式会社 リビングプロシード');
ok($zip->set_number('1028402')->is_valid_number, 'フェデラルエクスプレスジャパン 株式会社');
ok($zip->set_number('1028404')->is_valid_number, '三菱電機エンジニアリング 株式会社');
ok($zip->set_number('1028405')->is_valid_number, '株式会社 ぶんか社');
ok($zip->set_number('1028406')->is_valid_number, '株式会社 ぶんか社 営業局');
ok($zip->set_number('1028407')->is_valid_number, '株式会社 ぶんか社 編集局');
ok($zip->set_number('1028410')->is_valid_number, '三進興産 株式会社');
ok($zip->set_number('1028411')->is_valid_number, '公益社団法人 全国農業共済協会');
ok($zip->set_number('1028414')->is_valid_number, '一般社団法人 日本病院会');
ok($zip->set_number('1028417')->is_valid_number, '株式会社 ヨーク');
ok($zip->set_number('1028419')->is_valid_number, '地方公共団体情報システム機構');
ok($zip->set_number('1028420')->is_valid_number, 'オーロラ 株式会社');
ok($zip->set_number('1028421')->is_valid_number, '電設工業 健康保険組合');
ok($zip->set_number('1028424')->is_valid_number, '大日本商事 (株)');
ok($zip->set_number('1028426')->is_valid_number, '株式会社 セブン・ミールサービス');
ok($zip->set_number('1028430')->is_valid_number, '第一火災海上保険 相互会社');
ok($zip->set_number('1028433')->is_valid_number, '株式会社 細川洋行');
ok($zip->set_number('1028437')->is_valid_number, '株式会社 セブン・カードサービス');
ok($zip->set_number('1028440')->is_valid_number, '株式会社 サンテック');
ok($zip->set_number('1028441')->is_valid_number, '丸紅エネルギー 株式会社');
ok($zip->set_number('1028445')->is_valid_number, '法政大学 通信教育部');
ok($zip->set_number('1028448')->is_valid_number, '地方職員共済組合団体共済部');
ok($zip->set_number('1028450')->is_valid_number, '(株) イトーヨーカ堂');
ok($zip->set_number('1028451')->is_valid_number, '東亜建設工業 株式会社');
ok($zip->set_number('1028452')->is_valid_number, '株式会社 セブン&アイ・ホールディングス');
ok($zip->set_number('1028455')->is_valid_number, '株式会社 セブン-イレブン・ジャパン');
ok($zip->set_number('1028459')->is_valid_number, '興研 株式会社');
ok($zip->set_number('1028460')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('1028461')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('1028462')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('1028464')->is_valid_number, '全日本自治団体 労働組合');
ok($zip->set_number('1028465')->is_valid_number, '住友大阪セメント 株式会社');
ok($zip->set_number('1028466')->is_valid_number, '株式会社 セブンドリーム・ドットコム');
ok($zip->set_number('1028468')->is_valid_number, 'バクスター 株式会社');
ok($zip->set_number('1028470')->is_valid_number, '学校法人 雙葉学園');
ok($zip->set_number('1028474')->is_valid_number, '財団法人 河川情報センター');
ok($zip->set_number('1028477')->is_valid_number, 'プルデンシャル生命保険 株式会社');
ok($zip->set_number('1028484')->is_valid_number, 'トラベラー 株式会社');
ok($zip->set_number('1028488')->is_valid_number, '株式会社 スポーツマーケティングプロパティーズ');
ok($zip->set_number('1028489')->is_valid_number, '日東紡績 株式会社');
ok($zip->set_number('1028502')->is_valid_number, '一般財団法人 歯科医療振興財団');
ok($zip->set_number('1028503')->is_valid_number, '株式会社 オリエントコーポレーション');
ok($zip->set_number('1028504')->is_valid_number, '株式会社 オリエントコーポレーション 首都圏管理センター');
ok($zip->set_number('1028506')->is_valid_number, '株式会社 ワコール 東京支社');
ok($zip->set_number('1028508')->is_valid_number, '医療法人社団 こころとからだの元氣プラザ');
ok($zip->set_number('1028510')->is_valid_number, 'ジブラルタ生命保険 株式会社');
ok($zip->set_number('1028511')->is_valid_number, '株式会社 アダック');
ok($zip->set_number('1028512')->is_valid_number, '株式会社 日本エディターズ');
ok($zip->set_number('1028513')->is_valid_number, '株式会社 DTダイナミクス');
ok($zip->set_number('1028515')->is_valid_number, '株式会社 サンケイリビング新聞社');
ok($zip->set_number('1028516')->is_valid_number, '松井証券 株式会社');
ok($zip->set_number('1028519')->is_valid_number, '株式会社 ポプラ社');
ok($zip->set_number('1028520')->is_valid_number, '株式会社 ミカミ');
ok($zip->set_number('1028522')->is_valid_number, '株式会社 協同宣伝');
ok($zip->set_number('1028525')->is_valid_number, 'メットライフ生命保険 株式会社');
ok($zip->set_number('1028528')->is_valid_number, '株式会社 生産日本社');
ok($zip->set_number('1028529')->is_valid_number, '真柄建設 株式会社 東京支店');
ok($zip->set_number('1028530')->is_valid_number, 'サントリー 株式会社');
ok($zip->set_number('1028531')->is_valid_number, 'クレジット債権管理組合');
ok($zip->set_number('1028532')->is_valid_number, '全国土木建築 国民健康保険組合 関東事務所');
ok($zip->set_number('1028533')->is_valid_number, '株式会社 エスコム');
ok($zip->set_number('1028539')->is_valid_number, '日本工営 株式会社');
ok($zip->set_number('1028540')->is_valid_number, '株式会社 かんき出版');
ok($zip->set_number('1028541')->is_valid_number, '海洋水産資源開発センター');
ok($zip->set_number('1028543')->is_valid_number, '扶桑レクセル 株式会社');
ok($zip->set_number('1028552')->is_valid_number, '株式会社 KADOKAWA');
ok($zip->set_number('1028553')->is_valid_number, '伊藤園 新俳句大賞事務局');
ok($zip->set_number('1028554')->is_valid_number, '上智大学 (上智学院)');
ok($zip->set_number('1028555')->is_valid_number, '財団法人 新エネルギー財団');
ok($zip->set_number('1028556')->is_valid_number, '公益社団法人 全国自治体病院協議会');
ok($zip->set_number('1028557')->is_valid_number, 'MBE 紀尾井町店');
ok($zip->set_number('1028558')->is_valid_number, '株式会社 スタッフ・サービス 千代田支社');
ok($zip->set_number('1028559')->is_valid_number, '公益社団法人 日本文藝家協会');
ok($zip->set_number('1028560')->is_valid_number, 'ハウス食品 株式会社');
ok($zip->set_number('1028561')->is_valid_number, '一般社団法人 倫理研究所');
ok($zip->set_number('1028563')->is_valid_number, 'リコーリース 株式会社');
ok($zip->set_number('1028564')->is_valid_number, '全国土木建築国民健康保険組合');
ok($zip->set_number('1028565')->is_valid_number, '株式会社 オータニコーポレーション');
ok($zip->set_number('1028566')->is_valid_number, '岩田地崎建設 株式会社');
ok($zip->set_number('1028567')->is_valid_number, '財団法人 日本海事協会');
ok($zip->set_number('1028569')->is_valid_number, '株式会社 ニッポン放送プロジェクト');
ok($zip->set_number('1028570')->is_valid_number, 'ビーエーエスエフジャパン 株式会社');
ok($zip->set_number('1028571')->is_valid_number, 'SJハウス');
ok($zip->set_number('1028573')->is_valid_number, '株式会社 大塚商会');
ok($zip->set_number('1028577')->is_valid_number, '社団法人 日本民間放送連盟');
ok($zip->set_number('1028578')->is_valid_number, '株式会社 ニュー・オータニ');
ok($zip->set_number('1028580')->is_valid_number, '株式会社 インフィニトラベルインフォメーション');
ok($zip->set_number('1028582')->is_valid_number, '株式会社 ミスミ');
ok($zip->set_number('1028583')->is_valid_number, '株式会社 ミスミグループ本社');
ok($zip->set_number('1028585')->is_valid_number, 'ザ・プリンスギャラリー 東京紀尾井町');
ok($zip->set_number('1028586')->is_valid_number, 'エイチアールティーニューオータニ 株式会社');
ok($zip->set_number('1028588')->is_valid_number, '警察共済組合 本部');
ok($zip->set_number('1028601')->is_valid_number, '地方職員 共済組合');
ok($zip->set_number('1028602')->is_valid_number, '株式会社 放送出版プロモーション');
ok($zip->set_number('1028603')->is_valid_number, '社団法人 日本船主協会');
ok($zip->set_number('1028604')->is_valid_number, '株式会社 放送出版エージェンシー');
ok($zip->set_number('1028606')->is_valid_number, 'LVMHフレグランスブランズ 株式会社');
ok($zip->set_number('1028607')->is_valid_number, '警察職員生活協同組合');
ok($zip->set_number('1028609')->is_valid_number, '株式会社 読売情報開発 読売ファミリー・サークル');
ok($zip->set_number('1028610')->is_valid_number, '生活協同組合全国都市職員災害共済会');
ok($zip->set_number('1028611')->is_valid_number, '株式会社 システム収納センター');
ok($zip->set_number('1028612')->is_valid_number, '株式会社 水中造形センター');
ok($zip->set_number('1028613')->is_valid_number, '伊藤忠フアインケミカル 株式会社');
ok($zip->set_number('1028614')->is_valid_number, '住銀保証 株式会社');
ok($zip->set_number('1028617')->is_valid_number, '株式会社 ディーエムジェイ');
ok($zip->set_number('1028618')->is_valid_number, '(株) 読売情報開発');
ok($zip->set_number('1028619')->is_valid_number, '(株) 読売ハートサービス');
ok($zip->set_number('1028620')->is_valid_number, '株式会社 ブティック社');
ok($zip->set_number('1028621')->is_valid_number, '株式会社 みらい建設グループ');
ok($zip->set_number('1028622')->is_valid_number, '株式会社 カービュー');
ok($zip->set_number('1028626')->is_valid_number, '日本能力科学アカデミー');
ok($zip->set_number('1028627')->is_valid_number, '株式会社 全日本通教');
ok($zip->set_number('1028628')->is_valid_number, 'きんでん 東京本社');
ok($zip->set_number('1028630')->is_valid_number, '全国共済農業協同組合連合会 全国本部');
ok($zip->set_number('1028631')->is_valid_number, '野村貿易 株式会社');
ok($zip->set_number('1028632')->is_valid_number, 'プリメイト');
ok($zip->set_number('1028633')->is_valid_number, '株式会社 たいよう共済');
ok($zip->set_number('1028635')->is_valid_number, '全国市長会');
ok($zip->set_number('1028637')->is_valid_number, '株式会社 全日本通販');
ok($zip->set_number('1028639')->is_valid_number, 'あしなが育英会');
ok($zip->set_number('1028642')->is_valid_number, '株式会社 ユーラシア旅行社');
ok($zip->set_number('1028643')->is_valid_number, '公益財団法人 日本生産性本部');
ok($zip->set_number('1028644')->is_valid_number, '株式会社 ビーエス日本(ビーエス日テレ)');
ok($zip->set_number('1028645')->is_valid_number, 'セコム損害保険 株式会社');
ok($zip->set_number('1028650')->is_valid_number, '財形住宅金融 株式会社');
ok($zip->set_number('1028651')->is_valid_number, '最高裁判所');
ok($zip->set_number('1028655')->is_valid_number, 'パルファン・クリスチャン・ディオール・ジャポン 株式会社');
ok($zip->set_number('1028656')->is_valid_number, '日本芸術文化振興会');
ok($zip->set_number('1028660')->is_valid_number, '株式会社 あおぞら銀行');
ok($zip->set_number('1028666')->is_valid_number, '独立行政法人 科学技術振興機構');
ok($zip->set_number('1028667')->is_valid_number, '万有製薬 株式会社');
ok($zip->set_number('1028668')->is_valid_number, '財団法人 日本棋院');
ok($zip->set_number('1028671')->is_valid_number, '株式会社 エルヴィジョン');
ok($zip->set_number('1028677')->is_valid_number, '株式会社 日本金融通信社 (ニッキン)');
ok($zip->set_number('1028678')->is_valid_number, '株式会社 錢高組 東京本社・支社');
ok($zip->set_number('1028679')->is_valid_number, '株式会社 ソニー・マガジンズ');
ok($zip->set_number('1028680')->is_valid_number, '株式会社 世界文化社');
ok($zip->set_number('1028685')->is_valid_number, '株式会社 角川ヘラルド・ピクチャーズ');
ok($zip->set_number('1028688')->is_valid_number, '東京都千代田区役所');
ok($zip->set_number('1028689')->is_valid_number, '株式会社 第一学習社');
ok($zip->set_number('1028730')->is_valid_number, 'ダイトロン 株式会社');
ok($zip->set_number('1028795')->is_valid_number, '総務省 関東総合通信局');
ok($zip->set_number('1028798')->is_valid_number, '東京逓信病院');
ok($zip->set_number('1038001')->is_valid_number, '株式会社 三越');
ok($zip->set_number('1038011')->is_valid_number, '野村證券 株式会社');
ok($zip->set_number('1038201')->is_valid_number, '三洋証券 株式会社');
ok($zip->set_number('1038202')->is_valid_number, '日本証券代行 株式会社');
ok($zip->set_number('1038203')->is_valid_number, 'オーストラリアドライフルーツ 株式会社');
ok($zip->set_number('1038203')->is_valid_number, '株式会社 京まろん');
ok($zip->set_number('1038203')->is_valid_number, '株式会社 正栄デリシィ');
ok($zip->set_number('1038203')->is_valid_number, '株式会社 ロビニア');
ok($zip->set_number('1038203')->is_valid_number, '正栄食品工業 株式会社');
ok($zip->set_number('1038203')->is_valid_number, '成光商事 株式会社');
ok($zip->set_number('1038203')->is_valid_number, '筑波乳業 株式会社');
ok($zip->set_number('1038203')->is_valid_number, '本多興産 有限会社');
ok($zip->set_number('1038204')->is_valid_number, '住友三井オートサービス 株式会社');
ok($zip->set_number('1038205')->is_valid_number, 'ハナマルキ 株式会社');
ok($zip->set_number('1038206')->is_valid_number, '田中貴金属工業 株式会社');
ok($zip->set_number('1038208')->is_valid_number, '日本電子計算 株式会社');
ok($zip->set_number('1038210')->is_valid_number, '花王 株式会社');
ok($zip->set_number('1038211')->is_valid_number, '澁澤倉庫 株式会社');
ok($zip->set_number('1038212')->is_valid_number, '全国経済事業協同組合連合会');
ok($zip->set_number('1038214')->is_valid_number, '株式会社 第一成和事務所');
ok($zip->set_number('1038218')->is_valid_number, '高島屋スペースクリエイツ 株式会社');
ok($zip->set_number('1038221')->is_valid_number, 'SMBCフレンド証券 株式会社');
ok($zip->set_number('1038222')->is_valid_number, '平和不動産 株式会社');
ok($zip->set_number('1038224')->is_valid_number, '株式会社 日本取引所グループ');
ok($zip->set_number('1038225')->is_valid_number, 'SMBC日興証券 株式会社');
ok($zip->set_number('1038228')->is_valid_number, '加藤産商 株式会社');
ok($zip->set_number('1038229')->is_valid_number, '日本取引所自主規制法人');
ok($zip->set_number('1038230')->is_valid_number, 'BofA証券 株式会社');
ok($zip->set_number('1038231')->is_valid_number, '株式会社 毎日EVRシステム');
ok($zip->set_number('1038232')->is_valid_number, '宝酒造 株式会社 首都圏支社');
ok($zip->set_number('1038233')->is_valid_number, 'DIC 株式会社');
ok($zip->set_number('1038234')->is_valid_number, '第一三共 株式会社 第一三共日本橋ビル');
ok($zip->set_number('1038235')->is_valid_number, '高島屋クレジット 株式会社');
ok($zip->set_number('1038236')->is_valid_number, '日本農薬 株式会社');
ok($zip->set_number('1038237')->is_valid_number, 'NS建材薄板 株式会社');
ok($zip->set_number('1038238')->is_valid_number, '株式会社 東日本銀行');
ok($zip->set_number('1038239')->is_valid_number, '株式会社 オンワードホールディングス');
ok($zip->set_number('1038240')->is_valid_number, '大和製罐 株式会社');
ok($zip->set_number('1038241')->is_valid_number, '国分グループ本社 株式会社');
ok($zip->set_number('1038243')->is_valid_number, '富士電機イー・アイ・シー 株式会社');
ok($zip->set_number('1038245')->is_valid_number, '丸善 株式会社');
ok($zip->set_number('1038247')->is_valid_number, '伊藤忠丸紅鉄鋼 株式会社');
ok($zip->set_number('1038248')->is_valid_number, '株式会社 馬渕商事');
ok($zip->set_number('1038250')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('1038251')->is_valid_number, '株式会社 コーセー');
ok($zip->set_number('1038252')->is_valid_number, '日本生命保険 相互会社 日本橋総支社');
ok($zip->set_number('1038255')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('1038256')->is_valid_number, '株式会社 サニクリーン');
ok($zip->set_number('1038259')->is_valid_number, 'スミダ電機 株式会社');
ok($zip->set_number('1038260')->is_valid_number, '野村アセットマネジメント 株式会社');
ok($zip->set_number('1038261')->is_valid_number, '神鋼商事 株式会社');
ok($zip->set_number('1038263')->is_valid_number, '三井造船 株式会社');
ok($zip->set_number('1038265')->is_valid_number, '株式会社 高島屋');
ok($zip->set_number('1038266')->is_valid_number, '株式会社 日本旅行');
ok($zip->set_number('1038270')->is_valid_number, '日本橋社会保険事務所');
ok($zip->set_number('1038273')->is_valid_number, '三井リース事業 株式会社');
ok($zip->set_number('1038276')->is_valid_number, '株式会社 コングレ');
ok($zip->set_number('1038277')->is_valid_number, '株式会社 エヌ・ティ・ティ・ロジスコ');
ok($zip->set_number('1038277')->is_valid_number, '株式会社 エヌ・ティ・ティ・ロジスコサービス');
ok($zip->set_number('1038278')->is_valid_number, '岡三証券 株式会社');
ok($zip->set_number('1038282')->is_valid_number, '日本電工 株式会社');
ok($zip->set_number('1038284')->is_valid_number, '株式会社 東陽テクニカ');
ok($zip->set_number('1038285')->is_valid_number, '東京建物 株式会社');
ok($zip->set_number('1038287')->is_valid_number, '株式会社 廣瀬商会');
ok($zip->set_number('1038301')->is_valid_number, '緑屋電気 株式会社');
ok($zip->set_number('1038303')->is_valid_number, '株式会社 SBI新生銀行');
ok($zip->set_number('1038307')->is_valid_number, 'ブリヂストン化成品東京 株式会社');
ok($zip->set_number('1038308')->is_valid_number, '富士フィルター工業 株式会社');
ok($zip->set_number('1038311')->is_valid_number, '旭電化工業 株式会社');
ok($zip->set_number('1038312')->is_valid_number, '株式会社 アプラス');
ok($zip->set_number('1038313')->is_valid_number, '小堺化学工業 株式会社');
ok($zip->set_number('1038314')->is_valid_number, '株式会社 クマヒラ');
ok($zip->set_number('1038317')->is_valid_number, '株式会社 QUICK 本社');
ok($zip->set_number('1038318')->is_valid_number, '昭和リース 株式会社');
ok($zip->set_number('1038321')->is_valid_number, 'ユニチカ 株式会社 東京本社');
ok($zip->set_number('1038323')->is_valid_number, '三井信託銀行 株式会社');
ok($zip->set_number('1038324')->is_valid_number, '中外製薬 株式会社');
ok($zip->set_number('1038325')->is_valid_number, '株式会社 ニッセイコム');
ok($zip->set_number('1038328')->is_valid_number, 'マンダリン・オリエンタル東京 株式会社');
ok($zip->set_number('1038330')->is_valid_number, 'わかもと製薬 株式会社');
ok($zip->set_number('1038331')->is_valid_number, '三機工業 株式会社');
ok($zip->set_number('1038333')->is_valid_number, 'UFJつばさ証券 株式会社');
ok($zip->set_number('1038335')->is_valid_number, '日本レジャーカードシステム 株式会社');
ok($zip->set_number('1038337')->is_valid_number, 'MBEジャパン 株式会社');
ok($zip->set_number('1038338')->is_valid_number, 'デンカ 株式会社');
ok($zip->set_number('1038339')->is_valid_number, '三省物産 株式会社');
ok($zip->set_number('1038341')->is_valid_number, '北興化学工業 株式会社');
ok($zip->set_number('1038345')->is_valid_number, '株式会社 東洋経済新報社');
ok($zip->set_number('1038346')->is_valid_number, '全国社会保険労務士会連合会');
ok($zip->set_number('1038347')->is_valid_number, '全国社会保険労務士会連合会 社会保険労務士試験センター');
ok($zip->set_number('1038350')->is_valid_number, '早川商事 株式会社');
ok($zip->set_number('1038351')->is_valid_number, 'ゼリア新薬工業 株式会社');
ok($zip->set_number('1038352')->is_valid_number, '小原化工 株式会社');
ok($zip->set_number('1038354')->is_valid_number, '株式会社 アドバンス');
ok($zip->set_number('1038358')->is_valid_number, '日本トレーディング 株式会社');
ok($zip->set_number('1038360')->is_valid_number, '東京都中央区日本橋特別出張所');
ok($zip->set_number('1038363')->is_valid_number, '橋本総業 株式会社');
ok($zip->set_number('1038366')->is_valid_number, '曽田香料 株式会社');
ok($zip->set_number('1038370')->is_valid_number, '株式会社 エトワール海渡');
ok($zip->set_number('1038380')->is_valid_number, '株式会社 岡永');
ok($zip->set_number('1038383')->is_valid_number, '大日精化工業 株式会社');
ok($zip->set_number('1038384')->is_valid_number, '開智日本橋学園中学・高等学校');
ok($zip->set_number('1038388')->is_valid_number, 'マービー 株式会社');
ok($zip->set_number('1038401')->is_valid_number, '大木建設 株式会社');
ok($zip->set_number('1038402')->is_valid_number, '信越ポリマー 株式会社');
ok($zip->set_number('1038403')->is_valid_number, 'アステナホールディングス 株式会社');
ok($zip->set_number('1038404')->is_valid_number, 'ツカモト 株式会社');
ok($zip->set_number('1038405')->is_valid_number, '田辺三菱製薬 株式会社 東京本社');
ok($zip->set_number('1038407')->is_valid_number, '東洋ケミカルズ 株式会社');
ok($zip->set_number('1038410')->is_valid_number, 'KISCO 株式会社');
ok($zip->set_number('1038411')->is_valid_number, 'アステラス製薬 株式会社');
ok($zip->set_number('1038412')->is_valid_number, '関東化学 株式会社');
ok($zip->set_number('1038413')->is_valid_number, 'カネダ 株式会社');
ok($zip->set_number('1038414')->is_valid_number, '丹平中田 株式会社 東京支社');
ok($zip->set_number('1038415')->is_valid_number, '伊藤忠紙パルプ 株式会社');
ok($zip->set_number('1038416')->is_valid_number, '萬有製薬 株式会社');
ok($zip->set_number('1038417')->is_valid_number, 'オー・ジー 株式会社 東京支店');
ok($zip->set_number('1038419')->is_valid_number, '伊藤忠建材 株式会社');
ok($zip->set_number('1038422')->is_valid_number, '日曹商事 株式会社');
ok($zip->set_number('1038424')->is_valid_number, 'ポリマテック 株式会社');
ok($zip->set_number('1038425')->is_valid_number, '大建工業 株式会社');
ok($zip->set_number('1038426')->is_valid_number, '第一三共 株式会社 本社ビル');
ok($zip->set_number('1038427')->is_valid_number, '伊藤忠連合健康保険組合');
ok($zip->set_number('1038430')->is_valid_number, '株式会社 建設技術研究所');
ok($zip->set_number('1038431')->is_valid_number, '長谷川香料 株式会社');
ok($zip->set_number('1038432')->is_valid_number, 'ヤマト科学 株式会社');
ok($zip->set_number('1038433')->is_valid_number, '興和 株式会社 東京支店');
ok($zip->set_number('1038434')->is_valid_number, '岩城製薬 株式会社');
ok($zip->set_number('1038435')->is_valid_number, '小津産業 株式会社');
ok($zip->set_number('1038438')->is_valid_number, 'リケンテクノス 株式会社');
ok($zip->set_number('1038439')->is_valid_number, '鳥居薬品 株式会社');
ok($zip->set_number('1038443')->is_valid_number, '株式会社 つぼ八');
ok($zip->set_number('1038448')->is_valid_number, '稲畑産業 株式会社');
ok($zip->set_number('1038450')->is_valid_number, '株式会社 上田嘉一朗商店');
ok($zip->set_number('1038451')->is_valid_number, '株式会社 ガイア');
ok($zip->set_number('1038456')->is_valid_number, '日清紡マイクロデバイス 株式会社');
ok($zip->set_number('1038460')->is_valid_number, 'ミツワ電機 株式会社');
ok($zip->set_number('1038461')->is_valid_number, 'カゴメ 株式会社 東京本社');
ok($zip->set_number('1038462')->is_valid_number, 'カゴメ 株式会社 東京支社');
ok($zip->set_number('1038464')->is_valid_number, '株式会社 エー・アンド・イー');
ok($zip->set_number('1038465')->is_valid_number, '東京実業健康保険組合');
ok($zip->set_number('1038466')->is_valid_number, '株式会社 大山');
ok($zip->set_number('1038468')->is_valid_number, '一般財団法人 日本中国語検定協会');
ok($zip->set_number('1038470')->is_valid_number, '三共生興 株式会社');
ok($zip->set_number('1038471')->is_valid_number, '斎長物産 株式会社');
ok($zip->set_number('1038472')->is_valid_number, '豊島 株式会社 東京本社');
ok($zip->set_number('1038473')->is_valid_number, 'ゼリア新薬工業 株式会社 東京支店');
ok($zip->set_number('1038480')->is_valid_number, 'ピジョン 株式会社');
ok($zip->set_number('1038482')->is_valid_number, '株式会社 ベースボール・マガジン社');
ok($zip->set_number('1038484')->is_valid_number, '社団法人 日本ボウリング場協会');
ok($zip->set_number('1038485')->is_valid_number, '株式会社 化学工業日報社');
ok($zip->set_number('1038487')->is_valid_number, '長瀬ランダウア 株式会社');
ok($zip->set_number('1038488')->is_valid_number, 'トヨタモビリティサービス 株式会社');
ok($zip->set_number('1038501')->is_valid_number, 'ソフトバンク 株式会社');
ok($zip->set_number('1038502')->is_valid_number, 'マックス 株式会社');
ok($zip->set_number('1038503')->is_valid_number, '協和発酵キリン 株式会社 東京支店');
ok($zip->set_number('1038506')->is_valid_number, '全国建設工事業国民健康保険組合');
ok($zip->set_number('1038510')->is_valid_number, '日本アイ・ビー・エム 株式会社 箱崎事業所');
ok($zip->set_number('1038511')->is_valid_number, 'ダイトウボウ 株式会社');
ok($zip->set_number('1038512')->is_valid_number, '日本オフィス・システム 株式会社');
ok($zip->set_number('1038515')->is_valid_number, 'サンテレホン 株式会社');
ok($zip->set_number('1038517')->is_valid_number, '株式会社 吉野家');
ok($zip->set_number('1038520')->is_valid_number, '株式会社 ロイヤルパークホテル');
ok($zip->set_number('1038521')->is_valid_number, '株式会社 インパクト21');
ok($zip->set_number('1038522')->is_valid_number, '株式会社 桃屋');
ok($zip->set_number('1038525')->is_valid_number, '株式会社 ジャック');
ok($zip->set_number('1038534')->is_valid_number, '曙ブレーキ工業 株式会社');
ok($zip->set_number('1038535')->is_valid_number, '(株) 新聞編集センター');
ok($zip->set_number('1038536')->is_valid_number, '日新製糖 株式会社 日新製糖ホールディングス 株式会社');
ok($zip->set_number('1038537')->is_valid_number, 'ユーシーカード 株式会社');
ok($zip->set_number('1038538')->is_valid_number, 'ぺんてる 株式会社');
ok($zip->set_number('1038542')->is_valid_number, '株式会社 山下設計');
ok($zip->set_number('1038543')->is_valid_number, '株式会社 不動テトラ');
ok($zip->set_number('1038548')->is_valid_number, '株式会社 日刊工業新聞社');
ok($zip->set_number('1038551')->is_valid_number, '日本橋税務署');
ok($zip->set_number('1038552')->is_valid_number, '株式会社 クレハ');
ok($zip->set_number('1038554')->is_valid_number, '東京織物健康保険組合');
ok($zip->set_number('1038556')->is_valid_number, '三井物産フューチャーズ 株式会社');
ok($zip->set_number('1038558')->is_valid_number, '市田 株式会社');
ok($zip->set_number('1038566')->is_valid_number, 'デンヨー 株式会社');
ok($zip->set_number('1038567')->is_valid_number, '株式会社 サントリーショッピングクラブ');
ok($zip->set_number('1038571')->is_valid_number, 'ヤマト 株式会社');
ok($zip->set_number('1038577')->is_valid_number, '丸文 株式会社');
ok($zip->set_number('1038584')->is_valid_number, 'トスコ 株式会社');
ok($zip->set_number('1038585')->is_valid_number, '富士紡ホールディングス 株式会社');
ok($zip->set_number('1038586')->is_valid_number, '日本トータルテレマーケティング 株式会社');
ok($zip->set_number('1038588')->is_valid_number, '株式会社 パーカーコーポレーション');
ok($zip->set_number('1038631')->is_valid_number, '出光クレジット 株式会社');
ok($zip->set_number('1038636')->is_valid_number, '株式会社 興伸');
ok($zip->set_number('1038639')->is_valid_number, '佐藤工業 株式会社');
ok($zip->set_number('1038640')->is_valid_number, '日本アジア証券 株式会社');
ok($zip->set_number('1038650')->is_valid_number, '日清紡ホールディングス 株式会社');
ok($zip->set_number('1038651')->is_valid_number, '株式会社 山口銀行 東京支店');
ok($zip->set_number('1038653')->is_valid_number, '株式会社 千葉銀行 東京営業部');
ok($zip->set_number('1038656')->is_valid_number, '株式会社 広島銀行 東京支店');
ok($zip->set_number('1038660')->is_valid_number, '日本銀行');
ok($zip->set_number('1038666')->is_valid_number, '東レ 株式会社 本社');
ok($zip->set_number('1038668')->is_valid_number, '武田薬品工業 株式会社');
ok($zip->set_number('1038676')->is_valid_number, '株式会社 群馬銀行 東京支店');
ok($zip->set_number('1038677')->is_valid_number, '株式会社 みずほコーポレート銀行');
ok($zip->set_number('1038680')->is_valid_number, '株式会社 守谷商会');
ok($zip->set_number('1038684')->is_valid_number, '株式会社 三菱UFJ銀行');
ok($zip->set_number('1038686')->is_valid_number, '株式会社 ベネッセコーポレーション');
ok($zip->set_number('1038689')->is_valid_number, 'スルガ銀行 株式会社 東京支店');
ok($zip->set_number('1046241')->is_valid_number, 'SCSK 株式会社');
ok($zip->set_number('1048001')->is_valid_number, '株式会社 リクルート 銀座8丁目ビル');
ok($zip->set_number('1048002')->is_valid_number, 'Meiji Seika ファルマ 株式会社');
ok($zip->set_number('1048003')->is_valid_number, '株式会社 マガジンハウス');
ok($zip->set_number('1048004')->is_valid_number, '株式会社 東京ニュース通信社');
ok($zip->set_number('1048007')->is_valid_number, '株式会社 日刊現代');
ok($zip->set_number('1048010')->is_valid_number, '株式会社 資生堂');
ok($zip->set_number('1048011')->is_valid_number, '朝日新聞 東京本社');
ok($zip->set_number('1048055')->is_valid_number, '株式会社 日刊スポーツ新聞社');
ok($zip->set_number('1048077')->is_valid_number, '公益財団法人 都民劇場');
ok($zip->set_number('1048101')->is_valid_number, '株式会社 紀文食品');
ok($zip->set_number('1048102')->is_valid_number, '株式会社 ワシントン靴店');
ok($zip->set_number('1048104')->is_valid_number, '株式会社 法研');
ok($zip->set_number('1048105')->is_valid_number, '株式会社 和光');
ok($zip->set_number('1048108')->is_valid_number, '東映 株式会社');
ok($zip->set_number('1048109')->is_valid_number, 'ソマール 株式会社');
ok($zip->set_number('1048110')->is_valid_number, 'セイコーホールディングス 株式会社');
ok($zip->set_number('1048111')->is_valid_number, '廣告社 株式会社');
ok($zip->set_number('1048112')->is_valid_number, '独立行政法人 日本学生支援機構');
ok($zip->set_number('1048114')->is_valid_number, '社団法人 公開経営指導協会');
ok($zip->set_number('1048115')->is_valid_number, '千代田工販 株式会社');
ok($zip->set_number('1048116')->is_valid_number, '北野建設 株式会社 東京本社');
ok($zip->set_number('1048117')->is_valid_number, '大和自動車交通 株式會社');
ok($zip->set_number('1048118')->is_valid_number, 'セイコーウオッチ 株式会社');
ok($zip->set_number('1048122')->is_valid_number, '富士火災海上保険 株式会社');
ok($zip->set_number('1048123')->is_valid_number, 'UIP映画');
ok($zip->set_number('1048124')->is_valid_number, '中越パルプ工業 株式会社');
ok($zip->set_number('1048125')->is_valid_number, 'ヤマト運輸 株式会社');
ok($zip->set_number('1048128')->is_valid_number, '綜合ユニコム 株式会社');
ok($zip->set_number('1048129')->is_valid_number, 'セイコーホールディングス 株式会社');
ok($zip->set_number('1048130')->is_valid_number, '株式会社 松屋 銀座本店');
ok($zip->set_number('1048131')->is_valid_number, '押谷フエルト化成 株式会社');
ok($zip->set_number('1048132')->is_valid_number, '株式会社 博品館');
ok($zip->set_number('1048133')->is_valid_number, '東京電力 株式会社 銀座支店');
ok($zip->set_number('1048134')->is_valid_number, 'リコーリース 株式会社');
ok($zip->set_number('1048135')->is_valid_number, '株式会社 日本香堂');
ok($zip->set_number('1048138')->is_valid_number, '株式会社 ゼアリズ');
ok($zip->set_number('1048139')->is_valid_number, '株式会社 紙パルプ会館');
ok($zip->set_number('1048142')->is_valid_number, '株式会社 ジャパン・エンターテイメント・ネットワーク');
ok($zip->set_number('1048145')->is_valid_number, '株式会社 ミキモト 銀座4丁目本店');
ok($zip->set_number('1048150')->is_valid_number, '株式会社 東京ソワール');
ok($zip->set_number('1048151')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('1048158')->is_valid_number, '共同ピーアール 株式会社');
ok($zip->set_number('1048161')->is_valid_number, '株式会社 電通名鉄コミュニケーションズ');
ok($zip->set_number('1048162')->is_valid_number, '合同酒精 株式会社');
ok($zip->set_number('1048165')->is_valid_number, '電源開発 株式会社');
ok($zip->set_number('1048167')->is_valid_number, '日放 株式会社');
ok($zip->set_number('1048168')->is_valid_number, '株式会社 近代映画社');
ok($zip->set_number('1048170')->is_valid_number, '株式会社 イノアックコーポレーション');
ok($zip->set_number('1048171')->is_valid_number, '株式会社 電通マクロミルインサイト');
ok($zip->set_number('1048174')->is_valid_number, '荏原実業 株式会社');
ok($zip->set_number('1048175')->is_valid_number, '日本年金機構 中央年金事務所');
ok($zip->set_number('1048176')->is_valid_number, '株式会社 日本経済社');
ok($zip->set_number('1048178')->is_valid_number, '株式会社 時事通信社');
ok($zip->set_number('1048179')->is_valid_number, '一般社団法人 中央調査社');
ok($zip->set_number('1048183')->is_valid_number, '株式会社 東成社');
ok($zip->set_number('1048188')->is_valid_number, 'スウォッチ グループ ジャパン 株式会社');
ok($zip->set_number('1048189')->is_valid_number, '株式会社 栄美通信');
ok($zip->set_number('1048205')->is_valid_number, '福徳長酒類 株式会社');
ok($zip->set_number('1048206')->is_valid_number, '共和ピー・アール 株式会社');
ok($zip->set_number('1048208')->is_valid_number, '株式会社 ノエビア');
ok($zip->set_number('1048210')->is_valid_number, '株式会社 電通パブリックリレーションズ');
ok($zip->set_number('1048211')->is_valid_number, '中央宣興 株式会社');
ok($zip->set_number('1048212')->is_valid_number, '株式会社 三越 銀座店');
ok($zip->set_number('1048218')->is_valid_number, '株式会社 ENEOSフロンティア');
ok($zip->set_number('1048238')->is_valid_number, 'ストックプラス');
ok($zip->set_number('1048240')->is_valid_number, '株式会社 ヒサヤ大黒堂');
ok($zip->set_number('1048251')->is_valid_number, '株式会社 アカギ');
ok($zip->set_number('1048252')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('1048254')->is_valid_number, '日本酒類販売 株式会社');
ok($zip->set_number('1048255')->is_valid_number, 'セントラルスポーツ 株式会社');
ok($zip->set_number('1048257')->is_valid_number, '日本重化学工業 株式会社');
ok($zip->set_number('1048258')->is_valid_number, '三井住友海上あいおい生命保険 株式会社');
ok($zip->set_number('1048262')->is_valid_number, '青山特殊鋼 株式会社');
ok($zip->set_number('1048266')->is_valid_number, '株式会社 鈴乃屋');
ok($zip->set_number('1048271')->is_valid_number, 'SMBC日興証券 株式会社');
ok($zip->set_number('1048280')->is_valid_number, '新日鉄住金ソリューションズ 株式会社');
ok($zip->set_number('1048281')->is_valid_number, '松井建設 株式会社');
ok($zip->set_number('1048282')->is_valid_number, '株式会社 内田洋行');
ok($zip->set_number('1048283')->is_valid_number, '株式会社 SBI新生銀行');
ok($zip->set_number('1048284')->is_valid_number, 'アイク 株式会社');
ok($zip->set_number('1048285')->is_valid_number, '日清オイリオグループ 株式会社');
ok($zip->set_number('1048289')->is_valid_number, '大豊建設 株式会社');
ok($zip->set_number('1048301')->is_valid_number, 'LG Electronics Japan 株式会社');
ok($zip->set_number('1048302')->is_valid_number, '株式会社 明治屋');
ok($zip->set_number('1048304')->is_valid_number, '株式会社 パイロットコーポレーション');
ok($zip->set_number('1048306')->is_valid_number, '株式会社 明治');
ok($zip->set_number('1048307')->is_valid_number, '株式会社 クボタ');
ok($zip->set_number('1048310')->is_valid_number, '全国信用協同組合連合会');
ok($zip->set_number('1048312')->is_valid_number, '片倉工業 株式会社');
ok($zip->set_number('1048313')->is_valid_number, '株式会社 朝日広告社');
ok($zip->set_number('1048315')->is_valid_number, '味の素 株式会社 (本社)');
ok($zip->set_number('1048317')->is_valid_number, '東海東京証券 株式会社');
ok($zip->set_number('1048319')->is_valid_number, '王子ネピア 株式会社');
ok($zip->set_number('1048324')->is_valid_number, '東洋熱工業 株式会社');
ok($zip->set_number('1048325')->is_valid_number, '株式会社 読売新聞社 事業局');
ok($zip->set_number('1048328')->is_valid_number, '株式会社 オービック');
ok($zip->set_number('1048330')->is_valid_number, '大成有楽不動産 株式会社');
ok($zip->set_number('1048332')->is_valid_number, '大成有楽不動産 株式会社');
ok($zip->set_number('1048333')->is_valid_number, '国際紙パルプ商事 株式会社');
ok($zip->set_number('1048335')->is_valid_number, '株式会社 巴川製紙所');
ok($zip->set_number('1048338')->is_valid_number, '兼松エレクトロニクス 株式会社');
ok($zip->set_number('1048340')->is_valid_number, '株式会社 ブリヂストン');
ok($zip->set_number('1048341')->is_valid_number, '大成有楽不動産 株式会社 東京マンション管理支店');
ok($zip->set_number('1048342')->is_valid_number, '大成有楽不動産 株式会社 東京ビル管理第一支店');
ok($zip->set_number('1048343')->is_valid_number, '大成有楽不動産 株式会社 東京ビル管理第二支店');
ok($zip->set_number('1048344')->is_valid_number, '大成有楽不動産 株式会社 東京支店');
ok($zip->set_number('1048345')->is_valid_number, '東洋紡 株式会社');
ok($zip->set_number('1048350')->is_valid_number, '株式会社 日立物流');
ok($zip->set_number('1048351')->is_valid_number, '前澤工業 株式会社');
ok($zip->set_number('1048356')->is_valid_number, '大日本住友製薬 株式会社');
ok($zip->set_number('1048357')->is_valid_number, '株式会社 主婦と生活社');
ok($zip->set_number('1048363')->is_valid_number, '監査法人 日本橋事務所');
ok($zip->set_number('1048365')->is_valid_number, '日本冶金工業 株式会社');
ok($zip->set_number('1048370')->is_valid_number, '清水建設 株式会社');
ok($zip->set_number('1048377')->is_valid_number, '東洋インキSCホールディングス 株式会社');
ok($zip->set_number('1048378')->is_valid_number, '東洋インキ 株式会社');
ok($zip->set_number('1048379')->is_valid_number, 'トーヨーケム 株式会社');
ok($zip->set_number('1048380')->is_valid_number, '株式会社 NIPPOコーポレーション');
ok($zip->set_number('1048381')->is_valid_number, 'トーヨーカラー 株式会社');
ok($zip->set_number('1048383')->is_valid_number, '大成ロテック 株式会社');
ok($zip->set_number('1048386')->is_valid_number, '日本農薬 株式会社');
ok($zip->set_number('1048388')->is_valid_number, '戸田建設 株式会社');
ok($zip->set_number('1048389')->is_valid_number, '神鋼商事 株式会社');
ok($zip->set_number('1048401')->is_valid_number, '日本管材センター 株式会社');
ok($zip->set_number('1048402')->is_valid_number, '株式会社 ニチレイ');
ok($zip->set_number('1048404')->is_valid_number, '東京都中央区役所');
ok($zip->set_number('1048405')->is_valid_number, '東京教区教務所');
ok($zip->set_number('1048406')->is_valid_number, '日通商事 株式会社');
ok($zip->set_number('1048407')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('1048408')->is_valid_number, '菱洋エレクトロ 株式会社');
ok($zip->set_number('1048413')->is_valid_number, '株式会社 旅行読売出版社');
ok($zip->set_number('1048415')->is_valid_number, '株式会社 東京ニュース 通信社');
ok($zip->set_number('1048416')->is_valid_number, 'トリンプ・インターナショナル・ジャパン 株式会社');
ok($zip->set_number('1048419')->is_valid_number, '全国情報サービス産業企業年金基金');
ok($zip->set_number('1048420')->is_valid_number, '株式会社 読売旅行');
ok($zip->set_number('1048421')->is_valid_number, 'オフィストウエンティワン 株式会社');
ok($zip->set_number('1048422')->is_valid_number, '松竹 株式会社');
ok($zip->set_number('1048423')->is_valid_number, '日本バイリーン 株式会社');
ok($zip->set_number('1048424')->is_valid_number, '日刊スポーツ出版社');
ok($zip->set_number('1048426')->is_valid_number, '株式会社 日本農業新聞');
ok($zip->set_number('1048429')->is_valid_number, '阪和興業 株式会社');
ok($zip->set_number('1048430')->is_valid_number, '住友生命保険 相互会社');
ok($zip->set_number('1048431')->is_valid_number, '株式会社 中村自工');
ok($zip->set_number('1048433')->is_valid_number, '株式会社 朝日学生新聞社');
ok($zip->set_number('1048435')->is_valid_number, '築地本願寺');
ok($zip->set_number('1048438')->is_valid_number, '東日本建設業保証 株式会社');
ok($zip->set_number('1048439')->is_valid_number, '三井造船 株式会社');
ok($zip->set_number('1048440')->is_valid_number, '株式会社 サンギ');
ok($zip->set_number('1048442')->is_valid_number, 'SMBCファイナンスサービス 株式会社');
ok($zip->set_number('1048443')->is_valid_number, '朝日ニュースター 株式会社 衛星チャンネル');
ok($zip->set_number('1048444')->is_valid_number, '日商エレクトロニクス 株式会社');
ok($zip->set_number('1048449')->is_valid_number, '東京国税局');
ok($zip->set_number('1048450')->is_valid_number, '商工組合中央金庫 本店');
ok($zip->set_number('1048455')->is_valid_number, 'キグナス石油 株式会社');
ok($zip->set_number('1048456')->is_valid_number, '株式会社 八重洲ブックセンター');
ok($zip->set_number('1048460')->is_valid_number, '国際興業 株式会社');
ok($zip->set_number('1048468')->is_valid_number, '大王製紙 株式会社');
ok($zip->set_number('1048481')->is_valid_number, 'みずほ証券 株式会社');
ok($zip->set_number('1048486')->is_valid_number, 'ヤンマー 株式会社 東京支社');
ok($zip->set_number('1048488')->is_valid_number, '株式会社 八重洲出版');
ok($zip->set_number('1048501')->is_valid_number, 'ライオンズクラブ東京合同事務局');
ok($zip->set_number('1048502')->is_valid_number, '丸善石油化学 株式会社');
ok($zip->set_number('1048505')->is_valid_number, '株式会社 日之出出版');
ok($zip->set_number('1048506')->is_valid_number, '三機工業 株式会社');
ok($zip->set_number('1048510')->is_valid_number, '株式会社 兼松KGK');
ok($zip->set_number('1048512')->is_valid_number, 'ユニデン 株式会社');
ok($zip->set_number('1048518')->is_valid_number, '太平洋セメント 株式会社');
ok($zip->set_number('1048521')->is_valid_number, '富士電機総設 株式会社');
ok($zip->set_number('1048523')->is_valid_number, '富士電機ITソリューション 株式会社');
ok($zip->set_number('1048526')->is_valid_number, '加賀電子 株式会社 EMS事業部');
ok($zip->set_number('1048527')->is_valid_number, '加賀電子 株式会社 特機事業部');
ok($zip->set_number('1048528')->is_valid_number, 'エンパイヤ自動車 株式会社');
ok($zip->set_number('1048530')->is_valid_number, 'ナラサキ産業 株式会社');
ok($zip->set_number('1048533')->is_valid_number, '月星商事 株式会社');
ok($zip->set_number('1048536')->is_valid_number, '株式会社 サッポロライオン');
ok($zip->set_number('1048538')->is_valid_number, '株式会社 サークルKサンクス');
ok($zip->set_number('1048539')->is_valid_number, '株式会社 共同紙販ホールディングス');
ok($zip->set_number('1048543')->is_valid_number, 'オリックス・システム 株式会社');
ok($zip->set_number('1048545')->is_valid_number, '株式会社 ワールド');
ok($zip->set_number('1048546')->is_valid_number, '三井住商建材 株式会社');
ok($zip->set_number('1048547')->is_valid_number, 'スミダコーポレーション 株式会社');
ok($zip->set_number('1048548')->is_valid_number, '住友商事マシネックス 株式会社');
ok($zip->set_number('1048550')->is_valid_number, '三菱製鋼 株式会社');
ok($zip->set_number('1048551')->is_valid_number, '江間忠合板 株式会社');
ok($zip->set_number('1048554')->is_valid_number, '平野通信機材 株式会社');
ok($zip->set_number('1048555')->is_valid_number, 'ニチアス 株式会社');
ok($zip->set_number('1048556')->is_valid_number, 'ニッセイ同和損害保険 株式会社');
ok($zip->set_number('1048558')->is_valid_number, '東京都中央都税事務所');
ok($zip->set_number('1048559')->is_valid_number, '日本酒類販売 株式会社');
ok($zip->set_number('1048560')->is_valid_number, '財団法人 聖路加国際病院');
ok($zip->set_number('1048566')->is_valid_number, 'うおがし銘茶 株式会社');
ok($zip->set_number('1048568')->is_valid_number, '株式会社 サントリー・ショッピング・クラブ');
ok($zip->set_number('1048580')->is_valid_number, 'キヤノンITソリューションズ 株式会社');
ok($zip->set_number('1048581')->is_valid_number, '一般財団法人 日本エネルギー経済研究所 石油情報センター');
ok($zip->set_number('1048584')->is_valid_number, '一般財団法人 電気技術者試験センター');
ok($zip->set_number('1048585')->is_valid_number, '中央区月島特別出張所 (月島区民センター)');
ok($zip->set_number('1048588')->is_valid_number, '大栄太源 株式会社');
ok($zip->set_number('1048614')->is_valid_number, 'ヤマトマテリアル 株式会社');
ok($zip->set_number('1048650')->is_valid_number, '株式会社 ディーエムエス');
ok($zip->set_number('1048656')->is_valid_number, '日本紙パルプ商事 株式会社');
ok($zip->set_number('1048661')->is_valid_number, '朝日新聞 東京支社(編集・出版・文化企画)');
ok($zip->set_number('1048665')->is_valid_number, '朝日新聞 東京支社(友の会・販売・広告)');
ok($zip->set_number('1048678')->is_valid_number, '東洋証券 株式会社');
ok($zip->set_number('1048680')->is_valid_number, '味の素 株式会社');
ok($zip->set_number('1048685')->is_valid_number, '株式会社 帝国データバンクビジネスサービス');
ok($zip->set_number('1056050')->is_valid_number, '株式会社 スター・チャンネル');
ok($zip->set_number('1056950')->is_valid_number, '伊藤忠テクノソリューションズ 株式会社');
ok($zip->set_number('1057050')->is_valid_number, '株式会社 電通グループ');
ok($zip->set_number('1057077')->is_valid_number, '株式会社 電通デジタル');
ok($zip->set_number('1057080')->is_valid_number, '株式会社 電通コーポレートワン');
ok($zip->set_number('1057365')->is_valid_number, '株式会社 ピーエス三菱 本社');
ok($zip->set_number('1057366')->is_valid_number, '株式会社 ピーエス三菱 東京土木支店');
ok($zip->set_number('1057367')->is_valid_number, '株式会社 ピーエス三菱 東京建築支店');
ok($zip->set_number('1057444')->is_valid_number, '日本テレビ放送網 株式会社');
ok($zip->set_number('1058001')->is_valid_number, '株式会社 東芝');
ok($zip->set_number('1058002')->is_valid_number, '株式会社 文化放送');
ok($zip->set_number('1058005')->is_valid_number, '兼松 株式会社');
ok($zip->set_number('1058008')->is_valid_number, '株式会社 ライトアップショッピングクラブ');
ok($zip->set_number('1058010')->is_valid_number, '独立行政法人 農業者年金基金');
ok($zip->set_number('1058039')->is_valid_number, '株式会社 日立国際電気');
ok($zip->set_number('1058055')->is_valid_number, '(株) 徳間書店');
ok($zip->set_number('1058070')->is_valid_number, '株式会社 扶桑社');
ok($zip->set_number('1058077')->is_valid_number, '独立行政法人 勤労者退職金共済機構');
ok($zip->set_number('1058085')->is_valid_number, '(株) カネボウ化粧品');
ok($zip->set_number('1058088')->is_valid_number, '企業年金連合会');
ok($zip->set_number('1058301')->is_valid_number, 'パナソニック 株式会社');
ok($zip->set_number('1058302')->is_valid_number, 'コスモエネルギーホールディングス 株式会社');
ok($zip->set_number('1058303')->is_valid_number, 'コスモ石油健康保険組合');
ok($zip->set_number('1058304')->is_valid_number, 'コスモビジネスアソシエイツ 株式会社');
ok($zip->set_number('1058305')->is_valid_number, 'TOTO 株式会社');
ok($zip->set_number('1058306')->is_valid_number, 'TOTO メンテナンス 株式会社');
ok($zip->set_number('1058307')->is_valid_number, 'TOTO アクアエンジ 株式会社');
ok($zip->set_number('1058308')->is_valid_number, '株式会社 日経BP');
ok($zip->set_number('1058310')->is_valid_number, '株式会社 資生堂');
ok($zip->set_number('1058311')->is_valid_number, 'トッパン・フォームズ 株式会社');
ok($zip->set_number('1058312')->is_valid_number, 'トッパン・フォームズ・オペレーション 株式会社');
ok($zip->set_number('1058313')->is_valid_number, 'テクノ・トッパン・フォームズ 株式会社');
ok($zip->set_number('1058314')->is_valid_number, 'コスモ石油マーケティング 株式会社');
ok($zip->set_number('1058315')->is_valid_number, '川崎重工業 株式会社');
ok($zip->set_number('1058317')->is_valid_number, 'ミネベアミツミ 株式会社');
ok($zip->set_number('1058318')->is_valid_number, '株式会社 広済堂ホールディングス');
ok($zip->set_number('1058319')->is_valid_number, 'センクシア 株式会社');
ok($zip->set_number('1058320')->is_valid_number, '株式会社 協和企画');
ok($zip->set_number('1058322')->is_valid_number, '日本通運 株式会社');
ok($zip->set_number('1058323')->is_valid_number, 'コスモエネルギー開発 株式会社');
ok($zip->set_number('1058325')->is_valid_number, 'コスモトレードアンドサービス 株式会社');
ok($zip->set_number('1058330')->is_valid_number, '株式会社 S&Sエンジニアリング');
ok($zip->set_number('1058331')->is_valid_number, 'コスモ石油ルブリカンツ 株式会社');
ok($zip->set_number('1058333')->is_valid_number, '株式会社 ロイヤルパーク汐留タワー');
ok($zip->set_number('1058335')->is_valid_number, '株式会社 JTBコミュニケーションデザイン');
ok($zip->set_number('1058338')->is_valid_number, 'NX商事 株式会社');
ok($zip->set_number('1058401')->is_valid_number, '西松建設 株式会社');
ok($zip->set_number('1058402')->is_valid_number, '東京都情報サービス産業健康保険組合');
ok($zip->set_number('1058403')->is_valid_number, 'アメリカンホーム医療・損害保険 株式会社(アメリカンホーム保険会社)');
ok($zip->set_number('1058407')->is_valid_number, '(株) ジャパンエナジー');
ok($zip->set_number('1058408')->is_valid_number, '日本技術貿易 株式会社');
ok($zip->set_number('1058410')->is_valid_number, '日立グローバルライフソリューションズ 株式会社');
ok($zip->set_number('1058411')->is_valid_number, '日精 株式会社');
ok($zip->set_number('1058412')->is_valid_number, '新日本石油 株式会社');
ok($zip->set_number('1058414')->is_valid_number, 'ローレルバンクマシン (株)');
ok($zip->set_number('1058415')->is_valid_number, '株式会社 ソニー・ピクチャーズエンタテインメント');
ok($zip->set_number('1058416')->is_valid_number, '株式会社 ホテルオークラ');
ok($zip->set_number('1058417')->is_valid_number, 'JX金属 株式会社');
ok($zip->set_number('1058418')->is_valid_number, 'パンパシフィック・カッパー 株式会社');
ok($zip->set_number('1058419')->is_valid_number, '東亞合成 株式会社');
ok($zip->set_number('1058420')->is_valid_number, '都築エンベデッドソリューションズ 株式会社');
ok($zip->set_number('1058423')->is_valid_number, '青和特許法律事務所');
ok($zip->set_number('1058424')->is_valid_number, 'シリリュス・サービスセンター');
ok($zip->set_number('1058427')->is_valid_number, '三井農林 株式会社');
ok($zip->set_number('1058428')->is_valid_number, 'キッコーマン 株式会社');
ok($zip->set_number('1058429')->is_valid_number, '株式会社 トクヤマ');
ok($zip->set_number('1058431')->is_valid_number, '気象庁');
ok($zip->set_number('1058433')->is_valid_number, 'PHC 株式会社');
ok($zip->set_number('1058433')->is_valid_number, 'PHCホールディングス 株式会社');
ok($zip->set_number('1058434')->is_valid_number, '独立行政法人 鉄道建設・運輸施設整備支援機構 国鉄精算事業本部');
ok($zip->set_number('1058435')->is_valid_number, '北海道新聞 東京支社');
ok($zip->set_number('1058436')->is_valid_number, '株式会社 日本教育新聞社');
ok($zip->set_number('1058437')->is_valid_number, '美浜 株式会社');
ok($zip->set_number('1058440')->is_valid_number, '東京実業健康保険組合 城南支部');
ok($zip->set_number('1058441')->is_valid_number, '財団法人 ゆうちょ財団');
ok($zip->set_number('1058444')->is_valid_number, '一般社団法人 建設技能人材機構,JAC');
ok($zip->set_number('1058445')->is_valid_number, '独立行政法人 国立印刷局');
ok($zip->set_number('1058446')->is_valid_number, '一般財団法人 長寿社会開発センター');
ok($zip->set_number('1058447')->is_valid_number, '高圧ガス保安協会');
ok($zip->set_number('1058448')->is_valid_number, '株式会社 永谷園');
ok($zip->set_number('1058448')->is_valid_number, '株式会社 永谷園ホールディングス');
ok($zip->set_number('1058449')->is_valid_number, 'UBE 株式会社');
ok($zip->set_number('1058451')->is_valid_number, '森村商事 株式会社');
ok($zip->set_number('1058452')->is_valid_number, 'クオール 株式会社');
ok($zip->set_number('1058453')->is_valid_number, '独立行政法人 中小企業基盤整備機構');
ok($zip->set_number('1058456')->is_valid_number, '日本ポラロイド (株)');
ok($zip->set_number('1058457')->is_valid_number, '日本デスコ 株式会社');
ok($zip->set_number('1058458')->is_valid_number, '岩谷産業 株式会社');
ok($zip->set_number('1058460')->is_valid_number, '沖電気工業 株式会社');
ok($zip->set_number('1058461')->is_valid_number, '学校法人 慈恵大学');
ok($zip->set_number('1058464')->is_valid_number, '三井住友ファイナンス&リース 株式会社');
ok($zip->set_number('1058465')->is_valid_number, '競馬セキュリティサービス 株式会社');
ok($zip->set_number('1058466')->is_valid_number, '三井食品 株式会社');
ok($zip->set_number('1058467')->is_valid_number, '日本国土開発 株式会社');
ok($zip->set_number('1058468')->is_valid_number, '株式会社 グルメ杵屋 東京支社');
ok($zip->set_number('1058469')->is_valid_number, 'セイコークロック 株式会社');
ok($zip->set_number('1058470')->is_valid_number, '国家公務員 共済組合連合会 虎の門病院');
ok($zip->set_number('1058471')->is_valid_number, '東京慈恵会医科大学附属病院');
ok($zip->set_number('1058472')->is_valid_number, '財団法人 家電製品協会');
ok($zip->set_number('1058475')->is_valid_number, '株式会社 公募ガイド社');
ok($zip->set_number('1058477')->is_valid_number, 'デンカアステック 株式会社');
ok($zip->set_number('1058482')->is_valid_number, 'コロムビアミュージックエンタテインメント 株式会社');
ok($zip->set_number('1058483')->is_valid_number, 'カンタスエアーウエイズリミテッド');
ok($zip->set_number('1058484')->is_valid_number, 'マグレガーゴルフジャパン 株式会社');
ok($zip->set_number('1058485')->is_valid_number, '一般財団法人 日本不動産研究所');
ok($zip->set_number('1058486')->is_valid_number, '独立行政法人 福祉医療機構');
ok($zip->set_number('1058501')->is_valid_number, '三菱UFJリサーチ&コンサルティング 株式会社');
ok($zip->set_number('1058502')->is_valid_number, '株式会社 ノリタケカンパニーリミテド');
ok($zip->set_number('1058503')->is_valid_number, 'リコージャパン 株式会社');
ok($zip->set_number('1058505')->is_valid_number, '株式会社 テイチクエンタテインメント');
ok($zip->set_number('1058507')->is_valid_number, '株式会社 長谷工コーポレーション &(株)長谷工アーベストを除くグループ会社');
ok($zip->set_number('1058508')->is_valid_number, '日本タタ・コンサルタンシー・サービシズ 株式会社');
ok($zip->set_number('1058509')->is_valid_number, '世紀東急工業 株式会社');
ok($zip->set_number('1058510')->is_valid_number, '美和ロック 株式会社');
ok($zip->set_number('1058511')->is_valid_number, '東京都港区役所');
ok($zip->set_number('1058512')->is_valid_number, '慶應義塾大学 薬学部');
ok($zip->set_number('1058515')->is_valid_number, '高千穂電気 株式会社');
ok($zip->set_number('1058516')->is_valid_number, '港区芝浦港南地区 総合支所');
ok($zip->set_number('1058518')->is_valid_number, '昭和電工 株式会社');
ok($zip->set_number('1058521')->is_valid_number, '日本赤十字社');
ok($zip->set_number('1058522')->is_valid_number, '一般社団法人 日本能率協会');
ok($zip->set_number('1058523')->is_valid_number, '全日産・一般業種 労働組合連合会(略称:日産労連)');
ok($zip->set_number('1058524')->is_valid_number, '公益財団法人 笹川平和財団');
ok($zip->set_number('1058525')->is_valid_number, 'シナネン 株式会社');
ok($zip->set_number('1058527')->is_valid_number, '東京ガス 株式会社');
ok($zip->set_number('1058528')->is_valid_number, 'コスモ石油 株式会社');
ok($zip->set_number('1058529')->is_valid_number, 'オックスフォード大学出版局 株式会社');
ok($zip->set_number('1058530')->is_valid_number, '社団法人 日本自動車販売協会連合会');
ok($zip->set_number('1058534')->is_valid_number, '株式会社 日本能率協会コンサルティング');
ok($zip->set_number('1058535')->is_valid_number, 'エヌ・ティ・ティ・コミュニケーションズ 株式会社');
ok($zip->set_number('1058537')->is_valid_number, 'エア・ウォーター・マテリアル 株式会社');
ok($zip->set_number('1058540')->is_valid_number, '日本電気 株式会社 セレスティンビル');
ok($zip->set_number('1058543')->is_valid_number, '株式会社 朝日工業社');
ok($zip->set_number('1058544')->is_valid_number, '曹洞宗 宗務庁');
ok($zip->set_number('1058545')->is_valid_number, '株式会社 長谷工アーベスト');
ok($zip->set_number('1058546')->is_valid_number, 'MAアルミニウム 株式会社');
ok($zip->set_number('1058550')->is_valid_number, '礎会館(東京電力労働組合)');
ok($zip->set_number('1058551')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('1058553')->is_valid_number, 'ポケットカード 株式会社');
ok($zip->set_number('1058554')->is_valid_number, 'スカイマークエアラインズ 株式会社');
ok($zip->set_number('1058555')->is_valid_number, 'ニチアス 株式会社');
ok($zip->set_number('1058556')->is_valid_number, '大島椿 株式会社');
ok($zip->set_number('1058557')->is_valid_number, '株式会社 アドピア');
ok($zip->set_number('1058558')->is_valid_number, '東京計装 株式会社');
ok($zip->set_number('1058560')->is_valid_number, '東京プリンスホテル');
ok($zip->set_number('1058563')->is_valid_number, 'ザ・プリンス パークタワー東京');
ok($zip->set_number('1058565')->is_valid_number, '株式会社 日経ラジオ社');
ok($zip->set_number('1058567')->is_valid_number, '日昭産業 株式会社');
ok($zip->set_number('1058568')->is_valid_number, 'YKアクロス 株式会社');
ok($zip->set_number('1058574')->is_valid_number, '三井住友信託銀行 株式会社');
ok($zip->set_number('1058575')->is_valid_number, '株式会社 ヤナセ');
ok($zip->set_number('1058576')->is_valid_number, '株式会社 ホスピタリティ・ネットワーク');
ok($zip->set_number('1058577')->is_valid_number, 'UCC上島珈琲 株式会社 東京本部');
ok($zip->set_number('1058578')->is_valid_number, '日本ビジネスシステムズ (株)');
ok($zip->set_number('1058579')->is_valid_number, '日本マスタートラスト信託銀行 株式会社');
ok($zip->set_number('1058580')->is_valid_number, '株式会社 バンザイ');
ok($zip->set_number('1058581')->is_valid_number, 'パナソニック 株式会社 東京パナソニックビル1号館');
ok($zip->set_number('1058582')->is_valid_number, 'メルパルク TOKYO');
ok($zip->set_number('1058583')->is_valid_number, '株式会社 オレンジページ');
ok($zip->set_number('1058584')->is_valid_number, 'オイレス工業 株式会社');
ok($zip->set_number('1058585')->is_valid_number, 'NOK 株式会社');
ok($zip->set_number('1058587')->is_valid_number, 'イーグル工業 株式会社');
ok($zip->set_number('1058588')->is_valid_number, '協栄電気 株式会社');
ok($zip->set_number('1058589')->is_valid_number, 'オリックス自動車 (株)');
ok($zip->set_number('1058603')->is_valid_number, '株式会社 紀文産業');
ok($zip->set_number('1058604')->is_valid_number, '共栄火災海上保険 株式会社');
ok($zip->set_number('1058606')->is_valid_number, '株式会社 日本旅行');
ok($zip->set_number('1058608')->is_valid_number, '有限会社 つきプランニング');
ok($zip->set_number('1058610')->is_valid_number, '大東京信用組合');
ok($zip->set_number('1058611')->is_valid_number, '株式会社 モーターマガジン社');
ok($zip->set_number('1058613')->is_valid_number, '株式会社 電通イースリー');
ok($zip->set_number('1058614')->is_valid_number, '日立金属 株式会社');
ok($zip->set_number('1058615')->is_valid_number, '片岡物産 株式会社');
ok($zip->set_number('1058620')->is_valid_number, '資生堂ジャパン 株式会社');
ok($zip->set_number('1058621')->is_valid_number, '第一ホテル東京');
ok($zip->set_number('1058623')->is_valid_number, '東ソー 株式会社');
ok($zip->set_number('1058623')->is_valid_number, '日本ミラクトラン 株式会社 東京営業所');
ok($zip->set_number('1058625')->is_valid_number, 'SMBCファイナンスサービス 株式会社 決済ビジネス業務センター');
ok($zip->set_number('1058626')->is_valid_number, '株式会社 紀文食品');
ok($zip->set_number('1058627')->is_valid_number, 'SMBCファイナンスサービス 株式会社 東京事務センター');
ok($zip->set_number('1058630')->is_valid_number, '古河産業 株式会社');
ok($zip->set_number('1058634')->is_valid_number, '株式会社 SUMCO');
ok($zip->set_number('1058640')->is_valid_number, 'JSR 株式会社');
ok($zip->set_number('1058641')->is_valid_number, '住友大阪セメント 株式会社');
ok($zip->set_number('1058642')->is_valid_number, '株式会社 コシダテック');
ok($zip->set_number('1058644')->is_valid_number, 'BS日テレ');
ok($zip->set_number('1058654')->is_valid_number, 'NTTファイナンス 株式会社');
ok($zip->set_number('1058656')->is_valid_number, '株式会社 大広WEDO');
ok($zip->set_number('1058658')->is_valid_number, '株式会社 大広');
ok($zip->set_number('1058660')->is_valid_number, '株式会社 ヤクルト本社');
ok($zip->set_number('1058665')->is_valid_number, '都築電気 株式会社');
ok($zip->set_number('1058666')->is_valid_number, '一般社団法人 日本港運協会');
ok($zip->set_number('1058668')->is_valid_number, '富士通エフ・アイ・ピー 株式会社 アクティブオフィス');
ok($zip->set_number('1058670')->is_valid_number, '株式会社 ゴルフダイジェスト社');
ok($zip->set_number('1058672')->is_valid_number, '株式会社 阪急交通社');
ok($zip->set_number('1058676')->is_valid_number, '株式会社 ニッスイ');
ok($zip->set_number('1058677')->is_valid_number, 'FDK 株式会社');
ok($zip->set_number('1058678')->is_valid_number, '(株) 東京商工リサーチ');
ok($zip->set_number('1058680')->is_valid_number, '株式会社 アシェット 婦人画報社');
ok($zip->set_number('1058681')->is_valid_number, '日本軽金属グループ');
ok($zip->set_number('1058685')->is_valid_number, '横浜ゴム 株式会社');
ok($zip->set_number('1058686')->is_valid_number, '八洲電機 株式会社');
ok($zip->set_number('1058689')->is_valid_number, '商工組合中央金庫 東京支店');
ok($zip->set_number('1058701')->is_valid_number, '企業年金連合会');
ok($zip->set_number('1058702')->is_valid_number, '企業年金連合会');
ok($zip->set_number('1058707')->is_valid_number, '株式会社 興伸アクトサービス');
ok($zip->set_number('1058712')->is_valid_number, '三菱HCキャピタル 株式会社');
ok($zip->set_number('1058716')->is_valid_number, '住友金属鉱山 株式会社');
ok($zip->set_number('1058717')->is_valid_number, '株式会社 日立ハイテクノロジーズ');
ok($zip->set_number('1058788')->is_valid_number, '日本郵政 株式会社 首都圏施設センター');
ok($zip->set_number('1066060')->is_valid_number, '株式会社 アーキテクト');
ok($zip->set_number('1066066')->is_valid_number, '株式会社 クラップ&ウォーク');
ok($zip->set_number('1066161')->is_valid_number, '株式会社 サイバード');
ok($zip->set_number('1066188')->is_valid_number, '株式会社 エフエムジャパン');
ok($zip->set_number('1068001')->is_valid_number, '株式会社 テレビ朝日');
ok($zip->set_number('1068007')->is_valid_number, '株式会社 テレビ東京・株式会社 テレビ東京ホールディングス');
ok($zip->set_number('1068011')->is_valid_number, '株式会社 スペースシャワーネットワーク');
ok($zip->set_number('1068039')->is_valid_number, '株式会社 アール・エフラジオ日本');
ok($zip->set_number('1068107')->is_valid_number, '株式会社 BSジャパン');
ok($zip->set_number('1068401')->is_valid_number, '日本中央競馬会 六本木事務所');
ok($zip->set_number('1068487')->is_valid_number, '株式会社 ポニーキャニオン');
ok($zip->set_number('1068507')->is_valid_number, '学校法人 東洋英和女学院');
ok($zip->set_number('1068508')->is_valid_number, '日本ルーセントテクノロジー 株式会社');
ok($zip->set_number('1068514')->is_valid_number, 'フランス大使館');
ok($zip->set_number('1068515')->is_valid_number, '港区麻布支所');
ok($zip->set_number('1068518')->is_valid_number, '株式会社 内原');
ok($zip->set_number('1068521')->is_valid_number, '株式会社 ほうらいやビル');
ok($zip->set_number('1068522')->is_valid_number, '株式会社 WDI');
ok($zip->set_number('1068531')->is_valid_number, '株式会社 エムオン・エンタテインメント');
ok($zip->set_number('1068531')->is_valid_number, '株式会社 kiraramedia');
ok($zip->set_number('1068537')->is_valid_number, 'フィリピン共和国大使館');
ok($zip->set_number('1068541')->is_valid_number, 'ハリウッド美容専門学校');
ok($zip->set_number('1068544')->is_valid_number, '株式会社 フリップサイド');
ok($zip->set_number('1068545')->is_valid_number, '全日本海員組合');
ok($zip->set_number('1068550')->is_valid_number, '東芝シリコーン 株式会社');
ok($zip->set_number('1068551')->is_valid_number, '東通産業 株式会社');
ok($zip->set_number('1068552')->is_valid_number, '株式会社 テレビ朝日ミュージック');
ok($zip->set_number('1068555')->is_valid_number, '日本学術会議');
ok($zip->set_number('1068556')->is_valid_number, '株式会社 シーボン');
ok($zip->set_number('1068558')->is_valid_number, '独立行政法人 国立美術館 国立新美術館');
ok($zip->set_number('1068559')->is_valid_number, 'MTV JAPAN');
ok($zip->set_number('1068560')->is_valid_number, '東京都港都税事務所');
ok($zip->set_number('1068561')->is_valid_number, '駐日フィンランド大使館');
ok($zip->set_number('1068562')->is_valid_number, '株式会社 エル');
ok($zip->set_number('1068563')->is_valid_number, '社団法人 東亜科学技術協力協会');
ok($zip->set_number('1068565')->is_valid_number, 'コロムビアミュージックエンタテインメント 株式会社');
ok($zip->set_number('1068566')->is_valid_number, 'エヌ・ティ・ティ ラーニングシステムズ 株式会社');
ok($zip->set_number('1068567')->is_valid_number, '株式会社 佐藤渡辺');
ok($zip->set_number('1068569')->is_valid_number, '統計数理研究所');
ok($zip->set_number('1068571')->is_valid_number, '株式会社 ディーエイチシー');
ok($zip->set_number('1068573')->is_valid_number, '日本モトローラ 株式会社');
ok($zip->set_number('1068575')->is_valid_number, '東京都立中央図書館');
ok($zip->set_number('1068576')->is_valid_number, 'マサモト 株式会社');
ok($zip->set_number('1068577')->is_valid_number, '駐日大韓民国大使館');
ok($zip->set_number('1068578')->is_valid_number, '象印マホービン 株式会社');
ok($zip->set_number('1068580')->is_valid_number, '恩賜財団 母子愛育会');
ok($zip->set_number('1068581')->is_valid_number, '医療法人財団 厚生会');
ok($zip->set_number('1068585')->is_valid_number, '在日本大韓民国民団 中央本部');
ok($zip->set_number('1068587')->is_valid_number, '株式会社 日比谷花壇');
ok($zip->set_number('1068588')->is_valid_number, '株式会社 一徳商会');
ok($zip->set_number('1068589')->is_valid_number, 'スイス大使館');
ok($zip->set_number('1068601')->is_valid_number, '日本シャクリー 株式会社');
ok($zip->set_number('1068608')->is_valid_number, '財団法人 書海社');
ok($zip->set_number('1068611')->is_valid_number, '株式会社 ユース・プランニングセンター');
ok($zip->set_number('1068616')->is_valid_number, '日本タッパーウェア 株式会社');
ok($zip->set_number('1068620')->is_valid_number, '富士フイルム 株式会社');
ok($zip->set_number('1068622')->is_valid_number, 'SBIマーケティング 株式会社');
ok($zip->set_number('1068625')->is_valid_number, '財団法人 日本オペラ振興会');
ok($zip->set_number('1068626')->is_valid_number, '株式会社 ファンキー・ジャム');
ok($zip->set_number('1068630')->is_valid_number, '麻布税務署');
ok($zip->set_number('1068635')->is_valid_number, '独立行政法人 農畜産業振興機構');
ok($zip->set_number('1068636')->is_valid_number, '株式会社 商業界');
ok($zip->set_number('1068639')->is_valid_number, '地方競馬全国協会');
ok($zip->set_number('1068640')->is_valid_number, '株式会社 ケンコーポレーション');
ok($zip->set_number('1068641')->is_valid_number, '株式会社 マツイ');
ok($zip->set_number('1068642')->is_valid_number, 'NTTビジュアル通信 株式会社');
ok($zip->set_number('1068644')->is_valid_number, '霊友会');
ok($zip->set_number('1068648')->is_valid_number, 'ピーネット通信 株式会社');
ok($zip->set_number('1068649')->is_valid_number, '社団法人 東京アメリカンクラブ');
ok($zip->set_number('1068652')->is_valid_number, 'トヨタモビリティパーツ 株式会社 東京・山梨統括支社');
ok($zip->set_number('1068655')->is_valid_number, '株式会社 東機貿');
ok($zip->set_number('1068665')->is_valid_number, '有限会社 エリカインターナショナル');
ok($zip->set_number('1068668')->is_valid_number, 'チューブ・ライダース');
ok($zip->set_number('1068677')->is_valid_number, '政策研究大学院大学');
ok($zip->set_number('1068797')->is_valid_number, '株式会社 かんぽ生命 麻布支店');
ok($zip->set_number('1078001')->is_valid_number, '株式会社 TBSラジオ');
ok($zip->set_number('1078006')->is_valid_number, '株式会社 TBSテレビ');
ok($zip->set_number('1078010')->is_valid_number, 'きらぼしライフデザイン証券 株式会社');
ok($zip->set_number('1078060')->is_valid_number, '医療法人財団 順和会 山王病院');
ok($zip->set_number('1078077')->is_valid_number, '伊藤忠商事 株式会社');
ok($zip->set_number('1078320')->is_valid_number, 'トーヨーマテリア 株式会社');
ok($zip->set_number('1078323')->is_valid_number, 'コナミ 株式会社');
ok($zip->set_number('1078324')->is_valid_number, '株式会社 コナミデジタルエンタテインメント');
ok($zip->set_number('1078326')->is_valid_number, 'コナミリアルエステート 株式会社');
ok($zip->set_number('1078330')->is_valid_number, '株式会社 東通');
ok($zip->set_number('1078332')->is_valid_number, '医療法人財団 順和会 山王メディカルセンター');
ok($zip->set_number('1078336')->is_valid_number, '株式会社 グッデイ');
ok($zip->set_number('1078340')->is_valid_number, 'ファミリー劇場');
ok($zip->set_number('1078342')->is_valid_number, '株式会社 インターネットレボリューション');
ok($zip->set_number('1078348')->is_valid_number, '鹿島建設 株式会社 赤坂別館');
ok($zip->set_number('1078349')->is_valid_number, '株式会社 オークネット');
ok($zip->set_number('1078351')->is_valid_number, '株式会社 パソナグループ');
ok($zip->set_number('1078352')->is_valid_number, '株式会社 パソナ');
ok($zip->set_number('1078355')->is_valid_number, '株式会社 ソーゴー東京');
ok($zip->set_number('1078360')->is_valid_number, '株式会社 ホンダトレーディング');
ok($zip->set_number('1078370')->is_valid_number, '(株) ビー・エス・ジェイ・ラジオ');
ok($zip->set_number('1078371')->is_valid_number, '学校法人 山脇学園');
ok($zip->set_number('1078373')->is_valid_number, '株式会社 日経ラジオ社');
ok($zip->set_number('1078380')->is_valid_number, '株式会社 日音');
ok($zip->set_number('1078384')->is_valid_number, '株式会社 ジュン');
ok($zip->set_number('1078388')->is_valid_number, '鹿島建設 株式会社 本社');
ok($zip->set_number('1078401')->is_valid_number, '株式会社 虎屋');
ok($zip->set_number('1078402')->is_valid_number, '国際医療福祉大学 東京赤坂キャンパス');
ok($zip->set_number('1078403')->is_valid_number, 'サントリー 株式会社 サントリーホール');
ok($zip->set_number('1078404')->is_valid_number, '日本財団');
ok($zip->set_number('1078410')->is_valid_number, '株式会社 山と渓谷社');
ok($zip->set_number('1078411')->is_valid_number, '事業構想大学院大学');
ok($zip->set_number('1078412')->is_valid_number, '株式会社 グローバルユースビューロー');
ok($zip->set_number('1078414')->is_valid_number, '株式会社 小松製作所');
ok($zip->set_number('1078416')->is_valid_number, '一般財団法人 日本建設情報総合センター');
ok($zip->set_number('1078417')->is_valid_number, '株式会社 東急エージェンシー');
ok($zip->set_number('1078418')->is_valid_number, '事業構想大学院大学');
ok($zip->set_number('1078419')->is_valid_number, '全国卸商業団地厚生年金基金');
ok($zip->set_number('1078420')->is_valid_number, '米国大使館');
ok($zip->set_number('1078434')->is_valid_number, 'ANAインターコンチネンタルホテル東京');
ok($zip->set_number('1078440')->is_valid_number, '財団法人 日本規格協会');
ok($zip->set_number('1078448')->is_valid_number, '株式会社 松田平田設計');
ok($zip->set_number('1078450')->is_valid_number, '伊藤忠食品 株式会社');
ok($zip->set_number('1078456')->is_valid_number, '日本カルミック 株式会社');
ok($zip->set_number('1078460')->is_valid_number, '株式会社 東北新社');
ok($zip->set_number('1078463')->is_valid_number, '株式会社 アイビー化粧品');
ok($zip->set_number('1078468')->is_valid_number, '住友電気工業 株式会社');
ok($zip->set_number('1078471')->is_valid_number, '株式会社 TBSビジョン');
ok($zip->set_number('1078477')->is_valid_number, '鹿島建設 株式会社 東京支店');
ok($zip->set_number('1078482')->is_valid_number, '株式会社 TBSサービス');
ok($zip->set_number('1078484')->is_valid_number, '八洲貿易 株式会社');
ok($zip->set_number('1078502')->is_valid_number, '鹿島建設 株式会社 KIビル');
ok($zip->set_number('1078505')->is_valid_number, '財団法人 草月会');
ok($zip->set_number('1078507')->is_valid_number, '明治記念館');
ok($zip->set_number('1078508')->is_valid_number, 'タカタ 株式会社');
ok($zip->set_number('1078511')->is_valid_number, '綜合警備保障 株式会社');
ok($zip->set_number('1078514')->is_valid_number, '株式会社 大本組');
ok($zip->set_number('1078520')->is_valid_number, '株式会社 アメリア・ネットワーク');
ok($zip->set_number('1078521')->is_valid_number, '株式会社 ツムラ');
ok($zip->set_number('1078527')->is_valid_number, '日鉄物産 株式会社');
ok($zip->set_number('1078528')->is_valid_number, 'ザ・シネマ');
ok($zip->set_number('1078532')->is_valid_number, '商船三井客船 株式会社');
ok($zip->set_number('1078545')->is_valid_number, '中央物産 株式会社');
ok($zip->set_number('1078546')->is_valid_number, 'ハーバライフ・オブ・ジャパン 株式会社');
ok($zip->set_number('1078550')->is_valid_number, '株式会社 宣伝会議 本社');
ok($zip->set_number('1078552')->is_valid_number, '株式会社 アクシヴ');
ok($zip->set_number('1078556')->is_valid_number, '本田技研工業 株式会社');
ok($zip->set_number('1078558')->is_valid_number, '健康保険組合連合会');
ok($zip->set_number('1078560')->is_valid_number, '第一法規出版 株式会社');
ok($zip->set_number('1078563')->is_valid_number, '株式会社 キネマ旬報社');
ok($zip->set_number('1078567')->is_valid_number, '株式会社 朝日データサービス');
ok($zip->set_number('1078572')->is_valid_number, '株式会社 青二プロダクション');
ok($zip->set_number('1078581')->is_valid_number, '(株) プレアデスセンター');
ok($zip->set_number('1078601')->is_valid_number, '株式会社 NHK文化センター');
ok($zip->set_number('1078615')->is_valid_number, '株式会社 ホギメディカル');
ok($zip->set_number('1078616')->is_valid_number, 'ニッカウイスキー 株式会社');
ok($zip->set_number('1078617')->is_valid_number, '株式会社 フルハウス');
ok($zip->set_number('1078619')->is_valid_number, '株式会社 アイプラネット');
ok($zip->set_number('1078620')->is_valid_number, '株式会社 ワールド');
ok($zip->set_number('1078623')->is_valid_number, '株式会社 鎌倉製作所');
ok($zip->set_number('1078625')->is_valid_number, '株式会社 ハウスオブローゼ');
ok($zip->set_number('1078627')->is_valid_number, '株式会社 スーパーネットワーク');
ok($zip->set_number('1078630')->is_valid_number, '株式会社 クレヨンハウス');
ok($zip->set_number('1078631')->is_valid_number, 'サントリー 株式会社');
ok($zip->set_number('1078632')->is_valid_number, 'サントリーフーズ 株式会社');
ok($zip->set_number('1078633')->is_valid_number, 'ブラジル大使館');
ok($zip->set_number('1078636')->is_valid_number, '東海カーボン 株式会社');
ok($zip->set_number('1078638')->is_valid_number, 'かたばみ興業 株式会社');
ok($zip->set_number('1078639')->is_valid_number, '株式会社 ワーナーミュージック・ジャパン');
ok($zip->set_number('1078650')->is_valid_number, '三菱UFJ信託銀行');
ok($zip->set_number('1078666')->is_valid_number, '株式会社 アイ・アールジャパン');
ok($zip->set_number('1078674')->is_valid_number, '株式会社 日本教文社');
ok($zip->set_number('1078676')->is_valid_number, '株式会社 興伸');
ok($zip->set_number('1078680')->is_valid_number, '帝国データバンク');
ok($zip->set_number('1078686')->is_valid_number, '株式会社 ジェーシービー 青山本社');
ok($zip->set_number('1078688')->is_valid_number, 'UCC上島珈琲 株式会社');
ok($zip->set_number('1078797')->is_valid_number, '日本郵便 株式会社 東京支社');
ok($zip->set_number('1086350')->is_valid_number, 'SMBCファイナンスサービス 株式会社');
ok($zip->set_number('1086363')->is_valid_number, 'SMBC電子債権記録 株式会社');
ok($zip->set_number('1088001')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088005')->is_valid_number, 'ENEOS 株式会社');
ok($zip->set_number('1088011')->is_valid_number, 'キヤノンマーケティングジャパン 株式会社');
ok($zip->set_number('1088020')->is_valid_number, 'アクサ生命保険 株式会社');
ok($zip->set_number('1088050')->is_valid_number, 'サクサ 株式会社');
ok($zip->set_number('1088071')->is_valid_number, '株式会社 ジャパンタイムズ');
ok($zip->set_number('1088080')->is_valid_number, 'クラシエホールディングス 株式会社');
ok($zip->set_number('1088117')->is_valid_number, '株式会社 セディナ');
ok($zip->set_number('1088118')->is_valid_number, 'エヌ・ティ・ティ・コミュニケーションズ 株式会社');
ok($zip->set_number('1088201')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('1088202')->is_valid_number, 'NTTテクノクロス 株式会社');
ok($zip->set_number('1088203')->is_valid_number, '外国人技能実習機構 東京事務所');
ok($zip->set_number('1088206')->is_valid_number, '公益財団法人 JKA');
ok($zip->set_number('1088207')->is_valid_number, '株式会社 富士通マーケティング');
ok($zip->set_number('1088208')->is_valid_number, '豊田通商 株式会社');
ok($zip->set_number('1088209')->is_valid_number, '株式会社 JALUX');
ok($zip->set_number('1088210')->is_valid_number, '株式会社 ソラスト');
ok($zip->set_number('1088211')->is_valid_number, '大東建託 株式会社');
ok($zip->set_number('1088212')->is_valid_number, 'FDK 株式会社');
ok($zip->set_number('1088215')->is_valid_number, '三菱重工業 株式会社');
ok($zip->set_number('1088216')->is_valid_number, '豊通ケミプラス 株式会社');
ok($zip->set_number('1088217')->is_valid_number, '株式会社 山善');
ok($zip->set_number('1088220')->is_valid_number, '株式会社 丹青社');
ok($zip->set_number('1088221')->is_valid_number, '株式会社 富士通パーソナルズ');
ok($zip->set_number('1088222')->is_valid_number, '椿本興業 (株) 東京本社');
ok($zip->set_number('1088224')->is_valid_number, '日立金属 株式会社');
ok($zip->set_number('1088225')->is_valid_number, 'キヤノンシステムアンドサポート 株式会社');
ok($zip->set_number('1088230')->is_valid_number, '株式会社 ダイセル');
ok($zip->set_number('1088231')->is_valid_number, 'ダイセルミライズ 株式会社');
ok($zip->set_number('1088232')->is_valid_number, 'ダイセルバリューコーティング (株)');
ok($zip->set_number('1088233')->is_valid_number, 'ダイセル物流 株式会社');
ok($zip->set_number('1088234')->is_valid_number, '共栄殖産 (株) 東京営業所');
ok($zip->set_number('1088240')->is_valid_number, '日本サムスン 株式会社');
ok($zip->set_number('1088241')->is_valid_number, '大塚ホールディングス 株式会社');
ok($zip->set_number('1088242')->is_valid_number, '大塚製薬 株式会社');
ok($zip->set_number('1088243')->is_valid_number, '日本特殊陶業 株式会社 東京支社');
ok($zip->set_number('1088248')->is_valid_number, 'マクセル 株式会社');
ok($zip->set_number('1088250')->is_valid_number, '株式会社 日立製作所 情報・通信システム社');
ok($zip->set_number('1088255')->is_valid_number, '東京入国管理局');
ok($zip->set_number('1088270')->is_valid_number, '株式会社 ソニー・コンピュータエンタテインメント');
ok($zip->set_number('1088275')->is_valid_number, '日本トーター 株式会社');
ok($zip->set_number('1088276')->is_valid_number, '法務省 入国管理局 登録課分室');
ok($zip->set_number('1088280')->is_valid_number, 'ポリプラスチックス 株式会社');
ok($zip->set_number('1088282')->is_valid_number, 'ストリングスホテル東京インターコンチネンタル');
ok($zip->set_number('1088288')->is_valid_number, '日本システム技術 株式会社');
ok($zip->set_number('1088301')->is_valid_number, '株式会社 アイスター商事');
ok($zip->set_number('1088303')->is_valid_number, '住友電設 株式会社');
ok($zip->set_number('1088305')->is_valid_number, '株式会社 NECライベックス');
ok($zip->set_number('1088307')->is_valid_number, 'フジテック 株式会社 東京本社');
ok($zip->set_number('1088308')->is_valid_number, '株式会社 朝日旅行');
ok($zip->set_number('1088310')->is_valid_number, '株式会社 バンダイナムコアミューズメント');
ok($zip->set_number('1088313')->is_valid_number, '株式会社 一点');
ok($zip->set_number('1088315')->is_valid_number, '港区 みなと保健所');
ok($zip->set_number('1088316')->is_valid_number, '京セラ 株式会社 東京事業所');
ok($zip->set_number('1088322')->is_valid_number, '双信電機 株式会社');
ok($zip->set_number('1088325')->is_valid_number, '株式会社 新進商会');
ok($zip->set_number('1088326')->is_valid_number, '全日本電機電子情報関連産業 労働組合連合会');
ok($zip->set_number('1088328')->is_valid_number, '株式会社 ゼネシス 東京支店');
ok($zip->set_number('1088329')->is_valid_number, '国際医療福祉大学附属三田病院');
ok($zip->set_number('1088333')->is_valid_number, '矢崎総業 株式会社');
ok($zip->set_number('1088334')->is_valid_number, '立川ブラインド工業 株式会社');
ok($zip->set_number('1088341')->is_valid_number, '福西電機 株式会社');
ok($zip->set_number('1088345')->is_valid_number, '慶應義塾');
ok($zip->set_number('1088350')->is_valid_number, '株式会社 サニクリーン 本部');
ok($zip->set_number('1088355')->is_valid_number, '株式会社 阪急交通社');
ok($zip->set_number('1088358')->is_valid_number, '財団法人 香川育英会');
ok($zip->set_number('1088360')->is_valid_number, 'DKSHジャパン 株式会社');
ok($zip->set_number('1088361')->is_valid_number, 'オーストラリア大使館 AUSTRALIAN EMBASSY');
ok($zip->set_number('1088372')->is_valid_number, '社団法人 日本作業環境測定協会');
ok($zip->set_number('1088373')->is_valid_number, '宇都宮螺子 株式会社');
ok($zip->set_number('1088375')->is_valid_number, '株式会社 東京機械製作所');
ok($zip->set_number('1088379')->is_valid_number, '株式会社 インボイス');
ok($zip->set_number('1088380')->is_valid_number, '株式会社 テノックス');
ok($zip->set_number('1088381')->is_valid_number, '株式会社 奥村組 東京支社');
ok($zip->set_number('1088383')->is_valid_number, '株式会社 長谷工コミュニティ');
ok($zip->set_number('1088384')->is_valid_number, '森永乳業 株式会社');
ok($zip->set_number('1088385')->is_valid_number, '理想科学工業 株式会社');
ok($zip->set_number('1088386')->is_valid_number, 'オックスフォード大学出版局 株式会社');
ok($zip->set_number('1088388')->is_valid_number, '横浜化成 株式会社');
ok($zip->set_number('1088389')->is_valid_number, '合成化学産業 労働組合連合');
ok($zip->set_number('1088403')->is_valid_number, '森永製菓 株式会社');
ok($zip->set_number('1088404')->is_valid_number, '三信電気 株式会社');
ok($zip->set_number('1088405')->is_valid_number, 'サーモス 株式会社');
ok($zip->set_number('1088407')->is_valid_number, '三菱自動車ファイナンス 株式会社');
ok($zip->set_number('1088410')->is_valid_number, '三菱自動車工業 株式会社');
ok($zip->set_number('1088411')->is_valid_number, '三菱オートリース 株式会社');
ok($zip->set_number('1088414')->is_valid_number, '社団法人 日本建築学会');
ok($zip->set_number('1088415')->is_valid_number, '三菱化学メディア 株式会社');
ok($zip->set_number('1088416')->is_valid_number, '株式会社 コスモスイニシア');
ok($zip->set_number('1088417')->is_valid_number, '株式会社 コスモスイニシア');
ok($zip->set_number('1088420')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088421')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088423')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088424')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088425')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088432')->is_valid_number, '東京労働局 需給調整事業部');
ok($zip->set_number('1088439')->is_valid_number, '(株) オンワード樫山');
ok($zip->set_number('1088444')->is_valid_number, 'アプライドマテリアルズジャパン 株式会社');
ok($zip->set_number('1088448')->is_valid_number, '栗林運輸 株式会社');
ok($zip->set_number('1088456')->is_valid_number, 'ケイヒン 株式会社');
ok($zip->set_number('1088466')->is_valid_number, '日本カーバイド工業 株式会社');
ok($zip->set_number('1088468')->is_valid_number, 'イギン 株式会社 東京本社');
ok($zip->set_number('1088470')->is_valid_number, '水ing 株式会社');
ok($zip->set_number('1088477')->is_valid_number, '東京海洋大学');
ok($zip->set_number('1088478')->is_valid_number, '大同特殊鋼 株式会社 東京本社');
ok($zip->set_number('1088501')->is_valid_number, '東洋水産 株式会社');
ok($zip->set_number('1088502')->is_valid_number, '株式会社 大林組 東京本社 品川事務所');
ok($zip->set_number('1088503')->is_valid_number, 'サントリー田町オフィス');
ok($zip->set_number('1088504')->is_valid_number, '昭光通商 株式会社');
ok($zip->set_number('1088505')->is_valid_number, '株式会社 NTTデータ');
ok($zip->set_number('1088506')->is_valid_number, 'THK 株式会社');
ok($zip->set_number('1088507')->is_valid_number, '株式会社 フィリップスエレクトロニクスジャパン');
ok($zip->set_number('1088508')->is_valid_number, 'ピコ 株式会社');
ok($zip->set_number('1088509')->is_valid_number, '日本エア・リキード 株式会社');
ok($zip->set_number('1088510')->is_valid_number, '株式会社 ネクスティエレクトロニクス');
ok($zip->set_number('1088511')->is_valid_number, 'ITX 株式会社');
ok($zip->set_number('1088512')->is_valid_number, '東京コカコーラボトリング 株式会社');
ok($zip->set_number('1088515')->is_valid_number, 'NECネッツエスアイ 株式会社');
ok($zip->set_number('1088520')->is_valid_number, '株式会社 タツノ');
ok($zip->set_number('1088521')->is_valid_number, 'テクノレント 株式会社');
ok($zip->set_number('1088522')->is_valid_number, '株式会社 ニフコ 東京支社');
ok($zip->set_number('1088523')->is_valid_number, '太洋日産自動車販売 株式会社');
ok($zip->set_number('1088525')->is_valid_number, '伊藤忠エネクス 株式会社');
ok($zip->set_number('1088530')->is_valid_number, '監査法人 トーマツ');
ok($zip->set_number('1088532')->is_valid_number, 'あすか製薬 株式会社');
ok($zip->set_number('1088533')->is_valid_number, '株式会社 関電工');
ok($zip->set_number('1088536')->is_valid_number, '株式会社 トッパン・コスモ');
ok($zip->set_number('1088539')->is_valid_number, '凸版印刷 株式会社 エレクトロニクス事業本部');
ok($zip->set_number('1088540')->is_valid_number, '株式会社 ダイトーコーポレーション');
ok($zip->set_number('1088543')->is_valid_number, '中野冷機 株式会社');
ok($zip->set_number('1088545')->is_valid_number, '株式会社 タカマコンペテイションプロダクト');
ok($zip->set_number('1088548')->is_valid_number, '芝浦工業大学');
ok($zip->set_number('1088550')->is_valid_number, '五十嵐冷蔵 株式会社');
ok($zip->set_number('1088551')->is_valid_number, '沖電気工業 株式会社');
ok($zip->set_number('1088552')->is_valid_number, '株式会社 スマイルドラッグ');
ok($zip->set_number('1088553')->is_valid_number, '株式会社 ITサービス 芝浦事業所');
ok($zip->set_number('1088555')->is_valid_number, '株式会社 オリコフォレントインシュア');
ok($zip->set_number('1088556')->is_valid_number, '日本電気 株式会社 第二田町ビル');
ok($zip->set_number('1088557')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088558')->is_valid_number, '日本電気 株式会社');
ok($zip->set_number('1088560')->is_valid_number, '日本コンクリート工業 株式会社');
ok($zip->set_number('1088564')->is_valid_number, '(株) コスモ総合研究所');
ok($zip->set_number('1088566')->is_valid_number, 'エイ・エイ・ピー・シー・ジャパン 株式会社 プルマン東京田町');
ok($zip->set_number('1088568')->is_valid_number, 'ヤマハ 株式会社 東京営業事務所');
ok($zip->set_number('1088570')->is_valid_number, '株式会社 コシダテック');
ok($zip->set_number('1088571')->is_valid_number, '株式会社 日本能率協会コンサルティング');
ok($zip->set_number('1088573')->is_valid_number, '株式会社 ドウシシャ');
ok($zip->set_number('1088575')->is_valid_number, 'ユニ・チャーム 株式会社');
ok($zip->set_number('1088580')->is_valid_number, '東芝キヤリア 株式会社');
ok($zip->set_number('1088581')->is_valid_number, '東京都 港区役所高輪支所');
ok($zip->set_number('1088582')->is_valid_number, '株式会社 ビー・エム・ディー');
ok($zip->set_number('1088583')->is_valid_number, '独立行政法人 地域医療機能推進機構');
ok($zip->set_number('1088585')->is_valid_number, '社団法人 日本フラワーデザイナー協会');
ok($zip->set_number('1088586')->is_valid_number, '日本トムソン 株式会社');
ok($zip->set_number('1088588')->is_valid_number, 'テクマトリックス 株式会社');
ok($zip->set_number('1088602')->is_valid_number, '国民生活センター');
ok($zip->set_number('1088606')->is_valid_number, '東京船員保険病院');
ok($zip->set_number('1088607')->is_valid_number, '財団法人 日本ユニセフ協会');
ok($zip->set_number('1088610')->is_valid_number, 'コムシス情報システム 株式会社');
ok($zip->set_number('1088611')->is_valid_number, '品川プリンスホテル');
ok($zip->set_number('1088612')->is_valid_number, '高輪プリンスホテル 新高輪プリンスホテル');
ok($zip->set_number('1088615')->is_valid_number, '株式会社 レアソン');
ok($zip->set_number('1088616')->is_valid_number, '地域医療機能推進機構健康保険組合');
ok($zip->set_number('1088617')->is_valid_number, '株式会社 くもん出版');
ok($zip->set_number('1088622')->is_valid_number, '品川税務署');
ok($zip->set_number('1088628')->is_valid_number, '株式会社 二葉');
ok($zip->set_number('1088631')->is_valid_number, '八芳園');
ok($zip->set_number('1088632')->is_valid_number, '株式会社 近鉄ホテルシステムズ');
ok($zip->set_number('1088633')->is_valid_number, '株式会社 ヤマプラス');
ok($zip->set_number('1088636')->is_valid_number, '明治学院大学');
ok($zip->set_number('1088638')->is_valid_number, '株式会社 日本教育新聞社');
ok($zip->set_number('1088639')->is_valid_number, '東京大学医科学研究所');
ok($zip->set_number('1088640')->is_valid_number, '株式会社 都ホテル東京');
ok($zip->set_number('1088641')->is_valid_number, '学校法人 北里研究所');
ok($zip->set_number('1088642')->is_valid_number, '北里研究所病院');
ok($zip->set_number('1088648')->is_valid_number, 'サクサビジネスシステム 株式会社');
ok($zip->set_number('1088650')->is_valid_number, 'さくら情報システム 株式会社');
ok($zip->set_number('1088707')->is_valid_number, '一般財団法人 日本モーターボート競走会');
ok($zip->set_number('1088710')->is_valid_number, 'コクヨ (株) 品川オフィス');
ok($zip->set_number('1088713')->is_valid_number, 'トヨタモビリティ東京 株式会社');
ok($zip->set_number('1098792')->is_valid_number, '株式会社 かんぽ生命保険 東京サービスセンター');
ok($zip->set_number('1108408')->is_valid_number, '栄研化学 株式会社');
ok($zip->set_number('1108501')->is_valid_number, '野村證券 株式会社 上野支店');
ok($zip->set_number('1108502')->is_valid_number, '株式会社 丸井 上野店');
ok($zip->set_number('1108503')->is_valid_number, '株式会社 松坂屋 上野店');
ok($zip->set_number('1108505')->is_valid_number, '株式会社 真多呂人形');
ok($zip->set_number('1108507')->is_valid_number, '株式会社 ヨシダ');
ok($zip->set_number('1108509')->is_valid_number, '橋本産業 株式会社');
ok($zip->set_number('1108510')->is_valid_number, '株式会社 下谷金属');
ok($zip->set_number('1108511')->is_valid_number, '株式会社 トータルアクセスシャトル');
ok($zip->set_number('1108513')->is_valid_number, '株式会社 モリタ');
ok($zip->set_number('1108515')->is_valid_number, '大和證券 株式会社 上野支店');
ok($zip->set_number('1108516')->is_valid_number, '株式会社 日伝 東京支店');
ok($zip->set_number('1108517')->is_valid_number, 'ヒカリ興業 株式会社');
ok($zip->set_number('1108520')->is_valid_number, '株式会社 理研グリーン');
ok($zip->set_number('1108522')->is_valid_number, '株式会社 吉池');
ok($zip->set_number('1108524')->is_valid_number, '朝日生命保険 相互会社 東京東統括支社');
ok($zip->set_number('1108530')->is_valid_number, '株式会社 日本歯科工業社');
ok($zip->set_number('1108531')->is_valid_number, '株式会社 台和');
ok($zip->set_number('1108532')->is_valid_number, '株式会社 文昌堂');
ok($zip->set_number('1108533')->is_valid_number, '株式会社 新生銀行 上野支店');
ok($zip->set_number('1108534')->is_valid_number, '三洋電機 株式会社');
ok($zip->set_number('1108536')->is_valid_number, 'オリエンタルモーター 株式会社');
ok($zip->set_number('1108537')->is_valid_number, '(株) 鈴乃屋');
ok($zip->set_number('1108539')->is_valid_number, '株式会社 上野風月堂');
ok($zip->set_number('1108540')->is_valid_number, '一般財団法人 日本船員住宅協会');
ok($zip->set_number('1108541')->is_valid_number, '(株) アブアブ赤札堂');
ok($zip->set_number('1108543')->is_valid_number, '株式会社 和光ハトヤ');
ok($zip->set_number('1108546')->is_valid_number, '株式会社 ナガホリ');
ok($zip->set_number('1108548')->is_valid_number, '株式会社 酒悦');
ok($zip->set_number('1108550')->is_valid_number, '三共スポーツ 株式会社');
ok($zip->set_number('1108555')->is_valid_number, 'サンデンホールディングス 株式会社 東京本社');
ok($zip->set_number('1108559')->is_valid_number, 'イン・ステップ 有限会社');
ok($zip->set_number('1108560')->is_valid_number, '凸版印刷 株式会社');
ok($zip->set_number('1108561')->is_valid_number, '東京法務局 台東出張所');
ok($zip->set_number('1108562')->is_valid_number, '日本リテイルシステム 株式会社');
ok($zip->set_number('1108565')->is_valid_number, '東日本電信電話 株式会社 上野支店');
ok($zip->set_number('1108566')->is_valid_number, '藤川伝導機 株式会社');
ok($zip->set_number('1108567')->is_valid_number, '社団法人 日本動物園水族館協会');
ok($zip->set_number('1108575')->is_valid_number, '山田マシンツール 株式会社');
ok($zip->set_number('1108576')->is_valid_number, '昭和室内工業 (株)');
ok($zip->set_number('1108577')->is_valid_number, '千代田機工 株式会社');
ok($zip->set_number('1108578')->is_valid_number, '株式会社 内外出版社');
ok($zip->set_number('1108580')->is_valid_number, '農林漁業団体職員共済組合');
ok($zip->set_number('1108582')->is_valid_number, 'YKK ファスニングプロダクツ販売 株式会社');
ok($zip->set_number('1108583')->is_valid_number, '株式会社 多慶屋');
ok($zip->set_number('1108584')->is_valid_number, '株式会社 富士商会');
ok($zip->set_number('1108586')->is_valid_number, '東和通商 株式会社');
ok($zip->set_number('1108588')->is_valid_number, '神田電子工業 株式会社');
ok($zip->set_number('1108602')->is_valid_number, '警視庁 上野警察署');
ok($zip->set_number('1108605')->is_valid_number, '特定非営利活動法人 日本国際ボランティアセンター');
ok($zip->set_number('1108609')->is_valid_number, '上野公共職業安定所');
ok($zip->set_number('1108610')->is_valid_number, '共立食品 株式会社');
ok($zip->set_number('1108614')->is_valid_number, '東京地下鉄 株式会社');
ok($zip->set_number('1108615')->is_valid_number, '東京都台東区役所');
ok($zip->set_number('1108618')->is_valid_number, 'J-NET中央 株式会社');
ok($zip->set_number('1108619')->is_valid_number, 'ウインドミル 株式会社');
ok($zip->set_number('1108620')->is_valid_number, '新明和工業 株式会社 パーキングシステム事業部');
ok($zip->set_number('1108621')->is_valid_number, '株式会社 シー・アイ・シー');
ok($zip->set_number('1108622')->is_valid_number, 'プラチナ萬年筆 株式会社');
ok($zip->set_number('1108625')->is_valid_number, '株式会社 笠倉出版社');
ok($zip->set_number('1108626')->is_valid_number, '一般社団法人 日本ジュエリー協会');
ok($zip->set_number('1108628')->is_valid_number, '大同生命保険 相互会社 上野支社');
ok($zip->set_number('1108630')->is_valid_number, '金方堂松本工業 株式会社');
ok($zip->set_number('1108631')->is_valid_number, '関工商事 株式会社');
ok($zip->set_number('1108635')->is_valid_number, '中央日立家電 株式会社');
ok($zip->set_number('1108638')->is_valid_number, 'ジェイ・アキュレート 株式会社');
ok($zip->set_number('1108641')->is_valid_number, '日立コンシューマ・マーケティング 株式会社 東京支社');
ok($zip->set_number('1108642')->is_valid_number, '学校法人 上野学園');
ok($zip->set_number('1108644')->is_valid_number, 'ヨシディア 株式会社');
ok($zip->set_number('1108645')->is_valid_number, '財団法人 ライフ・エクステンション研究所 附属 永寿総合病院');
ok($zip->set_number('1108646')->is_valid_number, '全国印刷工業健康保険組合');
ok($zip->set_number('1108653')->is_valid_number, '日本通信紙 株式会社');
ok($zip->set_number('1108660')->is_valid_number, '日本年金機構 上野年金事務所');
ok($zip->set_number('1108662')->is_valid_number, '学校法人 華学園 華服飾専門学校 華調理師専門学校 華学園栄養専門学校 華学園オーケービジネス専門学校');
ok($zip->set_number('1108665')->is_valid_number, '株式会社 タジマヤ');
ok($zip->set_number('1108669')->is_valid_number, '株式会社 鈴木産業');
ok($zip->set_number('1108673')->is_valid_number, '丸喜 株式会社 東京支店');
ok($zip->set_number('1108675')->is_valid_number, '株式会社 シモダイラ');
ok($zip->set_number('1108676')->is_valid_number, '財団法人 自然環境研究センター');
ok($zip->set_number('1108677')->is_valid_number, '三輝工業 株式会社');
ok($zip->set_number('1108678')->is_valid_number, '警視庁 下谷警察署');
ok($zip->set_number('1108680')->is_valid_number, 'アトムリビンテック 株式会社');
ok($zip->set_number('1108681')->is_valid_number, '株式会社 ムトウ 東京事業本部');
ok($zip->set_number('1108685')->is_valid_number, 'トクダマシモエース 株式会社');
ok($zip->set_number('1108686')->is_valid_number, '日本エアーテック 株式会社');
ok($zip->set_number('1108687')->is_valid_number, '(財)東京菓子会館');
ok($zip->set_number('1108706')->is_valid_number, '日本電設工業 株式会社');
ok($zip->set_number('1108708')->is_valid_number, '日本郵政グループ労働組合');
ok($zip->set_number('1108712')->is_valid_number, '東京国立博物館');
ok($zip->set_number('1108713')->is_valid_number, '独立行政法人 文化財研究所 東京文化財研究所');
ok($zip->set_number('1108714')->is_valid_number, '東京芸術大学');
ok($zip->set_number('1108715')->is_valid_number, '(株) 精養軒');
ok($zip->set_number('1108716')->is_valid_number, '東京文化会館');
ok($zip->set_number('1108722')->is_valid_number, '全国新聞情報農業 協同組合連合会 (日本農業新聞)');
ok($zip->set_number('1108723')->is_valid_number, '正栄食品工業 株式会社');
ok($zip->set_number('1108725')->is_valid_number, '東洋ロープ 株式会社');
ok($zip->set_number('1108733')->is_valid_number, '株式会社 三共 東京支店');
ok($zip->set_number('1108736')->is_valid_number, '島津ダイアグノスティクス 株式会社');
ok($zip->set_number('1108780')->is_valid_number, '株式会社 落合');
ok($zip->set_number('1108782')->is_valid_number, 'クミアイ化学工業 株式会社');
ok($zip->set_number('1108787')->is_valid_number, '商工中金 上野支店');
ok($zip->set_number('1108807')->is_valid_number, '株式会社 オンダ');
ok($zip->set_number('1118081')->is_valid_number, '株式会社 バンダイ');
ok($zip->set_number('1118501')->is_valid_number, '浅草警察署');
ok($zip->set_number('1118502')->is_valid_number, 'エスエスユニオン 株式会社');
ok($zip->set_number('1118505')->is_valid_number, 'ハインツ日本 株式会社');
ok($zip->set_number('1118506')->is_valid_number, '日本アイ・エス・ケイ 株式会社');
ok($zip->set_number('1118507')->is_valid_number, '勝村建設 株式会社');
ok($zip->set_number('1118508')->is_valid_number, '日新明弘テック 株式会社');
ok($zip->set_number('1118510')->is_valid_number, '株式会社 十字屋');
ok($zip->set_number('1118511')->is_valid_number, '滝川 株式会社');
ok($zip->set_number('1118512')->is_valid_number, 'マドラス 株式会社');
ok($zip->set_number('1118515')->is_valid_number, '株式会社 吉徳');
ok($zip->set_number('1118518')->is_valid_number, '株式会社 木馬');
ok($zip->set_number('1118521')->is_valid_number, '東都フジクラ販売 株式会社');
ok($zip->set_number('1118522')->is_valid_number, '日本マタイ 株式会社');
ok($zip->set_number('1118525')->is_valid_number, '株式会社 ブンカ');
ok($zip->set_number('1118530')->is_valid_number, '東京電子機械工業 健康保険組合');
ok($zip->set_number('1118531')->is_valid_number, '株式会社 東京ユニコム');
ok($zip->set_number('1118532')->is_valid_number, '協同組合 趣味の百撰会');
ok($zip->set_number('1118533')->is_valid_number, '株式会社 ノダ');
ok($zip->set_number('1118534')->is_valid_number, 'セイコーミシン 株式会社');
ok($zip->set_number('1118535')->is_valid_number, '東京楽天地浅草ビル');
ok($zip->set_number('1118539')->is_valid_number, '株式会社 シタシオンジャパン');
ok($zip->set_number('1118543')->is_valid_number, '株式会社 壽商会');
ok($zip->set_number('1118551')->is_valid_number, 'サンスター文具 株式会社');
ok($zip->set_number('1118555')->is_valid_number, '株式会社 エポック社');
ok($zip->set_number('1118556')->is_valid_number, '株式会社 ジェイ・エス・ティ');
ok($zip->set_number('1118558')->is_valid_number, 'バンダイビジュアル 株式会社');
ok($zip->set_number('1118560')->is_valid_number, 'ミツワ 株式会社');
ok($zip->set_number('1118561')->is_valid_number, '株式会社 ケーブル・アンド・ワイヤレス・アイディーシー・エスアイ');
ok($zip->set_number('1118566')->is_valid_number, '松本徽章工業 株式会社');
ok($zip->set_number('1118567')->is_valid_number, '株式会社 コマキ楽器');
ok($zip->set_number('1118575')->is_valid_number, 'モリト 株式会社 東京支社');
ok($zip->set_number('1118577')->is_valid_number, 'トッパンレーベル 株式会社');
ok($zip->set_number('1118580')->is_valid_number, '株式会社 エスエスケイ 東京支店');
ok($zip->set_number('1118585')->is_valid_number, '衛星デジタル音楽放送 株式会社');
ok($zip->set_number('1118588')->is_valid_number, '株式会社 高山');
ok($zip->set_number('1118602')->is_valid_number, '浅草税務署');
ok($zip->set_number('1118605')->is_valid_number, 'ファースト・ファシリティーズ 株式会社');
ok($zip->set_number('1118606')->is_valid_number, '東京都台東都税事務所');
ok($zip->set_number('1118608')->is_valid_number, '株式会社 ベンチャー・リンク');
ok($zip->set_number('1118610')->is_valid_number, '株式会社 コロンブス');
ok($zip->set_number('1118611')->is_valid_number, '株式会社 東京文具共和会館');
ok($zip->set_number('1118612')->is_valid_number, 'カネダ 株式会社');
ok($zip->set_number('1118615')->is_valid_number, '株式会社 リンク総研');
ok($zip->set_number('1118618')->is_valid_number, '株式会社 エポック社');
ok($zip->set_number('1118620')->is_valid_number, '株式会社 コバヤシ');
ok($zip->set_number('1118621')->is_valid_number, '台東区生涯学習センター');
ok($zip->set_number('1118622')->is_valid_number, 'ミツワ産業 株式会社');
ok($zip->set_number('1118625')->is_valid_number, '日本コパック 株式会社');
ok($zip->set_number('1118628')->is_valid_number, '有限会社 ニイミ洋食器店');
ok($zip->set_number('1118630')->is_valid_number, '東和エンタープライズ 株式会社');
ok($zip->set_number('1118631')->is_valid_number, '日本電子総合サービス 株式会社');
ok($zip->set_number('1118633')->is_valid_number, 'アクサ損害保険 株式会社');
ok($zip->set_number('1118637')->is_valid_number, '小野田ケミコ 株式会社');
ok($zip->set_number('1118639')->is_valid_number, '三平建設 株式会社');
ok($zip->set_number('1118640')->is_valid_number, '株式会社 内田');
ok($zip->set_number('1118642')->is_valid_number, '株式会社 トークツ');
ok($zip->set_number('1118644')->is_valid_number, 'ライオン 株式会社');
ok($zip->set_number('1118648')->is_valid_number, '八千代エンジニヤリング 株式会社');
ok($zip->set_number('1118650')->is_valid_number, '緑川化成工業 株式会社');
ok($zip->set_number('1118655')->is_valid_number, 'エース 株式会社 東京店');
ok($zip->set_number('1118661')->is_valid_number, '株式会社 マルショウエンドウ');
ok($zip->set_number('1118666')->is_valid_number, 'レデイマドラス 株式会社');
ok($zip->set_number('1118676')->is_valid_number, '株式会社 アルメックス');
ok($zip->set_number('1118677')->is_valid_number, '首都圏新都市鉄道 株式会社');
ok($zip->set_number('1118678')->is_valid_number, '株式会社 増田屋コーポレーション');
ok($zip->set_number('1118681')->is_valid_number, '株式会社 エポック社');
ok($zip->set_number('1118683')->is_valid_number, '中部物産貿易 株式会社 東京支店');
ok($zip->set_number('1118686')->is_valid_number, '株式会社 神栄');
ok($zip->set_number('1118688')->is_valid_number, '株式会社 盛光');
ok($zip->set_number('1118701')->is_valid_number, '大和証券 雷門支店');
ok($zip->set_number('1118707')->is_valid_number, '株式会社 東京デジタルホン');
ok($zip->set_number('1118708')->is_valid_number, '野村ファンドネット証券 株式会社');
ok($zip->set_number('1118710')->is_valid_number, 'ユウユウ〈株式会社ユウメディア〉');
ok($zip->set_number('1118711')->is_valid_number, '株式会社 陶漆芸巧');
ok($zip->set_number('1118721')->is_valid_number, '株式会社 シンエイ');
ok($zip->set_number('1118755')->is_valid_number, '株式会社 筑摩書房');
ok($zip->set_number('1118765')->is_valid_number, '浅草ビューホテル');
ok($zip->set_number('1118798')->is_valid_number, '日本郵政 株式会社 CRE部門 ファシリティマネジメント部');
ok($zip->set_number('1128001')->is_valid_number, '株式会社 講談社');
ok($zip->set_number('1128011')->is_valid_number, '株式会社 光文社');
ok($zip->set_number('1128088')->is_valid_number, 'エーザイ 株式会社');
ok($zip->set_number('1128138')->is_valid_number, '株式会社 中山書店');
ok($zip->set_number('1128501')->is_valid_number, '共同印刷 株式会社');
ok($zip->set_number('1128502')->is_valid_number, 'キネマ旬報社');
ok($zip->set_number('1128503')->is_valid_number, '太平洋セメント 株式会社');
ok($zip->set_number('1128505')->is_valid_number, '日本建設 株式会社 東京支店');
ok($zip->set_number('1128506')->is_valid_number, '財団法人 加越能育英社 明倫学館');
ok($zip->set_number('1128508')->is_valid_number, '株式会社 HS情報システムズ');
ok($zip->set_number('1128509')->is_valid_number, 'レック 株式会社');
ok($zip->set_number('1128511')->is_valid_number, '明星電気 株式会社');
ok($zip->set_number('1128512')->is_valid_number, '株式会社 チャイルド本社');
ok($zip->set_number('1128514')->is_valid_number, '株式会社 キッズステーション');
ok($zip->set_number('1128516')->is_valid_number, '株式会社 瑞穂');
ok($zip->set_number('1128524')->is_valid_number, 'カテナ (株) 水道橋オフィス');
ok($zip->set_number('1128525')->is_valid_number, 'アルテミラ製缶 株式会社');
ok($zip->set_number('1128528')->is_valid_number, '大新東 株式会社');
ok($zip->set_number('1128530')->is_valid_number, '株式会社 KADOKAWA Game Linkage');
ok($zip->set_number('1128531')->is_valid_number, '凸版印刷 (株) パッケージ事業本部');
ok($zip->set_number('1128533')->is_valid_number, '成美堂出版 株式会社');
ok($zip->set_number('1128538')->is_valid_number, '株式会社 大阪屋 東京支社');
ok($zip->set_number('1128540')->is_valid_number, '株式会社 太洋社');
ok($zip->set_number('1128541')->is_valid_number, '株式会社 精案社 DMセンター');
ok($zip->set_number('1128548')->is_valid_number, '浜井電球工業 株式会社');
ok($zip->set_number('1128550')->is_valid_number, '東京都文京都税事務所');
ok($zip->set_number('1128551')->is_valid_number, '中央大学 理工学部');
ok($zip->set_number('1128555')->is_valid_number, '文京区役所');
ok($zip->set_number('1128556')->is_valid_number, '株式会社 ウィズマン');
ok($zip->set_number('1128557')->is_valid_number, '有限会社 ウィズアドバタイジング');
ok($zip->set_number('1128558')->is_valid_number, '小石川税務署');
ok($zip->set_number('1128562')->is_valid_number, '東京ドームホテル');
ok($zip->set_number('1128563')->is_valid_number, '日立建機 (株)');
ok($zip->set_number('1128566')->is_valid_number, '鹿島道路 株式会社');
ok($zip->set_number('1128569')->is_valid_number, '全逓会館');
ok($zip->set_number('1128570')->is_valid_number, '独立行政法人 住宅金融支援機構');
ok($zip->set_number('1128573')->is_valid_number, '中央労働基準監督署');
ok($zip->set_number('1128575')->is_valid_number, '株式会社 東京ドーム');
ok($zip->set_number('1128576')->is_valid_number, '五洋建設 株式会社');
ok($zip->set_number('1128580')->is_valid_number, '株式会社 芳文社');
ok($zip->set_number('1128583')->is_valid_number, '株式会社 ミスミグループ本社');
ok($zip->set_number('1128585')->is_valid_number, '学校法人 拓殖大学(文京キャンパス)');
ok($zip->set_number('1128586')->is_valid_number, '中央大学 小石川キャンパス');
ok($zip->set_number('1128601')->is_valid_number, '宝くじ業務センター 通信販売係');
ok($zip->set_number('1128604')->is_valid_number, '公益財団法人 原子力安全技術センター');
ok($zip->set_number('1128606')->is_valid_number, '東洋大学');
ok($zip->set_number('1128607')->is_valid_number, '(学) 東洋大学 京北事務室');
ok($zip->set_number('1128609')->is_valid_number, 'お茶の水女子大学 音羽館');
ok($zip->set_number('1128610')->is_valid_number, 'お茶の水女子大学');
ok($zip->set_number('1128611')->is_valid_number, '裁判所 裁判書記官研修所');
ok($zip->set_number('1128612')->is_valid_number, '京華学園');
ok($zip->set_number('1128618')->is_valid_number, '株式会社 ヨツワ産業');
ok($zip->set_number('1128619')->is_valid_number, 'CQ出版 株式会社');
ok($zip->set_number('1128620')->is_valid_number, '文京カテリーナ');
ok($zip->set_number('1128622')->is_valid_number, 'アカツキ産業 株式会社');
ok($zip->set_number('1128625')->is_valid_number, '学校法人 貞静学園');
ok($zip->set_number('1128627')->is_valid_number, '全国森林関連産業労働者共済 生活協同組合');
ok($zip->set_number('1128629')->is_valid_number, '学校法人 跡見学園');
ok($zip->set_number('1128630')->is_valid_number, '貞静学園短期大学');
ok($zip->set_number('1128631')->is_valid_number, '中央大学 茗荷谷キャンパス');
ok($zip->set_number('1128632')->is_valid_number, '株式会社 図書館流通センター');
ok($zip->set_number('1128633')->is_valid_number, '(株) コア・ブレイン');
ok($zip->set_number('1128634')->is_valid_number, '株式会社 村田金箔');
ok($zip->set_number('1128635')->is_valid_number, '株式会社 文渓堂');
ok($zip->set_number('1128642')->is_valid_number, '住商マシネックス 株式会社');
ok($zip->set_number('1128644')->is_valid_number, '音羽女子学生会館');
ok($zip->set_number('1128645')->is_valid_number, '酒井工業 株式会社');
ok($zip->set_number('1128650')->is_valid_number, '全薬工業 株式会社');
ok($zip->set_number('1128651')->is_valid_number, '(株) エーオーエーアオバ');
ok($zip->set_number('1128652')->is_valid_number, '講談社インターナショナル 株式会社');
ok($zip->set_number('1128653')->is_valid_number, '株式会社 宙出版');
ok($zip->set_number('1128654')->is_valid_number, 'プラス 株式会社');
ok($zip->set_number('1128655')->is_valid_number, '(株) 二見書房');
ok($zip->set_number('1128657')->is_valid_number, '加賀電子 株式会社');
ok($zip->set_number('1128660')->is_valid_number, 'センコー商事 株式会社');
ok($zip->set_number('1128662')->is_valid_number, '古久根建設 株式会社');
ok($zip->set_number('1128663')->is_valid_number, 'ニチバン 株式会社');
ok($zip->set_number('1128664')->is_valid_number, '藤田観光 株式会社');
ok($zip->set_number('1128668')->is_valid_number, '株式会社 アイ・エヌ・エー');
ok($zip->set_number('1128670')->is_valid_number, 'Jフォン');
ok($zip->set_number('1128671')->is_valid_number, '住宅金融支援機構 首都圏支店');
ok($zip->set_number('1128675')->is_valid_number, '株式会社 主婦の友社');
ok($zip->set_number('1128677')->is_valid_number, 'NKSJシステムズ 株式会社');
ok($zip->set_number('1128677')->is_valid_number, 'NKSJホールディングス');
ok($zip->set_number('1128677')->is_valid_number, '株式会社 プライムアシスタンス');
ok($zip->set_number('1128677')->is_valid_number, '日本興亜ホットライン24 株式会社');
ok($zip->set_number('1128678')->is_valid_number, '日本総合住生活 株式会社 東京支社');
ok($zip->set_number('1128680')->is_valid_number, '藤田観光 株式会社 ホテル椿山荘東京');
ok($zip->set_number('1128681')->is_valid_number, '日本女子大学');
ok($zip->set_number('1128682')->is_valid_number, '和敬塾');
ok($zip->set_number('1128683')->is_valid_number, '株式会社 リテック・コンサルタンツ');
ok($zip->set_number('1128684')->is_valid_number, '株式会社 トルテック都市建築設計事務所');
ok($zip->set_number('1128685')->is_valid_number, '株式会社 デュープレックス・ギャザリング');
ok($zip->set_number('1128687')->is_valid_number, '跡見学園女子大学');
ok($zip->set_number('1128688')->is_valid_number, '三菱UFJモルガン・スタンレー証券 株式会社');
ok($zip->set_number('1128690')->is_valid_number, '株式会社 JTB商事');
ok($zip->set_number('1128701')->is_valid_number, 'トヨタ自動車 株式会社 東京本社');
ok($zip->set_number('1128702')->is_valid_number, '株式会社 日本アカデミー');
ok($zip->set_number('1128710')->is_valid_number, 'クラリオン販売 株式会社');
ok($zip->set_number('1128750')->is_valid_number, 'キャリテック 株式会社');
ok($zip->set_number('1128760')->is_valid_number, '株式会社 エム・シー・フーズ');
ok($zip->set_number('1128778')->is_valid_number, '三菱食品 株式会社');
ok($zip->set_number('1138139')->is_valid_number, '公益財団法人 通信文化協会');
ok($zip->set_number('1138311')->is_valid_number, '財団法人 日本サッカー協会');
ok($zip->set_number('1138401')->is_valid_number, 'ビッグホリデー 株式会社');
ok($zip->set_number('1138402')->is_valid_number, '株式会社 シード');
ok($zip->set_number('1138404')->is_valid_number, '東邦テナックス 株式会社');
ok($zip->set_number('1138408')->is_valid_number, '栄研化学 株式会社');
ok($zip->set_number('1138410')->is_valid_number, '株式会社 南江堂');
ok($zip->set_number('1138411')->is_valid_number, '三菱UFJニコス 株式会社');
ok($zip->set_number('1138412')->is_valid_number, '三菱UFJニコス 株式会社');
ok($zip->set_number('1138413')->is_valid_number, '三菱UFJニコス 株式会社');
ok($zip->set_number('1138415')->is_valid_number, 'パラテクノ 株式会社');
ok($zip->set_number('1138418')->is_valid_number, '公益社団法人 日本整形外科学会');
ok($zip->set_number('1138420')->is_valid_number, 'フクダ電子 (株)');
ok($zip->set_number('1138421')->is_valid_number, '順天堂大学');
ok($zip->set_number('1138422')->is_valid_number, 'ADEKAクリーンエイド 株式会社');
ok($zip->set_number('1138423')->is_valid_number, '株式会社 りそな銀行 本郷支店');
ok($zip->set_number('1138431')->is_valid_number, '順天堂大学附属 順天堂医院');
ok($zip->set_number('1138433')->is_valid_number, '社団法人 日本内科学会');
ok($zip->set_number('1138434')->is_valid_number, '三洋電機 株式会社 日本サッカー協会ビル');
ok($zip->set_number('1138435')->is_valid_number, 'トノクラ医科工業 株式会社');
ok($zip->set_number('1138441')->is_valid_number, '日本私立学校振興・共済事業団');
ok($zip->set_number('1138444')->is_valid_number, '富士エレクトロニクス 株式会社');
ok($zip->set_number('1138448')->is_valid_number, '株式会社 日本スポーツ企画出版社');
ok($zip->set_number('1138450')->is_valid_number, '株式会社 第一科学');
ok($zip->set_number('1138451')->is_valid_number, '村中医療器 株式会社 東京支店');
ok($zip->set_number('1138456')->is_valid_number, '東芝メディカル 株式会社');
ok($zip->set_number('1138459')->is_valid_number, '本郷税務署');
ok($zip->set_number('1138462')->is_valid_number, '全国労働組合総連合');
ok($zip->set_number('1138463')->is_valid_number, '日本国民救援会');
ok($zip->set_number('1138464')->is_valid_number, '原水爆禁止日本協議会');
ok($zip->set_number('1138465')->is_valid_number, '全日本民主医療機関連合会');
ok($zip->set_number('1138466')->is_valid_number, '株式会社 工業調査会');
ok($zip->set_number('1138471')->is_valid_number, '東京スバル 株式会社');
ok($zip->set_number('1138474')->is_valid_number, '株式会社 太平エンジニアリング');
ok($zip->set_number('1138477')->is_valid_number, '株式会社 柴田書店');
ok($zip->set_number('1138479')->is_valid_number, '株式会社 シモン');
ok($zip->set_number('1138483')->is_valid_number, 'フクダ電子 (株)');
ok($zip->set_number('1138484')->is_valid_number, '欧文印刷 株式会社');
ok($zip->set_number('1138485')->is_valid_number, '東京大学南研究棟');
ok($zip->set_number('1138488')->is_valid_number, 'ワールド通商 株式会社');
ok($zip->set_number('1138501')->is_valid_number, '株式会社 新建築社');
ok($zip->set_number('1138503')->is_valid_number, '加賀電子 株式会社');
ok($zip->set_number('1138504')->is_valid_number, '加賀電子 株式会社');
ok($zip->set_number('1138505')->is_valid_number, '加賀電子 株式会社');
ok($zip->set_number('1138507')->is_valid_number, '日本金型工業企業年金基金');
ok($zip->set_number('1138509')->is_valid_number, 'コミュニティ・ネットワーク 株式会社');
ok($zip->set_number('1138510')->is_valid_number, '東京医科歯科大学 本部');
ok($zip->set_number('1138512')->is_valid_number, '水野産業 株式会社');
ok($zip->set_number('1138513')->is_valid_number, '東邦レマック 株式会社');
ok($zip->set_number('1138517')->is_valid_number, '公益財団法人 ボーイスカウト日本連盟');
ok($zip->set_number('1138519')->is_valid_number, '東京医科歯科大学 医学部');
ok($zip->set_number('1138520')->is_valid_number, '松吉医科器械 株式会社');
ok($zip->set_number('1138521')->is_valid_number, '株式会社 TONEGAWA');
ok($zip->set_number('1138524')->is_valid_number, '株式会社 交通タイムス社');
ok($zip->set_number('1138525')->is_valid_number, '株式会社 オーディオテクニカ');
ok($zip->set_number('1138530')->is_valid_number, '一般社団法人 日本ウオーキング協会');
ok($zip->set_number('1138534')->is_valid_number, '株式会社 三啓');
ok($zip->set_number('1138535')->is_valid_number, '文化シヤッター 株式会社');
ok($zip->set_number('1138536')->is_valid_number, '株式会社 関工ファシリティーズ');
ok($zip->set_number('1138538')->is_valid_number, '株式会社 日本アクセス 事務管理部');
ok($zip->set_number('1138541')->is_valid_number, '株式会社 大修館書店');
ok($zip->set_number('1138543')->is_valid_number, 'ヨネックス 株式会社');
ok($zip->set_number('1138546')->is_valid_number, '東京工事警備 株式会社');
ok($zip->set_number('1138549')->is_valid_number, '東京医科歯科大学 歯学部');
ok($zip->set_number('1138551')->is_valid_number, '株式会社 夏目製作所');
ok($zip->set_number('1138553')->is_valid_number, '財務省関東財務局 東京財務事務所');
ok($zip->set_number('1138555')->is_valid_number, '東京都電機企業年金基金');
ok($zip->set_number('1138556')->is_valid_number, '株式会社 ケイリース');
ok($zip->set_number('1138560')->is_valid_number, '株式会社 マキノ出版');
ok($zip->set_number('1138561')->is_valid_number, '株式会社 マイヘルス社');
ok($zip->set_number('1138562')->is_valid_number, '株式会社 特選街出版');
ok($zip->set_number('1138563')->is_valid_number, '株式会社 壮快薬品');
ok($zip->set_number('1138564')->is_valid_number, '株式会社 壮快薬品');
ok($zip->set_number('1138566')->is_valid_number, '東京都電機健康保険組合');
ok($zip->set_number('1138570')->is_valid_number, 'フクダ電子 株式会社');
ok($zip->set_number('1138601')->is_valid_number, 'キャピタル (株)');
ok($zip->set_number('1138602')->is_valid_number, '日本医科大学');
ok($zip->set_number('1138603')->is_valid_number, '日本医科大学付属病院');
ok($zip->set_number('1138604')->is_valid_number, '学校法人 日本医科大学');
ok($zip->set_number('1138606')->is_valid_number, 'J-POWERテレコミュニケーションサービス 株式会社');
ok($zip->set_number('1138608')->is_valid_number, '開隆堂出版 (株)');
ok($zip->set_number('1138610')->is_valid_number, '日本工業出版 株式会社');
ok($zip->set_number('1138611')->is_valid_number, '株式会社 フレーベル館');
ok($zip->set_number('1138612')->is_valid_number, '医歯薬出版 (株)');
ok($zip->set_number('1138633')->is_valid_number, '株式会社 アストリア');
ok($zip->set_number('1138638')->is_valid_number, '株式会社 セムコーポレーション');
ok($zip->set_number('1138650')->is_valid_number, '科研製薬 株式会社');
ok($zip->set_number('1138654')->is_valid_number, '東京大学 本部事務組織');
ok($zip->set_number('1138655')->is_valid_number, '東京大学医学部附属病院');
ok($zip->set_number('1138656')->is_valid_number, '東京大学 工学部');
ok($zip->set_number('1138657')->is_valid_number, '東京大学 農学部');
ok($zip->set_number('1138658')->is_valid_number, '東京大学 情報基盤センター');
ok($zip->set_number('1138660')->is_valid_number, '文京グリーンコートビル (株)');
ok($zip->set_number('1138661')->is_valid_number, '日本生命保険 相互会社');
ok($zip->set_number('1138662')->is_valid_number, 'クラリアントジャパン (株)');
ok($zip->set_number('1138663')->is_valid_number, '独立行政法人 情報処理推進機構 デジタル人材センター 国家資格・試験部');
ok($zip->set_number('1138667')->is_valid_number, '文京学院大学女子高等学校・中学校');
ok($zip->set_number('1138668')->is_valid_number, '学校法人 文京学園 文京学院大学');
ok($zip->set_number('1138677')->is_valid_number, '東京都立駒込病院');
ok($zip->set_number('1138681')->is_valid_number, '株式会社 千代田テクノル');
ok($zip->set_number('1138686')->is_valid_number, '株式会社 福音館書店');
ok($zip->set_number('1138701')->is_valid_number, '財団法人 日本青少年ペンフレンドクラブ協会');
ok($zip->set_number('1138710')->is_valid_number, 'オカモト 株式会社');
ok($zip->set_number('1138711')->is_valid_number, 'UFJニコス 株式会社');
ok($zip->set_number('1138712')->is_valid_number, 'UFJニコス 株式会社');
ok($zip->set_number('1138719')->is_valid_number, '医学書院');
ok($zip->set_number('1148501')->is_valid_number, '株式会社 コモディイイダ');
ok($zip->set_number('1148502')->is_valid_number, '聖学院中学校高等学校');
ok($zip->set_number('1148503')->is_valid_number, '北とぴあ');
ok($zip->set_number('1148505')->is_valid_number, '川田建設 株式会社');
ok($zip->set_number('1148506')->is_valid_number, '東京都水道局 北営業所');
ok($zip->set_number('1148507')->is_valid_number, '朝日生命保険 相互会社 首都圏第二営業本部 事務センター');
ok($zip->set_number('1148508')->is_valid_number, '東京都北区役所');
ok($zip->set_number('1148510')->is_valid_number, '日本リーテック 株式会社');
ok($zip->set_number('1148512')->is_valid_number, '東京シンコール 株式会社');
ok($zip->set_number('1148514')->is_valid_number, '全日本運輸一般 労働組合');
ok($zip->set_number('1148515')->is_valid_number, '株式会社 ヨコオ');
ok($zip->set_number('1148517')->is_valid_number, '東京都北都税事務所');
ok($zip->set_number('1148518')->is_valid_number, 'リョービ 株式会社');
ok($zip->set_number('1148519')->is_valid_number, '株式会社 サーベイリサーチセンター');
ok($zip->set_number('1148520')->is_valid_number, '京三電線 株式会社');
ok($zip->set_number('1148521')->is_valid_number, '城北信用金庫 本部');
ok($zip->set_number('1148522')->is_valid_number, '城北信用金庫 王子営業部');
ok($zip->set_number('1148523')->is_valid_number, '田端文士村記念館');
ok($zip->set_number('1148524')->is_valid_number, '東京書籍 株式会社');
ok($zip->set_number('1148526')->is_valid_number, '学校法人 東京成徳学園');
ok($zip->set_number('1148528')->is_valid_number, '東京フェライト製造 株式会社');
ok($zip->set_number('1148530')->is_valid_number, 'リーベ 株式会社');
ok($zip->set_number('1148531')->is_valid_number, '東京法務局 北出張所');
ok($zip->set_number('1148532')->is_valid_number, 'フジ電設 株式会社');
ok($zip->set_number('1148534')->is_valid_number, '北区滝野川会館');
ok($zip->set_number('1148535')->is_valid_number, '東京ガスネットワーク (株)');
ok($zip->set_number('1148538')->is_valid_number, '株式会社 三共製作所');
ok($zip->set_number('1148539')->is_valid_number, '東海商事 株式会社');
ok($zip->set_number('1148540')->is_valid_number, 'タツミ産業 株式会社');
ok($zip->set_number('1148541')->is_valid_number, '(株) 小泉 中央城北営業所');
ok($zip->set_number('1148543')->is_valid_number, '学校法人 中央工学校');
ok($zip->set_number('1148545')->is_valid_number, 'トーメン食品 株式会社');
ok($zip->set_number('1148546')->is_valid_number, '東京都北区役所 滝野川分庁舎');
ok($zip->set_number('1148550')->is_valid_number, '東日本旅客鉄道 株式会社 首都圏本部');
ok($zip->set_number('1148552')->is_valid_number, '十條木材 株式会社');
ok($zip->set_number('1148553')->is_valid_number, 'サイタ工業 株式会社');
ok($zip->set_number('1148554')->is_valid_number, '学校法人 桜丘女子学園');
ok($zip->set_number('1148555')->is_valid_number, '日本製紙総合開発 株式会社');
ok($zip->set_number('1148557')->is_valid_number, '株式会社 東洋精機製作所');
ok($zip->set_number('1148560')->is_valid_number, '王子税務署');
ok($zip->set_number('1148561')->is_valid_number, '東京都立 飛鳥高等学校');
ok($zip->set_number('1148562')->is_valid_number, '川田工業 株式会社');
ok($zip->set_number('1148565')->is_valid_number, '海上自衛隊 需給統制隊');
ok($zip->set_number('1148571')->is_valid_number, '瀧野川信用金庫');
ok($zip->set_number('1148574')->is_valid_number, '学校法人聖学院 聖学院広報センター 女子聖学院中学校高等学校 聖学院小学校 聖学院幼稚園');
ok($zip->set_number('1148577')->is_valid_number, '株式会社 模範薬品研究所');
ok($zip->set_number('1148580')->is_valid_number, '東京外国語大学');
ok($zip->set_number('1148581')->is_valid_number, '株式会社 アドバネクス');
ok($zip->set_number('1148583')->is_valid_number, '株式会社 トンボ鉛筆');
ok($zip->set_number('1148584')->is_valid_number, '日本特殊塗料 株式会社');
ok($zip->set_number('1148585')->is_valid_number, 'コーセー化粧品販売 株式会社 東京支社');
ok($zip->set_number('1148588')->is_valid_number, '吉澤原動機 株式会社');
ok($zip->set_number('1148595')->is_valid_number, 'みどり生命保険 株式会社');
ok($zip->set_number('1148602')->is_valid_number, '株式会社 なとり 東京営業所');
ok($zip->set_number('1148603')->is_valid_number, '株式会社 全珍 東京営業所');
ok($zip->set_number('1148604')->is_valid_number, '株式会社 好好飲茶');
ok($zip->set_number('1148605')->is_valid_number, '株式会社 なとりデリカ');
ok($zip->set_number('1148606')->is_valid_number, '株式会社 なとり 食品総合ラボラトリー');
ok($zip->set_number('1148611')->is_valid_number, '株式会社 なとり');
ok($zip->set_number('1148686')->is_valid_number, '中央工学校 生涯学習センター');
ok($zip->set_number('1158001')->is_valid_number, '大日本印刷 株式会社');
ok($zip->set_number('1158510')->is_valid_number, '日本交通 株式会社 本社');
ok($zip->set_number('1158511')->is_valid_number, '株式会社 ディー・エヌ・ケー');
ok($zip->set_number('1158524')->is_valid_number, '学校法人 星美学園 短期大学、高等学校、中学校、小学校、幼稚園');
ok($zip->set_number('1158529')->is_valid_number, '株式会社 吉野家');
ok($zip->set_number('1158555')->is_valid_number, '三恵技研工業 株式会社');
ok($zip->set_number('1158585')->is_valid_number, '株式会社 DNPロジスティクス');
ok($zip->set_number('1158586')->is_valid_number, '東京都立産業技術研究所');
ok($zip->set_number('1158588')->is_valid_number, '日本化薬 株式会社 東京工場');
ok($zip->set_number('1158622')->is_valid_number, '浮間合成 株式会社');
ok($zip->set_number('1158650')->is_valid_number, '東洋大学 赤羽台キャンパス');
ok($zip->set_number('1158711')->is_valid_number, '大和証券 株式会社 赤羽支店');
ok($zip->set_number('1168501')->is_valid_number, '荒川区役所');
ok($zip->set_number('1168502')->is_valid_number, '荒川区保健所');
ok($zip->set_number('1168503')->is_valid_number, '株式会社 白興');
ok($zip->set_number('1168505')->is_valid_number, '三菱電機ビルテクノサービス 株式会社');
ok($zip->set_number('1168507')->is_valid_number, '荒川区がん予防・健康づくりセンター');
ok($zip->set_number('1168508')->is_valid_number, '株式会社 ヤマトメ');
ok($zip->set_number('1168521')->is_valid_number, '東京都水道局 荒川営業所');
ok($zip->set_number('1168522')->is_valid_number, '東京ガス 株式会社 東部事業本部');
ok($zip->set_number('1168523')->is_valid_number, '東京都立産業技術高等専門学校 荒川キャンパス');
ok($zip->set_number('1168524')->is_valid_number, '城信ビジネスサービス 株式会社');
ok($zip->set_number('1168532')->is_valid_number, '株式会社 タカイシ');
ok($zip->set_number('1168533')->is_valid_number, '東京シンコーレザー 株式会社');
ok($zip->set_number('1168537')->is_valid_number, '株式会社 エドウイン');
ok($zip->set_number('1168540')->is_valid_number, 'アイセック 株式会社');
ok($zip->set_number('1168541')->is_valid_number, '井関農機 株式会社');
ok($zip->set_number('1168543')->is_valid_number, '井嶋金銀工業 株式会社');
ok($zip->set_number('1168544')->is_valid_number, '株式会社 協和商事');
ok($zip->set_number('1168546')->is_valid_number, '株式会社 千代田');
ok($zip->set_number('1168548')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('1168549')->is_valid_number, '東栄産業 株式会社');
ok($zip->set_number('1168550')->is_valid_number, '東京電力ホールディングス 株式会社');
ok($zip->set_number('1168551')->is_valid_number, '東京都立医療技術短期大学');
ok($zip->set_number('1168552')->is_valid_number, '長島特殊塗料 株式会社');
ok($zip->set_number('1168553')->is_valid_number, '株式会社 ADEKA 尾久地区開発研究所');
ok($zip->set_number('1168554')->is_valid_number, '株式会社 ADEKA');
ok($zip->set_number('1168556')->is_valid_number, '高六商事 株式会社');
ok($zip->set_number('1168561')->is_valid_number, '日本アンテナ 株式会社');
ok($zip->set_number('1168562')->is_valid_number, '稲垣機材 株式会社');
ok($zip->set_number('1168567')->is_valid_number, '東京女子医科大学附属第二病院');
ok($zip->set_number('1168571')->is_valid_number, '株式会社 ウチダ和漢薬');
ok($zip->set_number('1168580')->is_valid_number, '(株) ダイナム');
ok($zip->set_number('1168581')->is_valid_number, '株式会社 サーベイリサーチセンター');
ok($zip->set_number('1168584')->is_valid_number, 'イセキ販売金融 株式会社');
ok($zip->set_number('1168585')->is_valid_number, '井島貴金属精錬 株式会社');
ok($zip->set_number('1168586')->is_valid_number, '荒川都税事務所');
ok($zip->set_number('1168587')->is_valid_number, 'クリナップ 株式会社');
ok($zip->set_number('1168588')->is_valid_number, '荒川税務署');
ok($zip->set_number('1168621')->is_valid_number, '株式会社 エスエスケイ');
ok($zip->set_number('1208501')->is_valid_number, '(株) 丸井 北千住店');
ok($zip->set_number('1208507')->is_valid_number, '東京電力 株式会社 東京支店上野支社足立営業センター');
ok($zip->set_number('1208510')->is_valid_number, '足立区役所');
ok($zip->set_number('1208512')->is_valid_number, '足立区役所 区民部 戸籍住民課');
ok($zip->set_number('1208520')->is_valid_number, '足立税務署');
ok($zip->set_number('1208526')->is_valid_number, '株式会社 タジマ');
ok($zip->set_number('1208528')->is_valid_number, '東京都立小台橋高等学校');
ok($zip->set_number('1208530')->is_valid_number, '足立公共職業安定所');
ok($zip->set_number('1208534')->is_valid_number, '一般財団法人 海外産業人材育成協会');
ok($zip->set_number('1208536')->is_valid_number, '株式会社 吉安本店');
ok($zip->set_number('1208539')->is_valid_number, '協和機工 株式会社');
ok($zip->set_number('1208544')->is_valid_number, '株式会社 丸愛');
ok($zip->set_number('1208550')->is_valid_number, '東京千住魚市場卸協同組合');
ok($zip->set_number('1208551')->is_valid_number, '学校法人 東京電機大学');
ok($zip->set_number('1208554')->is_valid_number, '株式会社 ルミネ 北千住店');
ok($zip->set_number('1208555')->is_valid_number, '千住金属工業 株式会社');
ok($zip->set_number('1208556')->is_valid_number, '大都魚類 株式会社 千住支社');
ok($zip->set_number('1208558')->is_valid_number, '東京北魚 株式会社');
ok($zip->set_number('1208570')->is_valid_number, '太陽生命保険 相互会社 千住支社');
ok($zip->set_number('1208575')->is_valid_number, '公益財団法人 足立区勤労福祉サービスセンター');
ok($zip->set_number('1208581')->is_valid_number, '株式会社 江戸一');
ok($zip->set_number('1208601')->is_valid_number, '株式会社 ニッピ');
ok($zip->set_number('1208602')->is_valid_number, '株式会社 ニッピコラーゲン化粧品');
ok($zip->set_number('1218080')->is_valid_number, '株式会社 トップアート');
ok($zip->set_number('1218504')->is_valid_number, '杉本興業 株式会社');
ok($zip->set_number('1218505')->is_valid_number, '日東燃料工業 (株)');
ok($zip->set_number('1218508')->is_valid_number, 'シチズンカスタマーサービス 株式会社');
ok($zip->set_number('1218510')->is_valid_number, '東京北足立市場青果卸売 協同組合');
ok($zip->set_number('1218512')->is_valid_number, '足立区足立福祉事務所');
ok($zip->set_number('1218515')->is_valid_number, '医療法人社団 成仁病院');
ok($zip->set_number('1218520')->is_valid_number, 'イワヤ (株)');
ok($zip->set_number('1218521')->is_valid_number, '株式会社 アローシステム開発');
ok($zip->set_number('1218550')->is_valid_number, '東京都水道局 足立東営業所');
ok($zip->set_number('1218555')->is_valid_number, '足立福祉事務所 北部福祉課');
ok($zip->set_number('1218577')->is_valid_number, '文教大学 東京あだちキャンパス');
ok($zip->set_number('1218585')->is_valid_number, '東京エコール 総合流通センター');
ok($zip->set_number('1218588')->is_valid_number, '東京千住青果 株式会社');
ok($zip->set_number('1218610')->is_valid_number, '加藤産業 株式会社 足立支店');
ok($zip->set_number('1218611')->is_valid_number, '株式会社 丸井スズキ');
ok($zip->set_number('1218633')->is_valid_number, '株式会社 サンエス');
ok($zip->set_number('1218639')->is_valid_number, '(株) 第一エレクトロニクス');
ok($zip->set_number('1218682')->is_valid_number, '(株) トップライン');
ok($zip->set_number('1218711')->is_valid_number, 'マスセット (株)');
ok($zip->set_number('1218729')->is_valid_number, 'シーエル商事 (株)');
ok($zip->set_number('1238501')->is_valid_number, '西新井税務署');
ok($zip->set_number('1238503')->is_valid_number, '森宮電機 株式会社');
ok($zip->set_number('1238505')->is_valid_number, '富双合成 株式会社');
ok($zip->set_number('1238506')->is_valid_number, '信州名鉄運輸 株式会社');
ok($zip->set_number('1238507')->is_valid_number, '株式会社 ハイロジック 東京支店');
ok($zip->set_number('1238508')->is_valid_number, 'イーダ 株式会社');
ok($zip->set_number('1238509')->is_valid_number, '株式会社 アベルコ');
ok($zip->set_number('1238511')->is_valid_number, '並木精密宝石 株式会社');
ok($zip->set_number('1238512')->is_valid_number, '東京都足立都税事務所');
ok($zip->set_number('1238514')->is_valid_number, '丸石自転車 株式会社 東京工場');
ok($zip->set_number('1238517')->is_valid_number, '水道局 足立西営業所');
ok($zip->set_number('1238540')->is_valid_number, '警視庁 西新井警察署');
ok($zip->set_number('1238558')->is_valid_number, '東京女子医科大学附属足立医療センター');
ok($zip->set_number('1238588')->is_valid_number, 'トークシステム 株式会社');
ok($zip->set_number('1248501')->is_valid_number, '東栄信用金庫');
ok($zip->set_number('1248502')->is_valid_number, '東京法務局 城北出張所');
ok($zip->set_number('1248503')->is_valid_number, '株式会社 国際貿易');
ok($zip->set_number('1248509')->is_valid_number, '松久 株式会社');
ok($zip->set_number('1248510')->is_valid_number, 'ミヨシ油脂 株式会社');
ok($zip->set_number('1248511')->is_valid_number, '株式会社 タカラトミー');
ok($zip->set_number('1248520')->is_valid_number, '東京都 葛飾都税事務所');
ok($zip->set_number('1248524')->is_valid_number, '葛飾商工信用組合');
ok($zip->set_number('1248530')->is_valid_number, '学校法人 東京聖栄大学');
ok($zip->set_number('1248533')->is_valid_number, '鬼怒川パシフィック 株式会社');
ok($zip->set_number('1248535')->is_valid_number, '大成化工 株式会社');
ok($zip->set_number('1248538')->is_valid_number, '辰巳屋興業 株式会社');
ok($zip->set_number('1248539')->is_valid_number, 'NTT葛飾');
ok($zip->set_number('1248550')->is_valid_number, '小里機材 株式会社');
ok($zip->set_number('1248555')->is_valid_number, '葛飾区役所');
ok($zip->set_number('1248560')->is_valid_number, '葛飾税務署');
ok($zip->set_number('1248577')->is_valid_number, '森永乳業 株式会社 東京工場');
ok($zip->set_number('1248585')->is_valid_number, '株式会社 バンダイロジパル');
ok($zip->set_number('1248588')->is_valid_number, 'カール事務器 株式会社');
ok($zip->set_number('1258503')->is_valid_number, '株式会社 タカラトミー');
ok($zip->set_number('1258504')->is_valid_number, '石徳螺子 株式会社');
ok($zip->set_number('1258505')->is_valid_number, '三和ニードルベアリング 株式会社');
ok($zip->set_number('1258506')->is_valid_number, '東京慈恵会 医科大学葛飾医療センター');
ok($zip->set_number('1258507')->is_valid_number, '修徳高等学校');
ok($zip->set_number('1258508')->is_valid_number, '亀有信用金庫');
ok($zip->set_number('1258511')->is_valid_number, 'アルフレッサ・ヘルスケア');
ok($zip->set_number('1258512')->is_valid_number, '(財) 東京都保健医療公社 東部地域病院');
ok($zip->set_number('1258513')->is_valid_number, '株式会社 ジョイフルまるやま');
ok($zip->set_number('1258514')->is_valid_number, '株式会社 京成ストア');
ok($zip->set_number('1258517')->is_valid_number, '京成不動産 株式会社');
ok($zip->set_number('1258520')->is_valid_number, '亀有病院');
ok($zip->set_number('1258522')->is_valid_number, '葛飾区東福祉サービスセンター');
ok($zip->set_number('1258526')->is_valid_number, '株式会社 三王商会');
ok($zip->set_number('1258585')->is_valid_number, '学校法人 東京理科大学');
ok($zip->set_number('1258588')->is_valid_number, '医療法人社団 玲瓏会 金町中央病院');
ok($zip->set_number('1258601')->is_valid_number, '三菱ガス化学 株式会社 東京研究所');
ok($zip->set_number('1308501')->is_valid_number, '株式会社 ハセガワ');
ok($zip->set_number('1308503')->is_valid_number, '株式会社 大和研材商会');
ok($zip->set_number('1308504')->is_valid_number, '株式会社 ロゴスコーポレーション');
ok($zip->set_number('1308505')->is_valid_number, '株式会社 新藤コーポレーション');
ok($zip->set_number('1308506')->is_valid_number, '株式会社 ミノウラ');
ok($zip->set_number('1308507')->is_valid_number, 'ヤバネスポーツ 株式会社');
ok($zip->set_number('1308508')->is_valid_number, 'ハクバ写真産業 株式会社');
ok($zip->set_number('1308509')->is_valid_number, '大東信用金庫');
ok($zip->set_number('1308510')->is_valid_number, '株式会社 ローズマダム');
ok($zip->set_number('1308511')->is_valid_number, '千代田管鉄 株式会社');
ok($zip->set_number('1308512')->is_valid_number, '石塚電子 株式会社');
ok($zip->set_number('1308513')->is_valid_number, '電気硝子建材 株式会社');
ok($zip->set_number('1308514')->is_valid_number, '東京文具 株式会社');
ok($zip->set_number('1308515')->is_valid_number, '助野靴下 株式会社 東京支店');
ok($zip->set_number('1308516')->is_valid_number, '株式会社 吉田製作所');
ok($zip->set_number('1308517')->is_valid_number, 'ツバメ石油 株式会社');
ok($zip->set_number('1308518')->is_valid_number, '株式会社 丸井 錦糸町店');
ok($zip->set_number('1308520')->is_valid_number, '渡辺パイプ 株式会社');
ok($zip->set_number('1308521')->is_valid_number, 'YKK AP 株式会社');
ok($zip->set_number('1308522')->is_valid_number, '坂田建設 株式会社');
ok($zip->set_number('1308525')->is_valid_number, 'ピップトウキョウ 株式会社 メディカル事業部');
ok($zip->set_number('1308528')->is_valid_number, 'ナイガイ 株式会社');
ok($zip->set_number('1308530')->is_valid_number, '岡部バルブ工業 株式会社');
ok($zip->set_number('1308531')->is_valid_number, '三井金属エンジニアリング 株式会社');
ok($zip->set_number('1308533')->is_valid_number, '協和自動車 株式会社');
ok($zip->set_number('1308534')->is_valid_number, '株式会社 サンヨー堂');
ok($zip->set_number('1308535')->is_valid_number, '株式会社 東京楽天地');
ok($zip->set_number('1308538')->is_valid_number, '近江屋写真用品 株式会社');
ok($zip->set_number('1308539')->is_valid_number, '国宝商事 株式会社');
ok($zip->set_number('1308543')->is_valid_number, '株式会社 昭電');
ok($zip->set_number('1308545')->is_valid_number, '東京東信用金庫');
ok($zip->set_number('1308546')->is_valid_number, 'さくらカード 株式会社');
ok($zip->set_number('1308548')->is_valid_number, '株式会社 セディナ');
ok($zip->set_number('1308553')->is_valid_number, '東京都金属プレス工業健康保険組合');
ok($zip->set_number('1308554')->is_valid_number, 'JMSA福祉企業年金基金');
ok($zip->set_number('1308555')->is_valid_number, '株式会社 ティムコ');
ok($zip->set_number('1308556')->is_valid_number, '日本電技 株式会社');
ok($zip->set_number('1308557')->is_valid_number, 'エイアイジー・スター生命保険 株式会社');
ok($zip->set_number('1308558')->is_valid_number, '株式会社 アイフルホームテクノロジー');
ok($zip->set_number('1308561')->is_valid_number, 'メットライフ生命保険 株式会社');
ok($zip->set_number('1308563')->is_valid_number, 'サンデン・リテールシステム 株式会社');
ok($zip->set_number('1308565')->is_valid_number, '学校法人 東京IT会計法律学園');
ok($zip->set_number('1308566')->is_valid_number, '大井工業 株式会社');
ok($zip->set_number('1308567')->is_valid_number, 'マルヤマエクセル 株式会社');
ok($zip->set_number('1308570')->is_valid_number, 'ロンシール工業 株式会社');
ok($zip->set_number('1308575')->is_valid_number, '東京都立墨東病院');
ok($zip->set_number('1308577')->is_valid_number, 'アカツキ商事 株式会社');
ok($zip->set_number('1308580')->is_valid_number, '株式会社 錦糸町ステーションビル');
ok($zip->set_number('1308583')->is_valid_number, 'エムシーエス債権管理回収 株式会社');
ok($zip->set_number('1308584')->is_valid_number, 'ライオンハイジーン 株式会社');
ok($zip->set_number('1308585')->is_valid_number, '一般財団法人 大蔵財務協会');
ok($zip->set_number('1308588')->is_valid_number, 'ダイオーミウラ 株式会社');
ok($zip->set_number('1308601')->is_valid_number, 'オーベクス 株式会社');
ok($zip->set_number('1308602')->is_valid_number, 'アサヒビール 株式会社');
ok($zip->set_number('1308603')->is_valid_number, '日本たばこ産業 株式会社 東京工場');
ok($zip->set_number('1308604')->is_valid_number, '石川玩具 株式会社');
ok($zip->set_number('1308605')->is_valid_number, '西武商事 株式会社');
ok($zip->set_number('1308606')->is_valid_number, '一般財団法人 自然環境研究センター');
ok($zip->set_number('1308608')->is_valid_number, '東京都墨田都税事務所');
ok($zip->set_number('1308609')->is_valid_number, '墨田 公共職業安定所');
ok($zip->set_number('1308611')->is_valid_number, '社団法人 日本玩具協会');
ok($zip->set_number('1308612')->is_valid_number, '向島労働基準監督署');
ok($zip->set_number('1308615')->is_valid_number, '安田学園');
ok($zip->set_number('1308625')->is_valid_number, 'AIGエジソン生命保険 株式会社');
ok($zip->set_number('1308633')->is_valid_number, '株式会社 報知新聞社');
ok($zip->set_number('1308636')->is_valid_number, '東京簡易裁判所 墨田庁舎');
ok($zip->set_number('1308637')->is_valid_number, '東京簡易裁判所 墨田庁舎');
ok($zip->set_number('1308640')->is_valid_number, '墨田区役所');
ok($zip->set_number('1308642')->is_valid_number, '田中商事 株式会社');
ok($zip->set_number('1308644')->is_valid_number, 'ライオン 株式会社');
ok($zip->set_number('1308650')->is_valid_number, '明治乳業 株式会社 東京支社');
ok($zip->set_number('1308655')->is_valid_number, '株式会社 三喜');
ok($zip->set_number('1308660')->is_valid_number, 'エイアイジー・スター生命保険 株式会社');
ok($zip->set_number('1308666')->is_valid_number, '株式会社 小森コーポレーション');
ok($zip->set_number('1308668')->is_valid_number, 'オキナ 株式会社');
ok($zip->set_number('1308671')->is_valid_number, 'クラヤ商事 株式会社');
ok($zip->set_number('1308677')->is_valid_number, 'ニコンカメラ販売 株式会社');
ok($zip->set_number('1308686')->is_valid_number, '本所税務署');
ok($zip->set_number('1308701')->is_valid_number, '株式会社 東京鋲兼');
ok($zip->set_number('1308706')->is_valid_number, '株式会社 ミドリ');
ok($zip->set_number('1308710')->is_valid_number, '東興商事 株式会社');
ok($zip->set_number('1308720')->is_valid_number, '株式会社 ヤマモリ');
ok($zip->set_number('1318139')->is_valid_number, '郵政博物館');
ok($zip->set_number('1318501')->is_valid_number, '花王 株式会社 すみだ事業所');
ok($zip->set_number('1318503')->is_valid_number, '東武商事 株式会社');
ok($zip->set_number('1318505')->is_valid_number, '岡部 株式会社');
ok($zip->set_number('1318507')->is_valid_number, '株式会社 久保商会');
ok($zip->set_number('1318508')->is_valid_number, '東武バス 株式会社');
ok($zip->set_number('1318509')->is_valid_number, '向島税務署');
ok($zip->set_number('1318510')->is_valid_number, '株式会社 大林組 東京本社 墨田事務所');
ok($zip->set_number('1318511')->is_valid_number, '株式会社 ハクタ商会');
ok($zip->set_number('1318512')->is_valid_number, '山下商事 株式会社');
ok($zip->set_number('1318513')->is_valid_number, 'カネボウ物流 株式会社 東京支店');
ok($zip->set_number('1318518')->is_valid_number, '杉本商事 株式会社 墨田営業所');
ok($zip->set_number('1318519')->is_valid_number, '株式会社 イナゲ');
ok($zip->set_number('1318520')->is_valid_number, 'ナガセケンコー 株式会社');
ok($zip->set_number('1318524')->is_valid_number, '東武谷内田建設 株式会社');
ok($zip->set_number('1318526')->is_valid_number, '株式会社 ときわ商会');
ok($zip->set_number('1318527')->is_valid_number, '丸源飲料工業 株式会社');
ok($zip->set_number('1318530')->is_valid_number, '東京東 信用金庫');
ok($zip->set_number('1318533')->is_valid_number, 'NECインフロンティア 株式会社 墨田事業所');
ok($zip->set_number('1318550')->is_valid_number, '東武ビルマネジメント 株式会社');
ok($zip->set_number('1318555')->is_valid_number, '京成電鉄 株式会社');
ok($zip->set_number('1318565')->is_valid_number, '株式会社 日本旅行 東日本営業本部');
ok($zip->set_number('1318584')->is_valid_number, '株式会社 ジェイコム東京 すみだ・台東局');
ok($zip->set_number('1318585')->is_valid_number, '小管 株式会社');
ok($zip->set_number('1318588')->is_valid_number, '株式会社 フタキ商事');
ok($zip->set_number('1318634')->is_valid_number, '東武タワースカイツリー 株式会社');
ok($zip->set_number('1318711')->is_valid_number, 'エヌティティテレマーケティング 株式会社');
ok($zip->set_number('1328501')->is_valid_number, '江戸川区役所');
ok($zip->set_number('1328503')->is_valid_number, '京和工業 (株)');
ok($zip->set_number('1328507')->is_valid_number, '江戸川保健所');
ok($zip->set_number('1328515')->is_valid_number, '株式会社 イー・ロジット 東京フルフィルメントセンター');
ok($zip->set_number('1328533')->is_valid_number, '株式会社 小松川プラスチックス');
ok($zip->set_number('1328550')->is_valid_number, '東京電力 株式会社 江東支店 江戸川営業センター');
ok($zip->set_number('1328551')->is_valid_number, '東京都江戸川都税事務所');
ok($zip->set_number('1328555')->is_valid_number, '株式会社 大同商会');
ok($zip->set_number('1328562')->is_valid_number, '(株) ホリゾン東テクノ');
ok($zip->set_number('1328567')->is_valid_number, '東京都水道局 江戸川営業所');
ok($zip->set_number('1328585')->is_valid_number, '東京法務局 江戸川出張所');
ok($zip->set_number('1328601')->is_valid_number, '東金属 株式会社');
ok($zip->set_number('1328666')->is_valid_number, '内宮運輸機工 株式会社');
ok($zip->set_number('1328668')->is_valid_number, '江戸川北税務署');
ok($zip->set_number('1328674')->is_valid_number, '一般社団法人 江戸川区医師会');
ok($zip->set_number('1328686')->is_valid_number, 'タイヘイ 株式会社');
ok($zip->set_number('1328688')->is_valid_number, '興伸');
ok($zip->set_number('1328711')->is_valid_number, '小松川信用金庫');
ok($zip->set_number('1328730')->is_valid_number, 'アイリス企画');
ok($zip->set_number('1328732')->is_valid_number, 'ネグロス電工 株式会社');
ok($zip->set_number('1328739')->is_valid_number, 'スピーディ');
ok($zip->set_number('1338501')->is_valid_number, 'エステイワイ工業 株式会社');
ok($zip->set_number('1338511')->is_valid_number, '王子製紙 (株) 江戸川工場');
ok($zip->set_number('1338552')->is_valid_number, '学校法人 江戸川学園 江戸川女子中学校 江戸川女子高等学校');
ok($zip->set_number('1338553')->is_valid_number, '株式会社 丸昌 小岩店');
ok($zip->set_number('1338558')->is_valid_number, '株式会社 タカノスマイル');
ok($zip->set_number('1338580')->is_valid_number, '王子パッケージング (株)');
ok($zip->set_number('1338585')->is_valid_number, '学校法人 愛国学園');
ok($zip->set_number('1338704')->is_valid_number, '野村証券 株式会社 小岩支店');
ok($zip->set_number('1338706')->is_valid_number, '株式会社 興伸デリバリーセンター モンダミン係');
ok($zip->set_number('1348502')->is_valid_number, '株式会社 白子');
ok($zip->set_number('1348503')->is_valid_number, 'スターツ 株式会社');
ok($zip->set_number('1348507')->is_valid_number, '(株) ノニ21');
ok($zip->set_number('1348515')->is_valid_number, 'スターツデベロップメント 株式会社');
ok($zip->set_number('1348520')->is_valid_number, '月島食品工業 株式会社');
ok($zip->set_number('1348533')->is_valid_number, '日本ロール製造 株式会社');
ok($zip->set_number('1348555')->is_valid_number, '東京都立葛西南高等学校');
ok($zip->set_number('1348570')->is_valid_number, 'センコー 株式会社');
ok($zip->set_number('1348575')->is_valid_number, 'イプソス 株式会社');
ok($zip->set_number('1348576')->is_valid_number, 'バニーコルアート 株式会社');
ok($zip->set_number('1348577')->is_valid_number, '株式会社 ユー・エス・エス');
ok($zip->set_number('1348585')->is_valid_number, '株式会社 アテナ');
ok($zip->set_number('1348586')->is_valid_number, '株式会社 マリモクラフト');
ok($zip->set_number('1348587')->is_valid_number, '東京都葛西臨海水族園');
ok($zip->set_number('1348588')->is_valid_number, 'アドレス通商 株式会社');
ok($zip->set_number('1348601')->is_valid_number, '江戸川区スポーツセンター');
ok($zip->set_number('1348602')->is_valid_number, '株式会社 ニチベイパーツ');
ok($zip->set_number('1348603')->is_valid_number, 'ジャスコ 株式会社 葛西店');
ok($zip->set_number('1348609')->is_valid_number, 'みずほ情報総研 (株)');
ok($zip->set_number('1348610')->is_valid_number, 'NTT データ通信 株式会社');
ok($zip->set_number('1348612')->is_valid_number, '山一興産 株式会社');
ok($zip->set_number('1348622')->is_valid_number, '懸賞TV 株式会社');
ok($zip->set_number('1348630')->is_valid_number, '第一三共 株式会社 葛西研究開発センター');
ok($zip->set_number('1348631')->is_valid_number, '丸泰土木 株式会社');
ok($zip->set_number('1348640')->is_valid_number, 'カツデン 株式会社');
ok($zip->set_number('1348642')->is_valid_number, '株式会社 ライト');
ok($zip->set_number('1348686')->is_valid_number, '株式会社 リケン');
ok($zip->set_number('1348702')->is_valid_number, '(株) 三井住友銀行 葛西支店');
ok($zip->set_number('1358074')->is_valid_number, '昭和シェル石油 株式会社');
ok($zip->set_number('1358080')->is_valid_number, '株式会社 WOWOW 放送センター');
ok($zip->set_number('1358108')->is_valid_number, '中央魚類 株式会社');
ok($zip->set_number('1358109')->is_valid_number, '大都魚類 株式会社');
ok($zip->set_number('1358110')->is_valid_number, 'SCSK 株式会社');
ok($zip->set_number('1358111')->is_valid_number, '株式会社 ミライト・ワン');
ok($zip->set_number('1358114')->is_valid_number, '築地魚市場 株式会社');
ok($zip->set_number('1358115')->is_valid_number, '明星電気 株式会社');
ok($zip->set_number('1358118')->is_valid_number, '株式会社 博報堂コネクト');
ok($zip->set_number('1358121')->is_valid_number, '丸千千代田水産 株式会社');
ok($zip->set_number('1358130')->is_valid_number, '第一水産 株式会社');
ok($zip->set_number('1358134')->is_valid_number, '東都水産 株式会社');
ok($zip->set_number('1358137')->is_valid_number, '株式会社 PHP研究所');
ok($zip->set_number('1358139')->is_valid_number, '芝浦工業大学附属中学高等学校');
ok($zip->set_number('1358145')->is_valid_number, '株式会社 ミキモト');
ok($zip->set_number('1358150')->is_valid_number, '株式会社 中央コンピュータシステム');
ok($zip->set_number('1358165')->is_valid_number, '株式会社 JTBパブリッシング');
ok($zip->set_number('1358178')->is_valid_number, 'エヌ・ティ・ティ・データ・カスタマサービス 株式会社');
ok($zip->set_number('1358180')->is_valid_number, '株式会社 ワールドサプライ');
ok($zip->set_number('1358181')->is_valid_number, '学校法人 武蔵野大学 法人本部(有明キャンパス)');
ok($zip->set_number('1358210')->is_valid_number, '株式会社 レナウン');
ok($zip->set_number('1358222')->is_valid_number, '大樹生命保険 株式会社');
ok($zip->set_number('1358224')->is_valid_number, 'アスクル DCM 物流センター');
ok($zip->set_number('1358301')->is_valid_number, '株式会社 レイメイ藤井');
ok($zip->set_number('1358303')->is_valid_number, '株式会社 シモダ');
ok($zip->set_number('1358306')->is_valid_number, '東京製綱 株式会社');
ok($zip->set_number('1358308')->is_valid_number, 'クラブツーリズム 株式会社');
ok($zip->set_number('1358310')->is_valid_number, '小浅商事 株式会社 東京支店');
ok($zip->set_number('1358311')->is_valid_number, '江東西税務署');
ok($zip->set_number('1358312')->is_valid_number, 'セーラー万年筆 (株)');
ok($zip->set_number('1358318')->is_valid_number, '印刷製本包装機械健康保険組合');
ok($zip->set_number('1358320')->is_valid_number, '全国信用協同組合連合会 別館');
ok($zip->set_number('1358330')->is_valid_number, '栄進物産 株式会社');
ok($zip->set_number('1358331')->is_valid_number, '株式会社 イヨベ工芸社');
ok($zip->set_number('1358350')->is_valid_number, '(株) 東京クラウン');
ok($zip->set_number('1358360')->is_valid_number, '株式会社 紅三');
ok($zip->set_number('1358362')->is_valid_number, '株式会社 日立オートサービス');
ok($zip->set_number('1358363')->is_valid_number, 'センクシア 株式会社');
ok($zip->set_number('1358370')->is_valid_number, 'リコーテクノネット 株式会社 東京本社');
ok($zip->set_number('1358375')->is_valid_number, '関東森林管理局 東京事務所');
ok($zip->set_number('1358383')->is_valid_number, '東京都江東区役所');
ok($zip->set_number('1358384')->is_valid_number, '日本ボールドウィン 株式会社');
ok($zip->set_number('1358385')->is_valid_number, '明治安田システム・テクノロジー 株式会社 MBS事業部門');
ok($zip->set_number('1358387')->is_valid_number, '神鋼電機 (株)');
ok($zip->set_number('1358402')->is_valid_number, '株式会社 ザ マイラ');
ok($zip->set_number('1358404')->is_valid_number, '学校法人 中村学園');
ok($zip->set_number('1358411')->is_valid_number, '岩野物産 株式会社');
ok($zip->set_number('1358415')->is_valid_number, '株式会社 レオテックス');
ok($zip->set_number('1358422')->is_valid_number, '株式会社 日立東サービスエンジニアリング 本社');
ok($zip->set_number('1358427')->is_valid_number, '日本空調サービス 株式会社');
ok($zip->set_number('1358430')->is_valid_number, '日本プレシジョン・サーキッツ 株式会社');
ok($zip->set_number('1358432')->is_valid_number, '株式会社 マサル');
ok($zip->set_number('1358436')->is_valid_number, '株式会社 ヤマタネ 情報本部');
ok($zip->set_number('1358440')->is_valid_number, '江東オール印刷 株式会社');
ok($zip->set_number('1358443')->is_valid_number, '社団法人 日本倉庫協会');
ok($zip->set_number('1358445')->is_valid_number, '旭硝子保険マネジメント 株式会社');
ok($zip->set_number('1358448')->is_valid_number, '東京アール・ビー商事 株式会社');
ok($zip->set_number('1358451')->is_valid_number, '株式会社 JPビジネスサービス');
ok($zip->set_number('1358458')->is_valid_number, '(株) ミスミ');
ok($zip->set_number('1358460')->is_valid_number, '株式会社 大和総研 本社');
ok($zip->set_number('1358461')->is_valid_number, '株式会社 大和総研 東京センター');
ok($zip->set_number('1358464')->is_valid_number, '一般財団法人 グリーンチャンネル');
ok($zip->set_number('1358470')->is_valid_number, '株式会社 レナウン');
ok($zip->set_number('1358473')->is_valid_number, '財団法人 未来工学研究所');
ok($zip->set_number('1358477')->is_valid_number, '日本中央競馬会 電話投票センター');
ok($zip->set_number('1358480')->is_valid_number, '株式会社 ムトウユニパック');
ok($zip->set_number('1358481')->is_valid_number, '東京倉庫協会');
ok($zip->set_number('1358482')->is_valid_number, '株式会社 前川製作所');
ok($zip->set_number('1358501')->is_valid_number, '株式会社 ヤマタネ');
ok($zip->set_number('1358502')->is_valid_number, '株式会社 東芝パーソナル&クライアントソリューション社');
ok($zip->set_number('1358504')->is_valid_number, '株式会社 ユニパック・ダイレクト');
ok($zip->set_number('1358505')->is_valid_number, 'Dynabook 株式会社');
ok($zip->set_number('1358508')->is_valid_number, 'オーク 株式会社');
ok($zip->set_number('1358510')->is_valid_number, '大丸コアビル');
ok($zip->set_number('1358511')->is_valid_number, '日本アイ・ビー・エム 株式会社 豊洲事業所');
ok($zip->set_number('1358512')->is_valid_number, '株式会社 フジクラ');
ok($zip->set_number('1358513')->is_valid_number, '澁澤倉庫 株式会社');
ok($zip->set_number('1358514')->is_valid_number, 'アーバンドック ららぽーと豊洲アネックス');
ok($zip->set_number('1358517')->is_valid_number, '(株) スポーツニッポン新聞 東京本社');
ok($zip->set_number('1358518')->is_valid_number, 'リコーリース 株式会社');
ok($zip->set_number('1358521')->is_valid_number, '日本赤十字社 血液事業本部 辰巳分室');
ok($zip->set_number('1358522')->is_valid_number, '株式会社 芳賀洋紙店');
ok($zip->set_number('1358523')->is_valid_number, '日本赤十字社 血液事業本部 中央骨髄データセンター');
ok($zip->set_number('1358525')->is_valid_number, 'フジコピアン 株式会社 東京支店');
ok($zip->set_number('1358527')->is_valid_number, '株式会社 OCS');
ok($zip->set_number('1358528')->is_valid_number, '昭和リース 株式会社');
ok($zip->set_number('1358530')->is_valid_number, '清水建設 (株) 技術研究所 管理部');
ok($zip->set_number('1358531')->is_valid_number, '株式会社 トラベルプラザインターナショナル');
ok($zip->set_number('1358532')->is_valid_number, '日興ビジネスシステムズ 株式会社');
ok($zip->set_number('1358533')->is_valid_number, '東京海洋大学');
ok($zip->set_number('1358535')->is_valid_number, '(株) 長谷川萬治商店');
ok($zip->set_number('1358538')->is_valid_number, '財団法人 全日本空手道連盟');
ok($zip->set_number('1358548')->is_valid_number, '芝浦工業大学');
ok($zip->set_number('1358550')->is_valid_number, '公益財団法人 がん研究会');
ok($zip->set_number('1358551')->is_valid_number, 'UDトラックス 株式会社');
ok($zip->set_number('1358552')->is_valid_number, '日本衛星放送 (株) WOWOW');
ok($zip->set_number('1358553')->is_valid_number, '日新製糖 株式会社 余暇開発本部 ドゥ・スポーツプラザ晴海');
ok($zip->set_number('1358554')->is_valid_number, '日本電子計算 株式会社');
ok($zip->set_number('1358555')->is_valid_number, '株式会社 タキネット');
ok($zip->set_number('1358556')->is_valid_number, '(株) 東京宇佐美');
ok($zip->set_number('1358557')->is_valid_number, 'セイコークロック 株式会社');
ok($zip->set_number('1358558')->is_valid_number, '王子製紙 株式会社 東雲研究センター');
ok($zip->set_number('1358559')->is_valid_number, 'TD SYNNEX 株式会社');
ok($zip->set_number('1358560')->is_valid_number, 'BIPROGY 株式会社');
ok($zip->set_number('1358563')->is_valid_number, '六三印刷 株式会社');
ok($zip->set_number('1358565')->is_valid_number, 'カテナ (株)');
ok($zip->set_number('1358566')->is_valid_number, 'デイリースポーツ社');
ok($zip->set_number('1358567')->is_valid_number, '株式会社 久米設計');
ok($zip->set_number('1358568')->is_valid_number, '日本オフィス・システム 株式会社');
ok($zip->set_number('1358570')->is_valid_number, '日新製糖 株式会社 豊洲工場');
ok($zip->set_number('1358575')->is_valid_number, '株式会社 ペイロール');
ok($zip->set_number('1358577')->is_valid_number, '昭和大学江東豊洲病院');
ok($zip->set_number('1358578')->is_valid_number, '太平洋セメント 株式会社');
ok($zip->set_number('1358579')->is_valid_number, '株式会社 ナカノ 東京支店');
ok($zip->set_number('1358581')->is_valid_number, '株式会社 りそな銀行');
ok($zip->set_number('1358582')->is_valid_number, '株式会社 りそなホールディングス');
ok($zip->set_number('1358585')->is_valid_number, '宗教法人 カトリック中央協議会');
ok($zip->set_number('1358587')->is_valid_number, '財団法人 日本海事科学振興財団');
ok($zip->set_number('1358602')->is_valid_number, '株式会社 アイアイジェイフィナンシャルシステムズ');
ok($zip->set_number('1358608')->is_valid_number, 'マルハニチロ 株式会社');
ok($zip->set_number('1358610')->is_valid_number, 'セイコータイムクリエーション 株式会社');
ok($zip->set_number('1358611')->is_valid_number, 'アクサ損害保険 株式会社');
ok($zip->set_number('1358614')->is_valid_number, 'アーバンドック ららぽーと豊洲');
ok($zip->set_number('1358615')->is_valid_number, '東京税関');
ok($zip->set_number('1358616')->is_valid_number, '株式会社 博報堂DYホールディングス');
ok($zip->set_number('1358617')->is_valid_number, '株式会社 博報堂DYアイ・オー');
ok($zip->set_number('1358618')->is_valid_number, '株式会社 博報堂DYトータルサポート');
ok($zip->set_number('1358619')->is_valid_number, '株式会社 博報堂プロダクツ');
ok($zip->set_number('1358620')->is_valid_number, '株式会社 博報堂アドダム');
ok($zip->set_number('1358621')->is_valid_number, '株式会社 博報堂アイ・スタジオ');
ok($zip->set_number('1358622')->is_valid_number, '株式会社 乃村工藝社');
ok($zip->set_number('1358625')->is_valid_number, '株式会社 東京ヒューマニアエンタプライズ');
ok($zip->set_number('1358630')->is_valid_number, '国際研究交流大学村 東京国際交流館');
ok($zip->set_number('1358631')->is_valid_number, 'サントリー 株式会社');
ok($zip->set_number('1358632')->is_valid_number, 'サントリーフーズ 株式会社');
ok($zip->set_number('1358639')->is_valid_number, '東京都赤十字血液センター');
ok($zip->set_number('1358639')->is_valid_number, '日本赤十字社 関東甲信越ブロック血液センター');
ok($zip->set_number('1358650')->is_valid_number, 'ソフトバンクテレコム 株式会社');
ok($zip->set_number('1358655')->is_valid_number, '日商岩井 株式会社');
ok($zip->set_number('1358659')->is_valid_number, '株式会社 コックス');
ok($zip->set_number('1358661')->is_valid_number, '日本テレコムIDC 株式会社');
ok($zip->set_number('1358666')->is_valid_number, '日本ベニア 株式会社 東京営業所');
ok($zip->set_number('1358668')->is_valid_number, '株式会社 ジェイ・スポーツ');
ok($zip->set_number('1358670')->is_valid_number, '株式会社 システムソフト 東京センター');
ok($zip->set_number('1358677')->is_valid_number, '株式会社 NTTデータ・スマートソーシング');
ok($zip->set_number('1358678')->is_valid_number, '株式会社 NTTデータSMS');
ok($zip->set_number('1358686')->is_valid_number, '富士通エフ・アイ・ピー 株式会社');
ok($zip->set_number('1358701')->is_valid_number, 'グランドニッコー東京 台場');
ok($zip->set_number('1358707')->is_valid_number, 'アクアシティお台場');
ok($zip->set_number('1358710')->is_valid_number, '株式会社 IHI');
ok($zip->set_number('1358711')->is_valid_number, 'かえつ有明中学校・かえつ有明高等学校');
ok($zip->set_number('1358717')->is_valid_number, '株式会社 オートバックスセブン');
ok($zip->set_number('1358718')->is_valid_number, 'メディアージュ');
ok($zip->set_number('1358720')->is_valid_number, '明治生命保険相互会社');
ok($zip->set_number('1358721')->is_valid_number, '東京スポーツ新聞社');
ok($zip->set_number('1358722')->is_valid_number, 'みずほ信託銀行 株式会社 証券代行部');
ok($zip->set_number('1358723')->is_valid_number, 'みずほ信託銀行 株式会社 事務推進部');
ok($zip->set_number('1358727')->is_valid_number, 'みずほ信託銀行 株式会社 トラスト事務センター');
ok($zip->set_number('1358730')->is_valid_number, '株式会社 内田洋行');
ok($zip->set_number('1358731')->is_valid_number, '石川島播磨重工業 株式会社 東京第一工場');
ok($zip->set_number('1358732')->is_valid_number, '石川島播磨重工業 株式会社 東二テクニカルセンター');
ok($zip->set_number('1358733')->is_valid_number, '石川島播磨重工業 株式会社 豊洲総合事務所');
ok($zip->set_number('1358797')->is_valid_number, '日本郵便 株式会社 東京支社');
ok($zip->set_number('1368405')->is_valid_number, 'JKホールディングス 株式会社');
ok($zip->set_number('1368501')->is_valid_number, '川鉄建材');
ok($zip->set_number('1368502')->is_valid_number, '三洋工業');
ok($zip->set_number('1368505')->is_valid_number, '江東東税務署');
ok($zip->set_number('1368507')->is_valid_number, '翼システム');
ok($zip->set_number('1368512')->is_valid_number, 'セイコーインスツルメンツ 株式会社');
ok($zip->set_number('1368513')->is_valid_number, '亀戸労働基準監督署');
ok($zip->set_number('1368515')->is_valid_number, '日本化学工業 株式会社');
ok($zip->set_number('1368517')->is_valid_number, '大末建設 株式会社');
ok($zip->set_number('1368521')->is_valid_number, 'ヤマト特殊鋼 株式会社');
ok($zip->set_number('1368522')->is_valid_number, 'サンコーコンサルタント 株式会社');
ok($zip->set_number('1368523')->is_valid_number, 'みずほ信託銀行 株式会社');
ok($zip->set_number('1368525')->is_valid_number, '日本年金機構 江東年金事務所');
ok($zip->set_number('1368531')->is_valid_number, '吉野工業所');
ok($zip->set_number('1368533')->is_valid_number, '江東都税事務所');
ok($zip->set_number('1368535')->is_valid_number, '株式会社 LIXIL WINGビル');
ok($zip->set_number('1368540')->is_valid_number, '昭電');
ok($zip->set_number('1368543')->is_valid_number, '物林 株式会社');
ok($zip->set_number('1368550')->is_valid_number, '多田建設 株式会社');
ok($zip->set_number('1368555')->is_valid_number, '日本レジャーカードシステム 株式会社');
ok($zip->set_number('1368556')->is_valid_number, 'Bizex 新木場センター');
ok($zip->set_number('1368560')->is_valid_number, '日本テレコム 株式会社');
ok($zip->set_number('1368567')->is_valid_number, '三和紙業 株式会社');
ok($zip->set_number('1368570')->is_valid_number, '株式会社 竹中土木');
ok($zip->set_number('1368575')->is_valid_number, '株式会社 ぎょうせい');
ok($zip->set_number('1368577')->is_valid_number, '基礎地盤コンサルタンツ 株式会社');
ok($zip->set_number('1368580')->is_valid_number, '丸文 株式会社 南砂事業所');
ok($zip->set_number('1368581')->is_valid_number, '(株) CRC総合研究所');
ok($zip->set_number('1368585')->is_valid_number, 'アシックスジャパン 株式会社');
ok($zip->set_number('1368588')->is_valid_number, '川崎重工業 株式会社 東京設計事務所');
ok($zip->set_number('1368589')->is_valid_number, '株式会社 志正堂');
ok($zip->set_number('1368603')->is_valid_number, '(株) 徳間書店');
ok($zip->set_number('1368605')->is_valid_number, '株式会社 銘林');
ok($zip->set_number('1368607')->is_valid_number, '内田食品 株式会社');
ok($zip->set_number('1368608')->is_valid_number, 'NECソリューションイノベータ 株式会社');
ok($zip->set_number('1368612')->is_valid_number, '東京集成材工業 株式会社 東京営業所');
ok($zip->set_number('1368615')->is_valid_number, '株式会社 もくもく');
ok($zip->set_number('1368620')->is_valid_number, 'ヤバネスポーツ 株式会社');
ok($zip->set_number('1368622')->is_valid_number, '兼松日産農林 株式会社');
ok($zip->set_number('1368626')->is_valid_number, '株式会社 西林');
ok($zip->set_number('1368627')->is_valid_number, 'NECソリューションイノベータ 株式会社');
ok($zip->set_number('1368630')->is_valid_number, '江戸川木材工業 株式会社');
ok($zip->set_number('1368631')->is_valid_number, 'オルガノ 株式会社');
ok($zip->set_number('1368635')->is_valid_number, 'JST 株式会社');
ok($zip->set_number('1368637')->is_valid_number, '株式会社 インテック');
ok($zip->set_number('1368640')->is_valid_number, '株式会社 日本デジタル研究所');
ok($zip->set_number('1368648')->is_valid_number, '株式会社 IHI 砂町工場');
ok($zip->set_number('1368651')->is_valid_number, 'Xフロンティア');
ok($zip->set_number('1368666')->is_valid_number, 'トーヨーカネツ 株式会社');
ok($zip->set_number('1368666')->is_valid_number, 'トーヨーカネツソリューションズ 株式会社');
ok($zip->set_number('1368668')->is_valid_number, 'マルゼン商事 株式会社');
ok($zip->set_number('1368670')->is_valid_number, 'パラマウントベッド 株式会社');
ok($zip->set_number('1368671')->is_valid_number, 'パラマウントベッドホールディングス 株式会社');
ok($zip->set_number('1368675')->is_valid_number, 'ヤマトシステム開発 株式会社');
ok($zip->set_number('1368677')->is_valid_number, 'みずほ信託銀行 トラスト事務センター');
ok($zip->set_number('1368680')->is_valid_number, '株式会社 ビームスホールディングス ビームストランスファーセンター');
ok($zip->set_number('1368686')->is_valid_number, '株式会社 三越伊勢丹通信販売');
ok($zip->set_number('1368711')->is_valid_number, '日本ヒューレット・パッカード 株式会社');
ok($zip->set_number('1368723')->is_valid_number, '株式会社 東京ダンケ');
ok($zip->set_number('1368733')->is_valid_number, '日鉄商事 株式会社');
ok($zip->set_number('1368880')->is_valid_number, '株式会社 鴻池組');
ok($zip->set_number('1368888')->is_valid_number, '佐川急便 株式会社 東京本社');
ok($zip->set_number('1368908')->is_valid_number, '株式会社 明治');
ok($zip->set_number('1378081')->is_valid_number, '三菱UFJ信託銀行 株式会社 証券代行部');
ok($zip->set_number('1378088')->is_valid_number, '株式会社 フジテレビジョン');
ok($zip->set_number('1378581')->is_valid_number, '株式会社 郵便局物販サービス');
ok($zip->set_number('1378623')->is_valid_number, '北三 株式会社');
ok($zip->set_number('1378686')->is_valid_number, '株式会社 ニッポン放送');
ok($zip->set_number('1408502')->is_valid_number, '日立電子サービス 株式会社 システム事業本部');
ok($zip->set_number('1408503')->is_valid_number, '株式会社 日本理化工業所');
ok($zip->set_number('1408505')->is_valid_number, '(株)ニコン');
ok($zip->set_number('1408506')->is_valid_number, '三菱総研DCS 株式会社');
ok($zip->set_number('1408507')->is_valid_number, '米山紙商事 株式会社');
ok($zip->set_number('1408508')->is_valid_number, '富士通 (株) 大井町ビル');
ok($zip->set_number('1408509')->is_valid_number, '日本サブウェイ 合同会社');
ok($zip->set_number('1408511')->is_valid_number, '株式会社 ニッセイコム');
ok($zip->set_number('1408512')->is_valid_number, '株式会社 日立製作所 情報・通信システム社');
ok($zip->set_number('1408515')->is_valid_number, '大成温調 株式会社');
ok($zip->set_number('1408516')->is_valid_number, 'フクビ化学工業');
ok($zip->set_number('1408521')->is_valid_number, '前田硝子 株式会社');
ok($zip->set_number('1408522')->is_valid_number, '医療法人社団緑野会 東京品川病院');
ok($zip->set_number('1408523')->is_valid_number, '日産プリンス東京販売 株式会社');
ok($zip->set_number('1408525')->is_valid_number, 'ドウシシャ 東京本社');
ok($zip->set_number('1408526')->is_valid_number, 'キヤノンMJアイティグループホールディングス 株式会社');
ok($zip->set_number('1408529')->is_valid_number, 'プリマハム (株)');
ok($zip->set_number('1408530')->is_valid_number, 'シンワ 株式会社');
ok($zip->set_number('1408531')->is_valid_number, '光文工業 株式会社');
ok($zip->set_number('1408533')->is_valid_number, '株式会社 理研オプテック');
ok($zip->set_number('1408536')->is_valid_number, '株式会社 東京書芸館');
ok($zip->set_number('1408537')->is_valid_number, '三菱鉛筆 株式会社');
ok($zip->set_number('1408538')->is_valid_number, '株式会社 加藤製作所');
ok($zip->set_number('1408539')->is_valid_number, '三愛石油');
ok($zip->set_number('1408540')->is_valid_number, '株式会社 シンクロン');
ok($zip->set_number('1408541')->is_valid_number, 'ハイデルベルグ・ジャパン 株式会社');
ok($zip->set_number('1408543')->is_valid_number, '田中商事 株式会社');
ok($zip->set_number('1408547')->is_valid_number, 'インターワイヤード 株式会社');
ok($zip->set_number('1408548')->is_valid_number, '企業年金ビジネスサービス 株式会社');
ok($zip->set_number('1408549')->is_valid_number, '企業年金ビジネスサービス 株式会社');
ok($zip->set_number('1408551')->is_valid_number, '平河ヒューテック 株式会社');
ok($zip->set_number('1408552')->is_valid_number, '下田工業 株式会社 東京支社');
ok($zip->set_number('1408554')->is_valid_number, '株式会社 GSTV');
ok($zip->set_number('1408558')->is_valid_number, '株式会社 竹虎');
ok($zip->set_number('1408560')->is_valid_number, '(株) 東京測器研究所');
ok($zip->set_number('1408563')->is_valid_number, 'ニッサン・モータースポーツ・インターナショナル 株式会社');
ok($zip->set_number('1408566')->is_valid_number, 'サンワサプライ (株) 東京サプライセンター');
ok($zip->set_number('1408567')->is_valid_number, '富士通サポートアンドサービス 株式会社');
ok($zip->set_number('1408571')->is_valid_number, '株式会社 日平トヤマ');
ok($zip->set_number('1408572')->is_valid_number, '株式会社 日立製作所 情報・通信グループ');
ok($zip->set_number('1408573')->is_valid_number, '株式会社 日立製作所 情報・通信グループ');
ok($zip->set_number('1408574')->is_valid_number, '株式会社 日立製作所デジタルシステム&サービス統括本部');
ok($zip->set_number('1408576')->is_valid_number, '(株) ロキテクノ');
ok($zip->set_number('1408580')->is_valid_number, 'テクノレント 株式会社');
ok($zip->set_number('1408583')->is_valid_number, '株式会社 セガ');
ok($zip->set_number('1408584')->is_valid_number, 'ジャックス債権回収サービス 株式会社');
ok($zip->set_number('1408586')->is_valid_number, '富士通コンポーネント 株式会社');
ok($zip->set_number('1408590')->is_valid_number, '株式会社 バンダイナムコゲームス');
ok($zip->set_number('1408601')->is_valid_number, '(株) ニコン大井製作所');
ok($zip->set_number('1408602')->is_valid_number, 'JTB');
ok($zip->set_number('1408611')->is_valid_number, '株式会社 サンゲツ 東京店');
ok($zip->set_number('1408614')->is_valid_number, '株式会社 コスモトレード&サービス');
ok($zip->set_number('1408615')->is_valid_number, '寺田倉庫 株式会社');
ok($zip->set_number('1408616')->is_valid_number, 'ベークライト商事 株式会社');
ok($zip->set_number('1408617')->is_valid_number, 'ダウ・ケミカル日本 株式会社');
ok($zip->set_number('1408619')->is_valid_number, '株式会社 アクセス国際ネットワーク');
ok($zip->set_number('1408621')->is_valid_number, 'ネットワンシステムズ 株式会社');
ok($zip->set_number('1408623')->is_valid_number, '富士通 株式会社 (東京MIビル)');
ok($zip->set_number('1408625')->is_valid_number, 'JAL マイレージバンク日本地区会員事務局');
ok($zip->set_number('1408626')->is_valid_number, 'アイ・シー・アイ・ジャパン 株式会社');
ok($zip->set_number('1408628')->is_valid_number, '日本軽金属');
ok($zip->set_number('1408630')->is_valid_number, '株式会社 UEX');
ok($zip->set_number('1408631')->is_valid_number, '株式会社 ナイキジャパン');
ok($zip->set_number('1408634')->is_valid_number, '日軽産業 株式会社');
ok($zip->set_number('1408637')->is_valid_number, '日本航空 株式会社');
ok($zip->set_number('1408640')->is_valid_number, '東芝ライテック');
ok($zip->set_number('1408644')->is_valid_number, '株式会社 東機貿 天王州オフィス');
ok($zip->set_number('1408650')->is_valid_number, 'キヤノンシステムアンドサポート 株式会社');
ok($zip->set_number('1408653')->is_valid_number, '株式会社 ジャルキャピタル');
ok($zip->set_number('1408654')->is_valid_number, 'ソニーネットワークコミュニケーションズ 株式会社');
ok($zip->set_number('1408655')->is_valid_number, '(株) リコー システムセンター');
ok($zip->set_number('1408656')->is_valid_number, '株式会社 ジャルカード');
ok($zip->set_number('1408658')->is_valid_number, '株式会社 ジャルパック');
ok($zip->set_number('1408660')->is_valid_number, '東芝ライテック');
ok($zip->set_number('1408661')->is_valid_number, '(株) 恒陽社印刷');
ok($zip->set_number('1408663')->is_valid_number, 'AOI TYO Holdings 株式会社');
ok($zip->set_number('1408666')->is_valid_number, '(株) 日光商会');
ok($zip->set_number('1408668')->is_valid_number, '山岸塗装 株式会社 本社');
ok($zip->set_number('1408669')->is_valid_number, '三和テッキ 株式会社');
ok($zip->set_number('1408670')->is_valid_number, '東洋紙業 株式会社 東京本社');
ok($zip->set_number('1408672')->is_valid_number, '株式会社 シミズシンテック 東京支店');
ok($zip->set_number('1408675')->is_valid_number, '日本ペイント・インダストリアルコーティングス 株式会社');
ok($zip->set_number('1408675')->is_valid_number, '日本ペイント・オートモーティブコーティングス 株式会社');
ok($zip->set_number('1408675')->is_valid_number, '日本ペイント・サーフケミカルズ 株式会社');
ok($zip->set_number('1408675')->is_valid_number, '日本ペイントホールディングス 株式会社');
ok($zip->set_number('1408676')->is_valid_number, '扶桑電機工業 株式会社');
ok($zip->set_number('1408677')->is_valid_number, '日本ペイント 株式会社');
ok($zip->set_number('1408678')->is_valid_number, '株式会社 古西電機');
ok($zip->set_number('1408680')->is_valid_number, '丸磯建設 株式会社 本社、東京支店');
ok($zip->set_number('1408682')->is_valid_number, '自動車安全運転センター 東京都事務所');
ok($zip->set_number('1408687')->is_valid_number, '日本ゼネラルモーターズ 株式会社');
ok($zip->set_number('1408688')->is_valid_number, '沖電気工事 株式会社');
ok($zip->set_number('1408702')->is_valid_number, '株式会社 勝亦電機製作所');
ok($zip->set_number('1408707')->is_valid_number, '品川女子学院');
ok($zip->set_number('1408709')->is_valid_number, '社団法人 日本生花通信配達協会');
ok($zip->set_number('1408710')->is_valid_number, '第一三共 株式会社 品川研究開発センター');
ok($zip->set_number('1408711')->is_valid_number, '株式会社 寺岡製作所');
ok($zip->set_number('1408715')->is_valid_number, '品川区役所');
ok($zip->set_number('1408716')->is_valid_number, '東京都品川都税事務所');
ok($zip->set_number('1408717')->is_valid_number, '法務局 品川出張所');
ok($zip->set_number('1408721')->is_valid_number, '山下電気 株式会社');
ok($zip->set_number('1408722')->is_valid_number, 'いすゞ自動車 株式会社');
ok($zip->set_number('1408788')->is_valid_number, '東京都民銀行 楽天支店');
ok($zip->set_number('1408810')->is_valid_number, '京セラ 株式会社 東京事業所');
ok($zip->set_number('1418001')->is_valid_number, '大日本印刷 株式会社');
ok($zip->set_number('1418201')->is_valid_number, 'カルチュア・エンタテインメント 株式会社');
ok($zip->set_number('1418202')->is_valid_number, '株式会社 徳間書店');
ok($zip->set_number('1418203')->is_valid_number, '株式会社 美術出版社');
ok($zip->set_number('1418204')->is_valid_number, '株式会社 復刊ドットコム');
ok($zip->set_number('1418205')->is_valid_number, '株式会社 CCCメディアハウス');
ok($zip->set_number('1418206')->is_valid_number, '株式会社 Cーパブリッシングサービス');
ok($zip->set_number('1418214')->is_valid_number, '株式会社 レイヤーズ・コンサルティング');
ok($zip->set_number('1418255')->is_valid_number, '株式会社 エドウイン');
ok($zip->set_number('1418255')->is_valid_number, '株式会社 エドウイン直営店');
ok($zip->set_number('1418255')->is_valid_number, 'イー・ジーニング 株式会社');
ok($zip->set_number('1418260')->is_valid_number, '東洋鋼鈑 株式会社');
ok($zip->set_number('1418411')->is_valid_number, '株式会社 学研エデュケーショナル');
ok($zip->set_number('1418412')->is_valid_number, '株式会社 学研パブリッシング');
ok($zip->set_number('1418413')->is_valid_number, '株式会社 学研教育出版');
ok($zip->set_number('1418416')->is_valid_number, '株式会社 Gakken');
ok($zip->set_number('1418418')->is_valid_number, '株式会社 学研プロダクツサポート');
ok($zip->set_number('1418419')->is_valid_number, '株式会社 学研ステイフル');
ok($zip->set_number('1418420')->is_valid_number, '株式会社 学研ココファンホールディングス');
ok($zip->set_number('1418421')->is_valid_number, '株式会社 学研ロジスティクス');
ok($zip->set_number('1418422')->is_valid_number, '株式会社 学研アソシエ');
ok($zip->set_number('1418423')->is_valid_number, '銀座アスター食品 株式会社');
ok($zip->set_number('1418424')->is_valid_number, '株式会社 学研教育アイ・シー・ティー');
ok($zip->set_number('1418425')->is_valid_number, '株式会社 地球の歩き方');
ok($zip->set_number('1418426')->is_valid_number, '株式会社 文理');
ok($zip->set_number('1418488')->is_valid_number, '株式会社 くもん出版');
ok($zip->set_number('1418501')->is_valid_number, 'アルパイン 株式会社');
ok($zip->set_number('1418503')->is_valid_number, 'THK 株式会社');
ok($zip->set_number('1418504')->is_valid_number, '大和証券 株式会社 五反田支店');
ok($zip->set_number('1418505')->is_valid_number, '三菱電機フィナンシャルソリューションズ 株式会社');
ok($zip->set_number('1418507')->is_valid_number, '東京電力パワーグリッド 株式会社 品川支社');
ok($zip->set_number('1418510')->is_valid_number, '株式会社 学研ホールディングス');
ok($zip->set_number('1418512')->is_valid_number, '株式会社 ハマイ');
ok($zip->set_number('1418515')->is_valid_number, '正電社');
ok($zip->set_number('1418517')->is_valid_number, '長田電機工業 株式会社');
ok($zip->set_number('1418519')->is_valid_number, '株式会社 キョウワエコテック');
ok($zip->set_number('1418519')->is_valid_number, '共和化工 株式会社');
ok($zip->set_number('1418519')->is_valid_number, '共和メンテナンス 株式会社');
ok($zip->set_number('1418519')->is_valid_number, '和饗エコファーム 株式会社');
ok($zip->set_number('1418520')->is_valid_number, '株式会社 レナウン');
ok($zip->set_number('1418521')->is_valid_number, '社団法人 関東年金福祉協会');
ok($zip->set_number('1418522')->is_valid_number, '伊藤忠テクノソリューションズ (株) 大崎オフィス');
ok($zip->set_number('1418525')->is_valid_number, '小澤物産 株式会社');
ok($zip->set_number('1418534')->is_valid_number, '住江織物 (株) 東京支店');
ok($zip->set_number('1418540')->is_valid_number, '新光商事 株式会社');
ok($zip->set_number('1418544')->is_valid_number, '(株) エフ・ディ・シィ・プロダクツ');
ok($zip->set_number('1418555')->is_valid_number, '辰巳産業 株式会社');
ok($zip->set_number('1418559')->is_valid_number, 'ヤスマ (株)');
ok($zip->set_number('1418560')->is_valid_number, '日本精工 株式会社');
ok($zip->set_number('1418561')->is_valid_number, '太陽金網 株式会社');
ok($zip->set_number('1418562')->is_valid_number, '東芝テック 株式会社');
ok($zip->set_number('1418565')->is_valid_number, '(株) 明電舎 東京事業所');
ok($zip->set_number('1418566')->is_valid_number, '株式会社 寺岡精工 営業本部');
ok($zip->set_number('1418567')->is_valid_number, '光村印刷 (株)');
ok($zip->set_number('1418568')->is_valid_number, '品川商工 株式会社');
ok($zip->set_number('1418569')->is_valid_number, '株式会社 ソニー・ミュージックアーティスツ');
ok($zip->set_number('1418572')->is_valid_number, '日本年金機構 品川年金事務所');
ok($zip->set_number('1418576')->is_valid_number, '日立オムロンターミナルソリューションズ 株式会社');
ok($zip->set_number('1418577')->is_valid_number, '立正中高');
ok($zip->set_number('1418580')->is_valid_number, '株式会社 AOI Pro.');
ok($zip->set_number('1418581')->is_valid_number, 'グローリー 株式会社 品川事業所');
ok($zip->set_number('1418582')->is_valid_number, '株式会社 日本アクセス');
ok($zip->set_number('1418584')->is_valid_number, '三井金属鉱業 株式会社');
ok($zip->set_number('1418588')->is_valid_number, 'センチュリーメディカル 株式会社');
ok($zip->set_number('1418602')->is_valid_number, '立正大学');
ok($zip->set_number('1418603')->is_valid_number, '株式会社 サンリオ');
ok($zip->set_number('1418604')->is_valid_number, '日鉄エンジニアリング 株式会社');
ok($zip->set_number('1418605')->is_valid_number, '日本ケミコン 株式会社');
ok($zip->set_number('1418606')->is_valid_number, '協同広告 株式会社');
ok($zip->set_number('1418607')->is_valid_number, '株式会社 明電エンジニアリング');
ok($zip->set_number('1418609')->is_valid_number, '株式会社 ローソンエンタテインメント');
ok($zip->set_number('1418610')->is_valid_number, 'ソニー 株式会社 ソニーシティ大崎');
ok($zip->set_number('1418611')->is_valid_number, '三英電業 株式会社');
ok($zip->set_number('1418613')->is_valid_number, '株式会社 ローソンストア100');
ok($zip->set_number('1418615')->is_valid_number, '三明化成 株式会社');
ok($zip->set_number('1418616')->is_valid_number, '明電興産 株式会社');
ok($zip->set_number('1418620')->is_valid_number, 'セメダイン 株式会社');
ok($zip->set_number('1418623')->is_valid_number, '東京日産自動車販売 株式会社');
ok($zip->set_number('1418626')->is_valid_number, 'コベルコ建機 株式会社 東京本社');
ok($zip->set_number('1418627')->is_valid_number, '東洋製罐グループホールディングス 株式会社');
ok($zip->set_number('1418629')->is_valid_number, '株式会社 セントラルフーズ');
ok($zip->set_number('1418630')->is_valid_number, '富士通コンポーネント 株式会社');
ok($zip->set_number('1418631')->is_valid_number, '株式会社 ミライト・テクノロジーズ');
ok($zip->set_number('1418637')->is_valid_number, 'リコーエレメックス 株式会社');
ok($zip->set_number('1418638')->is_valid_number, '(株) 千趣会');
ok($zip->set_number('1418639')->is_valid_number, 'ネツレン');
ok($zip->set_number('1418640')->is_valid_number, '東洋製罐 株式会社');
ok($zip->set_number('1418641')->is_valid_number, 'シーメンス 株式会社');
ok($zip->set_number('1418642')->is_valid_number, '清泉女子大学');
ok($zip->set_number('1418643')->is_valid_number, '(株) ローソン');
ok($zip->set_number('1418644')->is_valid_number, 'シーメンスヘルスケア 株式会社');
ok($zip->set_number('1418646')->is_valid_number, '大崎電気工業 株式会社');
ok($zip->set_number('1418647')->is_valid_number, '日本コムシス 株式会社');
ok($zip->set_number('1418648')->is_valid_number, '東京医療保健大学');
ok($zip->set_number('1418650')->is_valid_number, '日本建工 株式会社');
ok($zip->set_number('1418656')->is_valid_number, '日本クラフトフーズ 株式会社');
ok($zip->set_number('1418657')->is_valid_number, '株式会社 ジェイ・アイ・シー');
ok($zip->set_number('1418658')->is_valid_number, '井上電気 株式会社');
ok($zip->set_number('1418660')->is_valid_number, 'ホーチキ 株式会社');
ok($zip->set_number('1418663')->is_valid_number, '公益財団法人 日本サイクリング協会');
ok($zip->set_number('1418664')->is_valid_number, '東芝テック 株式会社');
ok($zip->set_number('1418665')->is_valid_number, '前田道路 株式会社');
ok($zip->set_number('1418671')->is_valid_number, 'シック・ジャパン 株式会社');
ok($zip->set_number('1418672')->is_valid_number, '株式会社 日立システムズ');
ok($zip->set_number('1418673')->is_valid_number, 'シーメンスヘルスケア・ダイアグノスティクス 株式会社');
ok($zip->set_number('1418677')->is_valid_number, '株式会社 第一興商');
ok($zip->set_number('1418679')->is_valid_number, 'Chubb 損害保険 株式会社');
ok($zip->set_number('1418680')->is_valid_number, 'ソニー 株式会社 本社');
ok($zip->set_number('1418684')->is_valid_number, 'スリーエム ジャパン 株式会社');
ok($zip->set_number('1418688')->is_valid_number, '株式会社 神戸製鋼所 東京本社');
ok($zip->set_number('1418701')->is_valid_number, '株式会社 第一興商');
ok($zip->set_number('1418707')->is_valid_number, 'グラフテック 株式会社');
ok($zip->set_number('1418710')->is_valid_number, '城南信用金庫');
ok($zip->set_number('1418715')->is_valid_number, '(株) 電波新聞社');
ok($zip->set_number('1418716')->is_valid_number, 'ネオファースト生命保険 株式会社');
ok($zip->set_number('1418924')->is_valid_number, 'パーク24 株式会社');
ok($zip->set_number('1428501')->is_valid_number, '星薬科大学');
ok($zip->set_number('1428511')->is_valid_number, 'SMK 株式会社');
ok($zip->set_number('1428533')->is_valid_number, '杉本電器 株式会社');
ok($zip->set_number('1428540')->is_valid_number, '荏原税務署');
ok($zip->set_number('1428550')->is_valid_number, '青稜中学高等学校');
ok($zip->set_number('1428555')->is_valid_number, '昭和大学');
ok($zip->set_number('1428558')->is_valid_number, '大陽日酸 株式会社');
ok($zip->set_number('1428611')->is_valid_number, '株式会社 三英社製作所');
ok($zip->set_number('1428666')->is_valid_number, '昭和大学病院');
ok($zip->set_number('1428777')->is_valid_number, '昭和大学 教育研修棟');
ok($zip->set_number('1438502')->is_valid_number, '東京海上日動ファイナンス 株式会社 カード事業部');
ok($zip->set_number('1438504')->is_valid_number, '株式会社 ヤマダコーポレーション');
ok($zip->set_number('1438505')->is_valid_number, '医療法人財団 仁医会 牧田総合病院');
ok($zip->set_number('1438507')->is_valid_number, '株式会社 ケツト科学研究所');
ok($zip->set_number('1438508')->is_valid_number, '株式会社 メリーチョコレートカムパニー');
ok($zip->set_number('1438509')->is_valid_number, 'アマゾン大田フルフィルメントセンター');
ok($zip->set_number('1438511')->is_valid_number, '池伝 株式会社');
ok($zip->set_number('1438513')->is_valid_number, 'リコーロジスティクス 株式会社 物流センター城南島');
ok($zip->set_number('1438514')->is_valid_number, '東京海上日動ファイナンス 株式会社');
ok($zip->set_number('1438515')->is_valid_number, '山一電機 株式会社');
ok($zip->set_number('1438520')->is_valid_number, '株式会社 ニシベ計器製造所');
ok($zip->set_number('1438521')->is_valid_number, '株式会社 ヴァレオジャパン');
ok($zip->set_number('1438525')->is_valid_number, 'ヤマトシステム開発 株式会社 新東京ロジシスセンター');
ok($zip->set_number('1438528')->is_valid_number, '共栄工業 株式会社');
ok($zip->set_number('1438530')->is_valid_number, '株式会社 エヌ・ティ・ティ・ロジスコ');
ok($zip->set_number('1438530')->is_valid_number, '株式会社 エヌ・ティ・ティ・ロジスコインフォメーションサービス');
ok($zip->set_number('1438530')->is_valid_number, '株式会社 エヌ・ティ・ティ・ロジスコサービス');
ok($zip->set_number('1438531')->is_valid_number, 'フコク物産 株式会社');
ok($zip->set_number('1438533')->is_valid_number, '株式会社 トミタ');
ok($zip->set_number('1438535')->is_valid_number, '株式会社 増田製作所');
ok($zip->set_number('1438538')->is_valid_number, '株式会社 ジーネット 東京支社');
ok($zip->set_number('1438539')->is_valid_number, 'テクニカル電子 株式会社');
ok($zip->set_number('1438540')->is_valid_number, '学校法人 東邦大学');
ok($zip->set_number('1438541')->is_valid_number, '東邦大学 医療センター 大森病院');
ok($zip->set_number('1438544')->is_valid_number, '長野計器 株式会社');
ok($zip->set_number('1438550')->is_valid_number, '日外アソシエーツ 株式会社');
ok($zip->set_number('1438552')->is_valid_number, '東京都水道局 大田営業所');
ok($zip->set_number('1438555')->is_valid_number, '株式会社 リコー 大森事務所');
ok($zip->set_number('1438557')->is_valid_number, '立正大学付属立正中学校・高等学校');
ok($zip->set_number('1438558')->is_valid_number, '株式会社 電業社機械製作所');
ok($zip->set_number('1438560')->is_valid_number, 'サンワテクノス 株式会社');
ok($zip->set_number('1438565')->is_valid_number, '大森税務署');
ok($zip->set_number('1438567')->is_valid_number, '株式会社 ベンカン・ジャパン');
ok($zip->set_number('1438568')->is_valid_number, '株式会社 ユニックス');
ok($zip->set_number('1438570')->is_valid_number, '株式会社 浅井');
ok($zip->set_number('1438580')->is_valid_number, '株式会社 ディスコ 本社');
ok($zip->set_number('1438585')->is_valid_number, '株式会社 NTT東日本-東京 営業部業務推進部門 公衆電話サービスセンタテレカ充当担当');
ok($zip->set_number('1448505')->is_valid_number, '株式会社 巴商会');
ok($zip->set_number('1448506')->is_valid_number, '東京都立六郷工科高等学校');
ok($zip->set_number('1448510')->is_valid_number, '株式会社 荏原製作所');
ok($zip->set_number('1448511')->is_valid_number, '東京都大田都税事務所');
ok($zip->set_number('1448513')->is_valid_number, '日本調理機 株式会社');
ok($zip->set_number('1448515')->is_valid_number, '全日本空輸 株式会社 羽田空港 第1ターミナル');
ok($zip->set_number('1448516')->is_valid_number, '株式会社 丸昌');
ok($zip->set_number('1448522')->is_valid_number, '株式会社 加登屋');
ok($zip->set_number('1448525')->is_valid_number, '全日本空輸 株式会社 羽田空港 第2ターミナル');
ok($zip->set_number('1448531')->is_valid_number, '株式会社 セガ');
ok($zip->set_number('1448532')->is_valid_number, '株式会社 セガ');
ok($zip->set_number('1448533')->is_valid_number, '東京都立 つばさ総合高等学校');
ok($zip->set_number('1448535')->is_valid_number, '東京工科大学');
ok($zip->set_number('1448536')->is_valid_number, '東京工科大学附属日本語学校');
ok($zip->set_number('1448544')->is_valid_number, '蒲田女子高等学校');
ok($zip->set_number('1448544')->is_valid_number, '蒲田保育専門学校');
ok($zip->set_number('1448544')->is_valid_number, '蒲田保育専門学校附属幼稚園');
ok($zip->set_number('1448550')->is_valid_number, '五十鈴 株式会社');
ok($zip->set_number('1448551')->is_valid_number, '東京計器 株式会社');
ok($zip->set_number('1448555')->is_valid_number, '日本防蝕工業 株式会社');
ok($zip->set_number('1448566')->is_valid_number, '山一電機 株式会社');
ok($zip->set_number('1448570')->is_valid_number, '東京南部法律事務所');
ok($zip->set_number('1448575')->is_valid_number, '全日本空輸 株式会社 国際旅客ターミナル');
ok($zip->set_number('1448577')->is_valid_number, '石川島建機 株式会社 東京本部');
ok($zip->set_number('1448580')->is_valid_number, '大田区立新蒲田福祉センター');
ok($zip->set_number('1448581')->is_valid_number, '山一電機 株式会社');
ok($zip->set_number('1448588')->is_valid_number, '富士通 株式会社 富士通ソリューションスクエア');
ok($zip->set_number('1448602')->is_valid_number, '株式会社 エヌエス商事');
ok($zip->set_number('1448611')->is_valid_number, 'イーター電機工業 株式会社');
ok($zip->set_number('1448621')->is_valid_number, '大田区役所');
ok($zip->set_number('1448622')->is_valid_number, '大田区役所');
ok($zip->set_number('1448623')->is_valid_number, '大田区教育委員会');
ok($zip->set_number('1448626')->is_valid_number, 'ソレキア 株式会社');
ok($zip->set_number('1448650')->is_valid_number, '学校法人 片柳学園');
ok($zip->set_number('1448655')->is_valid_number, '学校法人 片柳学園 日本工学院専門学校');
ok($zip->set_number('1448656')->is_valid_number, '蒲田ゴム 株式会社');
ok($zip->set_number('1448660')->is_valid_number, 'ユザワヤ商事 株式会社');
ok($zip->set_number('1448661')->is_valid_number, '大一商事 株式会社');
ok($zip->set_number('1448666')->is_valid_number, '株式会社 メガネドラッグ');
ok($zip->set_number('1448677')->is_valid_number, '荏原テクノサーブ 株式会社');
ok($zip->set_number('1448678')->is_valid_number, 'ソレキア 株式会社');
ok($zip->set_number('1458501')->is_valid_number, 'アルプス電気 株式会社');
ok($zip->set_number('1458506')->is_valid_number, '雪谷税務署');
ok($zip->set_number('1458511')->is_valid_number, '天象短歌会');
ok($zip->set_number('1458515')->is_valid_number, '昭和大学 歯科病院');
ok($zip->set_number('1458523')->is_valid_number, '東京日産モーター 株式会社');
ok($zip->set_number('1458533')->is_valid_number, '銀座マギー');
ok($zip->set_number('1458558')->is_valid_number, '株式会社 メディカルカラー現像所');
ok($zip->set_number('1458566')->is_valid_number, '斉藤税務会計事務所');
ok($zip->set_number('1468501')->is_valid_number, 'キヤノン 株式会社');
ok($zip->set_number('1468503')->is_valid_number, 'キヤノン健康保険組合');
ok($zip->set_number('1468505')->is_valid_number, '旭計器 株式会社');
ok($zip->set_number('1468510')->is_valid_number, 'ユシロ化学工業 株式会社');
ok($zip->set_number('1468511')->is_valid_number, '株式会社 小野測器');
ok($zip->set_number('1468512')->is_valid_number, 'キヤノン (株) 本社別館1.2');
ok($zip->set_number('1468515')->is_valid_number, '理化工業 株式会社');
ok($zip->set_number('1468522')->is_valid_number, '株式会社 桂川精螺製作所');
ok($zip->set_number('1468531')->is_valid_number, '医療法人 社団松和会 池上総合病院');
ok($zip->set_number('1468540')->is_valid_number, '松下電工制御テクノ 株式会社');
ok($zip->set_number('1468543')->is_valid_number, '株式会社 稲葉製作所');
ok($zip->set_number('1468544')->is_valid_number, '宗教法人 日蓮宗宗務院');
ok($zip->set_number('1468551')->is_valid_number, '日本電熱計器 株式会社');
ok($zip->set_number('1468555')->is_valid_number, '日東工器 株式会社');
ok($zip->set_number('1468558')->is_valid_number, '三井精機工業 株式会社');
ok($zip->set_number('1468567')->is_valid_number, '池上通信機 株式会社');
ok($zip->set_number('1468576')->is_valid_number, '池上 本門寺');
ok($zip->set_number('1468577')->is_valid_number, '株式会社 金羊社');
ok($zip->set_number('1468580')->is_valid_number, '株式会社 寺岡精工');
ok($zip->set_number('1468585')->is_valid_number, '株式会社 三桂製作所');
ok($zip->set_number('1468588')->is_valid_number, '日体荏原高等学校');
ok($zip->set_number('1468601')->is_valid_number, '株式会社 TKR');
ok($zip->set_number('1468610')->is_valid_number, '東京電力パワーグリッド 株式会社 品川支社 大田事務所');
ok($zip->set_number('1468620')->is_valid_number, '株式会社 白洋舎 東京支店');
ok($zip->set_number('1468623')->is_valid_number, '日産部品東京神奈川販売 株式会社');
ok($zip->set_number('1468631')->is_valid_number, '篠田商事 株式会社');
ok($zip->set_number('1468650')->is_valid_number, '日本プリメックス (株)');
ok($zip->set_number('1468655')->is_valid_number, '株式会社 バンダイナムコゲームス');
ok($zip->set_number('1468656')->is_valid_number, '株式会社 ナムコ');
ok($zip->set_number('1468666')->is_valid_number, '太産工業 株式会社');
ok($zip->set_number('1468668')->is_valid_number, '大宏電機 株式会社');
ok($zip->set_number('1468677')->is_valid_number, '日本オートマチックマシン');
ok($zip->set_number('1508001')->is_valid_number, 'NHK放送センター');
ok($zip->set_number('1508010')->is_valid_number, '東京都 渋谷区役所');
ok($zip->set_number('1508015')->is_valid_number, '三菱UFJニコス 株式会社');
ok($zip->set_number('1508019')->is_valid_number, '株式会社 東急百貨店 本店');
ok($zip->set_number('1508081')->is_valid_number, '株式会社 NHK出版');
ok($zip->set_number('1508301')->is_valid_number, '東京法務局 渋谷出張所');
ok($zip->set_number('1508307')->is_valid_number, '公益財団法人 日本生産性本部');
ok($zip->set_number('1508319')->is_valid_number, '株式会社 東急百貨店 渋谷東急フードショー');
ok($zip->set_number('1508322')->is_valid_number, '東京都 住宅供給公社');
ok($zip->set_number('1508324')->is_valid_number, '昭和オートレンタリース 株式会社');
ok($zip->set_number('1508325')->is_valid_number, '株式会社 トイズファクトリー');
ok($zip->set_number('1508326')->is_valid_number, '(株) スカイパーフェクト・コミュニケーションズ');
ok($zip->set_number('1508327')->is_valid_number, '株式会社 三共');
ok($zip->set_number('1508328')->is_valid_number, '財団法人 NHKサービスセンター');
ok($zip->set_number('1508330')->is_valid_number, '株式会社 そごう・西武 西武渋谷店');
ok($zip->set_number('1508333')->is_valid_number, '渋谷税務署');
ok($zip->set_number('1508336')->is_valid_number, '株式会社 マリークヮントコスメチックス');
ok($zip->set_number('1508338')->is_valid_number, 'キユーピー 株式会社');
ok($zip->set_number('1508340')->is_valid_number, '東急建設 株式会社');
ok($zip->set_number('1508343')->is_valid_number, '株式会社 プラップジャパン');
ok($zip->set_number('1508350')->is_valid_number, '株式会社 BMGジャパン');
ok($zip->set_number('1508355')->is_valid_number, '国際教育交換協議会');
ok($zip->set_number('1508360')->is_valid_number, 'ボッシュ 株式会社');
ok($zip->set_number('1508363')->is_valid_number, '一般財団法人 ベターホーム協会');
ok($zip->set_number('1508366')->is_valid_number, '学校法人 青山学院');
ok($zip->set_number('1508373')->is_valid_number, '商工組合 中央金庫 渋谷支店');
ok($zip->set_number('1508377')->is_valid_number, '株式会社 パルコ 渋谷店');
ok($zip->set_number('1508384')->is_valid_number, '日本生命保険 相互会社 渋谷総支社');
ok($zip->set_number('1508385')->is_valid_number, '東京都水道局 渋谷営業所');
ok($zip->set_number('1508402')->is_valid_number, 'バークレイズ・グローバル・インベスターズ信託銀行 株式会社');
ok($zip->set_number('1508408')->is_valid_number, '東京スバル 株式会社');
ok($zip->set_number('1508409')->is_valid_number, '株式会社 ダイヤモンド社');
ok($zip->set_number('1508412')->is_valid_number, '株式会社 ドトールコーヒー');
ok($zip->set_number('1508436')->is_valid_number, 'ニッセイ電機 株式会社');
ok($zip->set_number('1508440')->is_valid_number, '学校法人 國學院大學');
ok($zip->set_number('1508448')->is_valid_number, '株式会社 トゥモローランド');
ok($zip->set_number('1508455')->is_valid_number, 'ミドリ安全 株式会社');
ok($zip->set_number('1508482')->is_valid_number, '株式会社 ワニブックス');
ok($zip->set_number('1508488')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('1508501')->is_valid_number, '株式会社 サイバーエージェント');
ok($zip->set_number('1508502')->is_valid_number, '海光電業 株式会社');
ok($zip->set_number('1508503')->is_valid_number, '財団法人 東京都防災・建築まちづくりセンター');
ok($zip->set_number('1508505')->is_valid_number, '日本たばこ産業 株式会社');
ok($zip->set_number('1508507')->is_valid_number, '株式会社 東急文化村');
ok($zip->set_number('1508508')->is_valid_number, '株式会社 ジェイアール東日本企画');
ok($zip->set_number('1508509')->is_valid_number, '渋谷ヒカリエ ShinQs');
ok($zip->set_number('1508510')->is_valid_number, '渋谷ヒカリエ');
ok($zip->set_number('1508511')->is_valid_number, '東急 株式会社');
ok($zip->set_number('1508512')->is_valid_number, 'セルリアンタワー');
ok($zip->set_number('1508514')->is_valid_number, '株式会社 アバハウスインターナショナル');
ok($zip->set_number('1508515')->is_valid_number, 'ニッポンレンタカーサービス 株式会社');
ok($zip->set_number('1508516')->is_valid_number, '株式会社 テイチクエンタテインメント');
ok($zip->set_number('1508517')->is_valid_number, '株式会社 ゴールドウイン');
ok($zip->set_number('1508522')->is_valid_number, 'サッポロビール 株式会社');
ok($zip->set_number('1508525')->is_valid_number, '伊藤忠プラスチックス 株式会社');
ok($zip->set_number('1508526')->is_valid_number, '株式会社 三越伊勢丹 三越恵比寿店');
ok($zip->set_number('1508530')->is_valid_number, 'トランス・コスモス 株式会社');
ok($zip->set_number('1508533')->is_valid_number, '東急電鉄 株式会社');
ok($zip->set_number('1508538')->is_valid_number, '実践女子大学・実践女子短期大学');
ok($zip->set_number('1508545')->is_valid_number, 'トランスワールドジャパン 株式会社');
ok($zip->set_number('1508551')->is_valid_number, '株式会社 ユース・プラニングセンター');
ok($zip->set_number('1508552')->is_valid_number, 'アイア 株式会社');
ok($zip->set_number('1508553')->is_valid_number, 'アイア 株式会社');
ok($zip->set_number('1508554')->is_valid_number, '富士重工業 株式会社');
ok($zip->set_number('1508555')->is_valid_number, '明和地所 株式会社');
ok($zip->set_number('1508563')->is_valid_number, '養命酒製造 株式会社');
ok($zip->set_number('1508567')->is_valid_number, '日本レストランシステム 株式会社');
ok($zip->set_number('1508575')->is_valid_number, '株式会社 ティーガイア');
ok($zip->set_number('1508577')->is_valid_number, 'NSW 株式会社');
ok($zip->set_number('1508585')->is_valid_number, '協栄産業 株式会社');
ok($zip->set_number('1508587')->is_valid_number, '株式会社 花形商品研究所');
ok($zip->set_number('1508588')->is_valid_number, 'UFJニコス 株式会社 渋谷支店');
ok($zip->set_number('1508672')->is_valid_number, '宗教法人 生長の家');
ok($zip->set_number('1508673')->is_valid_number, '塩野義製薬 株式会社 東京支店');
ok($zip->set_number('1508677')->is_valid_number, '日機装 株式会社');
ok($zip->set_number('1508688')->is_valid_number, '株式会社 アカデミー出版');
ok($zip->set_number('1508902')->is_valid_number, '第一園芸 株式会社');
ok($zip->set_number('1508911')->is_valid_number, '東京自動車サービス健康保険組合');
ok($zip->set_number('1508923')->is_valid_number, '財団法人 母子衛生研究会(母子保健事業団)');
ok($zip->set_number('1508925')->is_valid_number, '国際連合大学');
ok($zip->set_number('1508932')->is_valid_number, '株式会社 ジャックス');
ok($zip->set_number('1508935')->is_valid_number, '日本赤十字社医療センター');
ok($zip->set_number('1508938')->is_valid_number, '聖心女子大学');
ok($zip->set_number('1508940')->is_valid_number, '株式会社 キリンビジネスシステム');
ok($zip->set_number('1508955')->is_valid_number, '株式会社 ポリスター');
ok($zip->set_number('1508967')->is_valid_number, '株式会社 三菱東京UFJ銀行 渋谷支店');
ok($zip->set_number('1518070')->is_valid_number, '積水ハウス 株式会社');
ok($zip->set_number('1518401')->is_valid_number, '株式会社 アートネイチャー');
ok($zip->set_number('1518404')->is_valid_number, 'ジャパンシステム 株式会社');
ok($zip->set_number('1518502')->is_valid_number, '株式会社 郵愛');
ok($zip->set_number('1518503')->is_valid_number, '株式会社 フジタ 東京支店');
ok($zip->set_number('1518504')->is_valid_number, '(株) かんそうしん');
ok($zip->set_number('1518505')->is_valid_number, '社団法人 日本理容美容教育センター');
ok($zip->set_number('1518506')->is_valid_number, '株式会社 大京');
ok($zip->set_number('1518507')->is_valid_number, '明星食品 株式会社');
ok($zip->set_number('1518509')->is_valid_number, '(社) 輿論科学協会');
ok($zip->set_number('1518510')->is_valid_number, 'イトキン 株式会社');
ok($zip->set_number('1518511')->is_valid_number, '株式会社 ソキア');
ok($zip->set_number('1518516')->is_valid_number, '社団法人 日本将棋連盟');
ok($zip->set_number('1518517')->is_valid_number, '株式会社 パソナソフトバンク');
ok($zip->set_number('1518518')->is_valid_number, 'テイーポール 株式会社');
ok($zip->set_number('1518519')->is_valid_number, 'トータルライフサービス 株式会社');
ok($zip->set_number('1518520')->is_valid_number, 'NTTドコモ 代々木ビル');
ok($zip->set_number('1518521')->is_valid_number, '学校法人 文化学園');
ok($zip->set_number('1518522')->is_valid_number, '文化服装学院');
ok($zip->set_number('1518523')->is_valid_number, '文化女子大学');
ok($zip->set_number('1518524')->is_valid_number, '文化出版局');
ok($zip->set_number('1518525')->is_valid_number, '日本交通公社教育旅行 東京西支店');
ok($zip->set_number('1518527')->is_valid_number, 'マクセル 株式会社');
ok($zip->set_number('1518528')->is_valid_number, '東日本旅客鉄道 株式会社 JR東京総合病院');
ok($zip->set_number('1518529')->is_valid_number, '文化学園服飾博物館');
ok($zip->set_number('1518530')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('1518531')->is_valid_number, '全国労働者 共済生活 共同組合 再共済連合会');
ok($zip->set_number('1518532')->is_valid_number, '株式会社 エム・エム・エフ');
ok($zip->set_number('1518533')->is_valid_number, 'マイクロソフト 株式会社');
ok($zip->set_number('1518534')->is_valid_number, '鉄道情報システム 株式会社 本社');
ok($zip->set_number('1518535')->is_valid_number, 'ニッタン 株式会社');
ok($zip->set_number('1518536')->is_valid_number, '株式会社 アトリエサブ');
ok($zip->set_number('1518537')->is_valid_number, '日本製粉 株式会社');
ok($zip->set_number('1518538')->is_valid_number, '社団法人 日本経営協会');
ok($zip->set_number('1518539')->is_valid_number, '山野美容専門学校');
ok($zip->set_number('1518540')->is_valid_number, '(社) 日本音楽著作権協会');
ok($zip->set_number('1518541')->is_valid_number, '株式会社 中村屋');
ok($zip->set_number('1518542')->is_valid_number, '株式会社 有働音楽事務所');
ok($zip->set_number('1518543')->is_valid_number, 'カシオ計算機 (株)');
ok($zip->set_number('1518544')->is_valid_number, '株式会社 スクウェア・エニックス');
ok($zip->set_number('1518545')->is_valid_number, '財団法人 電気安全環境研究所');
ok($zip->set_number('1518546')->is_valid_number, '東京都渋谷都税事務所');
ok($zip->set_number('1518547')->is_valid_number, '文化ファッション大学院大学');
ok($zip->set_number('1518548')->is_valid_number, '株式会社 ガーリック事務所');
ok($zip->set_number('1518549')->is_valid_number, '株式会社 ウェットウエア');
ok($zip->set_number('1518550')->is_valid_number, '株式会社 伊藤園');
ok($zip->set_number('1518552')->is_valid_number, '東京興産 株式会社/東興管理 株式会社');
ok($zip->set_number('1518554')->is_valid_number, '(株) イッセイ ミヤケ');
ok($zip->set_number('1518555')->is_valid_number, '財団法人 企業経営通信学院');
ok($zip->set_number('1518558')->is_valid_number, '独立行政法人 国際協力機構');
ok($zip->set_number('1518559')->is_valid_number, '学校法人 高宮学園代々木ゼミナール');
ok($zip->set_number('1518561')->is_valid_number, '株式会社 イセキ開発工機');
ok($zip->set_number('1518562')->is_valid_number, '株式会社 アグレックス');
ok($zip->set_number('1518563')->is_valid_number, 'アボットジャパン 株式会社');
ok($zip->set_number('1518565')->is_valid_number, '帝国石油 (株)');
ok($zip->set_number('1518566')->is_valid_number, 'グラクソスミスクライン 株式会社');
ok($zip->set_number('1518567')->is_valid_number, 'YKT 株式会社');
ok($zip->set_number('1518568')->is_valid_number, '東京税理士会');
ok($zip->set_number('1518569')->is_valid_number, '日本電波工業 株式会社 本社事務所');
ok($zip->set_number('1518570')->is_valid_number, '株式会社 フジタ');
ok($zip->set_number('1518571')->is_valid_number, '全国労働者 共済生活 協同組合連合会');
ok($zip->set_number('1518572')->is_valid_number, '日本ロレアル (株)');
ok($zip->set_number('1518573')->is_valid_number, '日本ロレアル (株)');
ok($zip->set_number('1518574')->is_valid_number, '山野医療専門学校');
ok($zip->set_number('1518576')->is_valid_number, '株式会社 エス・シー・アライアンス');
ok($zip->set_number('1518577')->is_valid_number, '有限会社 ヨシムラエンタープライズ');
ok($zip->set_number('1518578')->is_valid_number, 'JR東日本 (株) 本社');
ok($zip->set_number('1518580')->is_valid_number, '株式会社 高島屋 新宿店');
ok($zip->set_number('1518582')->is_valid_number, '日本瓦斯 株式会社');
ok($zip->set_number('1518583')->is_valid_number, '小田急サザンタワー');
ok($zip->set_number('1518584')->is_valid_number, 'テルモ (株)');
ok($zip->set_number('1518585')->is_valid_number, '株式会社 ホーメスト');
ok($zip->set_number('1518586')->is_valid_number, '日本共産党 中央委員会');
ok($zip->set_number('1518587')->is_valid_number, '櫻護謨 株式会社');
ok($zip->set_number('1518590')->is_valid_number, 'コンフェックス 株式会社');
ok($zip->set_number('1518591')->is_valid_number, '日本郵政グループ労働者共済生活協同組合');
ok($zip->set_number('1518592')->is_valid_number, '株式会社 アインファーマシーズ');
ok($zip->set_number('1518600')->is_valid_number, '株式会社 フリップサイド');
ok($zip->set_number('1518601')->is_valid_number, '兼松コミュニケーションズ 株式会社');
ok($zip->set_number('1518651')->is_valid_number, 'マニュライフ生命保険 株式会社');
ok($zip->set_number('1518652')->is_valid_number, 'マニュライフ生命保険 株式会社');
ok($zip->set_number('1518653')->is_valid_number, 'マニュライフ生命保険 株式会社');
ok($zip->set_number('1518671')->is_valid_number, '日本園芸協会');
ok($zip->set_number('1518672')->is_valid_number, '株式会社 東京書道教育会');
ok($zip->set_number('1518673')->is_valid_number, '(株) いいもの王国');
ok($zip->set_number('1518674')->is_valid_number, '株式会社 カタログハウス');
ok($zip->set_number('1518675')->is_valid_number, '赤旗編集局');
ok($zip->set_number('1518676')->is_valid_number, '文化書道学会');
ok($zip->set_number('1518677')->is_valid_number, '学校法人 東海大学');
ok($zip->set_number('1518677')->is_valid_number, '学校法人 東海大学');
ok($zip->set_number('1528503')->is_valid_number, '光明理化学工業 株式会社');
ok($zip->set_number('1528506')->is_valid_number, 'エーアイ出版 株式会社');
ok($zip->set_number('1528507')->is_valid_number, '株式会社 小笠原計器制作所');
ok($zip->set_number('1528508')->is_valid_number, '(株) 日本エレクトリック・インスルメント');
ok($zip->set_number('1528510')->is_valid_number, '前澤給装工業 株式会社');
ok($zip->set_number('1528511')->is_valid_number, '株式会社 創育');
ok($zip->set_number('1528520')->is_valid_number, '本多通信工業 株式会社');
ok($zip->set_number('1528521')->is_valid_number, '東京法務局 目黒出張所');
ok($zip->set_number('1528522')->is_valid_number, 'アイア 株式会社');
ok($zip->set_number('1528525')->is_valid_number, '敷島製パン 株式会社 東京事業部');
ok($zip->set_number('1528527')->is_valid_number, '東京地方裁判所 民事執行センター');
ok($zip->set_number('1528531')->is_valid_number, 'プリマハム 株式会社');
ok($zip->set_number('1528532')->is_valid_number, '株式会社 ランナーズ');
ok($zip->set_number('1528533')->is_valid_number, '株式会社 レックス');
ok($zip->set_number('1528535')->is_valid_number, '東京物産 株式会社');
ok($zip->set_number('1528541')->is_valid_number, '泰榮商工 株式会社');
ok($zip->set_number('1528544')->is_valid_number, '株式会社 ジャップス');
ok($zip->set_number('1528549')->is_valid_number, '(株) エディトリアル・クリッパー');
ok($zip->set_number('1528550')->is_valid_number, '東京工業大学');
ok($zip->set_number('1528551')->is_valid_number, '東京工業大学 理学部');
ok($zip->set_number('1528552')->is_valid_number, '東京工業大学 工学部');
ok($zip->set_number('1528558')->is_valid_number, '東京医療保健大学 東が丘看護学部');
ok($zip->set_number('1528561')->is_valid_number, '大和証券 株式会社 自由が丘支店');
ok($zip->set_number('1528570')->is_valid_number, 'キヤノンプレシジョン 株式会社');
ok($zip->set_number('1528578')->is_valid_number, '株式会社 牧野フライス製作所');
ok($zip->set_number('1528601')->is_valid_number, '株式会社 平凡社');
ok($zip->set_number('1528621')->is_valid_number, '独立行政法人 国立病院機構本部');
ok($zip->set_number('1528902')->is_valid_number, '独立行政法人 国立病院機構 東京医療センター');
ok($zip->set_number('1528904')->is_valid_number, '株式会社 anovan');
ok($zip->set_number('1528904')->is_valid_number, '株式会社 亀万');
ok($zip->set_number('1528904')->is_valid_number, '株式会社 亀屋万年堂');
ok($zip->set_number('1528904')->is_valid_number, '亀屋万年堂製菓 株式会社');
ok($zip->set_number('1528905')->is_valid_number, '株式会社 私の部屋リビング');
ok($zip->set_number('1528907')->is_valid_number, 'ニッカン工業 株式会社');
ok($zip->set_number('1528909')->is_valid_number, '株式会社 東急ストア');
ok($zip->set_number('1528910')->is_valid_number, '日本オンライン整備 株式会社');
ok($zip->set_number('1528913')->is_valid_number, '六桜商事 株式会社');
ok($zip->set_number('1538501')->is_valid_number, '大学入試センター');
ok($zip->set_number('1538502')->is_valid_number, 'りそな決済サービス (株) 支払業務センター');
ok($zip->set_number('1538503')->is_valid_number, '(財) 日本国際教育支援協会');
ok($zip->set_number('1538504')->is_valid_number, '株式会社 紀伊國屋書店');
ok($zip->set_number('1538505')->is_valid_number, '東京大学生産技術研究所');
ok($zip->set_number('1538506')->is_valid_number, 'りそな決済サービス 株式会社 業務センター');
ok($zip->set_number('1538508')->is_valid_number, '学校法人 日本工業大学');
ok($zip->set_number('1538510')->is_valid_number, 'やまう 株式会社');
ok($zip->set_number('1538512')->is_valid_number, '株式会社 ヴァンテック');
ok($zip->set_number('1538515')->is_valid_number, '東邦大学医療センター 大橋病院');
ok($zip->set_number('1538516')->is_valid_number, '社会福祉法人 愛隣会');
ok($zip->set_number('1538518')->is_valid_number, '東急バス 株式会社');
ok($zip->set_number('1538520')->is_valid_number, '株式会社 ジェディックス');
ok($zip->set_number('1538521')->is_valid_number, '株式会社 ジュンアシダ');
ok($zip->set_number('1538522')->is_valid_number, '財団法人 日本地図センター');
ok($zip->set_number('1538523')->is_valid_number, 'あおば生命 株式会社');
ok($zip->set_number('1538525')->is_valid_number, '株式会社 聖林公司');
ok($zip->set_number('1538526')->is_valid_number, 'メルク製薬 株式会社');
ok($zip->set_number('1538530')->is_valid_number, 'エトー 株式会社');
ok($zip->set_number('1538531')->is_valid_number, '株式会社 ジャパンライフデザインシステムズ');
ok($zip->set_number('1538536')->is_valid_number, '株式会社 ピー・エックス');
ok($zip->set_number('1538537')->is_valid_number, '知的財産高等裁判所');
ok($zip->set_number('1538539')->is_valid_number, '日本航空電子工業 株式会社');
ok($zip->set_number('1538540')->is_valid_number, 'チャコット 株式会社');
ok($zip->set_number('1538541')->is_valid_number, '株式会社 CCCメディアハウス');
ok($zip->set_number('1538543')->is_valid_number, '株式会社 阪急トラベルサポート');
ok($zip->set_number('1538545')->is_valid_number, '株式会社 ネコ・パブリッシング');
ok($zip->set_number('1538550')->is_valid_number, 'トップツアー 株式会社');
ok($zip->set_number('1538551')->is_valid_number, '田中興産 株式会社 絵里奈事業部');
ok($zip->set_number('1538552')->is_valid_number, '自衛隊中央病院 高等看護学院');
ok($zip->set_number('1538553')->is_valid_number, 'ニッポンレンタカーアーバンネット 株式会社 東京ディビジョン');
ok($zip->set_number('1538554')->is_valid_number, 'ビーシーアイ 株式会社');
ok($zip->set_number('1538555')->is_valid_number, '株式会社 パスコ 東京支社');
ok($zip->set_number('1538556')->is_valid_number, 'りそな決済サービス (株) 代金回収センター(公文)');
ok($zip->set_number('1538558')->is_valid_number, '太陽工業株式会社');
ok($zip->set_number('1538560')->is_valid_number, '株式会社 イワセ・エスタ');
ok($zip->set_number('1538565')->is_valid_number, '株式会社 カイタックインターナショナル');
ok($zip->set_number('1538567')->is_valid_number, '株式会社 リアルロックス');
ok($zip->set_number('1538571')->is_valid_number, 'アベイズム 株式会社');
ok($zip->set_number('1538573')->is_valid_number, '目黒区役所');
ok($zip->set_number('1538577')->is_valid_number, '株式会社 東急ストア');
ok($zip->set_number('1538578')->is_valid_number, 'ユニリーバ・ジャパン ホールディングス 合同会社');
ok($zip->set_number('1538580')->is_valid_number, '株式会社 三田ホールディング ウェスティンホテル東京');
ok($zip->set_number('1538581')->is_valid_number, '総合病院 厚生中央病院');
ok($zip->set_number('1538582')->is_valid_number, '東京都 水道局 目黒営業所');
ok($zip->set_number('1538585')->is_valid_number, '社団法人 目黒法人会');
ok($zip->set_number('1538586')->is_valid_number, '中央化学産業 株式会社');
ok($zip->set_number('1538587')->is_valid_number, '伊藤ハム 株式会社');
ok($zip->set_number('1538589')->is_valid_number, '株式会社 阪急交通社');
ok($zip->set_number('1538601')->is_valid_number, '三井住友信託銀行 株式会社');
ok($zip->set_number('1538610')->is_valid_number, '株式会社 ビギ');
ok($zip->set_number('1538616')->is_valid_number, '株式会社 ジャックス 東京住宅ローンセンター');
ok($zip->set_number('1538620')->is_valid_number, '株式会社 ホットスタッフ・プロモーション');
ok($zip->set_number('1538622')->is_valid_number, '学校法人 東京音楽大学');
ok($zip->set_number('1538626')->is_valid_number, '東京地方裁判所 中目黒庁舎');
ok($zip->set_number('1538630')->is_valid_number, '防衛省 技術研究本部 艦艇装備研究所');
ok($zip->set_number('1538631')->is_valid_number, '学校法人 目黒学院');
ok($zip->set_number('1538633')->is_valid_number, '目黒税務署');
ok($zip->set_number('1538635')->is_valid_number, '株式会社 アートコーヒー');
ok($zip->set_number('1538636')->is_valid_number, 'スタンレー電気 株式会社');
ok($zip->set_number('1538638')->is_valid_number, '株式会社 ルック');
ok($zip->set_number('1538640')->is_valid_number, '全国酒販会館');
ok($zip->set_number('1538650')->is_valid_number, '新光商事 株式会社');
ok($zip->set_number('1538652')->is_valid_number, '株式会社 日本ホールマーク');
ok($zip->set_number('1538653')->is_valid_number, '株式会社 コミューチュア 東京支店');
ok($zip->set_number('1538654')->is_valid_number, 'パイオニア 株式会社');
ok($zip->set_number('1538655')->is_valid_number, '伊藤忠エネクス 株式会社');
ok($zip->set_number('1538657')->is_valid_number, '森永乳業 株式会社 管理センター');
ok($zip->set_number('1538660')->is_valid_number, '株式会社 ホリプロ');
ok($zip->set_number('1538662')->is_valid_number, 'ミネベア 株式会社');
ok($zip->set_number('1538665')->is_valid_number, 'パイオニア 株式会社 PAXビル');
ok($zip->set_number('1538666')->is_valid_number, '一般財団法人 ヤマハ音楽振興会');
ok($zip->set_number('1538668')->is_valid_number, 'ジプロ 株式会社');
ok($zip->set_number('1538669')->is_valid_number, '目黒雅叙園');
ok($zip->set_number('1538670')->is_valid_number, '株式会社 ディスクガレージ');
ok($zip->set_number('1538671')->is_valid_number, '大東通信機 株式会社');
ok($zip->set_number('1538677')->is_valid_number, 'さわやか信用金庫');
ok($zip->set_number('1538687')->is_valid_number, 'パナソニックコミュニケーションズ 株式会社');
ok($zip->set_number('1538688')->is_valid_number, '株式会社 スクウェア');
ok($zip->set_number('1538902')->is_valid_number, '東京大学大学院総合文化研究科・教養学部');
ok($zip->set_number('1538904')->is_valid_number, '東京大学先端科学技術研究センター');
ok($zip->set_number('1538906')->is_valid_number, '株式会社 メルローズ');
ok($zip->set_number('1538911')->is_valid_number, '東京富士 株式会社');
ok($zip->set_number('1538913')->is_valid_number, '株式会社 ホワイ');
ok($zip->set_number('1538914')->is_valid_number, '東京大学大学院 数理科学研究科');
ok($zip->set_number('1538923')->is_valid_number, 'サクサ 株式会社');
ok($zip->set_number('1538925')->is_valid_number, '株式会社 リテイルネットワークス');
ok($zip->set_number('1538927')->is_valid_number, 'メルク 株式会社');
ok($zip->set_number('1538930')->is_valid_number, '雅叙園観光 株式会社');
ok($zip->set_number('1538933')->is_valid_number, '航空自衛隊目黒基地 幹部学校');
ok($zip->set_number('1538934')->is_valid_number, '国家公務員共済組合連合会総合病院東京共済病院');
ok($zip->set_number('1538936')->is_valid_number, '目黒信用金庫');
ok($zip->set_number('1538937')->is_valid_number, '東京都目黒都税事務所');
ok($zip->set_number('1538939')->is_valid_number, '東京都教育相談センター');
ok($zip->set_number('1548503')->is_valid_number, '(株) 東京メガネ');
ok($zip->set_number('1548504')->is_valid_number, '世田谷区役所');
ok($zip->set_number('1548505')->is_valid_number, '丸幸製茶販売 (株)');
ok($zip->set_number('1548506')->is_valid_number, '昭和オプトロニクス 株式会社');
ok($zip->set_number('1548509')->is_valid_number, '株式会社 コスミック出版');
ok($zip->set_number('1548510')->is_valid_number, '株式会社 エヌ・ユー・エス');
ok($zip->set_number('1548511')->is_valid_number, '防衛省 技術研究本部電子装備研究所');
ok($zip->set_number('1548515')->is_valid_number, '国士舘大学');
ok($zip->set_number('1548516')->is_valid_number, '株式会社 グレイスファミリー');
ok($zip->set_number('1548520')->is_valid_number, '三菱電機システムサービス 株式会社');
ok($zip->set_number('1548521')->is_valid_number, '旭日電気工業 (株)');
ok($zip->set_number('1548523')->is_valid_number, '世田谷税務署');
ok($zip->set_number('1548525')->is_valid_number, '駒澤大学');
ok($zip->set_number('1548530')->is_valid_number, '国土情報開発 株式会社');
ok($zip->set_number('1548532')->is_valid_number, '自衛隊中央病院');
ok($zip->set_number('1548533')->is_valid_number, '昭和女子大学');
ok($zip->set_number('1548536')->is_valid_number, '(株) ニューズヴァリュー');
ok($zip->set_number('1548539')->is_valid_number, 'エム・シー・エム・ジャパン (株)');
ok($zip->set_number('1548543')->is_valid_number, '東京電力 世田谷支社');
ok($zip->set_number('1548544')->is_valid_number, '学校法人 食糧学院');
ok($zip->set_number('1548545')->is_valid_number, '公益財団法人 プラン・インターナショナル・ジャパン');
ok($zip->set_number('1548551')->is_valid_number, 'オットージャパン 株式会社');
ok($zip->set_number('1548552')->is_valid_number, '株式会社 コア');
ok($zip->set_number('1548553')->is_valid_number, '国士舘中学校・高等学校');
ok($zip->set_number('1548554')->is_valid_number, '世田谷区役所');
ok($zip->set_number('1548555')->is_valid_number, '世田谷社会保険事務所');
ok($zip->set_number('1548560')->is_valid_number, '武藤工業 株式会社');
ok($zip->set_number('1548565')->is_valid_number, 'セントラル工商 株式会社');
ok($zip->set_number('1548566')->is_valid_number, '陸上自衛隊衛生学校');
ok($zip->set_number('1548567')->is_valid_number, 'エディー・バウアー・ジャパン 株式会社');
ok($zip->set_number('1548568')->is_valid_number, '東京医療保健大学');
ok($zip->set_number('1548570')->is_valid_number, 'チャコット 株式会社 営業センター');
ok($zip->set_number('1548571')->is_valid_number, '昭和女子大学 オープンカレッジ');
ok($zip->set_number('1548577')->is_valid_number, '東京都世田谷都税事務所');
ok($zip->set_number('1548580')->is_valid_number, '株式会社 東京特殊印刷工業');
ok($zip->set_number('1548581')->is_valid_number, '世田谷信用金庫');
ok($zip->set_number('1548582')->is_valid_number, '株式会社 テック・インデックス');
ok($zip->set_number('1548584')->is_valid_number, 'ロイヤル (株) 東京本部');
ok($zip->set_number('1548585')->is_valid_number, 'いであ 株式会社');
ok($zip->set_number('1548703')->is_valid_number, '株式会社 グローバル');
ok($zip->set_number('1548732')->is_valid_number, '東京都水道局 世田谷東営業所');
ok($zip->set_number('1558610')->is_valid_number, '学校法人 松蔭学園');
ok($zip->set_number('1558626')->is_valid_number, '(株) 第二書房');
ok($zip->set_number('1558633')->is_valid_number, '小林製薬工業 株式会社');
ok($zip->set_number('1558655')->is_valid_number, '東邦薬品 株式会社');
ok($zip->set_number('1558663')->is_valid_number, '(財) 秋田県育英会 東京寮');
ok($zip->set_number('1558668')->is_valid_number, '学校法人 成徳学園');
ok($zip->set_number('1568502')->is_valid_number, '学校法人 東京農業大学');
ok($zip->set_number('1568504')->is_valid_number, '東京農業大学 常磐松学生会館');
ok($zip->set_number('1568506')->is_valid_number, '財団法人 東京都医学総合研究所');
ok($zip->set_number('1568510')->is_valid_number, '株式会社 玉川繊維工業所');
ok($zip->set_number('1568511')->is_valid_number, '東京いすゞ自動車 株式会社');
ok($zip->set_number('1568520')->is_valid_number, '学校法人 恵泉女学園');
ok($zip->set_number('1568522')->is_valid_number, '東京都水道局 世田谷西営業所');
ok($zip->set_number('1568533')->is_valid_number, '日本アイ・ビー・エム・ビズインテック 株式会社');
ok($zip->set_number('1568555')->is_valid_number, '北沢税務署');
ok($zip->set_number('1568588')->is_valid_number, 'キーウェアソリューションズ (株)');
ok($zip->set_number('1568666')->is_valid_number, '株式会社 美好屋商店');
ok($zip->set_number('1578501')->is_valid_number, '世田谷区 砧総合支所');
ok($zip->set_number('1578508')->is_valid_number, '株式会社 八木橋');
ok($zip->set_number('1578510')->is_valid_number, '日本放送協会 放送技術研究所');
ok($zip->set_number('1578511')->is_valid_number, '学校法人 成城学園');
ok($zip->set_number('1578520')->is_valid_number, '財団法人 NHK放送研修センター');
ok($zip->set_number('1578521')->is_valid_number, '日本書学舘');
ok($zip->set_number('1578522')->is_valid_number, '学校法人 成城学園 初等学校');
ok($zip->set_number('1578530')->is_valid_number, 'NHK 東京事務センター');
ok($zip->set_number('1578535')->is_valid_number, '国立 成育医療センター');
ok($zip->set_number('1578543')->is_valid_number, '株式会社 ティ・ヴイクラブ');
ok($zip->set_number('1578550')->is_valid_number, '(社) 至誠会 第二病院');
ok($zip->set_number('1578561')->is_valid_number, '東宝 (株) 東宝スタジオ');
ok($zip->set_number('1578562')->is_valid_number, '学校法人 科学技術学園');
ok($zip->set_number('1578563')->is_valid_number, '株式会社 ジャパンハウス');
ok($zip->set_number('1578565')->is_valid_number, '学校法人 二階堂学園');
ok($zip->set_number('1578566')->is_valid_number, 'サクラビア成城 (株) プライムステージ');
ok($zip->set_number('1578567')->is_valid_number, '(株) ウテナ');
ok($zip->set_number('1578570')->is_valid_number, '日本大学 商学部');
ok($zip->set_number('1578573')->is_valid_number, '財団法人 日本品質保証機構');
ok($zip->set_number('1578575')->is_valid_number, '(社) 友愛十字会');
ok($zip->set_number('1578577')->is_valid_number, '昭和大学附属烏山病院');
ok($zip->set_number('1588501')->is_valid_number, '国立医薬品食品衛生研究所');
ok($zip->set_number('1588502')->is_valid_number, '東神開発 株式会社');
ok($zip->set_number('1588503')->is_valid_number, '玉川総合支所');
ok($zip->set_number('1588505')->is_valid_number, 'ジャガージャパン 株式会社');
ok($zip->set_number('1588508')->is_valid_number, '日本体育大学');
ok($zip->set_number('1588509')->is_valid_number, '株式会社 東急コミュニティー');
ok($zip->set_number('1588510')->is_valid_number, '(財) 五島美術館');
ok($zip->set_number('1588511')->is_valid_number, '学校法人 田園調布雙葉学園');
ok($zip->set_number('1588512')->is_valid_number, '学校法人 調布学園');
ok($zip->set_number('1588513')->is_valid_number, '昭栄電気工具 株式会社');
ok($zip->set_number('1588514')->is_valid_number, '石橋刷子製造 株式会社');
ok($zip->set_number('1588518')->is_valid_number, '新日本気象海洋 株式会社');
ok($zip->set_number('1588520')->is_valid_number, '株式会社 ジャレコ');
ok($zip->set_number('1588522')->is_valid_number, '株式会社 アサヒ安全業務社');
ok($zip->set_number('1588523')->is_valid_number, '日本中央競馬会 馬事公苑');
ok($zip->set_number('1588525')->is_valid_number, '明星電気 株式会社');
ok($zip->set_number('1588531')->is_valid_number, '公立学校共済組合 関東中央病院');
ok($zip->set_number('1588533')->is_valid_number, 'シンコー 株式会社');
ok($zip->set_number('1588534')->is_valid_number, '東急カード 株式会社');
ok($zip->set_number('1588539')->is_valid_number, '東急ファシリティサービス 株式会社');
ok($zip->set_number('1588543')->is_valid_number, '岡谷電機産業 株式会社');
ok($zip->set_number('1588544')->is_valid_number, '愛国産業 株式会社');
ok($zip->set_number('1588549')->is_valid_number, '株式会社 サクラス');
ok($zip->set_number('1588550')->is_valid_number, '日本ジョンソン・アンド・ヒギンズ 株式会社');
ok($zip->set_number('1588551')->is_valid_number, '株式会社 本間ゴルフ');
ok($zip->set_number('1588552')->is_valid_number, '長谷川病院');
ok($zip->set_number('1588557')->is_valid_number, '東京都市大学');
ok($zip->set_number('1588558')->is_valid_number, '学校法人 多摩美術大学');
ok($zip->set_number('1588561')->is_valid_number, '世田谷税務署');
ok($zip->set_number('1588566')->is_valid_number, '東京都立園芸高等学校');
ok($zip->set_number('1588567')->is_valid_number, '株式会社 レアーズ');
ok($zip->set_number('1588575')->is_valid_number, '株式会社 サンエー・インターナショナル');
ok($zip->set_number('1588577')->is_valid_number, '学校法人 駒澤大学高等学校');
ok($zip->set_number('1588578')->is_valid_number, '株式会社 オリーブ情報システム');
ok($zip->set_number('1588580')->is_valid_number, '東京外かく環状道路調査事務所');
ok($zip->set_number('1588585')->is_valid_number, '医療法人 社団和乃会小倉病院');
ok($zip->set_number('1588586')->is_valid_number, '東京都市大学 等々力キャンパス');
ok($zip->set_number('1588588')->is_valid_number, 'ファーレン東京 株式会社');
ok($zip->set_number('1588601')->is_valid_number, '玉川税務署');
ok($zip->set_number('1588602')->is_valid_number, '株式会社 銀座マギー');
ok($zip->set_number('1588610')->is_valid_number, '京セラミタ 株式会社 東京R&Dセンター');
ok($zip->set_number('1588615')->is_valid_number, 'タイコヘルスケアジャパン 株式会社');
ok($zip->set_number('1588622')->is_valid_number, '東京都世田谷都税事務所');
ok($zip->set_number('1588628')->is_valid_number, '株式会社 タカラ 東京本社');
ok($zip->set_number('1588630')->is_valid_number, '産業能率大学');
ok($zip->set_number('1588631')->is_valid_number, '産業能率大学');
ok($zip->set_number('1588632')->is_valid_number, '産業能率大学');
ok($zip->set_number('1588633')->is_valid_number, '日本オラクル 株式会社');
ok($zip->set_number('1588640')->is_valid_number, 'エディトリアルクリッパー');
ok($zip->set_number('1588666')->is_valid_number, '株式会社 伸商');
ok($zip->set_number('1588701')->is_valid_number, '(株) 高島屋 玉川店');
ok($zip->set_number('1588771')->is_valid_number, '株式会社 大正オーディット');
ok($zip->set_number('1608001')->is_valid_number, '株式会社 小田急百貨店');
ok($zip->set_number('1608011')->is_valid_number, '株式会社 三越伊勢丹 伊勢丹新宿店');
ok($zip->set_number('1608070')->is_valid_number, '聖教新聞社');
ok($zip->set_number('1608301')->is_valid_number, '株式会社 秀栄興産');
ok($zip->set_number('1608304')->is_valid_number, '東京都新宿都税事務所');
ok($zip->set_number('1608306')->is_valid_number, '株式会社 日本小児医事出版社');
ok($zip->set_number('1608309')->is_valid_number, '小田急電鉄 株式会社');
ok($zip->set_number('1608311')->is_valid_number, '有限会社 森野ウレタン社');
ok($zip->set_number('1608313')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('1608316')->is_valid_number, '富士重工業 株式会社');
ok($zip->set_number('1608319')->is_valid_number, '株式会社 ビックカメラ 新宿西口店');
ok($zip->set_number('1608321')->is_valid_number, '株式会社 京王百貨店');
ok($zip->set_number('1608327')->is_valid_number, '中央職業能力開発協会');
ok($zip->set_number('1608330')->is_valid_number, '株式会社 京王プラザホテル');
ok($zip->set_number('1608331')->is_valid_number, '三井不動産住宅サービス 株式会社');
ok($zip->set_number('1608334')->is_valid_number, '株式会社 三松');
ok($zip->set_number('1608336')->is_valid_number, '新宿ワシントンホテル');
ok($zip->set_number('1608338')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('1608341')->is_valid_number, '株式会社 DeNAトラベル');
ok($zip->set_number('1608347')->is_valid_number, 'HOYA 株式会社');
ok($zip->set_number('1608351')->is_valid_number, '野村不動産パートナーズ 株式会社');
ok($zip->set_number('1608352')->is_valid_number, 'アニコム損害保険 株式会社');
ok($zip->set_number('1608353')->is_valid_number, '(公財) 東京都防災・建築まちづくりセンター');
ok($zip->set_number('1608358')->is_valid_number, '株式会社 ビックピーカン');
ok($zip->set_number('1608361')->is_valid_number, '全研本社 株式会社');
ok($zip->set_number('1608366')->is_valid_number, '日本テキサス・インスツルメンツ 株式会社');
ok($zip->set_number('1608368')->is_valid_number, '富国生命保険 相互会社 新宿支社');
ok($zip->set_number('1608373')->is_valid_number, '全保連 株式会社');
ok($zip->set_number('1608374')->is_valid_number, '芸能花伝舎');
ok($zip->set_number('1608375')->is_valid_number, '株式会社 シー・アイ・シー');
ok($zip->set_number('1608378')->is_valid_number, '株式会社 フジタ 東京支店');
ok($zip->set_number('1608389')->is_valid_number, '社団法人 日本薬剤師会');
ok($zip->set_number('1608401')->is_valid_number, '大和証券 株式会社 新宿支店');
ok($zip->set_number('1608402')->is_valid_number, '学校法人 東京医科大学');
ok($zip->set_number('1608403')->is_valid_number, '川辺 株式会社');
ok($zip->set_number('1608407')->is_valid_number, '財団法人 東京社会保険協会');
ok($zip->set_number('1608408')->is_valid_number, '株式会社 エムアイカード');
ok($zip->set_number('1608409')->is_valid_number, '日本ハウズイング 株式会社');
ok($zip->set_number('1608410')->is_valid_number, '日本ハウズイング 株式会社');
ok($zip->set_number('1608411')->is_valid_number, '日神不動産 株式会社');
ok($zip->set_number('1608415')->is_valid_number, 'ネッツトヨタ東京 株式会社');
ok($zip->set_number('1608420')->is_valid_number, '株式会社 マースエンジニアリング');
ok($zip->set_number('1608422')->is_valid_number, 'キーウェアソリューションズ 株式会社');
ok($zip->set_number('1608423')->is_valid_number, 'オートビジネスサービス 株式会社');
ok($zip->set_number('1608429')->is_valid_number, '株式会社 アデランス');
ok($zip->set_number('1608430')->is_valid_number, '株式会社 スクウェア・エニックス');
ok($zip->set_number('1608433')->is_valid_number, '株式会社 佐藤秀');
ok($zip->set_number('1608441')->is_valid_number, '廣告社 株式会社');
ok($zip->set_number('1608444')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('1608447')->is_valid_number, '株式会社 タイトー');
ok($zip->set_number('1608450')->is_valid_number, '株式会社 長谷工コミュニティ 東京支店');
ok($zip->set_number('1608461')->is_valid_number, '株式会社 三栄');
ok($zip->set_number('1608463')->is_valid_number, '株式会社 サンズ');
ok($zip->set_number('1608466')->is_valid_number, 'ホテルグレイスリー新宿');
ok($zip->set_number('1608472')->is_valid_number, '新宿区役所 地域調整課 文化国際課');
ok($zip->set_number('1608484')->is_valid_number, '新宿区役所');
ok($zip->set_number('1608485')->is_valid_number, '新宿区役所 総務部 税務課');
ok($zip->set_number('1608486')->is_valid_number, '株式会社 ヨドバシカメラ');
ok($zip->set_number('1608487')->is_valid_number, '新宿プリンスホテル');
ok($zip->set_number('1608488')->is_valid_number, '財団法人 東京都保険医療公社 大久保病院');
ok($zip->set_number('1608489')->is_valid_number, '新宿公共職業安定所');
ok($zip->set_number('1608501')->is_valid_number, '株式会社 サンミュージックプロダクション');
ok($zip->set_number('1608507')->is_valid_number, '全国健康保険協会 本部');
ok($zip->set_number('1608510')->is_valid_number, '新菱冷熱工業 株式会社');
ok($zip->set_number('1608511')->is_valid_number, '大塚刷毛製造 (株)');
ok($zip->set_number('1608512')->is_valid_number, '生活協同組合 東京マイコープ');
ok($zip->set_number('1608515')->is_valid_number, '持田製薬 (株)');
ok($zip->set_number('1608516')->is_valid_number, 'なないろ生命保険 株式会社');
ok($zip->set_number('1608519')->is_valid_number, '社団法人 金融財政事情研究会');
ok($zip->set_number('1608520')->is_valid_number, '株式会社 きんざい');
ok($zip->set_number('1608521')->is_valid_number, '公明機関紙局');
ok($zip->set_number('1608522')->is_valid_number, '女子学生会館 「明泉」');
ok($zip->set_number('1608524')->is_valid_number, '日清食品 株式会社 東京本社');
ok($zip->set_number('1608529')->is_valid_number, '社団法人 金融財政事情研究会 検定センター');
ok($zip->set_number('1608530')->is_valid_number, '四谷税務署');
ok($zip->set_number('1608535')->is_valid_number, 'あんしん財団 災害防止部');
ok($zip->set_number('1608543')->is_valid_number, 'コモンズ 株式会社');
ok($zip->set_number('1608547')->is_valid_number, '株式会社 三栄');
ok($zip->set_number('1608565')->is_valid_number, '株式会社 ポプラ社');
ok($zip->set_number('1608571')->is_valid_number, '株式会社 太田出版');
ok($zip->set_number('1608575')->is_valid_number, '雪印メグミルク 株式会社');
ok($zip->set_number('1608577')->is_valid_number, '三井住友建設 株式会社');
ok($zip->set_number('1608580')->is_valid_number, '株式会社 ワニマガジン社');
ok($zip->set_number('1608581')->is_valid_number, '新宿区 四谷特別出張所');
ok($zip->set_number('1608581')->is_valid_number, '四谷区民ホール');
ok($zip->set_number('1608581')->is_valid_number, '四谷地域センター');
ok($zip->set_number('1608581')->is_valid_number, '四谷図書館');
ok($zip->set_number('1608582')->is_valid_number, '慶應義塾大学 医学部');
ok($zip->set_number('1608583')->is_valid_number, '創価学会');
ok($zip->set_number('1608587')->is_valid_number, '東京都水道局 新宿営業所');
ok($zip->set_number('1608588')->is_valid_number, '(財) 民主音楽協会');
ok($zip->set_number('1608589')->is_valid_number, '東鉄工業 株式会社');
ok($zip->set_number('1608601')->is_valid_number, '日本年金機構 新宿年金事務所');
ok($zip->set_number('1608680')->is_valid_number, 'あんしん財団 「楽しいイベント」係');
ok($zip->set_number('1608801')->is_valid_number, 'エプソン販売 株式会社');
ok($zip->set_number('1608801')->is_valid_number, 'セイコーエプソン 株式会社');
ok($zip->set_number('1608812')->is_valid_number, 'シティグループ・サービス・ジャパン 株式会社');
ok($zip->set_number('1608910')->is_valid_number, '伯東 株式会社');
ok($zip->set_number('1618508')->is_valid_number, '株式会社 オーバル');
ok($zip->set_number('1618511')->is_valid_number, '下田商事 株式会社');
ok($zip->set_number('1618520')->is_valid_number, 'ライオン企画 株式会社');
ok($zip->set_number('1618521')->is_valid_number, '社会福祉法人 聖母会 聖母病院');
ok($zip->set_number('1618522')->is_valid_number, '目白研心中学校・高等学校');
ok($zip->set_number('1618528')->is_valid_number, 'JA全農たまご 株式会社');
ok($zip->set_number('1618531')->is_valid_number, 'ウエットマスター 株式会社');
ok($zip->set_number('1618539')->is_valid_number, '目白学園');
ok($zip->set_number('1618540')->is_valid_number, 'エステー 株式会社');
ok($zip->set_number('1618541')->is_valid_number, '三宝製薬 株式会社');
ok($zip->set_number('1618545')->is_valid_number, '工新建設 株式会社');
ok($zip->set_number('1618546')->is_valid_number, 'アニコム損害保険 株式会社');
ok($zip->set_number('1618552')->is_valid_number, '株式会社 誠和');
ok($zip->set_number('1618553')->is_valid_number, '株式会社 日本コンサルタントグループ');
ok($zip->set_number('1618556')->is_valid_number, '学校法人 東京富士大学');
ok($zip->set_number('1618557')->is_valid_number, '学校法人 田中芸術学園 東京美容専門学校');
ok($zip->set_number('1618558')->is_valid_number, '一世印刷 株式会社');
ok($zip->set_number('1618560')->is_valid_number, '日本光電工業 株式会社');
ok($zip->set_number('1618565')->is_valid_number, '相模商工 株式会社');
ok($zip->set_number('1618567')->is_valid_number, '東京日産モーター 株式会社 丸山店');
ok($zip->set_number('1618575')->is_valid_number, '八千代エンジニヤリング 株式会社');
ok($zip->set_number('1618710')->is_valid_number, '株式会社 講談社');
ok($zip->set_number('1628001')->is_valid_number, '大日本印刷 株式会社');
ok($zip->set_number('1628005')->is_valid_number, '公益財団法人 東京都予防医学協会');
ok($zip->set_number('1628020')->is_valid_number, 'わらべや日洋 株式会社');
ok($zip->set_number('1628020')->is_valid_number, 'わらべや日洋ホールディングス 株式会社');
ok($zip->set_number('1628021')->is_valid_number, '株式会社 日洋');
ok($zip->set_number('1628022')->is_valid_number, '総務省 人事・恩給局');
ok($zip->set_number('1628055')->is_valid_number, '公益財団法人 日本英語検定協会');
ok($zip->set_number('1628060')->is_valid_number, '公益財団法人 日本英語検定協会 英検サービスセンター');
ok($zip->set_number('1628402')->is_valid_number, '公益財団法人 東京都予防医学協会');
ok($zip->set_number('1628407')->is_valid_number, '新日本法規出版 株式会社');
ok($zip->set_number('1628411')->is_valid_number, '株式会社 福田組 東京本店');
ok($zip->set_number('1628412')->is_valid_number, '独立行政法人 日本学生支援機構');
ok($zip->set_number('1628415')->is_valid_number, 'アンスティチュ・フランセ東京');
ok($zip->set_number('1628421')->is_valid_number, '株式会社 経済法令研究会');
ok($zip->set_number('1628422')->is_valid_number, '菱電エレベータ施設 株式会社');
ok($zip->set_number('1628433')->is_valid_number, '独立行政法人 国際協力機構研究所');
ok($zip->set_number('1628440')->is_valid_number, '東京産婦人科医会');
ok($zip->set_number('1628445')->is_valid_number, '成美堂出版 (株)');
ok($zip->set_number('1628448')->is_valid_number, '一般社団法人 家の光協会');
ok($zip->set_number('1628450')->is_valid_number, '株式会社 偕成社');
ok($zip->set_number('1628451')->is_valid_number, '持田製薬 株式会社 本社別館');
ok($zip->set_number('1628455')->is_valid_number, '株式会社 井田両国堂');
ok($zip->set_number('1628460')->is_valid_number, '公益財団法人 東京都予防医学協会 代謝異常検査センター');
ok($zip->set_number('1628464')->is_valid_number, '銀行業務検定協会');
ok($zip->set_number('1628471')->is_valid_number, '経済アナリスト協会');
ok($zip->set_number('1628473')->is_valid_number, '中央大学 市ヶ谷キャンパス');
ok($zip->set_number('1628476')->is_valid_number, '株式会社 インテリジェンス');
ok($zip->set_number('1628478')->is_valid_number, '中央大学 市ヶ谷田町キャンパス');
ok($zip->set_number('1628480')->is_valid_number, '早稲田大学 先端生命医科学センター');
ok($zip->set_number('1628484')->is_valid_number, '公益財団法人 ユネスコ・アジア文化センター');
ok($zip->set_number('1628488')->is_valid_number, '職業訓練法人 日本技能教育開発センター');
ok($zip->set_number('1628502')->is_valid_number, '株式会社 山文');
ok($zip->set_number('1628503')->is_valid_number, '東京シティ信用金庫 神楽坂支店');
ok($zip->set_number('1628505')->is_valid_number, '株式会社 日本スタデオ');
ok($zip->set_number('1628512')->is_valid_number, '株式会社 自治体研究社');
ok($zip->set_number('1628515')->is_valid_number, '株式会社 現代書林');
ok($zip->set_number('1628530')->is_valid_number, '三晃印刷 株式会社');
ok($zip->set_number('1628535')->is_valid_number, '株式会社 アプラス');
ok($zip->set_number('1628540')->is_valid_number, '株式会社 双葉社');
ok($zip->set_number('1628543')->is_valid_number, '東京厚生年金病院');
ok($zip->set_number('1628551')->is_valid_number, '有限責任 あずさ監査法人');
ok($zip->set_number('1628556')->is_valid_number, '株式会社 銀座コージーコーナー');
ok($zip->set_number('1628557')->is_valid_number, '株式会社 熊谷組');
ok($zip->set_number('1628558')->is_valid_number, '株式会社 アスク');
ok($zip->set_number('1628562')->is_valid_number, 'ゼブラ 株式会社');
ok($zip->set_number('1628565')->is_valid_number, '大興電子通信 株式会社');
ok($zip->set_number('1628575')->is_valid_number, '協立機電工業 株式会社');
ok($zip->set_number('1628585')->is_valid_number, '株式会社 TKC 東京本社');
ok($zip->set_number('1628587')->is_valid_number, '土地興業 株式会社');
ok($zip->set_number('1628601')->is_valid_number, '学校法人 東京理科大学');
ok($zip->set_number('1628602')->is_valid_number, '株式会社 新学社 東京支社');
ok($zip->set_number('1628604')->is_valid_number, '株式会社 ダイアプレス');
ok($zip->set_number('1628608')->is_valid_number, '株式会社 ピーズサイテック');
ok($zip->set_number('1628612')->is_valid_number, '東京都立新宿山吹高等学校');
ok($zip->set_number('1628614')->is_valid_number, '株式会社 大洋図書');
ok($zip->set_number('1628615')->is_valid_number, '株式会社 ムックハウス');
ok($zip->set_number('1628616')->is_valid_number, 'イカロス出版 株式会社');
ok($zip->set_number('1628620')->is_valid_number, '大日本印刷 株式会社 榎町工場');
ok($zip->set_number('1628624')->is_valid_number, '教職員共済生活協同組合');
ok($zip->set_number('1628626')->is_valid_number, '全国測量業 厚生年金基金');
ok($zip->set_number('1628628')->is_valid_number, '株式会社 サイエンス リサーチアンドコンサルティング');
ok($zip->set_number('1628636')->is_valid_number, '独立行政法人 国立健康・栄養研究所');
ok($zip->set_number('1628638')->is_valid_number, '東洋ゴム化工品 株式会社 ダイバーテックカンパニー環境工事システム販売部');
ok($zip->set_number('1628639')->is_valid_number, '東京都赤十字血液センター');
ok($zip->set_number('1628640')->is_valid_number, '国立感染症研究所');
ok($zip->set_number('1628644')->is_valid_number, '早稲田大学 第一文学部');
ok($zip->set_number('1628646')->is_valid_number, '共栄電資 株式会社');
ok($zip->set_number('1628650')->is_valid_number, '学習院女子大学');
ok($zip->set_number('1628654')->is_valid_number, '学校法人 早稲田高等学校');
ok($zip->set_number('1628655')->is_valid_number, '国立国際医療センター');
ok($zip->set_number('1628656')->is_valid_number, '学習院女子中・高等科');
ok($zip->set_number('1628666')->is_valid_number, '学校法人 東京女子医科大学');
ok($zip->set_number('1628668')->is_valid_number, '総務省 統計局');
ok($zip->set_number('1628669')->is_valid_number, '綜通 株式会社');
ok($zip->set_number('1628670')->is_valid_number, '成城中・高等学校');
ok($zip->set_number('1628680')->is_valid_number, '株式会社 旺文社');
ok($zip->set_number('1628701')->is_valid_number, '株式会社 ディスコ 神楽坂HCスタジオ');
ok($zip->set_number('1628707')->is_valid_number, '株式会社 朝倉書店');
ok($zip->set_number('1628710')->is_valid_number, '株式会社 トーハン');
ok($zip->set_number('1628711')->is_valid_number, '株式会社 新潮社');
ok($zip->set_number('1628716')->is_valid_number, '株式会社 音楽之友社');
ok($zip->set_number('1628717')->is_valid_number, '株式会社 学文社');
ok($zip->set_number('1628718')->is_valid_number, '株式会社 学文社');
ok($zip->set_number('1628801')->is_valid_number, '防衛省 内部部局');
ok($zip->set_number('1628802')->is_valid_number, '防衛省 陸上幕僚監部');
ok($zip->set_number('1628803')->is_valid_number, '防衛省 海上幕僚監部');
ok($zip->set_number('1628804')->is_valid_number, '防衛省 航空幕僚監部');
ok($zip->set_number('1628805')->is_valid_number, '防衛省 統合幕僚会議');
ok($zip->set_number('1628806')->is_valid_number, '防衛省 情報本部');
ok($zip->set_number('1628807')->is_valid_number, '防衛省 防衛監察本部');
ok($zip->set_number('1628808')->is_valid_number, '防衛省防衛研究所');
ok($zip->set_number('1628830')->is_valid_number, '防衛省 技術研究本部');
ok($zip->set_number('1628850')->is_valid_number, '自衛隊 東京地方 協力本部');
ok($zip->set_number('1628853')->is_valid_number, '防衛省 共済組合');
ok($zip->set_number('1628860')->is_valid_number, '防衛省 装備施設本部');
ok($zip->set_number('1628861')->is_valid_number, '防衛施設庁 内部部局');
ok($zip->set_number('1628953')->is_valid_number, '社会福祉法人 東京都社会福祉協議会');
ok($zip->set_number('1630261')->is_valid_number, '光ビジネスフォーム 株式会社');
ok($zip->set_number('1630268')->is_valid_number, '三井住友海上火災保険 (株)');
ok($zip->set_number('1630278')->is_valid_number, '株式会社 朝日カルチャーセンター 通信講座');
ok($zip->set_number('1630287')->is_valid_number, '司法書士法人 中央事務所');
ok($zip->set_number('1630456')->is_valid_number, 'アフラック・アセット・マネジメント 株式会社');
ok($zip->set_number('1630456')->is_valid_number, '日本法人化準備 株式会社');
ok($zip->set_number('1630456')->is_valid_number, 'アフラック');
ok($zip->set_number('1630478')->is_valid_number, '三和ホールディングス 株式会社');
ok($zip->set_number('1630553')->is_valid_number, 'ケーオーデンタル 株式会社');
ok($zip->set_number('1630557')->is_valid_number, '(株) 総合資格');
ok($zip->set_number('1630558')->is_valid_number, '松田産業 (株)');
ok($zip->set_number('1630560')->is_valid_number, '東京実業健康保険組合 城西支部');
ok($zip->set_number('1630562')->is_valid_number, '野村不動産パートナーズ 株式会社');
ok($zip->set_number('1630566')->is_valid_number, '野村不動産 (株)');
ok($zip->set_number('1630569')->is_valid_number, '日本デルファイ・オートモーティブ・システムズ 株式会社');
ok($zip->set_number('1630570')->is_valid_number, 'リードエグジビションジャパン 株式会社');
ok($zip->set_number('1630575')->is_valid_number, '住鉱潤滑剤 株式会社');
ok($zip->set_number('1630576')->is_valid_number, '野村不動産アーバンネット 株式会社');
ok($zip->set_number('1630655')->is_valid_number, 'TBCグループ 株式会社');
ok($zip->set_number('1630659')->is_valid_number, 'エス・バイ・エル (株) 東京支店');
ok($zip->set_number('1630663')->is_valid_number, '大和証券 株式会社 新宿センタービル支店');
ok($zip->set_number('1630665')->is_valid_number, '東京建物不動産販売 (株)');
ok($zip->set_number('1630669')->is_valid_number, '二幸産業 (株)');
ok($zip->set_number('1630675')->is_valid_number, '(株) ナック');
ok($zip->set_number('1630676')->is_valid_number, '株式会社 みずほ銀行 新宿新都心支店');
ok($zip->set_number('1630677')->is_valid_number, '芙蓉総合リース (株) 新宿支店');
ok($zip->set_number('1630727')->is_valid_number, '積水化成品工業 株式会社 東京本部');
ok($zip->set_number('1630777')->is_valid_number, '株式会社 日本システムディベロップメント');
ok($zip->set_number('1630831')->is_valid_number, 'セントラル警備保障 (株)');
ok($zip->set_number('1630833')->is_valid_number, 'ミサワホーム (株)');
ok($zip->set_number('1630836')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ 新宿支店');
ok($zip->set_number('1630850')->is_valid_number, 'ミサワホームホールディングス 株式会社');
ok($zip->set_number('1630867')->is_valid_number, '株式会社 京王エージェンシー');
ok($zip->set_number('1630936')->is_valid_number, '旭化成ホームズ 株式会社 集合住宅営業本部');
ok($zip->set_number('1630938')->is_valid_number, 'エボニック デグサ ジャパン 株式会社');
ok($zip->set_number('1630943')->is_valid_number, '有限会社 東京エイドセンター');
ok($zip->set_number('1631053')->is_valid_number, '東京ガス都市開発 (株)');
ok($zip->set_number('1631055')->is_valid_number, 'パークタワーホテル (株) パークハイアット東京');
ok($zip->set_number('1631061')->is_valid_number, '株式会社 NIPPO 関東第一支店');
ok($zip->set_number('1631065')->is_valid_number, '株式会社 JTB法人東京');
ok($zip->set_number('1631066')->is_valid_number, '株式会社 JTB法人東京');
ok($zip->set_number('1631071')->is_valid_number, '日本ロレアル 株式会社');
ok($zip->set_number('1631073')->is_valid_number, '日本ミシュランタイヤ 株式会社');
ok($zip->set_number('1631345')->is_valid_number, '独立行政法人 都市再生機構 募集販売本部');
ok($zip->set_number('1631349')->is_valid_number, 'オータ事務所 株式会社');
ok($zip->set_number('1631350')->is_valid_number, '有限会社 アイランド建設業経営状況分析センター');
ok($zip->set_number('1631363')->is_valid_number, '東日本住宅 (株)');
ok($zip->set_number('1631371')->is_valid_number, 'インセル 株式会社');
ok($zip->set_number('1631382')->is_valid_number, '独立行政法人 都市再生機構 東日本支社');
ok($zip->set_number('1631388')->is_valid_number, '日本シイエムケイ (株)');
ok($zip->set_number('1631455')->is_valid_number, '社団法人 電気通信協会');
ok($zip->set_number('1631470')->is_valid_number, '東京通販 株式会社');
ok($zip->set_number('1631488')->is_valid_number, 'サノフィ 株式会社');
ok($zip->set_number('1631533')->is_valid_number, '株式会社 三菱東京UFJ銀行 新宿新都心支店');
ok($zip->set_number('1631537')->is_valid_number, 'エムエスティ保険サービス 株式会社');
ok($zip->set_number('1631588')->is_valid_number, '(株) 日税ビジネスサービス');
ok($zip->set_number('1638001')->is_valid_number, '東京都庁');
ok($zip->set_number('1638003')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('1638012')->is_valid_number, 'アイタウンプラザ・アイタウンレピア');
ok($zip->set_number('1638019')->is_valid_number, '東日本電信電話 株式会社');
ok($zip->set_number('1638080')->is_valid_number, '株式会社 フジサンケイリビングサービス');
ok($zip->set_number('1638081')->is_valid_number, '株式会社 フジサンケイリビングサービス');
ok($zip->set_number('1638082')->is_valid_number, '株式会社 フジサンケイリビングサービス');
ok($zip->set_number('1638535')->is_valid_number, 'KDDI総合サービス 株式会社');
ok($zip->set_number('1638548')->is_valid_number, '株式会社 KDDIテレサーブ');
ok($zip->set_number('1638602')->is_valid_number, '三菱UFJ信託銀行 株式会社 新宿支店');
ok($zip->set_number('1638620')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('1638626')->is_valid_number, '損保ジャパン日本興亜ひまわり生命保険 株式会社');
ok($zip->set_number('1638638')->is_valid_number, '株式会社 日商データ・サービス');
ok($zip->set_number('1638639')->is_valid_number, '大正薬化工業');
ok($zip->set_number('1638660')->is_valid_number, '財団法人 実務教育研究所');
ok($zip->set_number('1638661')->is_valid_number, '株式会社 実務教育出版');
ok($zip->set_number('1638666')->is_valid_number, '商工組合中央金庫 新宿支店');
ok($zip->set_number('1638671')->is_valid_number, '株式会社 実務教育出版');
ok($zip->set_number('1638677')->is_valid_number, '学校法人 工学院大学');
ok($zip->set_number('1638680')->is_valid_number, '(株) ロッテリア');
ok($zip->set_number('1648501')->is_valid_number, '中野区役所');
ok($zip->set_number('1648503')->is_valid_number, '三協立山 株式会社');
ok($zip->set_number('1648504')->is_valid_number, '株式会社 インターコミュニケーションズ');
ok($zip->set_number('1648505')->is_valid_number, '株式会社 SCC');
ok($zip->set_number('1648512')->is_valid_number, '株式会社 中野サンプラザ');
ok($zip->set_number('1648522')->is_valid_number, '三和電気工業 株式会社');
ok($zip->set_number('1648525')->is_valid_number, '学校法人 明治大学 中野キャンパス');
ok($zip->set_number('1648530')->is_valid_number, '帝京平成大学 中野キャンパス');
ok($zip->set_number('1648540')->is_valid_number, '全国健康保険協会 東京支部');
ok($zip->set_number('1648541')->is_valid_number, '東京警察病院');
ok($zip->set_number('1648545')->is_valid_number, 'HOYA 株式会社');
ok($zip->set_number('1648550')->is_valid_number, '学校法人 森谷学園');
ok($zip->set_number('1648555')->is_valid_number, '三井情報 株式会社');
ok($zip->set_number('1648567')->is_valid_number, '株式会社 アポロ社');
ok($zip->set_number('1648570')->is_valid_number, '日本無線 株式会社');
ok($zip->set_number('1648585')->is_valid_number, '学校法人 窪田学園 窪田理容美容専門学校');
ok($zip->set_number('1648588')->is_valid_number, 'アーク・インターナショナル 株式会社');
ok($zip->set_number('1648601')->is_valid_number, '株式会社 エイト日本技術開発');
ok($zip->set_number('1648608')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('1648611')->is_valid_number, '株式会社 カーメイト');
ok($zip->set_number('1648616')->is_valid_number, '株式会社 ケンコー・トキナー');
ok($zip->set_number('1648617')->is_valid_number, '立正佼成会附属佼成病院');
ok($zip->set_number('1648620')->is_valid_number, '株式会社 矢野経済研究所');
ok($zip->set_number('1648631')->is_valid_number, 'こども教育宝仙大学');
ok($zip->set_number('1648638')->is_valid_number, '学校法人 新渡戸文化学園');
ok($zip->set_number('1648642')->is_valid_number, '入一通信工業 株式会社');
ok($zip->set_number('1648644')->is_valid_number, '株式会社 ジャパン イマジネーション');
ok($zip->set_number('1648650')->is_valid_number, '鉱研工業 株式会社');
ok($zip->set_number('1648666')->is_valid_number, '日本アルミット 株式会社');
ok($zip->set_number('1648677')->is_valid_number, '株式会社 ヴィアックス');
ok($zip->set_number('1648678')->is_valid_number, '学校法人 東京工芸大学');
ok($zip->set_number('1648682')->is_valid_number, '富士フイルムサービスクリエイティブ 株式会社');
ok($zip->set_number('1648686')->is_valid_number, '日商簿記専門学校(日商クリエーション)');
ok($zip->set_number('1648701')->is_valid_number, '株式会社 丸井');
ok($zip->set_number('1648705')->is_valid_number, '株式会社 日本ヴォーグ社');
ok($zip->set_number('1648725')->is_valid_number, 'NTT クオリス (株)');
ok($zip->set_number('1658555')->is_valid_number, '株式会社 クレディセゾン 顧客サービス部');
ok($zip->set_number('1658630')->is_valid_number, '株式会社 近代セールス社');
ok($zip->set_number('1658780')->is_valid_number, '東京法務局 民事行政部 動産・債券登録課');
ok($zip->set_number('1668501')->is_valid_number, '杉並税務署');
ok($zip->set_number('1668502')->is_valid_number, '東京都杉並都税事務所');
ok($zip->set_number('1668503')->is_valid_number, '東京都水道局 杉並東営業所');
ok($zip->set_number('1668520')->is_valid_number, '武蔵野産業 株式会社');
ok($zip->set_number('1668531')->is_valid_number, '立花産業 株式会社');
ok($zip->set_number('1668532')->is_valid_number, '全国大学生活協同組合連合会');
ok($zip->set_number('1668533')->is_valid_number, '救心製薬 株式会社');
ok($zip->set_number('1668535')->is_valid_number, '株式会社 佼成出版社');
ok($zip->set_number('1668537')->is_valid_number, '立正佼成会');
ok($zip->set_number('1668538')->is_valid_number, '学校法人 女子美術大学');
ok($zip->set_number('1668539')->is_valid_number, '社団法人 日本印刷技術協会');
ok($zip->set_number('1668540')->is_valid_number, '白石建設 株式会社');
ok($zip->set_number('1668542')->is_valid_number, '学校法人 中央ゼミナール');
ok($zip->set_number('1668545')->is_valid_number, '(株) 桐原書店');
ok($zip->set_number('1668565')->is_valid_number, '株式会社 ヴァル研究所');
ok($zip->set_number('1668566')->is_valid_number, '株式会社 ヴァル研究所');
ok($zip->set_number('1668567')->is_valid_number, '学校法人 立志舎');
ok($zip->set_number('1668570')->is_valid_number, '杉並区役所');
ok($zip->set_number('1668577')->is_valid_number, '株式会社 細田工務店');
ok($zip->set_number('1668578')->is_valid_number, '(株) 大丸ピーコック');
ok($zip->set_number('1668588')->is_valid_number, '医療法人財団 河北総合病院');
ok($zip->set_number('1678001')->is_valid_number, 'アメリカン・エキスプレス・インターナショナル.Inc.');
ok($zip->set_number('1678501')->is_valid_number, '株式会社 新星堂');
ok($zip->set_number('1678505')->is_valid_number, '株式会社 チヨダ');
ok($zip->set_number('1678506')->is_valid_number, '荻窪税務署');
ok($zip->set_number('1678507')->is_valid_number, '東京衛生病院');
ok($zip->set_number('1678510')->is_valid_number, '東亜紙巧業 株式会社');
ok($zip->set_number('1678515')->is_valid_number, '荻窪病院');
ok($zip->set_number('1678520')->is_valid_number, '丸美屋食品工業 株式会社');
ok($zip->set_number('1678534')->is_valid_number, '東京電力パワーグリッド 株式会社 荻窪支社');
ok($zip->set_number('1678551')->is_valid_number, 'ケーオーデンタル 株式会社');
ok($zip->set_number('1678555')->is_valid_number, '株式会社 小泉');
ok($zip->set_number('1678560')->is_valid_number, '『杉並文化村』');
ok($zip->set_number('1678585')->is_valid_number, '東京女子大学');
ok($zip->set_number('1678601')->is_valid_number, '株式会社 イー・エス・エス');
ok($zip->set_number('1678602')->is_valid_number, '株式会社 イー・エス・エス 配送センター');
ok($zip->set_number('1678610')->is_valid_number, '丸美屋食品工業 株式会社');
ok($zip->set_number('1678628')->is_valid_number, '株式会社 日本標準');
ok($zip->set_number('1688081')->is_valid_number, '株式会社 郵趣サービス社');
ok($zip->set_number('1688501')->is_valid_number, '岩崎通信機 株式会社');
ok($zip->set_number('1688503')->is_valid_number, '株式会社 岩通シャトルシステム');
ok($zip->set_number('1688504')->is_valid_number, '岩通アイセック 株式会社');
ok($zip->set_number('1688506')->is_valid_number, '朝日生命保険 相互会社');
ok($zip->set_number('1688508')->is_valid_number, '学校法人 高千穂学園');
ok($zip->set_number('1688510')->is_valid_number, '浴風会');
ok($zip->set_number('1688511')->is_valid_number, '岩通計測 株式会社');
ok($zip->set_number('1688512')->is_valid_number, '岩通計測製造 株式会社 久我山工場');
ok($zip->set_number('1688516')->is_valid_number, 'なないろ生命保険 株式会社');
ok($zip->set_number('1688520')->is_valid_number, '松風園');
ok($zip->set_number('1688525')->is_valid_number, '浴風会ケアハウス');
ok($zip->set_number('1688530')->is_valid_number, '浴風園');
ok($zip->set_number('1688533')->is_valid_number, 'ミサワホーム 株式会社');
ok($zip->set_number('1688535')->is_valid_number, '社会福祉法人 浴風会病院');
ok($zip->set_number('1688548')->is_valid_number, '日本年金機構健康保険組合');
ok($zip->set_number('1688550')->is_valid_number, '南陽園');
ok($zip->set_number('1688555')->is_valid_number, '学校法人 明治大学 和泉校舎');
ok($zip->set_number('1688558')->is_valid_number, '山崎製パン 株式会社 杉並工場');
ok($zip->set_number('1688560')->is_valid_number, '第二南陽園');
ok($zip->set_number('1688570')->is_valid_number, '宗教法人 大宮八幡宮');
ok($zip->set_number('1688580')->is_valid_number, '株式会社 スズキ自販東京');
ok($zip->set_number('1688601')->is_valid_number, '東京水道局 杉並西営業所');
ok($zip->set_number('1688608')->is_valid_number, 'アイデックスラボラトリーズ 株式会社');
ok($zip->set_number('1688611')->is_valid_number, '株式会社 アルク');
ok($zip->set_number('1688616')->is_valid_number, '学校法人 立教女学院');
ok($zip->set_number('1688620')->is_valid_number, '日本証券代行 株式会社 代理人部');
ok($zip->set_number('1688626')->is_valid_number, '立教女学院短期大学');
ok($zip->set_number('1688681')->is_valid_number, '株式会社 アルク');
ok($zip->set_number('1688686')->is_valid_number, 'サミット 株式会社');
ok($zip->set_number('1698011')->is_valid_number, '日本通信教育連盟');
ok($zip->set_number('1698012')->is_valid_number, '東京社会保険事務局');
ok($zip->set_number('1698050')->is_valid_number, '早稲田大学');
ok($zip->set_number('1698077')->is_valid_number, '株式会社 説話社 マイバースディ編集室');
ok($zip->set_number('1698228')->is_valid_number, '株式会社 ライトアップショッピングクラブ');
ok($zip->set_number('1698503')->is_valid_number, '呉羽化学工業 株式会社 生物医学研究所');
ok($zip->set_number('1698509')->is_valid_number, 'キリスト教学校教育同盟');
ok($zip->set_number('1698516')->is_valid_number, '関東ITソフトウェア健康保険組合');
ok($zip->set_number('1698517')->is_valid_number, '大久保健診センター');
ok($zip->set_number('1698518')->is_valid_number, '学校法人 日本教育研究団 社会情報大学院大学');
ok($zip->set_number('1698520')->is_valid_number, '株式会社 井成');
ok($zip->set_number('1698521')->is_valid_number, '社団法人 俳人協会');
ok($zip->set_number('1698522')->is_valid_number, '学校法人 電子学園 日本電子専門学校');
ok($zip->set_number('1698525')->is_valid_number, '株式会社 益田屋');
ok($zip->set_number('1698526')->is_valid_number, '生活協同組合パルシステム東京');
ok($zip->set_number('1698527')->is_valid_number, 'パルシステム生活協同組合連合会');
ok($zip->set_number('1698531')->is_valid_number, '株式会社 シジシージャパン');
ok($zip->set_number('1698535')->is_valid_number, '日本年金機構 会計部');
ok($zip->set_number('1698540')->is_valid_number, '日本赤十字社 東京都支部');
ok($zip->set_number('1698541')->is_valid_number, '東京税務会計事務所 健康保険組合');
ok($zip->set_number('1698550')->is_valid_number, '株式会社 三徳');
ok($zip->set_number('1698555')->is_valid_number, '早稲田大学 理工学部');
ok($zip->set_number('1698556')->is_valid_number, '東京都 電設工業厚生年金基金');
ok($zip->set_number('1698558')->is_valid_number, '株式会社 河田');
ok($zip->set_number('1698561')->is_valid_number, '新宿税務署');
ok($zip->set_number('1698568')->is_valid_number, '財団法人 実務技能検定協会');
ok($zip->set_number('1698570')->is_valid_number, '日拓エンタープライズ (株)');
ok($zip->set_number('1698577')->is_valid_number, '(株) 白夜書房');
ok($zip->set_number('1698578')->is_valid_number, '株式会社 ガイドワークス');
ok($zip->set_number('1698580')->is_valid_number, 'マルコメ (株) 東京支店');
ok($zip->set_number('1698586')->is_valid_number, '社会福祉法人 日本点字図書館');
ok($zip->set_number('1698605')->is_valid_number, '株式会社 ぱぁとわん');
ok($zip->set_number('1698608')->is_valid_number, '(株) 學燈社');
ok($zip->set_number('1698610')->is_valid_number, '警視庁 戸塚警察署');
ok($zip->set_number('1698611')->is_valid_number, 'シャプラニール 市民による海外協力の会');
ok($zip->set_number('1698612')->is_valid_number, '中央開発 株式会社');
ok($zip->set_number('1698613')->is_valid_number, '(株) リーガロイヤルホテル早稲田');
ok($zip->set_number('1698616')->is_valid_number, '(財) 早稲田奉仕園');
ok($zip->set_number('1698639')->is_valid_number, '株式会社 サンマーク');
ok($zip->set_number('1698644')->is_valid_number, '三葉化工 株式会社');
ok($zip->set_number('1698648')->is_valid_number, '東亜ディーケーケー 株式会社');
ok($zip->set_number('1698650')->is_valid_number, '全国建設労働組合総連合');
ok($zip->set_number('1698655')->is_valid_number, '株式会社 マツダアンフィニ東京');
ok($zip->set_number('1698664')->is_valid_number, '社会福祉法人 日本盲人会連合');
ok($zip->set_number('1698668')->is_valid_number, '花田歯科医院');
ok($zip->set_number('1698677')->is_valid_number, 'ビッグボックス西武スポーツプラザ');
ok($zip->set_number('1698701')->is_valid_number, '安田生命保険 相互会社');
ok($zip->set_number('1698711')->is_valid_number, '株式会社 日本文化センター');
ok($zip->set_number('1698722')->is_valid_number, '株式会社 プランネル');
ok($zip->set_number('1698885')->is_valid_number, 'アキレス 株式会社');
ok($zip->set_number('1698915')->is_valid_number, '日本文化出版 (株)');
ok($zip->set_number('1706080')->is_valid_number, 'アグリネット');
ok($zip->set_number('1708055')->is_valid_number, '独立行政法人 勤労者退職金共済機構');
ok($zip->set_number('1708073')->is_valid_number, '一般社団法人 日本アマチュア無線連盟');
ok($zip->set_number('1708401')->is_valid_number, '株式会社 マルエツ');
ok($zip->set_number('1708402')->is_valid_number, '株式会社 クレディセゾン 東京営業所');
ok($zip->set_number('1708404')->is_valid_number, '株式会社 ファミリーマート 本部');
ok($zip->set_number('1708405')->is_valid_number, 'トヨタ自動車 株式会社 池袋ビル');
ok($zip->set_number('1708406')->is_valid_number, 'カードショップ 羅針盤');
ok($zip->set_number('1708409')->is_valid_number, '池袋公共職業安定所(ハローワーク池袋)');
ok($zip->set_number('1708410')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('1708411')->is_valid_number, 'NTTインターナショナル (株)');
ok($zip->set_number('1708415')->is_valid_number, '株式会社 ワンダーライフ');
ok($zip->set_number('1708416')->is_valid_number, 'デュプロ 株式会社');
ok($zip->set_number('1708417')->is_valid_number, '株式会社 倉本産業');
ok($zip->set_number('1708419')->is_valid_number, 'ビックカメラ 本店');
ok($zip->set_number('1708420')->is_valid_number, '日本信販 株式会社 事務システム本部');
ok($zip->set_number('1708421')->is_valid_number, 'ダイワ商事 株式会社');
ok($zip->set_number('1708423')->is_valid_number, 'テンプスタッフ 株式会社');
ok($zip->set_number('1708424')->is_valid_number, '良品計画・東池袋');
ok($zip->set_number('1708426')->is_valid_number, '学校法人 東京福祉大学');
ok($zip->set_number('1708427')->is_valid_number, '株式会社 芸文社');
ok($zip->set_number('1708430')->is_valid_number, 'ドコモサービス 株式会社 東京モバイル第一料金センター');
ok($zip->set_number('1708432')->is_valid_number, '株式会社 三貴');
ok($zip->set_number('1708433')->is_valid_number, '株式会社 池袋ショッピングパーク');
ok($zip->set_number('1708434')->is_valid_number, '学校法人 サンシャイン学園');
ok($zip->set_number('1708436')->is_valid_number, 'サミー 株式会社');
ok($zip->set_number('1708438')->is_valid_number, '株式会社 ビーエフ');
ok($zip->set_number('1708440')->is_valid_number, 'サンシャインシティプリンスホテル');
ok($zip->set_number('1708441')->is_valid_number, '木内建設 株式会社 東京支店');
ok($zip->set_number('1708442')->is_valid_number, '豊島区立中央図書館');
ok($zip->set_number('1708444')->is_valid_number, '学校法人 都築関東学園東京国際情報ビジネス専門学校');
ok($zip->set_number('1708448')->is_valid_number, '菱電商事 株式会社');
ok($zip->set_number('1708450')->is_valid_number, '株式会社 アーバンウエスト');
ok($zip->set_number('1708451')->is_valid_number, '山洋電気 株式会社');
ok($zip->set_number('1708455')->is_valid_number, '財団法人 癌研究会');
ok($zip->set_number('1708456')->is_valid_number, '東都化学工業 株式会社');
ok($zip->set_number('1708457')->is_valid_number, '株式会社 ベストセラーズ');
ok($zip->set_number('1708458')->is_valid_number, '(社) 全日本ピアノ指導者協会');
ok($zip->set_number('1708459')->is_valid_number, '株式会社 ユーコー');
ok($zip->set_number('1708460')->is_valid_number, '株式会社 銀行研修社');
ok($zip->set_number('1708462')->is_valid_number, 'アスビルトレーディング 株式会社');
ok($zip->set_number('1708465')->is_valid_number, '株式会社 東京めいらく');
ok($zip->set_number('1708466')->is_valid_number, '株式会社 日立プラントテクノロジー');
ok($zip->set_number('1708470')->is_valid_number, '大正大学');
ok($zip->set_number('1708474')->is_valid_number, '株式会社 日本評論社');
ok($zip->set_number('1708476')->is_valid_number, '東京都立大塚病院');
ok($zip->set_number('1708477')->is_valid_number, '巣鴨信用金庫');
ok($zip->set_number('1708480')->is_valid_number, '一般財団法人 情報通信振興会');
ok($zip->set_number('1708488')->is_valid_number, '永田精機 株式会社');
ok($zip->set_number('1708551')->is_valid_number, 'ナウカ 株式会社');
ok($zip->set_number('1708585')->is_valid_number, '財団法人 日本データ通信協会');
ok($zip->set_number('1708602')->is_valid_number, 'みずほ銀行 池袋支店');
ok($zip->set_number('1708605')->is_valid_number, '中央三井信託銀行');
ok($zip->set_number('1708633')->is_valid_number, '大正製薬 株式会社');
ok($zip->set_number('1708635')->is_valid_number, '大正富山医薬品 株式会社');
ok($zip->set_number('1708655')->is_valid_number, '大正製薬ホールディングス 株式会社');
ok($zip->set_number('1708666')->is_valid_number, '有限会社 エンゼルダイレクト');
ok($zip->set_number('1708686')->is_valid_number, '株式会社 日本香堂');
ok($zip->set_number('1718422')->is_valid_number, '豊島区役所');
ok($zip->set_number('1718501')->is_valid_number, '立教大学');
ok($zip->set_number('1718502')->is_valid_number, '池袋労働基準監督署');
ok($zip->set_number('1718503')->is_valid_number, '財団法人 関東電気保安協会');
ok($zip->set_number('1718505')->is_valid_number, 'ホテルメトロポリタン');
ok($zip->set_number('1718507')->is_valid_number, '東京法務局 豊島出張所');
ok($zip->set_number('1718508')->is_valid_number, '三菱信託銀行 株式会社 証券代行部');
ok($zip->set_number('1718510')->is_valid_number, '株式会社 婦人之友社');
ok($zip->set_number('1718511')->is_valid_number, '株式会社 建築資料研究社');
ok($zip->set_number('1718512')->is_valid_number, '株式会社 東武百貨店 池袋店');
ok($zip->set_number('1718514')->is_valid_number, '株式会社 日立国際電気サービス');
ok($zip->set_number('1718516')->is_valid_number, '日本加除出版 株式会社');
ok($zip->set_number('1718518')->is_valid_number, '(株) アップルホテルズ');
ok($zip->set_number('1718520')->is_valid_number, 'ハナシン 株式会社');
ok($zip->set_number('1718521')->is_valid_number, '豊島税務署');
ok($zip->set_number('1718522')->is_valid_number, 'オリヒロ 株式会社 東京支店');
ok($zip->set_number('1718523')->is_valid_number, '警視庁 池袋通告センター');
ok($zip->set_number('1718525')->is_valid_number, 'リコーエレメックス 株式会社');
ok($zip->set_number('1718526')->is_valid_number, '養老乃瀧 株式会社');
ok($zip->set_number('1718527')->is_valid_number, '株式会社 ジェムスタージャパン');
ok($zip->set_number('1718531')->is_valid_number, '綜研化学 株式会社');
ok($zip->set_number('1718539')->is_valid_number, 'ワールドファミリー 株式会社');
ok($zip->set_number('1718540')->is_valid_number, '東京音楽大学');
ok($zip->set_number('1718544')->is_valid_number, '東洋ゴム工業 株式会社 東京本社');
ok($zip->set_number('1718545')->is_valid_number, '中外製薬 株式会社 中央研究所');
ok($zip->set_number('1718552')->is_valid_number, '白十字 株式会社');
ok($zip->set_number('1718553')->is_valid_number, '株式会社 コアマガジン');
ok($zip->set_number('1718555')->is_valid_number, 'オリジン電気 株式会社');
ok($zip->set_number('1718557')->is_valid_number, '株式会社 パルコ');
ok($zip->set_number('1718558')->is_valid_number, 'エヌピー通信社');
ok($zip->set_number('1718560')->is_valid_number, '株木建設 株式会社 本社');
ok($zip->set_number('1718561')->is_valid_number, '株木建設 株式会社 東京支店');
ok($zip->set_number('1718568')->is_valid_number, '株式会社 清和ライフサービス');
ok($zip->set_number('1718569')->is_valid_number, '株式会社 西武百貨店 池袋店');
ok($zip->set_number('1718570')->is_valid_number, '株式会社 白夜書房');
ok($zip->set_number('1718572')->is_valid_number, '鉱研工業 株式会社');
ok($zip->set_number('1718577')->is_valid_number, '(有) オートショップ馬力屋');
ok($zip->set_number('1718580')->is_valid_number, '株式会社 デサント東京オフィス');
ok($zip->set_number('1718582')->is_valid_number, '株式会社 日本ドリコム');
ok($zip->set_number('1718586')->is_valid_number, '(財) 実務技能検定協会');
ok($zip->set_number('1718588')->is_valid_number, '学校法人 学習院・学習院大学・学習院幼稚園');
ok($zip->set_number('1738501')->is_valid_number, '東京都 板橋区役所');
ok($zip->set_number('1738510')->is_valid_number, '東京都板橋都税事務所');
ok($zip->set_number('1738511')->is_valid_number, '株式会社 モトヤ 東京本社');
ok($zip->set_number('1738512')->is_valid_number, '株式会社 ハリカ');
ok($zip->set_number('1738515')->is_valid_number, '国立極地研究所');
ok($zip->set_number('1738516')->is_valid_number, '(株) マツダアンフィニ東京');
ok($zip->set_number('1738517')->is_valid_number, '(株) マツダアンフィニ南東京');
ok($zip->set_number('1738518')->is_valid_number, '(株) マツダアンフィニ西東京');
ok($zip->set_number('1738519')->is_valid_number, '(株) マツダアンフィニ北東京');
ok($zip->set_number('1738520')->is_valid_number, '東京都主税局徴収部納税推進課');
ok($zip->set_number('1738530')->is_valid_number, '板橋税務署');
ok($zip->set_number('1738540')->is_valid_number, 'エクシオ物流サービス 株式会社');
ok($zip->set_number('1738543')->is_valid_number, '松崎商事 株式会社');
ok($zip->set_number('1738552')->is_valid_number, '株式会社 イシダ 東京支店');
ok($zip->set_number('1738555')->is_valid_number, '学校法人 帝京学園 帝京中学校 帝京高等学校');
ok($zip->set_number('1738558')->is_valid_number, '株式会社 ムービック');
ok($zip->set_number('1738561')->is_valid_number, '株式会社 フロンティアワークス');
ok($zip->set_number('1738580')->is_valid_number, '昭産商事 株式会社');
ok($zip->set_number('1738585')->is_valid_number, '株式会社 コバックス');
ok($zip->set_number('1738588')->is_valid_number, '財団法人 愛世会 愛誠病院');
ok($zip->set_number('1738601')->is_valid_number, '株式会社 ライカ 東京支店');
ok($zip->set_number('1738602')->is_valid_number, '東京家政大学');
ok($zip->set_number('1738605')->is_valid_number, '帝京大学');
ok($zip->set_number('1738606')->is_valid_number, '帝京大学医学部附属病院');
ok($zip->set_number('1738610')->is_valid_number, '日本大学 医学部');
ok($zip->set_number('1738611')->is_valid_number, '板橋工業 株式会社');
ok($zip->set_number('1738632')->is_valid_number, '株式会社 チノー');
ok($zip->set_number('1738639')->is_valid_number, 'カネボウフーズ 株式会社');
ok($zip->set_number('1738648')->is_valid_number, '富士テレコム 株式会社');
ok($zip->set_number('1738710')->is_valid_number, '株式会社 日刊建設産業新聞社');
ok($zip->set_number('1748501')->is_valid_number, 'トックベアリング (株)');
ok($zip->set_number('1748503')->is_valid_number, '株式会社 TJMデザイン');
ok($zip->set_number('1748505')->is_valid_number, 'オリエンタル酵母工業 株式会社');
ok($zip->set_number('1748510')->is_valid_number, '凸版物流 株式会社');
ok($zip->set_number('1748520')->is_valid_number, 'DICグラフィックス 株式会社');
ok($zip->set_number('1748521')->is_valid_number, '東京日野自動車 株式会社');
ok($zip->set_number('1748524')->is_valid_number, '芝浦工業大学中学高等学校');
ok($zip->set_number('1748525')->is_valid_number, '富士フイルムシステムサービス 株式会社');
ok($zip->set_number('1748526')->is_valid_number, '電設健保総合健康管理センター');
ok($zip->set_number('1748530')->is_valid_number, '群峰アクシア 株式会社');
ok($zip->set_number('1748550')->is_valid_number, '日本電産コパル 株式会社');
ok($zip->set_number('1748555')->is_valid_number, '株式会社 LSIメディエンス');
ok($zip->set_number('1748558')->is_valid_number, '凸版印刷 株式会社 情報コミュニケーション事業本部');
ok($zip->set_number('1748560')->is_valid_number, '日本金属 株式会社 板橋工場');
ok($zip->set_number('1748562')->is_valid_number, 'アスクルDCM 第2物流センター');
ok($zip->set_number('1748567')->is_valid_number, '(株) 鈴木商館');
ok($zip->set_number('1748580')->is_valid_number, '株式会社 トプコン');
ok($zip->set_number('1748588')->is_valid_number, '淑徳小学校');
ok($zip->set_number('1748601')->is_valid_number, '(株) タニタハウジングウェア');
ok($zip->set_number('1748602')->is_valid_number, 'ナカバヤシ 株式会社 東京本社');
ok($zip->set_number('1748612')->is_valid_number, 'アステラス製薬 株式会社 総務室');
ok($zip->set_number('1748630')->is_valid_number, '株式会社 タニタ');
ok($zip->set_number('1748633')->is_valid_number, '(株) ライト製作所');
ok($zip->set_number('1748636')->is_valid_number, '千葉金属工業 株式会社');
ok($zip->set_number('1748639')->is_valid_number, 'ペンタックス 株式会社');
ok($zip->set_number('1748646')->is_valid_number, '淑徳幼児教育専門学校');
ok($zip->set_number('1748651')->is_valid_number, 'エスビー食品 株式会社 板橋スパイスセンター');
ok($zip->set_number('1748680')->is_valid_number, '飯沼病院');
ok($zip->set_number('1748686')->is_valid_number, '医療法人 慈誠会 上板橋病院');
ok($zip->set_number('1748688')->is_valid_number, '日本教育書道連盟、財団法人 日本書道美術館');
ok($zip->set_number('1748701')->is_valid_number, '株式会社 昭和コーポレーション');
ok($zip->set_number('1748711')->is_valid_number, '城北学園');
ok($zip->set_number('1748730')->is_valid_number, '金門製作所');
ok($zip->set_number('1748737')->is_valid_number, '株式会社 中央社');
ok($zip->set_number('1748739')->is_valid_number, '栗田出版販売');
ok($zip->set_number('1748740')->is_valid_number, '東京セールスプロデュース (株)');
ok($zip->set_number('1748741')->is_valid_number, '(株) ディーエムエス');
ok($zip->set_number('1748743')->is_valid_number, '(株) ディーエムエス');
ok($zip->set_number('1748744')->is_valid_number, '理研計器 株式会社');
ok($zip->set_number('1748787')->is_valid_number, '警視庁 志村警察署');
ok($zip->set_number('1748860')->is_valid_number, '共立印刷 (株)');
ok($zip->set_number('1748903')->is_valid_number, '清水産業 (株)');
ok($zip->set_number('1758571')->is_valid_number, '学校法人 大東文化学園');
ok($zip->set_number('1758588')->is_valid_number, '日本電機ヒーター 株式会社');
ok($zip->set_number('1768501')->is_valid_number, '練馬区役所');
ok($zip->set_number('1768502')->is_valid_number, '株式会社 シコクヤ');
ok($zip->set_number('1768503')->is_valid_number, '練馬東税務署');
ok($zip->set_number('1768507')->is_valid_number, 'アイカ販売 株式会社');
ok($zip->set_number('1768508')->is_valid_number, '太陽インキ製造 株式会社');
ok($zip->set_number('1768509')->is_valid_number, '東京都都税総合事務センター 自動車税課調査班');
ok($zip->set_number('1768511')->is_valid_number, '東京都練馬都税事務所');
ok($zip->set_number('1768512')->is_valid_number, '品川電線 株式会社');
ok($zip->set_number('1768515')->is_valid_number, '東京電力 株式会社 練馬営業センター');
ok($zip->set_number('1768516')->is_valid_number, '三菱電線工業 株式会社');
ok($zip->set_number('1768517')->is_valid_number, '東京都都税総合事務センター 自動車税課課税班');
ok($zip->set_number('1768518')->is_valid_number, '株式会社 永岡書店');
ok($zip->set_number('1768521')->is_valid_number, '学校法人 武蔵野音楽学園');
ok($zip->set_number('1768522')->is_valid_number, '野口興産 株式会社');
ok($zip->set_number('1768525')->is_valid_number, '日本大学 芸術学部');
ok($zip->set_number('1768526')->is_valid_number, '東京都都税総合事務センター 還付管理課');
ok($zip->set_number('1768528')->is_valid_number, 'アジアカラー 株式会社');
ok($zip->set_number('1768530')->is_valid_number, '練馬総合病院');
ok($zip->set_number('1768531')->is_valid_number, '株式会社 豊島園');
ok($zip->set_number('1768533')->is_valid_number, '学校法人 根津育英会武蔵学園');
ok($zip->set_number('1768534')->is_valid_number, '武蔵大学');
ok($zip->set_number('1768535')->is_valid_number, '武蔵高等学校・中学校');
ok($zip->set_number('1768536')->is_valid_number, '内野建設 株式会社');
ok($zip->set_number('1768540')->is_valid_number, '都水道局 練馬東営業所');
ok($zip->set_number('1768560')->is_valid_number, '(株) 協和');
ok($zip->set_number('1768585')->is_valid_number, '三笠製薬 株式会社');
ok($zip->set_number('1778501')->is_valid_number, '大陽ステンレススプリング (株)');
ok($zip->set_number('1778502')->is_valid_number, '独立行政法人 労働政策研究・研修機構');
ok($zip->set_number('1778503')->is_valid_number, '株式会社 アートプリントジャパン');
ok($zip->set_number('1778508')->is_valid_number, '社団法人 練馬区医師会');
ok($zip->set_number('1778509')->is_valid_number, '練馬区石神井庁舎');
ok($zip->set_number('1778521')->is_valid_number, '順天堂大学医学部附属 練馬病院');
ok($zip->set_number('1788501')->is_valid_number, '陸上自衛隊 朝霞駐屯地');
ok($zip->set_number('1788502')->is_valid_number, '株式会社 西友オズ 大泉西武店');
ok($zip->set_number('1788511')->is_valid_number, '株式会社 タムラ製作所');
ok($zip->set_number('1788567')->is_valid_number, '東映アニメーション 株式会社');
ok($zip->set_number('1788601')->is_valid_number, '大泉 総合福祉事務所');
ok($zip->set_number('1788624')->is_valid_number, '練馬西 税務署');
ok($zip->set_number('1788666')->is_valid_number, '東映 株式会社 東京撮影所');
ok($zip->set_number('1788686')->is_valid_number, '株式会社 セコニック');
ok($zip->set_number('1798501')->is_valid_number, '東京法務局 練馬出張所');
ok($zip->set_number('1798901')->is_valid_number, '松下ライフエレクトロニクス (株)');
ok($zip->set_number('1798903')->is_valid_number, '前田建設 (株)');
ok($zip->set_number('1798904')->is_valid_number, '河端建設 (株)');
ok($zip->set_number('1798906')->is_valid_number, '光が丘パークヴィラ');
ok($zip->set_number('1798907')->is_valid_number, '光が丘高等学校');
ok($zip->set_number('1798909')->is_valid_number, '練馬工業高等学校');
ok($zip->set_number('1798911')->is_valid_number, 'トモダ企画');
ok($zip->set_number('1798914')->is_valid_number, '前田建設 技術研究所');
ok($zip->set_number('1808505')->is_valid_number, '学校法人 井之頭学園藤村女子中学・高等学校');
ok($zip->set_number('1808508')->is_valid_number, '株式会社 日本マイクロニクス');
ok($zip->set_number('1808517')->is_valid_number, 'サンケイリビング新聞社 武蔵野本部');
ok($zip->set_number('1808519')->is_valid_number, '株式会社 東急百貨店 吉祥寺店');
ok($zip->set_number('1808520')->is_valid_number, '株式会社 パルコ 吉祥寺店');
ok($zip->set_number('1808522')->is_valid_number, '武蔵野税務署');
ok($zip->set_number('1808527')->is_valid_number, '株式会社 冬水社');
ok($zip->set_number('1808531')->is_valid_number, '三井生命 武蔵野支社');
ok($zip->set_number('1808533')->is_valid_number, '名糖運輸 株式会社');
ok($zip->set_number('1808538')->is_valid_number, '株式会社 モンテローザ');
ok($zip->set_number('1808566')->is_valid_number, '学校法人 武蔵野美術大学 武蔵野美術学園 武蔵野美術大学短期大学部 通信教育部');
ok($zip->set_number('1808571')->is_valid_number, '多摩信用金庫 武蔵野支店');
ok($zip->set_number('1808577')->is_valid_number, '東京電力 株式会社 武蔵野支社');
ok($zip->set_number('1808580')->is_valid_number, '株式会社 すかいらーくホールディングス');
ok($zip->set_number('1808602')->is_valid_number, '日本獣医畜産大学');
ok($zip->set_number('1808608')->is_valid_number, '株式会社 すかいらーくD&M');
ok($zip->set_number('1808610')->is_valid_number, '武蔵野赤十字病院');
ok($zip->set_number('1808611')->is_valid_number, 'ユニダックス 株式会社');
ok($zip->set_number('1808618')->is_valid_number, '日本赤十字武蔵野短期大学');
ok($zip->set_number('1808629')->is_valid_number, '学校法人 亜細亜学園');
ok($zip->set_number('1808633')->is_valid_number, '学校法人 成蹊学園(成蹊大学・成蹊高等学校・成蹊中学校・成蹊小学校)');
ok($zip->set_number('1808750')->is_valid_number, '横河電機 株式会社');
ok($zip->set_number('1808777')->is_valid_number, '武蔵野市役所');
ok($zip->set_number('1818001')->is_valid_number, '株式会社 ジェーシービー JCBカードセンター');
ok($zip->set_number('1818503')->is_valid_number, '医療法人財団 慈生会 野村病院');
ok($zip->set_number('1818505')->is_valid_number, '三鷹市教育委員会');
ok($zip->set_number('1818511')->is_valid_number, 'セントラル・コンピュータ・サービス 株式会社 情報通信センター');
ok($zip->set_number('1818517')->is_valid_number, '三鷹公共職業安定所');
ok($zip->set_number('1818518')->is_valid_number, '春日電機 株式会社');
ok($zip->set_number('1818521')->is_valid_number, 'セコムTEセンター');
ok($zip->set_number('1818522')->is_valid_number, '株式会社 ジャパンエナジー JOMOカードセンター');
ok($zip->set_number('1818528')->is_valid_number, 'セコムSCセンター');
ok($zip->set_number('1818531')->is_valid_number, '財団法人 井之頭病院');
ok($zip->set_number('1818533')->is_valid_number, 'アツデン 株式会社');
ok($zip->set_number('1818535')->is_valid_number, '株式会社 テスコ');
ok($zip->set_number('1818541')->is_valid_number, 'サンマルイ (株) 西東京カンパニー');
ok($zip->set_number('1818551')->is_valid_number, '酒井薬品 株式会社');
ok($zip->set_number('1818555')->is_valid_number, '三鷹市役所');
ok($zip->set_number('1818567')->is_valid_number, '株式会社 Jマート');
ok($zip->set_number('1818571')->is_valid_number, '株式会社 ジャムコ');
ok($zip->set_number('1818577')->is_valid_number, '富士重工業 株式会社 東京事業所');
ok($zip->set_number('1818585')->is_valid_number, '学校法人 国際基督教大学(ICU)');
ok($zip->set_number('1818586')->is_valid_number, '長谷川病院');
ok($zip->set_number('1818588')->is_valid_number, '大学共同利用機関法人 自然科学研究機構 国立天文台');
ok($zip->set_number('1818601')->is_valid_number, 'アサカ物産 株式会社');
ok($zip->set_number('1818608')->is_valid_number, 'アイデックスラボラトリーズ 株式会社');
ok($zip->set_number('1818611')->is_valid_number, '学校法人 杏林学園');
ok($zip->set_number('1818612')->is_valid_number, '学校法人 杏林学園 杏林大学井の頭キャンパス');
ok($zip->set_number('1818614')->is_valid_number, '杏林大学医学部付属看護専門学校');
ok($zip->set_number('1818622')->is_valid_number, '株式会社 日立製作所 ヘルスケア 三鷹事業所');
ok($zip->set_number('1818633')->is_valid_number, '消防研究所');
ok($zip->set_number('1818648')->is_valid_number, 'いずみ書房 株式会社');
ok($zip->set_number('1828001')->is_valid_number, 'アフラック調布サウスゲートビル');
ok($zip->set_number('1828006')->is_valid_number, 'アフラック 調布スクエアビル');
ok($zip->set_number('1828508')->is_valid_number, '消防大学校');
ok($zip->set_number('1828510')->is_valid_number, '桐朋学園 女子部門');
ok($zip->set_number('1828511')->is_valid_number, '調布市役所');
ok($zip->set_number('1828512')->is_valid_number, '林建設 株式会社');
ok($zip->set_number('1828520')->is_valid_number, '株式会社 共和電業');
ok($zip->set_number('1828522')->is_valid_number, '国立研究開発法人 宇宙航空研究開発機構');
ok($zip->set_number('1828525')->is_valid_number, '白百合女子大学');
ok($zip->set_number('1828555')->is_valid_number, '株式会社 東京現像所');
ok($zip->set_number('1828558')->is_valid_number, 'キユーピー 株式会社 仙川工場');
ok($zip->set_number('1828567')->is_valid_number, '小田急バス 株式会社');
ok($zip->set_number('1828570')->is_valid_number, '東京慈恵会 医科大学');
ok($zip->set_number('1828585')->is_valid_number, '電気通信大学');
ok($zip->set_number('1828601')->is_valid_number, '第百生命保険 相互会社');
ok($zip->set_number('1828602')->is_valid_number, '島田理化工業 (株)');
ok($zip->set_number('1828621')->is_valid_number, 'マニュライフ・センチュリー生命保険 株式会社');
ok($zip->set_number('1828686')->is_valid_number, '株式会社 フジカラーサービス 東京事業所');
ok($zip->set_number('1838501')->is_valid_number, '日本電気 株式会社 府中事業場');
ok($zip->set_number('1838502')->is_valid_number, 'NEC中河原技術センター');
ok($zip->set_number('1838505')->is_valid_number, '府中社会保険事務所');
ok($zip->set_number('1838506')->is_valid_number, '警視庁 府中運転免許試験場');
ok($zip->set_number('1838511')->is_valid_number, '(株) 東芝 府中事業所');
ok($zip->set_number('1838512')->is_valid_number, '東芝ソリューション 株式会社 府中ソリューションセンター');
ok($zip->set_number('1838513')->is_valid_number, '東芝プラントシステム 株式会社 府中事務所');
ok($zip->set_number('1838514')->is_valid_number, '多摩川競艇場');
ok($zip->set_number('1838516')->is_valid_number, '横河ディジタルコンピュータ 株式会社');
ok($zip->set_number('1838519')->is_valid_number, '株式会社 田原電機製作所');
ok($zip->set_number('1838521')->is_valid_number, '航空自衛隊 府中基地');
ok($zip->set_number('1838522')->is_valid_number, '株式会社 ドライバースタンド');
ok($zip->set_number('1838524')->is_valid_number, '東京都立 多摩総合医療センター');
ok($zip->set_number('1838525')->is_valid_number, '府中市生涯学習センター');
ok($zip->set_number('1838526')->is_valid_number, '財団法人 東京都神経科学総合研究所');
ok($zip->set_number('1838528')->is_valid_number, '東芝ITサービス 株式会社');
ok($zip->set_number('1838529')->is_valid_number, '(株) 大東京綜合卸売センター');
ok($zip->set_number('1838530')->is_valid_number, '株式会社 五藤光学研究所');
ok($zip->set_number('1838532')->is_valid_number, '東芝ソリューション 株式会社 府中エンジニアリングセンター');
ok($zip->set_number('1838534')->is_valid_number, '東京外国語大学');
ok($zip->set_number('1838536')->is_valid_number, 'モランボン 株式会社');
ok($zip->set_number('1838539')->is_valid_number, '株式会社 セイジョー');
ok($zip->set_number('1838540')->is_valid_number, '株式会社 ワイ・ディ・シー');
ok($zip->set_number('1838541')->is_valid_number, '株式会社 伊勢丹 府中店');
ok($zip->set_number('1838548')->is_valid_number, '武蔵府中税務署');
ok($zip->set_number('1838549')->is_valid_number, '東京都 府中都税支所');
ok($zip->set_number('1838550')->is_valid_number, '東京競馬場');
ok($zip->set_number('1838551')->is_valid_number, 'NECスペーステクノロジー 株式会社');
ok($zip->set_number('1838553')->is_valid_number, '東京都立 府中療育センター');
ok($zip->set_number('1838561')->is_valid_number, '東京都立 小児総合医療センター');
ok($zip->set_number('1838570')->is_valid_number, 'アマゾン府中FC');
ok($zip->set_number('1838585')->is_valid_number, '警視庁 警察学校');
ok($zip->set_number('1838701')->is_valid_number, '三井住友信託銀行 株式会社');
ok($zip->set_number('1838702')->is_valid_number, '日本銀行 府中分館');
ok($zip->set_number('1838703')->is_valid_number, '府中市役所');
ok($zip->set_number('1838705')->is_valid_number, '東京エレクトロン 株式会社 府中テクノロジーセンター');
ok($zip->set_number('1838706')->is_valid_number, '自動車安全運転センター 東京都事務所');
ok($zip->set_number('1838707')->is_valid_number, '株式会社 スーパーヤマザキ');
ok($zip->set_number('1848501')->is_valid_number, '東京学芸大学');
ok($zip->set_number('1848502')->is_valid_number, '株式会社 ヤジマ');
ok($zip->set_number('1848503')->is_valid_number, '国際基督教大学高等学校');
ok($zip->set_number('1848504')->is_valid_number, '小金井市役所');
ok($zip->set_number('1848505')->is_valid_number, 'あいおい損害保険 (株)');
ok($zip->set_number('1848508')->is_valid_number, '財団法人 日本リハビリテーション振興会専門学校社会医学技術学院');
ok($zip->set_number('1848510')->is_valid_number, '株式会社 長崎屋 小金井店');
ok($zip->set_number('1848511')->is_valid_number, '社会福祉法人 聖ヨハネ会総合病院 桜町病院');
ok($zip->set_number('1848515')->is_valid_number, 'アイデックスラボラトリーズ 株式会社');
ok($zip->set_number('1848522')->is_valid_number, '株式会社 ムラコシ');
ok($zip->set_number('1848533')->is_valid_number, '株式会社 コガネイ');
ok($zip->set_number('1848543')->is_valid_number, '学校法人 東京工学院専門学校');
ok($zip->set_number('1848555')->is_valid_number, '東京電機大学中学校・高等学校');
ok($zip->set_number('1848558')->is_valid_number, '医療法人財団 美生会小金井病院');
ok($zip->set_number('1848575')->is_valid_number, '中央大学附属高等学校');
ok($zip->set_number('1848577')->is_valid_number, '劇団ふるさときゃらばん');
ok($zip->set_number('1848581')->is_valid_number, '東京都立小金井工業高等学校');
ok($zip->set_number('1848584')->is_valid_number, '法政大学');
ok($zip->set_number('1848585')->is_valid_number, '医療法人社団 総合会武蔵野中央病院');
ok($zip->set_number('1848588')->is_valid_number, '東京農工大学 工学部');
ok($zip->set_number('1848595')->is_valid_number, '株式会社 ムラコシ精工');
ok($zip->set_number('1848795')->is_valid_number, '国立研究開発法人 情報通信研究機構');
ok($zip->set_number('1858501')->is_valid_number, '国分寺市役所');
ok($zip->set_number('1858502')->is_valid_number, '東京経済大学');
ok($zip->set_number('1858506')->is_valid_number, '早稲田大学系属 早稲田実業学校 初等部');
ok($zip->set_number('1858510')->is_valid_number, '鉄道情報システム 株式会社');
ok($zip->set_number('1858511')->is_valid_number, '農林水産省動物医薬品検査所');
ok($zip->set_number('1858520')->is_valid_number, '東京都立多摩図書館');
ok($zip->set_number('1858533')->is_valid_number, 'リオン 株式会社');
ok($zip->set_number('1858540')->is_valid_number, '公益財団法人 鉄道総合技術研究所');
ok($zip->set_number('1858562')->is_valid_number, '株式会社 丸井 マルイファミリー国分寺');
ok($zip->set_number('1858567')->is_valid_number, 'ダイトエレクトロン 株式会社 商品仕入部 東京センター');
ok($zip->set_number('1858601')->is_valid_number, '株式会社 日立製作所 中央研究所');
ok($zip->set_number('1858795')->is_valid_number, '情報通信政策研究所');
ok($zip->set_number('1868001')->is_valid_number, '学校法人 NHK学園');
ok($zip->set_number('1868501')->is_valid_number, '国立市役所');
ok($zip->set_number('1868505')->is_valid_number, 'ユアサ商事 株式会社 西関東営業所');
ok($zip->set_number('1868519')->is_valid_number, '進学舎');
ok($zip->set_number('1868585')->is_valid_number, '株式会社 セカンドスタッフ(パラダイスレコード)');
ok($zip->set_number('1868601')->is_valid_number, '一橋大学');
ok($zip->set_number('1868602')->is_valid_number, '一橋大学付属図書館');
ok($zip->set_number('1868603')->is_valid_number, '一橋大学経済研究所');
ok($zip->set_number('1868611')->is_valid_number, 'ENA');
ok($zip->set_number('1868619')->is_valid_number, '進研社');
ok($zip->set_number('1868650')->is_valid_number, '株式会社 ヤクルト本社 中央研究所');
ok($zip->set_number('1868666')->is_valid_number, '切手趣味研究会');
ok($zip->set_number('1868668')->is_valid_number, '東京女子体育大学');
ok($zip->set_number('1868680')->is_valid_number, '東京多摩青果 株式会社');
ok($zip->set_number('1868686')->is_valid_number, '多摩中央信用金庫 国立支店');
ok($zip->set_number('1868688')->is_valid_number, '大和證券 国立支店');
ok($zip->set_number('1868797')->is_valid_number, '郵政大学校');
ok($zip->set_number('1868798')->is_valid_number, '中央郵政研修センター');
ok($zip->set_number('1878502')->is_valid_number, '国立精神・神経医療研究センター 神経研究所');
ok($zip->set_number('1878503')->is_valid_number, 'わらべや日洋 株式会社');
ok($zip->set_number('1878505')->is_valid_number, '武蔵野美術大学');
ok($zip->set_number('1878507')->is_valid_number, '有限会社 鈴木園');
ok($zip->set_number('1878510')->is_valid_number, '公立昭和病院');
ok($zip->set_number('1878511')->is_valid_number, '株式会社 日立国際電気');
ok($zip->set_number('1878512')->is_valid_number, '株式会社 HYSエンジニアリングサービス');
ok($zip->set_number('1878518')->is_valid_number, '東京むさし農業共同組合 小平支店');
ok($zip->set_number('1878520')->is_valid_number, '国土交通省 国土交通大学校');
ok($zip->set_number('1878522')->is_valid_number, '株式会社 日立超LSIシステムズ');
ok($zip->set_number('1878531')->is_valid_number, '株式会社 ブリヂストン 東京工場');
ok($zip->set_number('1878533')->is_valid_number, '東京都小平都税支所');
ok($zip->set_number('1878540')->is_valid_number, '財団法人 全国建設研修センター');
ok($zip->set_number('1878551')->is_valid_number, '国立精神・神経医療研究センター');
ok($zip->set_number('1878553')->is_valid_number, '国立精神・神経医療研究センター 精神保健研究所');
ok($zip->set_number('1878555')->is_valid_number, '警視庁 小平警察署');
ok($zip->set_number('1878558')->is_valid_number, '株式会社 コバヤシ');
ok($zip->set_number('1878560')->is_valid_number, '学校法人 東京朝鮮学園 朝鮮大学校');
ok($zip->set_number('1878567')->is_valid_number, '株式会社 小泉 多摩本社');
ok($zip->set_number('1878570')->is_valid_number, '学校法人 白梅学園');
ok($zip->set_number('1878577')->is_valid_number, '学校法人 津田塾大学');
ok($zip->set_number('1878578')->is_valid_number, '嘉悦大学');
ok($zip->set_number('1878581')->is_valid_number, '株式会社 紙叶');
ok($zip->set_number('1878585')->is_valid_number, '財団法人 多摩緑成会');
ok($zip->set_number('1878587')->is_valid_number, '大学評価・学位授与機構');
ok($zip->set_number('1878588')->is_valid_number, '株式会社 ルネサスエレクトロニクス 武蔵事業所');
ok($zip->set_number('1878611')->is_valid_number, '第一屋製パン 株式会社');
ok($zip->set_number('1878701')->is_valid_number, '小平市役所');
ok($zip->set_number('1888511')->is_valid_number, 'シチズン時計 株式会社 田無製造所');
ok($zip->set_number('1888555')->is_valid_number, '石川島播磨重工業 株式会社');
ok($zip->set_number('1888585')->is_valid_number, '住友重機械工業 株式会社 田無製造所');
ok($zip->set_number('1888666')->is_valid_number, '西東京市役所 田無庁舎');
ok($zip->set_number('1888680')->is_valid_number, '株式会社 ロッテ ((株) 有謝商会)');
ok($zip->set_number('1888701')->is_valid_number, '(株) インテージ');
ok($zip->set_number('1898501')->is_valid_number, '東村山市役所');
ok($zip->set_number('1898511')->is_valid_number, '東京都 多摩北部医療センター');
ok($zip->set_number('1898520')->is_valid_number, '日機装 株式会社 東村山製作所');
ok($zip->set_number('1898550')->is_valid_number, '国立療養所 多磨全生園');
ok($zip->set_number('1898555')->is_valid_number, '東村山税務署');
ok($zip->set_number('1898585')->is_valid_number, '山崎製パン (株) 武蔵野第二工場');
ok($zip->set_number('1900192')->is_valid_number, '日の出町役場');
ok($zip->set_number('1901292')->is_valid_number, '瑞穂町役場');
ok($zip->set_number('1901293')->is_valid_number, '株式会社 桝屋');
ok($zip->set_number('1901295')->is_valid_number, '株式会社 ソニック');
ok($zip->set_number('1901297')->is_valid_number, '株式会社 IHI');
ok($zip->set_number('1901298')->is_valid_number, '株式会社 日本アクセス 西多摩センター');
ok($zip->set_number('1908501')->is_valid_number, '陸上自衛隊 立川駐屯地');
ok($zip->set_number('1908503')->is_valid_number, '住宅・都市整備公団 東京支社 北多摩営業所');
ok($zip->set_number('1908505')->is_valid_number, '株式会社 和凰');
ok($zip->set_number('1908506')->is_valid_number, '第一デパート (株式会社 サビアコーポレーション)');
ok($zip->set_number('1908507')->is_valid_number, '株式会社 高島屋 立川店');
ok($zip->set_number('1908508')->is_valid_number, '多摩運送 株式会社');
ok($zip->set_number('1908510')->is_valid_number, '株式会社 日本旅行 立川支店');
ok($zip->set_number('1908511')->is_valid_number, '株式会社 伊勢丹 立川店');
ok($zip->set_number('1908513')->is_valid_number, '日本信販 株式会社 西関東統括部');
ok($zip->set_number('1908514')->is_valid_number, '株式会社 東京スター銀行 立川支店');
ok($zip->set_number('1908515')->is_valid_number, '軽貨急配シーエス 株式会社 立川支店');
ok($zip->set_number('1908516')->is_valid_number, '立川労働基準監督署');
ok($zip->set_number('1908517')->is_valid_number, '株式会社 いなげや');
ok($zip->set_number('1908518')->is_valid_number, '国立極地研究所');
ok($zip->set_number('1908519')->is_valid_number, '宗教法人 真如苑');
ok($zip->set_number('1908520')->is_valid_number, '学校法人 国立音楽大学');
ok($zip->set_number('1908522')->is_valid_number, '超音波工業 株式会社');
ok($zip->set_number('1908528')->is_valid_number, 'オリックス・クレジット 株式会社');
ok($zip->set_number('1908530')->is_valid_number, '昭和記念公園 パークス共同体 国営昭和記念公園 管理センター');
ok($zip->set_number('1908531')->is_valid_number, '国家公務員共済組合連合会 立川病院');
ok($zip->set_number('1908535')->is_valid_number, '財団法人 東京顕微鏡院');
ok($zip->set_number('1908536')->is_valid_number, '株式会社 NTTドコモ 多摩支店');
ok($zip->set_number('1908537')->is_valid_number, 'NEC三栄 株式会社');
ok($zip->set_number('1908539')->is_valid_number, '株式会社 ジェイコム多摩');
ok($zip->set_number('1908540')->is_valid_number, '読売新聞 東京本社 立川支局');
ok($zip->set_number('1908542')->is_valid_number, '株式会社 壽屋');
ok($zip->set_number('1908543')->is_valid_number, '東京都立多摩社会教育会館');
ok($zip->set_number('1908544')->is_valid_number, '東京地方検察庁 立川支部');
ok($zip->set_number('1908550')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('1908551')->is_valid_number, '株式会社 日本政策金融公庫 立川支店');
ok($zip->set_number('1908553')->is_valid_number, 'あいおい損害保険 株式会社 東京西支店');
ok($zip->set_number('1908554')->is_valid_number, 'ジェイアール東日本商業開発 株式会社 (グランデュオ)');
ok($zip->set_number('1908555')->is_valid_number, '株式会社 田島');
ok($zip->set_number('1908557')->is_valid_number, '森永乳業 株式会社 多摩支店');
ok($zip->set_number('1908558')->is_valid_number, '国土交通省 関東地方整備局 国営昭和記念公園事務所');
ok($zip->set_number('1908560')->is_valid_number, '株式会社 日本アクセス 東京西支店');
ok($zip->set_number('1908561')->is_valid_number, '大学共同利用機関法人 人間文化研究機構 国立国語研究所');
ok($zip->set_number('1908562')->is_valid_number, '情報・システム研究機構 統計数理研究所');
ok($zip->set_number('1908565')->is_valid_number, '立川税務署');
ok($zip->set_number('1908566')->is_valid_number, '株式会社 セレモアつくば');
ok($zip->set_number('1908571')->is_valid_number, '東京地方裁判所 立川支部');
ok($zip->set_number('1908572')->is_valid_number, '立川簡易裁判所');
ok($zip->set_number('1908573')->is_valid_number, '東京都市町村 職員共済組合');
ok($zip->set_number('1908575')->is_valid_number, '関東財務局 立川出張所');
ok($zip->set_number('1908578')->is_valid_number, '社会医療法人社団 健生会 立川相互病院');
ok($zip->set_number('1908579')->is_valid_number, '独立行政法人 国立病院機構本部 DMAT事務局');
ok($zip->set_number('1908581')->is_valid_number, '自治大学校');
ok($zip->set_number('1908582')->is_valid_number, '日本生命保険 相互会社 東京西支社');
ok($zip->set_number('1908583')->is_valid_number, '東京都立砂川高等学校');
ok($zip->set_number('1908586')->is_valid_number, '横河電機 株式会社 立川オフィス');
ok($zip->set_number('1908588')->is_valid_number, 'サンケイリビング新聞社 多摩本部');
ok($zip->set_number('1908589')->is_valid_number, '東京家庭裁判所 立川支部');
ok($zip->set_number('1908590')->is_valid_number, '東京医療保健大学 国立病院機構立川キャンパス');
ok($zip->set_number('1908609')->is_valid_number, '立川公共職業安定所');
ok($zip->set_number('1908666')->is_valid_number, '立川市役所');
ok($zip->set_number('1908680')->is_valid_number, '立飛企業 株式会社');
ok($zip->set_number('1908681')->is_valid_number, '多摩信用金庫');
ok($zip->set_number('1908686')->is_valid_number, '大和証券 株式会社 立川支店');
ok($zip->set_number('1908688')->is_valid_number, '新立川航空機 株式会社');
ok($zip->set_number('1918501')->is_valid_number, 'セイコーエプソン 株式会社');
ok($zip->set_number('1918502')->is_valid_number, '富士電機 株式会社 東京工場');
ok($zip->set_number('1918503')->is_valid_number, 'GEヘルスケア・ジャパン 株式会社');
ok($zip->set_number('1918506')->is_valid_number, '明星大学');
ok($zip->set_number('1918507')->is_valid_number, '東京電力 株式会社 総合研修センター');
ok($zip->set_number('1918509')->is_valid_number, 'ファナック 株式会社');
ok($zip->set_number('1918510')->is_valid_number, '実践女子大学');
ok($zip->set_number('1918511')->is_valid_number, 'コニカミノルタ 東京サイト日野');
ok($zip->set_number('1918512')->is_valid_number, '帝人株式会社 東京研究センター');
ok($zip->set_number('1918520')->is_valid_number, '日野税務署');
ok($zip->set_number('1918660')->is_valid_number, '日野自動車 株式会社');
ok($zip->set_number('1918686')->is_valid_number, '日野市役所');
ok($zip->set_number('1920392')->is_valid_number, '東京薬科大学');
ok($zip->set_number('1920393')->is_valid_number, '中央大学');
ok($zip->set_number('1920394')->is_valid_number, '学校法人 多摩美術大学 八王子校舎');
ok($zip->set_number('1920395')->is_valid_number, '帝京大学 八王子校舎');
ok($zip->set_number('1920396')->is_valid_number, '山野美容芸術短期大学');
ok($zip->set_number('1920397')->is_valid_number, '東京都立大学');
ok($zip->set_number('1920398')->is_valid_number, '株式会社 スリーボンド');
ok($zip->set_number('1920981')->is_valid_number, '学校法人 片柳学園');
ok($zip->set_number('1920982')->is_valid_number, '学校法人 片柳学園 東京工科大学');
ok($zip->set_number('1920983')->is_valid_number, '日本工学院八王子専門学校');
ok($zip->set_number('1920986')->is_valid_number, '日本文化大學');
ok($zip->set_number('1920988')->is_valid_number, '日本水産 株式会社 八王子総合工場');
ok($zip->set_number('1920989')->is_valid_number, '八王子総合卸売センター 株式会社');
ok($zip->set_number('1920991')->is_valid_number, '株式会社 ニッスイ 東京イノベーションセンター');
ok($zip->set_number('1920992')->is_valid_number, '東京造形大学');
ok($zip->set_number('1920993')->is_valid_number, '東京電力 株式会社 多摩支店');
ok($zip->set_number('1920996')->is_valid_number, '株式会社 八王子エフエム');
ok($zip->set_number('1928501')->is_valid_number, '八王子市役所');
ok($zip->set_number('1928502')->is_valid_number, '東日本旅客鉄道 株式会社 八王子支社');
ok($zip->set_number('1928505')->is_valid_number, 'コニカミノルタ 東京サイト八王子');
ok($zip->set_number('1928506')->is_valid_number, '八王子社会保険事務所');
ok($zip->set_number('1928507')->is_valid_number, 'オリンパス光学工業 株式会社 技術開発センター石川');
ok($zip->set_number('1928508')->is_valid_number, '杏林大学');
ok($zip->set_number('1928510')->is_valid_number, 'アジレント・テクノロジー 株式会社');
ok($zip->set_number('1928512')->is_valid_number, 'オリンパス光学工業 株式会社 技術開発センター宇津木');
ok($zip->set_number('1928515')->is_valid_number, '株式会社 東京精密');
ok($zip->set_number('1928516')->is_valid_number, '八王子簡易裁判所');
ok($zip->set_number('1928518')->is_valid_number, 'MS&AD八王子センター MS&AD事務サービス 株式会社');
ok($zip->set_number('1928520')->is_valid_number, '八王子商工会議所');
ok($zip->set_number('1928522')->is_valid_number, '株式会社 ニレコ');
ok($zip->set_number('1928525')->is_valid_number, '株式会社 JVC ケンウッド');
ok($zip->set_number('1928532')->is_valid_number, '中央電子 株式会社');
ok($zip->set_number('1928533')->is_valid_number, '双葉産業 (株)');
ok($zip->set_number('1928535')->is_valid_number, '(株) エスアールエル 八王子ラボラトリー');
ok($zip->set_number('1928536')->is_valid_number, '読売新聞 東京本社 八王子支局');
ok($zip->set_number('1928537')->is_valid_number, '日本分光 株式会社');
ok($zip->set_number('1928550')->is_valid_number, 'キーサイト・テクノロジー 合同会社');
ok($zip->set_number('1928551')->is_valid_number, '株式会社 村内ファニチャーアクセス');
ok($zip->set_number('1928553')->is_valid_number, '東京地方検察庁 八王子支部');
ok($zip->set_number('1928556')->is_valid_number, 'カシオ計算機 株式会社 八王子研究所');
ok($zip->set_number('1928558')->is_valid_number, '(株) 関電工 多摩支店');
ok($zip->set_number('1928560')->is_valid_number, 'アマゾン八王子フルフィルメントセンター');
ok($zip->set_number('1928562')->is_valid_number, '東京都立南多摩中等教育学校');
ok($zip->set_number('1928565')->is_valid_number, '八王子税務署');
ok($zip->set_number('1928566')->is_valid_number, '横河計測 株式会社');
ok($zip->set_number('1928568')->is_valid_number, '東京都立八王子東高等学校');
ok($zip->set_number('1928577')->is_valid_number, '学校法人 創価大学');
ok($zip->set_number('1928585')->is_valid_number, '日本ヒューレット・パッカード 合同会社');
ok($zip->set_number('1928611')->is_valid_number, '東京都八王子都税事務所');
ok($zip->set_number('1928622')->is_valid_number, '工学院大学附属中学・高等学校');
ok($zip->set_number('1928633')->is_valid_number, '日本コンテック 株式会社 産業資材部');
ok($zip->set_number('1928644')->is_valid_number, '日本銀刺ワーム');
ok($zip->set_number('1928648')->is_valid_number, '中日本高速道路 (株) 八王子支社');
ok($zip->set_number('1928650')->is_valid_number, '商工中金 八王子支店');
ok($zip->set_number('1928655')->is_valid_number, '大和證券 八王子支店');
ok($zip->set_number('1928702')->is_valid_number, '八王子市役所 市民部市民課');
ok($zip->set_number('1930985')->is_valid_number, '拓殖大学 (八王子キャンパス)');
ok($zip->set_number('1930991')->is_valid_number, '蛇の目ミシン工業 株式会社');
ok($zip->set_number('1930997')->is_valid_number, '東京工業高等専門学校');
ok($zip->set_number('1930998')->is_valid_number, '東京医科大八王子医療センター');
ok($zip->set_number('1938501')->is_valid_number, '共立女子大学');
ok($zip->set_number('1938505')->is_valid_number, '医療法人財団 青渓会 駒木野病院');
ok($zip->set_number('1938510')->is_valid_number, '(株) 育良精機製作所 八王子事業所');
ok($zip->set_number('1938511')->is_valid_number, '高尾登山電鉄 株式会社');
ok($zip->set_number('1938520')->is_valid_number, '八王子保健生活協同組合');
ok($zip->set_number('1938525')->is_valid_number, 'HOYA (株) 八王子工場');
ok($zip->set_number('1938550')->is_valid_number, 'OKIセミコンダクタ 株式会社');
ok($zip->set_number('1938570')->is_valid_number, '林野庁 森林技術総合研修所');
ok($zip->set_number('1938666')->is_valid_number, '共立女子第二中学・高等学校');
ok($zip->set_number('1938686')->is_valid_number, '宗教法人 薬王院');
ok($zip->set_number('1940292')->is_valid_number, '東京家政学院大学');
ok($zip->set_number('1940293')->is_valid_number, '中央協同組合学園');
ok($zip->set_number('1940294')->is_valid_number, '桜美林学園');
ok($zip->set_number('1940295')->is_valid_number, '株式会社 オーク製作所');
ok($zip->set_number('1940296')->is_valid_number, '東京航空計器 株式会社');
ok($zip->set_number('1940297')->is_valid_number, '医療法人社団 幸隆会 多摩丘陵リハビリテーション病院');
ok($zip->set_number('1940298')->is_valid_number, '法政大学');
ok($zip->set_number('1948501')->is_valid_number, '町田東急ツインズ');
ok($zip->set_number('1948502')->is_valid_number, '株式会社 スクールパートナーズ');
ok($zip->set_number('1948503')->is_valid_number, '株式会社 エルハート 横浜店');
ok($zip->set_number('1948505')->is_valid_number, '株式会社 東急ハンズ 町田店');
ok($zip->set_number('1948507')->is_valid_number, '株式会社 家具の大正堂');
ok($zip->set_number('1948508')->is_valid_number, '株式会社 高速道路総合技術研究所');
ok($zip->set_number('1948510')->is_valid_number, '株式会社 PFU');
ok($zip->set_number('1948511')->is_valid_number, '三菱化学生命科学研究所');
ok($zip->set_number('1948515')->is_valid_number, '株式会社 サマディ');
ok($zip->set_number('1948520')->is_valid_number, '町田市役所');
ok($zip->set_number('1948530')->is_valid_number, '株式会社 三和');
ok($zip->set_number('1948533')->is_valid_number, '協和キリン 株式会社 東京リサーチパーク');
ok($zip->set_number('1948538')->is_valid_number, '株式会社 長崎屋 町田店');
ok($zip->set_number('1948540')->is_valid_number, '東京都 町田都税事務所');
ok($zip->set_number('1948543')->is_valid_number, '学校法人 昭和薬科大学');
ok($zip->set_number('1948550')->is_valid_number, '小田急百貨店 町田店');
ok($zip->set_number('1948551')->is_valid_number, 'サンケイリビング新聞社 まちだ・さがみ本部');
ok($zip->set_number('1948555')->is_valid_number, '株式会社 ケーユー');
ok($zip->set_number('1948560')->is_valid_number, '電気化学工業 株式会社 総合研究所');
ok($zip->set_number('1948566')->is_valid_number, '株式会社 オーディオテクニカ 成瀬事業所');
ok($zip->set_number('1948567')->is_valid_number, '町田税務署');
ok($zip->set_number('1948570')->is_valid_number, '株式会社 ジャックス');
ok($zip->set_number('1948577')->is_valid_number, 'ホーチキ 株式会社 町田事業所');
ok($zip->set_number('1948580')->is_valid_number, '町田市役所 市民課');
ok($zip->set_number('1948585')->is_valid_number, 'オリックス・レンテック 株式会社');
ok($zip->set_number('1948586')->is_valid_number, '町田郵便貯金地域文化活動支援施設');
ok($zip->set_number('1948588')->is_valid_number, '協栄電気 株式会社');
ok($zip->set_number('1948589')->is_valid_number, 'グランベリーパーク');
ok($zip->set_number('1948610')->is_valid_number, '学校法人 玉川学園');
ok($zip->set_number('1948611')->is_valid_number, '玉川大学 通信教育部');
ok($zip->set_number('1948612')->is_valid_number, '玉川大学 入試広報部');
ok($zip->set_number('1948666')->is_valid_number, '株式会社 オーディオテクニカ');
ok($zip->set_number('1958550')->is_valid_number, '国士舘大学');
ok($zip->set_number('1958555')->is_valid_number, '学校法人 和光学園');
ok($zip->set_number('1958585')->is_valid_number, '和光大学');
ok($zip->set_number('1968501')->is_valid_number, 'スタック電子 株式会社');
ok($zip->set_number('1968510')->is_valid_number, 'HOYA 株式会社 昭島工場');
ok($zip->set_number('1968511')->is_valid_number, '昭島市役所');
ok($zip->set_number('1968522')->is_valid_number, '昭和飛行機工業 株式会社');
ok($zip->set_number('1968533')->is_valid_number, 'MORIPARK OutdoorVillage');
ok($zip->set_number('1968550')->is_valid_number, 'フォスター電機 株式会社');
ok($zip->set_number('1968555')->is_valid_number, '日本航空電子工業 株式会社');
ok($zip->set_number('1968558')->is_valid_number, '日本電子 株式会社');
ok($zip->set_number('1968560')->is_valid_number, '東日本成人矯正医療センター');
ok($zip->set_number('1968570')->is_valid_number, '法務省 国連アジア極東犯罪防止研修所');
ok($zip->set_number('1968570')->is_valid_number, '法務省 法務総合研究所国際協力部');
ok($zip->set_number('1968580')->is_valid_number, '法務省 矯正研修所');
ok($zip->set_number('1968585')->is_valid_number, '株式会社 三井E&Sパワーシステムズ');
ok($zip->set_number('1968588')->is_valid_number, '協立包装材 (株)');
ok($zip->set_number('1968601')->is_valid_number, 'アーバンリゾーツ昭和の森 株式会社');
ok($zip->set_number('1968611')->is_valid_number, '株式会社 タチエス');
ok($zip->set_number('1968666')->is_valid_number, '株式会社 リガク');
ok($zip->set_number('1968668')->is_valid_number, '日本ゼネラルモーターズ 株式会社/デルファイ・オートモーティブ・システムズ');
ok($zip->set_number('1968686')->is_valid_number, '株式会社 IHI');
ok($zip->set_number('1978501')->is_valid_number, '福生市役所');
ok($zip->set_number('1978511')->is_valid_number, '福生病院組合');
ok($zip->set_number('1978555')->is_valid_number, '武陽ガス 株式会社');
ok($zip->set_number('1978601')->is_valid_number, '株式会社 大多摩ハム 小林商会');
ok($zip->set_number('1978623')->is_valid_number, '石川酒造 株式会社');
ok($zip->set_number('1988501')->is_valid_number, 'アマゾン青梅FC');
ok($zip->set_number('1988510')->is_valid_number, '株式会社 東邦製作所');
ok($zip->set_number('1988512')->is_valid_number, '株式会社 日立製作所 マイクロデバイス事業部');
ok($zip->set_number('1988522')->is_valid_number, 'ホットマン 株式会社');
ok($zip->set_number('1988525')->is_valid_number, '日本年金機構 青梅年金事務所');
ok($zip->set_number('1988531')->is_valid_number, '社会福祉法人 聖明福祉協会');
ok($zip->set_number('1988555')->is_valid_number, '株式会社 テラミクロス');
ok($zip->set_number('1988577')->is_valid_number, '株式会社 日立製作所 ヘルスケア東京事業所');
ok($zip->set_number('1988585')->is_valid_number, '青梅商工会議所');
ok($zip->set_number('1988588')->is_valid_number, '株式会社 オザム');
ok($zip->set_number('1988601')->is_valid_number, '住友金属鉱山 株式会社 電子事業本部');
ok($zip->set_number('1988611')->is_valid_number, '日立ライティング 株式会社 青梅事業所');
ok($zip->set_number('1988655')->is_valid_number, '明星大学 青梅キャンパス');
ok($zip->set_number('1988666')->is_valid_number, 'アジアエレクトロニクス 株式会社');
ok($zip->set_number('1988700')->is_valid_number, '青梅市役所');
ok($zip->set_number('1988701')->is_valid_number, '青梅市役所');
ok($zip->set_number('1988710')->is_valid_number, '株式会社 東芝 青梅事業所');
ok($zip->set_number('1988711')->is_valid_number, '株式会社 共立');
ok($zip->set_number('1988722')->is_valid_number, '青梅信用金庫');
ok($zip->set_number('1988760')->is_valid_number, '(株) やまびこ');
ok($zip->set_number('2018501')->is_valid_number, '東京都立狛江高等学校');
ok($zip->set_number('2018511')->is_valid_number, '一般財団法人 電力中央研究所');
ok($zip->set_number('2018585')->is_valid_number, '狛江市役所');
ok($zip->set_number('2018588')->is_valid_number, '第一電材 株式会社');
ok($zip->set_number('2018601')->is_valid_number, '東京慈恵会医科大学附属第三病院');
ok($zip->set_number('2018686')->is_valid_number, '学校法人 狛江こだま学園');
ok($zip->set_number('2028520')->is_valid_number, '株式会社 パルコ ひばりが丘店');
ok($zip->set_number('2028555')->is_valid_number, '西東京市役所 保谷庁舎');
ok($zip->set_number('2028558')->is_valid_number, '株式会社 損害保険ジャパン');
ok($zip->set_number('2028585')->is_valid_number, '学校法人 武蔵野大学(武蔵野キャンパス)');
ok($zip->set_number('2038511')->is_valid_number, 'グローブライド 株式会社');
ok($zip->set_number('2038521')->is_valid_number, '自由学園(初等部・男子部中等科・女子部中等科・高等科・最高学部)');
ok($zip->set_number('2038555')->is_valid_number, '東久留米市役所');
ok($zip->set_number('2038585')->is_valid_number, '山崎製パン 株式会社 武蔵野工場');
ok($zip->set_number('2038588')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('2038601')->is_valid_number, '株式会社 インテージ');
ok($zip->set_number('2038739')->is_valid_number, '株式会社 インテージリサーチ IFIセンター');
ok($zip->set_number('2048501')->is_valid_number, '東京管区気象台');
ok($zip->set_number('2048511')->is_valid_number, '清瀬市役所');
ok($zip->set_number('2048522')->is_valid_number, '財団法人 結核予防会 複十字病院');
ok($zip->set_number('2048533')->is_valid_number, '財団法人 結核予防会 結核研究所');
ok($zip->set_number('2048555')->is_valid_number, '日本社会事業大学');
ok($zip->set_number('2048558')->is_valid_number, '株式会社 大林組 技術研究所');
ok($zip->set_number('2048567')->is_valid_number, '東京都立 清瀬小児病院');
ok($zip->set_number('2048585')->is_valid_number, '独立行政法人 国立病院機構 東京病院');
ok($zip->set_number('2048588')->is_valid_number, '明治薬科大学');
ok($zip->set_number('2048589')->is_valid_number, '明治薬科大学 図書館');
ok($zip->set_number('2058501')->is_valid_number, 'あすか製薬 株式会社');
ok($zip->set_number('2058503')->is_valid_number, '富士フレーバー 株式会社');
ok($zip->set_number('2058511')->is_valid_number, '日本フィルター工業 株式会社');
ok($zip->set_number('2058555')->is_valid_number, 'カシオ計算機 株式会社 羽村技術センター');
ok($zip->set_number('2058601')->is_valid_number, '羽村市役所');
ok($zip->set_number('2058604')->is_valid_number, '三和電気計器 株式会社・羽村工場');
ok($zip->set_number('2058606')->is_valid_number, '株式会社 日立国際電気 羽村工場');
ok($zip->set_number('2058607')->is_valid_number, '株式会社 カイジョー');
ok($zip->set_number('2058660')->is_valid_number, '日野自動車工業 株式会社 羽村工場');
ok($zip->set_number('2068502')->is_valid_number, '京王電鉄 株式会社');
ok($zip->set_number('2068503')->is_valid_number, '富士通 株式会社');
ok($zip->set_number('2068505')->is_valid_number, '生活協同組合 東京マイコープ');
ok($zip->set_number('2068510')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('2068511')->is_valid_number, '学校法人 駒澤学園');
ok($zip->set_number('2068512')->is_valid_number, '日本医科大学付属多摩永山病院');
ok($zip->set_number('2068515')->is_valid_number, '国士舘大学 体育学部');
ok($zip->set_number('2068520')->is_valid_number, '大和證券 株式会社 多摩支店');
ok($zip->set_number('2068522')->is_valid_number, '株式会社 京王ストア');
ok($zip->set_number('2068525')->is_valid_number, 'ミタニマイクロニクス 株式会社');
ok($zip->set_number('2068530')->is_valid_number, 'ティアック 株式会社');
ok($zip->set_number('2068540')->is_valid_number, '大妻学院 多摩校');
ok($zip->set_number('2068543')->is_valid_number, '三越 多摩センター店');
ok($zip->set_number('2068551')->is_valid_number, 'JUKI 株式会社');
ok($zip->set_number('2068555')->is_valid_number, '富士通フロンテック 株式会社');
ok($zip->set_number('2068561')->is_valid_number, '帝京大学小学校');
ok($zip->set_number('2068566')->is_valid_number, '株式会社 よみうりランド');
ok($zip->set_number('2068567')->is_valid_number, 'ミツミ電機 株式会社');
ok($zip->set_number('2068577')->is_valid_number, '日本フイルコン 株式会社 東京事務所');
ok($zip->set_number('2068585')->is_valid_number, 'トヨタ西東京カローラ 株式会社');
ok($zip->set_number('2068586')->is_valid_number, '恵泉女学園大学');
ok($zip->set_number('2068588')->is_valid_number, '株式会社 サンリオエンターテイメント');
ok($zip->set_number('2068601')->is_valid_number, '稲城市役所');
ok($zip->set_number('2068611')->is_valid_number, '朝日生命保険 相互会社 多摩本社');
ok($zip->set_number('2068666')->is_valid_number, '多摩市役所');
ok($zip->set_number('2068686')->is_valid_number, '株式会社 ベネッセコーポレーション');
ok($zip->set_number('2078501')->is_valid_number, '株式会社 カシオ日立モバイルコミュニケーションズ');
ok($zip->set_number('2078515')->is_valid_number, '独立行政法人 中小企業基盤整備機構 関東支部 中小企業大学校 東京校');
ok($zip->set_number('2078585')->is_valid_number, '東大和市役所');
ok($zip->set_number('2088501')->is_valid_number, '武蔵村山市役所');
ok($zip->set_number('2088502')->is_valid_number, '武蔵村山市民総合センター');
ok($zip->set_number('2088503')->is_valid_number, '武蔵村山市社会福祉協議会');
ok($zip->set_number('2088555')->is_valid_number, '株式会社 コトブキ 村山工場');
ok($zip->set_number('2088585')->is_valid_number, '株式会社 新川');
ok($zip->set_number('2108502')->is_valid_number, '大和証券 株式会社 川崎支店');
ok($zip->set_number('2108504')->is_valid_number, '株式会社 岡田屋モアーズ');
ok($zip->set_number('2108506')->is_valid_number, 'トラスコ中山 株式会社 プラネット東京');
ok($zip->set_number('2108511')->is_valid_number, '川崎市 かわさき市税事務所 法人課税課');
ok($zip->set_number('2108512')->is_valid_number, 'プレス工業 株式会社');
ok($zip->set_number('2108521')->is_valid_number, '川崎大師 平間寺');
ok($zip->set_number('2108523')->is_valid_number, '東燃ゼネラル石油 (株) 川崎工場');
ok($zip->set_number('2108531')->is_valid_number, '川崎南税務署');
ok($zip->set_number('2108537')->is_valid_number, '横浜家庭裁判所 川崎支部');
ok($zip->set_number('2108538')->is_valid_number, '東芝マイクロエレクトロニクス 株式会社');
ok($zip->set_number('2108540')->is_valid_number, '東芝情報システム 株式会社');
ok($zip->set_number('2108541')->is_valid_number, '東芝自動機器システムサービス 株式会社');
ok($zip->set_number('2108543')->is_valid_number, '東芝ライフスタイル 株式会社');
ok($zip->set_number('2108544')->is_valid_number, '川崎合同法律事務所');
ok($zip->set_number('2108545')->is_valid_number, 'JXTGエネルギー 株式会社 川崎製造所');
ok($zip->set_number('2108547')->is_valid_number, '日本ポリエチレン (株) 川崎工場');
ok($zip->set_number('2108548')->is_valid_number, '日本ポリエチレン(株) 研究開発センター');
ok($zip->set_number('2108551')->is_valid_number, '東芝ITサービス 株式会社');
ok($zip->set_number('2108552')->is_valid_number, '住友生命保険 相互会社 川崎支社');
ok($zip->set_number('2108557')->is_valid_number, '東京新聞TODAY');
ok($zip->set_number('2108558')->is_valid_number, '日本冶金工業 株式会社 川崎製造所');
ok($zip->set_number('2108559')->is_valid_number, '横浜地方裁判所 川崎支部');
ok($zip->set_number('2108560')->is_valid_number, '三菱化工機 株式会社');
ok($zip->set_number('2108562')->is_valid_number, '神奈川県川崎県税事務所');
ok($zip->set_number('2108565')->is_valid_number, '川崎市消防局');
ok($zip->set_number('2108569')->is_valid_number, '株式会社 ディーアンドエムホールディングス');
ok($zip->set_number('2108570')->is_valid_number, '川崎区役所');
ok($zip->set_number('2108576')->is_valid_number, '川崎市 かわさき市税事務所');
ok($zip->set_number('2108577')->is_valid_number, '川崎市役所');
ok($zip->set_number('2108583')->is_valid_number, '株式会社 東芝 セミコンダクター社 マイクロエレクトロニクスセンター');
ok($zip->set_number('2108585')->is_valid_number, '株式会社 ヨドバシカメラYAC川崎');
ok($zip->set_number('2108586')->is_valid_number, '株式会社 さいか屋');
ok($zip->set_number('2108602')->is_valid_number, 'SBカワスミ 株式会社');
ok($zip->set_number('2108604')->is_valid_number, '野村證券 株式会社 川崎支店');
ok($zip->set_number('2108666')->is_valid_number, '川崎ダイスビル');
ok($zip->set_number('2108680')->is_valid_number, '味の素 (株) 川崎工場');
ok($zip->set_number('2108681')->is_valid_number, '味の素(株) 中央研究所');
ok($zip->set_number('2108686')->is_valid_number, '商工組合中央金庫 川崎支店');
ok($zip->set_number('2108793')->is_valid_number, '日本郵便 株式会社 南関東支社 郵便事業本部 (三種)');
ok($zip->set_number('2108794')->is_valid_number, '株式会社 かんぽ生命保険 南関東エリア本部');
ok($zip->set_number('2108795')->is_valid_number, '株式会社 ゆうちょ銀行 南関東エリア本部');
ok($zip->set_number('2108796')->is_valid_number, '日本郵便 株式会社 神奈川監査室');
ok($zip->set_number('2108797')->is_valid_number, '日本郵便 株式会社 南関東支社');
ok($zip->set_number('2108798')->is_valid_number, '日本郵政 株式会社 首都圏郵政健康管理センター 川崎分室');
ok($zip->set_number('2109501')->is_valid_number, '国立医薬品食品衛生研究所');
ok($zip->set_number('2109507')->is_valid_number, '日本ゼオン 株式会社 川崎工場');
ok($zip->set_number('2109511')->is_valid_number, 'アライオートオークションベイサイド');
ok($zip->set_number('2109526')->is_valid_number, '東燃ゼネラル石油 (株) 150号地');
ok($zip->set_number('2109530')->is_valid_number, '富士電機 株式会社 川崎工場');
ok($zip->set_number('2109533')->is_valid_number, '池上通信機 (株) 塩浜事業所');
ok($zip->set_number('2109555')->is_valid_number, '山本商会 株式会社');
ok($zip->set_number('2109567')->is_valid_number, '日本鋳造 株式会社');
ok($zip->set_number('2109582')->is_valid_number, '味の素(株) 西工場');
ok($zip->set_number('2109650')->is_valid_number, '日立造船 株式会社 神奈川工場');
ok($zip->set_number('2118501')->is_valid_number, 'キヤノン 株式会社 小杉事業所');
ok($zip->set_number('2118502')->is_valid_number, '東横化学 株式会社');
ok($zip->set_number('2118505')->is_valid_number, '株式会社 ドメス');
ok($zip->set_number('2118510')->is_valid_number, '関東労災病院');
ok($zip->set_number('2118511')->is_valid_number, '第一メール 株式会社');
ok($zip->set_number('2118520')->is_valid_number, '富士通 FIP');
ok($zip->set_number('2118522')->is_valid_number, '三菱ふそうトラック・バス 株式会社 川崎製作所');
ok($zip->set_number('2118530')->is_valid_number, '帝国通信工業 株式会社');
ok($zip->set_number('2118533')->is_valid_number, '日本医科大学武蔵小杉病院');
ok($zip->set_number('2118540')->is_valid_number, '富士通エフ・アイ・ピー 株式会社');
ok($zip->set_number('2118550')->is_valid_number, '株式会社 東計電算');
ok($zip->set_number('2118555')->is_valid_number, '株式会社 テクノ');
ok($zip->set_number('2118566')->is_valid_number, 'かわさき市民放送 株式会社');
ok($zip->set_number('2118570')->is_valid_number, '中原区役所');
ok($zip->set_number('2118577')->is_valid_number, '三木プーリ 株式会社');
ok($zip->set_number('2118585')->is_valid_number, '沖電線 株式会社');
ok($zip->set_number('2118588')->is_valid_number, '富士通 株式会社 川崎工場');
ok($zip->set_number('2118601')->is_valid_number, 'NECマネジメントパートナー 株式会社');
ok($zip->set_number('2118611')->is_valid_number, 'パイオニアプラズマディスプレイ 株式会社');
ok($zip->set_number('2118619')->is_valid_number, '武蔵小杉東急スクエア');
ok($zip->set_number('2118666')->is_valid_number, '日本電気 株式会社 玉川事業場');
ok($zip->set_number('2118675')->is_valid_number, '信号器材 株式会社');
ok($zip->set_number('2128502')->is_valid_number, 'タタ・エレクシー・リミテッド');
ok($zip->set_number('2128505')->is_valid_number, 'JBアドバンスト・テクノロジー 株式会社');
ok($zip->set_number('2128508')->is_valid_number, '田中製菓 株式会社');
ok($zip->set_number('2128509')->is_valid_number, '大陽日酸 株式会社 関東支社');
ok($zip->set_number('2128510')->is_valid_number, '富士通新川崎テクノロジースクエア');
ok($zip->set_number('2128511')->is_valid_number, 'キグナス石油販売 株式会社');
ok($zip->set_number('2128520')->is_valid_number, '株式会社 東芝 マイクロエレクトロニクスセンター 半導体システム技術センター分室');
ok($zip->set_number('2128525')->is_valid_number, '株式会社 東邦事業');
ok($zip->set_number('2128525')->is_valid_number, '和幸商事 株式会社');
ok($zip->set_number('2128525')->is_valid_number, '和幸フーズ 株式会社');
ok($zip->set_number('2128525')->is_valid_number, 'WAKO GROUP HOLDINGS 株式会社');
ok($zip->set_number('2128530')->is_valid_number, 'キヤノン 株式会社 矢向事業所');
ok($zip->set_number('2128551')->is_valid_number, '東芝プラントシステム 株式会社');
ok($zip->set_number('2128554')->is_valid_number, 'ミューザ川崎 管理組合');
ok($zip->set_number('2128557')->is_valid_number, 'ミューザ川崎シンフォニーホール');
ok($zip->set_number('2128560')->is_valid_number, '黒田精工 株式会社');
ok($zip->set_number('2128564')->is_valid_number, '株式会社 中央コンピュータシステム');
ok($zip->set_number('2128566')->is_valid_number, '日本トイザらス (株)');
ok($zip->set_number('2128567')->is_valid_number, '株式会社 日立製作所 情報システム事業部');
ok($zip->set_number('2128570')->is_valid_number, '川崎市 幸区役所');
ok($zip->set_number('2128572')->is_valid_number, '株式会社 東芝 川崎事業所');
ok($zip->set_number('2128576')->is_valid_number, 'ラゾーナ川崎プラザ');
ok($zip->set_number('2128577')->is_valid_number, '東芝健康保険組合');
ok($zip->set_number('2128581')->is_valid_number, '株式会社 東芝 小向工場');
ok($zip->set_number('2128582')->is_valid_number, '株式会社 東芝 研究開発センター');
ok($zip->set_number('2128583')->is_valid_number, '株式会社 東芝 セミコンダクター社 マイクロエレクトロセンター');
ok($zip->set_number('2128584')->is_valid_number, '株式会社 ビックカメラ');
ok($zip->set_number('2128585')->is_valid_number, '株式会社 東芝スマートコミュニティセンター');
ok($zip->set_number('2128602')->is_valid_number, 'キヤノン 株式会社 川崎事業所');
ok($zip->set_number('2128603')->is_valid_number, 'ディー・ティー・ファインエレクトロニクス 株式会社');
ok($zip->set_number('2128604')->is_valid_number, 'TTヒューマンアセットサービス 株式会社');
ok($zip->set_number('2138502')->is_valid_number, '株式会社 富士通ゼネラル');
ok($zip->set_number('2138503')->is_valid_number, '川崎北税務署');
ok($zip->set_number('2138505')->is_valid_number, 'クノール食品 株式会社');
ok($zip->set_number('2138507')->is_valid_number, '帝京大学 医学部 付属溝口病院');
ok($zip->set_number('2138511')->is_valid_number, 'NECプラットフォームズ 株式会社');
ok($zip->set_number('2138512')->is_valid_number, 'キヤノン 株式会社');
ok($zip->set_number('2138515')->is_valid_number, '神奈川県高津県税事務所');
ok($zip->set_number('2138516')->is_valid_number, 'アマゾン川崎FC HND6');
ok($zip->set_number('2138517')->is_valid_number, 'アマゾン川崎FC HND9');
ok($zip->set_number('2138520')->is_valid_number, 'エヌフーズ 株式会社');
ok($zip->set_number('2138521')->is_valid_number, '株式会社 日立システムズ');
ok($zip->set_number('2138522')->is_valid_number, 'あすか製薬 株式会社 川崎研究所');
ok($zip->set_number('2138525')->is_valid_number, '株式会社 文教堂');
ok($zip->set_number('2138533')->is_valid_number, '株式会社 ミツトヨ');
ok($zip->set_number('2138535')->is_valid_number, 'タイコ エレクトロニクスジャパン 合同会社');
ok($zip->set_number('2138550')->is_valid_number, '川崎電線 株式会社');
ok($zip->set_number('2138551')->is_valid_number, '昭和薬品 株式会社');
ok($zip->set_number('2138553')->is_valid_number, 'NKKスイッチズ 株式会社');
ok($zip->set_number('2138558')->is_valid_number, '株式会社 高砂製作所');
ok($zip->set_number('2138566')->is_valid_number, '株式会社 磐城無線研究所');
ok($zip->set_number('2138570')->is_valid_number, '高津区役所');
ok($zip->set_number('2138573')->is_valid_number, '川崎北 公共職業安定所');
ok($zip->set_number('2138576')->is_valid_number, '川崎市 みぞのくち市税事務所');
ok($zip->set_number('2138577')->is_valid_number, '関東地方整備局 川崎国道事務所');
ok($zip->set_number('2138580')->is_valid_number, '学校法人 洗足学園');
ok($zip->set_number('2138586')->is_valid_number, '富士通 株式会社 高津事業所');
ok($zip->set_number('2138587')->is_valid_number, '虎の門病院 分院');
ok($zip->set_number('2138588')->is_valid_number, '株式会社 常光');
ok($zip->set_number('2138589')->is_valid_number, '宗教法人 大明王院');
ok($zip->set_number('2148525')->is_valid_number, '川崎市立 多摩病院');
ok($zip->set_number('2148565')->is_valid_number, '学校法人 日本女子大学');
ok($zip->set_number('2148570')->is_valid_number, '多摩区役所');
ok($zip->set_number('2148571')->is_valid_number, '明治大学 生田校舎');
ok($zip->set_number('2148580')->is_valid_number, '学校法人 専修大学');
ok($zip->set_number('2148585')->is_valid_number, '独立行政法人 産業医学 総合研究所');
ok($zip->set_number('2148588')->is_valid_number, '電元社トーア 株式会社');
ok($zip->set_number('2158509')->is_valid_number, '株式会社 ジェイコムせたまち');
ok($zip->set_number('2158510')->is_valid_number, '株式会社 光和電機');
ok($zip->set_number('2158511')->is_valid_number, '株式会社 エリアブレインMYTOWN編集部');
ok($zip->set_number('2158515')->is_valid_number, '(株) NTTソルコ新百合ヶ丘センター');
ok($zip->set_number('2158520')->is_valid_number, '聖マリアンナ医科大学附属研究所ブレスト&イメージング先端医療センター附属クリニック');
ok($zip->set_number('2158521')->is_valid_number, '神津精機 株式会社');
ok($zip->set_number('2158527')->is_valid_number, '神奈川県麻生県税事務所');
ok($zip->set_number('2158530')->is_valid_number, '株式会社 シグマ');
ok($zip->set_number('2158542')->is_valid_number, '調布学園女子短期大学');
ok($zip->set_number('2158550')->is_valid_number, 'キヤノンアネルバ 株式会社');
ok($zip->set_number('2158558')->is_valid_number, '昭和音楽大学');
ok($zip->set_number('2158566')->is_valid_number, '川崎市郵送請求事務センター');
ok($zip->set_number('2158570')->is_valid_number, '麻生区役所');
ok($zip->set_number('2158576')->is_valid_number, '川崎市 しんゆり市税事務所');
ok($zip->set_number('2158585')->is_valid_number, '川崎西税務署');
ok($zip->set_number('2158588')->is_valid_number, '株式会社 Sohwa&Sophia Technologies');
ok($zip->set_number('2168501')->is_valid_number, '財団法人 労働科学研究所');
ok($zip->set_number('2168510')->is_valid_number, '日本道路公団 東京第一管理局');
ok($zip->set_number('2168511')->is_valid_number, '聖マリアンナ医科大学');
ok($zip->set_number('2168512')->is_valid_number, '聖マリアンナ難病センター');
ok($zip->set_number('2168514')->is_valid_number, '聖マリアンナ看護専門学校');
ok($zip->set_number('2168519')->is_valid_number, '株式会社 東急百貨店 通信販売事業部');
ok($zip->set_number('2168522')->is_valid_number, '川崎市中央卸売市場 北部市場');
ok($zip->set_number('2168556')->is_valid_number, '株式会社 シーボンパビリオン');
ok($zip->set_number('2168566')->is_valid_number, '株式会社 西川商事');
ok($zip->set_number('2168570')->is_valid_number, '宮前区役所');
ok($zip->set_number('2168631')->is_valid_number, '昌栄印刷 株式会社');
ok($zip->set_number('2208080')->is_valid_number, '株式会社 WOWOWコミュニケーションズ');
ok($zip->set_number('2208173')->is_valid_number, '株式会社 横浜ロイヤルパークホテル');
ok($zip->set_number('2208401')->is_valid_number, '三菱重工業 株式会社');
ok($zip->set_number('2208501')->is_valid_number, '横浜ベイシェラトンホテル&タワーズ');
ok($zip->set_number('2208502')->is_valid_number, '国際連合大学高等研究所');
ok($zip->set_number('2208507')->is_valid_number, 'Kアリーナ横浜');
ok($zip->set_number('2208508')->is_valid_number, 'ヒルトン横浜');
ok($zip->set_number('2208509')->is_valid_number, 'Kタワー横浜');
ok($zip->set_number('2208510')->is_valid_number, '株式会社 そごう 横浜店');
ok($zip->set_number('2208511')->is_valid_number, 'NTTデータ通信 株式会社');
ok($zip->set_number('2208515')->is_valid_number, '株式会社 山縣印刷所');
ok($zip->set_number('2208520')->is_valid_number, '東京電力 株式会社 横浜支社');
ok($zip->set_number('2208521')->is_valid_number, '財団法人 神奈川県警友会 けいゆう病院');
ok($zip->set_number('2208522')->is_valid_number, 'ヨコハマグランドインターコンチネンタルホテル');
ok($zip->set_number('2208523')->is_valid_number, '神奈川 日産自動車 株式会社');
ok($zip->set_number('2208530')->is_valid_number, '住友生命保険 相互会社 横浜支社');
ok($zip->set_number('2208536')->is_valid_number, '株式会社 ドコモCS 神奈川支店');
ok($zip->set_number('2208538')->is_valid_number, '全国健康保険協会 神奈川支部');
ok($zip->set_number('2208539')->is_valid_number, '株式会社 横浜ステーシヨンビル');
ok($zip->set_number('2208540')->is_valid_number, '(株) 関電工 神奈川支店');
ok($zip->set_number('2208541')->is_valid_number, '株式会社 システム情報センター');
ok($zip->set_number('2208542')->is_valid_number, '株式会社 クイーンズイースト');
ok($zip->set_number('2208558')->is_valid_number, '神奈川県 信用保証協会');
ok($zip->set_number('2208559')->is_valid_number, '(株) 資生堂グローバルイノベーションセンター');
ok($zip->set_number('2208560')->is_valid_number, '株式会社 エクサ');
ok($zip->set_number('2208565')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('2208566')->is_valid_number, '財団法人 神奈川県高等学校教育会館');
ok($zip->set_number('2208567')->is_valid_number, '株式会社 PFU');
ok($zip->set_number('2208577')->is_valid_number, '株式会社 マイカル 横浜ビブレ');
ok($zip->set_number('2208580')->is_valid_number, '東電同窓電気 株式会社');
ok($zip->set_number('2208585')->is_valid_number, '神奈川県立 図書館');
ok($zip->set_number('2208586')->is_valid_number, '日本KFCホールディングス 株式会社');
ok($zip->set_number('2208588')->is_valid_number, '株式会社 神奈川新聞社');
ok($zip->set_number('2208601')->is_valid_number, '株式会社 高島屋 横浜店');
ok($zip->set_number('2208604')->is_valid_number, '野村證券 (株)');
ok($zip->set_number('2208609')->is_valid_number, '商工中金 横浜西口支店');
ok($zip->set_number('2208611')->is_valid_number, '株式会社 横浜銀行');
ok($zip->set_number('2208612')->is_valid_number, '株式会社 横浜銀行 本店営業部');
ok($zip->set_number('2208613')->is_valid_number, '浜銀ファイナンス');
ok($zip->set_number('2208614')->is_valid_number, '横浜信用保証 株式会社');
ok($zip->set_number('2208615')->is_valid_number, '横浜銀行バンクカード');
ok($zip->set_number('2208616')->is_valid_number, '株式会社 浜銀総合研究所');
ok($zip->set_number('2208620')->is_valid_number, '大和ハウス工業 株式会社 横浜支社');
ok($zip->set_number('2208623')->is_valid_number, '日産自動車 株式会社 横浜工場');
ok($zip->set_number('2208625')->is_valid_number, '京浜急行電鉄 株式会社');
ok($zip->set_number('2208653')->is_valid_number, '三井住友信託銀行 株式会社 横浜支店');
ok($zip->set_number('2208660')->is_valid_number, 'みずほ信託銀行 株式会社 横浜支店');
ok($zip->set_number('2208668')->is_valid_number, '富士ゼロックス 株式会社 横浜みなとみらい事業所');
ok($zip->set_number('2208678')->is_valid_number, '富士ゼロックスアドバンストテクノロジー 株式会社 横浜みなとみらい事業所');
ok($zip->set_number('2208680')->is_valid_number, '株式会社 シンクロン');
ok($zip->set_number('2208684')->is_valid_number, 'スリーエムジャパン 株式会社');
ok($zip->set_number('2208686')->is_valid_number, '日産自動車 株式会社');
ok($zip->set_number('2208711')->is_valid_number, '富士通ネットワークソリューションズ 株式会社');
ok($zip->set_number('2208720')->is_valid_number, 'いすゞ自動車 株式会社');
ok($zip->set_number('2208722')->is_valid_number, '富士通 株式会社 神奈川支社');
ok($zip->set_number('2208739')->is_valid_number, '学校法人 神奈川大学 みなとみらいキャンパス');
ok($zip->set_number('2208750')->is_valid_number, 'ソニーグループ 株式会社 ソニーシティみなとみらい');
ok($zip->set_number('2208755')->is_valid_number, 'オーケー 株式会社');
ok($zip->set_number('2208765')->is_valid_number, '千代田化工建設 株式会社');
ok($zip->set_number('2218510')->is_valid_number, '株式会社 ぱど 横浜支局');
ok($zip->set_number('2218511')->is_valid_number, '楠原輸送 株式会社');
ok($zip->set_number('2218517')->is_valid_number, '昭和電工 株式会社 横浜事業所');
ok($zip->set_number('2218520')->is_valid_number, '株式会社 インテック');
ok($zip->set_number('2218522')->is_valid_number, '株式会社 インテックコスモセンター');
ok($zip->set_number('2218523')->is_valid_number, '横浜マリノス 株式会社');
ok($zip->set_number('2218529')->is_valid_number, '国立研究開発法人 水産研究・教育機構');
ok($zip->set_number('2218537')->is_valid_number, '千代田火災海上保険 株式会社 神奈川自動車支店');
ok($zip->set_number('2218540')->is_valid_number, 'コマツ物流 株式会社');
ok($zip->set_number('2218550')->is_valid_number, '三菱鉛筆 株式会社 横浜事業所');
ok($zip->set_number('2218558')->is_valid_number, 'キリンエンジニアリング 株式会社');
ok($zip->set_number('2218560')->is_valid_number, '日立キャピタル 株式会社 神奈川支店');
ok($zip->set_number('2218588')->is_valid_number, '株式会社 カナセキユニオン');
ok($zip->set_number('2218611')->is_valid_number, 'ミツワ電機 株式会社 横浜支店');
ok($zip->set_number('2218623')->is_valid_number, '日産自動車');
ok($zip->set_number('2218666')->is_valid_number, '株式会社 スルガコーポレーション');
ok($zip->set_number('2218686')->is_valid_number, '神奈川大学');
ok($zip->set_number('2218701')->is_valid_number, '松下電工 株式会社 横浜ショウルーム');
ok($zip->set_number('2218702')->is_valid_number, '日本発条 株式会社 横浜分室');
ok($zip->set_number('2218703')->is_valid_number, '株式会社 ハリマビステム');
ok($zip->set_number('2218705')->is_valid_number, '株式会社 ベリテ');
ok($zip->set_number('2218712')->is_valid_number, '東邦電気 株式会社');
ok($zip->set_number('2218718')->is_valid_number, '一般社団法人 日本自動車連盟 神奈川支部');
ok($zip->set_number('2218741')->is_valid_number, '株式会社 創健社');
ok($zip->set_number('2218765')->is_valid_number, '明和管理 株式会社');
ok($zip->set_number('2228501')->is_valid_number, '全労済 神奈川県本部');
ok($zip->set_number('2228505')->is_valid_number, '株式会社 図研');
ok($zip->set_number('2228507')->is_valid_number, '株式会社 小野測器');
ok($zip->set_number('2228508')->is_valid_number, '富士通エレクトロニクス 株式会社');
ok($zip->set_number('2228509')->is_valid_number, '中日本高速道路 (株) 横浜支社');
ok($zip->set_number('2228511')->is_valid_number, '株式会社 日能研');
ok($zip->set_number('2228515')->is_valid_number, '中央労働金庫 業務集中センター');
ok($zip->set_number('2228520')->is_valid_number, 'NECモバイリング 株式会社');
ok($zip->set_number('2228523')->is_valid_number, '株式会社 エヌ・ティ・エス');
ok($zip->set_number('2228525')->is_valid_number, '株式会社 チップワンストップ');
ok($zip->set_number('2228530')->is_valid_number, '株式会社 リコー 新横浜事業所');
ok($zip->set_number('2228533')->is_valid_number, '新横浜プリンスホテル');
ok($zip->set_number('2228550')->is_valid_number, '神奈川税務署');
ok($zip->set_number('2228552')->is_valid_number, 'レーザーテック 株式会社');
ok($zip->set_number('2228556')->is_valid_number, 'アクサ損害保険 株式会社');
ok($zip->set_number('2228558')->is_valid_number, 'アマノ 株式会社');
ok($zip->set_number('2228561')->is_valid_number, '株式会社 マクニカ');
ok($zip->set_number('2228562')->is_valid_number, 'マクニカネットワークス 株式会社');
ok($zip->set_number('2228563')->is_valid_number, '株式会社 マクニカ');
ok($zip->set_number('2228564')->is_valid_number, 'アマノマネジメントサービス 株式会社');
ok($zip->set_number('2228565')->is_valid_number, 'アマノメンテナンスエンジニアリング 株式会社');
ok($zip->set_number('2228566')->is_valid_number, 'ヒロセ電機 株式会社 菊名事業所');
ok($zip->set_number('2228575')->is_valid_number, 'ローム新横浜駅前ビル ラピスセミコンダクタ 株式会社 ラピステクノロジー 株式会社');
ok($zip->set_number('2228577')->is_valid_number, '株式会社 聘珍樓');
ok($zip->set_number('2228580')->is_valid_number, 'イノテック 株式会社');
ok($zip->set_number('2228585')->is_valid_number, '日本ランズエンド 株式会社');
ok($zip->set_number('2228586')->is_valid_number, 'イノマイクロ 株式会社');
ok($zip->set_number('2228622')->is_valid_number, '社団法人 書燈社');
ok($zip->set_number('2228652')->is_valid_number, 'ユーコープかながわ');
ok($zip->set_number('2238501')->is_valid_number, 'アネスト岩田 株式会社');
ok($zip->set_number('2238502')->is_valid_number, 'アルプス電気 株式会社 横浜事業所');
ok($zip->set_number('2238505')->is_valid_number, 'リーダー電子 株式会社');
ok($zip->set_number('2238506')->is_valid_number, '日本工営 株式会社 横浜事業所');
ok($zip->set_number('2238507')->is_valid_number, '日本無線 株式会社');
ok($zip->set_number('2238508')->is_valid_number, '株式会社 エヌエフ回路設計ブロック');
ok($zip->set_number('2238510')->is_valid_number, '株式会社 トーエル');
ok($zip->set_number('2238511')->is_valid_number, '住友重機械モダン 株式会社');
ok($zip->set_number('2238512')->is_valid_number, 'ホリエ電機 株式会社');
ok($zip->set_number('2238515')->is_valid_number, '横浜信用金庫');
ok($zip->set_number('2238520')->is_valid_number, '株式会社 大堀');
ok($zip->set_number('2238521')->is_valid_number, '慶應義塾大学 日吉キャンパス');
ok($zip->set_number('2238522')->is_valid_number, '慶應義塾大学 理工学部');
ok($zip->set_number('2238523')->is_valid_number, '慶應義塾大学デジタルメディア・コンテンツ統合研究センター');
ok($zip->set_number('2238525')->is_valid_number, '株式会社 松永製作所');
ok($zip->set_number('2238526')->is_valid_number, '慶應義塾協生館');
ok($zip->set_number('2238527')->is_valid_number, '株式会社 コーエーテクモネット');
ok($zip->set_number('2238530')->is_valid_number, '株式会社 トーエル 横浜営業所');
ok($zip->set_number('2238533')->is_valid_number, '株式会社 岡本工作機械製作所');
ok($zip->set_number('2238539')->is_valid_number, '松下通信システム建設 株式会社');
ok($zip->set_number('2238540')->is_valid_number, 'サンコースプリング 株式会社');
ok($zip->set_number('2238541')->is_valid_number, '株式会社 ガリバー');
ok($zip->set_number('2238542')->is_valid_number, '株式会社 小泉神奈川');
ok($zip->set_number('2238550')->is_valid_number, '日本電熱計器 株式会社');
ok($zip->set_number('2238555')->is_valid_number, '株式会社 ナイガイ横浜センター');
ok($zip->set_number('2238558')->is_valid_number, 'オータックス 株式会社');
ok($zip->set_number('2238560')->is_valid_number, '株式会社 トーゴ');
ok($zip->set_number('2238566')->is_valid_number, '日本大学高等学校・日本大学中学校');
ok($zip->set_number('2238567')->is_valid_number, 'ユニー 日吉店');
ok($zip->set_number('2238570')->is_valid_number, '株式会社 トーエル 別館');
ok($zip->set_number('2238572')->is_valid_number, 'ジェイ・アール・シー特機 株式会社');
ok($zip->set_number('2238577')->is_valid_number, '大塚製靴 株式会社 日吉工場');
ok($zip->set_number('2238580')->is_valid_number, '株式会社 浅川製作所');
ok($zip->set_number('2238585')->is_valid_number, 'ワコー電子 株式会社');
ok($zip->set_number('2238588')->is_valid_number, '株式会社 エイト工業');
ok($zip->set_number('2248501')->is_valid_number, 'ボッシュ 株式会社');
ok($zip->set_number('2248502')->is_valid_number, '京セラ 株式会社 横浜事業所');
ok($zip->set_number('2248503')->is_valid_number, '昭和大学 横浜市北部病院');
ok($zip->set_number('2248504')->is_valid_number, '昭和大学 診療放射線専門学校');
ok($zip->set_number('2248505')->is_valid_number, '富士通化成 株式会社');
ok($zip->set_number('2248507')->is_valid_number, '株式会社 アイネス');
ok($zip->set_number('2248510')->is_valid_number, '東京濾器 株式会社');
ok($zip->set_number('2248515')->is_valid_number, '中央大学付属横浜中学校・高等学校');
ok($zip->set_number('2248520')->is_valid_number, 'パナソニック 株式会社 オートモーティブシステムズ社');
ok($zip->set_number('2248522')->is_valid_number, '株式会社 ソディック');
ok($zip->set_number('2248524')->is_valid_number, '株式会社 亀屋万年堂');
ok($zip->set_number('2248524')->is_valid_number, '亀屋万年堂製菓 株式会社');
ok($zip->set_number('2248539')->is_valid_number, 'パナソニックモバイルコミュニケーションズ 株式会社');
ok($zip->set_number('2248540')->is_valid_number, 'ヒロセ電機 株式会社');
ok($zip->set_number('2248550')->is_valid_number, '日本ヒルティ 株式会社');
ok($zip->set_number('2248551')->is_valid_number, '東京都市大学 横浜キャンパス');
ok($zip->set_number('2248578')->is_valid_number, '株式会社 オリヒカ');
ok($zip->set_number('2248580')->is_valid_number, '株式会社 図研');
ok($zip->set_number('2248585')->is_valid_number, '株式会社 図研');
ok($zip->set_number('2248588')->is_valid_number, '株式会社 AOKIホールディングス');
ok($zip->set_number('2248686')->is_valid_number, '株式会社 サカタのタネ');
ok($zip->set_number('2248688')->is_valid_number, '株式会社 AOKI');
ok($zip->set_number('2258501')->is_valid_number, '株式会社 ジャンボ');
ok($zip->set_number('2258502')->is_valid_number, '学校法人 桐蔭学園');
ok($zip->set_number('2258503')->is_valid_number, '桐蔭横浜大学');
ok($zip->set_number('2258508')->is_valid_number, 'アキュフェーズ 株式会社');
ok($zip->set_number('2258513')->is_valid_number, '緑県税事務所');
ok($zip->set_number('2258525')->is_valid_number, 'トップツアー 株式会社 個人旅行事業部(WEB販売センター・提携販売センター)');
ok($zip->set_number('2258530')->is_valid_number, 'たまプラーザ テラス リンクプラザ');
ok($zip->set_number('2258535')->is_valid_number, 'たまプラーザテラス');
ok($zip->set_number('2258539')->is_valid_number, '株式会社 ブルックス');
ok($zip->set_number('2258550')->is_valid_number, '緑税務署');
ok($zip->set_number('2258560')->is_valid_number, 'イッツ・コミュニケーションズ (株)');
ok($zip->set_number('2258585')->is_valid_number, '劇団四季 (四季 株式会社)');
ok($zip->set_number('2268501')->is_valid_number, '国立大学法人 東京工業大学');
ok($zip->set_number('2268502')->is_valid_number, '国立大学法人 東京工業大学');
ok($zip->set_number('2268503')->is_valid_number, '国立大学法人 東京工業大学');
ok($zip->set_number('2268507')->is_valid_number, '株式会社 小野測器');
ok($zip->set_number('2268510')->is_valid_number, '独立行政法人 中小企業基盤整備機構 東工大横浜ベンチャープラザ');
ok($zip->set_number('2268512')->is_valid_number, '京セラ 株式会社 横浜中山事業所');
ok($zip->set_number('2268525')->is_valid_number, '株式会社 JVCケンウッド 白山事業所');
ok($zip->set_number('2268555')->is_valid_number, '昭和大学 保健医療学部');
ok($zip->set_number('2268570')->is_valid_number, '緑区役所');
ok($zip->set_number('2278501')->is_valid_number, '昭和大学藤が丘病院');
ok($zip->set_number('2278502')->is_valid_number, '三菱ケミカル 株式会社 横浜研究所');
ok($zip->set_number('2278505')->is_valid_number, '藤が丘女子学生会館');
ok($zip->set_number('2278508')->is_valid_number, '丸子電気工事 株式会社');
ok($zip->set_number('2278512')->is_valid_number, '日本たばこ産業 株式会社 たばこ中央研究所');
ok($zip->set_number('2278518')->is_valid_number, '昭和大学藤が丘リハビリテーション病院');
ok($zip->set_number('2278522')->is_valid_number, '星槎大学 横浜情報処理センター');
ok($zip->set_number('2278540')->is_valid_number, '東急テクノシステム 株式会社 長津田工場');
ok($zip->set_number('2308501')->is_valid_number, '鶴見大学');
ok($zip->set_number('2308504')->is_valid_number, '森永製菓');
ok($zip->set_number('2308511')->is_valid_number, '株式会社 エーアンドエーマテリアル');
ok($zip->set_number('2308550')->is_valid_number, '鶴見 税務署');
ok($zip->set_number('2308555')->is_valid_number, '鶴見社会保険事務所');
ok($zip->set_number('2308571')->is_valid_number, 'ナイス 株式会社');
ok($zip->set_number('2308577')->is_valid_number, '横浜商科大学');
ok($zip->set_number('2308611')->is_valid_number, 'JFEエンジニアリング 株式会社 鶴見事業所');
ok($zip->set_number('2308628')->is_valid_number, 'キリンビール 横浜工場');
ok($zip->set_number('2308666')->is_valid_number, '日本ファーネス工業');
ok($zip->set_number('2308686')->is_valid_number, '大本山総持寺');
ok($zip->set_number('2308765')->is_valid_number, '社会福祉法人恩賜財団 済生会 横浜市東部病院');
ok($zip->set_number('2318001')->is_valid_number, '株式会社 テレビ神奈川');
ok($zip->set_number('2318008')->is_valid_number, '富士ソフト 株式会社');
ok($zip->set_number('2318307')->is_valid_number, '横浜市郵送請求事務センター');
ok($zip->set_number('2318310')->is_valid_number, '(社) 神奈川県産業貿易振興協会');
ok($zip->set_number('2318311')->is_valid_number, '一般社団法人 日本新聞協会');
ok($zip->set_number('2318312')->is_valid_number, '横浜市財政局主税部 法人課税課 事業所税担当');
ok($zip->set_number('2318313')->is_valid_number, '横浜市財政局主税部 納税管理課');
ok($zip->set_number('2318314')->is_valid_number, '横浜市財政局主税部 法人課税課 特別徴収センター');
ok($zip->set_number('2318315')->is_valid_number, '横浜アイランドタワー');
ok($zip->set_number('2318316')->is_valid_number, '横浜市財政局主税部 法人課税課 法人市民税担当');
ok($zip->set_number('2318320')->is_valid_number, '財団法人 神奈川県厚生福利振興会');
ok($zip->set_number('2318321')->is_valid_number, '株式会社 熊谷組 横浜支店');
ok($zip->set_number('2318323')->is_valid_number, '神奈川県福祉共済協同組合');
ok($zip->set_number('2318324')->is_valid_number, '日本放送協会 横浜放送局');
ok($zip->set_number('2318328')->is_valid_number, '関東学院大学 関内キャンパス');
ok($zip->set_number('2318330')->is_valid_number, '株式会社 ダイトーコーポレーション 横浜支店');
ok($zip->set_number('2318331')->is_valid_number, 'TOCみなとみらい');
ok($zip->set_number('2318335')->is_valid_number, 'JXグループ健康保険組合');
ok($zip->set_number('2318338')->is_valid_number, 'WMBSサポートセンター');
ok($zip->set_number('2318340')->is_valid_number, 'ハイアットリージェンシー横浜');
ok($zip->set_number('2318343')->is_valid_number, '横浜市財政局主税部 償却資産課');
ok($zip->set_number('2318346')->is_valid_number, '社会保険診療報酬支払基金 神奈川支部内 基金本部横浜オフィス');
ok($zip->set_number('2318411')->is_valid_number, '横浜地方法務局');
ok($zip->set_number('2318419')->is_valid_number, '丸全昭和運輸');
ok($zip->set_number('2318434')->is_valid_number, '神奈川労働局');
ok($zip->set_number('2318445')->is_valid_number, '株式会社 神奈川新聞社');
ok($zip->set_number('2318455')->is_valid_number, '横浜市市民文化会館関内ホール');
ok($zip->set_number('2318464')->is_valid_number, '株式会社 東芝 神奈川支社');
ok($zip->set_number('2318477')->is_valid_number, '株式会社 日新');
ok($zip->set_number('2318478')->is_valid_number, '株式会社 オーヴァル');
ok($zip->set_number('2318484')->is_valid_number, '日本国土開発 株式会社 横浜支店');
ok($zip->set_number('2318504')->is_valid_number, '朝日新聞横浜総局');
ok($zip->set_number('2318520')->is_valid_number, '株式会社 ホテルニューグランド');
ok($zip->set_number('2318528')->is_valid_number, '株式会社 ファンケル');
ok($zip->set_number('2318530')->is_valid_number, 'ウエインズトヨタ神奈川 株式会社');
ok($zip->set_number('2318534')->is_valid_number, '神奈川県 社会保険診療報酬支払基金');
ok($zip->set_number('2318536')->is_valid_number, '日本赤十字社 神奈川県支部');
ok($zip->set_number('2318539')->is_valid_number, '株式会社 ぱど');
ok($zip->set_number('2318544')->is_valid_number, '株式会社 ロイヤルホール');
ok($zip->set_number('2318549')->is_valid_number, '協同電気 株式会社');
ok($zip->set_number('2318550')->is_valid_number, '横浜中税務署');
ok($zip->set_number('2318553')->is_valid_number, '独立行政法人 地域医療機能推進機構 横浜中央病院');
ok($zip->set_number('2318555')->is_valid_number, '神奈川県 横浜県税事務所');
ok($zip->set_number('2318562')->is_valid_number, '横浜雙葉小学校');
ok($zip->set_number('2318566')->is_valid_number, 'あいおいニッセイ同和損害保険 (株)');
ok($zip->set_number('2318585')->is_valid_number, '横浜家庭裁判所');
ok($zip->set_number('2318588')->is_valid_number, '神奈川県庁');
ok($zip->set_number('2318616')->is_valid_number, '大成建設 株式会社 横浜支店');
ok($zip->set_number('2318623')->is_valid_number, '株式会社 有隣堂 伊勢佐木町本店');
ok($zip->set_number('2318631')->is_valid_number, '株式会社 ダイイチ');
ok($zip->set_number('2318651')->is_valid_number, 'フェリス女学院大学');
ok($zip->set_number('2318652')->is_valid_number, '宗教法人 カトリック横浜司教区 山手カトリック教会');
ok($zip->set_number('2318654')->is_valid_number, '学校法人 サンモールインターナショナルスクール');
ok($zip->set_number('2318660')->is_valid_number, '学校法人 フェリス女学院');
ok($zip->set_number('2318682')->is_valid_number, '横浜市立 みなと赤十字病院');
ok($zip->set_number('2318689')->is_valid_number, '吉川商事 株式会社');
ok($zip->set_number('2318711')->is_valid_number, '商工組合中央金庫 横浜支店');
ok($zip->set_number('2318715')->is_valid_number, '三菱重工業 株式会社 横浜製作所 本牧工場');
ok($zip->set_number('2318750')->is_valid_number, '横浜中税務署');
ok($zip->set_number('2318771')->is_valid_number, '横浜市こども青少年局 こども家庭課');
ok($zip->set_number('2318772')->is_valid_number, '横浜市こども青少年局 こども家庭課');
ok($zip->set_number('2318831')->is_valid_number, '株式会社 日本政策金融公庫 横浜支店');
ok($zip->set_number('2318966')->is_valid_number, '日石横浜ビル');
ok($zip->set_number('2328510')->is_valid_number, '放送大学神奈川学習センター');
ok($zip->set_number('2328515')->is_valid_number, '宗教法人 大山ねずの命神示教会');
ok($zip->set_number('2328531')->is_valid_number, '株式会社 ノグチ 横浜支店');
ok($zip->set_number('2328555')->is_valid_number, '神奈川県立こども医療センター');
ok($zip->set_number('2328558')->is_valid_number, '馬淵建設 株式会社');
ok($zip->set_number('2328580')->is_valid_number, '学校法人 横浜英和学院');
ok($zip->set_number('2328585')->is_valid_number, '横浜南社会保険事務所');
ok($zip->set_number('2328587')->is_valid_number, '横浜植木 株式会社');
ok($zip->set_number('2328602')->is_valid_number, '神奈川県自動車税管理事務所');
ok($zip->set_number('2328688')->is_valid_number, '株式会社 ヤマリア');
ok($zip->set_number('2338501')->is_valid_number, '横浜刑務所');
ok($zip->set_number('2338502')->is_valid_number, '横浜拘置支所');
ok($zip->set_number('2338503')->is_valid_number, '国立療養所南横浜病院');
ok($zip->set_number('2338550')->is_valid_number, '(株) 日揮');
ok($zip->set_number('2338555')->is_valid_number, '株式会社 京急ショッピングセンター');
ok($zip->set_number('2338556')->is_valid_number, '株式会社 京急百貨店');
ok($zip->set_number('2358501')->is_valid_number, '株式会社 IHI 横浜事業所');
ok($zip->set_number('2358505')->is_valid_number, 'JFE鋼材 株式会社 横浜事業所');
ok($zip->set_number('2358522')->is_valid_number, '株式会社 東芝 横浜事業所');
ok($zip->set_number('2358523')->is_valid_number, '東芝エネルギーシステムズ 株式会社 磯子エンジニアリングセンター');
ok($zip->set_number('2358558')->is_valid_number, '日清オイリオグループ 株式会社 横浜磯子事業場');
ok($zip->set_number('2368501')->is_valid_number, '関東学院大学');
ok($zip->set_number('2368502')->is_valid_number, '関東学院大学 金沢文庫キャンパス');
ok($zip->set_number('2368503')->is_valid_number, '関東学院大学 金沢八景室の木キャンパス');
ok($zip->set_number('2368504')->is_valid_number, '関東学院六浦中学校・高等学校');
ok($zip->set_number('2368515')->is_valid_number, '三菱重工業 株式会社 横浜製作所');
ok($zip->set_number('2368540')->is_valid_number, '日本飛行機 株式会社');
ok($zip->set_number('2368550')->is_valid_number, '横浜南税務署');
ok($zip->set_number('2368555')->is_valid_number, '杉田ゴルフ場');
ok($zip->set_number('2368641')->is_valid_number, '株式会社 REJ');
ok($zip->set_number('2368645')->is_valid_number, '(株) オーバル 横浜事業所');
ok($zip->set_number('2368648')->is_valid_number, '国立研究開発法人 水産研究・教育機構 水産資源研究所');
ok($zip->set_number('2368651')->is_valid_number, '神奈川県立循環器呼吸器病センター');
ok($zip->set_number('2368653')->is_valid_number, '社会福祉法人 恩賜財団 済生会若草病院');
ok($zip->set_number('2378510')->is_valid_number, '東芝ライテック 株式会社 横須賀事業所');
ok($zip->set_number('2378515')->is_valid_number, '海上自衛隊 横須賀基地業務隊');
ok($zip->set_number('2378523')->is_valid_number, '日産自動車 株式会社 追浜工場');
ok($zip->set_number('2378555')->is_valid_number, '住友重機械工業 株式会社 横須賀造船所');
ok($zip->set_number('2380292')->is_valid_number, 'ソノラス・コート油壺');
ok($zip->set_number('2380298')->is_valid_number, '三浦市役所');
ok($zip->set_number('2388510')->is_valid_number, '横浜地方裁判所 横須賀支部');
ok($zip->set_number('2388511')->is_valid_number, '学校法人 横須賀学院');
ok($zip->set_number('2388513')->is_valid_number, '横浜家庭裁判所 横須賀支部');
ok($zip->set_number('2388520')->is_valid_number, '西友 横須賀店');
ok($zip->set_number('2388522')->is_valid_number, '神奈川県立 保健福祉大学');
ok($zip->set_number('2388533')->is_valid_number, 'モアーズシティ');
ok($zip->set_number('2388535')->is_valid_number, '関東財務局 横浜財務事務所 横須賀出張所');
ok($zip->set_number('2388536')->is_valid_number, '横浜地方法務局 横須賀支局');
ok($zip->set_number('2388540')->is_valid_number, '横浜地方検察庁 横須賀支部 横須賀区検察庁');
ok($zip->set_number('2388541')->is_valid_number, 'ダイエー 横須賀店');
ok($zip->set_number('2388550')->is_valid_number, '横須賀市役所');
ok($zip->set_number('2388558')->is_valid_number, '横須賀共済病院');
ok($zip->set_number('2388565')->is_valid_number, '横須賀税務署');
ok($zip->set_number('2388567')->is_valid_number, '横須賀市立 うわまち病院');
ok($zip->set_number('2388570')->is_valid_number, '神奈川歯科大学附属病院');
ok($zip->set_number('2388580')->is_valid_number, '神奈川歯科大学');
ok($zip->set_number('2388585')->is_valid_number, '横須賀商工会議所');
ok($zip->set_number('2388588')->is_valid_number, '社会福祉法人 日本医療伝道会 総合病院 衣笠病院');
ok($zip->set_number('2388616')->is_valid_number, '湘南信用金庫');
ok($zip->set_number('2388686')->is_valid_number, '三浦藤沢信用金庫');
ok($zip->set_number('2398501')->is_valid_number, 'ウィング久里浜');
ok($zip->set_number('2398528')->is_valid_number, '株式会社 JVCケンウッド 横須賀工場');
ok($zip->set_number('2398550')->is_valid_number, '株式会社 JVC ケンウッド 久里浜技術センター');
ok($zip->set_number('2398558')->is_valid_number, '株式会社 ニフコ 技術開発センター');
ok($zip->set_number('2398560')->is_valid_number, '株式会社 ニフコ 本社');
ok($zip->set_number('2398585')->is_valid_number, '独立行政法人 国立特別支援教育総合研究所');
ok($zip->set_number('2398588')->is_valid_number, '東京電力 株式会社 横須賀火力発電所');
ok($zip->set_number('2398686')->is_valid_number, '防衛大学校');
ok($zip->set_number('2398688')->is_valid_number, '株式会社 ヤマリア');
ok($zip->set_number('2400192')->is_valid_number, '葉山町役場');
ok($zip->set_number('2400193')->is_valid_number, '総合研究大学院大学');
ok($zip->set_number('2400195')->is_valid_number, '横須賀市立 市民病院');
ok($zip->set_number('2400196')->is_valid_number, '財団法人 電力中央研究所 横須賀研究所');
ok($zip->set_number('2400197')->is_valid_number, '社会福祉法人 全国社会福祉協議会 中央福祉学院');
ok($zip->set_number('2400198')->is_valid_number, '株式会社 湘南国際村協会');
ok($zip->set_number('2408501')->is_valid_number, '横浜国立大学');
ok($zip->set_number('2408521')->is_valid_number, '聖隷横浜病院');
ok($zip->set_number('2408540')->is_valid_number, 'NTT横浜情報サービスセンター');
ok($zip->set_number('2408550')->is_valid_number, '保土ケ谷税務署');
ok($zip->set_number('2408612')->is_valid_number, '横浜西労働基準監督署');
ok($zip->set_number('2418501')->is_valid_number, 'セブンスデー・アドベンチスト教団');
ok($zip->set_number('2418502')->is_valid_number, '学校法人 富士見丘学園 横浜富士見丘学園中等教育学校');
ok($zip->set_number('2418512')->is_valid_number, 'アイスター共済会(株式会社 アイボシ)');
ok($zip->set_number('2418515')->is_valid_number, '神奈川県立がんセンター');
ok($zip->set_number('2418525')->is_valid_number, '神奈川県内広域水道企業団 三ツ境本庁舎');
ok($zip->set_number('2418606')->is_valid_number, '医療法人 順正会 横浜鶴ヶ峰病院');
ok($zip->set_number('2428502')->is_valid_number, 'JP楽天ロジスティクス 株式会社 楽天フルフィルメントセンター中央林間');
ok($zip->set_number('2428507')->is_valid_number, '大和ラジオ放送 株式会社');
ok($zip->set_number('2428555')->is_valid_number, '太平金属工業 株式会社');
ok($zip->set_number('2428577')->is_valid_number, '株式会社 ガスター');
ok($zip->set_number('2428585')->is_valid_number, '日本モレックス 合同会社');
ok($zip->set_number('2428601')->is_valid_number, '大和市役所');
ok($zip->set_number('2428610')->is_valid_number, 'イオンリテール 株式会社 イオン大和店');
ok($zip->set_number('2430192')->is_valid_number, '日産自動車 株式会社 日産テクニカルセンター');
ok($zip->set_number('2430193')->is_valid_number, 'キヤノン 株式会社 中央研究所');
ok($zip->set_number('2430195')->is_valid_number, '清川村役場');
ok($zip->set_number('2430197')->is_valid_number, '株式会社 富士通研究所');
ok($zip->set_number('2430198')->is_valid_number, 'N・T・T・基礎技術総合研究所');
ok($zip->set_number('2430281')->is_valid_number, '日本フルハーフ 株式会社');
ok($zip->set_number('2430292')->is_valid_number, '神奈川工科大学');
ok($zip->set_number('2430297')->is_valid_number, '東京工芸大学');
ok($zip->set_number('2430298')->is_valid_number, '株式会社 リコー 厚木事業所');
ok($zip->set_number('2430392')->is_valid_number, '愛川町役場');
ok($zip->set_number('2430460')->is_valid_number, 'リコーテクノロジーセンター');
ok($zip->set_number('2430480')->is_valid_number, 'アマゾン海老名IXD');
ok($zip->set_number('2430482')->is_valid_number, 'ららぽーと海老名');
ok($zip->set_number('2430483')->is_valid_number, '株式会社 丸井 マルイファミリー海老名');
ok($zip->set_number('2430484')->is_valid_number, 'ビナウォーク4番館');
ok($zip->set_number('2430485')->is_valid_number, 'ビナウォーク管理センター');
ok($zip->set_number('2430486')->is_valid_number, 'TOHOシネマズ海老名');
ok($zip->set_number('2430487')->is_valid_number, 'オイシックスステーション');
ok($zip->set_number('2430489')->is_valid_number, '小田急電鉄 株式会社');
ok($zip->set_number('2430492')->is_valid_number, '海老名市役所');
ok($zip->set_number('2430493')->is_valid_number, 'アツギ 株式会社');
ok($zip->set_number('2430494')->is_valid_number, '富士ゼロックス 株式会社 海老名事業所');
ok($zip->set_number('2430496')->is_valid_number, 'ものみの塔聖書冊子協会');
ok($zip->set_number('2430497')->is_valid_number, '富士ゼロックスマニュファクチュアリング 株式会社 海老名(本社)');
ok($zip->set_number('2438501')->is_valid_number, 'ソニー学園湘北短期大学');
ok($zip->set_number('2438505')->is_valid_number, '株式会社 シーアールイー 厚木営業所');
ok($zip->set_number('2438510')->is_valid_number, '日立オートモティブシステムズ 株式会社');
ok($zip->set_number('2438511')->is_valid_number, '厚木市役所');
ok($zip->set_number('2438521')->is_valid_number, '昭和音楽大学');
ok($zip->set_number('2438522')->is_valid_number, '厚木県税事務所');
ok($zip->set_number('2438531')->is_valid_number, '森久保薬品 株式会社');
ok($zip->set_number('2438533')->is_valid_number, 'ミツミ電機 株式会社 厚木事業所');
ok($zip->set_number('2438550')->is_valid_number, '湘南厚木クリニック');
ok($zip->set_number('2438551')->is_valid_number, '湘南厚木病院');
ok($zip->set_number('2438555')->is_valid_number, 'アンリツ 株式会社');
ok($zip->set_number('2438571')->is_valid_number, '東名厚木病院');
ok($zip->set_number('2438577')->is_valid_number, '厚木税務署');
ok($zip->set_number('2438588')->is_valid_number, '厚木市立病院');
ok($zip->set_number('2438601')->is_valid_number, '大和証券');
ok($zip->set_number('2438604')->is_valid_number, '野村證券(株)厚木支店');
ok($zip->set_number('2438689')->is_valid_number, '鴻池運輸 株式会社 関東支店 厚木流通センター営業所');
ok($zip->set_number('2448501')->is_valid_number, '株式会社 タツノ・メカトロニクス 横浜工場');
ok($zip->set_number('2448502')->is_valid_number, '日立ハイブリッドネットワーク 株式会社');
ok($zip->set_number('2448503')->is_valid_number, 'グラフテック 株式会社');
ok($zip->set_number('2448510')->is_valid_number, '株式会社 ブリヂストン横浜工場');
ok($zip->set_number('2448511')->is_valid_number, 'ユテクジャパン 株式会社');
ok($zip->set_number('2448522')->is_valid_number, '株式会社 ニフコ');
ok($zip->set_number('2448528')->is_valid_number, 'ダイエー 東戸塚店');
ok($zip->set_number('2448530')->is_valid_number, '株式会社 西武百貨店 東戸塚店');
ok($zip->set_number('2448533')->is_valid_number, '株式会社 ニコン 横浜製作所');
ok($zip->set_number('2448539')->is_valid_number, '明治学院大学 横浜校舎');
ok($zip->set_number('2448550')->is_valid_number, '戸塚税務署');
ok($zip->set_number('2448555')->is_valid_number, '(株) 日立製作所ソフトウェア事業部');
ok($zip->set_number('2448558')->is_valid_number, '大洋建設 株式会社');
ok($zip->set_number('2448566')->is_valid_number, 'JCN神奈川エリア');
ok($zip->set_number('2448567')->is_valid_number, '株式会社 日立製作所 通信ネットワーク事業部');
ok($zip->set_number('2448569')->is_valid_number, 'KIホールディングス 株式会社');
ok($zip->set_number('2448571')->is_valid_number, 'コイト電工 株式会社');
ok($zip->set_number('2448577')->is_valid_number, '株式会社 ファンケル');
ok($zip->set_number('2448585')->is_valid_number, '株式会社 有隣堂');
ok($zip->set_number('2448588')->is_valid_number, '住友電気工業 株式会社 横浜製作所');
ok($zip->set_number('2448589')->is_valid_number, 'SEIオプティフロンティア 株式会社 本社・横浜事業所');
ok($zip->set_number('2448601')->is_valid_number, '大和証券 株式会社 戸塚支店');
ok($zip->set_number('2448602')->is_valid_number, '中外製薬 株式会社 中外ライフサイエンスパーク横浜');
ok($zip->set_number('2458510')->is_valid_number, '株式会社 ミツバ 横浜本社');
ok($zip->set_number('2458542')->is_valid_number, 'かもめプロペラ 株式会社');
ok($zip->set_number('2458550')->is_valid_number, '日本貿易印刷 株式会社');
ok($zip->set_number('2458555')->is_valid_number, 'ユージエム 株式会社');
ok($zip->set_number('2458558')->is_valid_number, '株式会社 日産クリエイティブサービス');
ok($zip->set_number('2458560')->is_valid_number, '医療法人 横浜博萌会 西横浜国際総合病院');
ok($zip->set_number('2458575')->is_valid_number, '独立行政法人 国立病院機構 横浜医療センター');
ok($zip->set_number('2458577')->is_valid_number, '三池工業 株式会社');
ok($zip->set_number('2458589')->is_valid_number, '横浜薬科大学');
ok($zip->set_number('2458650')->is_valid_number, 'フェリス女学院大学');
ok($zip->set_number('2458651')->is_valid_number, 'フェリス女学院大学附属図書館');
ok($zip->set_number('2468520')->is_valid_number, '(株) カナジュウ・コーポレーション');
ok($zip->set_number('2468550')->is_valid_number, '清水建設 株式会社 相模機械センター');
ok($zip->set_number('2468556')->is_valid_number, '株式会社 竹虎');
ok($zip->set_number('2478510')->is_valid_number, '電気化学工業 株式会社 大船工場');
ok($zip->set_number('2478530')->is_valid_number, '中外製薬 株式会社');
ok($zip->set_number('2478533')->is_valid_number, '湘南鎌倉総合病院');
ok($zip->set_number('2478538')->is_valid_number, 'ミハル通信 株式会社');
ok($zip->set_number('2478550')->is_valid_number, 'シンロイヒ (株)');
ok($zip->set_number('2478560')->is_valid_number, '芝浦メカトロニクス 株式会社 横浜事業所');
ok($zip->set_number('2478570')->is_valid_number, '株式会社 タツノ 横浜工場');
ok($zip->set_number('2478577')->is_valid_number, '株式会社 ファンケル');
ok($zip->set_number('2478578')->is_valid_number, '株式会社 ネオエフ');
ok($zip->set_number('2478585')->is_valid_number, 'キオクシア 株式会社 横浜テクノロジーキャンパス');
ok($zip->set_number('2478588')->is_valid_number, '株式会社 アテニア');
ok($zip->set_number('2478610')->is_valid_number, '芝浦メカトロニクス 株式会社 本社');
ok($zip->set_number('2478630')->is_valid_number, '株式会社 いいもの王国');
ok($zip->set_number('2478686')->is_valid_number, '株式会社 ジェイコム湘南鎌倉局');
ok($zip->set_number('2478730')->is_valid_number, '株式会社 いいもの王国');
ok($zip->set_number('2488555')->is_valid_number, '東レ 株式会社 基礎研究センター');
ok($zip->set_number('2488686')->is_valid_number, '鎌倉市役所');
ok($zip->set_number('2498510')->is_valid_number, '逗子開成中学・高等学校');
ok($zip->set_number('2498686')->is_valid_number, '逗子市役所');
ok($zip->set_number('2500192')->is_valid_number, '南足柄市役所');
ok($zip->set_number('2500193')->is_valid_number, '富士フイルム 株式会社 神奈川事業場');
ok($zip->set_number('2500280')->is_valid_number, '日本曹達 株式会社 小田原研究所');
ok($zip->set_number('2500292')->is_valid_number, '株式会社 竿好');
ok($zip->set_number('2500293')->is_valid_number, '愛光電気 株式会社');
ok($zip->set_number('2500294')->is_valid_number, '有限会社 ルートフィッシィング');
ok($zip->set_number('2500295')->is_valid_number, '日本インジェクタ 株式会社');
ok($zip->set_number('2500296')->is_valid_number, '小田原市水道局');
ok($zip->set_number('2500298')->is_valid_number, '株式会社 大川');
ok($zip->set_number('2500392')->is_valid_number, '富士屋ホテル 株式会社 湯本富士屋ホテル');
ok($zip->set_number('2500398')->is_valid_number, '箱根町役場');
ok($zip->set_number('2500493')->is_valid_number, '公益財団法人 彫刻の森芸術文化財団 彫刻の森美術館');
ok($zip->set_number('2500592')->is_valid_number, '箱根プリンスホテル');
ok($zip->set_number('2508511')->is_valid_number, '小田原税務署');
ok($zip->set_number('2508555')->is_valid_number, '小田原市役所');
ok($zip->set_number('2508560')->is_valid_number, 'アマゾン 小田原FC 入庫係');
ok($zip->set_number('2508588')->is_valid_number, '国際医療福祉大学 小田原保健医療学部');
ok($zip->set_number('2518501')->is_valid_number, '日本精工 株式会社 藤沢工場');
ok($zip->set_number('2518502')->is_valid_number, '株式会社 荏原製作所');
ok($zip->set_number('2518505')->is_valid_number, '学校法人 湘南学園');
ok($zip->set_number('2518510')->is_valid_number, 'ソニー 株式会社 湘南テクノロジーセンター');
ok($zip->set_number('2518511')->is_valid_number, '学校法人 湘南工科大学');
ok($zip->set_number('2518513')->is_valid_number, '池上通信機 株式会社 放送通信事業本部 湘南工場');
ok($zip->set_number('2518515')->is_valid_number, 'キーパー 株式会社');
ok($zip->set_number('2518522')->is_valid_number, '株式会社 山武 藤沢工場');
ok($zip->set_number('2518530')->is_valid_number, '医療法人 社団清心会 藤沢病院');
ok($zip->set_number('2518531')->is_valid_number, 'ミネベア 株式会社 藤沢製作所');
ok($zip->set_number('2518533')->is_valid_number, '神奈川県聴覚障害者福祉センター');
ok($zip->set_number('2518534')->is_valid_number, '藤沢県税事務所');
ok($zip->set_number('2518540')->is_valid_number, '株式会社 佐賀鉄工所 藤沢工場');
ok($zip->set_number('2518543')->is_valid_number, '株式会社 アトムシステム');
ok($zip->set_number('2518550')->is_valid_number, '藤沢市民病院');
ok($zip->set_number('2518551')->is_valid_number, '株式会社 神戸製鋼所 藤沢事業所');
ok($zip->set_number('2518555')->is_valid_number, '湘南ヘルスイノベーションパーク');
ok($zip->set_number('2518558')->is_valid_number, '株式会社 さいか屋 藤沢店');
ok($zip->set_number('2518560')->is_valid_number, '株式会社 ジェイコム湘南');
ok($zip->set_number('2518566')->is_valid_number, '藤沢税務署');
ok($zip->set_number('2518567')->is_valid_number, '吉原建設 株式会社');
ok($zip->set_number('2518570')->is_valid_number, 'ODAKYU 湘南 GATE');
ok($zip->set_number('2518580')->is_valid_number, '小田急百貨店 ふじさわ');
ok($zip->set_number('2518581')->is_valid_number, '東京スター銀行 藤沢支店');
ok($zip->set_number('2518588')->is_valid_number, '協同油脂 株式会社');
ok($zip->set_number('2518601')->is_valid_number, '藤沢市役所');
ok($zip->set_number('2520370')->is_valid_number, '株式会社 横浜岡田屋');
ok($zip->set_number('2520371')->is_valid_number, '伊勢丹 相模原店');
ok($zip->set_number('2520373')->is_valid_number, '学校法人 北里研究所');
ok($zip->set_number('2520374')->is_valid_number, '北里大学 医学部');
ok($zip->set_number('2520375')->is_valid_number, '北里大学病院');
ok($zip->set_number('2520377')->is_valid_number, '相模原市 南区役所');
ok($zip->set_number('2520378')->is_valid_number, '陸上自衛隊 座間駐屯地');
ok($zip->set_number('2520381')->is_valid_number, '相模原県税事務所');
ok($zip->set_number('2520383')->is_valid_number, '学校法人 相模女子大学');
ok($zip->set_number('2520385')->is_valid_number, '東芝林間病院');
ok($zip->set_number('2520386')->is_valid_number, '特別養護老人ホーム グレープの里');
ok($zip->set_number('2520388')->is_valid_number, '相模原年金事務所');
ok($zip->set_number('2520392')->is_valid_number, '独立行政法人 国立病院機構 相模原病院');
ok($zip->set_number('2520395')->is_valid_number, '東海大学付属相模高等学校・中等部');
ok($zip->set_number('2520398')->is_valid_number, '株式会社 家具の大正堂 本部');
ok($zip->set_number('2520880')->is_valid_number, '日本大学 生物資源科学部 湘南校舎');
ok($zip->set_number('2520881')->is_valid_number, 'いすゞ自動車 (株) 藤沢工場');
ok($zip->set_number('2520882')->is_valid_number, '慶應義塾湘南藤沢事務室');
ok($zip->set_number('2520883')->is_valid_number, '慶應義塾大学 看護医療学部');
ok($zip->set_number('2520885')->is_valid_number, '日本大学藤沢高等学校・日本大学藤沢中学校');
ok($zip->set_number('2520886')->is_valid_number, '社会福祉法人 光友会');
ok($zip->set_number('2520888')->is_valid_number, '株式会社 HGSTジャパン');
ok($zip->set_number('2521192')->is_valid_number, '綾瀬市役所');
ok($zip->set_number('2521193')->is_valid_number, '財団法人 相模中央化学研究所');
ok($zip->set_number('2521195')->is_valid_number, '株式会社 ガステック');
ok($zip->set_number('2525152')->is_valid_number, '相模原市 藤野総合事務所');
ok($zip->set_number('2525162')->is_valid_number, '相模原市 相模湖総合事務所');
ok($zip->set_number('2525172')->is_valid_number, '相模原市 津久井総合事務所');
ok($zip->set_number('2525177')->is_valid_number, '相模原市 緑区役所');
ok($zip->set_number('2525181')->is_valid_number, 'アイダエンジニアリング 株式会社');
ok($zip->set_number('2525183')->is_valid_number, '大和製缶 (株) 東京工場');
ok($zip->set_number('2525185')->is_valid_number, '神奈川つくい農業協同組合');
ok($zip->set_number('2525188')->is_valid_number, '相模原協同病院');
ok($zip->set_number('2525189')->is_valid_number, '日本板硝子 相模原事業所');
ok($zip->set_number('2525191')->is_valid_number, 'アイダエンジニアリング 株式会社 津久井事業所');
ok($zip->set_number('2525192')->is_valid_number, '相模原市 城山総合事務所');
ok($zip->set_number('2525201')->is_valid_number, '学校法人 麻布獣医学園');
ok($zip->set_number('2525210')->is_valid_number, '宇宙航空研究開発機構 宇宙科学研究所');
ok($zip->set_number('2525211')->is_valid_number, '相模原税務署');
ok($zip->set_number('2525212')->is_valid_number, 'GLP ALFALINK相模原1');
ok($zip->set_number('2525213')->is_valid_number, 'GLP ALFALINK相模原4');
ok($zip->set_number('2525214')->is_valid_number, 'GLP ALFALINK相模原2');
ok($zip->set_number('2525215')->is_valid_number, 'GLP ALFALINK相模原3');
ok($zip->set_number('2525220')->is_valid_number, 'アマゾン相模原FC');
ok($zip->set_number('2525221')->is_valid_number, 'サクサ 株式会社 相模原オフィス');
ok($zip->set_number('2525222')->is_valid_number, '和泉短期大学');
ok($zip->set_number('2525225')->is_valid_number, '社会福祉法人 相模更正会 総合相模更正病院');
ok($zip->set_number('2525233')->is_valid_number, 'J:COM');
ok($zip->set_number('2525250')->is_valid_number, '日本ルメンタム 株式会社');
ok($zip->set_number('2525252')->is_valid_number, '株式会社 オリバー');
ok($zip->set_number('2525255')->is_valid_number, 'ウイッツグループホールディングス 株式会社');
ok($zip->set_number('2525258')->is_valid_number, '青山学院大学 相模原キャンパス');
ok($zip->set_number('2525260')->is_valid_number, 'イトーヨーカ堂 相模原IDC');
ok($zip->set_number('2525269')->is_valid_number, 'CROOZ SHOPLIST 株式会社 SHOPLIST LOGISTICS CENTER');
ok($zip->set_number('2525277')->is_valid_number, '相模原市役所');
ok($zip->set_number('2525280')->is_valid_number, '株式会社 デュプロ');
ok($zip->set_number('2525285')->is_valid_number, 'スリーエムジャパン 株式会社 相模原事業所');
ok($zip->set_number('2525286')->is_valid_number, '株式会社 オハラ');
ok($zip->set_number('2525287')->is_valid_number, '東プレ 株式会社 相模原事業所');
ok($zip->set_number('2525288')->is_valid_number, '株式会社 エフエムさがみ');
ok($zip->set_number('2525293')->is_valid_number, '三菱重工業 株式会社 汎用機・特車事業本部');
ok($zip->set_number('2525294')->is_valid_number, '株式会社 ノジマ 相模原本店');
ok($zip->set_number('2525295')->is_valid_number, '三菱電機 株式会社 半導体・デバイス業務統括部 相模事務所');
ok($zip->set_number('2525297')->is_valid_number, 'マイクロン橋本技術センター');
ok($zip->set_number('2525298')->is_valid_number, '日本電気 株式会社 相模原事業場');
ok($zip->set_number('2528502')->is_valid_number, '日産自動車 株式会社 座間事業所');
ok($zip->set_number('2528511')->is_valid_number, 'キャンプ座間');
ok($zip->set_number('2528522')->is_valid_number, '株式会社 Paltac 横浜支社');
ok($zip->set_number('2528538')->is_valid_number, '女子美術大学');
ok($zip->set_number('2528539')->is_valid_number, '株式会社 マルスコーポレーション');
ok($zip->set_number('2528540')->is_valid_number, 'NPO法人 神奈川県視覚障害者福祉協会');
ok($zip->set_number('2528550')->is_valid_number, '東京コスモス電機 株式会社');
ok($zip->set_number('2528558')->is_valid_number, '株式会社 ユーテムプレシジョン');
ok($zip->set_number('2528560')->is_valid_number, 'マガシーク物流センターmagaco');
ok($zip->set_number('2528566')->is_valid_number, '座間市役所');
ok($zip->set_number('2528567')->is_valid_number, '株式会社 シーイーシー');
ok($zip->set_number('2528570')->is_valid_number, '日本電産トーソク 株式会社');
ok($zip->set_number('2528572')->is_valid_number, 'イオンモール座間');
ok($zip->set_number('2528585')->is_valid_number, '三木プーリ (株) 相模事業所');
ok($zip->set_number('2530193')->is_valid_number, 'ユシロ化学工業 株式会社 テクニカルセンター');
ok($zip->set_number('2530195')->is_valid_number, '寒川神社');
ok($zip->set_number('2530196')->is_valid_number, '寒川町役場');
ok($zip->set_number('2538510')->is_valid_number, '東邦チタニウム 株式会社');
ok($zip->set_number('2538522')->is_valid_number, 'アルバック・ファイ 株式会社');
ok($zip->set_number('2538530')->is_valid_number, '株式会社 寿恵会ネオ・サミット 茅ヶ崎');
ok($zip->set_number('2538531')->is_valid_number, 'イオンリテール 株式会社 イオンスタイル湘南茅ヶ崎');
ok($zip->set_number('2538543')->is_valid_number, '株式会社 アルバック');
ok($zip->set_number('2538550')->is_valid_number, '文教大学 湘南校舎 文教大学 女子短期大学部');
ok($zip->set_number('2538555')->is_valid_number, 'アルバックテクノ 株式会社');
ok($zip->set_number('2538571')->is_valid_number, '株式会社 オーテックジャパン');
ok($zip->set_number('2538577')->is_valid_number, 'TOTO株式会社 茅ヶ崎工場');
ok($zip->set_number('2538585')->is_valid_number, 'セイミケミカル 株式会社');
ok($zip->set_number('2538588')->is_valid_number, 'モリタ宮田工業 株式会社 茅ヶ崎工場');
ok($zip->set_number('2538660')->is_valid_number, '茅ヶ崎市保健所');
ok($zip->set_number('2538686')->is_valid_number, '茅ヶ崎市役所');
ok($zip->set_number('2548501')->is_valid_number, '神奈川中央交通 株式会社');
ok($zip->set_number('2548502')->is_valid_number, '平塚共済病院');
ok($zip->set_number('2548503')->is_valid_number, '日本特殊塗料 株式会社 平塚工場');
ok($zip->set_number('2548510')->is_valid_number, 'ららぽーと 湘南平塚');
ok($zip->set_number('2548530')->is_valid_number, 'JA全農青果センター 株式会社 営業本部 神奈川センター');
ok($zip->set_number('2548532')->is_valid_number, '株式会社 日産 サティオ湘南');
ok($zip->set_number('2548533')->is_valid_number, '平塚税務署');
ok($zip->set_number('2548543')->is_valid_number, '株式会社 KELK');
ok($zip->set_number('2548555')->is_valid_number, '株式会社 小松製作所 湘南工場');
ok($zip->set_number('2548562')->is_valid_number, '関西ペイント 株式会社 開発センター');
ok($zip->set_number('2548567')->is_valid_number, '株式会社 小松製作所 開発本部 先端・基盤技術センタ');
ok($zip->set_number('2548578')->is_valid_number, '平塚公共職業安定所');
ok($zip->set_number('2548585')->is_valid_number, '株式会社 パイロットコーポレーション 平塚工場');
ok($zip->set_number('2548588')->is_valid_number, 'ネッツトヨタ 神奈川 株式会社');
ok($zip->set_number('2548589')->is_valid_number, '関西ペイント 株式会社 平塚事業所');
ok($zip->set_number('2548601')->is_valid_number, '横浜ゴム 株式会社 平塚製造所');
ok($zip->set_number('2548610')->is_valid_number, '日産車体 株式会社');
ok($zip->set_number('2548612')->is_valid_number, '三菱ケミカル物流 株式会社 平塚支店');
ok($zip->set_number('2548614')->is_valid_number, '三菱ケミカル 株式会社 平塚工場');
ok($zip->set_number('2548686')->is_valid_number, '平塚市役所');
ok($zip->set_number('2558555')->is_valid_number, '大磯町役場');
ok($zip->set_number('2568510')->is_valid_number, '株式会社 HGSTジャパン');
ok($zip->set_number('2578501')->is_valid_number, '秦野市役所');
ok($zip->set_number('2578502')->is_valid_number, '株式会社 YDKテクノロジーズ');
ok($zip->set_number('2578511')->is_valid_number, '京セラ 株式会社 神奈川秦野工場');
ok($zip->set_number('2578523')->is_valid_number, '食品薬品安全センター');
ok($zip->set_number('2578533')->is_valid_number, '東京電力');
ok($zip->set_number('2578555')->is_valid_number, 'スタンレー電気 株式会社');
ok($zip->set_number('2578566')->is_valid_number, 'クアーズテック 株式会社 秦野事業所');
ok($zip->set_number('2578577')->is_valid_number, 'スタンレー電気 株式会社 秦野製作所 秦野テクニカルセンター');
ok($zip->set_number('2578584')->is_valid_number, '日立インフォメーション・テクノロジー');
ok($zip->set_number('2578585')->is_valid_number, '国立療養所 神奈川病院');
ok($zip->set_number('2578588')->is_valid_number, '秦野商工会議所');
ok($zip->set_number('2580195')->is_valid_number, '山北町役場');
ok($zip->set_number('2588501')->is_valid_number, '大井町役場');
ok($zip->set_number('2588506')->is_valid_number, '明治ゴム化成 株式会社');
ok($zip->set_number('2588511')->is_valid_number, '第一生命保険 株式会社 新大井事業所');
ok($zip->set_number('2588533')->is_valid_number, 'NEC湘南テクニカルセンター');
ok($zip->set_number('2588538')->is_valid_number, '富士写真フイルム 株式会社 宮台技術開発センター');
ok($zip->set_number('2588577')->is_valid_number, '富士フイルム先進研究所');
ok($zip->set_number('2588585')->is_valid_number, '松田町役場');
ok($zip->set_number('2590180')->is_valid_number, '株式会社 日立情報通信エンジニアリング 中井本社');
ok($zip->set_number('2590181')->is_valid_number, '株式会社 日立システムズ');
ok($zip->set_number('2590192')->is_valid_number, 'ファインテック製品事業本部');
ok($zip->set_number('2590193')->is_valid_number, '大磯プリンスホテル');
ok($zip->set_number('2590194')->is_valid_number, '有限会社 富士見グリーンサービス');
ok($zip->set_number('2590196')->is_valid_number, '二宮町役場');
ok($zip->set_number('2590197')->is_valid_number, '中井町役場');
ok($zip->set_number('2590392')->is_valid_number, '湯河原町役場');
ok($zip->set_number('2590393')->is_valid_number, '株式会社 ちぼり');
ok($zip->set_number('2590395')->is_valid_number, '財団法人 日本老人福祉財団 湯河原ゆうゆうの里');
ok($zip->set_number('2590396')->is_valid_number, '独立行政法人 地域医療機能推進機構 湯河原病院');
ok($zip->set_number('2591185')->is_valid_number, '学校法人 向上学園');
ok($zip->set_number('2591186')->is_valid_number, 'アマゾンジャパン伊勢原FC');
ok($zip->set_number('2591187')->is_valid_number, 'JA神奈川県厚生連 伊勢原協同病院');
ok($zip->set_number('2591188')->is_valid_number, '伊勢原市役所');
ok($zip->set_number('2591192')->is_valid_number, '市光工業 株式会社');
ok($zip->set_number('2591193')->is_valid_number, '東海大学医学部付属病院');
ok($zip->set_number('2591196')->is_valid_number, '株式会社 アマダ');
ok($zip->set_number('2591197')->is_valid_number, '産能大学');
ok($zip->set_number('2591198')->is_valid_number, '株式会社 アマダプレスシステム');
ok($zip->set_number('2591292')->is_valid_number, '東海大学 湘南校舎');
ok($zip->set_number('2591392')->is_valid_number, '株式会社 日立製作所 ITプラットフォーム営業本部');
ok($zip->set_number('2608501')->is_valid_number, '千葉県信用保証協会');
ok($zip->set_number('2608502')->is_valid_number, '千葉県市町村職員 共済組合');
ok($zip->set_number('2608503')->is_valid_number, '日本年金機構 千葉年金事務所');
ok($zip->set_number('2608505')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('2608506')->is_valid_number, '千葉労働基準監督署');
ok($zip->set_number('2608507')->is_valid_number, '千葉県赤十字血液センター 千葉港事業所');
ok($zip->set_number('2608508')->is_valid_number, '社会福祉法人 千葉県社会福祉協議会');
ok($zip->set_number('2608509')->is_valid_number, '日本赤十字社 千葉県支部');
ok($zip->set_number('2608510')->is_valid_number, '千葉中央警察署');
ok($zip->set_number('2608511')->is_valid_number, '千葉市中央保健福祉センター');
ok($zip->set_number('2608512')->is_valid_number, '全労済 千葉県本部');
ok($zip->set_number('2608513')->is_valid_number, '千葉保護観察所');
ok($zip->set_number('2608515')->is_valid_number, '日産プリンス千葉販売 株式会社');
ok($zip->set_number('2608516')->is_valid_number, '株式会社 NTTドコモ 千葉支店');
ok($zip->set_number('2608518')->is_valid_number, '千葉地方法務局');
ok($zip->set_number('2608521')->is_valid_number, '社会保険診療報酬支払基金 千葉支部');
ok($zip->set_number('2608523')->is_valid_number, '千葉県自動車税事務所');
ok($zip->set_number('2608524')->is_valid_number, '福井電機 株式会社');
ok($zip->set_number('2608527')->is_valid_number, '株式会社 ジャノメククレディア 出光クレジット係');
ok($zip->set_number('2608528')->is_valid_number, '株式会社 ジャノメククレディア データサービス部');
ok($zip->set_number('2608534')->is_valid_number, '小林商事 株式会社');
ok($zip->set_number('2608535')->is_valid_number, '千葉構内タクシー 株式会社');
ok($zip->set_number('2608536')->is_valid_number, '株式会社 井古田');
ok($zip->set_number('2608538')->is_valid_number, '千葉トヨタ自動車 株式会社');
ok($zip->set_number('2608540')->is_valid_number, '株式会社 NTTドコモ 千葉支店');
ok($zip->set_number('2608551')->is_valid_number, '東日本旅客鉄道 株式会社 千葉支社');
ok($zip->set_number('2608552')->is_valid_number, '大和リース 株式会社 千葉支店');
ok($zip->set_number('2608555')->is_valid_number, 'リコージャパン 株式会社 千葉支社');
ok($zip->set_number('2608557')->is_valid_number, '株式会社 そごう・西武 そごう千葉店');
ok($zip->set_number('2608558')->is_valid_number, '株式会社 関電工 千葉支店');
ok($zip->set_number('2608559')->is_valid_number, 'サンケイリビング新聞社 千葉本部');
ok($zip->set_number('2608560')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('2608561')->is_valid_number, '株式会社 東京クラウン 千葉支店');
ok($zip->set_number('2608562')->is_valid_number, '財団法人 日本防災通信協会 千葉県支部');
ok($zip->set_number('2608563')->is_valid_number, 'ネッツトヨタ千葉 株式会社');
ok($zip->set_number('2608564')->is_valid_number, '株式会社 千葉薬品');
ok($zip->set_number('2608566')->is_valid_number, '公益社団法人 千葉県防犯協会');
ok($zip->set_number('2608567')->is_valid_number, '株式会社 千葉測器');
ok($zip->set_number('2608570')->is_valid_number, '株式会社 内藤商店');
ok($zip->set_number('2608572')->is_valid_number, '学校法人 花沢学園');
ok($zip->set_number('2608575')->is_valid_number, '千葉県食糧 株式会社');
ok($zip->set_number('2608577')->is_valid_number, '千葉東税務署');
ok($zip->set_number('2608580')->is_valid_number, '東京国税局 千葉資料センター');
ok($zip->set_number('2608585')->is_valid_number, '千葉日産自動車 株式会社');
ok($zip->set_number('2608586')->is_valid_number, '千葉県酒類販売 株式会社');
ok($zip->set_number('2608588')->is_valid_number, '株式会社 ライフランド');
ok($zip->set_number('2608601')->is_valid_number, '学校法人 植草学園');
ok($zip->set_number('2608603')->is_valid_number, '中央労働金庫');
ok($zip->set_number('2608604')->is_valid_number, '日本年金機構 千葉事務センター');
ok($zip->set_number('2608606')->is_valid_number, '独立行政法人 国立病院機構 千葉医療センター');
ok($zip->set_number('2608607')->is_valid_number, '財務省 関東財務局 千葉財務事務所');
ok($zip->set_number('2608610')->is_valid_number, '日本放送協会 千葉放送局');
ok($zip->set_number('2608611')->is_valid_number, '株式会社 三井住友銀行 財形オフィス');
ok($zip->set_number('2608612')->is_valid_number, '千葉労働局 総務部・労働基準部・職業安定部・雇用均等室');
ok($zip->set_number('2608613')->is_valid_number, '株式会社 帝国データバンク 千葉支店');
ok($zip->set_number('2608618')->is_valid_number, '千葉市ボランティアセンター');
ok($zip->set_number('2608619')->is_valid_number, '公立学校共済組合 千葉支部');
ok($zip->set_number('2608620')->is_valid_number, '千葉地方検察庁');
ok($zip->set_number('2608621')->is_valid_number, '住友生命保険 相互会社 千葉支社');
ok($zip->set_number('2608622')->is_valid_number, '株式会社 阪急交通社 渡航手続センター');
ok($zip->set_number('2608624')->is_valid_number, '株式会社 阪急交通社 国内手続センター');
ok($zip->set_number('2608625')->is_valid_number, '千葉労働局 労働基準部 労災補償課分室');
ok($zip->set_number('2608626')->is_valid_number, '株式会社 三井不動産ホテルマネジメント 三井ガーデンホテル千葉');
ok($zip->set_number('2608627')->is_valid_number, '千葉県学校生活協同組合');
ok($zip->set_number('2608629')->is_valid_number, '財団法人 千葉県公立学校教職員互助会');
ok($zip->set_number('2608631')->is_valid_number, '株式会社 三越伊勢丹 三越千葉店');
ok($zip->set_number('2608633')->is_valid_number, '朝日生命保険 千葉支社');
ok($zip->set_number('2608635')->is_valid_number, '東京電力 株式会社');
ok($zip->set_number('2608636')->is_valid_number, '株式会社 三菱東京UFJ銀行 千葉支店、千葉中央支店');
ok($zip->set_number('2608637')->is_valid_number, '株式会社 大崎コンピュータエンヂニアリング 千葉支店');
ok($zip->set_number('2608642')->is_valid_number, '日本国土開発 株式会社 千葉営業所');
ok($zip->set_number('2608645')->is_valid_number, '全国健康保険協会 千葉支部');
ok($zip->set_number('2608647')->is_valid_number, '日本年金機構 千葉事務センター');
ok($zip->set_number('2608648')->is_valid_number, '日本年金機構 千葉事務センター');
ok($zip->set_number('2608654')->is_valid_number, '千葉県中央県税事務所');
ok($zip->set_number('2608656')->is_valid_number, '柏戸病院');
ok($zip->set_number('2608660')->is_valid_number, '千葉県立 中央図書館');
ok($zip->set_number('2608661')->is_valid_number, '公益財団法人 千葉県文化振興財団');
ok($zip->set_number('2608662')->is_valid_number, '千葉県教育庁 千葉県教育委員会');
ok($zip->set_number('2608663')->is_valid_number, '旭建設 株式会社');
ok($zip->set_number('2608665')->is_valid_number, '千葉県病院局');
ok($zip->set_number('2608666')->is_valid_number, '千葉窯業 株式会社');
ok($zip->set_number('2608667')->is_valid_number, '千葉県');
ok($zip->set_number('2608668')->is_valid_number, '千葉県警察本部');
ok($zip->set_number('2608670')->is_valid_number, '千葉大学 医学部');
ok($zip->set_number('2608671')->is_valid_number, '千葉大学附属図書館 亥鼻分館');
ok($zip->set_number('2608672')->is_valid_number, '千葉大学 看護学部');
ok($zip->set_number('2608673')->is_valid_number, '千葉大学真菌医学研究センター');
ok($zip->set_number('2608675')->is_valid_number, '千葉大学 薬学部 (医薬系総合研究棟)');
ok($zip->set_number('2608677')->is_valid_number, '千葉大学医学部附属病院');
ok($zip->set_number('2608682')->is_valid_number, '千葉県立 中央博物館');
ok($zip->set_number('2608685')->is_valid_number, '学校法人 千葉明徳学園');
ok($zip->set_number('2608688')->is_valid_number, '千葉南税務署');
ok($zip->set_number('2608701')->is_valid_number, '淑徳大学 千葉キャンパス');
ok($zip->set_number('2608703')->is_valid_number, '淑徳大学 看護栄養学部');
ok($zip->set_number('2608707')->is_valid_number, '医療法人 緑栄会 三愛記念 そが病院');
ok($zip->set_number('2608710')->is_valid_number, '千葉社会保険病院');
ok($zip->set_number('2608712')->is_valid_number, '独立行政法人 国立病院機構 千葉東病院');
ok($zip->set_number('2608713')->is_valid_number, '株式会社 みかど育種農業');
ok($zip->set_number('2608715')->is_valid_number, '千葉県衛生研究所');
ok($zip->set_number('2608717')->is_valid_number, '千葉県がんセンター');
ok($zip->set_number('2608720')->is_valid_number, '株式会社 千葉銀行');
ok($zip->set_number('2608722')->is_valid_number, '千葉市役所');
ok($zip->set_number('2608733')->is_valid_number, '千葉市中央区役所');
ok($zip->set_number('2608734')->is_valid_number, '千葉市区政事務センター');
ok($zip->set_number('2618501')->is_valid_number, '幕張テクノガーデン');
ok($zip->set_number('2618502')->is_valid_number, '東京歯科大学');
ok($zip->set_number('2618503')->is_valid_number, 'イオンリテール 株式会社 稲毛海岸事務所');
ok($zip->set_number('2618504')->is_valid_number, '株式会社 イオンファンタジー');
ok($zip->set_number('2618507')->is_valid_number, 'セイコーインスツル 株式会社');
ok($zip->set_number('2618508')->is_valid_number, '千葉県千葉西県税事務所');
ok($zip->set_number('2618510')->is_valid_number, '株式会社 ウェザーニューズ');
ok($zip->set_number('2618511')->is_valid_number, 'キンドリルジャパン 株式会社 幕張事業所');
ok($zip->set_number('2618512')->is_valid_number, '株式会社 京葉銀行 幸町センター');
ok($zip->set_number('2618513')->is_valid_number, 'イオンリテール 株式会社 ジャスコマリンピア店');
ok($zip->set_number('2618515')->is_valid_number, 'イオン 株式会社');
ok($zip->set_number('2618520')->is_valid_number, 'シャープ 株式会社 幕張事業所');
ok($zip->set_number('2618521')->is_valid_number, '東京電力 株式会社 千葉支社');
ok($zip->set_number('2618522')->is_valid_number, '日本アイ・ビー・エム 株式会社 幕張事業所');
ok($zip->set_number('2618528')->is_valid_number, 'アマゾン千葉みなとFC');
ok($zip->set_number('2618530')->is_valid_number, '山崎製パン 株式会社千葉工場');
ok($zip->set_number('2618533')->is_valid_number, '株式会社 QVCジャパン');
ok($zip->set_number('2618535')->is_valid_number, 'イオンモール 幕張新都心');
ok($zip->set_number('2618539')->is_valid_number, 'イオンモール 株式会社');
ok($zip->set_number('2618541')->is_valid_number, 'イオンコンパス (株) オペレーションセンター ハガキ事務局');
ok($zip->set_number('2618544')->is_valid_number, 'キヤノンマーケティングジャパン 株式会社 幕張事業所');
ok($zip->set_number('2618545')->is_valid_number, '日本貿易振興機構(ジェトロ) アジア経済研究所');
ok($zip->set_number('2618550')->is_valid_number, '幕張メッセ');
ok($zip->set_number('2618552')->is_valid_number, '千葉県企業局');
ok($zip->set_number('2618554')->is_valid_number, '株式会社 大地を守る会');
ok($zip->set_number('2618558')->is_valid_number, '独立行政法人 高齢・障害・求職者雇用支援機構');
ok($zip->set_number('2618560')->is_valid_number, '千葉県警察 千葉運転免許センター');
ok($zip->set_number('2618561')->is_valid_number, 'Sansan 株式会社 Bill Oneセンター');
ok($zip->set_number('2618566')->is_valid_number, 'スターツアメニティー 株式会社');
ok($zip->set_number('2618568')->is_valid_number, '住友ケミカルエンジニアリング 株式会社');
ok($zip->set_number('2618575')->is_valid_number, '(株) 日産フィナンシャルサービス');
ok($zip->set_number('2618577')->is_valid_number, '株式会社 キッツ');
ok($zip->set_number('2618581')->is_valid_number, '千葉市 美浜保健福祉センター');
ok($zip->set_number('2618582')->is_valid_number, '千葉市 西部市税事務所');
ok($zip->set_number('2618585')->is_valid_number, '千葉トヨペット 株式会社');
ok($zip->set_number('2618586')->is_valid_number, '放送大学');
ok($zip->set_number('2618587')->is_valid_number, '株式会社 千葉ロッテマリーンズ');
ok($zip->set_number('2618588')->is_valid_number, '富士通 株式会社');
ok($zip->set_number('2618609')->is_valid_number, '千葉公共職業安定所');
ok($zip->set_number('2618686')->is_valid_number, '放送大学');
ok($zip->set_number('2618733')->is_valid_number, '美浜区役所');
ok($zip->set_number('2628502')->is_valid_number, '千葉西税務署');
ok($zip->set_number('2628506')->is_valid_number, '医療法人社団 有相会 最成病院');
ok($zip->set_number('2628510')->is_valid_number, '千葉市花見川保健福祉センター');
ok($zip->set_number('2628511')->is_valid_number, '医療法人 社団有相会 介護老人保健施設 ゆうあい苑');
ok($zip->set_number('2628512')->is_valid_number, '千葉県 企業局');
ok($zip->set_number('2628514')->is_valid_number, '東京国税局インボイス登録センター');
ok($zip->set_number('2628733')->is_valid_number, '花見川区役所');
ok($zip->set_number('2638505')->is_valid_number, '大和リース 株式会社 千葉支店');
ok($zip->set_number('2638506')->is_valid_number, '二宮産業 株式会社');
ok($zip->set_number('2638512')->is_valid_number, '財団法人 日本分析センター');
ok($zip->set_number('2638522')->is_valid_number, '国立大学法人 千葉大学');
ok($zip->set_number('2638533')->is_valid_number, '(株) スズケン 千葉支店');
ok($zip->set_number('2638550')->is_valid_number, '千葉市稲毛保健福祉センター');
ok($zip->set_number('2638555')->is_valid_number, '国立研究開発法人 量子科学技術研究開発機構 放射線医学総合研究所');
ok($zip->set_number('2638566')->is_valid_number, '千葉県国民健康保険団体連合会');
ok($zip->set_number('2638577')->is_valid_number, '千葉県教育庁 千葉地方出張所');
ok($zip->set_number('2638585')->is_valid_number, '千葉経済大学附属高等学校');
ok($zip->set_number('2638588')->is_valid_number, '敬愛大学');
ok($zip->set_number('2638733')->is_valid_number, '稲毛区役所');
ok($zip->set_number('2648501')->is_valid_number, '陸上自衛隊 下志津駐屯地');
ok($zip->set_number('2648505')->is_valid_number, '千葉県立 千葉大宮高等学校');
ok($zip->set_number('2648510')->is_valid_number, '医療法人社団 創進会 みっつの輪');
ok($zip->set_number('2648530')->is_valid_number, 'みつわ台総合病院');
ok($zip->set_number('2648550')->is_valid_number, '千葉市若葉保健福祉センター');
ok($zip->set_number('2648582')->is_valid_number, '千葉市 東部市税事務所');
ok($zip->set_number('2648585')->is_valid_number, '千葉刑務所');
ok($zip->set_number('2648604')->is_valid_number, '野村証券 千葉支店');
ok($zip->set_number('2648646')->is_valid_number, '三菱UFJ信託銀行 株式会社 千葉支店');
ok($zip->set_number('2648733')->is_valid_number, '若葉区役所');
ok($zip->set_number('2658501')->is_valid_number, '東京情報大学');
ok($zip->set_number('2668550')->is_valid_number, '千葉市 緑保健福祉センター');
ok($zip->set_number('2668733')->is_valid_number, '千葉市緑区役所');
ok($zip->set_number('2700189')->is_valid_number, 'DPL流山\x87T');
ok($zip->set_number('2700192')->is_valid_number, '流山市役所');
ok($zip->set_number('2700194')->is_valid_number, '株式会社 タカラトミーグループ アフターサービスセンター');
ok($zip->set_number('2700195')->is_valid_number, '流山おおたかの森S・C');
ok($zip->set_number('2700196')->is_valid_number, 'アマゾン流山FC');
ok($zip->set_number('2700197')->is_valid_number, 'JP楽天ロジスティクス 株式会社 楽天フルフィルメントセンター流山');
ok($zip->set_number('2700198')->is_valid_number, '江戸川学園(江戸川大学・江戸川短期大学・江戸川大学総合福祉専門学校)');
ok($zip->set_number('2701192')->is_valid_number, '我孫子市役所');
ok($zip->set_number('2701194')->is_valid_number, '財団法人 電力中央研究所');
ok($zip->set_number('2701196')->is_valid_number, '中央学院大学');
ok($zip->set_number('2701198')->is_valid_number, '日本電気 株式会社 我孫子事業場');
ok($zip->set_number('2701380')->is_valid_number, 'アマゾンジャパン TPF7');
ok($zip->set_number('2701381')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('2701382')->is_valid_number, '日本通信紙 株式会社 印西BPOセンター');
ok($zip->set_number('2701383')->is_valid_number, 'フコク生命 千葉ニュータウン本社');
ok($zip->set_number('2701385')->is_valid_number, 'イオンリテール 株式会社 イオン千葉ニュータウン店');
ok($zip->set_number('2701387')->is_valid_number, '印西地区消防組合');
ok($zip->set_number('2701389')->is_valid_number, 'アマゾンジャパン TPF6');
ok($zip->set_number('2701392')->is_valid_number, 'イオンモール 千葉ニュータウン');
ok($zip->set_number('2701393')->is_valid_number, 'みずほ銀行');
ok($zip->set_number('2701395')->is_valid_number, '(株) 竹中工務店 技術研究所');
ok($zip->set_number('2701396')->is_valid_number, '印西市役所');
ok($zip->set_number('2701398')->is_valid_number, 'ソフトバンクテレコム 株式会社');
ok($zip->set_number('2701492')->is_valid_number, '白井市役所');
ok($zip->set_number('2701493')->is_valid_number, '社会保険大学校');
ok($zip->set_number('2701495')->is_valid_number, 'フクダ電子 (株)');
ok($zip->set_number('2701496')->is_valid_number, '信組情報サービス (株)');
ok($zip->set_number('2701592')->is_valid_number, '栄町役場');
ok($zip->set_number('2701693')->is_valid_number, '印西市役所 印旛支所');
ok($zip->set_number('2701694')->is_valid_number, '日本医科大学 千葉北総病院');
ok($zip->set_number('2701695')->is_valid_number, '順天堂大学');
ok($zip->set_number('2702280')->is_valid_number, 'マブチモーター 株式会社');
ok($zip->set_number('2702288')->is_valid_number, '陸上自衛隊 松戸駐屯地');
ok($zip->set_number('2702292')->is_valid_number, 'よしざわ 株式会社');
ok($zip->set_number('2702295')->is_valid_number, '日立粉末冶金 株式会社');
ok($zip->set_number('2702296')->is_valid_number, '松戸市立総合医療センター');
ok($zip->set_number('2702297')->is_valid_number, '株式会社 吉野工業所 松戸工場');
ok($zip->set_number('2702298')->is_valid_number, 'ウェル・エイジングプラザ松戸ニッセイエデンの園');
ok($zip->set_number('2702392')->is_valid_number, '印西市役所 本埜支所');
ok($zip->set_number('2702393')->is_valid_number, 'マブチモーター');
ok($zip->set_number('2708501')->is_valid_number, '株式会社 マツモトキヨシ');
ok($zip->set_number('2708511')->is_valid_number, '株式会社 マツモトキヨシホールディングス');
ok($zip->set_number('2708521')->is_valid_number, '株式会社 マツモトキヨシホールディングス 本社別館');
ok($zip->set_number('2708555')->is_valid_number, '流通経済大学');
ok($zip->set_number('2718501')->is_valid_number, '大和証券 株式会社 松戸支店');
ok($zip->set_number('2718510')->is_valid_number, '千葉大学 園芸学部');
ok($zip->set_number('2718515')->is_valid_number, '日本リーテック 株式会社 鉄道本部 中央支店');
ok($zip->set_number('2718518')->is_valid_number, '千葉地方法務局 松戸支局');
ok($zip->set_number('2718522')->is_valid_number, '千葉地方裁判所 松戸支部');
ok($zip->set_number('2718530')->is_valid_number, 'トラスコ中山 株式会社 プラネット東関東');
ok($zip->set_number('2718533')->is_valid_number, '松戸税務署');
ok($zip->set_number('2718551')->is_valid_number, '聖徳大学 (10号館)');
ok($zip->set_number('2718555')->is_valid_number, '聖徳大学');
ok($zip->set_number('2718557')->is_valid_number, '松戸警察署');
ok($zip->set_number('2718560')->is_valid_number, '千葉県東葛飾県民センター');
ok($zip->set_number('2718562')->is_valid_number, '松戸健康福祉センター');
ok($zip->set_number('2718563')->is_valid_number, '千葉県教育庁 東葛飾教育事務所');
ok($zip->set_number('2718564')->is_valid_number, '千葉県松戸県税事務所');
ok($zip->set_number('2718580')->is_valid_number, '山崎製パン 株式会社松戸工場');
ok($zip->set_number('2718585')->is_valid_number, '専修大学 松戸高等学校');
ok($zip->set_number('2718588')->is_valid_number, '松戸市役所');
ok($zip->set_number('2718620')->is_valid_number, 'とうかつ中央農業協同組合');
ok($zip->set_number('2718625')->is_valid_number, 'SMBC日興証券 株式会社 松戸支店');
ok($zip->set_number('2718666')->is_valid_number, '関東つくば銀行 松戸支店');
ok($zip->set_number('2718672')->is_valid_number, '商工組合中央金庫 松戸支店');
ok($zip->set_number('2720188')->is_valid_number, '日本郵便輸送 株式会社 市川営業所');
ok($zip->set_number('2720193')->is_valid_number, 'アマゾン 市川FC 入庫係');
ok($zip->set_number('2720195')->is_valid_number, 'JP楽天ロジスティクス 株式会社 楽天フルフィルメントセンター市川\x87U');
ok($zip->set_number('2728501')->is_valid_number, '市川市役所');
ok($zip->set_number('2728510')->is_valid_number, '京成電鉄 株式会社');
ok($zip->set_number('2728511')->is_valid_number, '市川簡易裁判所千葉家庭裁判所 市川出張所');
ok($zip->set_number('2728512')->is_valid_number, '学校法人 千葉学園');
ok($zip->set_number('2728513')->is_valid_number, '東京歯科大学市川総合病院');
ok($zip->set_number('2728514')->is_valid_number, '株式会社 京成ストア');
ok($zip->set_number('2728516')->is_valid_number, '国立国際医療研究センター国府台病院');
ok($zip->set_number('2728518')->is_valid_number, '株式会社 市進');
ok($zip->set_number('2728520')->is_valid_number, '千葉県立市川工業高等学校');
ok($zip->set_number('2728522')->is_valid_number, '市川商工会議所');
ok($zip->set_number('2728533')->is_valid_number, '和洋学園');
ok($zip->set_number('2728538')->is_valid_number, '株式会社 スズキ技研');
ok($zip->set_number('2728540')->is_valid_number, '京成バス 株式会社');
ok($zip->set_number('2728543')->is_valid_number, '市川公共職業安定所');
ok($zip->set_number('2728550')->is_valid_number, 'ユトー 株式会社');
ok($zip->set_number('2728555')->is_valid_number, '財団法人 市川市文化振興財団');
ok($zip->set_number('2728558')->is_valid_number, 'TDK 株式会社 テクニカルセンター');
ok($zip->set_number('2728560')->is_valid_number, '筑波大学付属聴覚特別支援学校');
ok($zip->set_number('2728561')->is_valid_number, '本八幡ビル 株式会社');
ok($zip->set_number('2728573')->is_valid_number, '市川税務署');
ok($zip->set_number('2728580')->is_valid_number, '京葉瓦斯 株式会社');
ok($zip->set_number('2728581')->is_valid_number, '山崎製パン 株式会社 総合クリエイションセンター');
ok($zip->set_number('2728585')->is_valid_number, '市川よみうり新聞社');
ok($zip->set_number('2728588')->is_valid_number, '住友金属鉱山 株式会社 技術本部中央研究所');
ok($zip->set_number('2730192')->is_valid_number, '新京成電鉄 株式会社');
ok($zip->set_number('2730193')->is_valid_number, '茂野製麺');
ok($zip->set_number('2730195')->is_valid_number, '鎌ケ谷市役所');
ok($zip->set_number('2730197')->is_valid_number, 'イオン 鎌ヶ谷店');
ok($zip->set_number('2738501')->is_valid_number, '船橋市役所');
ok($zip->set_number('2738502')->is_valid_number, '日鉄鋼板 株式会社 船橋製造所');
ok($zip->set_number('2738503')->is_valid_number, '東京都生コンクリート工業組合');
ok($zip->set_number('2738504')->is_valid_number, '船橋市役所 分庁舎');
ok($zip->set_number('2738505')->is_valid_number, '株式会社 ジェイコム千葉 YY船橋習志野局');
ok($zip->set_number('2738506')->is_valid_number, '船橋市保健福祉センター');
ok($zip->set_number('2738508')->is_valid_number, '株式会社 ぱど 船橋営業所');
ok($zip->set_number('2738510')->is_valid_number, '伊藤ハムフードソリューション');
ok($zip->set_number('2738511')->is_valid_number, '船橋商工会議所');
ok($zip->set_number('2738512')->is_valid_number, '渡辺パイプ 株式会社');
ok($zip->set_number('2738515')->is_valid_number, '株式会社 東京スター銀行 船橋支店');
ok($zip->set_number('2738520')->is_valid_number, '社会保険 船橋保健看護専門学校');
ok($zip->set_number('2738521')->is_valid_number, 'ニツスイ工業 株式会社');
ok($zip->set_number('2738522')->is_valid_number, 'フジフーズ 株式会社');
ok($zip->set_number('2738523')->is_valid_number, 'サンケイリビング新聞社');
ok($zip->set_number('2738530')->is_valid_number, 'ららぽーと TOKYO-BAY');
ok($zip->set_number('2738533')->is_valid_number, '京葉瓦斯 株式会社 船橋支社');
ok($zip->set_number('2738540')->is_valid_number, '財団法人 復光会総武病院');
ok($zip->set_number('2738542')->is_valid_number, '杉山金属印刷 株式会社');
ok($zip->set_number('2738543')->is_valid_number, '岡本 株式会社');
ok($zip->set_number('2738550')->is_valid_number, '西武百貨店 船橋店');
ok($zip->set_number('2738551')->is_valid_number, 'ユアサ・フナショク 株式会社');
ok($zip->set_number('2738555')->is_valid_number, '京葉住設 株式会社');
ok($zip->set_number('2738556')->is_valid_number, '社会保険船橋中央病院');
ok($zip->set_number('2738558')->is_valid_number, '千葉地方法務局 船橋支局');
ok($zip->set_number('2738560')->is_valid_number, '葛南県民センター');
ok($zip->set_number('2738566')->is_valid_number, '社会保険看護研修センター');
ok($zip->set_number('2738567')->is_valid_number, '株式会社 東武百貨店 船橋店');
ok($zip->set_number('2738570')->is_valid_number, '日本中央競馬会 中山競馬場');
ok($zip->set_number('2738574')->is_valid_number, '船橋税務署');
ok($zip->set_number('2738578')->is_valid_number, 'ビックカメラ船橋センター');
ok($zip->set_number('2738584')->is_valid_number, 'ロイヤル 株式会社');
ok($zip->set_number('2738585')->is_valid_number, '南船橋 WDC');
ok($zip->set_number('2738588')->is_valid_number, '船橋市立医療センター');
ok($zip->set_number('2738601')->is_valid_number, '石井食品 株式会社');
ok($zip->set_number('2738610')->is_valid_number, 'ショップチャンネル南船橋物流センター');
ok($zip->set_number('2738627')->is_valid_number, 'ネクスト船橋');
ok($zip->set_number('2738710')->is_valid_number, '東京医療保健大学 千葉看護学部');
ok($zip->set_number('2738733')->is_valid_number, 'ティーエルトレーディング');
ok($zip->set_number('2748501')->is_valid_number, '日本大学 理工学部');
ok($zip->set_number('2748503')->is_valid_number, '医療法人 沖縄徳洲会 千葉徳洲会病院');
ok($zip->set_number('2748504')->is_valid_number, '日大習志野高校');
ok($zip->set_number('2748505')->is_valid_number, '積和不動産 株式会社');
ok($zip->set_number('2748506')->is_valid_number, '船橋二和病院');
ok($zip->set_number('2748507')->is_valid_number, '日産化学工業 株式会社');
ok($zip->set_number('2748510')->is_valid_number, '学校法人 東邦大学');
ok($zip->set_number('2748520')->is_valid_number, '株式会社 タキガワ・コーポレーション・ジャパン');
ok($zip->set_number('2748530')->is_valid_number, '日軽建材工業 株式会社');
ok($zip->set_number('2748533')->is_valid_number, '株式会社 高山 船橋営業所');
ok($zip->set_number('2748555')->is_valid_number, '日本大学 薬学部');
ok($zip->set_number('2748558')->is_valid_number, 'イオン 株式会社 ジャスコ高根木戸店');
ok($zip->set_number('2748577')->is_valid_number, '陸上自衛隊 習志野駐屯地');
ok($zip->set_number('2748585')->is_valid_number, '日東ベスト 株式会社');
ok($zip->set_number('2748601')->is_valid_number, '住友大阪セメント 株式会社');
ok($zip->set_number('2758502')->is_valid_number, 'JP楽天ロジスティクス 株式会社 楽天フルフィルメントセンター習志野');
ok($zip->set_number('2758511')->is_valid_number, '東邦大学付属東邦中学校・高等学校');
ok($zip->set_number('2758520')->is_valid_number, '株式会社 日立産機システム');
ok($zip->set_number('2758525')->is_valid_number, '株式会社 ZOZO');
ok($zip->set_number('2758528')->is_valid_number, '大平洋機工 株式会社');
ok($zip->set_number('2758533')->is_valid_number, '天龍 株式会社');
ok($zip->set_number('2758550')->is_valid_number, '住商グローバル・ロジスティクス 株式会社 茜浜センター');
ok($zip->set_number('2758551')->is_valid_number, '住商グローバル・ロジスティクス 株式会社 東習志野センター');
ok($zip->set_number('2758560')->is_valid_number, 'セイコークロック 株式会社');
ok($zip->set_number('2758565')->is_valid_number, '株式会社 ZOZO');
ok($zip->set_number('2758572')->is_valid_number, 'アシザワ・ファインテック 株式会社');
ok($zip->set_number('2758575')->is_valid_number, '日本大学 生産工学部');
ok($zip->set_number('2758576')->is_valid_number, '日本大学 生産工学部 実籾校舎');
ok($zip->set_number('2758577')->is_valid_number, '鈴木金属工業 株式会社');
ok($zip->set_number('2758580')->is_valid_number, '社会福祉法人 恩賜財団 済生会 千葉県済生会習志野病院');
ok($zip->set_number('2758585')->is_valid_number, '株式会社 ダーバン 物流東京センター');
ok($zip->set_number('2758588')->is_valid_number, '学校法人 千葉工業大学 津田沼校舎');
ok($zip->set_number('2758601')->is_valid_number, '習志野市役所');
ok($zip->set_number('2758611')->is_valid_number, '株式会社 日立産機システム 習志野事業所');
ok($zip->set_number('2758666')->is_valid_number, '習志野市企業局');
ok($zip->set_number('2768501')->is_valid_number, '八千代市役所');
ok($zip->set_number('2768523')->is_valid_number, 'エドワーズ 株式会社');
ok($zip->set_number('2768524')->is_valid_number, '東京女子医科大学附属 八千代医療センター');
ok($zip->set_number('2768525')->is_valid_number, 'アマゾン 八千代FC 入庫係');
ok($zip->set_number('2768526')->is_valid_number, '三井食品 株式会社 イトーヨーカドー 八千代IDC(TC)');
ok($zip->set_number('2768527')->is_valid_number, '丸二倉庫 (株) YBL PLAZA 新館');
ok($zip->set_number('2768580')->is_valid_number, '石井食品 株式会社 八千代工場');
ok($zip->set_number('2778501')->is_valid_number, '株式会社 みずほ銀行 柏支店');
ok($zip->set_number('2778503')->is_valid_number, '柏市沼南庁舎');
ok($zip->set_number('2778504')->is_valid_number, '財務省 税関研修所');
ok($zip->set_number('2778505')->is_valid_number, '柏市役所');
ok($zip->set_number('2778507')->is_valid_number, '住友生命保険 相互会社 柏支社');
ok($zip->set_number('2778511')->is_valid_number, '株式会社 バンダイお客様相談センター');
ok($zip->set_number('2778515')->is_valid_number, '大機エンジニアリング 株式会社');
ok($zip->set_number('2778518')->is_valid_number, 'ららぽーと 柏の葉');
ok($zip->set_number('2778519')->is_valid_number, 'KOIL ららぽーと柏の葉・北館');
ok($zip->set_number('2778520')->is_valid_number, 'KOILパーク');
ok($zip->set_number('2778521')->is_valid_number, '株式会社 そごう 柏店');
ok($zip->set_number('2778522')->is_valid_number, '柏税務署');
ok($zip->set_number('2778531')->is_valid_number, '株式会社 DNPテクノフィルム');
ok($zip->set_number('2778533')->is_valid_number, '株式会社 トクシキ');
ok($zip->set_number('2778539')->is_valid_number, '三協フロンテア 株式会社');
ok($zip->set_number('2778550')->is_valid_number, '柏高島屋ステーションモール');
ok($zip->set_number('2778551')->is_valid_number, '柏厚生総合病院');
ok($zip->set_number('2778554')->is_valid_number, '柏警察署');
ok($zip->set_number('2778556')->is_valid_number, '昭和ゴム 株式会社');
ok($zip->set_number('2778557')->is_valid_number, 'パウダーテック 株式会社');
ok($zip->set_number('2778558')->is_valid_number, '千葉県 柏県税事務所');
ok($zip->set_number('2778561')->is_valid_number, '東京大学大学院 新領域創成科学研究科基盤棟');
ok($zip->set_number('2778562')->is_valid_number, '東京大学大学院 新領域創成科学研究科生命棟');
ok($zip->set_number('2778563')->is_valid_number, '東京大学大学院 新領域創成科学研究科環境棟');
ok($zip->set_number('2778564')->is_valid_number, '東京大学 大気海洋研究所');
ok($zip->set_number('2778565')->is_valid_number, '株式会社 DNPテクノポリマー');
ok($zip->set_number('2778566')->is_valid_number, '読売旅行 柏営業所');
ok($zip->set_number('2778569')->is_valid_number, '東京大学 柏キャンパス 設備センター');
ok($zip->set_number('2778570')->is_valid_number, '千葉県立 東葛飾高等学校');
ok($zip->set_number('2778571')->is_valid_number, 'アマゾンジャパン VJNA');
ok($zip->set_number('2778572')->is_valid_number, 'エディオン柏EC・TC第一');
ok($zip->set_number('2778573')->is_valid_number, 'エディオン柏EC・TC第二');
ok($zip->set_number('2778574')->is_valid_number, '東京大学 生産技術研究所 千葉実験所');
ok($zip->set_number('2778577')->is_valid_number, '国立がんセンター東病院');
ok($zip->set_number('2778579')->is_valid_number, '株式会社 日立物流首都圏MFLP倉庫');
ok($zip->set_number('2778581')->is_valid_number, '東京大学 物性研究所');
ok($zip->set_number('2778582')->is_valid_number, '東京大学 宇宙線研究所');
ok($zip->set_number('2778584')->is_valid_number, '東京大学 柏図書館');
ok($zip->set_number('2778585')->is_valid_number, '二松学舎大学');
ok($zip->set_number('2778586')->is_valid_number, '伊藤ハム 株式会社 東京工場');
ok($zip->set_number('2778587')->is_valid_number, '独立行政法人 日本原子力研究開発機構 システム計算科学センター');
ok($zip->set_number('2778588')->is_valid_number, 'サンケイリビング新聞社 東葛本部');
ok($zip->set_number('2778589')->is_valid_number, '東京大学 柏地区第2総合研究棟');
ok($zip->set_number('2778654')->is_valid_number, '公益財団法人 モラロジー研究所');
ok($zip->set_number('2778655')->is_valid_number, '三井生命保険 株式会社 事務センター');
ok($zip->set_number('2778661')->is_valid_number, '下総航空基地');
ok($zip->set_number('2778666')->is_valid_number, '株式会社 高島屋 柏店');
ok($zip->set_number('2778686')->is_valid_number, '学校法人 廣池学園');
ok($zip->set_number('2788501')->is_valid_number, '小張総合病院');
ok($zip->set_number('2788510')->is_valid_number, '東京理科大学');
ok($zip->set_number('2788521')->is_valid_number, '宗教法人 霊波之光');
ok($zip->set_number('2788533')->is_valid_number, '協栄電気 株式会社 野田受注センター');
ok($zip->set_number('2788550')->is_valid_number, '野田市役所');
ok($zip->set_number('2788555')->is_valid_number, '窪田味噌醤油 株式会社');
ok($zip->set_number('2788570')->is_valid_number, '株式会社 日立物流 東日本営業本部 東関東営業部');
ok($zip->set_number('2788577')->is_valid_number, '株式会社 メイワパックス');
ok($zip->set_number('2788601')->is_valid_number, 'キッコーマン飲料 株式会社');
ok($zip->set_number('2788601')->is_valid_number, 'キッコーマンクリーンサービス 株式会社');
ok($zip->set_number('2788601')->is_valid_number, 'キッコーマン食品 株式会社');
ok($zip->set_number('2788601')->is_valid_number, 'キッコーマンバイオケミファ 株式会社');
ok($zip->set_number('2788601')->is_valid_number, 'キッコーマンビジネスサービス 株式会社');
ok($zip->set_number('2788601')->is_valid_number, 'キッコーマン 株式会社');
ok($zip->set_number('2788686')->is_valid_number, '利根コカ・コーラボトリング 株式会社');
ok($zip->set_number('2798501')->is_valid_number, '浦安市役所');
ok($zip->set_number('2798502')->is_valid_number, 'ファウンテンテラスホテル');
ok($zip->set_number('2798503')->is_valid_number, 'パームテラスホテル');
ok($zip->set_number('2798505')->is_valid_number, '東京ディズニーランドホテル');
ok($zip->set_number('2798506')->is_valid_number, '東京ディズニーリゾート・トイ・ストーリーホテル');
ok($zip->set_number('2798511')->is_valid_number, '株式会社 オリエンタルランド');
ok($zip->set_number('2798516')->is_valid_number, '株式会社 オリエンタルランド・イノベーションズ');
ok($zip->set_number('2798517')->is_valid_number, '株式会社 ミリアルリゾートホテルズ(オリエンタルランド内第3別館1階)');
ok($zip->set_number('2798518')->is_valid_number, 'シルク・ドゥ・ソレイユ シアター東京');
ok($zip->set_number('2798519')->is_valid_number, '東京ディズニーシー・ホテルミラコスタ');
ok($zip->set_number('2798521')->is_valid_number, '株式会社 舞浜コーポレーション');
ok($zip->set_number('2798522')->is_valid_number, 'ディズニーアンバサダーホテル');
ok($zip->set_number('2798524')->is_valid_number, '株式会社 グリーンアンドアーツ');
ok($zip->set_number('2798525')->is_valid_number, '株式会社 フォトワークス');
ok($zip->set_number('2798526')->is_valid_number, '東京ディズニーシー・ファンタジースプリングスホテル');
ok($zip->set_number('2798529')->is_valid_number, '株式会社 イクスピアリ');
ok($zip->set_number('2798530')->is_valid_number, '東京電力 株式会社 市川浦安営業所');
ok($zip->set_number('2798531')->is_valid_number, '株式会社 MBM');
ok($zip->set_number('2798532')->is_valid_number, '株式会社 MBM');
ok($zip->set_number('2798541')->is_valid_number, '株式会社 パルタック 東京支社');
ok($zip->set_number('2798550')->is_valid_number, '明海大学');
ok($zip->set_number('2798553')->is_valid_number, '株式会社 リーガルコーポレーション');
ok($zip->set_number('2798555')->is_valid_number, '東レ 株式会社 第2本社');
ok($zip->set_number('2798558')->is_valid_number, '東海大学付属 浦安高等学校');
ok($zip->set_number('2798567')->is_valid_number, '学校法人 了徳寺大学');
ok($zip->set_number('2798580')->is_valid_number, '株式会社 オリエンタルランド');
ok($zip->set_number('2798581')->is_valid_number, '株式会社 グリーンアンドアーツ');
ok($zip->set_number('2798582')->is_valid_number, '株式会社 フォトワークス');
ok($zip->set_number('2798583')->is_valid_number, '株式会社 デザインファクトリー');
ok($zip->set_number('2798585')->is_valid_number, '株式会社 ホテルオークラ東京ベイ');
ok($zip->set_number('2798588')->is_valid_number, '日本コープ共済生活協同組合連合会');
ok($zip->set_number('2798601')->is_valid_number, 'サラリ工房 株式会社');
ok($zip->set_number('2798686')->is_valid_number, '株式会社 インシップ');
ok($zip->set_number('2828602')->is_valid_number, '東京航空局 成田空港事務所');
ok($zip->set_number('2828610')->is_valid_number, '日本航空インターナショナル 成田空港支店');
ok($zip->set_number('2830195')->is_valid_number, '九十九里町役場');
ok($zip->set_number('2838501')->is_valid_number, '千葉県東金県税事務所');
ok($zip->set_number('2838505')->is_valid_number, '山武郡市広域行政組合');
ok($zip->set_number('2838511')->is_valid_number, '東金市役所');
ok($zip->set_number('2838555')->is_valid_number, '城西国際大学');
ok($zip->set_number('2838588')->is_valid_number, '千葉県立東金病院');
ok($zip->set_number('2838650')->is_valid_number, '医療法人 静和会 浅井病院');
ok($zip->set_number('2838686')->is_valid_number, '地方独立行政法人 東金九十九里地域医療センター 東千葉メディカルセンター');
ok($zip->set_number('2838701')->is_valid_number, '一般社団法人 YASSAWAVE');
ok($zip->set_number('2848555')->is_valid_number, '四街道市役所');
ok($zip->set_number('2858501')->is_valid_number, '佐倉市役所');
ok($zip->set_number('2858502')->is_valid_number, '国立歴史民俗博物館');
ok($zip->set_number('2858503')->is_valid_number, '千葉県印旛地域振興事務所');
ok($zip->set_number('2858505')->is_valid_number, 'DIC川村記念美術館');
ok($zip->set_number('2858509')->is_valid_number, '酒々井プレミアム・アウトレット');
ok($zip->set_number('2858510')->is_valid_number, '酒々井町役場');
ok($zip->set_number('2858511')->is_valid_number, '古河ユニック 株式会社 佐倉工場');
ok($zip->set_number('2858520')->is_valid_number, '千葉県 印旛健康福祉センター');
ok($zip->set_number('2858521')->is_valid_number, '株式会社 QVCジャパン');
ok($zip->set_number('2858522')->is_valid_number, '古河ユニック 株式会社 サービス部');
ok($zip->set_number('2858533')->is_valid_number, '印旛郡市広域市町村圏事務組合');
ok($zip->set_number('2858550')->is_valid_number, '株式会社 フジクラ 佐倉事業所');
ok($zip->set_number('2858567')->is_valid_number, '千葉敬愛短期大学');
ok($zip->set_number('2858580')->is_valid_number, '株式会社 朋栄 佐倉研究開発センター');
ok($zip->set_number('2858585')->is_valid_number, 'TOTOバスクリエイト 株式会社');
ok($zip->set_number('2858586')->is_valid_number, '株式会社 広域高速ネット二九六');
ok($zip->set_number('2858588')->is_valid_number, '株式会社 ホソヤコーポレーション');
ok($zip->set_number('2858619')->is_valid_number, '佐倉市 八街市 酒々井町 消防組合');
ok($zip->set_number('2858655')->is_valid_number, '太平洋セメント 株式会社 中央研究所');
ok($zip->set_number('2858668')->is_valid_number, 'DIC 株式会社 総合研究所');
ok($zip->set_number('2858741')->is_valid_number, '東邦大学医療センター佐倉病院');
ok($zip->set_number('2858765')->is_valid_number, '社会福祉法人 聖隷福祉事業団 聖隷佐倉市民病院');
ok($zip->set_number('2860292')->is_valid_number, '富里市役所');
ok($zip->set_number('2868501')->is_valid_number, '成田税務署');
ok($zip->set_number('2868520')->is_valid_number, '国際医療福祉大学成田病院');
ok($zip->set_number('2868521')->is_valid_number, '株式会社 ボンベルタ');
ok($zip->set_number('2868523')->is_valid_number, '成田赤十字病院');
ok($zip->set_number('2868585')->is_valid_number, '成田市役所');
ok($zip->set_number('2868588')->is_valid_number, 'TDK 株式会社 成田工場');
ok($zip->set_number('2868686')->is_valid_number, '国際医療福祉大学');
ok($zip->set_number('2870292')->is_valid_number, '成田市役所 大栄支所');
ok($zip->set_number('2878501')->is_valid_number, '香取市役所');
ok($zip->set_number('2878502')->is_valid_number, '千葉県 香取地域振興事務所');
ok($zip->set_number('2878503')->is_valid_number, '千葉県 香取県税事務所');
ok($zip->set_number('2878510')->is_valid_number, '国土交通省 利根川下流河川事務所');
ok($zip->set_number('2878555')->is_valid_number, '佐原税務署');
ok($zip->set_number('2878585')->is_valid_number, '千葉社会保険事務局 佐原事務所');
ok($zip->set_number('2878601')->is_valid_number, '佐原信用金庫');
ok($zip->set_number('2888601')->is_valid_number, '銚子市役所');
ok($zip->set_number('2890192')->is_valid_number, '成田市 下総支所');
ok($zip->set_number('2890292')->is_valid_number, '神崎町役場');
ok($zip->set_number('2890392')->is_valid_number, 'アタリヤ農園');
ok($zip->set_number('2890393')->is_valid_number, '香取市役所 小見川支所');
ok($zip->set_number('2890492')->is_valid_number, '香取市役所 山田支所');
ok($zip->set_number('2890592')->is_valid_number, '旭市 干潟支所');
ok($zip->set_number('2890692')->is_valid_number, '東庄町役場');
ok($zip->set_number('2891192')->is_valid_number, '八街市役所');
ok($zip->set_number('2891297')->is_valid_number, '株式会社 アルバック');
ok($zip->set_number('2891298')->is_valid_number, '山武市 さんぶの森交流センター あららぎ館');
ok($zip->set_number('2891392')->is_valid_number, '山武市役所');
ok($zip->set_number('2891592')->is_valid_number, 'PDRファーマ 株式会社 千葉工場');
ok($zip->set_number('2891593')->is_valid_number, '山武市 松尾IT保健福祉センター');
ok($zip->set_number('2891594')->is_valid_number, '千葉県立 松尾高等学校');
ok($zip->set_number('2891692')->is_valid_number, '芝山町役場');
ok($zip->set_number('2891693')->is_valid_number, '日本オーチス・エレベータ 株式会社');
ok($zip->set_number('2891793')->is_valid_number, '横芝光町役場');
ok($zip->set_number('2891892')->is_valid_number, '山武市 蓮沼出張所');
ok($zip->set_number('2892192')->is_valid_number, '匝瑳市役所 野栄総合支所');
ok($zip->set_number('2892197')->is_valid_number, 'タイヘイ 株式会社');
ok($zip->set_number('2892198')->is_valid_number, '匝瑳市役所');
ok($zip->set_number('2892292')->is_valid_number, '多古町役場');
ok($zip->set_number('2892595')->is_valid_number, '旭市役所');
ok($zip->set_number('2900192')->is_valid_number, '帝京平成短期大学');
ok($zip->set_number('2900193')->is_valid_number, '帝京平成大学');
ok($zip->set_number('2900194')->is_valid_number, 'unimoちはら台');
ok($zip->set_number('2908501')->is_valid_number, '市原市役所');
ok($zip->set_number('2908503')->is_valid_number, '丸善石油化学 株式会社 千葉工場');
ok($zip->set_number('2908510')->is_valid_number, '旭硝子エンジニアリング 株式会社');
ok($zip->set_number('2908511')->is_valid_number, '富士電機システムズ 株式会社 千葉工場');
ok($zip->set_number('2908530')->is_valid_number, '日本曹達 株式会社 千葉工場');
ok($zip->set_number('2908531')->is_valid_number, '三井造船 株式会社 千葉事業所');
ok($zip->set_number('2908540')->is_valid_number, 'ウエルシア薬局 株式会社 ネット事業部');
ok($zip->set_number('2908550')->is_valid_number, 'UBEエラストマー 株式会社 千葉工場');
ok($zip->set_number('2908551')->is_valid_number, 'JNC石油化学 株式会社 市原製造所');
ok($zip->set_number('2908555')->is_valid_number, '古河電気工業 株式会社 千葉事業所');
ok($zip->set_number('2908558')->is_valid_number, 'コスモ石油 株式会社 千葉製油所');
ok($zip->set_number('2908560')->is_valid_number, 'KHネオケム 株式会社 千葉工場');
ok($zip->set_number('2908566')->is_valid_number, '旭硝子 株式会社 千葉工場');
ok($zip->set_number('2908567')->is_valid_number, '株式会社 レゾナック 五井事業所');
ok($zip->set_number('2908577')->is_valid_number, '株式会社 ヒノックス');
ok($zip->set_number('2908580')->is_valid_number, '宮地エンジニアリング 株式会社');
ok($zip->set_number('2908585')->is_valid_number, 'DIC 株式会社 千葉工場');
ok($zip->set_number('2908588')->is_valid_number, '電気化学工業 株式会社 千葉工場');
ok($zip->set_number('2908610')->is_valid_number, '不二サッシ 株式会社 千葉工場');
ok($zip->set_number('2928501')->is_valid_number, '木更津市役所');
ok($zip->set_number('2928510')->is_valid_number, '陸上自衛隊 木更津駐屯地');
ok($zip->set_number('2928511')->is_valid_number, '学校法人 君津学園');
ok($zip->set_number('2928520')->is_valid_number, '千葉県南房総県民センター');
ok($zip->set_number('2928522')->is_valid_number, '東京電力 (株) 木更津支社');
ok($zip->set_number('2928525')->is_valid_number, '千葉県木更津県税事務所');
ok($zip->set_number('2928530')->is_valid_number, '日本年金機構 木更津年金事務所');
ok($zip->set_number('2928533')->is_valid_number, 'ソニーイーエムシーエス (株) 木更津テック');
ok($zip->set_number('2928535')->is_valid_number, '君津中央病院');
ok($zip->set_number('2928539')->is_valid_number, '山九 株式会社 君津支店');
ok($zip->set_number('2928550')->is_valid_number, '木更津税務署');
ok($zip->set_number('2928555')->is_valid_number, '学校法人 君津学園 清和大学');
ok($zip->set_number('2928565')->is_valid_number, '学校法人 暁星国際学園');
ok($zip->set_number('2928568')->is_valid_number, '学校法人 紅陵学院、志学館中・高等学校、拓殖大学紅陵高等学校');
ok($zip->set_number('2928611')->is_valid_number, '千葉信用金庫');
ok($zip->set_number('2928686')->is_valid_number, '海上自衛隊 航空補給処');
ok($zip->set_number('2938506')->is_valid_number, '富津市役所');
ok($zip->set_number('2938511')->is_valid_number, '日本製鉄 株式会社 技術開発本部');
ok($zip->set_number('2948501')->is_valid_number, '海上自衛隊 館山航空基地');
ok($zip->set_number('2948502')->is_valid_number, '富士工業 株式会社');
ok($zip->set_number('2948503')->is_valid_number, '館山税務署');
ok($zip->set_number('2948601')->is_valid_number, '館山市役所');
ok($zip->set_number('2948701')->is_valid_number, '南房総市役所 三芳地域センター');
ok($zip->set_number('2948701')->is_valid_number, '南房総市役所 三芳分庁舎');
ok($zip->set_number('2950192')->is_valid_number, '南房総市役所 白浜地域センター');
ok($zip->set_number('2958601')->is_valid_number, '南房総市役所 朝夷行政センター');
ok($zip->set_number('2958601')->is_valid_number, '南房総市役所 水道部');
ok($zip->set_number('2960197')->is_valid_number, 'ヤスダファインテ 株式会社');
ok($zip->set_number('2968601')->is_valid_number, '鴨川市役所');
ok($zip->set_number('2968602')->is_valid_number, '医療法人 鉄蕉会 亀田総合病院');
ok($zip->set_number('2970192')->is_valid_number, '長南町役場');
ok($zip->set_number('2970193')->is_valid_number, '長南カントリークラブ');
ok($zip->set_number('2970194')->is_valid_number, 'ゴールデンクロスカントリークラブ');
ok($zip->set_number('2970195')->is_valid_number, 'トーヨーカントリークラブ');
ok($zip->set_number('2970196')->is_valid_number, '南茂原カントリークラブ');
ok($zip->set_number('2970197')->is_valid_number, 'アバイディングクラブ');
ok($zip->set_number('2970198')->is_valid_number, 'グレートアイランド倶楽部');
ok($zip->set_number('2970292')->is_valid_number, '大崎電気システムズ 株式会社 千葉工場');
ok($zip->set_number('2970298')->is_valid_number, '長柄町役場');
ok($zip->set_number('2978501')->is_valid_number, '茂原税務署');
ok($zip->set_number('2978511')->is_valid_number, '茂原市役所');
ok($zip->set_number('2978533')->is_valid_number, '千葉県東上総県民センター');
ok($zip->set_number('2978550')->is_valid_number, '関東天然瓦斯開発 株式会社');
ok($zip->set_number('2978555')->is_valid_number, '東芝コンポーネンツ 株式会社');
ok($zip->set_number('2978558')->is_valid_number, '日本電信電話 株式会社 茂原支店');
ok($zip->set_number('2978567')->is_valid_number, '大多喜ガス 株式会社');
ok($zip->set_number('2978588')->is_valid_number, '双葉電子工業 株式会社');
ok($zip->set_number('2978611')->is_valid_number, '房総信用組合');
ok($zip->set_number('2978622')->is_valid_number, '株式会社 ジャパンディスプレイ');
ok($zip->set_number('2978666')->is_valid_number, '三井化学 株式会社 茂原分工場');
ok($zip->set_number('2980292')->is_valid_number, '大多喜町役場');
ok($zip->set_number('2980295')->is_valid_number, '平林物産 株式会社');
ok($zip->set_number('2980296')->is_valid_number, 'サンファーム 株式会社');
ok($zip->set_number('2980297')->is_valid_number, '三育学院大学');
ok($zip->set_number('2988501')->is_valid_number, 'いすみ市役所');
ok($zip->set_number('2990192')->is_valid_number, '出光興産 株式会社 千葉事業所');
ok($zip->set_number('2990194')->is_valid_number, '出光エンジニアリング 株式会社 千葉事業所');
ok($zip->set_number('2990195')->is_valid_number, '住友化学工業 株式会社 千葉工場');
ok($zip->set_number('2990196')->is_valid_number, '東レ 株式会社 千葉工場');
ok($zip->set_number('2990197')->is_valid_number, '日本板硝子 株式会社 千葉工場');
ok($zip->set_number('2990198')->is_valid_number, '出光千葉建設保全協力会センター');
ok($zip->set_number('2990292')->is_valid_number, '袖ケ浦市役所');
ok($zip->set_number('2990293')->is_valid_number, '出光興産 株式会社 先進技術研究所');
ok($zip->set_number('2990295')->is_valid_number, '住友化学 株式会社 千葉工場');
ok($zip->set_number('2990296')->is_valid_number, '株式会社 荏原製作所 袖ヶ浦事業所');
ok($zip->set_number('2990297')->is_valid_number, '旭化成ケミカルズ 株式会社 川崎製造所 千葉工場');
ok($zip->set_number('2990298')->is_valid_number, '社会福祉法人 千葉県社会福祉事業団');
ok($zip->set_number('2991192')->is_valid_number, '君津市役所');
ok($zip->set_number('2991194')->is_valid_number, '株式会社 日鉄エレックス 君津支店');
ok($zip->set_number('2991195')->is_valid_number, '三島光産 株式会社 鉄鋼事業本部');
ok($zip->set_number('2992192')->is_valid_number, '鋸南町役場');
ok($zip->set_number('2992292')->is_valid_number, '南房総市役所 富山地域センター');
ok($zip->set_number('2992492')->is_valid_number, '南房総市役所');
ok($zip->set_number('2992592')->is_valid_number, '南房総市役所 丸山地域センター');
ok($zip->set_number('2992592')->is_valid_number, '南房総市役所 丸山分庁舎');
ok($zip->set_number('2992792')->is_valid_number, '南房総市役所 和田地域センター');
ok($zip->set_number('2992795')->is_valid_number, '千葉県立 安房拓心高等学校');
ok($zip->set_number('2994192')->is_valid_number, '公立長生病院');
ok($zip->set_number('2994292')->is_valid_number, '白子町役場');
ok($zip->set_number('2994392')->is_valid_number, 'ホテル一宮シーサイドオーツカ');
ok($zip->set_number('2994394')->is_valid_number, '長生村役場');
ok($zip->set_number('2994395')->is_valid_number, '双葉電子工業 株式会社');
ok($zip->set_number('2994396')->is_valid_number, '一宮町役場');
ok($zip->set_number('2994397')->is_valid_number, '千葉地方・家庭裁判所一宮支部 千葉一宮簡易裁判所');
ok($zip->set_number('2994492')->is_valid_number, '睦沢町役場');
ok($zip->set_number('2994493')->is_valid_number, '房総カントリークラブ');
ok($zip->set_number('2994692')->is_valid_number, 'いすみ市役所 岬庁舎');
ok($zip->set_number('2995192')->is_valid_number, '御宿町役場');
ok($zip->set_number('2995292')->is_valid_number, '勝浦市役所');
ok($zip->set_number('2995295')->is_valid_number, '国際武道大学');
ok($zip->set_number('3000192')->is_valid_number, 'かすみがうら市総務部霞ケ浦庁舎');
ok($zip->set_number('3000193')->is_valid_number, '株式会社 三喜つくば流通センター');
ok($zip->set_number('3000195')->is_valid_number, '東京製綱 株式会社 土浦工場');
ok($zip->set_number('3000388')->is_valid_number, 'あみプレミアム・アウトレット');
ok($zip->set_number('3000392')->is_valid_number, '阿見町役場');
ok($zip->set_number('3000393')->is_valid_number, '茨城大学 農学部');
ok($zip->set_number('3000394')->is_valid_number, '茨城県立医療大学');
ok($zip->set_number('3000395')->is_valid_number, '東京医科大学 茨城医療センター');
ok($zip->set_number('3000396')->is_valid_number, '富士電機 株式会社 筑波製作所');
ok($zip->set_number('3000397')->is_valid_number, '三菱化学 (株) 科学技術戦略室 筑波センター');
ok($zip->set_number('3000398')->is_valid_number, 'MCフードスペシャリティーズ 株式会社 土浦工場');
ok($zip->set_number('3000492')->is_valid_number, '美浦村役場');
ok($zip->set_number('3000496')->is_valid_number, '日本テキサスインスツルメンツ 株式会社');
ok($zip->set_number('3000593')->is_valid_number, '茨城県土浦県税事務所 稲敷支所');
ok($zip->set_number('3000595')->is_valid_number, '稲敷市役所');
ok($zip->set_number('3000692')->is_valid_number, '稲敷市役所桜川庁舎');
ok($zip->set_number('3000792')->is_valid_number, '稲敷市役所 東庁舎');
ok($zip->set_number('3001192')->is_valid_number, '株式会社 ツムラ 茨城工場');
ok($zip->set_number('3001193')->is_valid_number, '株式会社 長崎屋 荒川沖店');
ok($zip->set_number('3001195')->is_valid_number, 'キヤノン 株式会社 阿見事業所');
ok($zip->set_number('3001292')->is_valid_number, '牛久市役所');
ok($zip->set_number('3001294')->is_valid_number, 'キヤノン化成 株式会社 本社筑波事業所');
ok($zip->set_number('3001295')->is_valid_number, '三菱化学 株式会社 筑波事業所');
ok($zip->set_number('3001296')->is_valid_number, '牛久愛和総合病院');
ok($zip->set_number('3001392')->is_valid_number, '河内町役場');
ok($zip->set_number('3001492')->is_valid_number, '稲敷市役所 新利根庁舎');
ok($zip->set_number('3001592')->is_valid_number, '取手市役所 藤代庁舎');
ok($zip->set_number('3001696')->is_valid_number, '利根町役場');
ok($zip->set_number('3002395')->is_valid_number, 'つくばみらい市役所 伊奈庁舎');
ok($zip->set_number('3002492')->is_valid_number, 'つくばみらい市役所 谷和原庁舎');
ok($zip->set_number('3002493')->is_valid_number, 'SMC 株式会社 筑波技術センター');
ok($zip->set_number('3002494')->is_valid_number, 'トーソー 株式会社');
ok($zip->set_number('3002495')->is_valid_number, 'ピジョン 株式会社 中央研究所');
ok($zip->set_number('3002497')->is_valid_number, '不二製油 株式会社 つくば開発研究センター');
ok($zip->set_number('3002498')->is_valid_number, '丸井加工 株式会社');
ok($zip->set_number('3002593')->is_valid_number, 'SMC 株式会社 筑波工場');
ok($zip->set_number('3002686')->is_valid_number, '長瀬ランダウア 株式会社');
ok($zip->set_number('3002692')->is_valid_number, '株式会社 ZOZO');
ok($zip->set_number('3002695')->is_valid_number, 'インテルジャパン 株式会社');
ok($zip->set_number('3002698')->is_valid_number, 'アステラス製薬 株式会社 東光台研究センター');
ok($zip->set_number('3002792')->is_valid_number, '常総市 石下総合福祉センター');
ok($zip->set_number('3002793')->is_valid_number, '常総市役所 石下庁舎');
ok($zip->set_number('3002795')->is_valid_number, '三菱マテリアル 株式会社 筑波製作所');
ok($zip->set_number('3002797')->is_valid_number, '常総市 石下総合運動公園 スポーツ振興課');
ok($zip->set_number('3003294')->is_valid_number, '住友化学 株式会社 筑波研究所');
ok($zip->set_number('3003295')->is_valid_number, '医療法人 健佑会');
ok($zip->set_number('3003592')->is_valid_number, '八千代町役場');
ok($zip->set_number('3003595')->is_valid_number, '理化工業 株式会社');
ok($zip->set_number('3003598')->is_valid_number, 'ヤマダイ 株式会社');
ok($zip->set_number('3004193')->is_valid_number, 'エポック社');
ok($zip->set_number('3004293')->is_valid_number, '武田薬品工業 株式会社');
ok($zip->set_number('3004295')->is_valid_number, 'マルハニチロ 株式会社 中央研究所');
ok($zip->set_number('3004495')->is_valid_number, '桜川市役所 真壁庁舎');
ok($zip->set_number('3004598')->is_valid_number, '筑西市役所明野支所');
ok($zip->set_number('3008550')->is_valid_number, 'オリエンタルモーター 株式会社 土浦事業所');
ok($zip->set_number('3008567')->is_valid_number, '土浦簡易裁判所');
ok($zip->set_number('3008567')->is_valid_number, '土浦検察審査会');
ok($zip->set_number('3008567')->is_valid_number, '水戸家庭裁判所 土浦支部');
ok($zip->set_number('3008567')->is_valid_number, '水戸地方裁判所 土浦支部');
ok($zip->set_number('3008588')->is_valid_number, 'ボッシュ・レックスロス 株式会社');
ok($zip->set_number('3008601')->is_valid_number, '土浦税務署');
ok($zip->set_number('3008619')->is_valid_number, '陸上自衛隊 霞ヶ浦駐屯地');
ok($zip->set_number('3008686')->is_valid_number, '土浦市役所');
ok($zip->set_number('3018501')->is_valid_number, 'TCM 株式会社 竜ヶ崎工場');
ok($zip->set_number('3018505')->is_valid_number, 'イセデリカ (株)');
ok($zip->set_number('3018555')->is_valid_number, '流通経済大学');
ok($zip->set_number('3018601')->is_valid_number, '竜ヶ崎税務署');
ok($zip->set_number('3018602')->is_valid_number, '株式会社 龍ケ崎カントリー倶楽部');
ok($zip->set_number('3018610')->is_valid_number, '日立ライティング 株式会社 竜ケ崎事業所');
ok($zip->set_number('3018611')->is_valid_number, '龍ケ崎市役所');
ok($zip->set_number('3020198')->is_valid_number, '守谷市役所');
ok($zip->set_number('3028501')->is_valid_number, 'キヤノン 株式会社 取手事業所');
ok($zip->set_number('3028502')->is_valid_number, 'キリンビール 株式会社 取手工場');
ok($zip->set_number('3028585')->is_valid_number, '取手市役所');
ok($zip->set_number('3028586')->is_valid_number, '伊藤ハム 株式会社 取手工場');
ok($zip->set_number('3038501')->is_valid_number, '常総市役所');
ok($zip->set_number('3038503')->is_valid_number, 'キヤノンファインテックニスカ 株式会社');
ok($zip->set_number('3048501')->is_valid_number, '下妻市役所');
ok($zip->set_number('3048601')->is_valid_number, '株式会社 筑波銀行 下妻営業部');
ok($zip->set_number('3058501')->is_valid_number, '日本電気 株式会社 筑波研究所');
ok($zip->set_number('3058502')->is_valid_number, '茗溪学園中学校高等学校');
ok($zip->set_number('3058503')->is_valid_number, '株式会社 ライトオン');
ok($zip->set_number('3058504')->is_valid_number, 'クリタ分析センター 株式会社');
ok($zip->set_number('3058505')->is_valid_number, '独立行政法人 宇宙航空研究開発機構 筑波宇宙センター');
ok($zip->set_number('3058506')->is_valid_number, '独立行政法人 国立環境研究所');
ok($zip->set_number('3058510')->is_valid_number, '株式会社 カスミ');
ok($zip->set_number('3058515')->is_valid_number, '関彰商事 株式会社');
ok($zip->set_number('3058516')->is_valid_number, '独立行政法人 土木研究所');
ok($zip->set_number('3058517')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構');
ok($zip->set_number('3058518')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 作物研究部門');
ok($zip->set_number('3058519')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 野菜花き研究部門');
ok($zip->set_number('3058520')->is_valid_number, '国立大学法人 筑波技術大学 天久保キャンパス');
ok($zip->set_number('3058521')->is_valid_number, '国立大学法人 筑波技術大学 春日キャンパス');
ok($zip->set_number('3058550')->is_valid_number, '筑波大学 図書館情報メディア');
ok($zip->set_number('3058555')->is_valid_number, 'つくば市役所');
ok($zip->set_number('3058560')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば中央第1事業所 (つくば本部・情報技術共同研究棟)');
ok($zip->set_number('3058561')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば中央第1事業所');
ok($zip->set_number('3058563')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば中央第3事業所');
ok($zip->set_number('3058564')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば東事業所');
ok($zip->set_number('3058565')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば中央第5事業所');
ok($zip->set_number('3058566')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば中央第6事業所');
ok($zip->set_number('3058567')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば中央第7事業所');
ok($zip->set_number('3058568')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば中央第2事業所');
ok($zip->set_number('3058569')->is_valid_number, '国立研究開発法人 産業技術総合研究所 つくば西事業所');
ok($zip->set_number('3058571')->is_valid_number, '筑波大学 第一学群 人文社会');
ok($zip->set_number('3058572')->is_valid_number, '筑波大学 第二学群 人間');
ok($zip->set_number('3058573')->is_valid_number, '筑波大学 第三学群 システム情報');
ok($zip->set_number('3058574')->is_valid_number, '筑波大学 体育・芸術専門学群');
ok($zip->set_number('3058575')->is_valid_number, '筑波大学 医学専門学群');
ok($zip->set_number('3058576')->is_valid_number, '筑波大学付属病院');
ok($zip->set_number('3058577')->is_valid_number, '筑波大学(事務局・中央図書館)');
ok($zip->set_number('3058585')->is_valid_number, 'アステラス製薬 株式会社 御幸が丘研究センター');
ok($zip->set_number('3058601')->is_valid_number, '農林水産技術会議事務局 筑波産学連携支援センター');
ok($zip->set_number('3058602')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 基盤技術研究本部遺伝資源研究センター');
ok($zip->set_number('3058604')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 農業環境変動研究センター');
ok($zip->set_number('3058605')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 果樹茶業研究部門');
ok($zip->set_number('3058609')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 農村工学研究部門');
ok($zip->set_number('3058634')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 生物機能利用研究部門');
ok($zip->set_number('3058642')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 食品研究部門');
ok($zip->set_number('3058666')->is_valid_number, '国立研究開発法人 農業・食品産業技術総合研究機構 中央農業研究センター');
ok($zip->set_number('3058686')->is_valid_number, '国際農林水産業研究センター');
ok($zip->set_number('3058687')->is_valid_number, '独立行政法人 森林総合研究所');
ok($zip->set_number('3058701')->is_valid_number, '株式会社 ZOZO');
ok($zip->set_number('3058702')->is_valid_number, '株式会社 ZOZO');
ok($zip->set_number('3060292')->is_valid_number, 'アマゾンジャパン TPZ1');
ok($zip->set_number('3060392')->is_valid_number, '五霞町役場');
ok($zip->set_number('3060492')->is_valid_number, '株式会社 アサヒペン 関東流通センター');
ok($zip->set_number('3060493')->is_valid_number, '旭化成建材 株式会社 境工場');
ok($zip->set_number('3060495')->is_valid_number, '境町役場');
ok($zip->set_number('3060595')->is_valid_number, '坂東市役所 猿島庁舎');
ok($zip->set_number('3060692')->is_valid_number, '坂東市役所 岩井庁舎');
ok($zip->set_number('3068601')->is_valid_number, '古河市役所');
ok($zip->set_number('3068686')->is_valid_number, '古河税務署');
ok($zip->set_number('3078501')->is_valid_number, '結城市役所');
ok($zip->set_number('3078601')->is_valid_number, '結城信用金庫');
ok($zip->set_number('3080193')->is_valid_number, 'フレクストロニクス・インターナショナル 株式会社');
ok($zip->set_number('3080194')->is_valid_number, '筑西市役所関城支所');
ok($zip->set_number('3088510')->is_valid_number, '茨城県県西県民センター');
ok($zip->set_number('3088511')->is_valid_number, '茨城県 筑西県税事務所');
ok($zip->set_number('3088512')->is_valid_number, '関彰商事 株式会社');
ok($zip->set_number('3088513')->is_valid_number, '日本ハム 株式会社 茨城工場');
ok($zip->set_number('3088521')->is_valid_number, '日立化成 株式会社 下館事業所');
ok($zip->set_number('3088522')->is_valid_number, 'NC東日本コンクリート工業 株式会社');
ok($zip->set_number('3088523')->is_valid_number, '株式会社 ハウステック 結城事業所');
ok($zip->set_number('3088524')->is_valid_number, '日立化成 株式会社 下館事業所(五所宮)');
ok($zip->set_number('3088540')->is_valid_number, '東京電力 株式会社 下館支社');
ok($zip->set_number('3088550')->is_valid_number, '株式会社 ディスタ');
ok($zip->set_number('3088608')->is_valid_number, '下館税務署');
ok($zip->set_number('3088616')->is_valid_number, '筑西市役所');
ok($zip->set_number('3088638')->is_valid_number, '株式会社 MCC');
ok($zip->set_number('3091192')->is_valid_number, '筑西市役所 協和支所');
ok($zip->set_number('3091195')->is_valid_number, '協和中央病院');
ok($zip->set_number('3091292')->is_valid_number, '桜川市役所 岩瀬庁舎');
ok($zip->set_number('3091293')->is_valid_number, '桜川市役所');
ok($zip->set_number('3091294')->is_valid_number, '茨城県立 岩瀬高等学校');
ok($zip->set_number('3091295')->is_valid_number, '県西総合病院');
ok($zip->set_number('3091296')->is_valid_number, '岩崎電気 株式会社');
ok($zip->set_number('3091297')->is_valid_number, '株式会社 スミハツ');
ok($zip->set_number('3091698')->is_valid_number, '笠間市役所 笠間支所');
ok($zip->set_number('3091792')->is_valid_number, '笠間市役所');
ok($zip->set_number('3091793')->is_valid_number, '茨城県立 中央病院');
ok($zip->set_number('3091797')->is_valid_number, '株式会社 MonotaRO 笠間ディストリビューションセンター');
ok($zip->set_number('3108282')->is_valid_number, '株式会社 関西ケーズデンキ');
ok($zip->set_number('3108282')->is_valid_number, '株式会社 九州ケーズデンキ');
ok($zip->set_number('3108282')->is_valid_number, '株式会社 ケーズキャリアスタッフ');
ok($zip->set_number('3108282')->is_valid_number, '株式会社 ケーズホールディングス');
ok($zip->set_number('3108282')->is_valid_number, '株式会社 テクニカルアーツ');
ok($zip->set_number('3108282')->is_valid_number, 'ケーズグループユニオン連合会');
ok($zip->set_number('3108282')->is_valid_number, 'ケーズホールディングスユニオン');
ok($zip->set_number('3108282')->is_valid_number, 'テクニカルアーツユニオン');
ok($zip->set_number('3108501')->is_valid_number, '財団法人 茨城県総合健診協会');
ok($zip->set_number('3108502')->is_valid_number, '全国健康保険協会 茨城支部');
ok($zip->set_number('3108505')->is_valid_number, '株式会社 茨城放送');
ok($zip->set_number('3108508')->is_valid_number, '茨城県社会保険診療報酬支払基金');
ok($zip->set_number('3108509')->is_valid_number, '水戸公共職業安定所');
ok($zip->set_number('3108511')->is_valid_number, '茨城労働局');
ok($zip->set_number('3108512')->is_valid_number, '茨城大学');
ok($zip->set_number('3108520')->is_valid_number, '三菱ふそうトラック・バス 株式会社 茨城ふそう 水戸支店');
ok($zip->set_number('3108525')->is_valid_number, '昭和建設 株式会社');
ok($zip->set_number('3108536')->is_valid_number, '株式会社 NTTドコモ 茨城支店');
ok($zip->set_number('3108540')->is_valid_number, '水戸地方検察庁');
ok($zip->set_number('3108550')->is_valid_number, '茨城県警察本部');
ok($zip->set_number('3108551')->is_valid_number, '水戸警察署');
ok($zip->set_number('3108555')->is_valid_number, '茨城県庁');
ok($zip->set_number('3108558')->is_valid_number, '東日本電信電話 株式会社 茨城支店');
ok($zip->set_number('3108567')->is_valid_number, '日本放送協会 水戸放送局');
ok($zip->set_number('3108570')->is_valid_number, '日本年金機構 茨城事務センター');
ok($zip->set_number('3108581')->is_valid_number, '一般財団法人 茨城県メディカルセンター');
ok($zip->set_number('3108585')->is_valid_number, '常磐大学');
ok($zip->set_number('3108586')->is_valid_number, '社会福祉法人 茨城県社会福祉協議会');
ok($zip->set_number('3108588')->is_valid_number, '茨城県教育庁');
ok($zip->set_number('3108601')->is_valid_number, '大和證券 株式会社 水戸支店');
ok($zip->set_number('3108602')->is_valid_number, '日本生命保険 相互会社 水戸支社');
ok($zip->set_number('3108604')->is_valid_number, '株式会社 常陽銀行 本店');
ok($zip->set_number('3108610')->is_valid_number, '水戸市役所');
ok($zip->set_number('3108616')->is_valid_number, '茨城県信用農業 協同組合連合会');
ok($zip->set_number('3108622')->is_valid_number, '茨城県信用組合');
ok($zip->set_number('3108639')->is_valid_number, '日本銀行 水戸事務所');
ok($zip->set_number('3108641')->is_valid_number, '(株) 奈良屋');
ok($zip->set_number('3108666')->is_valid_number, '水戸 税務署');
ok($zip->set_number('3108668')->is_valid_number, '全国共済農業協同組合連合会 茨城県本部');
ok($zip->set_number('3108671')->is_valid_number, '読売新聞 水戸支局');
ok($zip->set_number('3108677')->is_valid_number, '商工組合 中央金庫 水戸支店');
ok($zip->set_number('3108686')->is_valid_number, '株式会社 茨城新聞社');
ok($zip->set_number('3110192')->is_valid_number, '那珂市役所');
ok($zip->set_number('3110193')->is_valid_number, '国立研究開発法人 量子科学技術研究開発機構 那珂核融合研究所');
ok($zip->set_number('3111392')->is_valid_number, '大洗町役場');
ok($zip->set_number('3111393')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構 大洗研究開発センター');
ok($zip->set_number('3111492')->is_valid_number, '鉾田市役所 旭総合支所');
ok($zip->set_number('3111493')->is_valid_number, '千代田メインテナンス 株式会社');
ok($zip->set_number('3111592')->is_valid_number, '茨城県 鉾田市役所');
ok($zip->set_number('3111593')->is_valid_number, '茨城県 鹿行総合事務所');
ok($zip->set_number('3111792')->is_valid_number, '行方市役所 北浦庁舎');
ok($zip->set_number('3112492')->is_valid_number, '潮来税務署');
ok($zip->set_number('3112493')->is_valid_number, '潮来市役所');
ok($zip->set_number('3112495')->is_valid_number, '潮来市役所 牛堀支所');
ok($zip->set_number('3113192')->is_valid_number, '茨城町役場');
ok($zip->set_number('3113193')->is_valid_number, '独立行政法人 国立病院機構 水戸医療センター');
ok($zip->set_number('3113194')->is_valid_number, '三菱ふそうトラック・バス (株) 茨城ふそう');
ok($zip->set_number('3113195')->is_valid_number, '茨城県工業技術センター');
ok($zip->set_number('3113197')->is_valid_number, '茨城県警察本部 交通部運転免許センター');
ok($zip->set_number('3113492')->is_valid_number, '小美玉市役所 小川総合支所');
ok($zip->set_number('3113493')->is_valid_number, 'クレハプラスチックス 株式会社');
ok($zip->set_number('3113494')->is_valid_number, '航空自衛隊 百里基地');
ok($zip->set_number('3113497')->is_valid_number, 'ぺんてる 株式会社 茨城工場');
ok($zip->set_number('3113498')->is_valid_number, '丸玉産業');
ok($zip->set_number('3113880')->is_valid_number, 'なめがたファーマーズヴィレッジ');
ok($zip->set_number('3113892')->is_valid_number, '行方市役所');
ok($zip->set_number('3113893')->is_valid_number, '茨城県 行方県税事務所');
ok($zip->set_number('3113894')->is_valid_number, '茨城ライスミル 株式会社');
ok($zip->set_number('3114193')->is_valid_number, 'いばらきコープ生活 協同組合');
ok($zip->set_number('3114194')->is_valid_number, '茨城県教科書販売 株式会社');
ok($zip->set_number('3114195')->is_valid_number, '戸田産業 株式会社');
ok($zip->set_number('3114196')->is_valid_number, '株式会社 ケーシーエス');
ok($zip->set_number('3114198')->is_valid_number, '水戸済生会総合病院');
ok($zip->set_number('3114391')->is_valid_number, '城里町役場 本庁舎');
ok($zip->set_number('3114392')->is_valid_number, '茨城県立水戸桜ノ牧高等学校 常北校');
ok($zip->set_number('3114393')->is_valid_number, '株式会社 イトウ');
ok($zip->set_number('3114592')->is_valid_number, '常陸大宮市役所 御前山総合支所');
ok($zip->set_number('3114595')->is_valid_number, '城里町役場 桂支所');
ok($zip->set_number('3128501')->is_valid_number, 'ひたちなか市役所');
ok($zip->set_number('3128502')->is_valid_number, '日立工機 株式会社');
ok($zip->set_number('3128503')->is_valid_number, '日立Astemo 株式会社');
ok($zip->set_number('3128504')->is_valid_number, '株式会社 日立ハイテクノロジーズ');
ok($zip->set_number('3128505')->is_valid_number, '日立ビークルエナジー 株式会社');
ok($zip->set_number('3128507')->is_valid_number, '株式会社 日立パワーソリューションズ 勝田事業所');
ok($zip->set_number('3128508')->is_valid_number, '茨城工業高等専門学校');
ok($zip->set_number('3128510')->is_valid_number, '株式会社 ジョイフル本田 ニューポートひたちなか店');
ok($zip->set_number('3128511')->is_valid_number, 'ルネサスエレクトロニクス 株式会社 那珂事業所');
ok($zip->set_number('3138511')->is_valid_number, '川崎病院');
ok($zip->set_number('3138611')->is_valid_number, '常陸太田市役所');
ok($zip->set_number('3138666')->is_valid_number, '茨城県常陸太田県税事務所');
ok($zip->set_number('3138686')->is_valid_number, '太田 税務署');
ok($zip->set_number('3140192')->is_valid_number, '神栖市役所');
ok($zip->set_number('3140193')->is_valid_number, 'DIC 株式会社 鹿島工場');
ok($zip->set_number('3140194')->is_valid_number, '昭和産業 株式会社 鹿島工場');
ok($zip->set_number('3140195')->is_valid_number, '旭硝子 株式会社 鹿島工場');
ok($zip->set_number('3140197')->is_valid_number, '株式会社 クラレ 鹿島工場');
ok($zip->set_number('3140198')->is_valid_number, '鹿島石油 株式会社 鹿島製油所');
ok($zip->set_number('3148501')->is_valid_number, '独立行政法人 情報通信研究機構 鹿島宇宙技術センター');
ok($zip->set_number('3148655')->is_valid_number, '鹿嶋市役所');
ok($zip->set_number('3150195')->is_valid_number, '八郷総合支所');
ok($zip->set_number('3158511')->is_valid_number, '東日電線 株式会社');
ok($zip->set_number('3158512')->is_valid_number, 'かすみがうら市役所 千代田庁舎');
ok($zip->set_number('3158513')->is_valid_number, '東洋平成ポリマー 株式会社');
ok($zip->set_number('3158516')->is_valid_number, '入江工営 株式会社');
ok($zip->set_number('3158518')->is_valid_number, 'マグ・イゾベール 株式会社 土浦工場');
ok($zip->set_number('3158522')->is_valid_number, '湖北水道企業団');
ok($zip->set_number('3158525')->is_valid_number, '日本板硝子関東販売 株式会社');
ok($zip->set_number('3158527')->is_valid_number, '株式会社 武井工業所');
ok($zip->set_number('3158585')->is_valid_number, '東洋製罐 株式会社 石岡工場');
ok($zip->set_number('3158640')->is_valid_number, '石岡市役所');
ok($zip->set_number('3168501')->is_valid_number, '日立製作所 国分工場');
ok($zip->set_number('3168502')->is_valid_number, '日立グローバルライフソリューションズ 生活家電本部');
ok($zip->set_number('3168511')->is_valid_number, '茨城大学 工学部');
ok($zip->set_number('3168533')->is_valid_number, '社会医療法人 愛宣会 ひたち医療センター');
ok($zip->set_number('3178511')->is_valid_number, '株式会社 日立製作所 日立事業所');
ok($zip->set_number('3178555')->is_valid_number, '日立化成 株式会社 山崎事業所');
ok($zip->set_number('3178585')->is_valid_number, '三菱重工業 株式会社 日立工場');
ok($zip->set_number('3178601')->is_valid_number, '日立市役所');
ok($zip->set_number('3178602')->is_valid_number, '日立 税務署');
ok($zip->set_number('3188501')->is_valid_number, '東部大建工業 株式会社');
ok($zip->set_number('3188505')->is_valid_number, '日本ケミコン 株式会社 高萩工場');
ok($zip->set_number('3188511')->is_valid_number, '高萩市役所');
ok($zip->set_number('3190192')->is_valid_number, '小美玉市役所');
ok($zip->set_number('3190198')->is_valid_number, '横浜ゴム 株式会社 茨城工場');
ok($zip->set_number('3190292')->is_valid_number, '茨城県農業総合センター');
ok($zip->set_number('3190294')->is_valid_number, '笠間市役所 岩間支所');
ok($zip->set_number('3190295')->is_valid_number, '株式会社 金陽社 茨城工場');
ok($zip->set_number('3190393')->is_valid_number, '水戸市役所 内原庁舎');
ok($zip->set_number('3190394')->is_valid_number, 'イオン 水戸内原ショッピングセンター');
ok($zip->set_number('3190395')->is_valid_number, 'ジャスコ 水戸内原店');
ok($zip->set_number('3190397')->is_valid_number, '茨城県神社庁');
ok($zip->set_number('3191182')->is_valid_number, '積水メディカル 株式会社 創薬支援センター');
ok($zip->set_number('3191184')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構');
ok($zip->set_number('3191188')->is_valid_number, '東京大学大学院 工学系研究科 原子力専攻');
ok($zip->set_number('3191192')->is_valid_number, '東海村役場');
ok($zip->set_number('3191194')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構 核燃料サイクル工学研究所');
ok($zip->set_number('3191195')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構 原子力科学研究所');
ok($zip->set_number('3191196')->is_valid_number, '原子燃料工業 株式会社 東海事業所');
ok($zip->set_number('3191197')->is_valid_number, '三菱原子燃料 株式会社');
ok($zip->set_number('3191292')->is_valid_number, '株式会社 日立製作所 日立研究所');
ok($zip->set_number('3191293')->is_valid_number, '株式会社 日立製作所 サービス&プラットフォームビジネスユニット');
ok($zip->set_number('3191295')->is_valid_number, '茨城キリスト教学園');
ok($zip->set_number('3191393')->is_valid_number, '国民宿舎「鵜の岬」');
ok($zip->set_number('3191592')->is_valid_number, '北茨城市役所');
ok($zip->set_number('3191593')->is_valid_number, 'ユニマテック 株式会社');
ok($zip->set_number('3192192')->is_valid_number, '那珂市役所 瓜連支所');
ok($zip->set_number('3192692')->is_valid_number, '常陸大宮市役所美和総合所');
ok($zip->set_number('3193595')->is_valid_number, '大子町役場');
ok($zip->set_number('3208501')->is_valid_number, '栃木県庁');
ok($zip->set_number('3208502')->is_valid_number, 'NHK 宇都宮放送局');
ok($zip->set_number('3208503')->is_valid_number, 'とちぎ健康の森');
ok($zip->set_number('3208505')->is_valid_number, '宇都宮地方裁判所');
ok($zip->set_number('3208506')->is_valid_number, '栃木県立特別支援学校 宇都宮青葉高等学園');
ok($zip->set_number('3208507')->is_valid_number, '住友生命保険 相互会社');
ok($zip->set_number('3208508')->is_valid_number, 'とちぎ福祉プラザ');
ok($zip->set_number('3208510')->is_valid_number, '栃木県警察本部');
ok($zip->set_number('3208511')->is_valid_number, '東京海上日動火災保険 株式会社 栃木支店');
ok($zip->set_number('3208512')->is_valid_number, '株式会社 下野新聞アドセンター');
ok($zip->set_number('3208514')->is_valid_number, '全国健康保険協会 栃木支部');
ok($zip->set_number('3208515')->is_valid_number, '宇都宮地方法務局');
ok($zip->set_number('3208517')->is_valid_number, '株式会社 栃木よみうり');
ok($zip->set_number('3208521')->is_valid_number, '医療法人 報徳会');
ok($zip->set_number('3208522')->is_valid_number, '栃木社会保険事務局');
ok($zip->set_number('3208523')->is_valid_number, '栃木日産自動車販売 株式会社');
ok($zip->set_number('3208525')->is_valid_number, '作新学院');
ok($zip->set_number('3208528')->is_valid_number, '株式会社 コジマ');
ok($zip->set_number('3208530')->is_valid_number, '財団法人 とちぎ生涯学習文化財団');
ok($zip->set_number('3208531')->is_valid_number, '(株) とちぎテレビ');
ok($zip->set_number('3208532')->is_valid_number, '財務省 関東財務局 宇都宮財務事務所');
ok($zip->set_number('3208533')->is_valid_number, '宇都宮ビジネス電子専門学校');
ok($zip->set_number('3208538')->is_valid_number, '宇都宮大学教育学部附属学校');
ok($zip->set_number('3208540')->is_valid_number, '宇都宮市役所');
ok($zip->set_number('3208541')->is_valid_number, 'トヨタウッドユーホーム 株式会社');
ok($zip->set_number('3208543')->is_valid_number, '宇都宮市上下水道局');
ok($zip->set_number('3208550')->is_valid_number, '株式会社 エフエム栃木');
ok($zip->set_number('3208551')->is_valid_number, '帝京大学 理工学部');
ok($zip->set_number('3208555')->is_valid_number, '栃木社会保険事務局 宇都宮西社会保険事務室');
ok($zip->set_number('3208560')->is_valid_number, '株式会社 東武宇都宮百貨店');
ok($zip->set_number('3208564')->is_valid_number, '株式会社 SUBARU 宇都宮製作所');
ok($zip->set_number('3208566')->is_valid_number, '株式会社 パルコ 宇都宮店');
ok($zip->set_number('3208570')->is_valid_number, '(財) 宇都宮市文化会館管理公社');
ok($zip->set_number('3208577')->is_valid_number, '栃木県社会保険診療報酬支払基金');
ok($zip->set_number('3208580')->is_valid_number, '独立行政法人 国立病院機構 栃木医療センター');
ok($zip->set_number('3208585')->is_valid_number, '宇都宮短期大学附属高等学校');
ok($zip->set_number('3208588')->is_valid_number, '栃木トヨペット 株式会社');
ok($zip->set_number('3208601')->is_valid_number, '株式会社 栃木放送');
ok($zip->set_number('3208610')->is_valid_number, '株式会社 足利銀行');
ok($zip->set_number('3208611')->is_valid_number, '大和証券 株式会社 宇都宮支店');
ok($zip->set_number('3208618')->is_valid_number, '栃木県信用保証協会');
ok($zip->set_number('3208620')->is_valid_number, '株式会社 足利銀行 宇都宮中央支店');
ok($zip->set_number('3208655')->is_valid_number, '宇都宮 税務署');
ok($zip->set_number('3208668')->is_valid_number, '商工組合 中央金庫 宇都宮支店');
ok($zip->set_number('3208680')->is_valid_number, '株式会社 栃木銀行');
ok($zip->set_number('3208686')->is_valid_number, '株式会社 下野新聞社');
ok($zip->set_number('3208688')->is_valid_number, '株式会社 足利銀行 宇都宮支店');
ok($zip->set_number('3210194')->is_valid_number, 'トヨタカローラ栃木 株式会社');
ok($zip->set_number('3210195')->is_valid_number, 'とちぎコープ生活 協同組合');
ok($zip->set_number('3210198')->is_valid_number, '栃木県立 宇都宮工業高等学校');
ok($zip->set_number('3210292')->is_valid_number, '壬生町役場');
ok($zip->set_number('3210293')->is_valid_number, '獨協医科大学');
ok($zip->set_number('3210295')->is_valid_number, '日立古河建機 株式会社');
ok($zip->set_number('3210298')->is_valid_number, '株式会社 バンダイ 栃木修理・配送センター');
ok($zip->set_number('3210592')->is_valid_number, '那須南農業協同組合');
ok($zip->set_number('3210593')->is_valid_number, '矢崎部品 株式会社 栃木工場');
ok($zip->set_number('3210595')->is_valid_number, '那須烏山市 南那須庁舎');
ok($zip->set_number('3210692')->is_valid_number, '那須烏山市役所');
ok($zip->set_number('3211292')->is_valid_number, '日光市役所');
ok($zip->set_number('3211293')->is_valid_number, '日本年金機構 今市年金事務所');
ok($zip->set_number('3211298')->is_valid_number, '獨協医科大学 日光医療センター');
ok($zip->set_number('3211492')->is_valid_number, '日光市役所 日光総合支所');
ok($zip->set_number('3211493')->is_valid_number, '古河電工');
ok($zip->set_number('3212492')->is_valid_number, '東武建設 株式会社');
ok($zip->set_number('3212493')->is_valid_number, 'ジャスコ 今市店');
ok($zip->set_number('3212592')->is_valid_number, '金谷ホテル観光 株式会社 鬼怒川温泉ホテル');
ok($zip->set_number('3212593')->is_valid_number, '東武ワールドスクウェア 株式会社');
ok($zip->set_number('3212595')->is_valid_number, '日光市 藤原総合支所');
ok($zip->set_number('3212596')->is_valid_number, '日光市 藤原水道事務所');
ok($zip->set_number('3212598')->is_valid_number, '株式会社 あさやホテル');
ok($zip->set_number('3212792')->is_valid_number, '栃木県酪農業協同組合・大笹牧場');
ok($zip->set_number('3213292')->is_valid_number, 'キヤノン 株式会社 宇都宮光学機器事業所');
ok($zip->set_number('3213293')->is_valid_number, 'キヤノン 株式会社 宇都宮工場');
ok($zip->set_number('3213295')->is_valid_number, '作新学院大学');
ok($zip->set_number('3213296')->is_valid_number, 'エム・イー・エム・シー 株式会社');
ok($zip->set_number('3213297')->is_valid_number, 'マルハ 株式会社 宇都宮工場');
ok($zip->set_number('3213298')->is_valid_number, 'キヤノン 株式会社 光学技術研究所');
ok($zip->set_number('3213392')->is_valid_number, '芳賀町役場');
ok($zip->set_number('3213393')->is_valid_number, '本田技研工業 株式会社');
ok($zip->set_number('3213395')->is_valid_number, '本田技研工業 株式会社 四輪事業本部 ものづくりセンター 生産技術統括部');
ok($zip->set_number('3213398')->is_valid_number, '株式会社 エイチワン 機種開発センター');
ok($zip->set_number('3213493')->is_valid_number, '市貝町役場');
ok($zip->set_number('3213497')->is_valid_number, '花王 株式会社 栃木工場');
ok($zip->set_number('3213498')->is_valid_number, '花王 株式会社 栃木研究所');
ok($zip->set_number('3213595')->is_valid_number, '栃木県立茂木高等高校');
ok($zip->set_number('3213597')->is_valid_number, '株式会社 モビリティランド ツインリンクもてぎ');
ok($zip->set_number('3213598')->is_valid_number, '茂木町役場');
ok($zip->set_number('3214292')->is_valid_number, 'ペンタックス 株式会社 益子事業所');
ok($zip->set_number('3214293')->is_valid_number, '益子町役場');
ok($zip->set_number('3214295')->is_valid_number, '益子焼窯元共販 株式会社');
ok($zip->set_number('3214392')->is_valid_number, 'SHPPジャパン 合同会社');
ok($zip->set_number('3214393')->is_valid_number, '第一電子工業 株式会社');
ok($zip->set_number('3214395')->is_valid_number, '真岡市役所');
ok($zip->set_number('3214396')->is_valid_number, '富士ファイバーグラス 株式会社');
ok($zip->set_number('3214398')->is_valid_number, '真岡県税事務所');
ok($zip->set_number('3218502')->is_valid_number, 'パナソニック コミュニケーションズ 株式会社');
ok($zip->set_number('3218505')->is_valid_number, '宇都宮大学');
ok($zip->set_number('3218555')->is_valid_number, '株式会社 ベルモール');
ok($zip->set_number('3218585')->is_valid_number, '宇都宮大学 工学部');
ok($zip->set_number('3220393')->is_valid_number, '鹿沼市役所 粟野支所');
ok($zip->set_number('3220692')->is_valid_number, '栃木市役所 西方総合支所');
ok($zip->set_number('3228501')->is_valid_number, 'デクセリアルズ 株式会社 鹿沼事業所 第1工場');
ok($zip->set_number('3228502')->is_valid_number, 'デクセリアルズ 株式会社 鹿沼事業所 第2工場');
ok($zip->set_number('3228503')->is_valid_number, 'デクセリアルズ 株式会社 鹿沼事業所 第3工場');
ok($zip->set_number('3228511')->is_valid_number, '株式会社 JSP 鹿沼工場');
ok($zip->set_number('3228550')->is_valid_number, '上都賀厚生農業協同組合連合会 上都賀病院');
ok($zip->set_number('3228555')->is_valid_number, '株式会社 東京インテリア家具 本部情報商品センター');
ok($zip->set_number('3228585')->is_valid_number, '住友電工電子ワイヤー 株式会社');
ok($zip->set_number('3228588')->is_valid_number, '株式会社 関口');
ok($zip->set_number('3228601')->is_valid_number, '鹿沼市役所');
ok($zip->set_number('3228603')->is_valid_number, '鹿沼 税務署');
ok($zip->set_number('3228666')->is_valid_number, '株式会社 ナカニシ');
ok($zip->set_number('3228688')->is_valid_number, '株式会社 栃の葉書房');
ok($zip->set_number('3230192')->is_valid_number, 'ソニーエナジー・デバイス 株式会社 栃木事業所');
ok($zip->set_number('3230194')->is_valid_number, 'デクセリアルズ 株式会社 栃木事業所');
ok($zip->set_number('3231192')->is_valid_number, '栃木市役所 藤岡総合支所');
ok($zip->set_number('3238511')->is_valid_number, '富士通 株式会社 小山工場');
ok($zip->set_number('3238558')->is_valid_number, '株式会社 小松製作所 小山工場');
ok($zip->set_number('3238567')->is_valid_number, 'コマツ 栃木工場');
ok($zip->set_number('3238585')->is_valid_number, '白鴎大学');
ok($zip->set_number('3238586')->is_valid_number, '白鴎大学 駅東キャンパス');
ok($zip->set_number('3238601')->is_valid_number, '古河機械金属 株式会社 小山工場');
ok($zip->set_number('3238611')->is_valid_number, '小平産業 株式会社');
ok($zip->set_number('3238678')->is_valid_number, '昭和アルミニウム 株式会社 小山製造所');
ok($zip->set_number('3238686')->is_valid_number, '小山市役所');
ok($zip->set_number('3238755')->is_valid_number, '株式会社 YSO.PARTNER\'S');
ok($zip->set_number('3238756')->is_valid_number, '株式会社 YSO.PARTNER\'S MEGAキャンペーン');
ok($zip->set_number('3240292')->is_valid_number, '大田原市役所 黒羽支所');
ok($zip->set_number('3240293')->is_valid_number, '黒羽刑務所');
ok($zip->set_number('3240492')->is_valid_number, '大田原市役所 湯津上庁舎');
ok($zip->set_number('3240592')->is_valid_number, '株式会社 吉野工業所 那須小川工場');
ok($zip->set_number('3240593')->is_valid_number, '株式会社 吉野工業所 小川第二工場');
ok($zip->set_number('3240594')->is_valid_number, '株式会社 吉野工業所 小川金型工場');
ok($zip->set_number('3240595')->is_valid_number, '那珂川町役場 小川支所');
ok($zip->set_number('3240596')->is_valid_number, '那須小川ゴルフクラブ');
ok($zip->set_number('3240692')->is_valid_number, '那珂川町役場');
ok($zip->set_number('3240693')->is_valid_number, '住友金属鉱山シポレックス 株式会社 栃木工場');
ok($zip->set_number('3248501')->is_valid_number, '国際医療福祉大学');
ok($zip->set_number('3248510')->is_valid_number, '富士電機 株式会社 大田原工場');
ok($zip->set_number('3248516')->is_valid_number, '大日本塗料 株式会社 那須工場');
ok($zip->set_number('3248520')->is_valid_number, '株式会社 栃木ニコンプレシジョン');
ok($zip->set_number('3248540')->is_valid_number, '日本年金機構 大田原年金事務所');
ok($zip->set_number('3248550')->is_valid_number, 'キヤノン電子管デバイス 株式会社');
ok($zip->set_number('3248550')->is_valid_number, 'キヤノンメディカルシステムズ 株式会社');
ok($zip->set_number('3248551')->is_valid_number, '大田原県税事務所');
ok($zip->set_number('3248555')->is_valid_number, '富士通 株式会社 那須工場');
ok($zip->set_number('3248585')->is_valid_number, '栃木県県北健康福祉センター');
ok($zip->set_number('3248625')->is_valid_number, '株式会社 栃木ニコン');
ok($zip->set_number('3248641')->is_valid_number, '大田原市役所');
ok($zip->set_number('3248642')->is_valid_number, '大田原 税務署');
ok($zip->set_number('3248686')->is_valid_number, '那須赤十字病院');
ok($zip->set_number('3248765')->is_valid_number, '大田原土木事務所');
ok($zip->set_number('3250392')->is_valid_number, '株式会社 サンバレー那須');
ok($zip->set_number('3250393')->is_valid_number, '株式会社 南ヶ丘牧場');
ok($zip->set_number('3250395')->is_valid_number, '那須ビューホテル');
ok($zip->set_number('3250397')->is_valid_number, '那須興業 株式会社');
ok($zip->set_number('3250398')->is_valid_number, '藤和那須リゾート 株式会社');
ok($zip->set_number('3260392')->is_valid_number, '両毛丸善 株式会社');
ok($zip->set_number('3260395')->is_valid_number, '三和シャッター 株式会社');
ok($zip->set_number('3268501')->is_valid_number, '株式会社 レンタルのニッケン');
ok($zip->set_number('3268502')->is_valid_number, '足利商工会議所');
ok($zip->set_number('3268505')->is_valid_number, '株式会社 開倫塾');
ok($zip->set_number('3268511')->is_valid_number, 'アキレス 株式会社');
ok($zip->set_number('3268520')->is_valid_number, '株式会社 コスミック出版');
ok($zip->set_number('3268521')->is_valid_number, '株式会社 電波実験社');
ok($zip->set_number('3268550')->is_valid_number, '株式会社 足利モール');
ok($zip->set_number('3268558')->is_valid_number, '足利大学');
ok($zip->set_number('3268572')->is_valid_number, 'アピタ 足利店');
ok($zip->set_number('3268585')->is_valid_number, '株式会社 信栄');
ok($zip->set_number('3268601')->is_valid_number, '足利市役所');
ok($zip->set_number('3268611')->is_valid_number, '株式会社 足利銀行 足利支店');
ok($zip->set_number('3268630')->is_valid_number, '足利税務署');
ok($zip->set_number('3268686')->is_valid_number, '商工組合 中央金庫 足利支店');
ok($zip->set_number('3270192')->is_valid_number, '佐野日本大学中学・高等学校');
ok($zip->set_number('3270398')->is_valid_number, '佐野市役所 田沼庁舎');
ok($zip->set_number('3270592')->is_valid_number, '吉澤石灰工業 株式会社');
ok($zip->set_number('3270595')->is_valid_number, '佐野市役所 葛生行政センター');
ok($zip->set_number('3278501')->is_valid_number, '佐野市役所');
ok($zip->set_number('3278503')->is_valid_number, '佐野県税事務所');
ok($zip->set_number('3278511')->is_valid_number, '佐野厚生農業協同組合連合会 佐野厚生総合病院');
ok($zip->set_number('3278533')->is_valid_number, '佐野プレミアム・アウトレット');
ok($zip->set_number('3278555')->is_valid_number, '佐野厄よけ大師');
ok($zip->set_number('3278601')->is_valid_number, '佐野 税務署');
ok($zip->set_number('3278603')->is_valid_number, '佐野信用金庫');
ok($zip->set_number('3278678')->is_valid_number, '株式会社 足利銀行 佐野支店');
ok($zip->set_number('3280192')->is_valid_number, '栃木市役所 都賀総合支所');
ok($zip->set_number('3288501')->is_valid_number, 'イオン (株) ジャスコ栃木店');
ok($zip->set_number('3288502')->is_valid_number, 'GKNドライブラインジャパン 株式会社');
ok($zip->set_number('3288503')->is_valid_number, '三井鉱山 株式会社 栃木事業所');
ok($zip->set_number('3288504')->is_valid_number, '栃木県税事務所');
ok($zip->set_number('3288533')->is_valid_number, '栃木年金事務所');
ok($zip->set_number('3288550')->is_valid_number, '栃木刑務所');
ok($zip->set_number('3288555')->is_valid_number, '岩下食品 株式会社');
ok($zip->set_number('3288556')->is_valid_number, '不二ラテックス 株式会社 栃木工場');
ok($zip->set_number('3288558')->is_valid_number, '栃木県立学悠館高等学校');
ok($zip->set_number('3288585')->is_valid_number, '栃木商工会議所');
ok($zip->set_number('3288586')->is_valid_number, '滝沢ハム 株式会社');
ok($zip->set_number('3288587')->is_valid_number, '関東信越国税局業務センター 栃木分室');
ok($zip->set_number('3288588')->is_valid_number, '國學院大學栃木学園');
ok($zip->set_number('3288666')->is_valid_number, '栃木 税務署');
ok($zip->set_number('3288668')->is_valid_number, '株式会社 足利銀行 栃木支店');
ok($zip->set_number('3288686')->is_valid_number, '栃木市役所');
ok($zip->set_number('3290195')->is_valid_number, '野木町役場');
ok($zip->set_number('3290492')->is_valid_number, '下野市役所');
ok($zip->set_number('3290493')->is_valid_number, 'ケーブルビジョン 株式会社 ラジオ事業部(FMゆうがお)');
ok($zip->set_number('3290498')->is_valid_number, '自治医科大学');
ok($zip->set_number('3290595')->is_valid_number, 'グンゼ 株式会社 宇都宮工場');
ok($zip->set_number('3290596')->is_valid_number, '医療法人社団 友志会 石橋総合病院');
ok($zip->set_number('3290598')->is_valid_number, '第一化成 株式会社');
ok($zip->set_number('3290692')->is_valid_number, '日産自動車 株式会社 栃木工場');
ok($zip->set_number('3290696')->is_valid_number, '上三川町役場');
ok($zip->set_number('3291193')->is_valid_number, '独立行政法人 国立病院機構 宇都宮病院');
ok($zip->set_number('3291194')->is_valid_number, '財団法人 栃木県保健衛生事業団 岡本水質食品検査所');
ok($zip->set_number('3291196')->is_valid_number, '栃木県保健環境センター');
ok($zip->set_number('3291198')->is_valid_number, '財団法人 栃木県環境技術協会');
ok($zip->set_number('3291292')->is_valid_number, '高根沢町役場');
ok($zip->set_number('3291392')->is_valid_number, 'さくら市役所');
ok($zip->set_number('3291393')->is_valid_number, '氏家税務署');
ok($zip->set_number('3291395')->is_valid_number, '社団医療法人 恵生会 黒須病院');
ok($zip->set_number('3291493')->is_valid_number, '喜連川社会復帰促進センター');
ok($zip->set_number('3292192')->is_valid_number, '矢板市役所');
ok($zip->set_number('3292292')->is_valid_number, '塩谷町役場');
ok($zip->set_number('3292792')->is_valid_number, '那須塩原市役所 西那須野支所');
ok($zip->set_number('3292793')->is_valid_number, '独立行政法人 農業・食品産業技術総合研究機構 畜産草地研究所');
ok($zip->set_number('3292992')->is_valid_number, '株式会社 ホテルニュー塩原');
ok($zip->set_number('3292993')->is_valid_number, '那須塩原市役所 塩原支所');
ok($zip->set_number('3293292')->is_valid_number, '那須町役場');
ok($zip->set_number('3294392')->is_valid_number, '栃木市役所 岩舟総合支所');
ok($zip->set_number('3294492')->is_valid_number, '栃木市役所 大平総合支所');
ok($zip->set_number('3294493')->is_valid_number, '日立アプライアンス (株) 栃木空調本部');
ok($zip->set_number('3294498')->is_valid_number, 'とちぎメディカルセンターしもつが');
ok($zip->set_number('3308501')->is_valid_number, 'さいたま市 大宮区役所');
ok($zip->set_number('3308503')->is_valid_number, '自治医科大学附属さいたま医療センター');
ok($zip->set_number('3308505')->is_valid_number, 'NTT 大宮支店');
ok($zip->set_number('3308506')->is_valid_number, '社団法人 埼玉県トラック協会');
ok($zip->set_number('3308508')->is_valid_number, '三菱マテリアル 株式会社');
ok($zip->set_number('3308510')->is_valid_number, '郵便局ビジネスサポート 株式会社 関東地方運用センター');
ok($zip->set_number('3308511')->is_valid_number, '株式会社 高島屋 大宮店');
ok($zip->set_number('3308518')->is_valid_number, '埼玉会館');
ok($zip->set_number('3308519')->is_valid_number, '朝日生命保険 相互会社 浦和支社');
ok($zip->set_number('3308522')->is_valid_number, '埼玉県社会福祉事業団 障害者交流センター');
ok($zip->set_number('3308529')->is_valid_number, '埼玉県社会福祉協議会');
ok($zip->set_number('3308532')->is_valid_number, 'さいたま市水道局');
ok($zip->set_number('3308533')->is_valid_number, '埼玉県警察本部');
ok($zip->set_number('3308538')->is_valid_number, '株式会社 テレビ埼玉');
ok($zip->set_number('3308547')->is_valid_number, '株式会社 日本政策金融公庫 さいたま支店 国民生活事業');
ok($zip->set_number('3308548')->is_valid_number, '学校法人 国際学院 国際学院埼玉短期大学');
ok($zip->set_number('3308550')->is_valid_number, 'サンケイリビング新聞社 埼玉本部');
ok($zip->set_number('3308551')->is_valid_number, '読売新聞社 浦和支局');
ok($zip->set_number('3308552')->is_valid_number, '中央労働金庫 さいたま支店');
ok($zip->set_number('3308553')->is_valid_number, 'さいたま赤十字病院');
ok($zip->set_number('3308557')->is_valid_number, '朝日新聞 さいたま総局');
ok($zip->set_number('3308562')->is_valid_number, '全国農業協同組合連合会 埼玉県本部');
ok($zip->set_number('3308564')->is_valid_number, '株式会社 関電工 北関東・北信越営業本部');
ok($zip->set_number('3308565')->is_valid_number, '株式会社 住田光学ガラス');
ok($zip->set_number('3308566')->is_valid_number, '新洋信販 株式会社');
ok($zip->set_number('3308571')->is_valid_number, '全労済 埼玉県本部');
ok($zip->set_number('3308572')->is_valid_number, '浦和地方検察庁');
ok($zip->set_number('3308579')->is_valid_number, '株式会社 FMNACK5');
ok($zip->set_number('3308580')->is_valid_number, '浦和年金事務所');
ok($zip->set_number('3308581')->is_valid_number, '株式会社 富士薬品');
ok($zip->set_number('3308585')->is_valid_number, '株式会社 ユーディケー');
ok($zip->set_number('3308589')->is_valid_number, '大宮ラクーン');
ok($zip->set_number('3308601')->is_valid_number, '大和証券 株式会社 大宮支店');
ok($zip->set_number('3308603')->is_valid_number, 'さいたま市財政局 北部市税事務所 法人課税課 特別徴収係');
ok($zip->set_number('3308634')->is_valid_number, 'むさし証券 株式会社');
ok($zip->set_number('3308647')->is_valid_number, '浦和レッドダイヤモンズ 株式会社');
ok($zip->set_number('3308669')->is_valid_number, 'ソニックシティビル');
ok($zip->set_number('3308671')->is_valid_number, 'アークランズ 株式会社');
ok($zip->set_number('3308686')->is_valid_number, '全国健康保険協会 埼玉支部');
ok($zip->set_number('3308688')->is_valid_number, 'アクサ損害保険 株式会社');
ok($zip->set_number('3308708')->is_valid_number, '全国生活協同組合連合会');
ok($zip->set_number('3308710')->is_valid_number, '一般財団法人 郵政福祉 関東地方本部');
ok($zip->set_number('3308777')->is_valid_number, '埼玉県立小児医療センター');
ok($zip->set_number('3309011')->is_valid_number, '大平ビルサービス 株式会社 さいたま支店');
ok($zip->set_number('3309045')->is_valid_number, 'NTT東日本料金サービスセンター');
ok($zip->set_number('3309109')->is_valid_number, '株式会社 ミュージアム・タイセイ');
ok($zip->set_number('3309111')->is_valid_number, '株式会社 さいたまアリーナ');
ok($zip->set_number('3309301')->is_valid_number, '埼玉県');
ok($zip->set_number('3309303')->is_valid_number, '株式会社 三越伊勢丹 伊勢丹浦和店');
ok($zip->set_number('3309310')->is_valid_number, '日本放送協会 さいたま放送局');
ok($zip->set_number('3309311')->is_valid_number, '日新火災海上保険 株式会社');
ok($zip->set_number('3309330')->is_valid_number, '埼玉県立 浦和高等学校');
ok($zip->set_number('3309377')->is_valid_number, '埼玉SR経営労務センター');
ok($zip->set_number('3309501')->is_valid_number, '株式会社 丸井 大宮店');
ok($zip->set_number('3309502')->is_valid_number, 'ネッツ埼玉 株式会社');
ok($zip->set_number('3309503')->is_valid_number, '株式会社 富士通マーケティング');
ok($zip->set_number('3309507')->is_valid_number, '日本年金機構 北関東信越ブロック本部');
ok($zip->set_number('3309508')->is_valid_number, '株式会社 富士薬品');
ok($zip->set_number('3309509')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('3309511')->is_valid_number, '埼玉県社会保険診療報酬支払基金');
ok($zip->set_number('3309512')->is_valid_number, '学校法人 佐藤栄学園');
ok($zip->set_number('3309520')->is_valid_number, '株式会社 しまむら');
ok($zip->set_number('3309525')->is_valid_number, 'クレディ・スイス生命保険 株式会社 大宮支社');
ok($zip->set_number('3309531')->is_valid_number, '東芝エレベータ 株式会社 北関東支社');
ok($zip->set_number('3309535')->is_valid_number, '三光ソフラン 株式会社');
ok($zip->set_number('3309536')->is_valid_number, '株式会社 ドコモCS 埼玉支店');
ok($zip->set_number('3309540')->is_valid_number, '山善 北関東支社');
ok($zip->set_number('3309543')->is_valid_number, '株式会社 埼玉マツダ');
ok($zip->set_number('3309544')->is_valid_number, 'キヤノンマーケティングジャパン 株式会社 さいたま営業所');
ok($zip->set_number('3309545')->is_valid_number, '富士レビオ 株式会社 北関東支店');
ok($zip->set_number('3309548')->is_valid_number, '東京新聞ショッパー社');
ok($zip->set_number('3309550')->is_valid_number, '毎日新聞 さいたま支局');
ok($zip->set_number('3309551')->is_valid_number, 'リズム 株式会社');
ok($zip->set_number('3309553')->is_valid_number, '株式会社 ウィズウェイストジャパン');
ok($zip->set_number('3309555')->is_valid_number, '東日本旅客鉄道 (株) 大宮支社');
ok($zip->set_number('3309558')->is_valid_number, '大和ハウス工業 株式会社 埼玉支店');
ok($zip->set_number('3309559')->is_valid_number, '片倉工業 株式会社 コクーンシティ');
ok($zip->set_number('3309564')->is_valid_number, '昌和貿易 株式会社');
ok($zip->set_number('3309565')->is_valid_number, '埼玉県自動車販売整備健康保険組合');
ok($zip->set_number('3309566')->is_valid_number, '株式会社 マルフク');
ok($zip->set_number('3309575')->is_valid_number, '埼玉県自動車販売整備厚生年金基金');
ok($zip->set_number('3309577')->is_valid_number, '東日本旅客鉄道 (株) 大宮工場');
ok($zip->set_number('3309580')->is_valid_number, '日本信販 株式会社 関東第2エリア営業開発グループ');
ok($zip->set_number('3309581')->is_valid_number, '日本信販 株式会社 大宮支店');
ok($zip->set_number('3309582')->is_valid_number, 'エヌ・エス債権回収 株式会社 大宮支店');
ok($zip->set_number('3309583')->is_valid_number, '株式会社 日本ビジネスリース さいたま支店');
ok($zip->set_number('3309586')->is_valid_number, '浦和区役所');
ok($zip->set_number('3309587')->is_valid_number, '関東信越国税局業務センター');
ok($zip->set_number('3309588')->is_valid_number, 'さいたま市役所');
ok($zip->set_number('3309590')->is_valid_number, '浦和税務署');
ok($zip->set_number('3309601')->is_valid_number, '日本生命保険 相互会社 埼玉総支社');
ok($zip->set_number('3309608')->is_valid_number, '埼玉県信用保証協会');
ok($zip->set_number('3309611')->is_valid_number, '(株) エフエム浦和');
ok($zip->set_number('3309621')->is_valid_number, '株式会社 ロフト 大宮ロフト');
ok($zip->set_number('3309622')->is_valid_number, '(株) JTBトラベランド 関越事業部');
ok($zip->set_number('3309626')->is_valid_number, '大宮商工会議所');
ok($zip->set_number('3309630')->is_valid_number, '株式会社 ティー・ピー・エス テプコソニック');
ok($zip->set_number('3309666')->is_valid_number, 'りそな決済サービス 株式会社 集金代行部');
ok($zip->set_number('3309688')->is_valid_number, '財団法人 新藤花道学院');
ok($zip->set_number('3309696')->is_valid_number, '株式会社 ジャックス 大宮支店');
ok($zip->set_number('3309710')->is_valid_number, '関東信越厚生局 年金審査課');
ok($zip->set_number('3309713')->is_valid_number, '関東信越厚生局');
ok($zip->set_number('3309715')->is_valid_number, '関東経済産業局');
ok($zip->set_number('3309717')->is_valid_number, '総務省 関東管区行政評価局');
ok($zip->set_number('3309720')->is_valid_number, '環境省関東地方環境事務所');
ok($zip->set_number('3309727')->is_valid_number, '関東信越厚生局 指導監査課');
ok($zip->set_number('3309731')->is_valid_number, '独立行政法人 農林水産消費安全技術センター');
ok($zip->set_number('3309739')->is_valid_number, '国土交通省関東地方整備局 建政部建設産業第一課');
ok($zip->set_number('3309791')->is_valid_number, 'さいたまBPOセンター');
ok($zip->set_number('3309792')->is_valid_number, '日本郵政共済組合 共済センター');
ok($zip->set_number('3309793')->is_valid_number, '日本郵政共済組合 共済センター 被扶養者担当');
ok($zip->set_number('3309796')->is_valid_number, '埼玉監査室');
ok($zip->set_number('3309797')->is_valid_number, '株式会社 ゆうちょ銀行 さいたま支店');
ok($zip->set_number('3309797')->is_valid_number, '株式会社 かんぽ生命 さいたま支店');
ok($zip->set_number('3309797')->is_valid_number, '日本郵便 株式会社 関東支社');
ok($zip->set_number('3309850')->is_valid_number, '太陽生命保険 相互会社');
ok($zip->set_number('3318501')->is_valid_number, 'カルソニックカンセイ 株式会社');
ok($zip->set_number('3318511')->is_valid_number, '株式会社 島忠');
ok($zip->set_number('3318513')->is_valid_number, 'JR東日本 研究開発センター');
ok($zip->set_number('3318520')->is_valid_number, 'ツルゲン情報 株式会社');
ok($zip->set_number('3318532')->is_valid_number, '明治乳業 株式会社 東京支社 東関東支店');
ok($zip->set_number('3318533')->is_valid_number, '安田 株式会社 埼玉支店');
ok($zip->set_number('3318537')->is_valid_number, '生物系特定産業技術研究支援センター');
ok($zip->set_number('3318540')->is_valid_number, 'ユアサ商事 株式会社 北関東支社');
ok($zip->set_number('3318550')->is_valid_number, '陸上自衛隊 大宮駐屯地');
ok($zip->set_number('3318552')->is_valid_number, '株式会社 カネゲン');
ok($zip->set_number('3318560')->is_valid_number, '岩谷産業 株式会社 関東支社');
ok($zip->set_number('3318567')->is_valid_number, '大宮中央総合病院付属 大宮中央クリニック');
ok($zip->set_number('3318577')->is_valid_number, '彩の国 東大宮 メディカルセンター');
ok($zip->set_number('3318580')->is_valid_number, '埼玉県自動車税事務所');
ok($zip->set_number('3318585')->is_valid_number, '大宮アルディージャ クラブハウス');
ok($zip->set_number('3318586')->is_valid_number, '北区役所');
ok($zip->set_number('3318587')->is_valid_number, '西区役所');
ok($zip->set_number('3318588')->is_valid_number, '高田製薬 株式会社');
ok($zip->set_number('3318625')->is_valid_number, '独立行政法人 地域医療機能推進機構 さいたま北部医療センター');
ok($zip->set_number('3318633')->is_valid_number, 'カシュー 株式会社');
ok($zip->set_number('3318658')->is_valid_number, '株式会社 スズキ自販埼玉');
ok($zip->set_number('3318686')->is_valid_number, '株式会社 埼玉新聞社');
ok($zip->set_number('3318687')->is_valid_number, 'パナソニックSSマーケティング 株式会社 関越社');
ok($zip->set_number('3318688')->is_valid_number, '応用地質 株式会社');
ok($zip->set_number('3318701')->is_valid_number, 'キヤノンメディカルシステムズ 株式会社 関東支社');
ok($zip->set_number('3319510')->is_valid_number, '信越ポリマー 株式会社');
ok($zip->set_number('3319520')->is_valid_number, '大正製薬 株式会社 大宮工場');
ok($zip->set_number('3319530')->is_valid_number, '大正製薬 株式会社 総合研究所');
ok($zip->set_number('3319550')->is_valid_number, '株式会社 しまむら');
ok($zip->set_number('3319577')->is_valid_number, '大宮年金事務所');
ok($zip->set_number('3328501')->is_valid_number, '川口水道局');
ok($zip->set_number('3328502')->is_valid_number, '川口金属工業 株式会社');
ok($zip->set_number('3328503')->is_valid_number, 'アマゾン川口FC');
ok($zip->set_number('3328511')->is_valid_number, 'そごう 川口店');
ok($zip->set_number('3328512')->is_valid_number, '田中徳兵衛商店');
ok($zip->set_number('3328521')->is_valid_number, 'カシオテクノ 株式会社');
ok($zip->set_number('3328548')->is_valid_number, 'NTT東日本-埼玉 埼玉南営業支店');
ok($zip->set_number('3328555')->is_valid_number, '株式会社 深川製作所 株式会社 フカガワ 深川機械販売 株式会社');
ok($zip->set_number('3328556')->is_valid_number, '前沢工業');
ok($zip->set_number('3328558')->is_valid_number, '済生会川口総合病院');
ok($zip->set_number('3328577')->is_valid_number, '中興電機 株式会社');
ok($zip->set_number('3328585')->is_valid_number, 'クロゼン');
ok($zip->set_number('3328601')->is_valid_number, '川口市役所');
ok($zip->set_number('3328654')->is_valid_number, '西川口税務署');
ok($zip->set_number('3328666')->is_valid_number, '川口税務署');
ok($zip->set_number('3328686')->is_valid_number, '川口信用金庫');
ok($zip->set_number('3338601')->is_valid_number, '株式会社 改良園');
ok($zip->set_number('3338611')->is_valid_number, '株式会社 日本花卉');
ok($zip->set_number('3348501')->is_valid_number, '協和ゴム工業 株式会社');
ok($zip->set_number('3358501')->is_valid_number, '蕨市役所');
ok($zip->set_number('3358502')->is_valid_number, 'JX日鉱日石エネルギー 株式会社');
ok($zip->set_number('3358510')->is_valid_number, '沖電気工業 株式会社');
ok($zip->set_number('3358522')->is_valid_number, '株式会社 日教販');
ok($zip->set_number('3358533')->is_valid_number, '蕨警察署');
ok($zip->set_number('3358555')->is_valid_number, '戸田中央総合病院');
ok($zip->set_number('3358558')->is_valid_number, 'JA全農ミートフーズ 株式会社 東日本営業本部');
ok($zip->set_number('3358585')->is_valid_number, '株式会社 JOMOテクニカルリサーチセンター');
ok($zip->set_number('3358588')->is_valid_number, '戸田市役所');
ok($zip->set_number('3358655')->is_valid_number, '株式会社 埼玉りそな銀行 蕨支店');
ok($zip->set_number('3358666')->is_valid_number, '株式会社 埼玉りそな銀行 戸田支店');
ok($zip->set_number('3368505')->is_valid_number, '浦和レッドダイヤモンズ 株式会社');
ok($zip->set_number('3368508')->is_valid_number, '全国生活協同組合連合会');
ok($zip->set_number('3368512')->is_valid_number, '埼玉土建一般労働組合');
ok($zip->set_number('3368515')->is_valid_number, '社団法人 埼玉建設産業団体連合会');
ok($zip->set_number('3368521')->is_valid_number, '日本オート・フォート 株式会社');
ok($zip->set_number('3368522')->is_valid_number, 'さいたま市立病院');
ok($zip->set_number('3368523')->is_valid_number, '生活共同組合 コープみらい');
ok($zip->set_number('3368526')->is_valid_number, 'コープデリ生活協同組合連合会');
ok($zip->set_number('3368540')->is_valid_number, '埼玉三菱ふそう自動車販売 株式会社');
ok($zip->set_number('3368555')->is_valid_number, '埼玉県立 南教育センター');
ok($zip->set_number('3368558')->is_valid_number, '株式会社 長崎屋 浦和店');
ok($zip->set_number('3368561')->is_valid_number, '日特エンジニアリング 株式会社');
ok($zip->set_number('3368564')->is_valid_number, '株式会社 関電工 埼玉支店');
ok($zip->set_number('3368586')->is_valid_number, 'さいたま市南区役所');
ok($zip->set_number('3368587')->is_valid_number, '緑区役所');
ok($zip->set_number('3368636')->is_valid_number, '株式会社 コーケン');
ok($zip->set_number('3368655')->is_valid_number, '日本電信電話 株式会社');
ok($zip->set_number('3368666')->is_valid_number, '高田製薬 株式会社');
ok($zip->set_number('3368760')->is_valid_number, 'イオンモール 浦和美園');
ok($zip->set_number('3378501')->is_valid_number, '埼玉県大宮東警察署');
ok($zip->set_number('3378502')->is_valid_number, '株式会社 日立国際八木ソリューションズ');
ok($zip->set_number('3378507')->is_valid_number, '新日本法規出版 (株) 関東支社');
ok($zip->set_number('3378532')->is_valid_number, 'トキタ種苗 株式会社');
ok($zip->set_number('3378556')->is_valid_number, '株式会社 タムロン');
ok($zip->set_number('3378570')->is_valid_number, '芝浦工業大学');
ok($zip->set_number('3378586')->is_valid_number, '見沼区役所');
ok($zip->set_number('3388503')->is_valid_number, '日本ピストンリング 株式会社 本社');
ok($zip->set_number('3388504')->is_valid_number, '全労済 埼玉県本部');
ok($zip->set_number('3388505')->is_valid_number, '日本ピストンリング 株式会社 R&Dセンター');
ok($zip->set_number('3388506')->is_valid_number, '(財) 埼玉県芸術文化振興財団 彩の国さいたま芸術劇場');
ok($zip->set_number('3388508')->is_valid_number, '埼玉トヨペット 株式会社');
ok($zip->set_number('3388510')->is_valid_number, 'ミサワホーム西関東 (株)');
ok($zip->set_number('3388511')->is_valid_number, '株式会社 島忠');
ok($zip->set_number('3388512')->is_valid_number, '日本通運 株式会社 埼玉支店');
ok($zip->set_number('3388513')->is_valid_number, 'さいたま地方法務局');
ok($zip->set_number('3388515')->is_valid_number, '株式会社 大塚商会 埼玉営業部');
ok($zip->set_number('3388523')->is_valid_number, '日産プリンス埼玉販売 株式会社');
ok($zip->set_number('3388524')->is_valid_number, 'コニシ 株式会社 浦和工場');
ok($zip->set_number('3388525')->is_valid_number, '埼玉日産自動車 株式会社');
ok($zip->set_number('3388531')->is_valid_number, '社団法人 日本自動車連盟 埼玉支部');
ok($zip->set_number('3388538')->is_valid_number, '株式会社 モリタ 東京製作所');
ok($zip->set_number('3388540')->is_valid_number, 'ドイト 株式会社 通販部');
ok($zip->set_number('3388541')->is_valid_number, '三輪精機 株式会社');
ok($zip->set_number('3388551')->is_valid_number, '浦和中央青果市場 株式会社');
ok($zip->set_number('3388555')->is_valid_number, '埼玉スバル自動車 株式会社');
ok($zip->set_number('3388557')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('3388558')->is_valid_number, 'UFJニコス 株式会社 北関東管理部');
ok($zip->set_number('3388566')->is_valid_number, 'ドイト 株式会社');
ok($zip->set_number('3388567')->is_valid_number, '株式会社 与野フードセンター');
ok($zip->set_number('3388570')->is_valid_number, '埼玉大学');
ok($zip->set_number('3388575')->is_valid_number, '株式会社 カバサワ');
ok($zip->set_number('3388577')->is_valid_number, '埼玉精神神経センター');
ok($zip->set_number('3388580')->is_valid_number, '東京電力 株式会社 さいたま支社');
ok($zip->set_number('3388585')->is_valid_number, 'トヨタカローラ新埼玉 株式会社');
ok($zip->set_number('3388586')->is_valid_number, '桜区役所');
ok($zip->set_number('3388630')->is_valid_number, 'さいたま市郵送請求処理センター');
ok($zip->set_number('3388686')->is_valid_number, '中央区役所');
ok($zip->set_number('3398501')->is_valid_number, '目白大学');
ok($zip->set_number('3398503')->is_valid_number, 'アマゾンジャパンTPFI');
ok($zip->set_number('3398510')->is_valid_number, '藤倉ゴム工業 株式会社 岩槻工場');
ok($zip->set_number('3398511')->is_valid_number, '北海製罐 (株) 岩槻工場');
ok($zip->set_number('3398521')->is_valid_number, '丸山記念総合病院');
ok($zip->set_number('3398539')->is_valid_number, '人間総合科学大学');
ok($zip->set_number('3398551')->is_valid_number, '埼玉県立 小児医療センター');
ok($zip->set_number('3398558')->is_valid_number, '株式会社 プラコー');
ok($zip->set_number('3398566')->is_valid_number, '株式会社 トーモク岩槻工場');
ok($zip->set_number('3398585')->is_valid_number, 'さいたま市 岩槻区役所');
ok($zip->set_number('3398601')->is_valid_number, '曙ブレーキ岩槻製造 株式会社');
ok($zip->set_number('3398686')->is_valid_number, '花菱縫製 株式会社');
ok($zip->set_number('3400192')->is_valid_number, '幸手市役所');
ok($zip->set_number('3400193')->is_valid_number, 'コスモ石油 (株) 中央研究所');
ok($zip->set_number('3400194')->is_valid_number, 'トラスコ中山 株式会社 プラネット埼玉');
ok($zip->set_number('3400295')->is_valid_number, '久喜市 鷲宮総合支所');
ok($zip->set_number('3408501')->is_valid_number, '株式会社 ティ・アンド・ケイ・パッケージ');
ok($zip->set_number('3408509')->is_valid_number, '草加公共職業安定所');
ok($zip->set_number('3408510')->is_valid_number, '富安金属印刷 株式会社');
ok($zip->set_number('3408511')->is_valid_number, '旭鋼管工業 株式会社');
ok($zip->set_number('3408520')->is_valid_number, '株式会社 イー・ロジット 埼玉フルフィルメントセンター');
ok($zip->set_number('3408524')->is_valid_number, '埼玉県立草加西高等学校');
ok($zip->set_number('3408533')->is_valid_number, '株式会社 流通サービス');
ok($zip->set_number('3408550')->is_valid_number, '草加市役所');
ok($zip->set_number('3408551')->is_valid_number, '堀川産業 株式会社');
ok($zip->set_number('3408555')->is_valid_number, '草加市 水道部');
ok($zip->set_number('3408560')->is_valid_number, '草加市立病院');
ok($zip->set_number('3408567')->is_valid_number, 'タカギ冷機 株式会社');
ok($zip->set_number('3408568')->is_valid_number, '株式会社 川島製作所');
ok($zip->set_number('3408577')->is_valid_number, '東日本電信電話 株式会社 草加ビル');
ok($zip->set_number('3408585')->is_valid_number, '獨協大学 入試部');
ok($zip->set_number('3408588')->is_valid_number, '八潮市役所');
ok($zip->set_number('3408610')->is_valid_number, '天田印刷加工 株式会社');
ok($zip->set_number('3408611')->is_valid_number, '株式会社 クレシア 東京工場');
ok($zip->set_number('3408659')->is_valid_number, 'SMC 株式会社');
ok($zip->set_number('3408686')->is_valid_number, 'ソマール 株式会社');
ok($zip->set_number('3418501')->is_valid_number, '三郷市役所');
ok($zip->set_number('3418526')->is_valid_number, '医療法人社団 愛友会 三郷中央総合病院');
ok($zip->set_number('3418527')->is_valid_number, 'キヤノンファインテックニスカ 株式会社');
ok($zip->set_number('3418550')->is_valid_number, 'ららぽーと新三郷');
ok($zip->set_number('3418555')->is_valid_number, 'みさと健和病院');
ok($zip->set_number('3418558')->is_valid_number, '株式会社 七虹');
ok($zip->set_number('3428501')->is_valid_number, '吉川市役所');
ok($zip->set_number('3428502')->is_valid_number, '株式会社 オーム電機');
ok($zip->set_number('3428505')->is_valid_number, '株式会社 丸和運輸機関');
ok($zip->set_number('3428601')->is_valid_number, '株式会社 アサヒ情報');
ok($zip->set_number('3430192')->is_valid_number, '松伏町役場');
ok($zip->set_number('3430193')->is_valid_number, '大正大学 埼玉校舎');
ok($zip->set_number('3438501')->is_valid_number, '越谷市役所');
ok($zip->set_number('3438502')->is_valid_number, '林恒 株式会社');
ok($zip->set_number('3438511')->is_valid_number, '文教大学');
ok($zip->set_number('3438520')->is_valid_number, 'ホダカ 株式会社');
ok($zip->set_number('3438540')->is_valid_number, '埼玉県立大学');
ok($zip->set_number('3438554')->is_valid_number, '株式会社 ウエノ');
ok($zip->set_number('3438555')->is_valid_number, '独協医科大学 越谷病院');
ok($zip->set_number('3438558')->is_valid_number, 'イオンレイクタウンkaze');
ok($zip->set_number('3438585')->is_valid_number, '越谷年金事務所');
ok($zip->set_number('3438601')->is_valid_number, '越谷税務署');
ok($zip->set_number('3448506')->is_valid_number, '春日部労働基準監督署');
ok($zip->set_number('3448508')->is_valid_number, '埼玉県信用保証協会 春日部支店');
ok($zip->set_number('3448511')->is_valid_number, '株式会社 高橋監理');
ok($zip->set_number('3448521')->is_valid_number, '春日部女子高等学校');
ok($zip->set_number('3448522')->is_valid_number, '株式会社 桃屋 春日部工場');
ok($zip->set_number('3448533')->is_valid_number, '西武 春日部店');
ok($zip->set_number('3448535')->is_valid_number, '春日部警察署');
ok($zip->set_number('3448540')->is_valid_number, '株式会社 G.R.S.');
ok($zip->set_number('3448555')->is_valid_number, '埼玉県春日部県税事務所');
ok($zip->set_number('3448566')->is_valid_number, '株式会社 マルヤ');
ok($zip->set_number('3448577')->is_valid_number, '春日部市役所');
ok($zip->set_number('3448578')->is_valid_number, '春日部市 市民活動センター');
ok($zip->set_number('3448585')->is_valid_number, '春日部商工会議所');
ok($zip->set_number('3448588')->is_valid_number, '春日部市立医療センター');
ok($zip->set_number('3448680')->is_valid_number, '関東信越国税局 インボイス登録センター');
ok($zip->set_number('3448686')->is_valid_number, '春日部税務署');
ok($zip->set_number('3458501')->is_valid_number, '日本工業大学');
ok($zip->set_number('3458502')->is_valid_number, '杉戸町役場');
ok($zip->set_number('3458504')->is_valid_number, '宮代町役場');
ok($zip->set_number('3458508')->is_valid_number, '凸版印刷 株式会社');
ok($zip->set_number('3460181')->is_valid_number, '株式会社 日伝 東部物流センター');
ok($zip->set_number('3460183')->is_valid_number, 'ユニーグループ関東北物流センター');
ok($zip->set_number('3460192')->is_valid_number, '久喜市 菖蒲総合支所');
ok($zip->set_number('3460193')->is_valid_number, '日本鋳鉄管 株式会社');
ok($zip->set_number('3460194')->is_valid_number, '株式会社 エフテック');
ok($zip->set_number('3460195')->is_valid_number, 'モラージュ菖蒲');
ok($zip->set_number('3460196')->is_valid_number, '日本マタイ 株式会社 埼玉工場');
ok($zip->set_number('3460198')->is_valid_number, '株式会社 NSKマシナリー');
ok($zip->set_number('3468501')->is_valid_number, '久喜市役所');
ok($zip->set_number('3468506')->is_valid_number, '埼玉県立久喜図書館');
ok($zip->set_number('3468511')->is_valid_number, 'アマゾン久喜FC');
ok($zip->set_number('3468516')->is_valid_number, 'イトーヨーカ堂 久喜IDC(TC)');
ok($zip->set_number('3468524')->is_valid_number, '日本信号 (株)');
ok($zip->set_number('3468530')->is_valid_number, '埼玉県厚生農業協同組合連合会 久喜総合病院');
ok($zip->set_number('3468540')->is_valid_number, 'ベネッセコーポレーション (株)');
ok($zip->set_number('3468685')->is_valid_number, 'ベネッセコーポレーション');
ok($zip->set_number('3468686')->is_valid_number, 'ベネッセコーポレーション');
ok($zip->set_number('3470192')->is_valid_number, '加須市 騎西総合支所');
ok($zip->set_number('3470195')->is_valid_number, 'キサイフーズ工業 株式会社');
ok($zip->set_number('3478501')->is_valid_number, '加須市役所');
ok($zip->set_number('3478502')->is_valid_number, '花咲徳栄高校');
ok($zip->set_number('3478503')->is_valid_number, '埼玉短期大学');
ok($zip->set_number('3478504')->is_valid_number, '平成国際大学');
ok($zip->set_number('3478510')->is_valid_number, '社会福祉法人 愛の泉');
ok($zip->set_number('3478513')->is_valid_number, '県立不動岡高校');
ok($zip->set_number('3478550')->is_valid_number, 'ブリヂストンBRM 株式会社');
ok($zip->set_number('3478555')->is_valid_number, 'アトミクス 株式会社');
ok($zip->set_number('3478567')->is_valid_number, '大昭和紙工産業 株式会社 加須工場');
ok($zip->set_number('3478585')->is_valid_number, '日本ワイパブレード 株式会社');
ok($zip->set_number('3488501')->is_valid_number, '曙ブレーキ工業 株式会社 関東営業所');
ok($zip->set_number('3488502')->is_valid_number, '埼玉県立羽生実業高等学校');
ok($zip->set_number('3488503')->is_valid_number, '金子農機 株式会社');
ok($zip->set_number('3488505')->is_valid_number, '埼玉医療生活協同組合 羽生総合病院');
ok($zip->set_number('3488506')->is_valid_number, '日本精工 株式会社');
ok($zip->set_number('3488507')->is_valid_number, '関東三洋セミコンダクターズ 株式会社 羽生工場');
ok($zip->set_number('3488508')->is_valid_number, '曙ブレーキ工業 株式会社');
ok($zip->set_number('3488512')->is_valid_number, 'エーダイニット 株式会社');
ok($zip->set_number('3488513')->is_valid_number, 'ほくさい農業協同組合');
ok($zip->set_number('3488525')->is_valid_number, '田中鉄鋼販売 株式会社');
ok($zip->set_number('3488530')->is_valid_number, '共愛会');
ok($zip->set_number('3488540')->is_valid_number, '大正製薬 株式会社 羽生工場');
ok($zip->set_number('3488549')->is_valid_number, '日清ヨーク 株式会社 関東工場');
ok($zip->set_number('3488555')->is_valid_number, '株式会社 ダイチュー テクノロジーズ');
ok($zip->set_number('3488585')->is_valid_number, '昭和化成工業 株式会社');
ok($zip->set_number('3488601')->is_valid_number, '羽生市役所');
ok($zip->set_number('3490192')->is_valid_number, '株式会社 東光高岳');
ok($zip->set_number('3490193')->is_valid_number, '蓮田市役所');
ok($zip->set_number('3490195')->is_valid_number, '東京セキスイ工業 株式会社');
ok($zip->set_number('3490196')->is_valid_number, '独立行政法人 国立病院機構 東埼玉病院');
ok($zip->set_number('3490198')->is_valid_number, '積水化学工業 株式会社 武蔵工場');
ok($zip->set_number('3490292')->is_valid_number, '白岡市役所');
ok($zip->set_number('3490293')->is_valid_number, '大成ラミック 株式会社');
ok($zip->set_number('3490294')->is_valid_number, '日産化学工業 株式会社');
ok($zip->set_number('3490295')->is_valid_number, '医療法人社団哺育会 白岡中央総合病院');
ok($zip->set_number('3490296')->is_valid_number, '白岡市生涯学習センター[こもれびの森]');
ok($zip->set_number('3491192')->is_valid_number, '久喜市 栗橋総合支所');
ok($zip->set_number('3491193')->is_valid_number, '加須市 大利根総合支所');
ok($zip->set_number('3491292')->is_valid_number, '加須市 北川辺総合支所');
ok($zip->set_number('3500192')->is_valid_number, '川島町役場');
ok($zip->set_number('3500193')->is_valid_number, '三井精機工業 株式会社 川島工場');
ok($zip->set_number('3500195')->is_valid_number, 'アマゾン 川島FC 入庫係');
ok($zip->set_number('3500197')->is_valid_number, 'イーデーエム 株式会社 テクノセンター');
ok($zip->set_number('3500280')->is_valid_number, '株式会社 日東');
ok($zip->set_number('3500282')->is_valid_number, 'アマゾン坂戸FC');
ok($zip->set_number('3500283')->is_valid_number, '明海大学');
ok($zip->set_number('3500284')->is_valid_number, '株式会社 高純度化学研究所');
ok($zip->set_number('3500285')->is_valid_number, 'イーグル工業');
ok($zip->set_number('3500286')->is_valid_number, '株式会社 パイオニアFA');
ok($zip->set_number('3500287')->is_valid_number, 'パイオニアファインテック 株式会社');
ok($zip->set_number('3500288')->is_valid_number, '女子栄養大学');
ok($zip->set_number('3500289')->is_valid_number, '明治製菓');
ok($zip->set_number('3500292')->is_valid_number, '坂戸市役所');
ok($zip->set_number('3500295')->is_valid_number, '城西大学');
ok($zip->set_number('3500392')->is_valid_number, '鳩山町役場');
ok($zip->set_number('3500393')->is_valid_number, '独立行政法人 宇宙航空研究開発機構 地球観測センター');
ok($zip->set_number('3500394')->is_valid_number, '東京電機大学 理工学部');
ok($zip->set_number('3500395')->is_valid_number, '株式会社 日立製作所 基礎研究所');
ok($zip->set_number('3500396')->is_valid_number, '山村学園短期大学');
ok($zip->set_number('3500493')->is_valid_number, '毛呂山町役場');
ok($zip->set_number('3500494')->is_valid_number, '越生町役場');
ok($zip->set_number('3500495')->is_valid_number, '埼玉医科大学');
ok($zip->set_number('3500496')->is_valid_number, '学校法人 埼玉医科大学 保健医療学部 川角キャンパス');
ok($zip->set_number('3501181')->is_valid_number, '株式会社 アイエムエス');
ok($zip->set_number('3501182')->is_valid_number, 'アマゾン 川越FC 入庫係');
ok($zip->set_number('3501183')->is_valid_number, '埼玉県信用保証協会 川越支店');
ok($zip->set_number('3501185')->is_valid_number, 'アマゾンかわじまFC 小型商材 返品係');
ok($zip->set_number('3501188')->is_valid_number, '武州瓦斯 株式会社');
ok($zip->set_number('3501192')->is_valid_number, '小松ゼノア 株式会社');
ok($zip->set_number('3501194')->is_valid_number, 'アマゾン川越FC 返品係');
ok($zip->set_number('3501195')->is_valid_number, 'アマゾンかわじまFC 返品係');
ok($zip->set_number('3501196')->is_valid_number, '川越年金事務所');
ok($zip->set_number('3501197')->is_valid_number, '学校法人 金子教育団 東京国際大学(第一キャンパス)');
ok($zip->set_number('3501198')->is_valid_number, '学校法人 金子教育団 東京国際大学 (第二キャンパス)');
ok($zip->set_number('3501292')->is_valid_number, '日高市役所');
ok($zip->set_number('3501295')->is_valid_number, 'NECネットワーク・センサ 株式会社');
ok($zip->set_number('3501296')->is_valid_number, '太平洋セメント 株式会社 埼玉工場');
ok($zip->set_number('3501297')->is_valid_number, 'シグマ光機 株式会社');
ok($zip->set_number('3501298')->is_valid_number, '埼玉医科大学国際医療センター');
ok($zip->set_number('3501380')->is_valid_number, '狭山市役所');
ok($zip->set_number('3501383')->is_valid_number, 'アマゾン狭山広瀬台FC');
ok($zip->set_number('3501385')->is_valid_number, '阿部興業 株式会社');
ok($zip->set_number('3501386')->is_valid_number, 'アマゾン 狭山FC 入庫係');
ok($zip->set_number('3501388')->is_valid_number, '東亜ディーケーケー 株式会社 狭山テクニカルセンター');
ok($zip->set_number('3501389')->is_valid_number, 'アマゾン狭山日高FC');
ok($zip->set_number('3501392')->is_valid_number, '本田技研工業 株式会社 埼玉製作所');
ok($zip->set_number('3501395')->is_valid_number, '株式会社 鷺宮製作所 狭山事業所');
ok($zip->set_number('3501398')->is_valid_number, '東京家政大学 狭山校舎');
ok($zip->set_number('3502280')->is_valid_number, '東洋電装 株式会社');
ok($zip->set_number('3502281')->is_valid_number, '東光 (株) 埼玉事業所');
ok($zip->set_number('3502282')->is_valid_number, '株式会社 ベルク');
ok($zip->set_number('3502287')->is_valid_number, '株式会社 ネオシス');
ok($zip->set_number('3502288')->is_valid_number, 'オムロン プレシジョンテクノロジー 株式会社');
ok($zip->set_number('3502292')->is_valid_number, '鶴ヶ島市役所');
ok($zip->set_number('3502295')->is_valid_number, '株式会社 IHI航空・宇宙・防衛事業領域生産センター鶴ヶ島工場');
ok($zip->set_number('3508501')->is_valid_number, '川越プリンスホテル');
ok($zip->set_number('3508510')->is_valid_number, '川越商工会議所');
ok($zip->set_number('3508511')->is_valid_number, '株式会社 丸広百貨店');
ok($zip->set_number('3508531')->is_valid_number, 'さいたま地方裁判所 川越支部');
ok($zip->set_number('3508550')->is_valid_number, '埼玉医科大学総合医療センター');
ok($zip->set_number('3508555')->is_valid_number, 'パイオニア 株式会社 川越事業所');
ok($zip->set_number('3508585')->is_valid_number, '学校法人 東洋大学');
ok($zip->set_number('3508588')->is_valid_number, '医療法人 康正会病院');
ok($zip->set_number('3508601')->is_valid_number, '川越市役所');
ok($zip->set_number('3508666')->is_valid_number, '川越税務署');
ok($zip->set_number('3510188')->is_valid_number, '本田技研工業 株式会社 和光ビル');
ok($zip->set_number('3510192')->is_valid_number, '和光市役所');
ok($zip->set_number('3510193')->is_valid_number, '本田技術研究所');
ok($zip->set_number('3510194')->is_valid_number, '司法研修所');
ok($zip->set_number('3510196')->is_valid_number, '裁判所職員総合研修所');
ok($zip->set_number('3510197')->is_valid_number, '国立保健医療科学院');
ok($zip->set_number('3510198')->is_valid_number, '国立研究開発法人 理化学研究所');
ok($zip->set_number('3518501')->is_valid_number, '朝霞市役所');
ok($zip->set_number('3518503')->is_valid_number, '新電元工業 株式会社 朝霞事業所');
ok($zip->set_number('3518508')->is_valid_number, '株式会社 東京印書館');
ok($zip->set_number('3518510')->is_valid_number, '東洋大学 朝霞校舎');
ok($zip->set_number('3518511')->is_valid_number, '積水化学工業 株式会社 東京工場');
ok($zip->set_number('3518520')->is_valid_number, 'すまいるエフエム 株式会社');
ok($zip->set_number('3518555')->is_valid_number, '株式会社 本田技術研究所 二輪R&Dセンター');
ok($zip->set_number('3518560')->is_valid_number, '朝霞市社会福祉協議会');
ok($zip->set_number('3518585')->is_valid_number, '富士写真フィルム 株式会社 朝霞技術開発センター');
ok($zip->set_number('3518586')->is_valid_number, '株式会社 M-TEC');
ok($zip->set_number('3518601')->is_valid_number, '朝霞税務署');
ok($zip->set_number('3528501')->is_valid_number, '跡見学園女子大学');
ok($zip->set_number('3528510')->is_valid_number, '十文字学園女子大学・十文字学園女子大学 短期大学部');
ok($zip->set_number('3528523')->is_valid_number, '立教新座中学校・高等学校');
ok($zip->set_number('3528549')->is_valid_number, '立教大学 野球部');
ok($zip->set_number('3528555')->is_valid_number, '法台寺');
ok($zip->set_number('3528558')->is_valid_number, '立教大学 新座キャンパス');
ok($zip->set_number('3528572')->is_valid_number, '株式会社 ボッシュオートモーティブシステム 志木事務所');
ok($zip->set_number('3528577')->is_valid_number, '株式会社 マイカル新座サテイ');
ok($zip->set_number('3528588')->is_valid_number, '東京カネカ食品販売 株式会社');
ok($zip->set_number('3528589')->is_valid_number, '株式会社 ホンダアクセス');
ok($zip->set_number('3528623')->is_valid_number, '新座市役所');
ok($zip->set_number('3528666')->is_valid_number, 'サンケン電気 株式会社 本社');
ok($zip->set_number('3538501')->is_valid_number, '志木市役所');
ok($zip->set_number('3538555')->is_valid_number, '東京電力 株式会社 埼玉支店 志木支社');
ok($zip->set_number('3548501')->is_valid_number, '大崎電気 株式会社 埼玉事業所');
ok($zip->set_number('3548504')->is_valid_number, '(株) 学研ロジスティクス');
ok($zip->set_number('3548505')->is_valid_number, '株式会社 主婦の友社');
ok($zip->set_number('3548510')->is_valid_number, '淑徳大学 国際コミュニケーション学部');
ok($zip->set_number('3548511')->is_valid_number, '富士見市役所');
ok($zip->set_number('3548533')->is_valid_number, '株式会社主婦の友社 通販事業部');
ok($zip->set_number('3548555')->is_valid_number, '三芳町役場');
ok($zip->set_number('3548558')->is_valid_number, '大日本印刷 株式会社');
ok($zip->set_number('3548560')->is_valid_number, 'ららぽーと富士見');
ok($zip->set_number('3548565')->is_valid_number, 'ASKUL Logi PARK 首都圏');
ok($zip->set_number('3548577')->is_valid_number, '株式会社 T&K TOKA');
ok($zip->set_number('3548580')->is_valid_number, '日本シイエムケイ 株式会社 SEセンター');
ok($zip->set_number('3548585')->is_valid_number, '日酸TANAKA 株式会社');
ok($zip->set_number('3550192')->is_valid_number, '吉見町役場');
ok($zip->set_number('3550193')->is_valid_number, '東洋製罐 株式会社 埼玉工場');
ok($zip->set_number('3550194')->is_valid_number, 'Amazon TPF2');
ok($zip->set_number('3550195')->is_valid_number, 'プリマ食品 株式会社');
ok($zip->set_number('3550292')->is_valid_number, '独立行政法人 国立女性教育会館');
ok($zip->set_number('3550380')->is_valid_number, 'J-Mups売上票保管センター');
ok($zip->set_number('3550392')->is_valid_number, '小川町役場');
ok($zip->set_number('3550395')->is_valid_number, 'ときがわ町役場');
ok($zip->set_number('3558501')->is_valid_number, '大東文化大学');
ok($zip->set_number('3558585')->is_valid_number, '滑川町役場');
ok($zip->set_number('3558601')->is_valid_number, '東松山市役所');
ok($zip->set_number('3558603')->is_valid_number, 'ボッシュ 株式会社');
ok($zip->set_number('3558604')->is_valid_number, '東松山税務署');
ok($zip->set_number('3558605')->is_valid_number, 'ユニー 株式会社 アピタ東松山店');
ok($zip->set_number('3558606')->is_valid_number, 'ユニー 株式会社 ピオニウォーク東松山');
ok($zip->set_number('3558608')->is_valid_number, '株式会社 LIXILビバ 東松山物流センター');
ok($zip->set_number('3568501')->is_valid_number, 'ふじみ野市役所');
ok($zip->set_number('3568502')->is_valid_number, '株式会社 KDDI研究所');
ok($zip->set_number('3568507')->is_valid_number, '大日本印刷 株式会社 上福岡工場');
ok($zip->set_number('3568510')->is_valid_number, '日清紡マイクロデバイス 株式会社 川越事業所');
ok($zip->set_number('3568511')->is_valid_number, '(株) 日清製粉グループ本社');
ok($zip->set_number('3568525')->is_valid_number, 'イオンタウンふじみ野');
ok($zip->set_number('3568533')->is_valid_number, '文京学院大学');
ok($zip->set_number('3568550')->is_valid_number, '株式会社 内外テクノス');
ok($zip->set_number('3568555')->is_valid_number, 'ふじみ野市 大井総合支所');
ok($zip->set_number('3568556')->is_valid_number, '山下ゴム 株式会社');
ok($zip->set_number('3568567')->is_valid_number, '学校法人 ホンダ学園 ホンダテクニカルカレッジ関東');
ok($zip->set_number('3568580')->is_valid_number, '日本無線 株式会社 川越事業所');
ok($zip->set_number('3568585')->is_valid_number, '近藤建設 株式会社');
ok($zip->set_number('3578501')->is_valid_number, '飯能市役所');
ok($zip->set_number('3578510')->is_valid_number, '株式会社 椿本チエイン');
ok($zip->set_number('3578527')->is_valid_number, '大鵬薬品工業 株式会社');
ok($zip->set_number('3578550')->is_valid_number, '自由の森学園');
ok($zip->set_number('3578555')->is_valid_number, '駿河台大学');
ok($zip->set_number('3578558')->is_valid_number, '飯能信用金庫');
ok($zip->set_number('3578570')->is_valid_number, 'マミヤ・オーピー・ネクオス 株式会社');
ok($zip->set_number('3578585')->is_valid_number, '新電元工業 株式会社');
ok($zip->set_number('3578588')->is_valid_number, '飯能ケーブルテレビ 株式会社');
ok($zip->set_number('3588501')->is_valid_number, '株式会社 タムラ製作所');
ok($zip->set_number('3588510')->is_valid_number, 'ティアック 株式会社 EMCセンター');
ok($zip->set_number('3588511')->is_valid_number, '入間市役所');
ok($zip->set_number('3588515')->is_valid_number, '入間アウトレットパークOPC');
ok($zip->set_number('3588521')->is_valid_number, '武蔵野音楽学園');
ok($zip->set_number('3588555')->is_valid_number, '株式会社 安川電機');
ok($zip->set_number('3588558')->is_valid_number, '東野高等学校');
ok($zip->set_number('3588585')->is_valid_number, 'プラス工業 株式会社');
ok($zip->set_number('3588588')->is_valid_number, '大妻女子大学 狭山台校');
ok($zip->set_number('3591180')->is_valid_number, '西武バス 株式会社');
ok($zip->set_number('3591188')->is_valid_number, '平岩建設 株式会社');
ok($zip->set_number('3591189')->is_valid_number, '株式会社 西武ライオンズ');
ok($zip->set_number('3591192')->is_valid_number, '早稲田大学');
ok($zip->set_number('3591193')->is_valid_number, '大和証券 株式会社 所沢支店');
ok($zip->set_number('3591195')->is_valid_number, '埼玉りそな銀行 所沢支店');
ok($zip->set_number('3591196')->is_valid_number, '西武ライオンズ球場');
ok($zip->set_number('3591198')->is_valid_number, '株式会社 そごう・西武 西武所沢店');
ok($zip->set_number('3598501')->is_valid_number, '所沢市役所');
ok($zip->set_number('3598505')->is_valid_number, '所沢年金事務所');
ok($zip->set_number('3598507')->is_valid_number, '株式会社 バンガードシステムズ');
ok($zip->set_number('3598510')->is_valid_number, '(株) 西武ホールディングス');
ok($zip->set_number('3598511')->is_valid_number, '株式会社 シチズン時計');
ok($zip->set_number('3598513')->is_valid_number, '防衛医大');
ok($zip->set_number('3598520')->is_valid_number, '西武鉄道 株式会社');
ok($zip->set_number('3598533')->is_valid_number, 'NTT 所沢支店');
ok($zip->set_number('3598542')->is_valid_number, '東京電力 志木支社 所沢営業所センター');
ok($zip->set_number('3598550')->is_valid_number, '西武建設 株式会社');
ok($zip->set_number('3598555')->is_valid_number, '国立障害者リハビリテーションセンター');
ok($zip->set_number('3598558')->is_valid_number, '読売センター 東所沢');
ok($zip->set_number('3598560')->is_valid_number, '西武運輸 株式会社');
ok($zip->set_number('3598570')->is_valid_number, '西武バス 株式会社 本社');
ok($zip->set_number('3598580')->is_valid_number, '日本光電工業 株式会社');
ok($zip->set_number('3598585')->is_valid_number, '埼玉県 所沢県税事務所');
ok($zip->set_number('3598601')->is_valid_number, '所沢税務署');
ok($zip->set_number('3598648')->is_valid_number, '(株) 東京新聞ショッパー社');
ok($zip->set_number('3598686')->is_valid_number, '株式会社 タマス 所沢事業所');
ok($zip->set_number('3600192')->is_valid_number, '江南行政センター');
ok($zip->set_number('3600193')->is_valid_number, '株式会社 ゼクセルヴァレオ クライメートコントロール江南工場');
ok($zip->set_number('3600194')->is_valid_number, '立正大学 熊谷校舎');
ok($zip->set_number('3600195')->is_valid_number, '大里行政センター');
ok($zip->set_number('3600196')->is_valid_number, '株式会社 オキナヤ');
ok($zip->set_number('3600197')->is_valid_number, '埼玉県立 循環器・呼吸器病センター');
ok($zip->set_number('3608501')->is_valid_number, '埼玉県 熊谷県税事務所');
ok($zip->set_number('3608502')->is_valid_number, '(株) 八木橋');
ok($zip->set_number('3608512')->is_valid_number, '日東富士製粉 株式会社 埼玉工場');
ok($zip->set_number('3608515')->is_valid_number, 'シスコム 株式会社');
ok($zip->set_number('3608520')->is_valid_number, '関東国分 株式会社');
ok($zip->set_number('3608521')->is_valid_number, '株式会社 清水アーネット');
ok($zip->set_number('3608522')->is_valid_number, 'リケン 熊谷事業所');
ok($zip->set_number('3608523')->is_valid_number, '(株) 徳田練磨工作所');
ok($zip->set_number('3608532')->is_valid_number, '日東都市開発 株式会社');
ok($zip->set_number('3608543')->is_valid_number, '(株) アーレスティ 熊谷工場');
ok($zip->set_number('3608555')->is_valid_number, 'NTT東日本-埼玉');
ok($zip->set_number('3608558')->is_valid_number, '日本山村硝子 株式会社 埼玉工場');
ok($zip->set_number('3608559')->is_valid_number, '(株) ニコン 熊谷製作所');
ok($zip->set_number('3608567')->is_valid_number, '医療法人 熊谷総合病院');
ok($zip->set_number('3608577')->is_valid_number, '株式会社 プロテリアル 熊谷事業所');
ok($zip->set_number('3608580')->is_valid_number, '航空自衛隊 熊谷基地');
ok($zip->set_number('3608585')->is_valid_number, '熊谷年金事務所');
ok($zip->set_number('3608601')->is_valid_number, '熊谷市役所');
ok($zip->set_number('3608608')->is_valid_number, '埼玉県信用保証協会 熊谷支店');
ok($zip->set_number('3608611')->is_valid_number, '埼玉縣信用金庫');
ok($zip->set_number('3608620')->is_valid_number, '熊谷税務署');
ok($zip->set_number('3618503')->is_valid_number, '埼玉県行田県税事務所');
ok($zip->set_number('3618504')->is_valid_number, '行田労働基準監督署');
ok($zip->set_number('3618505')->is_valid_number, '岩崎電気');
ok($zip->set_number('3618506')->is_valid_number, '株式会社 ショーワ 本社 開発本部');
ok($zip->set_number('3618507')->is_valid_number, '株式会社 ショーワ 埼玉工場');
ok($zip->set_number('3618508')->is_valid_number, '株式会社 ショーワ 生産技術本部');
ok($zip->set_number('3618510')->is_valid_number, '東京軽合金製作所');
ok($zip->set_number('3618511')->is_valid_number, 'ジェコー');
ok($zip->set_number('3618513')->is_valid_number, '電元オートメーション');
ok($zip->set_number('3618539')->is_valid_number, '森乳業');
ok($zip->set_number('3618555')->is_valid_number, '寿屋フロンテ 埼玉工場');
ok($zip->set_number('3618585')->is_valid_number, 'ニッコー');
ok($zip->set_number('3618601')->is_valid_number, '行田市役所');
ok($zip->set_number('3618602')->is_valid_number, '行田税務署');
ok($zip->set_number('3618603')->is_valid_number, '足利銀行 行田支店');
ok($zip->set_number('3618604')->is_valid_number, 'SEIオプティフロンティア 株式会社 埼玉事業所');
ok($zip->set_number('3628501')->is_valid_number, '上尾市役所');
ok($zip->set_number('3628502')->is_valid_number, '日本ロジテム 株式会社 上尾営業所');
ok($zip->set_number('3628504')->is_valid_number, '上尾税務署');
ok($zip->set_number('3628508')->is_valid_number, 'アマゾン上尾FC');
ok($zip->set_number('3628510')->is_valid_number, '東京電力 株式会社 さいたま支社 上尾営業センター');
ok($zip->set_number('3628511')->is_valid_number, '昭産開発 株式会社');
ok($zip->set_number('3628517')->is_valid_number, '伊奈町役場');
ok($zip->set_number('3628520')->is_valid_number, 'ブリヂストンサイクル (株)');
ok($zip->set_number('3628521')->is_valid_number, 'ブリヂストンサイクル東日本販売 (株)');
ok($zip->set_number('3628523')->is_valid_number, 'UDトラックス 株式会社');
ok($zip->set_number('3628531')->is_valid_number, '株式会社 サイサン');
ok($zip->set_number('3628539')->is_valid_number, '株式会社 サイサン');
ok($zip->set_number('3628542')->is_valid_number, '株式会社 日本アクセス 埼玉支店');
ok($zip->set_number('3628550')->is_valid_number, '株式会社 アイチコーポレーション 上尾事業所');
ok($zip->set_number('3628553')->is_valid_number, '株式会社 日本アクセス 伊奈チルド物流センター');
ok($zip->set_number('3628555')->is_valid_number, 'トステムビバ 株式会社');
ok($zip->set_number('3628567')->is_valid_number, '埼玉県総合リハビリテーションセンター');
ok($zip->set_number('3628577')->is_valid_number, 'DIC 株式会社 埼玉工場');
ok($zip->set_number('3628585')->is_valid_number, '聖学院大学');
ok($zip->set_number('3628588')->is_valid_number, '医療法人社団 愛友会 上尾中央総合病院');
ok($zip->set_number('3628688')->is_valid_number, '株式会社 ベルーナ');
ok($zip->set_number('3638501')->is_valid_number, '桶川市役所');
ok($zip->set_number('3638505')->is_valid_number, '株式会社 シーエックスカーゴ');
ok($zip->set_number('3638509')->is_valid_number, 'マルキュー 株式会社');
ok($zip->set_number('3638510')->is_valid_number, '株式会社 プロテリアル 桶川工場');
ok($zip->set_number('3638555')->is_valid_number, 'ユニー 株式会社 ベニバナウォーク桶川・アピタ桶川店');
ok($zip->set_number('3638558')->is_valid_number, 'ザイロ 株式会社 関東物流センター');
ok($zip->set_number('3638601')->is_valid_number, '三国・コカコーラボトリング 株式会社');
ok($zip->set_number('3648501')->is_valid_number, '北里研究所 メディカルセンター病院');
ok($zip->set_number('3648511')->is_valid_number, '富士重工業 株式会社 埼玉製作所');
ok($zip->set_number('3648555')->is_valid_number, 'コマツ埼玉 株式会社');
ok($zip->set_number('3648585')->is_valid_number, '株式会社 エーアンド・デイ');
ok($zip->set_number('3648633')->is_valid_number, '北本市役所');
ok($zip->set_number('3658501')->is_valid_number, '運転免許センター');
ok($zip->set_number('3658502')->is_valid_number, '鴻巣市 川里支所');
ok($zip->set_number('3658503')->is_valid_number, '(株) イングコーポレーション');
ok($zip->set_number('3658505')->is_valid_number, 'イセデリカ 株式会社 鴻巣工場');
ok($zip->set_number('3658506')->is_valid_number, '野崎印刷紙業 株式会社 関東工場');
ok($zip->set_number('3658508')->is_valid_number, 'アサヒ紙工 株式会社');
ok($zip->set_number('3658512')->is_valid_number, '済生会鴻巣病院');
ok($zip->set_number('3658514')->is_valid_number, '(株) 広田屋');
ok($zip->set_number('3658585')->is_valid_number, '株式会社 保健科学 東日本');
ok($zip->set_number('3658601')->is_valid_number, '鴻巣市役所');
ok($zip->set_number('3658603')->is_valid_number, '中央化学 株式会社');
ok($zip->set_number('3668501')->is_valid_number, '深谷市役所');
ok($zip->set_number('3668502')->is_valid_number, '赤城乳業 株式会社');
ok($zip->set_number('3668510')->is_valid_number, '株式会社 東芝 深谷工場');
ok($zip->set_number('3668511')->is_valid_number, '株式会社 UACJ 深谷製造所');
ok($zip->set_number('3668515')->is_valid_number, '埼玉県立 深谷高等学校');
ok($zip->set_number('3668521')->is_valid_number, '日東電工 株式会社 関東事業所');
ok($zip->set_number('3668567')->is_valid_number, '株式会社 セキネ');
ok($zip->set_number('3668581')->is_valid_number, '三矢精工 株式会社');
ok($zip->set_number('3670192')->is_valid_number, 'キヤノン電子 株式会社 美里工場');
ok($zip->set_number('3670194')->is_valid_number, '美里町役場');
ok($zip->set_number('3670198')->is_valid_number, 'エーザイ 株式会社 美里工場');
ok($zip->set_number('3670198')->is_valid_number, '武州製薬 株式会社 美里工場');
ok($zip->set_number('3670292')->is_valid_number, '神川町役場');
ok($zip->set_number('3670296')->is_valid_number, '大鵬薬品工業 株式会社 児玉倉庫');
ok($zip->set_number('3670297')->is_valid_number, '埼玉日本電気 株式会社');
ok($zip->set_number('3670298')->is_valid_number, '本庄市 児玉総合支所');
ok($zip->set_number('3670393')->is_valid_number, '神川町神泉総合支所');
ok($zip->set_number('3678501')->is_valid_number, '本庄市役所');
ok($zip->set_number('3678686')->is_valid_number, '沖電気工業 株式会社');
ok($zip->set_number('3680192')->is_valid_number, '小鹿野町役場');
ok($zip->set_number('3680193')->is_valid_number, '株式会社 秩父富士');
ok($zip->set_number('3680195')->is_valid_number, '株式会社 秩父富士 長若工場');
ok($zip->set_number('3680292')->is_valid_number, '小鹿野町役場 両神庁舎');
ok($zip->set_number('3688501')->is_valid_number, '三菱マテリアル 株式会社 横瀬工場');
ok($zip->set_number('3688502')->is_valid_number, '三菱マテリアル 株式会社 セラミックス工場');
ok($zip->set_number('3688505')->is_valid_number, '菱光石灰工業 株式会社 生川事業所');
ok($zip->set_number('3688666')->is_valid_number, '秩父税務署');
ok($zip->set_number('3688680')->is_valid_number, '株式会社 矢尾百貨店');
ok($zip->set_number('3688686')->is_valid_number, '秩父市役所');
ok($zip->set_number('3690192')->is_valid_number, '富士電機機器制御 株式会社 吹上事業所');
ok($zip->set_number('3690195')->is_valid_number, '鴻巣市 吹上支所');
ok($zip->set_number('3690198')->is_valid_number, '富士電機 株式会社 生産技術センター 埼玉地区');
ok($zip->set_number('3690292')->is_valid_number, '深谷市 岡部総合支所');
ok($zip->set_number('3690293')->is_valid_number, '埼玉工業大学');
ok($zip->set_number('3690295')->is_valid_number, 'リケンテクノス 株式会社');
ok($zip->set_number('3690297')->is_valid_number, '日立化成 株式会社 埼玉事業所');
ok($zip->set_number('3690392')->is_valid_number, '上里町役場');
ok($zip->set_number('3690393')->is_valid_number, 'キヤノン・コンポーネンツ 株式会社');
ok($zip->set_number('3690395')->is_valid_number, '株式会社 日立ハイテクファインシステムズ');
ok($zip->set_number('3691192')->is_valid_number, '深谷市 川本総合支所');
ok($zip->set_number('3691193')->is_valid_number, 'KYB 株式会社 熊谷工場');
ok($zip->set_number('3691195')->is_valid_number, '米久デリカ 株式会社');
ok($zip->set_number('3691292')->is_valid_number, '寄居町役場');
ok($zip->set_number('3691293')->is_valid_number, '深谷市 花園総合支所');
ok($zip->set_number('3691295')->is_valid_number, '三菱電機ホーム機器 (株)');
ok($zip->set_number('3691298')->is_valid_number, '株式会社 ベルク');
ok($zip->set_number('3691392')->is_valid_number, '長瀞町役場');
ok($zip->set_number('3691492')->is_valid_number, '皆野町役場');
ok($zip->set_number('3691592')->is_valid_number, '秩父市役所 吉田総合支所');
ok($zip->set_number('3691593')->is_valid_number, '株式会社 タイセー');
ok($zip->set_number('3691596')->is_valid_number, '株式会社 善山JAPAN ユニオンエースゴルフクラブ ホテルユニオンヴェール');
ok($zip->set_number('3691892')->is_valid_number, 'キヤノン電子 株式会社 本社影森工場');
ok($zip->set_number('3691893')->is_valid_number, '昭和電工 株式会社 秩父工場');
ok($zip->set_number('3691894')->is_valid_number, '秩父市役所 荒川総合支所');
ok($zip->set_number('3691895')->is_valid_number, '株式会社 ウッディーコイケ');
ok($zip->set_number('3691998')->is_valid_number, '秩父市役所 大滝総合支所');
ok($zip->set_number('3700193')->is_valid_number, '株式会社 日本アクセス 群馬支店');
ok($zip->set_number('3700492')->is_valid_number, '三菱電機 株式会社 群馬製作所');
ok($zip->set_number('3700495')->is_valid_number, '太田市尾島総合支所');
ok($zip->set_number('3700595')->is_valid_number, '大泉町役場');
ok($zip->set_number('3700596')->is_valid_number, '三洋電機 株式会社');
ok($zip->set_number('3700598')->is_valid_number, '千代田町役場');
ok($zip->set_number('3700692')->is_valid_number, '邑楽町役場');
ok($zip->set_number('3700795')->is_valid_number, '明和町役場');
ok($zip->set_number('3701192')->is_valid_number, '玉村町役場');
ok($zip->set_number('3701193')->is_valid_number, '群馬県立女子大学');
ok($zip->set_number('3701195')->is_valid_number, '王子チヨダコンテナー 株式会社 高崎工場');
ok($zip->set_number('3701196')->is_valid_number, '太陽誘電 (株) 玉村工場');
ok($zip->set_number('3701292')->is_valid_number, '(独) 日本原子力研究開発機構 高崎量子応用研究所');
ok($zip->set_number('3701293')->is_valid_number, '群馬県立 近代美術館');
ok($zip->set_number('3701392')->is_valid_number, '高崎市 新町支所');
ok($zip->set_number('3701393')->is_valid_number, '学校法人 学文館法人本部 上武大学');
ok($zip->set_number('3701394')->is_valid_number, '陸上自衛隊 新町駐屯地');
ok($zip->set_number('3701395')->is_valid_number, 'カネボウフーズ 株式会社 新町工場');
ok($zip->set_number('3701396')->is_valid_number, '加ト吉水産 株式会社 フーズ部 群馬工場');
ok($zip->set_number('3701592')->is_valid_number, '神流町役場');
ok($zip->set_number('3702192')->is_valid_number, '高崎市 吉井支所');
ok($zip->set_number('3702292')->is_valid_number, '甘楽町役場');
ok($zip->set_number('3702392')->is_valid_number, '富岡市役所');
ok($zip->set_number('3702393')->is_valid_number, '公立富岡総合病院');
ok($zip->set_number('3702395')->is_valid_number, 'しののめ信用金庫');
ok($zip->set_number('3702396')->is_valid_number, '甘楽富岡農業 協同組合');
ok($zip->set_number('3702398')->is_valid_number, '株式会社 IHIエアロスペース 富岡事業所');
ok($zip->set_number('3702495')->is_valid_number, '株式会社 ヨコオ');
ok($zip->set_number('3702498')->is_valid_number, '株式会社 マンナンライフ');
ok($zip->set_number('3702498')->is_valid_number, '鶴田食品工業 株式会社');
ok($zip->set_number('3703192')->is_valid_number, '高崎市 箕郷支所');
ok($zip->set_number('3703392')->is_valid_number, '高崎市 榛名支所');
ok($zip->set_number('3703393')->is_valid_number, '社会福祉法人 新生会');
ok($zip->set_number('3703492')->is_valid_number, '高崎市 倉渕支所');
ok($zip->set_number('3703592')->is_valid_number, '高崎市 群馬支所');
ok($zip->set_number('3703593')->is_valid_number, '榛東村役場');
ok($zip->set_number('3703594')->is_valid_number, '陸上自衛隊 相馬原駐屯地');
ok($zip->set_number('3703692')->is_valid_number, '吉岡町役場');
ok($zip->set_number('3708501')->is_valid_number, '高崎市役所');
ok($zip->set_number('3708511')->is_valid_number, '高崎商工会議所');
ok($zip->set_number('3708522')->is_valid_number, '太陽誘電 株式会社 江木工場');
ok($zip->set_number('3708531')->is_valid_number, '前橋地方裁判所 高崎支部 前橋家庭裁判所高崎支部 高崎簡易裁判所 高崎検察審査会');
ok($zip->set_number('3708537')->is_valid_number, '独立行政法人 国立病院機構 高崎病院');
ok($zip->set_number('3708543')->is_valid_number, '東日本旅客鉄道 株式会社 高崎支社');
ok($zip->set_number('3708550')->is_valid_number, '日本たばこ産業 株式会社 高崎支店');
ok($zip->set_number('3708555')->is_valid_number, '株式会社 スズラン 高崎店');
ok($zip->set_number('3708565')->is_valid_number, '株式会社 高崎高島屋');
ok($zip->set_number('3708585')->is_valid_number, '沖電気工業 株式会社 高崎地区');
ok($zip->set_number('3708601')->is_valid_number, '大和証券 株式会社 高崎支店');
ok($zip->set_number('3708611')->is_valid_number, '高崎 税務署');
ok($zip->set_number('3708622')->is_valid_number, '株式会社 群馬銀行 高崎支店');
ok($zip->set_number('3708666')->is_valid_number, '東日本電信電話 (株) 群馬支店');
ok($zip->set_number('3708668')->is_valid_number, '高崎信用金庫');
ok($zip->set_number('3708686')->is_valid_number, '株式会社 ベネッセコーポレーション');
ok($zip->set_number('3710192')->is_valid_number, '前橋市 富士見支所');
ok($zip->set_number('3710292')->is_valid_number, '前橋市 大胡支所');
ok($zip->set_number('3710293')->is_valid_number, '前橋市 粕川支所');
ok($zip->set_number('3710294')->is_valid_number, '前橋市 宮城支所');
ok($zip->set_number('3718501')->is_valid_number, '群馬県 前橋県税事務所');
ok($zip->set_number('3718502')->is_valid_number, '群馬県社会保険診療報酬支払基金');
ok($zip->set_number('3718503')->is_valid_number, 'カネコ種苗 株式会社');
ok($zip->set_number('3718504')->is_valid_number, '中央労働金庫 群馬県本部');
ok($zip->set_number('3718505')->is_valid_number, '群馬県 市町村職員共済組合');
ok($zip->set_number('3718507')->is_valid_number, '群馬県 自動車税事務所');
ok($zip->set_number('3718508')->is_valid_number, '関東森林管理局');
ok($zip->set_number('3718510')->is_valid_number, '群馬大学 事務局 学生部 附属図書館 教育学部 社会情報学部');
ok($zip->set_number('3718511')->is_valid_number, '群馬大学 医学部');
ok($zip->set_number('3718512')->is_valid_number, '群馬大学 生体調節研究所');
ok($zip->set_number('3718513')->is_valid_number, '群馬大学 総合情報メディアセンター図書館 医学分館');
ok($zip->set_number('3718514')->is_valid_number, '群馬大学大学院 保健学研究科');
ok($zip->set_number('3718515')->is_valid_number, '日新電機 株式会社 前橋製作所');
ok($zip->set_number('3718516')->is_valid_number, '全国健康保険協会 群馬支部');
ok($zip->set_number('3718517')->is_valid_number, '財団法人 群馬県長寿社会づくり財団');
ok($zip->set_number('3718520')->is_valid_number, '群馬振興 株式会社');
ok($zip->set_number('3718521')->is_valid_number, '朝日新聞前橋総局');
ok($zip->set_number('3718522')->is_valid_number, '群馬 トヨペット株式会社');
ok($zip->set_number('3718525')->is_valid_number, '群馬県社会福祉協議会');
ok($zip->set_number('3718527')->is_valid_number, '日本精工 株式会社 前橋プラント');
ok($zip->set_number('3718528')->is_valid_number, 'NSKステアリングシステムズ (株)');
ok($zip->set_number('3718530')->is_valid_number, '群馬工業高等専門学校');
ok($zip->set_number('3718531')->is_valid_number, '前橋地方裁判所');
ok($zip->set_number('3718533')->is_valid_number, '株式会社 エフエム群馬');
ok($zip->set_number('3718535')->is_valid_number, '前橋地方法務局');
ok($zip->set_number('3718539')->is_valid_number, '住友生命保険 相互会社 群馬支社');
ok($zip->set_number('3718543')->is_valid_number, '日本ビクター 株式会社');
ok($zip->set_number('3718548')->is_valid_number, '群馬テレビ 株式会社');
ok($zip->set_number('3718550')->is_valid_number, '前橋地方検察庁');
ok($zip->set_number('3718555')->is_valid_number, 'NHK 前橋放送局');
ok($zip->set_number('3718556')->is_valid_number, 'スズラン 前橋店');
ok($zip->set_number('3718557')->is_valid_number, 'スズラン 本社');
ok($zip->set_number('3718560')->is_valid_number, '株式会社 東和銀行 総務部');
ok($zip->set_number('3718561')->is_valid_number, '株式会社 東和銀行 営業部');
ok($zip->set_number('3718567')->is_valid_number, '群馬労働局');
ok($zip->set_number('3718570')->is_valid_number, '群馬県庁');
ok($zip->set_number('3718572')->is_valid_number, '株式会社 群銀カード');
ok($zip->set_number('3718573')->is_valid_number, '前橋清陵高等学校');
ok($zip->set_number('3718580')->is_valid_number, '群馬県警察本部');
ok($zip->set_number('3718585')->is_valid_number, '群馬県卸酒販 株式会社');
ok($zip->set_number('3718586')->is_valid_number, '日本電信電話 株式会社 前橋支店');
ok($zip->set_number('3718587')->is_valid_number, '関東信越国税局業務センター 前橋分室');
ok($zip->set_number('3718601')->is_valid_number, '前橋市役所');
ok($zip->set_number('3718611')->is_valid_number, '株式会社 群馬銀行');
ok($zip->set_number('3718616')->is_valid_number, '日本生命保険 相互会社 群馬支社');
ok($zip->set_number('3718617')->is_valid_number, '第一生命保険 株式会社 群馬支社');
ok($zip->set_number('3718620')->is_valid_number, '株式会社 足利銀行 前橋支店');
ok($zip->set_number('3718625')->is_valid_number, '株式会社 群馬銀行 堅町支店');
ok($zip->set_number('3718636')->is_valid_number, 'みずほ信託銀行 前橋支店');
ok($zip->set_number('3718640')->is_valid_number, '日本銀行 前橋支店');
ok($zip->set_number('3718666')->is_valid_number, '株式会社 上毛新聞社');
ok($zip->set_number('3718677')->is_valid_number, 'たむらや');
ok($zip->set_number('3718686')->is_valid_number, '前橋 税務署');
ok($zip->set_number('3718688')->is_valid_number, 'しののめ信用金庫 本店');
ok($zip->set_number('3728501')->is_valid_number, '伊勢崎市役所');
ok($zip->set_number('3728502')->is_valid_number, 'サンデン 株式会社');
ok($zip->set_number('3728508')->is_valid_number, '富士重工 株式会社');
ok($zip->set_number('3728510')->is_valid_number, 'トラスコ中山 株式会社 プラネット 北関東');
ok($zip->set_number('3728558')->is_valid_number, 'サンデン 株式会社 八斗島事業所');
ok($zip->set_number('3728567')->is_valid_number, '株式会社 パイロットコーポレーション 伊勢崎工場');
ok($zip->set_number('3728580')->is_valid_number, '株式会社 ベイシア流通技術研究所');
ok($zip->set_number('3728585')->is_valid_number, '明星電気 株式会社 伊勢崎工場');
ok($zip->set_number('3728588')->is_valid_number, '上武大学');
ok($zip->set_number('3728686')->is_valid_number, '伊勢崎 税務署');
ok($zip->set_number('3738501')->is_valid_number, '富士部品工業 株式会社');
ok($zip->set_number('3738505')->is_valid_number, 'モメンティブ・パフォーマンス・マテリアルズ・ジャパン 合同会社 太田事業所');
ok($zip->set_number('3738508')->is_valid_number, '群馬県東部県税事務所');
ok($zip->set_number('3738509')->is_valid_number, '群馬県東部行政事務所');
ok($zip->set_number('3738510')->is_valid_number, '坂本工業 株式会社 新島工場');
ok($zip->set_number('3738511')->is_valid_number, '県立太田女子高等学校');
ok($zip->set_number('3738512')->is_valid_number, '株式会社 栗原医療器械店 太田ディストリビューションセンター');
ok($zip->set_number('3738513')->is_valid_number, '太田福島総合病院');
ok($zip->set_number('3738515')->is_valid_number, '関東学園大学');
ok($zip->set_number('3738521')->is_valid_number, '太田商工会議所');
ok($zip->set_number('3738530')->is_valid_number, '石橋建設工業 株式会社');
ok($zip->set_number('3738531')->is_valid_number, '前橋地方裁判所 太田支部');
ok($zip->set_number('3738550')->is_valid_number, '群馬県立 がんセンター');
ok($zip->set_number('3738551')->is_valid_number, '丸幸 株式会社');
ok($zip->set_number('3738555')->is_valid_number, '富士重工 株式会社 群馬製作所本工場');
ok($zip->set_number('3738557')->is_valid_number, '株式会社 栗原医療器械店');
ok($zip->set_number('3738560')->is_valid_number, '双葉繊維工業 株式会社');
ok($zip->set_number('3738561')->is_valid_number, '株式会社 太田双葉カントリークラブ');
ok($zip->set_number('3738567')->is_valid_number, 'コムベックス 株式会社');
ok($zip->set_number('3738578')->is_valid_number, '株式会社 フジタコーポレーション');
ok($zip->set_number('3738585')->is_valid_number, '富士重工業健康保険組合 太田記念病院');
ok($zip->set_number('3738588')->is_valid_number, 'しげる工業 株式会社');
ok($zip->set_number('3738601')->is_valid_number, '医療法人 三省会 堀江病院');
ok($zip->set_number('3738610')->is_valid_number, '東京電力 株式会社 太田営業所');
ok($zip->set_number('3738611')->is_valid_number, '株式会社 群馬銀行 太田支店');
ok($zip->set_number('3738622')->is_valid_number, '坂本工業 株式会社 本社');
ok($zip->set_number('3738660')->is_valid_number, 'NECパーソナルプロダクツ 株式会社 群馬事業場');
ok($zip->set_number('3738666')->is_valid_number, '株式会社 アイリス');
ok($zip->set_number('3738668')->is_valid_number, '日本ミシュランタイヤ 株式会社 太田サイト');
ok($zip->set_number('3738680')->is_valid_number, '桐生信用金庫');
ok($zip->set_number('3738686')->is_valid_number, 'NTT 太田支店');
ok($zip->set_number('3738688')->is_valid_number, '日本生命保険 相互会社 太田支社');
ok($zip->set_number('3738718')->is_valid_number, '太田市役所');
ok($zip->set_number('3740192')->is_valid_number, '板倉町役場');
ok($zip->set_number('3740193')->is_valid_number, '東洋大学 板倉キャンパス');
ok($zip->set_number('3748501')->is_valid_number, '館林市役所');
ok($zip->set_number('3748510')->is_valid_number, '正田醤油 株式会社');
ok($zip->set_number('3748511')->is_valid_number, '株式会社 アルティア橋本 館林工場');
ok($zip->set_number('3748512')->is_valid_number, '株式会社 とりせん');
ok($zip->set_number('3748518')->is_valid_number, 'ニプロ医工 株式会社');
ok($zip->set_number('3748520')->is_valid_number, '正田醤油株式会社 館林工場');
ok($zip->set_number('3748533')->is_valid_number, '館林厚生病院');
ok($zip->set_number('3748555')->is_valid_number, '関東学園');
ok($zip->set_number('3748577')->is_valid_number, '株式会社 アルファ 群馬工場');
ok($zip->set_number('3748588')->is_valid_number, '株式会社 館林うどん');
ok($zip->set_number('3748601')->is_valid_number, '群馬銀行 館林支店');
ok($zip->set_number('3748608')->is_valid_number, '館林信用金庫');
ok($zip->set_number('3748611')->is_valid_number, '館林市農業協同組合');
ok($zip->set_number('3748622')->is_valid_number, '第一紙工 株式会社');
ok($zip->set_number('3748640')->is_valid_number, '館林商工会議所');
ok($zip->set_number('3748686')->is_valid_number, '館林 税務署');
ok($zip->set_number('3758501')->is_valid_number, '三菱鉛筆 株式会社 群馬工場');
ok($zip->set_number('3758502')->is_valid_number, 'ヨシモトポール 株式会社');
ok($zip->set_number('3758503')->is_valid_number, '公立 藤岡総合病院');
ok($zip->set_number('3758504')->is_valid_number, '藤岡高校');
ok($zip->set_number('3758505')->is_valid_number, '株式会社 チノー');
ok($zip->set_number('3758506')->is_valid_number, '藤岡商工会議所');
ok($zip->set_number('3758507')->is_valid_number, '美里工業 株式会社');
ok($zip->set_number('3758601')->is_valid_number, '藤岡市役所');
ok($zip->set_number('3758602')->is_valid_number, '藤岡 税務署');
ok($zip->set_number('3758603')->is_valid_number, '多野信用金庫');
ok($zip->set_number('3758604')->is_valid_number, '群馬銀行');
ok($zip->set_number('3760192')->is_valid_number, 'みどり市役所 大間々庁舎');
ok($zip->set_number('3760193')->is_valid_number, '星野物産 株式会社');
ok($zip->set_number('3760194')->is_valid_number, '桐生市役所 新里支所');
ok($zip->set_number('3760392')->is_valid_number, 'サンレイク草木');
ok($zip->set_number('3760397')->is_valid_number, 'みどり市役所 東庁舎');
ok($zip->set_number('3768501')->is_valid_number, '桐生市役所');
ok($zip->set_number('3768502')->is_valid_number, '株式会社 両毛システムズ');
ok($zip->set_number('3768510')->is_valid_number, '株式会社 長崎屋 桐生店');
ok($zip->set_number('3768515')->is_valid_number, '群馬大学 工学部');
ok($zip->set_number('3768516')->is_valid_number, '群馬大学 総合情報メディアセンター図書館工学部分館');
ok($zip->set_number('3768523')->is_valid_number, '生活協同組合 コープぐんま');
ok($zip->set_number('3768528')->is_valid_number, '株式会社 桐生タイムス社');
ok($zip->set_number('3768531')->is_valid_number, '前橋地裁 桐生支部');
ok($zip->set_number('3768555')->is_valid_number, '株式会社 ミツバ');
ok($zip->set_number('3768558')->is_valid_number, '有限会社 ウオチ産業');
ok($zip->set_number('3768585')->is_valid_number, '株式会社 山田製作所');
ok($zip->set_number('3768666')->is_valid_number, '株式会社 カネトモ');
ok($zip->set_number('3768668')->is_valid_number, '桐生信用金庫');
ok($zip->set_number('3768686')->is_valid_number, '桐生 税務署');
ok($zip->set_number('3770192')->is_valid_number, '渋川市 伊香保総合支所');
ok($zip->set_number('3770193')->is_valid_number, '株式会社 福一');
ok($zip->set_number('3770195')->is_valid_number, '株式会社 天坊');
ok($zip->set_number('3770280')->is_valid_number, '独立行政法人 国立病院機構 渋川医療センター');
ok($zip->set_number('3770292')->is_valid_number, '渋川市 子持総合支所');
ok($zip->set_number('3770293')->is_valid_number, '日本精密測器 株式会社');
ok($zip->set_number('3770294')->is_valid_number, '社会福祉法人 渋川市社会福祉協議会 子持支所');
ok($zip->set_number('3770392')->is_valid_number, '渋川市 小野上総合支所');
ok($zip->set_number('3770395')->is_valid_number, '東吾妻町役場 東支所');
ok($zip->set_number('3770492')->is_valid_number, '中之条税務署');
ok($zip->set_number('3770494')->is_valid_number, '中之条町役場');
ok($zip->set_number('3770792')->is_valid_number, '高山村役場');
ok($zip->set_number('3770882')->is_valid_number, '原町赤十字病院');
ok($zip->set_number('3770883')->is_valid_number, '池原工業 株式会社');
ok($zip->set_number('3770892')->is_valid_number, '東吾妻町役場');
ok($zip->set_number('3770893')->is_valid_number, 'あがつま農業協同組合');
ok($zip->set_number('3770894')->is_valid_number, '群馬県立 吾妻高等学校');
ok($zip->set_number('3770896')->is_valid_number, '南波建設 株式会社');
ok($zip->set_number('3770897')->is_valid_number, 'リンテック 株式会社 吾妻工場');
ok($zip->set_number('3770898')->is_valid_number, 'パナソニックエコソリューションズ朝日 株式会社');
ok($zip->set_number('3771392')->is_valid_number, '長野原町役場');
ok($zip->set_number('3771393')->is_valid_number, '群馬県立長野原高等学校');
ok($zip->set_number('3771395')->is_valid_number, '国土交通省関東地方建設局 八ツ場ダム工事事務所');
ok($zip->set_number('3771593')->is_valid_number, '鬼押出し園');
ok($zip->set_number('3771594')->is_valid_number, '嬬恋プリンスホテル 嬬恋高原ゴルフ場');
ok($zip->set_number('3771595')->is_valid_number, '万座プリンスホテル');
ok($zip->set_number('3771692')->is_valid_number, '嬬恋村役場');
ok($zip->set_number('3771693')->is_valid_number, 'JA 嬬恋村');
ok($zip->set_number('3771695')->is_valid_number, '休暇村鹿沢高原');
ok($zip->set_number('3771792')->is_valid_number, '草津町役場');
ok($zip->set_number('3771793')->is_valid_number, '株式会社 中沢ヴィレッジ');
ok($zip->set_number('3771794')->is_valid_number, '草津簡易保険保養センター');
ok($zip->set_number('3771795')->is_valid_number, '中之条町 六合支所');
ok($zip->set_number('3771796')->is_valid_number, '株式会社 ホテル一井');
ok($zip->set_number('3771797')->is_valid_number, '草津温泉旅館協同組合');
ok($zip->set_number('3778501')->is_valid_number, '渋川市役所');
ok($zip->set_number('3778502')->is_valid_number, '渋川市 北橘総合支所');
ok($zip->set_number('3778503')->is_valid_number, '太田物産 株式会社');
ok($zip->set_number('3778508')->is_valid_number, 'エクセルイン渋川');
ok($zip->set_number('3778510')->is_valid_number, '株式会社 小笠原');
ok($zip->set_number('3778511')->is_valid_number, '独立行政法人 国立病院機構 西群馬病院');
ok($zip->set_number('3778513')->is_valid_number, '関東電化工業 株式会社 渋川工場');
ok($zip->set_number('3778520')->is_valid_number, '電気化学工業 株式会社 渋川工場');
ok($zip->set_number('3778533')->is_valid_number, '株式会社 津久井工務店');
ok($zip->set_number('3778555')->is_valid_number, '財団法人 群馬県埋蔵文化財調査事業団');
ok($zip->set_number('3778567')->is_valid_number, '社会福祉法人 恵の園');
ok($zip->set_number('3778577')->is_valid_number, '群馬県立 小児医療センター');
ok($zip->set_number('3778585')->is_valid_number, '南澤建設 株式会社');
ok($zip->set_number('3778588')->is_valid_number, '日本年金機構 渋川年金事務所');
ok($zip->set_number('3778616')->is_valid_number, '北群馬信用金庫');
ok($zip->set_number('3780498')->is_valid_number, '片品村役場');
ok($zip->set_number('3788501')->is_valid_number, '沼田市役所');
ok($zip->set_number('3790192')->is_valid_number, '安中市役所');
ok($zip->set_number('3790193')->is_valid_number, '群馬県信用組合');
ok($zip->set_number('3790195')->is_valid_number, '信越化学工業 株式会社 群馬事業所');
ok($zip->set_number('3790196')->is_valid_number, '信越半導体 株式会社 磯部工場');
ok($zip->set_number('3790197')->is_valid_number, '東邦亜鉛 株式会社 安中製錬所');
ok($zip->set_number('3790292')->is_valid_number, '安中市役所 松井田支所');
ok($zip->set_number('3791192')->is_valid_number, '赤城総合支所');
ok($zip->set_number('3791297')->is_valid_number, 'キャノン電子 株式会社 赤城事業所');
ok($zip->set_number('3791298')->is_valid_number, '昭和村役場');
ok($zip->set_number('3791393')->is_valid_number, 'みなかみ町役場');
ok($zip->set_number('3791498')->is_valid_number, 'みなかみ町役場 新治支所');
ok($zip->set_number('3791692')->is_valid_number, 'みなかみ町役場 水上支所');
ok($zip->set_number('3792180')->is_valid_number, '株式会社 チヨダコーポレーション');
ok($zip->set_number('3792181')->is_valid_number, '群馬県赤十字血液センター');
ok($zip->set_number('3792184')->is_valid_number, '学校法人 山崎学園');
ok($zip->set_number('3792185')->is_valid_number, '共愛学園中学高等学校');
ok($zip->set_number('3792186')->is_valid_number, '共愛学園小学校');
ok($zip->set_number('3792187')->is_valid_number, '株式会社 ベイシア');
ok($zip->set_number('3792192')->is_valid_number, '共愛学園前橋国際大学');
ok($zip->set_number('3792193')->is_valid_number, 'ナイス 株式会社 前橋市場');
ok($zip->set_number('3792194')->is_valid_number, '社団法人 群馬県トラック協会');
ok($zip->set_number('3792195')->is_valid_number, 'マック食品 株式会社');
ok($zip->set_number('3792197')->is_valid_number, 'マチダコーポレーション 株式会社');
ok($zip->set_number('3792198')->is_valid_number, '株式会社 フレッセイ');
ok($zip->set_number('3792292')->is_valid_number, '伊勢崎市 あずま支所');
ok($zip->set_number('3792298')->is_valid_number, '伊勢崎市 赤堀支所');
ok($zip->set_number('3792392')->is_valid_number, '桐生短期大学');
ok($zip->set_number('3792395')->is_valid_number, 'みどり市役所 笠懸庁舎');
ok($zip->set_number('3792398')->is_valid_number, '関東開発 株式会社');
ok($zip->set_number('3808501')->is_valid_number, '善光寺大勧進');
ok($zip->set_number('3808502')->is_valid_number, 'NHK 長野放送局');
ok($zip->set_number('3808503')->is_valid_number, '株式会社 たちばな');
ok($zip->set_number('3808505')->is_valid_number, '大和ハウス工業 株式会社 長野支店');
ok($zip->set_number('3808506')->is_valid_number, '社団法人 長野県雇用開発協会');
ok($zip->set_number('3808507')->is_valid_number, '昭和電機産業 株式会社');
ok($zip->set_number('3808508')->is_valid_number, '東京海上日動火災保険 株式会社 長野支店');
ok($zip->set_number('3808510')->is_valid_number, '長野県警察本部');
ok($zip->set_number('3808511')->is_valid_number, 'NTT 年金医療保険センター');
ok($zip->set_number('3808512')->is_valid_number, '長野市役所');
ok($zip->set_number('3808515')->is_valid_number, '長野県長野高等学校');
ok($zip->set_number('3808516')->is_valid_number, '株式会社 丸乙 小林商店');
ok($zip->set_number('3808518')->is_valid_number, '株式会社 トーエネック長野支店');
ok($zip->set_number('3808519')->is_valid_number, 'NTT 長野支店');
ok($zip->set_number('3808520')->is_valid_number, '株式会社 林');
ok($zip->set_number('3808521')->is_valid_number, '信越放送 株式会社');
ok($zip->set_number('3808524')->is_valid_number, '北野建設 株式会社');
ok($zip->set_number('3808525')->is_valid_number, '公立大学法人 長野県立大学');
ok($zip->set_number('3808526')->is_valid_number, '日東都市開発 株式会社 長野事業所');
ok($zip->set_number('3808530')->is_valid_number, '長野県長野西高等学校');
ok($zip->set_number('3808531')->is_valid_number, '丸文商事 株式会社');
ok($zip->set_number('3808533')->is_valid_number, '株式会社 守谷商会');
ok($zip->set_number('3808534')->is_valid_number, '信州ジャスコ 株式会社 長野店');
ok($zip->set_number('3808535')->is_valid_number, '長野県 社会保険診療報酬支払基金');
ok($zip->set_number('3808536')->is_valid_number, '株式会社 NTTドコモ長野支店');
ok($zip->set_number('3808537')->is_valid_number, '東日本建設業保証 株式会社 長野支店');
ok($zip->set_number('3808538')->is_valid_number, '株式会社 帝国データバンク 長野支店');
ok($zip->set_number('3808539')->is_valid_number, '株式会社 ながの東急百貨店');
ok($zip->set_number('3808540')->is_valid_number, '株式会社 ケイシイシイ');
ok($zip->set_number('3808543')->is_valid_number, '長野ステーションビル 株式会社');
ok($zip->set_number('3808544')->is_valid_number, '信州大学 教育学部');
ok($zip->set_number('3808545')->is_valid_number, '財団法人 長野県労働会館');
ok($zip->set_number('3808546')->is_valid_number, '信濃毎日新聞 株式会社');
ok($zip->set_number('3808550')->is_valid_number, '長野朝日放送 株式会社');
ok($zip->set_number('3808551')->is_valid_number, '長野県酒類販売 株式会社');
ok($zip->set_number('3808552')->is_valid_number, '株式会社 夏目');
ok($zip->set_number('3808553')->is_valid_number, '信州大学 工学部');
ok($zip->set_number('3808555')->is_valid_number, '株式会社 テレビ信州');
ok($zip->set_number('3808557')->is_valid_number, '住友生命保険 相互会社 長野支社');
ok($zip->set_number('3808558')->is_valid_number, '日本信販 株式会社 長野支店');
ok($zip->set_number('3808560')->is_valid_number, 'マルナカ通商 株式会社');
ok($zip->set_number('3808561')->is_valid_number, '(株) YKKAP長野');
ok($zip->set_number('3808565')->is_valid_number, '株式会社 長野ダイハツモータース');
ok($zip->set_number('3808566')->is_valid_number, '第一法規出版 株式会社');
ok($zip->set_number('3808567')->is_valid_number, '社団法人 長野県林業センター');
ok($zip->set_number('3808568')->is_valid_number, '株式会社 長野バスターミナル');
ok($zip->set_number('3808570')->is_valid_number, '長野県庁');
ok($zip->set_number('3808572')->is_valid_number, '長野労働局');
ok($zip->set_number('3808573')->is_valid_number, '長野労働基準監督署');
ok($zip->set_number('3808575')->is_valid_number, '中部森林管理局');
ok($zip->set_number('3808576')->is_valid_number, '株式会社 エヌ・ティ・ティ・テレコムエンジニアリング 信越');
ok($zip->set_number('3808577')->is_valid_number, '株式会社 協同測量社');
ok($zip->set_number('3808580')->is_valid_number, '財団法人 郵政福祉 信越地方本部');
ok($zip->set_number('3808581')->is_valid_number, '株式会社 インテージテクノスフィア');
ok($zip->set_number('3808582')->is_valid_number, '長野赤十字病院');
ok($zip->set_number('3808583')->is_valid_number, '全国健康保険協会 長野支部');
ok($zip->set_number('3808584')->is_valid_number, 'メルパルク長野(メルパルクナガノ)');
ok($zip->set_number('3808585')->is_valid_number, '社団法人 長野県地域包括医療協議会');
ok($zip->set_number('3808586')->is_valid_number, '長野県 市町村職員共済組合');
ok($zip->set_number('3808588')->is_valid_number, '株式会社 シューマート');
ok($zip->set_number('3808589')->is_valid_number, '郵便局ビジネスサポート 株式会社 信越地方運用センター');
ok($zip->set_number('3808601')->is_valid_number, 'テルウェル東日本 株式会社 長野支店');
ok($zip->set_number('3808605')->is_valid_number, '丸小商事 株式会社');
ok($zip->set_number('3808608')->is_valid_number, '株式会社 越前屋');
ok($zip->set_number('3808610')->is_valid_number, 'カワイ 株式会社');
ok($zip->set_number('3808611')->is_valid_number, '長野県 労働金庫');
ok($zip->set_number('3808612')->is_valid_number, '長野税務署');
ok($zip->set_number('3808614')->is_valid_number, '全国農業協同組合連合会 長野県支部');
ok($zip->set_number('3808622')->is_valid_number, '株式会社 新建新聞社');
ok($zip->set_number('3808625')->is_valid_number, '株式会社 角藤');
ok($zip->set_number('3808630')->is_valid_number, '鹿島・北野建設共同企業体 長野県庁本館棟耐震改修建築工事事務所');
ok($zip->set_number('3808633')->is_valid_number, '株式会社 長野放送');
ok($zip->set_number('3808639')->is_valid_number, 'JA長野共済連');
ok($zip->set_number('3808640')->is_valid_number, '野村證券 株式会社 長野支店');
ok($zip->set_number('3808648')->is_valid_number, '第一生命保険 株式会社 長野支社');
ok($zip->set_number('3808655')->is_valid_number, '日本生命保険 相互会社 長野支社');
ok($zip->set_number('3808660')->is_valid_number, 'NTT信越情報システムセンター');
ok($zip->set_number('3808666')->is_valid_number, '中部電力 株式会社 長野支店');
ok($zip->set_number('3808668')->is_valid_number, '長野県 信用組合');
ok($zip->set_number('3808677')->is_valid_number, '日本年金機構 長野南年金事務所');
ok($zip->set_number('3808682')->is_valid_number, '株式会社 八十二銀行');
ok($zip->set_number('3808686')->is_valid_number, '長野信用金庫');
ok($zip->set_number('3808688')->is_valid_number, '東京法令出版 株式会社');
ok($zip->set_number('3808710')->is_valid_number, '全労済 長野県本部');
ok($zip->set_number('3808794')->is_valid_number, '長野貯金事務センター');
ok($zip->set_number('3808795')->is_valid_number, '信越総合通信局');
ok($zip->set_number('3808796')->is_valid_number, '信越監査室');
ok($zip->set_number('3808797')->is_valid_number, '株式会社 ゆうちょ銀行 長野支店');
ok($zip->set_number('3808797')->is_valid_number, '株式会社 かんぽ生命 長野支店');
ok($zip->set_number('3808797')->is_valid_number, '日本郵便 株式会社 信越支社');
ok($zip->set_number('3808798')->is_valid_number, '信越郵政研修センター');
ok($zip->set_number('3810192')->is_valid_number, '株式会社 丸水長野県水 長野支店');
ok($zip->set_number('3810193')->is_valid_number, '株式会社 TOSYS');
ok($zip->set_number('3810288')->is_valid_number, '株式会社 イマイ企画');
ok($zip->set_number('3810292')->is_valid_number, '株式会社 竹風堂');
ok($zip->set_number('3810293')->is_valid_number, '株式会社 小布施堂');
ok($zip->set_number('3810295')->is_valid_number, '新生病院');
ok($zip->set_number('3810296')->is_valid_number, '株式会社 永井工業所');
ok($zip->set_number('3810297')->is_valid_number, '小布施町役場');
ok($zip->set_number('3810298')->is_valid_number, '桜井甘精堂');
ok($zip->set_number('3810497')->is_valid_number, '志賀高原プリンスホテル');
ok($zip->set_number('3810498')->is_valid_number, '山ノ内町役場');
ok($zip->set_number('3812280')->is_valid_number, '株式会社 シューマート');
ok($zip->set_number('3812281')->is_valid_number, '株式会社 マルイチ産商');
ok($zip->set_number('3812282')->is_valid_number, '長野愛知電機 株式会社');
ok($zip->set_number('3812283')->is_valid_number, 'ミヤマ 株式会社');
ok($zip->set_number('3812285')->is_valid_number, '長野日野自動車 株式会社');
ok($zip->set_number('3812286')->is_valid_number, '株式会社 丸水長野県水');
ok($zip->set_number('3812287')->is_valid_number, '新光電気工業 株式会社');
ok($zip->set_number('3812288')->is_valid_number, '長野日本無線 株式会社');
ok($zip->set_number('3812289')->is_valid_number, '日本無線 株式会社 長野事業所');
ok($zip->set_number('3812292')->is_valid_number, '株式会社 エス・エス・ブイ');
ok($zip->set_number('3812295')->is_valid_number, 'セラテックジャパン (株)');
ok($zip->set_number('3812298')->is_valid_number, '財団法人 長野県健康づくり事業団');
ok($zip->set_number('3814192')->is_valid_number, '長野市役所 戸隠支所');
ok($zip->set_number('3814193')->is_valid_number, '株式会社 おびなた');
ok($zip->set_number('3814393')->is_valid_number, '有限会社 いろは堂');
ok($zip->set_number('3818501')->is_valid_number, '富士通 株式会社 長野工場');
ok($zip->set_number('3818503')->is_valid_number, '新潟運輸局 長野陸運支局');
ok($zip->set_number('3818508')->is_valid_number, '株式会社 デジタル・ラボラトリー');
ok($zip->set_number('3818510')->is_valid_number, '一般社団法人 長野県自動車整備振興会');
ok($zip->set_number('3818511')->is_valid_number, '蔦友印刷 株式会社');
ok($zip->set_number('3818515')->is_valid_number, '大和ハウス工業 株式会社 長野支店');
ok($zip->set_number('3818520')->is_valid_number, '株式会社 シンエイハイテック');
ok($zip->set_number('3818525')->is_valid_number, '株式会社 デンセン');
ok($zip->set_number('3818530')->is_valid_number, '麻場産業 株式会社');
ok($zip->set_number('3818539')->is_valid_number, '松田産業 株式会社');
ok($zip->set_number('3818545')->is_valid_number, '株式会社 クリエイティブヨーコ');
ok($zip->set_number('3818548')->is_valid_number, '株式会社 TOSYS');
ok($zip->set_number('3818550')->is_valid_number, '長野工業高等専門学校');
ok($zip->set_number('3818551')->is_valid_number, '長野市民病院');
ok($zip->set_number('3818556')->is_valid_number, '長野県 トラック会館');
ok($zip->set_number('3818558')->is_valid_number, '長野北社会保険事務所');
ok($zip->set_number('3818560')->is_valid_number, '岡谷酸素 株式会社 長野事業部');
ok($zip->set_number('3818567')->is_valid_number, '国立療養所 東長野病院');
ok($zip->set_number('3818570')->is_valid_number, '長野県立 長野吉田高校');
ok($zip->set_number('3818577')->is_valid_number, '長野県 身体障害者リハビリテーションセンター');
ok($zip->set_number('3818580')->is_valid_number, '社会福祉法人 長野若槻園');
ok($zip->set_number('3818588')->is_valid_number, '株式会社 本久');
ok($zip->set_number('3818602')->is_valid_number, '富国物産 株式会社');
ok($zip->set_number('3818686')->is_valid_number, '株式会社 角藤');
ok($zip->set_number('3818793')->is_valid_number, '日本郵便 株式会社 信越支社 郵便事業本部 (三種)');
ok($zip->set_number('3828501')->is_valid_number, '富士通 株式会社 須坂工場');
ok($zip->set_number('3828502')->is_valid_number, 'オリオン機械 株式会社');
ok($zip->set_number('3828505')->is_valid_number, '須坂市学校給食センター');
ok($zip->set_number('3828508')->is_valid_number, 'アスザック 株式会社');
ok($zip->set_number('3828510')->is_valid_number, '高山村役場');
ok($zip->set_number('3828511')->is_valid_number, '須坂市役所');
ok($zip->set_number('3828512')->is_valid_number, '須高行政事務組合');
ok($zip->set_number('3828533')->is_valid_number, '株式会社 サンジュニア');
ok($zip->set_number('3828555')->is_valid_number, '株式会社 前田鉄工所');
ok($zip->set_number('3828577')->is_valid_number, '長野県立信州医療センター');
ok($zip->set_number('3828585')->is_valid_number, '北陸コカ・コーラボトリング 株式会社');
ok($zip->set_number('3828587')->is_valid_number, 'ながの農業協同組合 須坂支所');
ok($zip->set_number('3828588')->is_valid_number, '株式会社 鈴木');
ok($zip->set_number('3828633')->is_valid_number, '長野刑務所');
ok($zip->set_number('3838501')->is_valid_number, '有限会社 小林果樹園');
ok($zip->set_number('3838505')->is_valid_number, 'JA 長野厚生連 北信総合病院');
ok($zip->set_number('3838511')->is_valid_number, '長野県 中野西高等学校');
ok($zip->set_number('3838515')->is_valid_number, '長野県 北信合同庁舎');
ok($zip->set_number('3838555')->is_valid_number, '株式会社 コシナ');
ok($zip->set_number('3838567')->is_valid_number, '長野県 中野立志館高等学校');
ok($zip->set_number('3838581')->is_valid_number, '新光電気工業 株式会社 高丘工場');
ok($zip->set_number('3838585')->is_valid_number, '株式会社 タカギセイコー');
ok($zip->set_number('3838588')->is_valid_number, '中野市農業協同組合');
ok($zip->set_number('3838614')->is_valid_number, '中野市役所');
ok($zip->set_number('3838686')->is_valid_number, '信濃中野税務署');
ok($zip->set_number('3840393')->is_valid_number, '長野県厚生農業協同組合連合会 佐久総合病院');
ok($zip->set_number('3840692')->is_valid_number, '株式会社 八十二銀行 佐久穂支店');
ok($zip->set_number('3840695')->is_valid_number, '南佐久農業協同組合');
ok($zip->set_number('3840697')->is_valid_number, '佐久穂町役場 佐久庁舎');
ok($zip->set_number('3840698')->is_valid_number, '佐久穂町立 千曲病院');
ok($zip->set_number('3840798')->is_valid_number, '佐久穂町役場 八千穂庁舎');
ok($zip->set_number('3841192')->is_valid_number, '小海町役場');
ok($zip->set_number('3842292')->is_valid_number, '川西赤十字病院');
ok($zip->set_number('3848501')->is_valid_number, '小諸市役所');
ok($zip->set_number('3848511')->is_valid_number, '株式会社 小諸村田製作所');
ok($zip->set_number('3848558')->is_valid_number, '中棚温泉 中棚荘');
ok($zip->set_number('3848585')->is_valid_number, '日精エー・エス・ビー機械 株式会社');
ok($zip->set_number('3848588')->is_valid_number, '長野県厚生農業協同組合連合会 浅間南麓こもろ医療センター');
ok($zip->set_number('3848605')->is_valid_number, '小諸社会保険事務所');
ok($zip->set_number('3858501')->is_valid_number, '佐久市役所');
ok($zip->set_number('3858511')->is_valid_number, '樫山工業 株式会社');
ok($zip->set_number('3858522')->is_valid_number, 'イオン 佐久平店');
ok($zip->set_number('3858533')->is_valid_number, '佐久地方事務所');
ok($zip->set_number('3858555')->is_valid_number, 'TDK株式会社 浅間テクノ工場');
ok($zip->set_number('3858558')->is_valid_number, '佐久市立国保 浅間総合病院');
ok($zip->set_number('3858585')->is_valid_number, 'JA 佐久浅間');
ok($zip->set_number('3858586')->is_valid_number, 'ツガミ 株式会社 信州工場');
ok($zip->set_number('3858588')->is_valid_number, '佐久長聖高等学校');
ok($zip->set_number('3858601')->is_valid_number, 'TDK 株式会社 千曲川テクノ工場');
ok($zip->set_number('3858611')->is_valid_number, '佐久税務署');
ok($zip->set_number('3858686')->is_valid_number, 'シチズン時計マニュファクチャリング 株式会社 ミヨタ佐久工場');
ok($zip->set_number('3860192')->is_valid_number, '株式会社 TOTOKU');
ok($zip->set_number('3860393')->is_valid_number, '三才山病院');
ok($zip->set_number('3860396')->is_valid_number, '鹿教湯病院');
ok($zip->set_number('3860492')->is_valid_number, '上田市役所 丸子地域自治センター');
ok($zip->set_number('3860493')->is_valid_number, '医療法人 丸山会 丸子中央総合病院');
ok($zip->set_number('3860495')->is_valid_number, '日本電産セイミツ 株式会社');
ok($zip->set_number('3860497')->is_valid_number, '松山 株式会社');
ok($zip->set_number('3860498')->is_valid_number, 'シナノケンシ 株式会社');
ok($zip->set_number('3860592')->is_valid_number, '武石地域自治センター');
ok($zip->set_number('3861192')->is_valid_number, '日置電機 株式会社');
ok($zip->set_number('3861193')->is_valid_number, 'カネテック 株式会社');
ok($zip->set_number('3861298')->is_valid_number, '長野大学');
ok($zip->set_number('3862292')->is_valid_number, '上田市役所 真田地域自治センター');
ok($zip->set_number('3868501')->is_valid_number, '長野計器 株式会社');
ok($zip->set_number('3868505')->is_valid_number, '日信工業 株式会社');
ok($zip->set_number('3868510')->is_valid_number, '医療法人 健静会 上田病院');
ok($zip->set_number('3868511')->is_valid_number, '上田警察署');
ok($zip->set_number('3868522')->is_valid_number, '上田商工会議所');
ok($zip->set_number('3868543')->is_valid_number, '医療法人 慈善会 安藤病院');
ok($zip->set_number('3868551')->is_valid_number, '株式会社 新村');
ok($zip->set_number('3868553')->is_valid_number, '鍋林 株式会社 上田支店');
ok($zip->set_number('3868555')->is_valid_number, '長野県 上田合同庁舎');
ok($zip->set_number('3868567')->is_valid_number, '信州大学 繊維学部');
ok($zip->set_number('3868577')->is_valid_number, '上田交通 株式会社');
ok($zip->set_number('3868584')->is_valid_number, '医療法人 友愛会 千曲荘病院');
ok($zip->set_number('3868585')->is_valid_number, '長野県 上田千曲高等学校');
ok($zip->set_number('3868588')->is_valid_number, '永井プラスチック工業 株式会社');
ok($zip->set_number('3868601')->is_valid_number, '上田市役所');
ok($zip->set_number('3868608')->is_valid_number, '上田日本無線 株式会社');
ok($zip->set_number('3868609')->is_valid_number, 'ハローワーク上田(上田公共職業安定所)');
ok($zip->set_number('3868610')->is_valid_number, '独立行政法人 国立病院機構 信州上田医療センター');
ok($zip->set_number('3868611')->is_valid_number, '笠原工業 株式会社 上田工場');
ok($zip->set_number('3868624')->is_valid_number, '上田西高等学校');
ok($zip->set_number('3868634')->is_valid_number, '山洋電気 株式会社 上田事業所 神川工場');
ok($zip->set_number('3868638')->is_valid_number, '株式会社 三葉製作所');
ok($zip->set_number('3868666')->is_valid_number, 'シンワアドヴァンス 株式会社');
ok($zip->set_number('3868668')->is_valid_number, '信州うえだ 農業協同組合');
ok($zip->set_number('3868683')->is_valid_number, '長野県 上田東高等学校');
ok($zip->set_number('3868685')->is_valid_number, '長野県 上田染谷丘高等学校');
ok($zip->set_number('3868686')->is_valid_number, '信州ハム 株式会社');
ok($zip->set_number('3868688')->is_valid_number, '長野県厚生農業協同組合連合会 鹿教湯三才山リハビリテーションセンター 介護療養型老人保健施設いずみの');
ok($zip->set_number('3868705')->is_valid_number, '中部電力パワーグリッド 株式会社 上田営業所');
ok($zip->set_number('3868710')->is_valid_number, '株式会社 八十二銀行 上田支店');
ok($zip->set_number('3868715')->is_valid_number, '長野県 上田高等学校');
ok($zip->set_number('3868720')->is_valid_number, '上田税務署');
ok($zip->set_number('3878501')->is_valid_number, '長野県 屋代高等学校');
ok($zip->set_number('3878502')->is_valid_number, '長野県 屋代南高等学校');
ok($zip->set_number('3878503')->is_valid_number, '株式会社 菱食 長野支店');
ok($zip->set_number('3878511')->is_valid_number, '千曲市役所');
ok($zip->set_number('3878512')->is_valid_number, '更埴中央病院');
ok($zip->set_number('3878521')->is_valid_number, 'ちくま農業協同組合');
ok($zip->set_number('3878555')->is_valid_number, '長野電子工業 株式会社');
ok($zip->set_number('3878561')->is_valid_number, '長野工業 株式会社');
ok($zip->set_number('3878585')->is_valid_number, '丸善食品工業 株式会社');
ok($zip->set_number('3878601')->is_valid_number, 'フレックスジャパン 株式会社');
ok($zip->set_number('3878603')->is_valid_number, 'エムケー精工 株式会社');
ok($zip->set_number('3888511')->is_valid_number, 'JAグリーン長野');
ok($zip->set_number('3888522')->is_valid_number, '株式会社 前田製作所');
ok($zip->set_number('3888555')->is_valid_number, 'コープながの');
ok($zip->set_number('3890192')->is_valid_number, '軽井沢町役場');
ok($zip->set_number('3890193')->is_valid_number, '軽井沢プリンスホテル');
ok($zip->set_number('3890194')->is_valid_number, '株式会社 星野リゾート');
ok($zip->set_number('3890195')->is_valid_number, 'ホテルブレストンコート');
ok($zip->set_number('3890196')->is_valid_number, '塩壺温泉ホテル');
ok($zip->set_number('3890197')->is_valid_number, '軽井沢72ゴルフ');
ok($zip->set_number('3890198')->is_valid_number, '軽井沢千ヶ滝温泉ホテル');
ok($zip->set_number('3890292')->is_valid_number, '御代田町役場');
ok($zip->set_number('3890293')->is_valid_number, 'ミネベア 株式会社 軽井沢工場');
ok($zip->set_number('3890295')->is_valid_number, 'シチズンファインデバイス 株式会社 御代田事業所');
ok($zip->set_number('3890296')->is_valid_number, 'ミネベアモータ 株式会社 軽井沢事業所');
ok($zip->set_number('3890298')->is_valid_number, 'シチズン時計ミヨタ 株式会社');
ok($zip->set_number('3890592')->is_valid_number, '東御市役所');
ok($zip->set_number('3890593')->is_valid_number, '株式会社 アヅマ');
ok($zip->set_number('3890598')->is_valid_number, '永井農場');
ok($zip->set_number('3890681')->is_valid_number, '(株) 都築製作所');
ok($zip->set_number('3890682')->is_valid_number, 'ミヤリサン (株)');
ok($zip->set_number('3890688')->is_valid_number, 'KYB-YS 株式会社');
ok($zip->set_number('3890692')->is_valid_number, '坂城町役場');
ok($zip->set_number('3890693')->is_valid_number, '日精樹脂工業 (株)');
ok($zip->set_number('3890695')->is_valid_number, '(株) 栗林製作所');
ok($zip->set_number('3890696')->is_valid_number, 'デイリーフーズ (株)');
ok($zip->set_number('3890697')->is_valid_number, '寿製薬 株式会社');
ok($zip->set_number('3890698')->is_valid_number, '(株) アルプスツール');
ok($zip->set_number('3890892')->is_valid_number, '千曲市役所 戸倉庁舎');
ok($zip->set_number('3890893')->is_valid_number, '株式会社 宮下商店');
ok($zip->set_number('3890897')->is_valid_number, '千曲市役所 上山田庁舎');
ok($zip->set_number('3890898')->is_valid_number, 'アピックヤマダ 株式会社');
ok($zip->set_number('3891192')->is_valid_number, '長野市役所 豊野支所');
ok($zip->set_number('3891195')->is_valid_number, '鳥居化成 株式会社');
ok($zip->set_number('3891196')->is_valid_number, '仁科工業 株式会社');
ok($zip->set_number('3891293')->is_valid_number, '飯綱町役場');
ok($zip->set_number('3891392')->is_valid_number, '信濃町役場');
ok($zip->set_number('3892192')->is_valid_number, '中野市役所 豊田支所');
ok($zip->set_number('3892292')->is_valid_number, '飯山市役所');
ok($zip->set_number('3892298')->is_valid_number, '株式会社 しなの富士通');
ok($zip->set_number('3892392')->is_valid_number, '木島平村役場');
ok($zip->set_number('3892592')->is_valid_number, '野沢温泉村役場');
ok($zip->set_number('3892792')->is_valid_number, '栄村役場');
ok($zip->set_number('3901181')->is_valid_number, '株式会社 アップルランド');
ok($zip->set_number('3901182')->is_valid_number, '松本養護学校');
ok($zip->set_number('3901183')->is_valid_number, '片倉機器工業 株式会社');
ok($zip->set_number('3901185')->is_valid_number, '松築 株式会社');
ok($zip->set_number('3901186')->is_valid_number, '株式会社 マルイチ産商 松本支店');
ok($zip->set_number('3901187')->is_valid_number, '株式会社 エフケーケー');
ok($zip->set_number('3901188')->is_valid_number, '朝日村役場');
ok($zip->set_number('3901189')->is_valid_number, 'エヌシーシー 株式会社 松本支店');
ok($zip->set_number('3901193')->is_valid_number, '松本ハイランド農協 朝日支所');
ok($zip->set_number('3901197')->is_valid_number, '長野三菱ふそう自動車販売 株式会社 松本支店');
ok($zip->set_number('3901198')->is_valid_number, '株式会社 ワールドインダストリー松本技術研究所');
ok($zip->set_number('3901293')->is_valid_number, 'キッセイコムテック 株式会社');
ok($zip->set_number('3901295')->is_valid_number, '松本大学');
ok($zip->set_number('3901295')->is_valid_number, '松本大学 松商短期大学部');
ok($zip->set_number('3901298')->is_valid_number, '東洋計器 株式会社');
ok($zip->set_number('3901392')->is_valid_number, '山形村役場');
ok($zip->set_number('3901393')->is_valid_number, 'サンリン 株式会社');
ok($zip->set_number('3901394')->is_valid_number, 'アイシティー21 株式会社 井上');
ok($zip->set_number('3901492')->is_valid_number, '松本市役所 波田支所');
ok($zip->set_number('3901592')->is_valid_number, '松本市役所 安曇支所');
ok($zip->set_number('3901792')->is_valid_number, '松本市役所 梓川支所');
ok($zip->set_number('3908501')->is_valid_number, '岡野薬品 株式会社');
ok($zip->set_number('3908502')->is_valid_number, 'NHK 松本支局');
ok($zip->set_number('3908503')->is_valid_number, '松本商工会議所');
ok($zip->set_number('3908505')->is_valid_number, '松本協立病院');
ok($zip->set_number('3908506')->is_valid_number, '中部電力パワーグリッド 株式会社 松本営業所');
ok($zip->set_number('3908507')->is_valid_number, '株式会社 井上');
ok($zip->set_number('3908508')->is_valid_number, '陸上自衛隊 松本駐屯地');
ok($zip->set_number('3908510')->is_valid_number, '特定医療法人 慈泉会 (財団) 相沢病院');
ok($zip->set_number('3908511')->is_valid_number, '社団法人 才能教育研究会');
ok($zip->set_number('3908515')->is_valid_number, '松商学園高等学校');
ok($zip->set_number('3908518')->is_valid_number, 'アルピコ交通 株式会社');
ok($zip->set_number('3908520')->is_valid_number, '長野エフエム放送 株式会社');
ok($zip->set_number('3908523')->is_valid_number, '松本日産自動車 株式会社');
ok($zip->set_number('3908525')->is_valid_number, '長野県松本工業高等学校');
ok($zip->set_number('3908528')->is_valid_number, 'イオンリテール 株式会社 北陸信越カンパニー 長野事業部 松本事務所');
ok($zip->set_number('3908530')->is_valid_number, 'シンケン 株式会社');
ok($zip->set_number('3908531')->is_valid_number, '長野県 松本筑摩高等学校');
ok($zip->set_number('3908533')->is_valid_number, 'トヨタカローラ南信 株式会社');
ok($zip->set_number('3908535')->is_valid_number, '国民生活金融公庫');
ok($zip->set_number('3908539')->is_valid_number, '(株) 市民タイムス');
ok($zip->set_number('3908540')->is_valid_number, 'TIS 株式会社');
ok($zip->set_number('3908541')->is_valid_number, 'ハナ信用組合 松本支店');
ok($zip->set_number('3908543')->is_valid_number, '長野県松本県ケ丘高等学校');
ok($zip->set_number('3908550')->is_valid_number, 'エフエムまつもと 株式会社');
ok($zip->set_number('3908555')->is_valid_number, '松本ハイランド農協');
ok($zip->set_number('3908560')->is_valid_number, 'イオンモール松本 晴庭・空庭');
ok($zip->set_number('3908565')->is_valid_number, '一般社団法人 長野県サッカー協会');
ok($zip->set_number('3908585')->is_valid_number, '信濃毎日新聞社 松本本社(信毎メディアガーデン)');
ok($zip->set_number('3908601')->is_valid_number, '医療法人抱生会 丸の内病院');
ok($zip->set_number('3908602')->is_valid_number, '長野県松本美須々ケ丘高等学校');
ok($zip->set_number('3908603')->is_valid_number, '長野県松本深志高等学校');
ok($zip->set_number('3908605')->is_valid_number, '長野県松本蟻ケ崎高等学校');
ok($zip->set_number('3908610')->is_valid_number, '株式会社 エイコー');
ok($zip->set_number('3908611')->is_valid_number, '株式会社 テレビ信州');
ok($zip->set_number('3908620')->is_valid_number, '松本市役所');
ok($zip->set_number('3908621')->is_valid_number, '信州大学');
ok($zip->set_number('3908623')->is_valid_number, '学校法人 外語学園 信農むつみ高等学校');
ok($zip->set_number('3908630')->is_valid_number, '株式会社 ニシマ');
ok($zip->set_number('3908639')->is_valid_number, '株式会社 アスピア');
ok($zip->set_number('3908648')->is_valid_number, '社会医療法人 城西医療財団 城西病院');
ok($zip->set_number('3908686')->is_valid_number, '株式会社 中部日本医薬');
ok($zip->set_number('3908702')->is_valid_number, '松本社会保険事務所');
ok($zip->set_number('3908703')->is_valid_number, 'NTT 松本営業支店');
ok($zip->set_number('3908707')->is_valid_number, '第一生命保険 株式会社 松本支社');
ok($zip->set_number('3908710')->is_valid_number, '松本税務署');
ok($zip->set_number('3908711')->is_valid_number, '松本ガス 株式会社');
ok($zip->set_number('3908712')->is_valid_number, '日本銀行 松本支店');
ok($zip->set_number('3908714')->is_valid_number, '石川島芝浦機械 株式会社 松本工場');
ok($zip->set_number('3908765')->is_valid_number, '松本市保健所');
ok($zip->set_number('3910192')->is_valid_number, '原村役場');
ok($zip->set_number('3910292')->is_valid_number, '諏訪 東京理科大学');
ok($zip->set_number('3910293')->is_valid_number, '株式会社 コダックデジタルプロダクトセンター');
ok($zip->set_number('3910294')->is_valid_number, '株式会社 ダイイチコンポーネンツ');
ok($zip->set_number('3910295')->is_valid_number, '宮坂ゴム 株式会社');
ok($zip->set_number('3910296')->is_valid_number, '株式会社 サンヨー工業');
ok($zip->set_number('3910297')->is_valid_number, '株式会社 ディスコ 長野事業所');
ok($zip->set_number('3910392')->is_valid_number, '池の平ホテル');
ok($zip->set_number('3910393')->is_valid_number, '蓼科グランドホテル滝の湯');
ok($zip->set_number('3910394')->is_valid_number, '蓼科パークホテル');
ok($zip->set_number('3910395')->is_valid_number, 'アートランドホテル蓼科');
ok($zip->set_number('3910396')->is_valid_number, '株式会社 渡辺製麺');
ok($zip->set_number('3918501')->is_valid_number, '茅野市役所');
ok($zip->set_number('3918503')->is_valid_number, '諏訪中央病院');
ok($zip->set_number('3918510')->is_valid_number, '山高味噌 株式会社');
ok($zip->set_number('3918511')->is_valid_number, '長野県立 茅野高等学校');
ok($zip->set_number('3918512')->is_valid_number, '東海大学第三高等学校');
ok($zip->set_number('3918521')->is_valid_number, '茅野商工会議所');
ok($zip->set_number('3918522')->is_valid_number, '信州諏訪農業協同組合');
ok($zip->set_number('3918525')->is_valid_number, 'ナンシン機工 株式会社');
ok($zip->set_number('3918531')->is_valid_number, '株式会社 イースタン');
ok($zip->set_number('3918540')->is_valid_number, 'ファナックパートロニクス 株式会社');
ok($zip->set_number('3918550')->is_valid_number, '株式会社 飯沼ゲージ製作所');
ok($zip->set_number('3918555')->is_valid_number, '株式会社 キッツメタルワークス');
ok($zip->set_number('3918558')->is_valid_number, '株式会社 矢島');
ok($zip->set_number('3918560')->is_valid_number, '長野精工 株式会社');
ok($zip->set_number('3918561')->is_valid_number, '長野精工 株式会社 金沢工場');
ok($zip->set_number('3918566')->is_valid_number, '株式会社 キッツマイクロフィルター 茅野工場');
ok($zip->set_number('3918567')->is_valid_number, '野村ユニソン 株式会社');
ok($zip->set_number('3918580')->is_valid_number, '株式会社 ツチハシ');
ok($zip->set_number('3918588')->is_valid_number, '八ヶ岳乳業 株式会社');
ok($zip->set_number('3928502')->is_valid_number, 'セイコーエプソン 株式会社 本社');
ok($zip->set_number('3928505')->is_valid_number, '株式会社 国興');
ok($zip->set_number('3928510')->is_valid_number, '諏訪 赤十字病院');
ok($zip->set_number('3928511')->is_valid_number, '諏訪市役所');
ok($zip->set_number('3928520')->is_valid_number, '信濃毎日新聞 諏訪支社');
ok($zip->set_number('3928540')->is_valid_number, '(株) 竹屋');
ok($zip->set_number('3928548')->is_valid_number, '長野県諏訪清陵高等学校');
ok($zip->set_number('3928549')->is_valid_number, '長野県諏訪二葉高等学校');
ok($zip->set_number('3928555')->is_valid_number, '諏訪商工会議所');
ok($zip->set_number('3928577')->is_valid_number, '株式会社 ホテル紅や');
ok($zip->set_number('3928578')->is_valid_number, 'JA信州諏訪農業協同組合');
ok($zip->set_number('3928585')->is_valid_number, '太陽工業 株式会社');
ok($zip->set_number('3928601')->is_valid_number, '長野県 諏訪建設事務所');
ok($zip->set_number('3928601')->is_valid_number, '長野県 諏訪地方事務所');
ok($zip->set_number('3928601')->is_valid_number, '長野県 諏訪保健所');
ok($zip->set_number('3928601')->is_valid_number, '長野県 農業改良普及センター');
ok($zip->set_number('3928609')->is_valid_number, 'エルシーブイ 株式会社');
ok($zip->set_number('3928610')->is_valid_number, '諏訪税務署');
ok($zip->set_number('3928611')->is_valid_number, '株式会社 長野日報社');
ok($zip->set_number('3928627')->is_valid_number, '商工組合中央金庫 諏訪支店');
ok($zip->set_number('3928628')->is_valid_number, '株式会社 八十二銀行 諏訪支店');
ok($zip->set_number('3928686')->is_valid_number, '宮坂醸造 (株) 真澄');
ok($zip->set_number('3938501')->is_valid_number, '下諏訪町役場');
ok($zip->set_number('3938502')->is_valid_number, '山王閣');
ok($zip->set_number('3938503')->is_valid_number, '日本電産サンキョーオルゴール記念館 すわのね');
ok($zip->set_number('3938511')->is_valid_number, '日本電産サンキョー 株式会社');
ok($zip->set_number('3938555')->is_valid_number, '入一通信工業 株式会社');
ok($zip->set_number('3938585')->is_valid_number, '(株) 武藤工業');
ok($zip->set_number('3938601')->is_valid_number, '株式会社 オノウエ印刷 カード受注センター');
ok($zip->set_number('3948510')->is_valid_number, '岡谷市役所');
ok($zip->set_number('3948511')->is_valid_number, '帝国ピストンリング 株式会社 長野岡谷工場');
ok($zip->set_number('3948512')->is_valid_number, '市立岡谷病院');
ok($zip->set_number('3948515')->is_valid_number, '医療法人 研成会 諏訪湖畔病院');
ok($zip->set_number('3948520')->is_valid_number, '株式会社 みくに工業');
ok($zip->set_number('3948540')->is_valid_number, 'マルヤス機械 株式会社');
ok($zip->set_number('3948550')->is_valid_number, '京セラ 株式会社 長野岡谷工場');
ok($zip->set_number('3948555')->is_valid_number, '株式会社 マルニシ');
ok($zip->set_number('3948577')->is_valid_number, '株式会社 中外商工');
ok($zip->set_number('3948585')->is_valid_number, '岡谷酸素 株式会社');
ok($zip->set_number('3948588')->is_valid_number, '健康保険 岡谷塩嶺病院');
ok($zip->set_number('3948611')->is_valid_number, '諏訪信用金庫');
ok($zip->set_number('3948665')->is_valid_number, '岡谷年金事務所');
ok($zip->set_number('3948686')->is_valid_number, '沖電線 株式会社 岡谷工場');
ok($zip->set_number('3950192')->is_valid_number, 'みなみ信州 農業協同組合');
ok($zip->set_number('3950193')->is_valid_number, '綿半鋼機 株式会社');
ok($zip->set_number('3950195')->is_valid_number, '株式会社 平和時計製作所');
ok($zip->set_number('3950196')->is_valid_number, '天竜丸澤 株式会社');
ok($zip->set_number('3958501')->is_valid_number, '飯田市役所');
ok($zip->set_number('3958502')->is_valid_number, '飯田市立病院');
ok($zip->set_number('3958503')->is_valid_number, '飯田市立高松病院');
ok($zip->set_number('3958504')->is_valid_number, '飯田商工会議所');
ok($zip->set_number('3958505')->is_valid_number, '飯田病院');
ok($zip->set_number('3958511')->is_valid_number, '株式会社 マルタ');
ok($zip->set_number('3958515')->is_valid_number, '多摩川精機 (株)');
ok($zip->set_number('3958520')->is_valid_number, '多摩川精機 株式会社 第2事業所');
ok($zip->set_number('3958522')->is_valid_number, '健和会病院');
ok($zip->set_number('3958528')->is_valid_number, '飯田女子高等学校');
ok($zip->set_number('3958533')->is_valid_number, '飯田広域消防本部');
ok($zip->set_number('3958543')->is_valid_number, '長野県飯田風越高等学校');
ok($zip->set_number('3958555')->is_valid_number, '株式会社 長野県農協直販');
ok($zip->set_number('3958556')->is_valid_number, '信南交通 株式会社');
ok($zip->set_number('3958558')->is_valid_number, '医療法人 輝山会記念病院');
ok($zip->set_number('3958566')->is_valid_number, '株式会社 ミヤウチ');
ok($zip->set_number('3958567')->is_valid_number, '飯田女子短期大学');
ok($zip->set_number('3958577')->is_valid_number, '株式会社 平和時計製作所 松尾工場');
ok($zip->set_number('3958585')->is_valid_number, '株式会社 原鉄');
ok($zip->set_number('3958588')->is_valid_number, '株式会社 トマツ本店');
ok($zip->set_number('3958609')->is_valid_number, '飯田公共職業安定所');
ok($zip->set_number('3958611')->is_valid_number, '飯田信用金庫');
ok($zip->set_number('3958622')->is_valid_number, '中部電力 株式会社 飯田営業所');
ok($zip->set_number('3958646')->is_valid_number, '飯田税務署');
ok($zip->set_number('3958655')->is_valid_number, '飯田社会保険事務所');
ok($zip->set_number('3958682')->is_valid_number, '株式会社 八十二銀行 飯田支店');
ok($zip->set_number('3958688')->is_valid_number, '株式会社 外松');
ok($zip->set_number('3960293')->is_valid_number, '長野県高遠高等学校');
ok($zip->set_number('3968501')->is_valid_number, 'ベルシャイン伊那店');
ok($zip->set_number('3968510')->is_valid_number, '上伊那農業協同組合(JA上伊那)');
ok($zip->set_number('3968511')->is_valid_number, '日本電産サンキョー 株式会社 伊那事業所');
ok($zip->set_number('3968550')->is_valid_number, '伊那税務署');
ok($zip->set_number('3968555')->is_valid_number, '伊那 中央病院');
ok($zip->set_number('3968558')->is_valid_number, '長野県 伊那北高等学校');
ok($zip->set_number('3968585')->is_valid_number, 'KOA 株式会社');
ok($zip->set_number('3968609')->is_valid_number, '伊那公共職業安定所');
ok($zip->set_number('3968611')->is_valid_number, 'アルプス中央 信用金庫');
ok($zip->set_number('3968617')->is_valid_number, '伊那市役所');
ok($zip->set_number('3968682')->is_valid_number, '株式会社 八十二銀行 伊那支店');
ok($zip->set_number('3970292')->is_valid_number, '長野県製薬 株式会社');
ok($zip->set_number('3970392')->is_valid_number, '木曽町 開田支所');
ok($zip->set_number('3978550')->is_valid_number, '木曽合同庁舎');
ok($zip->set_number('3978555')->is_valid_number, '長野県立 木曽病院');
ok($zip->set_number('3978567')->is_valid_number, '長野県 木曽青峰高等学校 新開キャンパス');
ok($zip->set_number('3978571')->is_valid_number, '長野県 木曽青峰高等学校');
ok($zip->set_number('3978585')->is_valid_number, '木曽町文化交流センター');
ok($zip->set_number('3978588')->is_valid_number, '木曽町役場');
ok($zip->set_number('3978602')->is_valid_number, '木曽税務署');
ok($zip->set_number('3978609')->is_valid_number, '木曽福島公共職業安定所');
ok($zip->set_number('3988501')->is_valid_number, '大町税務署');
ok($zip->set_number('3988601')->is_valid_number, '大町市役所');
ok($zip->set_number('3988602')->is_valid_number, '長野県大町合同庁舎');
ok($zip->set_number('3988686')->is_valid_number, '株式会社 相模組');
ok($zip->set_number('3990292')->is_valid_number, '富士見町役場');
ok($zip->set_number('3990293')->is_valid_number, 'セイコーエプソン 株式会社 富士見事業所');
ok($zip->set_number('3990295')->is_valid_number, 'セイコーエプソン 株式会社 諏訪南事業所');
ok($zip->set_number('3990492')->is_valid_number, '石川島汎用機械 株式会社');
ok($zip->set_number('3990493')->is_valid_number, '辰野町役場');
ok($zip->set_number('3990495')->is_valid_number, '株式会社 エビデント 長野事業場');
ok($zip->set_number('3990496')->is_valid_number, '町立 辰野病院');
ok($zip->set_number('3990497')->is_valid_number, '株式会社 マブチ・エスアンドティー');
ok($zip->set_number('3990498')->is_valid_number, '信州豊南短期大学');
ok($zip->set_number('3990781')->is_valid_number, '学校法人 松本歯科大学');
ok($zip->set_number('3990782')->is_valid_number, '株式会社 サンコー');
ok($zip->set_number('3990785')->is_valid_number, 'セイコーエプソン 株式会社 広丘事業所');
ok($zip->set_number('3990786')->is_valid_number, '塩尻市役所');
ok($zip->set_number('3990796')->is_valid_number, 'セイコーエプソン 株式会社 塩尻事業所');
ok($zip->set_number('3990797')->is_valid_number, 'エプソンダイレクト 株式会社');
ok($zip->set_number('3991392')->is_valid_number, '飯田市役所 南信濃自治振興センター');
ok($zip->set_number('3991511')->is_valid_number, '阿南町役場');
ok($zip->set_number('3991689')->is_valid_number, '売木村役場');
ok($zip->set_number('3991895')->is_valid_number, '泰阜村役場');
ok($zip->set_number('3993192')->is_valid_number, '株式会社 マツザワ');
ok($zip->set_number('3993193')->is_valid_number, '高森町役場');
ok($zip->set_number('3993295')->is_valid_number, '豊丘村役場');
ok($zip->set_number('3993797')->is_valid_number, '飯島町役場');
ok($zip->set_number('3993892')->is_valid_number, '中川村役場');
ok($zip->set_number('3994192')->is_valid_number, '駒ヶ根市役所');
ok($zip->set_number('3994195')->is_valid_number, '株式会社 ヤマウラ');
ok($zip->set_number('3994392')->is_valid_number, '宮田村役場');
ok($zip->set_number('3994393')->is_valid_number, '株式会社 LIXIL');
ok($zip->set_number('3994394')->is_valid_number, '横河マニュファクチャリング 株式会社');
ok($zip->set_number('3994395')->is_valid_number, '株式会社 マルニシ 伊那店');
ok($zip->set_number('3994498')->is_valid_number, '伊那食品工業 株式会社 本社');
ok($zip->set_number('3994564')->is_valid_number, '西箕輪小学校');
ok($zip->set_number('3994565')->is_valid_number, '西箕輪中学校');
ok($zip->set_number('3994566')->is_valid_number, '南部小学校');
ok($zip->set_number('3994567')->is_valid_number, '南箕輪小学校');
ok($zip->set_number('3994568')->is_valid_number, '南箕輪中学校');
ok($zip->set_number('3994570')->is_valid_number, '国興 株式会社');
ok($zip->set_number('3994571')->is_valid_number, '越前屋 株式会社');
ok($zip->set_number('3994572')->is_valid_number, '上野興業 株式会社');
ok($zip->set_number('3994573')->is_valid_number, 'ジャパンエアガシズ');
ok($zip->set_number('3994575')->is_valid_number, 'エルコム');
ok($zip->set_number('3994576')->is_valid_number, '高山理化精機 株式会社');
ok($zip->set_number('3994577')->is_valid_number, '長野伊那養護学校');
ok($zip->set_number('3994578')->is_valid_number, 'ミツワマシンサービス');
ok($zip->set_number('3994581')->is_valid_number, 'BOCエドワーズ 株式会社');
ok($zip->set_number('3994583')->is_valid_number, 'マシンエンジニアリング 株式会社');
ok($zip->set_number('3994584')->is_valid_number, 'ニッセイ電子工業 株式会社');
ok($zip->set_number('3994585')->is_valid_number, '創研 株式会社');
ok($zip->set_number('3994586')->is_valid_number, 'ピスコ販売');
ok($zip->set_number('3994587')->is_valid_number, '日本ピスコ 第一工場');
ok($zip->set_number('3994588')->is_valid_number, '日本ピスコ 第二工場');
ok($zip->set_number('3994589')->is_valid_number, '信英蓄電器箔 株式会社');
ok($zip->set_number('3994592')->is_valid_number, '南箕輪村役場');
ok($zip->set_number('3994593')->is_valid_number, 'ルビコン 株式会社');
ok($zip->set_number('3994594')->is_valid_number, '長野県上伊那農業高等学校');
ok($zip->set_number('3994595')->is_valid_number, '株式会社 ハーモ');
ok($zip->set_number('3994597')->is_valid_number, '大明化学工業 株式会社');
ok($zip->set_number('3994598')->is_valid_number, '信州大学 農学部');
ok($zip->set_number('3994692')->is_valid_number, '株式会社 伸光製作所');
ok($zip->set_number('3994693')->is_valid_number, 'HOYA 株式会社 ビジョンケア部門 松島工場');
ok($zip->set_number('3994695')->is_valid_number, '箕輪町役場');
ok($zip->set_number('3994696')->is_valid_number, 'セイコーエプソン 株式会社 伊那事業所');
ok($zip->set_number('3994697')->is_valid_number, 'KOA 株式会社 アースウイング');
ok($zip->set_number('3996493')->is_valid_number, '洗馬農業協同組合');
ok($zip->set_number('3997192')->is_valid_number, '安曇野市役所 明科支所');
ok($zip->set_number('3997194')->is_valid_number, 'あづみ野エフエム放送 株式会社');
ok($zip->set_number('3998192')->is_valid_number, '安曇野市役所 三郷支所');
ok($zip->set_number('3998281')->is_valid_number, '安曇野市役所');
ok($zip->set_number('3998282')->is_valid_number, 'VAIO 株式会社');
ok($zip->set_number('3998283')->is_valid_number, 'あづみ農業協同組合');
ok($zip->set_number('3998285')->is_valid_number, 'セイコーエプソン 株式会社 豊科事業所');
ok($zip->set_number('3998286')->is_valid_number, '株式会社 デンソーエアクール');
ok($zip->set_number('3998288')->is_valid_number, '長野県立 こども病院');
ok($zip->set_number('3998292')->is_valid_number, '安曇野赤十字病院');
ok($zip->set_number('3998293')->is_valid_number, '日本電熱 株式会社');
ok($zip->set_number('3998295')->is_valid_number, '(財) アルプスあづみの公園管理センター');
ok($zip->set_number('3998297')->is_valid_number, '国土交通省 関東地方整備局 国営アルプスあづみの公園事務所');
ok($zip->set_number('3998386')->is_valid_number, '株式会社 デンソーエアクール 穂高本社工場');
ok($zip->set_number('3998392')->is_valid_number, '安曇野市役所 穂高支所');
ok($zip->set_number('3998695')->is_valid_number, '長野県厚生農業協同組合連合会 北アルプス医療センター あづみ病院');
ok($zip->set_number('3998696')->is_valid_number, '池田町役場');
ok($zip->set_number('3998701')->is_valid_number, 'まつもと医療センター 松本病院');
ok($zip->set_number('3998702')->is_valid_number, 'セイコーエプソン 株式会社 松本南事業所');
ok($zip->set_number('3998707')->is_valid_number, 'セイコーエプソン 株式会社 村井事業所');
ok($zip->set_number('3998710')->is_valid_number, 'キッセイ薬品工業 株式会社');
ok($zip->set_number('3998711')->is_valid_number, '信濃毎日新聞 株式会社 松本本社');
ok($zip->set_number('3998712')->is_valid_number, '株式会社 ナガノトマト');
ok($zip->set_number('3998720')->is_valid_number, '長野 コカ・コーラボトリング 株式会社');
ok($zip->set_number('3998721')->is_valid_number, '株式会社 泉精器製作所');
ok($zip->set_number('3998722')->is_valid_number, '高山理化精機 株式会社');
ok($zip->set_number('3998725')->is_valid_number, '桜田電気工業 株式会社 松本支店');
ok($zip->set_number('3998728')->is_valid_number, '信州ジャスコ 株式会社 管理本部');
ok($zip->set_number('3998730')->is_valid_number, 'パナソニック オートモーティブシステムズ 株式会社 松本工場');
ok($zip->set_number('3998733')->is_valid_number, '株式会社 シマコー');
ok($zip->set_number('3998738')->is_valid_number, '伊藤伊 株式会社 甲信支店');
ok($zip->set_number('3998739')->is_valid_number, 'セントラルパック 株式会社');
ok($zip->set_number('3998744')->is_valid_number, 'タカヤマケミカル 株式会社');
ok($zip->set_number('3998750')->is_valid_number, '株式会社 日邦バルブ');
ok($zip->set_number('3998751')->is_valid_number, '株式会社 ヤマサ');
ok($zip->set_number('3998754')->is_valid_number, 'アズサイエンス 株式会社');
ok($zip->set_number('3998755')->is_valid_number, '花村産業 株式会社');
ok($zip->set_number('3998760')->is_valid_number, '株式会社 上條器械店 松本営業所');
ok($zip->set_number('3999192')->is_valid_number, '大町市 美麻支所');
ok($zip->set_number('3999393')->is_valid_number, '白馬村役場');
ok($zip->set_number('3999494')->is_valid_number, '小谷村役場');
ok($zip->set_number('4000192')->is_valid_number, '甲斐市役所');
ok($zip->set_number('4000193')->is_valid_number, '甲斐市役所 敷島支所');
ok($zip->set_number('4000194')->is_valid_number, '株式会社 光彩工芸');
ok($zip->set_number('4000195')->is_valid_number, '竜王社会保険事務所');
ok($zip->set_number('4000196')->is_valid_number, '甲斐市役所 双葉支所');
ok($zip->set_number('4000280')->is_valid_number, '清水工機 株式会社');
ok($zip->set_number('4000292')->is_valid_number, '南アルプス市役所 白根支所');
ok($zip->set_number('4000293')->is_valid_number, '南アルプス市役所 芦安支所');
ok($zip->set_number('4000298')->is_valid_number, '南アルプス市役所 八田支所');
ok($zip->set_number('4000393')->is_valid_number, '南アルプス市役所 若草支所');
ok($zip->set_number('4000395')->is_valid_number, '南アルプス市役所');
ok($zip->set_number('4000398')->is_valid_number, '巨摩共立病院');
ok($zip->set_number('4000492')->is_valid_number, '南アルプス市役所 甲西支所');
ok($zip->set_number('4000493')->is_valid_number, '新旭電子工業山梨 株式会社');
ok($zip->set_number('4000495')->is_valid_number, 'TDK (株) 甲府工場');
ok($zip->set_number('4000498')->is_valid_number, '山梨アビオニクス (株)');
ok($zip->set_number('4000592')->is_valid_number, '富士川町役場');
ok($zip->set_number('4000593')->is_valid_number, 'キャノンファインテックニスカ 株式会社');
ok($zip->set_number('4000598')->is_valid_number, '株式会社 はくばく');
ok($zip->set_number('4000692')->is_valid_number, '山梨県 峡南地域県民センター');
ok($zip->set_number('4000693')->is_valid_number, '鰍沢税務署');
ok($zip->set_number('4000695')->is_valid_number, '富士川町役場 分庁舎');
ok($zip->set_number('4001592')->is_valid_number, '甲府市役所 中道支所');
ok($zip->set_number('4001593')->is_valid_number, '株式会社 シャトレーゼ');
ok($zip->set_number('4001594')->is_valid_number, '中央市役所 豊富庁舎');
ok($zip->set_number('4001597')->is_valid_number, 'よっちゃん食品工業 株式会社');
ok($zip->set_number('4001598')->is_valid_number, '株式会社 チロリーナ');
ok($zip->set_number('4008501')->is_valid_number, '山梨県庁');
ok($zip->set_number('4008502')->is_valid_number, '甲府信用金庫');
ok($zip->set_number('4008505')->is_valid_number, '株式会社 山梨文化会館');
ok($zip->set_number('4008506')->is_valid_number, '山梨県立 中央病院');
ok($zip->set_number('4008508')->is_valid_number, '学校法人 山梨英和学院');
ok($zip->set_number('4008509')->is_valid_number, '株式会社 日本ネットワークサービス');
ok($zip->set_number('4008510')->is_valid_number, '山梨大学');
ok($zip->set_number('4008511')->is_valid_number, '山梨大学 工学部');
ok($zip->set_number('4008512')->is_valid_number, '甲府商工会議所');
ok($zip->set_number('4008515')->is_valid_number, '株式会社 山梨日々新聞社');
ok($zip->set_number('4008520')->is_valid_number, '甲府地方法務局');
ok($zip->set_number('4008521')->is_valid_number, '甲府富士屋ホテル');
ok($zip->set_number('4008525')->is_valid_number, '株式会社 山梨放送');
ok($zip->set_number('4008531')->is_valid_number, '山梨社会保険事務局');
ok($zip->set_number('4008533')->is_valid_number, '独立行政法人 国立病院機構 甲府病院');
ok($zip->set_number('4008535')->is_valid_number, '株式会社 アドブレーン社');
ok($zip->set_number('4008536')->is_valid_number, '株式会社 エヌ・ティ・ティドコモ 山梨支店');
ok($zip->set_number('4008540')->is_valid_number, '清水工機 株式会社');
ok($zip->set_number('4008543')->is_valid_number, '中北保険福祉事務所');
ok($zip->set_number('4008544')->is_valid_number, 'UFJニコス 株式会社');
ok($zip->set_number('4008545')->is_valid_number, '株式会社 YBST&L');
ok($zip->set_number('4008550')->is_valid_number, '株式会社 エフエム富士');
ok($zip->set_number('4008552')->is_valid_number, 'NHK 甲府放送局');
ok($zip->set_number('4008555')->is_valid_number, '山梨英和大学');
ok($zip->set_number('4008556')->is_valid_number, '甲府地方検察庁');
ok($zip->set_number('4008558')->is_valid_number, '横河電機 株式会社 甲府事業所');
ok($zip->set_number('4008559')->is_valid_number, '全国健康保険協会 山梨支部');
ok($zip->set_number('4008565')->is_valid_number, '甲府社会保険事務所');
ok($zip->set_number('4008566')->is_valid_number, '中部食品 株式会社');
ok($zip->set_number('4008570')->is_valid_number, '株式会社 テレビ山梨');
ok($zip->set_number('4008571')->is_valid_number, '山梨労働局 労働基準部 労災補償課分室');
ok($zip->set_number('4008575')->is_valid_number, '山梨学院大学');
ok($zip->set_number('4008577')->is_valid_number, '山梨労働局');
ok($zip->set_number('4008578')->is_valid_number, '国土交通省 甲府河川国道事務所');
ok($zip->set_number('4008585')->is_valid_number, '甲府市役所');
ok($zip->set_number('4008586')->is_valid_number, '山梨県警察本部');
ok($zip->set_number('4008588')->is_valid_number, '長田組土木 株式会社');
ok($zip->set_number('4008601')->is_valid_number, '山梨中央銀行');
ok($zip->set_number('4008610')->is_valid_number, '日本生命保険 相互会社 甲府支社');
ok($zip->set_number('4008633')->is_valid_number, '商工組合中央金庫 甲府支店');
ok($zip->set_number('4008660')->is_valid_number, '株式会社 岡島');
ok($zip->set_number('4008666')->is_valid_number, '株式会社 テンヨ武田');
ok($zip->set_number('4008794')->is_valid_number, '山梨地域センター');
ok($zip->set_number('4010292')->is_valid_number, '上野原市役所 秋山支所');
ok($zip->set_number('4010380')->is_valid_number, '健康科学大学');
ok($zip->set_number('4010395')->is_valid_number, 'シチズンファインデバイス 株式会社');
ok($zip->set_number('4010396')->is_valid_number, '富士観光開発 株式会社');
ok($zip->set_number('4010397')->is_valid_number, 'アネルバ 株式会社 富士工場');
ok($zip->set_number('4010398')->is_valid_number, '鳴沢村役場');
ok($zip->set_number('4010592')->is_valid_number, '忍野村役場');
ok($zip->set_number('4010595')->is_valid_number, '山中湖村役場');
ok($zip->set_number('4010597')->is_valid_number, 'ファナック 株式会社');
ok($zip->set_number('4018501')->is_valid_number, '山梨社会保険事務局 大月事務所');
ok($zip->set_number('4018601')->is_valid_number, '大月市役所');
ok($zip->set_number('4028501')->is_valid_number, '都留市役所');
ok($zip->set_number('4028555')->is_valid_number, '都留文科大学');
ok($zip->set_number('4028580')->is_valid_number, '健康科学大学 看護学部');
ok($zip->set_number('4038522')->is_valid_number, '中央観光 株式会社');
ok($zip->set_number('4038555')->is_valid_number, '全国柔道整復師会');
ok($zip->set_number('4038601')->is_valid_number, '富士吉田市役所');
ok($zip->set_number('4048501')->is_valid_number, '甲州市役所');
ok($zip->set_number('4048601')->is_valid_number, '峡東地域県民センター');
ok($zip->set_number('4058501')->is_valid_number, '山梨市役所');
ok($zip->set_number('4058555')->is_valid_number, '笛吹市役所 一宮支所');
ok($zip->set_number('4058577')->is_valid_number, 'NSW 株式会社');
ok($zip->set_number('4058585')->is_valid_number, '山梨税務署');
ok($zip->set_number('4068505')->is_valid_number, '笛吹市役所 春日居分庁舎');
ok($zip->set_number('4068510')->is_valid_number, '笛吹市役所');
ok($zip->set_number('4068555')->is_valid_number, '笛吹市役所 八代分庁舎');
ok($zip->set_number('4068558')->is_valid_number, '山梨県自動車税事務所');
ok($zip->set_number('4068601')->is_valid_number, '山梨県総合県税事務所');
ok($zip->set_number('4070192')->is_valid_number, '東京エレクトロンAT 株式会社 山梨事業所 (穂坂地区)');
ok($zip->set_number('4078501')->is_valid_number, '韮崎市役所');
ok($zip->set_number('4078502')->is_valid_number, 'リバーエレテック 株式会社');
ok($zip->set_number('4078511')->is_valid_number, '東京エレクトロン 株式会社');
ok($zip->set_number('4078549')->is_valid_number, '救心製薬 株式会社 山梨工場');
ok($zip->set_number('4078555')->is_valid_number, '三井金属鉱業 株式会社');
ok($zip->set_number('4080188')->is_valid_number, '北杜市役所');
ok($zip->set_number('4080192')->is_valid_number, '北杜市役所 須玉総合支所');
ok($zip->set_number('4088511')->is_valid_number, '北杜市役所 高根総合支所');
ok($zip->set_number('4088515')->is_valid_number, '株式会社 キッツ 長坂工場');
ok($zip->set_number('4088522')->is_valid_number, '株式会社 アルソア本社');
ok($zip->set_number('4088533')->is_valid_number, '株式会社 ミヨシ');
ok($zip->set_number('4088550')->is_valid_number, 'HOYA 株式会社 長坂工場');
ok($zip->set_number('4088555')->is_valid_number, '北杜市役所 小淵沢総合支所');
ok($zip->set_number('4088585')->is_valid_number, '北杜市役所 長坂総合支所');
ok($zip->set_number('4090192')->is_valid_number, '上野原市役所');
ok($zip->set_number('4090193')->is_valid_number, '帝京科学大学');
ok($zip->set_number('4090195')->is_valid_number, '日本大学明誠高等学校');
ok($zip->set_number('4090198')->is_valid_number, '株式会社 エノモト');
ok($zip->set_number('4091298')->is_valid_number, '甲州市 大和地域総合局');
ok($zip->set_number('4091392')->is_valid_number, '甲州市 勝沼地域総合局');
ok($zip->set_number('4092192')->is_valid_number, '南部町役場');
ok($zip->set_number('4092193')->is_valid_number, 'JAふじかわ 富沢支店');
ok($zip->set_number('4092194')->is_valid_number, '富士ロイヤルカントリークラブ');
ok($zip->set_number('4092195')->is_valid_number, '随縁カントリー倶楽部 センチュリー富士コース');
ok($zip->set_number('4092196')->is_valid_number, '中央化学 (株) 山梨工場 第二事業所');
ok($zip->set_number('4092398')->is_valid_number, '南部町役場 南部分庁舎');
ok($zip->set_number('4092592')->is_valid_number, '身延町役場 身延支所');
ok($zip->set_number('4092593')->is_valid_number, '身延山久遠寺');
ok($zip->set_number('4092597')->is_valid_number, '身延山学園');
ok($zip->set_number('4092598')->is_valid_number, '上沢寺');
ok($zip->set_number('4092992')->is_valid_number, '身延町役場 下部支所');
ok($zip->set_number('4093293')->is_valid_number, '開運社');
ok($zip->set_number('4093392')->is_valid_number, '身延町役場');
ok($zip->set_number('4093393')->is_valid_number, '富士川カントリークラブ');
ok($zip->set_number('4093692')->is_valid_number, '株式会社 マルアイ');
ok($zip->set_number('4093792')->is_valid_number, '甲府市 上九一色出張所');
ok($zip->set_number('4093793')->is_valid_number, '笛吹市役所 芦川支所');
ok($zip->set_number('4093880')->is_valid_number, '昭和町役場');
ok($zip->set_number('4093883')->is_valid_number, '住友電工デバイス・イノベーション 株式会社');
ok($zip->set_number('4093885')->is_valid_number, '株式会社 渡辺商店');
ok($zip->set_number('4093888')->is_valid_number, '株式会社 サン宝石');
ok($zip->set_number('4093889')->is_valid_number, 'パイオニア・ディスプレイ・プロダクツ 株式会社');
ok($zip->set_number('4093892')->is_valid_number, '中央市役所');
ok($zip->set_number('4093893')->is_valid_number, '中央市役所 玉穂支所');
ok($zip->set_number('4093894')->is_valid_number, '株式会社 甲府明電舎');
ok($zip->set_number('4093895')->is_valid_number, 'パナソニックファクトリーソリューションズ 株式会社');
ok($zip->set_number('4093896')->is_valid_number, 'カシオビジネスサービス 株式会社');
ok($zip->set_number('4093897')->is_valid_number, '株式会社 アピオ');
ok($zip->set_number('4093898')->is_valid_number, '山梨大学医学部付属病院');
ok($zip->set_number('4100192')->is_valid_number, '加倉水産');
ok($zip->set_number('4100195')->is_valid_number, '沼津海産物協同組合');
ok($zip->set_number('4100395')->is_valid_number, '東海大学沼津校舎');
ok($zip->set_number('4100396')->is_valid_number, '富士通 株式会社 沼津工場');
ok($zip->set_number('4100398')->is_valid_number, '図書印刷 株式会社 沼津工場');
ok($zip->set_number('4101192')->is_valid_number, '裾野市役所');
ok($zip->set_number('4101193')->is_valid_number, 'トヨタ自動車 株式会社 東富士研究所');
ok($zip->set_number('4101194')->is_valid_number, '矢崎総業 株式会社 Y-CITY');
ok($zip->set_number('4101195')->is_valid_number, 'トヨタ自動車東日本 株式会社 東富士工場');
ok($zip->set_number('4101196')->is_valid_number, 'キヤノン 株式会社 富士裾野リサーチパーク');
ok($zip->set_number('4101197')->is_valid_number, '裾野警察署');
ok($zip->set_number('4101198')->is_valid_number, 'トヨタ自動車東日本 株式会社 東富士総合センター');
ok($zip->set_number('4101392')->is_valid_number, 'ユニバーサル製缶 株式会社');
ok($zip->set_number('4101393')->is_valid_number, '株式会社 日立ハイテクサイエンス 小山事業所');
ok($zip->set_number('4101394')->is_valid_number, 'フジボウ愛媛 株式会社 小山工場');
ok($zip->set_number('4101395')->is_valid_number, '小山町役場');
ok($zip->set_number('4101396')->is_valid_number, '株式会社 センサータ・テクノロジーズジャパン');
ok($zip->set_number('4102192')->is_valid_number, '伊豆の国市役所 韮山支所');
ok($zip->set_number('4102193')->is_valid_number, 'ABB日本ベーレー 株式会社');
ok($zip->set_number('4102194')->is_valid_number, '富士伊豆農業協同組合伊豆の国地区本部');
ok($zip->set_number('4102195')->is_valid_number, '伊豆韮山温泉病院');
ok($zip->set_number('4102292')->is_valid_number, '伊豆の国市役所');
ok($zip->set_number('4102295')->is_valid_number, '順天堂大学 医学部附属 静岡病院');
ok($zip->set_number('4102297')->is_valid_number, '株式会社 コクド 三養荘');
ok($zip->set_number('4102392')->is_valid_number, '東芝テック 株式会社 大仁事業所');
ok($zip->set_number('4102393')->is_valid_number, 'ワールドメイト');
ok($zip->set_number('4102394')->is_valid_number, 'ニッサン・モータースポーツ・インターナショナル (株) モビリティーパーク事業部');
ok($zip->set_number('4102395')->is_valid_number, '静岡県立 大仁高等学校');
ok($zip->set_number('4102396')->is_valid_number, '伊豆の国市役所 大仁支所');
ok($zip->set_number('4102592')->is_valid_number, '伊豆市 中伊豆支所');
ok($zip->set_number('4103292')->is_valid_number, '伊豆市役所 天城湯ヶ島支所');
ok($zip->set_number('4103693')->is_valid_number, '松崎高校');
ok($zip->set_number('4103696')->is_valid_number, '松崎町役場');
ok($zip->set_number('4108501')->is_valid_number, '沼津工業高等専門学校');
ok($zip->set_number('4108504')->is_valid_number, '株式会社 フジクラ 沼津工場');
ok($zip->set_number('4108508')->is_valid_number, '沼津警察署');
ok($zip->set_number('4108510')->is_valid_number, '東芝機械 株式会社 沼津事業所');
ok($zip->set_number('4108511')->is_valid_number, '矢崎総業 株式会社');
ok($zip->set_number('4108514')->is_valid_number, '株式会社 イワサキ経営');
ok($zip->set_number('4108515')->is_valid_number, '矢崎エナジーシステム 株式会社 沼津製作所');
ok($zip->set_number('4108520')->is_valid_number, '沼津財務事務所');
ok($zip->set_number('4108522')->is_valid_number, '東部教育事務所');
ok($zip->set_number('4108525')->is_valid_number, '株式会社 すみや電器 沼津営業所');
ok($zip->set_number('4108530')->is_valid_number, '米久 株式会社');
ok($zip->set_number('4108531')->is_valid_number, '三井生命保険 相互会社 沼津支社');
ok($zip->set_number('4108533')->is_valid_number, '沼津市立図書館');
ok($zip->set_number('4108535')->is_valid_number, '富士ロビン 株式会社');
ok($zip->set_number('4108540')->is_valid_number, '株式会社 特電');
ok($zip->set_number('4108541')->is_valid_number, '三井ショッピングパークららぽーと沼津');
ok($zip->set_number('4108543')->is_valid_number, '沼津保健所');
ok($zip->set_number('4108544')->is_valid_number, '静岡県農業協同組合中央会 東部支所');
ok($zip->set_number('4108545')->is_valid_number, '株式会社 TOKAIケーブルネットワーク カスタマーセンター');
ok($zip->set_number('4108550')->is_valid_number, '静岡地方裁判所 沼津支部 静岡家庭裁判所 沼津支部 沼津簡易裁判所 沼津検察審査会');
ok($zip->set_number('4108551')->is_valid_number, '株式会社 マルヤ水産');
ok($zip->set_number('4108552')->is_valid_number, '羽野水産 株式会社');
ok($zip->set_number('4108555')->is_valid_number, '財団法人 芙蓉協会 聖隷沼津病院');
ok($zip->set_number('4108558')->is_valid_number, 'NTT西日本 沼津支店');
ok($zip->set_number('4108567')->is_valid_number, '国土交通省 中部地方整備局 沼津河川国道事務所');
ok($zip->set_number('4108570')->is_valid_number, '株式会社 西武百貨店 沼津店');
ok($zip->set_number('4108575')->is_valid_number, '財団法人 復康会 沼津中央病院');
ok($zip->set_number('4108580')->is_valid_number, '聖隷沼津健康診断センター');
ok($zip->set_number('4108585')->is_valid_number, '株式会社 日本政策金融公庫 沼津支店');
ok($zip->set_number('4108588')->is_valid_number, '株式会社 明電舎 沼津事業所');
ok($zip->set_number('4108601')->is_valid_number, '沼津市役所');
ok($zip->set_number('4108602')->is_valid_number, '日本生命保険 相互会社 沼津支社');
ok($zip->set_number('4108610')->is_valid_number, '沼津信用金庫 本店 本部');
ok($zip->set_number('4108654')->is_valid_number, '商工組合中央金庫 沼津支店');
ok($zip->set_number('4108655')->is_valid_number, '沼津社会保険事務所');
ok($zip->set_number('4108686')->is_valid_number, '沼津税務署');
ok($zip->set_number('4108689')->is_valid_number, '株式会社 駿河銀行');
ok($zip->set_number('4108710')->is_valid_number, '株式会社 静岡中央銀行');
ok($zip->set_number('4108739')->is_valid_number, '株式会社 増進会出版社');
ok($zip->set_number('4118502')->is_valid_number, '静岡県立 静岡中央高等学校 通信制課程 東部キャンパス');
ok($zip->set_number('4118510')->is_valid_number, '東栄電機 株式会社');
ok($zip->set_number('4118511')->is_valid_number, 'オムロン 株式会社 三島事業所');
ok($zip->set_number('4118520')->is_valid_number, '東芝テック 株式会社 三島事業所');
ok($zip->set_number('4118525')->is_valid_number, '株式会社 三静工業');
ok($zip->set_number('4118533')->is_valid_number, '伊豆箱根鉄道 株式会社');
ok($zip->set_number('4118540')->is_valid_number, '大学共同利用機関法人 情報システム研究機構');
ok($zip->set_number('4118541')->is_valid_number, '和興産業 株式会社');
ok($zip->set_number('4118551')->is_valid_number, '三島税務署');
ok($zip->set_number('4118555')->is_valid_number, '日本大学 国際関係学部');
ok($zip->set_number('4118560')->is_valid_number, '株式会社 電業社 機械製作所');
ok($zip->set_number('4118577')->is_valid_number, '株式会社 鈴木工務店');
ok($zip->set_number('4118588')->is_valid_number, '日本大学 国際関係学部(三島駅北口校舎)');
ok($zip->set_number('4118610')->is_valid_number, '臼井国際産業 株式会社');
ok($zip->set_number('4118611')->is_valid_number, '独立行政法人 国立病院機構 静岡医療センター');
ok($zip->set_number('4118620')->is_valid_number, '野口アルミ箔加工紙 株式会社');
ok($zip->set_number('4118623')->is_valid_number, '株式会社 大成');
ok($zip->set_number('4118630')->is_valid_number, '近物レックス 株式会社');
ok($zip->set_number('4118641')->is_valid_number, 'フジトク 株式会社');
ok($zip->set_number('4118644')->is_valid_number, '三島商工会議所');
ok($zip->set_number('4118648')->is_valid_number, '明治ケンコーハム 株式会社 三島工場');
ok($zip->set_number('4118650')->is_valid_number, '清水町役場');
ok($zip->set_number('4118651')->is_valid_number, '三島信用金庫');
ok($zip->set_number('4118652')->is_valid_number, '東レ株式会社 三島工場');
ok($zip->set_number('4118660')->is_valid_number, '三島社会保険事務所');
ok($zip->set_number('4118666')->is_valid_number, '三島市役所');
ok($zip->set_number('4118668')->is_valid_number, '長泉町役場');
ok($zip->set_number('4118689')->is_valid_number, '株式会社 駿河銀行');
ok($zip->set_number('4118720')->is_valid_number, '東邦テナックス 株式会社 三島事業所');
ok($zip->set_number('4118722')->is_valid_number, '岳南光機 株式会社');
ok($zip->set_number('4118725')->is_valid_number, '株式会社 共和工機');
ok($zip->set_number('4118730')->is_valid_number, '株式会社 不二精機製造所');
ok($zip->set_number('4118731')->is_valid_number, '協和発酵工業 株式会社 富士工場');
ok($zip->set_number('4118740')->is_valid_number, 'ハックキミサワ');
ok($zip->set_number('4118750')->is_valid_number, '特種製紙');
ok($zip->set_number('4118777')->is_valid_number, '静岡県立 静岡がんセンター');
ok($zip->set_number('4118787')->is_valid_number, '順天堂大学 保健看護学部');
ok($zip->set_number('4128501')->is_valid_number, 'ジェイビルジャパン 株式会社');
ok($zip->set_number('4128505')->is_valid_number, 'メディアロジテック 株式会社');
ok($zip->set_number('4128511')->is_valid_number, '株式会社 ショーワ 御殿場工場');
ok($zip->set_number('4128512')->is_valid_number, '国立駿河療養所');
ok($zip->set_number('4128513')->is_valid_number, '中外製薬 株式会社 富士御殿場研究所');
ok($zip->set_number('4128524')->is_valid_number, '持田製薬 株式会社 富士中央研究所');
ok($zip->set_number('4128550')->is_valid_number, '陸上自衛隊 滝ケ原駐屯地');
ok($zip->set_number('4128585')->is_valid_number, '陸上自衛隊駒門駐屯地');
ok($zip->set_number('4128601')->is_valid_number, '御殿場市役所');
ok($zip->set_number('4128605')->is_valid_number, '御殿場 農業協同組合');
ok($zip->set_number('4128609')->is_valid_number, '駿河信用金庫 本店・本部(総務部・人事部・経理部・業務部・管理部・審査部・事務部・総合企業部・検査部)');
ok($zip->set_number('4128630')->is_valid_number, '菱和金属工業 株式会社');
ok($zip->set_number('4128634')->is_valid_number, '陸上自衛隊 板妻駐屯地');
ok($zip->set_number('4128701')->is_valid_number, '御殿場プレミアム・アウトレット');
ok($zip->set_number('4130196')->is_valid_number, '株式会社 間瀬');
ok($zip->set_number('4130292')->is_valid_number, '伊豆急行 株式会社');
ok($zip->set_number('4130293')->is_valid_number, '伊豆高原ゆうゆうの里');
ok($zip->set_number('4130298')->is_valid_number, '株式会社 伊豆急コミュニティー');
ok($zip->set_number('4130492')->is_valid_number, 'ホテル銀水荘');
ok($zip->set_number('4130493')->is_valid_number, '株式会社 徳造丸');
ok($zip->set_number('4138502')->is_valid_number, '熱海税務署');
ok($zip->set_number('4138505')->is_valid_number, '熱海簡易裁判所');
ok($zip->set_number('4138510')->is_valid_number, '日本ジャンボー 株式会社');
ok($zip->set_number('4138511')->is_valid_number, '財団法人 エム・オー・エー美術・文化財団 MOA美術館');
ok($zip->set_number('4138530')->is_valid_number, '株式会社 寿恵会 ネオ・サミット湯河原');
ok($zip->set_number('4138550')->is_valid_number, '熱海市役所');
ok($zip->set_number('4138555')->is_valid_number, 'ホテルニューアカオ');
ok($zip->set_number('4138558')->is_valid_number, '株式会社 中銀ライフケア');
ok($zip->set_number('4138560')->is_valid_number, '静岡地方法務局 熱海出張所');
ok($zip->set_number('4138566')->is_valid_number, '社会福祉法人 黎明会 熱海ゆとりあの郷');
ok($zip->set_number('4138567')->is_valid_number, '国際医療福祉大学附属熱海病院');
ok($zip->set_number('4138585')->is_valid_number, '世界救世教 いづのめ教団');
ok($zip->set_number('4138589')->is_valid_number, '熱海身代り不動尊');
ok($zip->set_number('4138611')->is_valid_number, 'ホテル大野屋');
ok($zip->set_number('4138618')->is_valid_number, '中島水産 株式会社');
ok($zip->set_number('4138626')->is_valid_number, '熱海後楽園');
ok($zip->set_number('4138678')->is_valid_number, 'ホテル池田');
ok($zip->set_number('4148511')->is_valid_number, '東海自動車 株式会社');
ok($zip->set_number('4148550')->is_valid_number, '株式会社 杉山製茶工場');
ok($zip->set_number('4148555')->is_valid_number, '伊東市役所');
ok($zip->set_number('4150192')->is_valid_number, '南伊豆国民休暇村');
ok($zip->set_number('4150193')->is_valid_number, '共立湊病院');
ok($zip->set_number('4150194')->is_valid_number, '南伊豆町観光協会');
ok($zip->set_number('4150392')->is_valid_number, '南伊豆町役場');
ok($zip->set_number('4158501')->is_valid_number, '下田市役所');
ok($zip->set_number('4158502')->is_valid_number, '藤田観光 (株) 下田事業所');
ok($zip->set_number('4158505')->is_valid_number, '一般社団法人 下田市観光協会');
ok($zip->set_number('4158506')->is_valid_number, '下田市 民宿組合連合会');
ok($zip->set_number('4158507')->is_valid_number, '株式会社 永谷');
ok($zip->set_number('4158508')->is_valid_number, '株式会社 静岡銀行 下田支店');
ok($zip->set_number('4158509')->is_valid_number, '下田公共職業安定所');
ok($zip->set_number('4158510')->is_valid_number, '株式会社 下田東急ホテル');
ok($zip->set_number('4158511')->is_valid_number, '株式会社 下田大和館');
ok($zip->set_number('4158512')->is_valid_number, 'ホテル伊豆急');
ok($zip->set_number('4158513')->is_valid_number, '下田ガス 株式会社');
ok($zip->set_number('4158514')->is_valid_number, '株式会社 黒船ホテル');
ok($zip->set_number('4158515')->is_valid_number, '下田税務署');
ok($zip->set_number('4158516')->is_valid_number, '賀茂米穀卸 株式会社');
ok($zip->set_number('4158517')->is_valid_number, 'サガミシード 株式会社');
ok($zip->set_number('4158518')->is_valid_number, '富士伊豆農業協同組合 伊豆太陽地区本部');
ok($zip->set_number('4158520')->is_valid_number, '静岡地方裁判所 下田支部');
ok($zip->set_number('4158521')->is_valid_number, '伊豆下田病院');
ok($zip->set_number('4158522')->is_valid_number, 'NTT 下田営業所');
ok($zip->set_number('4158523')->is_valid_number, '東京電力 株式会社 下田営業所');
ok($zip->set_number('4158524')->is_valid_number, '静岡地方法務局 下田支局');
ok($zip->set_number('4158525')->is_valid_number, '下田プリンスホテル');
ok($zip->set_number('4158526')->is_valid_number, '静岡県立下田南高等学校');
ok($zip->set_number('4158527')->is_valid_number, '静岡県立下田北高等学校');
ok($zip->set_number('4158528')->is_valid_number, '下田警察署');
ok($zip->set_number('4158530')->is_valid_number, '株式会社 サンプラーザ');
ok($zip->set_number('4158602')->is_valid_number, '下田信用金庫');
ok($zip->set_number('4158603')->is_valid_number, '下田商工会議所');
ok($zip->set_number('4158611')->is_valid_number, '河津建設 株式会社');
ok($zip->set_number('4168501')->is_valid_number, '旭化成 株式会社 富士支社');
ok($zip->set_number('4168521')->is_valid_number, '東芝キャリア 株式会社');
ok($zip->set_number('4168530')->is_valid_number, '日本製紙 株式会社 富士工場');
ok($zip->set_number('4168533')->is_valid_number, 'ポリプラスチックス 株式会社 富士工場');
ok($zip->set_number('4168540')->is_valid_number, 'オー・ジー 株式会社 富士支店');
ok($zip->set_number('4168544')->is_valid_number, '富士財務事務所');
ok($zip->set_number('4168555')->is_valid_number, '学校法人 富士学園 静岡県富士見中学校・高等学校');
ok($zip->set_number('4168558')->is_valid_number, '富士市 保健女性センター');
ok($zip->set_number('4168577')->is_valid_number, '株式会社 アールアンドケー');
ok($zip->set_number('4168650')->is_valid_number, '富士税務署');
ok($zip->set_number('4168654')->is_valid_number, '富士社会保険事務所');
ok($zip->set_number('4168655')->is_valid_number, '富士化工 株式会社');
ok($zip->set_number('4168656')->is_valid_number, '王子製紙 株式会社 富士工場');
ok($zip->set_number('4168659')->is_valid_number, '株式会社 石井組');
ok($zip->set_number('4168660')->is_valid_number, '大興製紙 株式会社');
ok($zip->set_number('4168686')->is_valid_number, '富士市 上下水道部');
ok($zip->set_number('4178501')->is_valid_number, 'アスト 株式会社');
ok($zip->set_number('4178503')->is_valid_number, '春日製紙工業 株式会社');
ok($zip->set_number('4178505')->is_valid_number, 'パーパス 株式会社');
ok($zip->set_number('4178506')->is_valid_number, '静岡県 労働金庫 吉原支店');
ok($zip->set_number('4178507')->is_valid_number, 'イデシギョー 株式会社');
ok($zip->set_number('4178508')->is_valid_number, '株式会社 ひのや');
ok($zip->set_number('4178510')->is_valid_number, '株式会社 スギヤマ');
ok($zip->set_number('4178511')->is_valid_number, '静岡地方裁判所 富士支部 静岡家庭裁判所 富士支部 富士簡易裁判所');
ok($zip->set_number('4178512')->is_valid_number, '株式会社 サンメイカ 富士支店');
ok($zip->set_number('4178519')->is_valid_number, 'NTTマーケティングアクト静岡 株式会社 富士ソリューション営業部');
ok($zip->set_number('4178520')->is_valid_number, '日本大昭和板紙吉永 株式会社');
ok($zip->set_number('4178522')->is_valid_number, '日本プラスト 株式会社');
ok($zip->set_number('4178529')->is_valid_number, '株式会社 イエローハット');
ok($zip->set_number('4178530')->is_valid_number, '日本食品化工 株式会社');
ok($zip->set_number('4178531')->is_valid_number, '川商コイル 株式会社');
ok($zip->set_number('4178533')->is_valid_number, '株式会社 中村組');
ok($zip->set_number('4178535')->is_valid_number, '三興製紙 株式会社');
ok($zip->set_number('4178538')->is_valid_number, '第一建設');
ok($zip->set_number('4178540')->is_valid_number, '株式会社 鈴木建設工業');
ok($zip->set_number('4178543')->is_valid_number, '櫻井化学興業 株式会社');
ok($zip->set_number('4178545')->is_valid_number, '県立吉原高等学校');
ok($zip->set_number('4178550')->is_valid_number, '静岡県富士工業技術支援センター');
ok($zip->set_number('4178555')->is_valid_number, '五條製紙 株式会社');
ok($zip->set_number('4178560')->is_valid_number, '株式会社 興人富士工場');
ok($zip->set_number('4178565')->is_valid_number, '株式会社 齊藤商会');
ok($zip->set_number('4178566')->is_valid_number, '静岡県富士警察署');
ok($zip->set_number('4178567')->is_valid_number, '富士市立中央病院');
ok($zip->set_number('4178570')->is_valid_number, '大昭和紙工産業');
ok($zip->set_number('4178571')->is_valid_number, '県立富士東高等学校');
ok($zip->set_number('4178575')->is_valid_number, 'ビヨンズ 株式会社');
ok($zip->set_number('4178577')->is_valid_number, '株式会社 近藤商店');
ok($zip->set_number('4178580')->is_valid_number, '株式会社 マルダイ');
ok($zip->set_number('4178585')->is_valid_number, 'ジヤトコ 株式会社');
ok($zip->set_number('4178588')->is_valid_number, '日医工ファーマテック 株式会社 静岡工場');
ok($zip->set_number('4178601')->is_valid_number, '富士市役所');
ok($zip->set_number('4178609')->is_valid_number, '富士公共職業安定所');
ok($zip->set_number('4178610')->is_valid_number, '日本製紙 株式会社 鈴川工場');
ok($zip->set_number('4178632')->is_valid_number, '富士商工会議所');
ok($zip->set_number('4178650')->is_valid_number, '興和 株式会社 富士工場');
ok($zip->set_number('4178686')->is_valid_number, '富士信用金庫');
ok($zip->set_number('4180192')->is_valid_number, '株式会社 エッチ・ケー・エス');
ok($zip->set_number('4188601')->is_valid_number, '富士宮市役所');
ok($zip->set_number('4188666')->is_valid_number, '富士写真フイルム 株式会社 富士宮工場');
ok($zip->set_number('4188686')->is_valid_number, '富士宮信用金庫');
ok($zip->set_number('4190192')->is_valid_number, '函南町役場');
ok($zip->set_number('4190193')->is_valid_number, 'NTT東日本 伊豆病院');
ok($zip->set_number('4190293')->is_valid_number, '丸井製紙 株式会社');
ok($zip->set_number('4190295')->is_valid_number, '丸富製紙 株式会社 富士根工場');
ok($zip->set_number('4190392')->is_valid_number, '富士宮市役所 芝川出張所');
ok($zip->set_number('4208501')->is_valid_number, '日本信販 株式会社 静岡統括部');
ok($zip->set_number('4208502')->is_valid_number, '静岡県立 静岡中央高等学校');
ok($zip->set_number('4208503')->is_valid_number, '株式会社 静岡リビング新聞社');
ok($zip->set_number('4208505')->is_valid_number, '三井住友建設 (株) 静岡支店');
ok($zip->set_number('4208507')->is_valid_number, '専門学校 静岡工科自動車大学校');
ok($zip->set_number('4208508')->is_valid_number, '新静岡セノバ');
ok($zip->set_number('4208509')->is_valid_number, '静鉄観光サービス 株式会社');
ok($zip->set_number('4208510')->is_valid_number, '静岡鉄道 株式会社');
ok($zip->set_number('4208511')->is_valid_number, '東海大学短期大学部');
ok($zip->set_number('4208512')->is_valid_number, '全国健康保険協会 静岡支部');
ok($zip->set_number('4208515')->is_valid_number, '株式会社 日本交通公社 静岡支店');
ok($zip->set_number('4208517')->is_valid_number, '株式会社 静岡伊勢丹');
ok($zip->set_number('4208520')->is_valid_number, '静岡広告 株式会社');
ok($zip->set_number('4208521')->is_valid_number, '富士ゼロックス 株式会社 静岡営業所');
ok($zip->set_number('4208522')->is_valid_number, '株式会社 静岡フジカラー');
ok($zip->set_number('4208523')->is_valid_number, '株式会社 青島文化教材社');
ok($zip->set_number('4208525')->is_valid_number, '相川鉄工 株式会社');
ok($zip->set_number('4208527')->is_valid_number, '静岡県立総合病院');
ok($zip->set_number('4208528')->is_valid_number, '株式会社 メガネトップ');
ok($zip->set_number('4208530')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('4208536')->is_valid_number, '株式会社 静岡三共');
ok($zip->set_number('4208537')->is_valid_number, '静岡産業技術専門学校');
ok($zip->set_number('4208538')->is_valid_number, '学校法人 静岡理工科大学');
ok($zip->set_number('4208550')->is_valid_number, '株式会社 村上開明堂');
ok($zip->set_number('4208555')->is_valid_number, '株式会社 静鉄ストア');
ok($zip->set_number('4208557')->is_valid_number, '静岡県 トラック運送健康組合');
ok($zip->set_number('4208558')->is_valid_number, '静岡県 国民健康保険団体連合会');
ok($zip->set_number('4208560')->is_valid_number, '株式会社 松阪屋 静岡店');
ok($zip->set_number('4208567')->is_valid_number, '株式会社 静岡朝日テレビ');
ok($zip->set_number('4208570')->is_valid_number, '株式会社 白形傳四郎商店');
ok($zip->set_number('4208580')->is_valid_number, 'ヤマキ 株式会社');
ok($zip->set_number('4208581')->is_valid_number, 'トヨタユナイテッド静岡 株式会社');
ok($zip->set_number('4208585')->is_valid_number, '東京海上日動火災保険 株式会社 静岡支店');
ok($zip->set_number('4208588')->is_valid_number, '常葉学園中・高等学校');
ok($zip->set_number('4208601')->is_valid_number, '静岡県庁');
ok($zip->set_number('4208602')->is_valid_number, '静岡市役所');
ok($zip->set_number('4208603')->is_valid_number, '社団法人 静岡市静岡医師会');
ok($zip->set_number('4208604')->is_valid_number, '静岡家庭裁判所');
ok($zip->set_number('4208606')->is_valid_number, '静岡税務署');
ok($zip->set_number('4208608')->is_valid_number, '静岡県立 静岡高等学校');
ok($zip->set_number('4208610')->is_valid_number, '静岡県警察本部');
ok($zip->set_number('4208611')->is_valid_number, '静岡地方検察庁');
ok($zip->set_number('4208612')->is_valid_number, '安藤建設 株式会社 静岡支店');
ok($zip->set_number('4208616')->is_valid_number, '日本生命保険 相互会社 静岡支社');
ok($zip->set_number('4208618')->is_valid_number, '農林水産省関東農政局 静岡農政事務所');
ok($zip->set_number('4208620')->is_valid_number, '静岡中央警察署');
ok($zip->set_number('4208622')->is_valid_number, '静岡労働基準監督署');
ok($zip->set_number('4208623')->is_valid_number, 'JA静岡厚生連静岡厚生病院');
ok($zip->set_number('4208624')->is_valid_number, '静岡シェル石油販売 株式会社');
ok($zip->set_number('4208628')->is_valid_number, '静岡雙葉学園');
ok($zip->set_number('4208630')->is_valid_number, '静岡市立静岡病院');
ok($zip->set_number('4208633')->is_valid_number, '静岡地方裁判所');
ok($zip->set_number('4208636')->is_valid_number, '東海財務局 静岡財務事務所');
ok($zip->set_number('4208637')->is_valid_number, '静岡県 環境衛生科学研究所');
ok($zip->set_number('4208639')->is_valid_number, '静岡労働基準局');
ok($zip->set_number('4208641')->is_valid_number, '株式会社 中日ショッパー 静岡統括部');
ok($zip->set_number('4208644')->is_valid_number, '東日本信用漁業協同組合連合会 静岡支店');
ok($zip->set_number('4208650')->is_valid_number, '静岡地方法務局');
ok($zip->set_number('4208655')->is_valid_number, '高田薬局');
ok($zip->set_number('4208660')->is_valid_number, '静岡県立 こども病院');
ok($zip->set_number('4208666')->is_valid_number, '静岡県漁業協同組合連合会');
ok($zip->set_number('4208670')->is_valid_number, '社会福祉法人 静岡県社会福祉協議会');
ok($zip->set_number('4208677')->is_valid_number, '株式会社 トーエネック 静岡支店');
ok($zip->set_number('4208680')->is_valid_number, '株式会社 帝国データバンク 静岡支店');
ok($zip->set_number('4208681')->is_valid_number, '株式会社 バンダイ お客様相談センター');
ok($zip->set_number('4208685')->is_valid_number, '西日本電信電話 株式会社 静岡支店');
ok($zip->set_number('4208688')->is_valid_number, '独立行政法人 国立病院機構 静岡てんかん神経医療センター');
ok($zip->set_number('4208703')->is_valid_number, '静岡県労働金庫');
ok($zip->set_number('4208704')->is_valid_number, '三井住友信託銀行 株式会社 静岡支店');
ok($zip->set_number('4208706')->is_valid_number, '共栄火災海上保険 株式会社');
ok($zip->set_number('4208709')->is_valid_number, '株式会社 稲葉商店');
ok($zip->set_number('4208710')->is_valid_number, '静岡県信用保証協会');
ok($zip->set_number('4208712')->is_valid_number, 'ヒダ 株式会社');
ok($zip->set_number('4208720')->is_valid_number, '日本銀行 静岡支店');
ok($zip->set_number('4208722')->is_valid_number, '大和証券 株式会社 静岡支店');
ok($zip->set_number('4208733')->is_valid_number, '中部電力 株式会社 静岡支店');
ok($zip->set_number('4208738')->is_valid_number, '株式会社 茜屋');
ok($zip->set_number('4208739')->is_valid_number, '商工組合中央金庫 静岡支店');
ok($zip->set_number('4208760')->is_valid_number, '株式会社 静岡銀行 本部');
ok($zip->set_number('4208761')->is_valid_number, '株式会社 静岡銀行 本店');
ok($zip->set_number('4210188')->is_valid_number, '株式会社 市川園');
ok($zip->set_number('4210192')->is_valid_number, '株式会社 巴川製紙所 静岡事業所');
ok($zip->set_number('4210193')->is_valid_number, '医療法人 沖縄徳洲会 静岡徳洲会病院');
ok($zip->set_number('4210195')->is_valid_number, '株式会社 平喜');
ok($zip->set_number('4210197')->is_valid_number, '中央物産 株式会社');
ok($zip->set_number('4210198')->is_valid_number, '株式会社 市川園');
ok($zip->set_number('4210292')->is_valid_number, '大井川庁舎');
ok($zip->set_number('4210293')->is_valid_number, '航空自衛隊');
ok($zip->set_number('4210298')->is_valid_number, '株式会社 ニッセー');
ok($zip->set_number('4210392')->is_valid_number, '株式会社 ライトアップショッピングクラブ');
ok($zip->set_number('4210393')->is_valid_number, '株式会社 ライトアップショッピングクラブ');
ok($zip->set_number('4210394')->is_valid_number, '株式会社 ライトアップショッピングクラブ');
ok($zip->set_number('4210395')->is_valid_number, '吉田町役場');
ok($zip->set_number('4210396')->is_valid_number, '富士写真フイルム 株式会社 吉田南工場');
ok($zip->set_number('4210397')->is_valid_number, '株式会社 ライトアップショッピングクラブ');
ok($zip->set_number('4210492')->is_valid_number, '矢崎部品 株式会社 榛原工場');
ok($zip->set_number('4210493')->is_valid_number, '榛原総合病院');
ok($zip->set_number('4210495')->is_valid_number, '牧之原市役所');
ok($zip->set_number('4210496')->is_valid_number, '日機装 株式会社 静岡製作所');
ok($zip->set_number('4210592')->is_valid_number, '牧之原市役所 相良庁舎');
ok($zip->set_number('4210593')->is_valid_number, '相良物産 株式会社');
ok($zip->set_number('4210595')->is_valid_number, 'TDK 株式会社 静岡工場');
ok($zip->set_number('4210596')->is_valid_number, '相良高等学校');
ok($zip->set_number('4210598')->is_valid_number, '東洋製罐 株式会社 静岡工場');
ok($zip->set_number('4211295')->is_valid_number, 'コクヨ西関東販売 株式会社');
ok($zip->set_number('4211298')->is_valid_number, '静岡県 静岡工業技術センター');
ok($zip->set_number('4211392')->is_valid_number, '株式会社 佐藤園');
ok($zip->set_number('4213292')->is_valid_number, 'リョービ 株式会社 静岡工場');
ok($zip->set_number('4213295')->is_valid_number, '株式会社 ホテイフーズコーポレーション');
ok($zip->set_number('4213296')->is_valid_number, 'ニチフリ食品 株式会社');
ok($zip->set_number('4213297')->is_valid_number, '日本軽金属 株式会社 蒲原製造所');
ok($zip->set_number('4213392')->is_valid_number, 'コアレックス信栄 株式会社');
ok($zip->set_number('4228502')->is_valid_number, '静岡いすず自動車 株式会社');
ok($zip->set_number('4228504')->is_valid_number, '大和ハウス工業 株式会社 静岡支店');
ok($zip->set_number('4228505')->is_valid_number, '村田工業 株式会社');
ok($zip->set_number('4228506')->is_valid_number, '静岡市 農業協同組合');
ok($zip->set_number('4228507')->is_valid_number, '太陽建機レンタル 株式会社');
ok($zip->set_number('4228509')->is_valid_number, '日産部品静岡販売 株式会社');
ok($zip->set_number('4228510')->is_valid_number, '社団法人 静岡県トラック協会');
ok($zip->set_number('4228511')->is_valid_number, '社会保険診療報酬支払基金 静岡支部');
ok($zip->set_number('4228512')->is_valid_number, '静岡日産自動車 株式会社');
ok($zip->set_number('4228514')->is_valid_number, '東海自動車工業 株式会社');
ok($zip->set_number('4228515')->is_valid_number, '静岡トヨタ自動車 株式会社');
ok($zip->set_number('4228516')->is_valid_number, '日星石油 株式会社');
ok($zip->set_number('4228517')->is_valid_number, '社団法人 日本自動車連盟 静岡支部');
ok($zip->set_number('4228518')->is_valid_number, '日産プリンス静岡販売 株式会社');
ok($zip->set_number('4228519')->is_valid_number, '矢崎化工 株式会社');
ok($zip->set_number('4228520')->is_valid_number, '静岡県 教職員生活協同組合');
ok($zip->set_number('4228521')->is_valid_number, 'トラスコ中山 株式会社 静岡営業所');
ok($zip->set_number('4228522')->is_valid_number, '株式会社 ビープラン');
ok($zip->set_number('4228523')->is_valid_number, '株式会社 オズ');
ok($zip->set_number('4228524')->is_valid_number, '株式会社 エスラップコミニュケーションズ');
ok($zip->set_number('4228525')->is_valid_number, 'テレビ静岡');
ok($zip->set_number('4228526')->is_valid_number, '静岡県立大学');
ok($zip->set_number('4228527')->is_valid_number, '静岡済生会総合病院');
ok($zip->set_number('4228528')->is_valid_number, '三菱電機 株式会社 静岡製作所');
ok($zip->set_number('4228529')->is_valid_number, '静岡大学');
ok($zip->set_number('4228530')->is_valid_number, '理研軽金属工業 株式会社');
ok($zip->set_number('4228531')->is_valid_number, '静岡大学片山寮');
ok($zip->set_number('4228545')->is_valid_number, '静岡英和学院大学 短期大学部');
ok($zip->set_number('4228550')->is_valid_number, '静岡市駿河区役所');
ok($zip->set_number('4228560')->is_valid_number, '株式会社 静岡第一テレビ');
ok($zip->set_number('4228561')->is_valid_number, '起立木工 株式会社');
ok($zip->set_number('4228562')->is_valid_number, '株式会社 グローバルアクト');
ok($zip->set_number('4228563')->is_valid_number, '株式会社 クレディア');
ok($zip->set_number('4228564')->is_valid_number, '富士工業 株式会社');
ok($zip->set_number('4228565')->is_valid_number, '東海家具工業 株式会社');
ok($zip->set_number('4228566')->is_valid_number, '真富士屋食品 株式会社');
ok($zip->set_number('4228567')->is_valid_number, '遠藤科学 株式会社');
ok($zip->set_number('4228568')->is_valid_number, 'NTT 静岡支店');
ok($zip->set_number('4228569')->is_valid_number, '株式会社 村上開明堂');
ok($zip->set_number('4228570')->is_valid_number, '旭化成ホームズ (株)');
ok($zip->set_number('4228571')->is_valid_number, '(株) ヤマシタコーポレーション');
ok($zip->set_number('4228573')->is_valid_number, '丸紅 (株) 静岡支店');
ok($zip->set_number('4228574')->is_valid_number, '(株) 富士ロジテック');
ok($zip->set_number('4228575')->is_valid_number, '(株) ホテル小田急静岡');
ok($zip->set_number('4228576')->is_valid_number, '(株) マルウ海野商店');
ok($zip->set_number('4228578')->is_valid_number, '静岡南警察署');
ok($zip->set_number('4228580')->is_valid_number, '旭化成リフォーム 株式会社 静岡事業所');
ok($zip->set_number('4228581')->is_valid_number, '常葉大学 静岡草薙キャンパス');
ok($zip->set_number('4228585')->is_valid_number, '株式会社 エヌ・ビー 中根屋');
ok($zip->set_number('4228610')->is_valid_number, '株式会社 タミヤ');
ok($zip->set_number('4228615')->is_valid_number, '株式会社 シャンソン化粧品');
ok($zip->set_number('4228619')->is_valid_number, '静岡県 農業協同組合中央会');
ok($zip->set_number('4228620')->is_valid_number, '静岡県 経済農業協同組合連合会');
ok($zip->set_number('4228621')->is_valid_number, '静岡県 信用農業協同組合連合会');
ok($zip->set_number('4228622')->is_valid_number, '全国共済農業協同組合連合会 静岡県本部');
ok($zip->set_number('4228628')->is_valid_number, '日本電信電話 株式会社 静岡情報システムサービスセンタ');
ok($zip->set_number('4228630')->is_valid_number, '静岡県 静岡財務事務所');
ok($zip->set_number('4228633')->is_valid_number, '木内建設 株式会社');
ok($zip->set_number('4228650')->is_valid_number, '平和みらい 株式会社');
ok($zip->set_number('4228654')->is_valid_number, 'スター精密 株式会社');
ok($zip->set_number('4228666')->is_valid_number, '日本レーベル印刷 株式会社');
ok($zip->set_number('4228668')->is_valid_number, '静岡社会保険事務局 静岡社会保険事務室');
ok($zip->set_number('4228670')->is_valid_number, '株式会社 静岡新聞社');
ok($zip->set_number('4228677')->is_valid_number, '株式会社 静岡鐵工所');
ok($zip->set_number('4228680')->is_valid_number, '静岡放送 株式会社');
ok($zip->set_number('4228686')->is_valid_number, '協立電機 株式会社');
ok($zip->set_number('4228688')->is_valid_number, '静岡ガス 株式会社');
ok($zip->set_number('4228766')->is_valid_number, '静岡ガス 株式会社 静岡支社');
ok($zip->set_number('4228787')->is_valid_number, '日本放送協会 静岡放送局');
ok($zip->set_number('4240192')->is_valid_number, '清水農業協同組合');
ok($zip->set_number('4240193')->is_valid_number, 'JA静岡厚生連 清水厚生病院');
ok($zip->set_number('4240292')->is_valid_number, '独立行政法人 農業・食品産業技術総合研究機構 果樹研究所カンキツ研究興津拠点');
ok($zip->set_number('4248502')->is_valid_number, '東海溶材 株式会社');
ok($zip->set_number('4248503')->is_valid_number, '静岡スバル自動車 株式会社');
ok($zip->set_number('4248510')->is_valid_number, '株式会社 アイ・テック');
ok($zip->set_number('4248511')->is_valid_number, '東洋冷蔵 株式会社(清水)');
ok($zip->set_number('4248550')->is_valid_number, '静岡県立 清水東高等学校');
ok($zip->set_number('4248555')->is_valid_number, '菊池建設 株式会社');
ok($zip->set_number('4248558')->is_valid_number, '日本ケミカル工業 株式会社');
ok($zip->set_number('4248566')->is_valid_number, '株式会社 駿河生産プラットフォーム');
ok($zip->set_number('4248601')->is_valid_number, '社会保険 桜ケ丘総合病院');
ok($zip->set_number('4248602')->is_valid_number, '静岡コンピューターサービス 株式会社');
ok($zip->set_number('4248603')->is_valid_number, 'JFEエンジニアリング 株式会社 清水製作所');
ok($zip->set_number('4248610')->is_valid_number, '東海大学 清水校舎');
ok($zip->set_number('4248611')->is_valid_number, '東海大学付属翔洋中等・高等学校');
ok($zip->set_number('4248620')->is_valid_number, '東海大学 社会教育センター');
ok($zip->set_number('4248622')->is_valid_number, '静岡県立 清水南高等学校');
ok($zip->set_number('4248624')->is_valid_number, '学校法人 星美学園');
ok($zip->set_number('4248631')->is_valid_number, '三井・デュポンフロロケミカル 株式会社 清水工場');
ok($zip->set_number('4248633')->is_valid_number, '独立行政法人 水産総合研究センター 国際水産資源研究所');
ok($zip->set_number('4248636')->is_valid_number, '静岡市立 清水病院');
ok($zip->set_number('4248637')->is_valid_number, '静岡県立 清水西高等学校');
ok($zip->set_number('4248648')->is_valid_number, '大和製缶 株式会社');
ok($zip->set_number('4248650')->is_valid_number, '静岡地方法務局 清水出張所');
ok($zip->set_number('4248666')->is_valid_number, '清和海運 株式会社');
ok($zip->set_number('4248668')->is_valid_number, '株式会社 古川組 静岡支店');
ok($zip->set_number('4248677')->is_valid_number, '株式会社 静岡銀行');
ok($zip->set_number('4248678')->is_valid_number, '独立行政法人 海員学校国立清水海上技術短期大学校');
ok($zip->set_number('4248686')->is_valid_number, '株式会社 カナサシ重工');
ok($zip->set_number('4248688')->is_valid_number, '協和医科器械 株式会社');
ok($zip->set_number('4248701')->is_valid_number, '静岡市役所 清水庁舎');
ok($zip->set_number('4248708')->is_valid_number, '村上貿易 株式会社');
ok($zip->set_number('4248715')->is_valid_number, '株式会社 清水銀行');
ok($zip->set_number('4248717')->is_valid_number, '株式会社 三明');
ok($zip->set_number('4248719')->is_valid_number, '株式会社 日本平ホテル');
ok($zip->set_number('4248720')->is_valid_number, '株式会社 ノダ 清水事業所');
ok($zip->set_number('4248721')->is_valid_number, '株式会社 静岡銀行 清水支店');
ok($zip->set_number('4248724')->is_valid_number, '東燃ゼネラル石油 株式会社 清水油漕所');
ok($zip->set_number('4248727')->is_valid_number, '望月燃料 株式会社');
ok($zip->set_number('4248730')->is_valid_number, '株式会社 ヤヨイサンフーズ');
ok($zip->set_number('4248734')->is_valid_number, '清水商工会議所');
ok($zip->set_number('4248750')->is_valid_number, 'はごろもフーズ 株式会社');
ok($zip->set_number('4248751')->is_valid_number, '清水税務署');
ok($zip->set_number('4248752')->is_valid_number, '静岡市立 清水商業高等学校');
ok($zip->set_number('4248755')->is_valid_number, '北静木材 株式会社');
ok($zip->set_number('4248760')->is_valid_number, 'アオキトランス 株式会社');
ok($zip->set_number('4248767')->is_valid_number, 'クミアイ化学工業 株式会社');
ok($zip->set_number('4248782')->is_valid_number, '株式会社 とらや');
ok($zip->set_number('4258501')->is_valid_number, '焼津信用金庫');
ok($zip->set_number('4258502')->is_valid_number, '焼津市役所');
ok($zip->set_number('4258503')->is_valid_number, '株式会社 菱食 静岡支店');
ok($zip->set_number('4258505')->is_valid_number, '焼津市立総合病院');
ok($zip->set_number('4258508')->is_valid_number, '株式会社 ハットリ製茶');
ok($zip->set_number('4258511')->is_valid_number, '株式会社 赤阪鉄工所');
ok($zip->set_number('4258522')->is_valid_number, 'サッポロビール 株式会社 静岡工場');
ok($zip->set_number('4258533')->is_valid_number, '焼津簡易保険保養センター');
ok($zip->set_number('4258555')->is_valid_number, '株式会社 ビック東海 西静支社');
ok($zip->set_number('4258560')->is_valid_number, '株式会社 アンビ・ア');
ok($zip->set_number('4258570')->is_valid_number, '焼津水産化学工業 株式会社');
ok($zip->set_number('4258585')->is_valid_number, '焼津市文化会館');
ok($zip->set_number('4258611')->is_valid_number, '静岡福祉大学');
ok($zip->set_number('4258680')->is_valid_number, '株式会社 富士屋');
ok($zip->set_number('4258686')->is_valid_number, '石原水産 株式会社');
ok($zip->set_number('4258701')->is_valid_number, '焼津漁業協同組合');
ok($zip->set_number('4258708')->is_valid_number, '株式会社 柳屋 本店');
ok($zip->set_number('4258711')->is_valid_number, '株式会社 ハセガワ');
ok($zip->set_number('4260292')->is_valid_number, '日本ビクター 株式会社 モーター事業部');
ok($zip->set_number('4268501')->is_valid_number, '株式会社 大黒屋');
ok($zip->set_number('4268503')->is_valid_number, '株式会社 静岡産業社 藤枝営業所');
ok($zip->set_number('4268510')->is_valid_number, '富士鋼業 株式会社');
ok($zip->set_number('4268511')->is_valid_number, '株式会社 マルタカ');
ok($zip->set_number('4268515')->is_valid_number, 'ヤマキ 株式会社 藤枝支店');
ok($zip->set_number('4268539')->is_valid_number, '株式会社 ツムラ 静岡工場');
ok($zip->set_number('4268543')->is_valid_number, '株式会社 西友 藤枝店');
ok($zip->set_number('4268566')->is_valid_number, '株式会社 扶桑工業');
ok($zip->set_number('4268570')->is_valid_number, '株式会社 アライドマテリアル');
ok($zip->set_number('4268575')->is_valid_number, '株式会社 山田組');
ok($zip->set_number('4268577')->is_valid_number, '静岡県立 藤枝東高等学校');
ok($zip->set_number('4268601')->is_valid_number, '株式会社 村上開明堂 藤枝工場');
ok($zip->set_number('4268612')->is_valid_number, '住友ベークライト 株式会社');
ok($zip->set_number('4268617')->is_valid_number, '有限会社 新日邦');
ok($zip->set_number('4268631')->is_valid_number, '藤枝製紙 株式会社');
ok($zip->set_number('4268632')->is_valid_number, '株式会社 ツチヤコーポレーション');
ok($zip->set_number('4268633')->is_valid_number, '共和成産 株式会社');
ok($zip->set_number('4268638')->is_valid_number, '財団法人 静岡県予防医学協会 総合健診センター ヘルスポート');
ok($zip->set_number('4268640')->is_valid_number, '持田製薬 株式会社 藤枝事業所');
ok($zip->set_number('4268642')->is_valid_number, '日清紡 藤枝工場');
ok($zip->set_number('4268646')->is_valid_number, '科研製薬 株式会社 静岡工場');
ok($zip->set_number('4268662')->is_valid_number, '医療法人社団 平成会藤枝平成記念病院');
ok($zip->set_number('4268663')->is_valid_number, '藤枝財務事務所');
ok($zip->set_number('4268666')->is_valid_number, '株式会社 藤越');
ok($zip->set_number('4268668')->is_valid_number, '静岡産業大学 国際情報学部');
ok($zip->set_number('4268670')->is_valid_number, '株式会社 ニシムラ');
ok($zip->set_number('4268677')->is_valid_number, '藤枝市立総合病院');
ok($zip->set_number('4268711')->is_valid_number, '藤枝 税務署');
ok($zip->set_number('4268722')->is_valid_number, '藤枝市役所');
ok($zip->set_number('4270193')->is_valid_number, '静岡カントリー事務センター 株式会社 東興');
ok($zip->set_number('4270195')->is_valid_number, '株式会社 ヤマシタコーポレーション 静岡事業所');
ok($zip->set_number('4270196')->is_valid_number, '(株)ヤマシタコーポレーション 本社業務部');
ok($zip->set_number('4278501')->is_valid_number, '島田市役所');
ok($zip->set_number('4278502')->is_valid_number, '市立島田市民病院');
ok($zip->set_number('4278505')->is_valid_number, '東海加工紙 株式会社');
ok($zip->set_number('4278508')->is_valid_number, '島田労働基準監督署');
ok($zip->set_number('4278509')->is_valid_number, '島田公共職業安定所');
ok($zip->set_number('4278510')->is_valid_number, '東海パルプ 株式会社');
ok($zip->set_number('4278511')->is_valid_number, '株式会社 シズテー');
ok($zip->set_number('4278512')->is_valid_number, 'サカイ産業 株式会社');
ok($zip->set_number('4278522')->is_valid_number, '大河原建設 株式会社');
ok($zip->set_number('4278541')->is_valid_number, '静岡県立島田工業高等学校');
ok($zip->set_number('4278555')->is_valid_number, '矢崎計器 株式会社 島田製作所');
ok($zip->set_number('4278581')->is_valid_number, '日清紡 株式会社 島田工場');
ok($zip->set_number('4278588')->is_valid_number, '静岡県立島田高等学校');
ok($zip->set_number('4278601')->is_valid_number, '島田 税務署');
ok($zip->set_number('4278602')->is_valid_number, '島田信用金庫');
ok($zip->set_number('4278686')->is_valid_number, '島田信用金庫 事務集中部');
ok($zip->set_number('4280192')->is_valid_number, '白瀧製茶 株式会社');
ok($zip->set_number('4288501')->is_valid_number, '野菜茶業試験場');
ok($zip->set_number('4288502')->is_valid_number, '株式会社 寺田製作所');
ok($zip->set_number('4288503')->is_valid_number, '大井川鉄道 株式会社');
ok($zip->set_number('4288650')->is_valid_number, '島田市役所 金谷支所');
ok($zip->set_number('4288651')->is_valid_number, 'ティーライフ 株式会社');
ok($zip->set_number('4288652')->is_valid_number, 'サンエムパッケージ 株式会社');
ok($zip->set_number('4288686')->is_valid_number, 'なかすぎ園');
ok($zip->set_number('4300897')->is_valid_number, '浜松市 南区役所');
ok($zip->set_number('4300898')->is_valid_number, '株式会社 マルイチ');
ok($zip->set_number('4308510')->is_valid_number, '共和レザー 株式会社');
ok($zip->set_number('4308511')->is_valid_number, 'ホテル クラウンパレス浜松');
ok($zip->set_number('4308520')->is_valid_number, '静岡地方裁判所 浜松支部');
ok($zip->set_number('4308530')->is_valid_number, 'アズマ工業 (株)');
ok($zip->set_number('4308533')->is_valid_number, '公立大学法人 静岡文化芸術大学');
ok($zip->set_number('4308536')->is_valid_number, '豊島 株式会社 浜松支店');
ok($zip->set_number('4308540')->is_valid_number, '日管 (株)');
ok($zip->set_number('4308553')->is_valid_number, '小栗 株式会社');
ok($zip->set_number('4308555')->is_valid_number, '株式会社 大誠');
ok($zip->set_number('4308558')->is_valid_number, '聖隷浜松病院');
ok($zip->set_number('4308560')->is_valid_number, '遠州綿業 株式会社');
ok($zip->set_number('4308570')->is_valid_number, '浜松簡易裁判所');
ok($zip->set_number('4308575')->is_valid_number, 'K・MIX 静岡エフエム放送');
ok($zip->set_number('4308577')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('4308580')->is_valid_number, '榎本 株式会社');
ok($zip->set_number('4308585')->is_valid_number, '浜松西税務署');
ok($zip->set_number('4308587')->is_valid_number, '浜松ホトニクス 株式会社 本社事務所');
ok($zip->set_number('4308588')->is_valid_number, '株式会社 遠鉄百貨店');
ok($zip->set_number('4308611')->is_valid_number, '浜松エフエム放送 株式会社 FM Haro!');
ok($zip->set_number('4308620')->is_valid_number, '静岡家庭裁判所 浜松支部');
ok($zip->set_number('4308630')->is_valid_number, '静岡地方検察庁浜松支部,浜松区検察庁');
ok($zip->set_number('4308639')->is_valid_number, '浜松労働基準監督署');
ok($zip->set_number('4308650')->is_valid_number, 'ヤマハ 株式会社');
ok($zip->set_number('4308652')->is_valid_number, '浜松市役所・浜松市中区役所');
ok($zip->set_number('4308653')->is_valid_number, '浜松市役所・浜松市中区役所');
ok($zip->set_number('4308654')->is_valid_number, '株式会社 静岡銀行 浜松営業部');
ok($zip->set_number('4308655')->is_valid_number, '遠州鉄道 株式会社');
ok($zip->set_number('4308665')->is_valid_number, '株式会社 河合楽器製作所');
ok($zip->set_number('4308667')->is_valid_number, '浜松東税務署');
ok($zip->set_number('4308668')->is_valid_number, '西日本電信電話 株式会社 浜松市支店');
ok($zip->set_number('4308670')->is_valid_number, '浜松信用金庫');
ok($zip->set_number('4308675')->is_valid_number, '大和証券 株式会社 浜松支店');
ok($zip->set_number('4308677')->is_valid_number, '株式会社 ウチゲン');
ok($zip->set_number('4308678')->is_valid_number, '中村建設 株式会社');
ok($zip->set_number('4308680')->is_valid_number, '商工組合中央金庫 浜松支店');
ok($zip->set_number('4308686')->is_valid_number, '三立製菓 株式会社');
ok($zip->set_number('4308687')->is_valid_number, '豊田通商 株式会社 浜松支店');
ok($zip->set_number('4308689')->is_valid_number, '遠州信用金庫');
ok($zip->set_number('4310192')->is_valid_number, '株式会社 アツミテック');
ok($zip->set_number('4310193')->is_valid_number, '浜松西区役所 雄踏地域自治センター');
ok($zip->set_number('4310292')->is_valid_number, '舞阪地域自治センター');
ok($zip->set_number('4310295')->is_valid_number, '大和養魚 株式会社');
ok($zip->set_number('4310298')->is_valid_number, 'スズキ直納 株式会社');
ok($zip->set_number('4310395')->is_valid_number, '湖西市 新居支所');
ok($zip->set_number('4310492')->is_valid_number, '湖西市役所');
ok($zip->set_number('4310493')->is_valid_number, '株式会社 デンソー湖西製作所');
ok($zip->set_number('4310494')->is_valid_number, '株式会社 ユニバンス');
ok($zip->set_number('4310495')->is_valid_number, 'FDK 株式会社 湖西工場');
ok($zip->set_number('4310496')->is_valid_number, 'ソニーブロードキャストプロダクツ 株式会社');
ok($zip->set_number('4311392')->is_valid_number, '社会福祉法人 聖隷福祉事業団 浜名湖エデンの園');
ok($zip->set_number('4311393')->is_valid_number, '財団法人 日本老人福祉財団 浜松ゆうゆうの里');
ok($zip->set_number('4311394')->is_valid_number, '株式会社 エフ・シー・シー');
ok($zip->set_number('4311395')->is_valid_number, '浜松市北区役所・細江地域自治センター');
ok($zip->set_number('4311495')->is_valid_number, '北区三ヶ日地域自治センター');
ok($zip->set_number('4311496')->is_valid_number, '浜名湖三ケ日簡易保険保養センター');
ok($zip->set_number('4311497')->is_valid_number, '三ケ日町 農業協同組合');
ok($zip->set_number('4312295')->is_valid_number, '引佐地域自治センター');
ok($zip->set_number('4313192')->is_valid_number, '浜松医科大学');
ok($zip->set_number('4313193')->is_valid_number, 'とぴあ浜松農業協同組合');
ok($zip->set_number('4313194')->is_valid_number, '株式会社 ユタカ技研');
ok($zip->set_number('4313195')->is_valid_number, '株式会社 日進機械製作所');
ok($zip->set_number('4313196')->is_valid_number, '浜松ホトニクス 株式会社 常光製作所');
ok($zip->set_number('4313392')->is_valid_number, '浜松市天竜区役所');
ok($zip->set_number('4313393')->is_valid_number, '矢崎エナジーシステム 株式会社 天竜工場');
ok($zip->set_number('4313492')->is_valid_number, '天竜厚生会');
ok($zip->set_number('4314195')->is_valid_number, '水窪協働センター');
ok($zip->set_number('4328501')->is_valid_number, '浜松商工会議所');
ok($zip->set_number('4328507')->is_valid_number, '株式会社 聴涛館');
ok($zip->set_number('4328508')->is_valid_number, '株式会社 丸八真綿');
ok($zip->set_number('4328521')->is_valid_number, '株式会社 クラベ');
ok($zip->set_number('4328522')->is_valid_number, 'エンシュウ 株式会社');
ok($zip->set_number('4328523')->is_valid_number, '沢根スプリング 株式会社');
ok($zip->set_number('4328528')->is_valid_number, 'ヤマハ発動機 株式会社 浜松マリン事業所');
ok($zip->set_number('4328531')->is_valid_number, '天方産業 株式会社');
ok($zip->set_number('4328532')->is_valid_number, '中泉 株式会社 浜松支店');
ok($zip->set_number('4328537')->is_valid_number, '浜松公共職業安定所');
ok($zip->set_number('4328539')->is_valid_number, '株式会社 不二');
ok($zip->set_number('4328541')->is_valid_number, '中部電力パワーグリッド 株式会社 浜松営業所');
ok($zip->set_number('4328550')->is_valid_number, '浜松市保健所');
ok($zip->set_number('4328551')->is_valid_number, '航空自衛隊 浜松基地');
ok($zip->set_number('4328555')->is_valid_number, '浜松労働基準監督署');
ok($zip->set_number('4328561')->is_valid_number, '静岡大学 工学部');
ok($zip->set_number('4328562')->is_valid_number, '須山建設 株式会社');
ok($zip->set_number('4328580')->is_valid_number, '財団法人 浜松市医療公社 浜松医療センター');
ok($zip->set_number('4328608')->is_valid_number, '株式会社 丸八');
ok($zip->set_number('4328611')->is_valid_number, 'スズキ 株式会社');
ok($zip->set_number('4328626')->is_valid_number, '日本年金機構 浜松西年金事務所');
ok($zip->set_number('4328680')->is_valid_number, '株式会社 ハマネツ');
ok($zip->set_number('4328686')->is_valid_number, '静岡県立 浜松大平台高等学校');
ok($zip->set_number('4328777')->is_valid_number, 'SLC浜松西');
ok($zip->set_number('4338501')->is_valid_number, '本田技研工業 株式会社 浜松製作所');
ok($zip->set_number('4338511')->is_valid_number, '浜松市 リハビリテーション病院');
ok($zip->set_number('4338550')->is_valid_number, '株式会社 栃木屋 東海営業所');
ok($zip->set_number('4338555')->is_valid_number, 'ユニー (株) アピタ初生店');
ok($zip->set_number('4338558')->is_valid_number, '社会福祉法人 聖隷福祉事業団 聖隷三方原病院');
ok($zip->set_number('4338567')->is_valid_number, '浜松工業高校');
ok($zip->set_number('4338601')->is_valid_number, '浜松信用金庫 事務集中部');
ok($zip->set_number('4348501')->is_valid_number, 'ヤマハ発動機 株式会社 浜北工場');
ok($zip->set_number('4348502')->is_valid_number, 'プレ葉ウォーク浜北');
ok($zip->set_number('4348505')->is_valid_number, '静岡県立浜北特別支援学校');
ok($zip->set_number('4348511')->is_valid_number, '独立行政法人 国立病院機構 天竜病院');
ok($zip->set_number('4348533')->is_valid_number, '浜松赤十字病院');
ok($zip->set_number('4348550')->is_valid_number, '浜松市 浜北区役所');
ok($zip->set_number('4348601')->is_valid_number, '浜松ホトニクス 株式会社 中央研究所');
ok($zip->set_number('4358502')->is_valid_number, '浜松プラザウエスト');
ok($zip->set_number('4358505')->is_valid_number, 'オー・ジー 株式会社 浜松支店');
ok($zip->set_number('4358510')->is_valid_number, '株式会社 スズケン 浜松支店');
ok($zip->set_number('4358515')->is_valid_number, '株式会社 マルト 神戸屋');
ok($zip->set_number('4358520')->is_valid_number, 'ナガセ東海 株式会社');
ok($zip->set_number('4358522')->is_valid_number, '東海染工 株式会社 浜松事業所');
ok($zip->set_number('4358533')->is_valid_number, '大興産業 株式会社');
ok($zip->set_number('4358539')->is_valid_number, '浜松日産自動車 株式会社');
ok($zip->set_number('4358540')->is_valid_number, '株式会社 マキ製作所');
ok($zip->set_number('4358551')->is_valid_number, 'ネッツトヨタ静浜 株式会社');
ok($zip->set_number('4358555')->is_valid_number, '中日新聞社 東海本社');
ok($zip->set_number('4358557')->is_valid_number, '株式会社 中日ショッパー');
ok($zip->set_number('4358558')->is_valid_number, '浜松ホトニクス 株式会社 本社工場');
ok($zip->set_number('4358560')->is_valid_number, '(株)ソミック石川');
ok($zip->set_number('4358561')->is_valid_number, '(株) 出雲流通センター');
ok($zip->set_number('4358567')->is_valid_number, 'ヤマハ (株) 天竜工場');
ok($zip->set_number('4358568')->is_valid_number, 'ヤマハファインテック (株)');
ok($zip->set_number('4358575')->is_valid_number, '矢崎総業 (株)');
ok($zip->set_number('4358585')->is_valid_number, 'ソニーイーエムシーエス 株式会社 浜松テック');
ok($zip->set_number('4358588')->is_valid_number, '弥栄商事 株式会社');
ok($zip->set_number('4358611')->is_valid_number, '株式会社 コーエイ');
ok($zip->set_number('4358619')->is_valid_number, '浜松東社会保険事務所');
ok($zip->set_number('4358642')->is_valid_number, '浜松市保健環境研究所');
ok($zip->set_number('4358660')->is_valid_number, '株式会社 スクロール');
ok($zip->set_number('4358661')->is_valid_number, '株式会社 静岡メイカン');
ok($zip->set_number('4358686')->is_valid_number, '浜松市 東区役所');
ok($zip->set_number('4368501')->is_valid_number, 'NECプラットフォームズ 株式会社');
ok($zip->set_number('4368502')->is_valid_number, '掛川市立総合病院');
ok($zip->set_number('4368503')->is_valid_number, 'ダイレクトワン 株式会社');
ok($zip->set_number('4368555')->is_valid_number, '掛川市・袋井市病院企業団立 中東遠総合医療センター');
ok($zip->set_number('4368650')->is_valid_number, '掛川市役所');
ok($zip->set_number('4368651')->is_valid_number, '掛川信用金庫');
ok($zip->set_number('4368652')->is_valid_number, '掛川 税務署');
ok($zip->set_number('4368653')->is_valid_number, '日本年金機構 掛川年金事務所');
ok($zip->set_number('4368701')->is_valid_number, 'トッパン・フォームズ東海 株式会社');
ok($zip->set_number('4370292')->is_valid_number, 'ヤマハモーターエレクトロニクス 株式会社');
ok($zip->set_number('4370293')->is_valid_number, '森町役場');
ok($zip->set_number('4370692')->is_valid_number, '春野協働センター');
ok($zip->set_number('4370693')->is_valid_number, '秋葉神社');
ok($zip->set_number('4371192')->is_valid_number, '袋井市 浅羽支所');
ok($zip->set_number('4371193')->is_valid_number, 'ミネベア 株式会社 浜松製作所');
ok($zip->set_number('4371194')->is_valid_number, '株式会社 ショーワ 浅羽工場');
ok($zip->set_number('4371195')->is_valid_number, '天龍製鋸 株式会社');
ok($zip->set_number('4371196')->is_valid_number, '株式会社 スタジオコバ');
ok($zip->set_number('4371197')->is_valid_number, '日本ハイパック 株式会社 静岡工場');
ok($zip->set_number('4371292')->is_valid_number, '磐田市 福田支所');
ok($zip->set_number('4371392')->is_valid_number, '株式会社 遠興');
ok($zip->set_number('4371393')->is_valid_number, '掛川市役所 大須賀支所');
ok($zip->set_number('4371395')->is_valid_number, '横須賀高等学校');
ok($zip->set_number('4371397')->is_valid_number, 'コーニングジャパン 株式会社');
ok($zip->set_number('4371492')->is_valid_number, '株式会社 キャタラー');
ok($zip->set_number('4371493')->is_valid_number, '株式会社 プロスパイラマニュファクチャリング');
ok($zip->set_number('4371494')->is_valid_number, '矢崎部品 株式会社 大浜工場');
ok($zip->set_number('4371495')->is_valid_number, '積水ハウス 株式会社 静岡工場');
ok($zip->set_number('4371496')->is_valid_number, 'クラリアントジャパン 株式会社 静岡工場');
ok($zip->set_number('4371592')->is_valid_number, '菊川市役所小笠支所');
ok($zip->set_number('4371593')->is_valid_number, '遠州夢咲 農業協同組合');
ok($zip->set_number('4371594')->is_valid_number, 'フガク工機 株式会社');
ok($zip->set_number('4371686')->is_valid_number, '株式会社 静岡カントリー 浜岡コース');
ok($zip->set_number('4371688')->is_valid_number, '御前崎市総合保健福祉センター');
ok($zip->set_number('4371692')->is_valid_number, '御前崎市役所');
ok($zip->set_number('4371693')->is_valid_number, '東海サンド 株式会社');
ok($zip->set_number('4371694')->is_valid_number, '御前崎市教育会館・市役所 御前崎支所');
ok($zip->set_number('4371695')->is_valid_number, '中部電力 株式会社 浜岡原子力発電所 総合事務所');
ok($zip->set_number('4371696')->is_valid_number, '市立御前崎総合病院');
ok($zip->set_number('4371697')->is_valid_number, 'シェブロンジャパン 株式会社 御前崎事業場');
ok($zip->set_number('4371698')->is_valid_number, 'エイケン工業 株式会社');
ok($zip->set_number('4378501')->is_valid_number, '株式会社 静岡カントリー 袋井コース');
ok($zip->set_number('4378502')->is_valid_number, 'ティーライフ 株式会社 物流センター');
ok($zip->set_number('4378511')->is_valid_number, '静岡パイオニア 株式会社');
ok($zip->set_number('4378545')->is_valid_number, 'エヌエスケー・ワーナー 株式会社');
ok($zip->set_number('4378555')->is_valid_number, '静岡理工科大学');
ok($zip->set_number('4378601')->is_valid_number, '静岡製機 株式会社');
ok($zip->set_number('4378611')->is_valid_number, '豊田肥料 株式会社');
ok($zip->set_number('4378666')->is_valid_number, '袋井市役所');
ok($zip->set_number('4378686')->is_valid_number, '丸尾興商 株式会社');
ok($zip->set_number('4380192')->is_valid_number, 'ヤマハ 株式会社 豊岡工場');
ok($zip->set_number('4380193')->is_valid_number, '浜松ホトニクス 株式会社 豊岡製作所');
ok($zip->set_number('4380195')->is_valid_number, '磐田市 豊岡支所');
ok($zip->set_number('4380292')->is_valid_number, '磐田市 竜洋支所');
ok($zip->set_number('4388501')->is_valid_number, 'ヤマハ発動機 株式会社');
ok($zip->set_number('4388510')->is_valid_number, 'NTN (株)');
ok($zip->set_number('4388543')->is_valid_number, '遠菱アルミホイール 株式会社');
ok($zip->set_number('4388550')->is_valid_number, '磐田市立総合病院');
ok($zip->set_number('4388555')->is_valid_number, '王子コンテナー 株式会社 静岡工場');
ok($zip->set_number('4388558')->is_valid_number, '静岡県 中遠農林事務所');
ok($zip->set_number('4388577')->is_valid_number, '県立農林大学校');
ok($zip->set_number('4388585')->is_valid_number, '磐田労働基準監督署');
ok($zip->set_number('4388601')->is_valid_number, '磐田市 豊田支所');
ok($zip->set_number('4388611')->is_valid_number, '大日精化工業 株式会社 東海製造事業所');
ok($zip->set_number('4388622')->is_valid_number, '静岡県 西部健康福祉センター');
ok($zip->set_number('4388650')->is_valid_number, '磐田市役所');
ok($zip->set_number('4388686')->is_valid_number, '磐田南高等学校');
ok($zip->set_number('4388711')->is_valid_number, '磐田 税務署');
ok($zip->set_number('4388718')->is_valid_number, '磐田農業高等学校');
ok($zip->set_number('4398650')->is_valid_number, '菊川市役所');
ok($zip->set_number('4398651')->is_valid_number, '旭テック 株式会社');
ok($zip->set_number('4408501')->is_valid_number, '豊橋市役所');
ok($zip->set_number('4408502')->is_valid_number, '豊橋市上下水道局');
ok($zip->set_number('4408504')->is_valid_number, '豊橋税務署');
ok($zip->set_number('4408505')->is_valid_number, 'NTT 三河支店');
ok($zip->set_number('4408506')->is_valid_number, '豊橋労働基準監督署');
ok($zip->set_number('4408507')->is_valid_number, '豊橋公共職業安定所');
ok($zip->set_number('4408508')->is_valid_number, '豊橋商工会議所');
ok($zip->set_number('4408510')->is_valid_number, '国立病院機構豊橋医療センター');
ok($zip->set_number('4408511')->is_valid_number, '豊橋創造大学');
ok($zip->set_number('4408512')->is_valid_number, '豊橋創造大学 短期大学部');
ok($zip->set_number('4408513')->is_valid_number, '鈴与商事 株式会社 豊橋支店');
ok($zip->set_number('4408514')->is_valid_number, 'マルキチ商事 有限会社');
ok($zip->set_number('4408515')->is_valid_number, '愛知県東三河総局');
ok($zip->set_number('4408516')->is_valid_number, '学校法人 桜丘学園');
ok($zip->set_number('4408517')->is_valid_number, '株式会社 精文館書店');
ok($zip->set_number('4408518')->is_valid_number, 'ササキ 株式会社');
ok($zip->set_number('4408520')->is_valid_number, '医療法人 青雲会佐野病院');
ok($zip->set_number('4408521')->is_valid_number, '株式会社 大仙');
ok($zip->set_number('4408522')->is_valid_number, '東愛知日産自動車 株式会社');
ok($zip->set_number('4408523')->is_valid_number, '中西相互 株式会社');
ok($zip->set_number('4408524')->is_valid_number, 'スバル東愛知販売 株式会社');
ok($zip->set_number('4408525')->is_valid_number, '株式会社 フジ電材');
ok($zip->set_number('4408526')->is_valid_number, '岩附 株式会社');
ok($zip->set_number('4408527')->is_valid_number, '豊橋ケーブルネットワーク 株式会社');
ok($zip->set_number('4408528')->is_valid_number, '愛知県東三河県税事務所');
ok($zip->set_number('4408530')->is_valid_number, '東海漬物 株式会社');
ok($zip->set_number('4408531')->is_valid_number, 'サーラエナジー 株式会社');
ok($zip->set_number('4408533')->is_valid_number, '株式会社 サーラコーポレーション');
ok($zip->set_number('4408543')->is_valid_number, '株式会社 エフエム豊橋');
ok($zip->set_number('4408601')->is_valid_number, '三菱ケミカル 株式会社 豊橋事業所');
ok($zip->set_number('4408603')->is_valid_number, '豊橋信用金庫');
ok($zip->set_number('4408604')->is_valid_number, '豊橋鉄道 株式会社');
ok($zip->set_number('4410193')->is_valid_number, '日本トレクス 株式会社');
ok($zip->set_number('4410194')->is_valid_number, 'サンビシ 株式会社');
ok($zip->set_number('4410195')->is_valid_number, '総合青山病院');
ok($zip->set_number('4410292')->is_valid_number, '豊川市 音羽支所');
ok($zip->set_number('4410295')->is_valid_number, '株式会社 東海理化電機製作所 音羽工場');
ok($zip->set_number('4410392')->is_valid_number, '豊川市 御津支所');
ok($zip->set_number('4410393')->is_valid_number, '株式会社 丸上製作所');
ok($zip->set_number('4411292')->is_valid_number, '豊川市一宮総合支所');
ok($zip->set_number('4411293')->is_valid_number, '豊川信用金庫 事務センター');
ok($zip->set_number('4411294')->is_valid_number, 'オーエスジー 株式会社');
ok($zip->set_number('4411295')->is_valid_number, '株式会社 UACJ銅管');
ok($zip->set_number('4411392')->is_valid_number, '新城市役所');
ok($zip->set_number('4411492')->is_valid_number, '新城市 作手総合支所');
ok($zip->set_number('4411692')->is_valid_number, '新城市 鳳来総合支所');
ok($zip->set_number('4413192')->is_valid_number, '朝日工業 株式会社');
ok($zip->set_number('4413193')->is_valid_number, '本多電子 株式会社');
ok($zip->set_number('4413194')->is_valid_number, '日東電工 株式会社 豊橋事業所');
ok($zip->set_number('4413195')->is_valid_number, 'シンフォニアテクノロジー 株式会社 豊橋製作所');
ok($zip->set_number('4413196')->is_valid_number, '福井漁網 株式会社');
ok($zip->set_number('4413492')->is_valid_number, '田原市役所');
ok($zip->set_number('4413695')->is_valid_number, '田原市役所 渥美支所');
ok($zip->set_number('4418501')->is_valid_number, 'ガステックサービス 株式会社 豊橋事業所');
ok($zip->set_number('4418502')->is_valid_number, '株式会社 住野商会');
ok($zip->set_number('4418503')->is_valid_number, '株式会社 マーメイド');
ok($zip->set_number('4418507')->is_valid_number, '渥美運輸 株式会社');
ok($zip->set_number('4418510')->is_valid_number, 'トピー工業 株式会社 豊橋製造所');
ok($zip->set_number('4418511')->is_valid_number, 'サーラE&L東三河 株式会社');
ok($zip->set_number('4418511')->is_valid_number, 'サーラエナジー 株式会社');
ok($zip->set_number('4418512')->is_valid_number, '株式会社 丸金商会');
ok($zip->set_number('4418515')->is_valid_number, '玉川屋 株式会社');
ok($zip->set_number('4418517')->is_valid_number, 'トヨタネ 株式会社');
ok($zip->set_number('4418519')->is_valid_number, 'イノチオプラントケア 株式会社');
ok($zip->set_number('4418520')->is_valid_number, 'ユタカ自動車総業 株式会社');
ok($zip->set_number('4418522')->is_valid_number, '愛知大学');
ok($zip->set_number('4418525')->is_valid_number, '愛知県経済農業 協同組合連合会');
ok($zip->set_number('4418530')->is_valid_number, '医療法人 澄心会 豊橋ハートセンター');
ok($zip->set_number('4418533')->is_valid_number, '守田屋塗料 株式会社');
ok($zip->set_number('4418539')->is_valid_number, '豊橋市保健所・保健センター及びこども発達センター');
ok($zip->set_number('4418540')->is_valid_number, 'ポップリベット・ファスナー 株式会社');
ok($zip->set_number('4418545')->is_valid_number, 'ユーアイ電子 株式会社');
ok($zip->set_number('4418550')->is_valid_number, 'フォルクスワーゲングループジャパン 株式会社');
ok($zip->set_number('4418555')->is_valid_number, '医療法人 義興会 可知病院');
ok($zip->set_number('4418558')->is_valid_number, '中部ホームサービスステーション');
ok($zip->set_number('4418560')->is_valid_number, '武蔵精密工業 株式会社');
ok($zip->set_number('4418566')->is_valid_number, 'ガステックサービス 株式会社');
ok($zip->set_number('4418570')->is_valid_number, '豊橋市民病院');
ok($zip->set_number('4418577')->is_valid_number, '株式会社 新来島豊橋造船');
ok($zip->set_number('4418580')->is_valid_number, '豊橋技術科学大学');
ok($zip->set_number('4418588')->is_valid_number, '株式会社 中部');
ok($zip->set_number('4418666')->is_valid_number, '株式会社 東愛知新聞社');
ok($zip->set_number('4418686')->is_valid_number, '伊藤ハム 株式会社 豊橋工場');
ok($zip->set_number('4428501')->is_valid_number, 'シロキ工業 株式会社');
ok($zip->set_number('4428502')->is_valid_number, '日本車輌製造 株式会社 豊川製作所');
ok($zip->set_number('4428503')->is_valid_number, 'コニカミノルタ 瑞穂サイト');
ok($zip->set_number('4428505')->is_valid_number, '新東工業 株式会社 豊川製作所');
ok($zip->set_number('4428506')->is_valid_number, 'トピー工業 株式会社 豊川製造所');
ok($zip->set_number('4428507')->is_valid_number, '名古屋大学太陽地球環境研究所');
ok($zip->set_number('4428509')->is_valid_number, '旭テック 株式会社 豊川事業所');
ok($zip->set_number('4428510')->is_valid_number, '中日精工 株式会社');
ok($zip->set_number('4428511')->is_valid_number, '千代田電子工業 株式会社');
ok($zip->set_number('4428512')->is_valid_number, '株式会社 富士精工');
ok($zip->set_number('4428513')->is_valid_number, 'バスデイ 株式会社');
ok($zip->set_number('4428515')->is_valid_number, '新東工業 株式会社 大崎事業所');
ok($zip->set_number('4428516')->is_valid_number, 'トーアス 株式会社');
ok($zip->set_number('4428517')->is_valid_number, 'ひまわり 農業協同組合');
ok($zip->set_number('4428518')->is_valid_number, 'ユニー 株式会社 アピタ豊川店');
ok($zip->set_number('4428520')->is_valid_number, '豊川信用金庫');
ok($zip->set_number('4428530')->is_valid_number, '株式会社 共栄社');
ok($zip->set_number('4428531')->is_valid_number, '石黒商事 有限会社');
ok($zip->set_number('4428532')->is_valid_number, '宮地病院');
ok($zip->set_number('4428533')->is_valid_number, '株式会社 三菱東京UFJ銀行 豊川支店');
ok($zip->set_number('4428535')->is_valid_number, '株式会社 トヨテック 本社');
ok($zip->set_number('4428538')->is_valid_number, '宗教法人 豊川閣妙厳寺');
ok($zip->set_number('4428540')->is_valid_number, '豊川商工会議所');
ok($zip->set_number('4428541')->is_valid_number, '株式会社 ツシマ');
ok($zip->set_number('4428543')->is_valid_number, 'オーエスジー 株式会社');
ok($zip->set_number('4428544')->is_valid_number, 'オーエスジー 株式会社 R&Dセンター');
ok($zip->set_number('4428545')->is_valid_number, '福山通運 株式会社 豊橋支店');
ok($zip->set_number('4428546')->is_valid_number, '株式会社 トヨコン');
ok($zip->set_number('4428550')->is_valid_number, 'イオンモール豊川');
ok($zip->set_number('4428555')->is_valid_number, 'コニカミノルタメカトロニクス 株式会社 本社');
ok($zip->set_number('4428558')->is_valid_number, 'コニカミノルタ 豊川サイト');
ok($zip->set_number('4428561')->is_valid_number, '豊川市民病院');
ok($zip->set_number('4428566')->is_valid_number, 'マルスホームデザイン');
ok($zip->set_number('4428569')->is_valid_number, '株式会社 対松堂');
ok($zip->set_number('4428573')->is_valid_number, '愛知県立豊川工業高等学校');
ok($zip->set_number('4428575')->is_valid_number, 'スズキ 株式会社 豊川工場');
ok($zip->set_number('4428576')->is_valid_number, '株式会社 アイイーメカトロニクス');
ok($zip->set_number('4428577')->is_valid_number, '岡田建設 株式会社');
ok($zip->set_number('4428580')->is_valid_number, '株式会社 AIHO');
ok($zip->set_number('4428581')->is_valid_number, '東海セイホク 株式会社');
ok($zip->set_number('4428585')->is_valid_number, 'コニカミノルタ 株式会社 三河サイト');
ok($zip->set_number('4428586')->is_valid_number, '愛知県立国府高等学校');
ok($zip->set_number('4428587')->is_valid_number, 'イトモル 株式会社');
ok($zip->set_number('4428588')->is_valid_number, 'イトモル精密株式会社');
ok($zip->set_number('4428590')->is_valid_number, '協同組合 ギフト用品卸販売二十一世紀');
ok($zip->set_number('4428591')->is_valid_number, 'TDM 株式会社');
ok($zip->set_number('4428601')->is_valid_number, '豊川市役所');
ok($zip->set_number('4428602')->is_valid_number, '陸上自衛隊 豊川駐屯地');
ok($zip->set_number('4428603')->is_valid_number, '世界心道教');
ok($zip->set_number('4430192')->is_valid_number, '泰興 株式会社');
ok($zip->set_number('4430193')->is_valid_number, '株式会社 蒲サ食品');
ok($zip->set_number('4430194')->is_valid_number, 'カネキ水産 株式会社');
ok($zip->set_number('4438505')->is_valid_number, '蒲郡商工会議所');
ok($zip->set_number('4438555')->is_valid_number, 'アイシン・エイ・ダブリュ 株式会社 蒲郡工場');
ok($zip->set_number('4438588')->is_valid_number, '学校法人 海陽学園 海陽中等教育学校');
ok($zip->set_number('4438601')->is_valid_number, '蒲郡市役所');
ok($zip->set_number('4438611')->is_valid_number, '竹本油脂 株式会社');
ok($zip->set_number('4440192')->is_valid_number, '幸田町役場');
ok($zip->set_number('4440193')->is_valid_number, '株式会社 デンソー 幸田製作所');
ok($zip->set_number('4440194')->is_valid_number, 'ソニーイーエムシーエス 株式会社 幸田テック');
ok($zip->set_number('4440381')->is_valid_number, '旭鉄工 株式会社');
ok($zip->set_number('4440391')->is_valid_number, '岡崎信用金庫 平坂支店');
ok($zip->set_number('4440392')->is_valid_number, '株式会社 オティックス');
ok($zip->set_number('4440393')->is_valid_number, '株式会社 杉浦製作所');
ok($zip->set_number('4440394')->is_valid_number, '東洋タイヤコード 株式会社');
ok($zip->set_number('4440395')->is_valid_number, '碧海工機 株式会社');
ok($zip->set_number('4440396')->is_valid_number, '幡豆工業 株式会社');
ok($zip->set_number('4440397')->is_valid_number, '(株) 松川鉄工所');
ok($zip->set_number('4440398')->is_valid_number, '阪部工業 (株)');
ok($zip->set_number('4440492')->is_valid_number, '西尾市役所 一色支所');
ok($zip->set_number('4440493')->is_valid_number, '毎味水産 株式会社');
ok($zip->set_number('4440494')->is_valid_number, 'イケダヤ製菓 株式会社');
ok($zip->set_number('4440495')->is_valid_number, '医療法人 社団福祉会 高須病院');
ok($zip->set_number('4440496')->is_valid_number, '一色高校');
ok($zip->set_number('4440592')->is_valid_number, '(株) キラ.コーポレーション');
ok($zip->set_number('4440593')->is_valid_number, '大丸産業 株式会社');
ok($zip->set_number('4440595')->is_valid_number, '朝岡ワールド 株式会社');
ok($zip->set_number('4440596')->is_valid_number, '西尾市役所 吉良支所');
ok($zip->set_number('4440798')->is_valid_number, '幡豆町役場');
ok($zip->set_number('4441192')->is_valid_number, 'アイシン・エイ・ダブリュ 株式会社');
ok($zip->set_number('4441193')->is_valid_number, '東洋理工 株式会社');
ok($zip->set_number('4441195')->is_valid_number, '株式会社 イノアックコーポレーション 桜井事業所');
ok($zip->set_number('4441198')->is_valid_number, '株式会社 南山園');
ok($zip->set_number('4441295')->is_valid_number, '株式会社 豊田自動織機 安城工場');
ok($zip->set_number('4441296')->is_valid_number, '株式会社 タケヒロ');
ok($zip->set_number('4441297')->is_valid_number, '株式会社 ニッセイ');
ok($zip->set_number('4441298')->is_valid_number, 'いずみ製菓 株式会社');
ok($zip->set_number('4441385')->is_valid_number, 'エヌティーテクノ 株式会社');
ok($zip->set_number('4441386')->is_valid_number, 'エヌティーツール 株式会社');
ok($zip->set_number('4441387')->is_valid_number, 'エヌティーエンジニアリング 株式会社');
ok($zip->set_number('4441388')->is_valid_number, 'エヌティー精密 株式会社');
ok($zip->set_number('4441393')->is_valid_number, '株式会社 豊田自動織機製作所 高浜工場');
ok($zip->set_number('4441394')->is_valid_number, '株式会社 スギヤス');
ok($zip->set_number('4441394')->is_valid_number, '株式会社 スギヤスエンタープライズ');
ok($zip->set_number('4441397')->is_valid_number, 'ユアサ建材工業 株式会社');
ok($zip->set_number('4441398')->is_valid_number, '愛知県 高浜市役所');
ok($zip->set_number('4442192')->is_valid_number, '東海光学 株式会社');
ok($zip->set_number('4442193')->is_valid_number, 'マルサンアイ 株式会社');
ok($zip->set_number('4442198')->is_valid_number, 'ミクスネットワーク 株式会社');
ok($zip->set_number('4442892')->is_valid_number, '豊田市役所 旭支所');
ok($zip->set_number('4442893')->is_valid_number, '愛知県旭高原少年自然の家');
ok($zip->set_number('4443592')->is_valid_number, '豊興工業 株式会社');
ok($zip->set_number('4443593')->is_valid_number, '株式会社 ジェイテクト 岡崎工場');
ok($zip->set_number('4443594')->is_valid_number, '株式会社 ジェイテクトグラインディングツール');
ok($zip->set_number('4443595')->is_valid_number, '株式会社 前田シェルサービス');
ok($zip->set_number('4443692')->is_valid_number, '株式会社 高木製作所 岡崎工場');
ok($zip->set_number('4443695')->is_valid_number, '日本タッパーウェア 株式会社 岡崎製作所');
ok($zip->set_number('4443696')->is_valid_number, '岡崎市役所 額田支所');
ok($zip->set_number('4443698')->is_valid_number, 'スタンレー電気 株式会社 岡崎工場');
ok($zip->set_number('4448501')->is_valid_number, '三菱自動車工業 株式会社 名古屋自動車製作所・技術センター');
ok($zip->set_number('4448503')->is_valid_number, '西三河県税事務所');
ok($zip->set_number('4448507')->is_valid_number, '東京海上火災保険 株式会社');
ok($zip->set_number('4448508')->is_valid_number, '名邦塗料商事 株式会社');
ok($zip->set_number('4448510')->is_valid_number, '日清紡績 株式会社 美合工場');
ok($zip->set_number('4448511')->is_valid_number, 'ユニチカ 株式会社 岡崎工場');
ok($zip->set_number('4448512')->is_valid_number, '東レ・モノフィラメント 株式会社');
ok($zip->set_number('4448515')->is_valid_number, '日本司法支援センター 愛知地方事務所 三河支部(法テラス三河)');
ok($zip->set_number('4448516')->is_valid_number, '槌屋ヤック 株式会社');
ok($zip->set_number('4448517')->is_valid_number, '住友生命保険 相互会社 愛知東支社');
ok($zip->set_number('4448520')->is_valid_number, '愛知学泉大学');
ok($zip->set_number('4448522')->is_valid_number, '東レ株式会社 岡崎工場');
ok($zip->set_number('4448525')->is_valid_number, 'トラスコ中山 株式会社 プラネット東海');
ok($zip->set_number('4448530')->is_valid_number, '株式会社 川本製作所 岡崎工場');
ok($zip->set_number('4448533')->is_valid_number, '名古屋法務局 岡崎支局');
ok($zip->set_number('4448540')->is_valid_number, '富士ファイン 株式会社');
ok($zip->set_number('4448542')->is_valid_number, '三菱UFJニコス 株式会社 岡崎支店');
ok($zip->set_number('4448543')->is_valid_number, '株式会社 新東');
ok($zip->set_number('4448545')->is_valid_number, '岡崎市保健所');
ok($zip->set_number('4448551')->is_valid_number, '愛知県西三河事務所');
ok($zip->set_number('4448552')->is_valid_number, '岡崎税務署');
ok($zip->set_number('4448553')->is_valid_number, '岡崎市民病院');
ok($zip->set_number('4448554')->is_valid_number, '名古屋地方裁判所 岡崎支部');
ok($zip->set_number('4448555')->is_valid_number, '愛知県立岡崎工業高等学校');
ok($zip->set_number('4448558')->is_valid_number, 'フタバ産業 株式会社');
ok($zip->set_number('4448560')->is_valid_number, '日清紡績 株式会社 美合工機工場');
ok($zip->set_number('4448564')->is_valid_number, 'アイシン・エイ・ダブリュ (株) 岡崎工場');
ok($zip->set_number('4448567')->is_valid_number, '株式会社 レッドバロン');
ok($zip->set_number('4448577')->is_valid_number, 'ユアサ商事 株式会社 岡崎支店');
ok($zip->set_number('4448580')->is_valid_number, 'マルヤス工業 株式会社 岡崎工場');
ok($zip->set_number('4448581')->is_valid_number, '志賀為 株式会社');
ok($zip->set_number('4448585')->is_valid_number, '大学共同利用機関法人 自然科学研究機構');
ok($zip->set_number('4448586')->is_valid_number, 'リコーエレメックス 株式会社 岡崎事業所');
ok($zip->set_number('4448588')->is_valid_number, '株式会社 MINEZAWA');
ok($zip->set_number('4448601')->is_valid_number, '岡崎市役所');
ok($zip->set_number('4448602')->is_valid_number, '岡崎信用金庫');
ok($zip->set_number('4448606')->is_valid_number, '中部電力パワーグリッド 株式会社 岡崎支社');
ok($zip->set_number('4448606')->is_valid_number, '中部電力ミライズ 株式会社 岡崎営業本部');
ok($zip->set_number('4448610')->is_valid_number, '大久保商事 株式会社');
ok($zip->set_number('4448611')->is_valid_number, '岡崎商工会議所');
ok($zip->set_number('4448612')->is_valid_number, '愛知県信用保証協会 西三河支店');
ok($zip->set_number('4448686')->is_valid_number, 'IPC国際ペットカルチャー総合学院');
ok($zip->set_number('4448710')->is_valid_number, '西武百貨店 岡崎店');
ok($zip->set_number('4448787')->is_valid_number, '大学共同利用機関法人 自然科学研究機構 岡崎山手地区');
ok($zip->set_number('4458501')->is_valid_number, '西尾市役所');
ok($zip->set_number('4458502')->is_valid_number, '株式会社 デンソー 西尾製作所');
ok($zip->set_number('4458503')->is_valid_number, '西尾ニュータウン開発 株式会社');
ok($zip->set_number('4458505')->is_valid_number, '西尾商工会議所');
ok($zip->set_number('4458510')->is_valid_number, '西尾市民病院');
ok($zip->set_number('4458511')->is_valid_number, '名古屋法務局 西尾支局');
ok($zip->set_number('4458555')->is_valid_number, '中日本鋳工 株式会社');
ok($zip->set_number('4458585')->is_valid_number, 'おしろタウン シャオ');
ok($zip->set_number('4458601')->is_valid_number, '西尾信用金庫');
ok($zip->set_number('4458602')->is_valid_number, '西尾税務署');
ok($zip->set_number('4468501')->is_valid_number, '安城市役所');
ok($zip->set_number('4468502')->is_valid_number, '株式会社 マキタ');
ok($zip->set_number('4468503')->is_valid_number, 'アンデン 株式会社');
ok($zip->set_number('4468504')->is_valid_number, '株式会社 イノアックコーポレーション 安城事業所');
ok($zip->set_number('4468505')->is_valid_number, '三浦電気 株式会社');
ok($zip->set_number('4468506')->is_valid_number, '愛知県経済農業協同組合連合会 西三河センター');
ok($zip->set_number('4468507')->is_valid_number, '株式会社 デンソー 高棚製作所');
ok($zip->set_number('4468508')->is_valid_number, '愛知県西三河県税事務所 安城県税センター');
ok($zip->set_number('4468511')->is_valid_number, '株式会社 デンソー 安城製作所');
ok($zip->set_number('4468512')->is_valid_number, '安城商工会議所');
ok($zip->set_number('4468514')->is_valid_number, 'タツミ商事 株式会社 豊田支店');
ok($zip->set_number('4468515')->is_valid_number, 'キャタピラーウエストジャパン 株式会社');
ok($zip->set_number('4468517')->is_valid_number, '衣浦東部保健所 安城支所');
ok($zip->set_number('4468518')->is_valid_number, '株式会社 クオリ');
ok($zip->set_number('4468520')->is_valid_number, '株式会社 ムロコーポレーション');
ok($zip->set_number('4468521')->is_valid_number, 'ユケン工業 株式会社 高棚工場');
ok($zip->set_number('4468522')->is_valid_number, '万能工業 株式会社');
ok($zip->set_number('4468523')->is_valid_number, '三河日産自動車 株式会社');
ok($zip->set_number('4468524')->is_valid_number, 'アイシン精機 株式会社 安城工場');
ok($zip->set_number('4468525')->is_valid_number, '森永製菓 株式会社 中京工場');
ok($zip->set_number('4468526')->is_valid_number, '安城簡易裁判所');
ok($zip->set_number('4468533')->is_valid_number, '株式会社 ユーハイム');
ok($zip->set_number('4468535')->is_valid_number, '株式会社 SKコーポレーション');
ok($zip->set_number('4468540')->is_valid_number, 'カリツー 株式会社');
ok($zip->set_number('4468550')->is_valid_number, '一般財団法人 杉浦地域医療振興財団');
ok($zip->set_number('4468555')->is_valid_number, '山崎製パン 株式会社 安城工場');
ok($zip->set_number('4468558')->is_valid_number, '豊臣機工 株式会社');
ok($zip->set_number('4468585')->is_valid_number, '碧海信用金庫事務センター');
ok($zip->set_number('4468588')->is_valid_number, '大見工業 株式会社');
ok($zip->set_number('4468601')->is_valid_number, 'あいち中央農業 協同組合');
ok($zip->set_number('4468602')->is_valid_number, '愛知県 厚生農業協同組合連合会 安城更生病院');
ok($zip->set_number('4468635')->is_valid_number, '安城学園高等学校');
ok($zip->set_number('4468641')->is_valid_number, '倉敷紡績 株式会社 安城工場');
ok($zip->set_number('4468686')->is_valid_number, '碧海信用金庫');
ok($zip->set_number('4478501')->is_valid_number, '碧南商工会議所');
ok($zip->set_number('4478502')->is_valid_number, '碧南市民病院');
ok($zip->set_number('4478503')->is_valid_number, '中庸スプリング 株式会社');
ok($zip->set_number('4478505')->is_valid_number, '旭鉄工 株式会社');
ok($zip->set_number('4478506')->is_valid_number, '伊藤忠製糖 株式会社');
ok($zip->set_number('4478507')->is_valid_number, '株式会社 豊田自動織機製作所 碧南工場');
ok($zip->set_number('4478510')->is_valid_number, '医療法人 愛生館 小林記念病院');
ok($zip->set_number('4478511')->is_valid_number, '株式会社 五十鈴製作所');
ok($zip->set_number('4478512')->is_valid_number, '丸栄陶業 株式会社');
ok($zip->set_number('4478601')->is_valid_number, '碧南市役所');
ok($zip->set_number('4478603')->is_valid_number, '九重味淋 株式会社');
ok($zip->set_number('4478605')->is_valid_number, '愛知県中央信用組合');
ok($zip->set_number('4478608')->is_valid_number, '日本コーンスターチ 株式会社 衣浦事業所');
ok($zip->set_number('4478610')->is_valid_number, '日本金属工業 株式会社 衣浦製造所');
ok($zip->set_number('4478680')->is_valid_number, '株式会社 平岩鉄工所');
ok($zip->set_number('4488501')->is_valid_number, '刈谷市役所');
ok($zip->set_number('4488505')->is_valid_number, '刈谷豊田総合病院');
ok($zip->set_number('4488506')->is_valid_number, '豊田通商 株式会社 刈谷支店');
ok($zip->set_number('4488511')->is_valid_number, 'ユケン工業 株式会社');
ok($zip->set_number('4488523')->is_valid_number, '刈谷税務署');
ok($zip->set_number('4488525')->is_valid_number, 'アイシン開発 株式会社 富士ビル');
ok($zip->set_number('4488531')->is_valid_number, '株式会社 東陽');
ok($zip->set_number('4488533')->is_valid_number, '株式会社 豊電子工業');
ok($zip->set_number('4488534')->is_valid_number, 'シミズ工業 株式会社');
ok($zip->set_number('4488535')->is_valid_number, 'DCMカーマ 株式会社');
ok($zip->set_number('4488540')->is_valid_number, 'ナゼロ 株式会社');
ok($zip->set_number('4488542')->is_valid_number, '国立大学法人 愛知教育大学');
ok($zip->set_number('4488543')->is_valid_number, '愛知教育大学 生活協同組合');
ok($zip->set_number('4488550')->is_valid_number, '株式会社 豊電子工業 第3工場');
ok($zip->set_number('4488601')->is_valid_number, 'アイリスオーヤマ 株式会社 名古屋営業所');
ok($zip->set_number('4488602')->is_valid_number, '株式会社 ブックセンター名豊');
ok($zip->set_number('4488605')->is_valid_number, 'アイシン・エンジニアリング 株式会社');
ok($zip->set_number('4488609')->is_valid_number, '刈谷公共職業安定所');
ok($zip->set_number('4488610')->is_valid_number, '大興運輸 株式会社 刈谷支店');
ok($zip->set_number('4488622')->is_valid_number, '株式会社 近藤組');
ok($zip->set_number('4488650')->is_valid_number, 'アイシン精機 株式会社');
ok($zip->set_number('4488651')->is_valid_number, 'トヨタ紡織 株式会社');
ok($zip->set_number('4488652')->is_valid_number, '株式会社 ジェイテクト');
ok($zip->set_number('4488653')->is_valid_number, '愛知県立 刈谷東高等学校');
ok($zip->set_number('4488655')->is_valid_number, '太田商事 株式会社');
ok($zip->set_number('4488656')->is_valid_number, '小林クリエイト 株式会社');
ok($zip->set_number('4488657')->is_valid_number, '津田工業 株式会社');
ok($zip->set_number('4488660')->is_valid_number, '中部電力パワーグリッド 株式会社 刈谷営業所');
ok($zip->set_number('4488661')->is_valid_number, '株式会社 デンソー本社');
ok($zip->set_number('4488665')->is_valid_number, 'クアーズテック (株) 刈谷事業所');
ok($zip->set_number('4488666')->is_valid_number, 'トヨタ車体 株式会社');
ok($zip->set_number('4488670')->is_valid_number, '大興運輸 株式会社 本社');
ok($zip->set_number('4488671')->is_valid_number, '株式会社 豊田自動織機');
ok($zip->set_number('4488677')->is_valid_number, '衣浦東部広域連合');
ok($zip->set_number('4488686')->is_valid_number, '株式会社 豊田自動織機 情報技術研究所');
ok($zip->set_number('4488688')->is_valid_number, '株式会社 アドヴィックス');
ok($zip->set_number('4488731')->is_valid_number, '株式会社 東陽');
ok($zip->set_number('4490292')->is_valid_number, '東栄町役場');
ok($zip->set_number('4490293')->is_valid_number, '東栄医療センター');
ok($zip->set_number('4506133')->is_valid_number, 'ジェイアールセントラルビル 株式会社');
ok($zip->set_number('4506363')->is_valid_number, '全国健康保険協会 愛知支部');
ok($zip->set_number('4506660')->is_valid_number, '名古屋JRゲートタワーホテル');
ok($zip->set_number('4508501')->is_valid_number, '名古屋鉄道 株式会社');
ok($zip->set_number('4508503')->is_valid_number, '郵便局 カタログ販売センター');
ok($zip->set_number('4508505')->is_valid_number, '株式会社 名鉄百貨店');
ok($zip->set_number('4508511')->is_valid_number, '株式会社 エディオン');
ok($zip->set_number('4508515')->is_valid_number, '株式会社 ジェイテクト 名古屋本社');
ok($zip->set_number('4508520')->is_valid_number, '三協化成産業 株式会社');
ok($zip->set_number('4508523')->is_valid_number, '森定興商 株式会社');
ok($zip->set_number('4508530')->is_valid_number, '有限責任監査法人 トーマツ');
ok($zip->set_number('4508533')->is_valid_number, '株式会社 阪急交通社 名古屋支店');
ok($zip->set_number('4508540')->is_valid_number, '明和産業 株式会社 名古屋支店');
ok($zip->set_number('4508561')->is_valid_number, '株式会社 中部経済新聞社');
ok($zip->set_number('4508567')->is_valid_number, '三機工業 株式会社 名古屋支店');
ok($zip->set_number('4508575')->is_valid_number, '豊田通商 株式会社');
ok($zip->set_number('4508577')->is_valid_number, '名鉄観光サービス 株式会社');
ok($zip->set_number('4508585')->is_valid_number, '小淺商事 株式会社');
ok($zip->set_number('4508601')->is_valid_number, '日鉄商事 株式会社 名古屋支店');
ok($zip->set_number('4508611')->is_valid_number, 'パナソニック 株式会社');
ok($zip->set_number('4508614')->is_valid_number, '東陽倉庫 株式会社');
ok($zip->set_number('4508615')->is_valid_number, '住友生命保険 相互会社 名古屋支社');
ok($zip->set_number('4508618')->is_valid_number, '名鉄協商 株式会社');
ok($zip->set_number('4508620')->is_valid_number, '藤田螺子工業 株式会社');
ok($zip->set_number('4508640')->is_valid_number, 'ダイコク電機 株式会社');
ok($zip->set_number('4508651')->is_valid_number, '株式会社 毎日新聞社 中部本社');
ok($zip->set_number('4508680')->is_valid_number, '三菱商事 株式会社 中部支社');
ok($zip->set_number('4508711')->is_valid_number, 'トヨタ自動車 株式会社 名古屋オフィス');
ok($zip->set_number('4508765')->is_valid_number, '株式会社 クレディセゾン 東海支店');
ok($zip->set_number('4508993')->is_valid_number, 'ゆうちょ銀行 名古屋中央店');
ok($zip->set_number('4508995')->is_valid_number, '株式会社 ゆうちょ銀行 東海エリア本部');
ok($zip->set_number('4508996')->is_valid_number, '日本郵政 株式会社 東海郵政健康管理センター');
ok($zip->set_number('4508997')->is_valid_number, '日本郵政 株式会社 中部施設センター');
ok($zip->set_number('4518501')->is_valid_number, '株式会社 ノリタケカンパニーリミテド');
ok($zip->set_number('4518502')->is_valid_number, '(株) 東芝 中部支社');
ok($zip->set_number('4518503')->is_valid_number, '名古屋西税務署');
ok($zip->set_number('4518508')->is_valid_number, '名古屋市西区役所');
ok($zip->set_number('4518511')->is_valid_number, '名鉄病院');
ok($zip->set_number('4518520')->is_valid_number, '名糖産業 株式会社');
ok($zip->set_number('4518522')->is_valid_number, '三菱電機 株式会社 中部支社');
ok($zip->set_number('4518541')->is_valid_number, '株式会社 ヒューマンライフ');
ok($zip->set_number('4518550')->is_valid_number, '株式会社 ヤマダヤ');
ok($zip->set_number('4518551')->is_valid_number, '株式会社 ナゴヤキャッスル');
ok($zip->set_number('4518555')->is_valid_number, '愛知県 名古屋北部県税事務所');
ok($zip->set_number('4518558')->is_valid_number, '日本年金機構 名古屋西年金事務所');
ok($zip->set_number('4518560')->is_valid_number, 'クロスプラス 株式会社');
ok($zip->set_number('4518561')->is_valid_number, '愛知県立名古屋西高等学校');
ok($zip->set_number('4518565')->is_valid_number, '山崎製パン 株式会社 名古屋工場');
ok($zip->set_number('4518568')->is_valid_number, '株式会社 フジキカイ');
ok($zip->set_number('4518570')->is_valid_number, '株式会社 カノークス');
ok($zip->set_number('4518571')->is_valid_number, '丸川製菓 株式会社');
ok($zip->set_number('4518575')->is_valid_number, '株式会社 サンゲツ');
ok($zip->set_number('4518577')->is_valid_number, '株式会社 ミヤタコーポレーション');
ok($zip->set_number('4518610')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('4518650')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('4518666')->is_valid_number, '東レ 株式会社 愛知工場');
ok($zip->set_number('4518688')->is_valid_number, 'タキヒヨー 株式会社');
ok($zip->set_number('4518701')->is_valid_number, '瀧冨工業 株式会社');
ok($zip->set_number('4528501')->is_valid_number, 'サカエ理研工業 株式会社');
ok($zip->set_number('4528502')->is_valid_number, '株式会社 フジミインコーポレーテッド');
ok($zip->set_number('4528503')->is_valid_number, '清須市役所 西枇杷島庁舎');
ok($zip->set_number('4528561')->is_valid_number, '三菱重工業 株式会社 冷熱事業本部');
ok($zip->set_number('4528562')->is_valid_number, '麒麟麦酒 株式会社 名古屋工場');
ok($zip->set_number('4528563')->is_valid_number, '清須市役所 清洲庁舎');
ok($zip->set_number('4528564')->is_valid_number, '豊田合成 株式会社');
ok($zip->set_number('4528565')->is_valid_number, '春日支所');
ok($zip->set_number('4528566')->is_valid_number, 'トッパンフォームズ東海 (株)');
ok($zip->set_number('4528567')->is_valid_number, '学校法人 トヨタ名古屋整備学園');
ok($zip->set_number('4528569')->is_valid_number, '清須市役所');
ok($zip->set_number('4528570')->is_valid_number, '御幸ホールディングス 株式会社');
ok($zip->set_number('4528601')->is_valid_number, '豊和工業 株式会社');
ok($zip->set_number('4528602')->is_valid_number, '株式会社 明電舎');
ok($zip->set_number('4538501')->is_valid_number, '中村区役所');
ok($zip->set_number('4538505')->is_valid_number, '中村県税事務所');
ok($zip->set_number('4538510')->is_valid_number, 'エスエス製薬 株式会社 名古屋支店');
ok($zip->set_number('4538511')->is_valid_number, '名古屋第一赤十字病院');
ok($zip->set_number('4538512')->is_valid_number, '株式会社 ジュニアー');
ok($zip->set_number('4538518')->is_valid_number, '愛鉄連厚生年金基金');
ok($zip->set_number('4538521')->is_valid_number, '財団法人 名古屋公衆医学研究所');
ok($zip->set_number('4538522')->is_valid_number, '山田工業 株式会社');
ok($zip->set_number('4538533')->is_valid_number, '株式会社 萬勇');
ok($zip->set_number('4538539')->is_valid_number, '株式会社 レアールパスコベーカリーズ');
ok($zip->set_number('4538540')->is_valid_number, '学校法人 同朋学園');
ok($zip->set_number('4538555')->is_valid_number, '株式会社 奥村組 名古屋支店');
ok($zip->set_number('4538558')->is_valid_number, '愛知県信用保証協会');
ok($zip->set_number('4538565')->is_valid_number, '学校法人 東京IT会計法律名古屋学園');
ok($zip->set_number('4538567')->is_valid_number, '株式会社 扇港電機');
ok($zip->set_number('4538570')->is_valid_number, '大和ハウス工業 株式会社 名古屋支社');
ok($zip->set_number('4538577')->is_valid_number, '株式会社 大同商会');
ok($zip->set_number('4538580')->is_valid_number, '明治電機工業 株式会社');
ok($zip->set_number('4538581')->is_valid_number, '株式会社 アイコー');
ok($zip->set_number('4538581')->is_valid_number, '株式会社 EXCITE');
ok($zip->set_number('4538581')->is_valid_number, '株式会社 シンセイ');
ok($zip->set_number('4538581')->is_valid_number, '株式会社 ニューギン・アドバンス');
ok($zip->set_number('4538581')->is_valid_number, '株式会社 ニューギン販売');
ok($zip->set_number('4538581')->is_valid_number, '(株) ニューギン');
ok($zip->set_number('4538585')->is_valid_number, '株式会社 ユーハイム 東海支社');
ok($zip->set_number('4538601')->is_valid_number, '中部電力パワーグリッド 株式会社 中村営業所');
ok($zip->set_number('4538608')->is_valid_number, '株式会社 ヤマナカ');
ok($zip->set_number('4538611')->is_valid_number, '河田フェザー 株式会社');
ok($zip->set_number('4538626')->is_valid_number, '名古屋市本陣市税事務所');
ok($zip->set_number('4538662')->is_valid_number, '東海デキストリン 株式会社');
ok($zip->set_number('4538686')->is_valid_number, '名古屋中村税務署');
ok($zip->set_number('4538701')->is_valid_number, '株式会社 中京テレビ事業');
ok($zip->set_number('4538702')->is_valid_number, '株式会社 サポーティング中京');
ok($zip->set_number('4538704')->is_valid_number, '中京テレビ放送 株式会社');
ok($zip->set_number('4538758')->is_valid_number, '愛知大学生活協同組合 名古屋書籍購買店');
ok($zip->set_number('4538765')->is_valid_number, '株式会社 ミスターゴルフ');
ok($zip->set_number('4538777')->is_valid_number, '学校法人 愛知大学 名古屋校舎');
ok($zip->set_number('4548501')->is_valid_number, '中川区役所');
ok($zip->set_number('4548502')->is_valid_number, '名古屋掖済会病院');
ok($zip->set_number('4548503')->is_valid_number, '愛知県 名古屋西部県税事務所');
ok($zip->set_number('4548504')->is_valid_number, '(株) 鈴木商会');
ok($zip->set_number('4548505')->is_valid_number, '株式会社 ナスコム');
ok($zip->set_number('4548506')->is_valid_number, '中部鋼鈑 株式会社');
ok($zip->set_number('4548508')->is_valid_number, '上地木材');
ok($zip->set_number('4548509')->is_valid_number, '藤田医科大学ばんたね病院');
ok($zip->set_number('4548511')->is_valid_number, '中川税務署');
ok($zip->set_number('4548512')->is_valid_number, '株式会社 太田廣');
ok($zip->set_number('4548514')->is_valid_number, '株式会社 ミツウロコ中部事業部');
ok($zip->set_number('4548515')->is_valid_number, '名鉄タクシーホールディングス 株式会社');
ok($zip->set_number('4548516')->is_valid_number, '大東建託 株式会社 名古屋事務所');
ok($zip->set_number('4548517')->is_valid_number, '瀧上工業 株式会社');
ok($zip->set_number('4548518')->is_valid_number, '中日本氷糖 株式会社');
ok($zip->set_number('4548519')->is_valid_number, 'シャープファイナンス 株式会社 中部統轄支店');
ok($zip->set_number('4548520')->is_valid_number, '日清製粉 株式会社 名古屋工場');
ok($zip->set_number('4548521')->is_valid_number, '宮崎精鋼 株式会社');
ok($zip->set_number('4548522')->is_valid_number, '愛知県 中川警察署');
ok($zip->set_number('4548524')->is_valid_number, 'シンコール 株式会社');
ok($zip->set_number('4548525')->is_valid_number, '医療法人 偕行会 名古屋共立病院');
ok($zip->set_number('4548526')->is_valid_number, '金印 株式会社');
ok($zip->set_number('4548527')->is_valid_number, 'ワタナベフーマック 株式会社');
ok($zip->set_number('4548529')->is_valid_number, 'シャープエレクトロニクスマーケティング 株式会社');
ok($zip->set_number('4548530')->is_valid_number, '三ツ矢製菓 株式会社');
ok($zip->set_number('4548533')->is_valid_number, '西山商事 株式会社');
ok($zip->set_number('4548550')->is_valid_number, '株式会社 アズパーク');
ok($zip->set_number('4548555')->is_valid_number, '株式会社 名鉄交通商事 名鉄タクシーチケットセンター');
ok($zip->set_number('4548558')->is_valid_number, '中部運輸局 愛知運輸支局');
ok($zip->set_number('4548560')->is_valid_number, '(株) あかのれん 千音寺店');
ok($zip->set_number('4548565')->is_valid_number, '伊藤ハム 株式会社 名古屋事務所');
ok($zip->set_number('4548651')->is_valid_number, 'リンナイ 株式会社');
ok($zip->set_number('4558501')->is_valid_number, 'ららぽーと名古屋みなとアクルス');
ok($zip->set_number('4558505')->is_valid_number, '株式会社 ダイセキ');
ok($zip->set_number('4558512')->is_valid_number, '株式会社 テクノ中部');
ok($zip->set_number('4558515')->is_valid_number, '三菱重工業 株式会社 名古屋航空宇宙システム製作所');
ok($zip->set_number('4558521')->is_valid_number, 'NTT マーケティングアクト名古屋 株式会社 中央南営業所');
ok($zip->set_number('4558525')->is_valid_number, '名古屋南労働基準監督署');
ok($zip->set_number('4558530')->is_valid_number, '独立行政法人 労働者健康安全機構 中部労災病院');
ok($zip->set_number('4558533')->is_valid_number, 'アピタ東海通店');
ok($zip->set_number('4558535')->is_valid_number, '名古屋税関');
ok($zip->set_number('4558545')->is_valid_number, '国土交通省 中部地方整備局');
ok($zip->set_number('4558555')->is_valid_number, '三菱航空機 株式会社');
ok($zip->set_number('4558560')->is_valid_number, '名古屋市国際展示場(ポートメッセなごや)');
ok($zip->set_number('4558585')->is_valid_number, '吉田産業 株式会社');
ok($zip->set_number('4558601')->is_valid_number, '法務省 名古屋入国管理局');
ok($zip->set_number('4558605')->is_valid_number, 'LEGOLAND Japan 株式会社');
ok($zip->set_number('4558606')->is_valid_number, 'LEGOLAND Japan Hotel');
ok($zip->set_number('4558610')->is_valid_number, 'ユニー 株式会社 アピタ港店');
ok($zip->set_number('4558620')->is_valid_number, 'イオンリテール 株式会社 イオン南陽店');
ok($zip->set_number('4558626')->is_valid_number, '名古屋市 ささしま市税事務所 東海通出張所');
ok($zip->set_number('4558630')->is_valid_number, 'ヤマト運輸 株式会社 中部支社');
ok($zip->set_number('4558639')->is_valid_number, '(株) 服部家具センター');
ok($zip->set_number('4558648')->is_valid_number, '愛日木研 株式会社');
ok($zip->set_number('4558668')->is_valid_number, '共立マテリアル 株式会社');
ok($zip->set_number('4558670')->is_valid_number, '株式会社 UACJ名古屋製造所');
ok($zip->set_number('4558671')->is_valid_number, '株式会社 正直屋');
ok($zip->set_number('4558777')->is_valid_number, '株式会社 東京インテリア家具 名古屋本店');
ok($zip->set_number('4568501')->is_valid_number, '名古屋市熱田区役所');
ok($zip->set_number('4568502')->is_valid_number, '郵送請求に係る証明書交付センター');
ok($zip->set_number('4568503')->is_valid_number, '名古屋南公共職業安定所');
ok($zip->set_number('4568511')->is_valid_number, '東邦ガス 株式会社');
ok($zip->set_number('4568516')->is_valid_number, '株式会社 中部プラントサービス');
ok($zip->set_number('4568523')->is_valid_number, '愛知日産自動車 株式会社');
ok($zip->set_number('4568530')->is_valid_number, '全労済愛知県本部');
ok($zip->set_number('4568544')->is_valid_number, '株式会社 日立産機システム 中部支社');
ok($zip->set_number('4568555')->is_valid_number, '名古屋トヨペット 株式会社');
ok($zip->set_number('4568556')->is_valid_number, 'NTPホールディングス 株式会社');
ok($zip->set_number('4568560')->is_valid_number, '株式会社 名給');
ok($zip->set_number('4568567')->is_valid_number, '熱田社会保険事務所');
ok($zip->set_number('4568580')->is_valid_number, '株式会社 名鉄パレ管財');
ok($zip->set_number('4568585')->is_valid_number, '熱田神宮宮庁');
ok($zip->set_number('4568587')->is_valid_number, '財団法人 ファインセラミックスセンター');
ok($zip->set_number('4568588')->is_valid_number, '株式会社 山善 名古屋支社');
ok($zip->set_number('4568601')->is_valid_number, '愛知機械工業 株式会社');
ok($zip->set_number('4568602')->is_valid_number, '株式会社 昭和');
ok($zip->set_number('4568610')->is_valid_number, '伊藤忠食品 株式会社 東海営業本部');
ok($zip->set_number('4568611')->is_valid_number, 'みなと医療生活 協同組合 協立総合病院');
ok($zip->set_number('4568612')->is_valid_number, '学校法人 名古屋学院大学');
ok($zip->set_number('4568620')->is_valid_number, '中部森林管理局 名古屋事務所');
ok($zip->set_number('4568666')->is_valid_number, 'アイホン 株式会社');
ok($zip->set_number('4568668')->is_valid_number, 'ネッツトヨタ中京 株式会社');
ok($zip->set_number('4568686')->is_valid_number, '株式会社 イノアックリビング');
ok($zip->set_number('4568688')->is_valid_number, '名古屋青果 株式会社');
ok($zip->set_number('4568691')->is_valid_number, '日本車輌製造 株式会社 本社');
ok($zip->set_number('4568711')->is_valid_number, '熱田税務署');
ok($zip->set_number('4568739')->is_valid_number, '商工組合中央金庫 熱田支店');
ok($zip->set_number('4568763')->is_valid_number, 'イオン熱田ショッピングセンター');
ok($zip->set_number('4578501')->is_valid_number, 'ネッツトヨタ東海 株式会社');
ok($zip->set_number('4578508')->is_valid_number, '名古屋市南区役所');
ok($zip->set_number('4578510')->is_valid_number, '社会保険中京病院');
ok($zip->set_number('4578511')->is_valid_number, '大同病院');
ok($zip->set_number('4578512')->is_valid_number, '社会福祉法人 大同福祉会');
ok($zip->set_number('4578515')->is_valid_number, '愛精病院');
ok($zip->set_number('4578522')->is_valid_number, '三井化学 株式会社 名古屋工場');
ok($zip->set_number('4578530')->is_valid_number, '大同大学');
ok($zip->set_number('4578531')->is_valid_number, '大同大学 滝春校舎');
ok($zip->set_number('4578532')->is_valid_number, '大同大学 白水校舎');
ok($zip->set_number('4578533')->is_valid_number, '株式会社 丸政');
ok($zip->set_number('4578535')->is_valid_number, '近藤産興 株式会社');
ok($zip->set_number('4578545')->is_valid_number, '大同特殊鋼 株式会社 星崎工場');
ok($zip->set_number('4578551')->is_valid_number, '株式会社 ミック');
ok($zip->set_number('4578555')->is_valid_number, 'カネハツ食品 株式会社');
ok($zip->set_number('4578558')->is_valid_number, '三菱ふそうトラック・バス 株式会社 東海ふそう');
ok($zip->set_number('4578560')->is_valid_number, '株式会社 テイラド');
ok($zip->set_number('4578566')->is_valid_number, '株式会社 チップトン');
ok($zip->set_number('4578567')->is_valid_number, '株式会社 あかのれん 内田橋店');
ok($zip->set_number('4578577')->is_valid_number, '株式会社 大同機械製作所');
ok($zip->set_number('4578585')->is_valid_number, '株式会社 ナカガワ');
ok($zip->set_number('4578588')->is_valid_number, '株式会社 八神製作所');
ok($zip->set_number('4578711')->is_valid_number, '株式会社 中部シントー');
ok($zip->set_number('4578712')->is_valid_number, '大同特殊鋼 株式会社 機械事業部 滝春テクノセンター');
ok($zip->set_number('4588501')->is_valid_number, '株式会社 東亜製作所');
ok($zip->set_number('4588502')->is_valid_number, '日本車輌製造 株式会社 鳴海製作所');
ok($zip->set_number('4588505')->is_valid_number, '中央発條 株式会社');
ok($zip->set_number('4588508')->is_valid_number, 'ソルダーコート 株式会社');
ok($zip->set_number('4588510')->is_valid_number, '佐久間特殊鋼 株式会社');
ok($zip->set_number('4588515')->is_valid_number, '中部電力 株式会社 緑電力センター');
ok($zip->set_number('4588520')->is_valid_number, 'UDトラックス 株式会社');
ok($zip->set_number('4588521')->is_valid_number, '株式会社 光金属工業所');
ok($zip->set_number('4588522')->is_valid_number, '高砂電気工業 株式会社');
ok($zip->set_number('4588530')->is_valid_number, '鳴海製陶 株式会社');
ok($zip->set_number('4588555')->is_valid_number, 'ユニー 株式会社 アピタ鳴海店');
ok($zip->set_number('4588570')->is_valid_number, 'ヒルズウォーク 徳重ガーデンズ');
ok($zip->set_number('4588571')->is_valid_number, 'ピアゴ ラフーズ コア 徳重店');
ok($zip->set_number('4588580')->is_valid_number, '名鉄自動車整備 株式会社');
ok($zip->set_number('4588581')->is_valid_number, '名城食品 株式会社');
ok($zip->set_number('4588585')->is_valid_number, '名古屋市緑区役所');
ok($zip->set_number('4598501')->is_valid_number, '株式会社 プロスチール');
ok($zip->set_number('4598511')->is_valid_number, 'ゴムノイナキ 株式会社 大高本社');
ok($zip->set_number('4598522')->is_valid_number, '中部電力 株式会社 技術開発本部研究企画部');
ok($zip->set_number('4598540')->is_valid_number, '総合病院 南生協病院');
ok($zip->set_number('4608201')->is_valid_number, '個人市民税特別徴収センター');
ok($zip->set_number('4608202')->is_valid_number, '名古屋市 市税収納事務センター');
ok($zip->set_number('4608203')->is_valid_number, '日刊スポーツ新聞 名古屋本社');
ok($zip->set_number('4608204')->is_valid_number, '社団法人 日本電気協会 中部支部');
ok($zip->set_number('4608302')->is_valid_number, 'エヌエスディ 株式会社');
ok($zip->set_number('4608310')->is_valid_number, '中部電力パワーグリッド 株式会社 中電千代田ビル(名古屋支店、中営業所、中電力センター)');
ok($zip->set_number('4608310')->is_valid_number, '中部電力ミライズ 株式会社 名古屋営業本部');
ok($zip->set_number('4608311')->is_valid_number, '名古屋テレビ放送 株式会社');
ok($zip->set_number('4608312')->is_valid_number, 'セルバンク クリニック');
ok($zip->set_number('4608314')->is_valid_number, 'リンタツ 株式会社');
ok($zip->set_number('4608315')->is_valid_number, '株式会社 バッファロー');
ok($zip->set_number('4608318')->is_valid_number, '株式会社 八神製作所');
ok($zip->set_number('4608319')->is_valid_number, 'NTT 東海支社');
ok($zip->set_number('4608320')->is_valid_number, 'テルウェル西日本 株式会社 東海支店');
ok($zip->set_number('4608321')->is_valid_number, 'ミサワホーム東海 株式会社');
ok($zip->set_number('4608325')->is_valid_number, 'テレビ愛知 株式会社');
ok($zip->set_number('4608330')->is_valid_number, '株式会社 槌屋');
ok($zip->set_number('4608331')->is_valid_number, '株式会社 カテックス');
ok($zip->set_number('4608333')->is_valid_number, 'ゴムノイナキ 株式会社');
ok($zip->set_number('4608338')->is_valid_number, '株式会社 ナデックス');
ok($zip->set_number('4608350')->is_valid_number, 'SMBCファイナンスサービス 株式会社');
ok($zip->set_number('4608351')->is_valid_number, '株式会社 毎日新聞社 中部本社');
ok($zip->set_number('4608351')->is_valid_number, '株式会社 毎日新聞社 中部本社 名古屋本部');
ok($zip->set_number('4608358')->is_valid_number, '寿がきや食品 株式会社');
ok($zip->set_number('4608360')->is_valid_number, '株式会社 愛知冠婚葬祭互助会');
ok($zip->set_number('4608366')->is_valid_number, '日本経済新聞社 名古屋支社');
ok($zip->set_number('4608383')->is_valid_number, '大有建設 株式会社');
ok($zip->set_number('4608388')->is_valid_number, '株式会社 エフエム愛知');
ok($zip->set_number('4608401')->is_valid_number, '富士ゼロックス愛知 株式会社 本社');
ok($zip->set_number('4608402')->is_valid_number, '株式会社 熊谷組 名古屋支店');
ok($zip->set_number('4608403')->is_valid_number, '株式会社 御園座');
ok($zip->set_number('4608404')->is_valid_number, '富士フイルム 株式会社');
ok($zip->set_number('4608405')->is_valid_number, 'CBC中部日本放送 株式会社');
ok($zip->set_number('4608408')->is_valid_number, '株式会社 トーエネック');
ok($zip->set_number('4608411')->is_valid_number, '木曽興業 株式会社');
ok($zip->set_number('4608412')->is_valid_number, '大日本土木 株式会社 名古屋支店');
ok($zip->set_number('4608415')->is_valid_number, 'ポッカサッポロフード&ビバレッジ 株式会社');
ok($zip->set_number('4608416')->is_valid_number, '株式会社 松村組 名古屋支店');
ok($zip->set_number('4608417')->is_valid_number, '日石三菱 株式会社 中部支店');
ok($zip->set_number('4608422')->is_valid_number, '名古屋商工会議所');
ok($zip->set_number('4608425')->is_valid_number, 'TIS 株式会社');
ok($zip->set_number('4608426')->is_valid_number, '株式会社 エイシアインターナショナル');
ok($zip->set_number('4608430')->is_valid_number, '株式会社 大丸松坂屋百貨店 松坂屋名古屋店');
ok($zip->set_number('4608431')->is_valid_number, '東海東京証券 株式会社');
ok($zip->set_number('4608432')->is_valid_number, '東海エレクトロニクス 株式会社');
ok($zip->set_number('4608433')->is_valid_number, '株式会社 新潟鐵工所 名古屋支店');
ok($zip->set_number('4608434')->is_valid_number, '中央電気工事 株式会社');
ok($zip->set_number('4608435')->is_valid_number, '株式会社 日立製作所 中部支社');
ok($zip->set_number('4608439')->is_valid_number, '株式会社 アトム');
ok($zip->set_number('4608440')->is_valid_number, '株式会社 ベネッセコーポレーション 名古屋事業所');
ok($zip->set_number('4608444')->is_valid_number, 'アリコ ジャパン');
ok($zip->set_number('4608445')->is_valid_number, '株式会社 電通 中部支社');
ok($zip->set_number('4608447')->is_valid_number, '名古屋市中区役所');
ok($zip->set_number('4608450')->is_valid_number, 'あいおい損害保険 株式会社 名古屋栄ビル');
ok($zip->set_number('4608451')->is_valid_number, '兼松エレクトロニクス 株式会社 名古屋支店');
ok($zip->set_number('4608455')->is_valid_number, '新日本法規出版 株式会社');
ok($zip->set_number('4608456')->is_valid_number, '新日本法規出版 株式会社 名古屋支社');
ok($zip->set_number('4608461')->is_valid_number, '株式会社 名古屋流行発信');
ok($zip->set_number('4608470')->is_valid_number, '読売新聞 東京本社 中部支社');
ok($zip->set_number('4608475')->is_valid_number, '株式会社 名古屋リビング新聞社');
ok($zip->set_number('4608477')->is_valid_number, '株式会社 ジーノット');
ok($zip->set_number('4608481')->is_valid_number, '愛知労働金庫');
ok($zip->set_number('4608482')->is_valid_number, 'テンプスタッフ・ピープル 株式会社');
ok($zip->set_number('4608483')->is_valid_number, '愛知県 名古屋東部県税事務所');
ok($zip->set_number('4608484')->is_valid_number, '独立行政法人 都市再生機構 中部支社');
ok($zip->set_number('4608485')->is_valid_number, '株式会社 日本メディカル総研 名古屋支社');
ok($zip->set_number('4608488')->is_valid_number, '朝日新聞 名古屋本社');
ok($zip->set_number('4608490')->is_valid_number, 'リゾートトラスト 株式会社 本社');
ok($zip->set_number('4608491')->is_valid_number, '大和ハウス工業 株式会社 名古屋支社');
ok($zip->set_number('4608501')->is_valid_number, '愛知県庁');
ok($zip->set_number('4608503')->is_valid_number, '名古屋高等裁判所');
ok($zip->set_number('4608504')->is_valid_number, '名古屋地方裁判所');
ok($zip->set_number('4608505')->is_valid_number, '名古屋簡易裁判所');
ok($zip->set_number('4608506')->is_valid_number, '日本電信電話 株式会社 名古屋支店');
ok($zip->set_number('4608507')->is_valid_number, '愛知労働基準局');
ok($zip->set_number('4608508')->is_valid_number, '名古屋市役所');
ok($zip->set_number('4608509')->is_valid_number, '名古屋地方裁判所 執行部 民事第2部');
ok($zip->set_number('4608510')->is_valid_number, '中部経済産業局');
ok($zip->set_number('4608511')->is_valid_number, '中日新聞');
ok($zip->set_number('4608512')->is_valid_number, '愛知県 尾張事務所');
ok($zip->set_number('4608513')->is_valid_number, '名古屋法務局');
ok($zip->set_number('4608514')->is_valid_number, '国土交通省 中部地方設備局');
ok($zip->set_number('4608515')->is_valid_number, '中北薬品 株式会社 本社事務所');
ok($zip->set_number('4608516')->is_valid_number, '東海農政局');
ok($zip->set_number('4608517')->is_valid_number, '国土交通省 中部地方整備局 港湾空港部');
ok($zip->set_number('4608520')->is_valid_number, '名古屋国税局');
ok($zip->set_number('4608521')->is_valid_number, '東海財務局');
ok($zip->set_number('4608522')->is_valid_number, '名古屋中税務署');
ok($zip->set_number('4608523')->is_valid_number, '名古屋地方検察庁');
ok($zip->set_number('4608524')->is_valid_number, '名古屋保護観察所');
ok($zip->set_number('4608525')->is_valid_number, '日本電気 株式会社 東海支社');
ok($zip->set_number('4608528')->is_valid_number, '中部運輸局');
ok($zip->set_number('4608530')->is_valid_number, '社団法人 名古屋タイムズ社');
ok($zip->set_number('4608531')->is_valid_number, 'マスダ 株式会社');
ok($zip->set_number('4608532')->is_valid_number, 'キヤノンマーケティングジャパン 株式会社 名古屋支店');
ok($zip->set_number('4608534')->is_valid_number, '愛知県教育委員会');
ok($zip->set_number('4608535')->is_valid_number, '株式会社 ロイヤル');
ok($zip->set_number('4608536')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('4608538')->is_valid_number, '株式会社 ダイテック');
ok($zip->set_number('4608541')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('4608545')->is_valid_number, '株式会社 中部しんきんカード');
ok($zip->set_number('4608550')->is_valid_number, '株式会社 藤栄');
ok($zip->set_number('4608551')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('4608555')->is_valid_number, '旭屋 株式会社');
ok($zip->set_number('4608558')->is_valid_number, '伊勢久 株式会社');
ok($zip->set_number('4608559')->is_valid_number, '財団法人 日本無線協会 東海支部');
ok($zip->set_number('4608560')->is_valid_number, '長瀬産業 株式会社 名古屋支店');
ok($zip->set_number('4608566')->is_valid_number, '愛知県 住宅供給公社');
ok($zip->set_number('4608567')->is_valid_number, '日本メナード化粧品 株式会社');
ok($zip->set_number('4608575')->is_valid_number, '社団法人 中部建設協会');
ok($zip->set_number('4608577')->is_valid_number, '株式会社 加名市');
ok($zip->set_number('4608578')->is_valid_number, '株式会社 エフエム名古屋');
ok($zip->set_number('4608580')->is_valid_number, '清水建設 株式会社 名古屋支店');
ok($zip->set_number('4608585')->is_valid_number, '富士通 株式会社 東海支社');
ok($zip->set_number('4608586')->is_valid_number, '株式会社 オリエントコーポレーション 名古屋支店');
ok($zip->set_number('4608588')->is_valid_number, 'ヤマハ 株式会社 名古屋支店');
ok($zip->set_number('4608602')->is_valid_number, '八木兵 株式会社');
ok($zip->set_number('4608605')->is_valid_number, 'マックスバリュ中部 株式会社 本社事務所');
ok($zip->set_number('4608606')->is_valid_number, '株式会社 シーエフプランニング');
ok($zip->set_number('4608608')->is_valid_number, '株式会社 名古屋観光ホテル');
ok($zip->set_number('4608610')->is_valid_number, 'ニチハ 株式会社');
ok($zip->set_number('4608614')->is_valid_number, '五洋建設 株式会社 名古屋支店');
ok($zip->set_number('4608615')->is_valid_number, '徳倉建設 株式会社');
ok($zip->set_number('4608616')->is_valid_number, '万兵 株式会社');
ok($zip->set_number('4608617')->is_valid_number, '日本紙パルプ商事 株式会社 中部支社');
ok($zip->set_number('4608618')->is_valid_number, '石田 株式会社');
ok($zip->set_number('4608619')->is_valid_number, '安藤証券 株式会社');
ok($zip->set_number('4608621')->is_valid_number, '株式会社 東海総合研究所');
ok($zip->set_number('4608623')->is_valid_number, '県民共済愛知県 生活協同組合');
ok($zip->set_number('4608625')->is_valid_number, '興和 株式会社');
ok($zip->set_number('4608626')->is_valid_number, '名古屋市 金山市税事務所');
ok($zip->set_number('4608627')->is_valid_number, '三菱UFJリサーチ&コンサルティング 株式会社');
ok($zip->set_number('4608628')->is_valid_number, '丹羽幸 株式会社');
ok($zip->set_number('4608630')->is_valid_number, '天野エンザイム 株式会社 本社');
ok($zip->set_number('4608631')->is_valid_number, '国際電信電話 株式会社 名古屋支店(KDD)');
ok($zip->set_number('4608632')->is_valid_number, 'コスモ石油 株式会社 名古屋支店');
ok($zip->set_number('4608633')->is_valid_number, '株式会社 竹中工務店 名古屋支店');
ok($zip->set_number('4608635')->is_valid_number, '三井海上火災保険 株式会社');
ok($zip->set_number('4608637')->is_valid_number, '株式会社 アルペン');
ok($zip->set_number('4608638')->is_valid_number, 'スターキャット・ケーブルネットワーク 株式会社');
ok($zip->set_number('4608650')->is_valid_number, '株式会社 川本製作所');
ok($zip->set_number('4608651')->is_valid_number, '遠山産業 株式会社');
ok($zip->set_number('4608653')->is_valid_number, '大和證券 株式会社 名古屋支店');
ok($zip->set_number('4608655')->is_valid_number, 'シヤチハタ商事 株式会社 名古屋支店');
ok($zip->set_number('4608657')->is_valid_number, '伊藤伊 株式会社');
ok($zip->set_number('4608660')->is_valid_number, '株式会社 三菱UFJ銀行');
ok($zip->set_number('4608665')->is_valid_number, '兼松 株式会社 名古屋支社');
ok($zip->set_number('4608666')->is_valid_number, '岡谷鋼機 株式会社');
ok($zip->set_number('4608667')->is_valid_number, '瀧定 株式会社');
ok($zip->set_number('4608669')->is_valid_number, '株式会社 名古屋三越 栄本店');
ok($zip->set_number('4608670')->is_valid_number, 'SMBCファイナンスサービス 株式会社');
ok($zip->set_number('4608671')->is_valid_number, '豊島 株式会社 名古屋本社');
ok($zip->set_number('4608672')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('4608674')->is_valid_number, '株式会社 丸栄');
ok($zip->set_number('4608678')->is_valid_number, '株式会社 愛知銀行 本店');
ok($zip->set_number('4608679')->is_valid_number, 'モリリン 株式会社 名古屋支店');
ok($zip->set_number('4608681')->is_valid_number, '株式会社 中京銀行');
ok($zip->set_number('4608683')->is_valid_number, '出光興産 株式会社 名古屋支店');
ok($zip->set_number('4608684')->is_valid_number, '株式会社 さくら銀行 名古屋支店');
ok($zip->set_number('4608686')->is_valid_number, '株式会社 リオ横山');
ok($zip->set_number('4608687')->is_valid_number, '愛知県共済生活 協同組合');
ok($zip->set_number('4608688')->is_valid_number, '株式会社 富士銀行 名古屋支店');
ok($zip->set_number('4608689')->is_valid_number, '野村證券 株式会社 名古屋支店');
ok($zip->set_number('4608690')->is_valid_number, '中電コンピューターサービス 株式会社');
ok($zip->set_number('4608703')->is_valid_number, 'ジャックス 株式会社 名古屋支店');
ok($zip->set_number('4608704')->is_valid_number, '東芝中部ライフエレクトロニクス 株式会社');
ok($zip->set_number('4608706')->is_valid_number, '株式会社 第一勧業銀行 名古屋支店');
ok($zip->set_number('4608707')->is_valid_number, '株式会社 NIPPO 中部支店');
ok($zip->set_number('4608708')->is_valid_number, '日本銀行 名古屋支店');
ok($zip->set_number('4608711')->is_valid_number, '丸紅 株式会社 中部支社');
ok($zip->set_number('4608718')->is_valid_number, '桜井 株式会社');
ok($zip->set_number('4608720')->is_valid_number, '富永電機 株式会社 本社');
ok($zip->set_number('4618501')->is_valid_number, '東海テレビ放送');
ok($zip->set_number('4618503')->is_valid_number, '東海ラジオ放送');
ok($zip->set_number('4618504')->is_valid_number, '東海ラジオ放送');
ok($zip->set_number('4618505')->is_valid_number, '株式会社 梅澤');
ok($zip->set_number('4618506')->is_valid_number, '株式会社 大林組 名古屋支店');
ok($zip->set_number('4618507')->is_valid_number, '住友林業 株式会社 営業本部 東海支店');
ok($zip->set_number('4618508')->is_valid_number, '東カン名古屋ビル');
ok($zip->set_number('4618511')->is_valid_number, 'キヤノンマーケティングジャパン 株式会社 名古屋支店');
ok($zip->set_number('4618512')->is_valid_number, '佐藤工業 株式会社 名古屋支店');
ok($zip->set_number('4618520')->is_valid_number, '萩原電気 株式会社');
ok($zip->set_number('4618522')->is_valid_number, 'サンデーフォークプロモーション');
ok($zip->set_number('4618525')->is_valid_number, '愛知芸術文化センター');
ok($zip->set_number('4618530')->is_valid_number, '松下電器産業 株式会社');
ok($zip->set_number('4618531')->is_valid_number, 'アスゲン製薬 株式会社');
ok($zip->set_number('4618532')->is_valid_number, '愛知県国民健康保険団体連合会');
ok($zip->set_number('4618534')->is_valid_number, '名城大学 ナゴヤドーム前キャンパス');
ok($zip->set_number('4618539')->is_valid_number, '玉野総合コンサルタント 株式会社');
ok($zip->set_number('4618540')->is_valid_number, '関西電力 株式会社 東海支社');
ok($zip->set_number('4618541')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('4618550')->is_valid_number, '第一法規出版 (株) 東海支社');
ok($zip->set_number('4618555')->is_valid_number, '株式会社 松本義肢製作所');
ok($zip->set_number('4618558')->is_valid_number, '西松建設 株式会社 中部支店');
ok($zip->set_number('4618560')->is_valid_number, '六合エレメック');
ok($zip->set_number('4618575')->is_valid_number, '名古屋北労働基準監督署');
ok($zip->set_number('4618577')->is_valid_number, '(株) レアールパスコベーカリーズ 名古屋本部');
ok($zip->set_number('4618580')->is_valid_number, '社団法人 中部産業連盟');
ok($zip->set_number('4618581')->is_valid_number, '大同特殊鋼 株式会社');
ok($zip->set_number('4618582')->is_valid_number, '株式会社 日刊工業新聞社 名古屋支社');
ok($zip->set_number('4618585')->is_valid_number, '日本国土開発 株式会社 名古屋支店');
ok($zip->set_number('4618586')->is_valid_number, '名古屋拘置所');
ok($zip->set_number('4618588')->is_valid_number, '株式会社 小出物産');
ok($zip->set_number('4618602')->is_valid_number, '住友生命保険 相互会社 愛知南支社');
ok($zip->set_number('4618603')->is_valid_number, '株式会社 大塚屋');
ok($zip->set_number('4618605')->is_valid_number, '(株) NTTデータ 東海支社');
ok($zip->set_number('4618610')->is_valid_number, '山田学園');
ok($zip->set_number('4618612')->is_valid_number, 'トヨタカローラ中京 株式会社');
ok($zip->set_number('4618620')->is_valid_number, 'ダイテック');
ok($zip->set_number('4618621')->is_valid_number, '名古屋東 税務署');
ok($zip->set_number('4618626')->is_valid_number, '名古屋市 栄市税事務所');
ok($zip->set_number('4618630')->is_valid_number, 'いその 株式会社');
ok($zip->set_number('4618631')->is_valid_number, '(株) 三和化学研究所');
ok($zip->set_number('4618636')->is_valid_number, '株式会社 コミュニティネットワークセンター');
ok($zip->set_number('4618639')->is_valid_number, '愛知国際放送 株式会社');
ok($zip->set_number('4618640')->is_valid_number, '名古屋市東区役所');
ok($zip->set_number('4618641')->is_valid_number, '愛知大学');
ok($zip->set_number('4618645')->is_valid_number, 'ジェイルハウス');
ok($zip->set_number('4618650')->is_valid_number, 'ホーユー 株式会社');
ok($zip->set_number('4618651')->is_valid_number, '千趣会 名古屋支社');
ok($zip->set_number('4618654')->is_valid_number, '旭陵高等学校');
ok($zip->set_number('4618655')->is_valid_number, '株式会社 タカコム');
ok($zip->set_number('4618658')->is_valid_number, '森永乳業 株式会社 東海支店');
ok($zip->set_number('4618666')->is_valid_number, 'ぴあ 株式会社 中部支局');
ok($zip->set_number('4618670')->is_valid_number, '三菱電機 株式会社 名古屋製作所');
ok($zip->set_number('4618671')->is_valid_number, '中京コカ・コーラボトリング 株式会社');
ok($zip->set_number('4618672')->is_valid_number, '株式会社 明治屋 名古屋支店');
ok($zip->set_number('4618673')->is_valid_number, '名古屋大学医学部保健学科 名古屋大学医療技術短期大学部');
ok($zip->set_number('4618675')->is_valid_number, '三菱電機システムサービス 株式会社');
ok($zip->set_number('4618676')->is_valid_number, '学校法人 名古屋学院(中学校・高等学校)');
ok($zip->set_number('4618678')->is_valid_number, '尾張精機 株式会社');
ok($zip->set_number('4618680')->is_valid_number, '中部電力パワーグリッド 株式会社');
ok($zip->set_number('4618680')->is_valid_number, '中部電力ミライズ 株式会社');
ok($zip->set_number('4618680')->is_valid_number, '中部電力');
ok($zip->set_number('4618703')->is_valid_number, 'ホーユー 株式会社');
ok($zip->set_number('4618706')->is_valid_number, 'ヒサゴ 株式会社');
ok($zip->set_number('4618707')->is_valid_number, '名古屋モザイク工業');
ok($zip->set_number('4618710')->is_valid_number, 'NHK 名古屋放送局');
ok($zip->set_number('4618714')->is_valid_number, '(株) 豊田自動織機 トヨタL&Fカンパニー 東桜ビル');
ok($zip->set_number('4618715')->is_valid_number, '千趣会');
ok($zip->set_number('4618717')->is_valid_number, '星野楽器 株式会社');
ok($zip->set_number('4618721')->is_valid_number, '敷島製パン 株式会社');
ok($zip->set_number('4618725')->is_valid_number, '日本放送協会 名古屋放送局');
ok($zip->set_number('4618729')->is_valid_number, '住友商事 株式会社 中部支社');
ok($zip->set_number('4618795')->is_valid_number, '東海総合通信局');
ok($zip->set_number('4618798')->is_valid_number, '名古屋逓信病院');
ok($zip->set_number('4628501')->is_valid_number, '株式会社 ニッショー');
ok($zip->set_number('4628508')->is_valid_number, '名古屋市立西部医療センター');
ok($zip->set_number('4628509')->is_valid_number, '東急鯱バス 株式会社');
ok($zip->set_number('4628511')->is_valid_number, '名古屋市北区役所');
ok($zip->set_number('4628512')->is_valid_number, '親和電機 株式会社');
ok($zip->set_number('4628519')->is_valid_number, '株式会社 東急サービス');
ok($zip->set_number('4628522')->is_valid_number, '名古屋北保健所');
ok($zip->set_number('4628523')->is_valid_number, '社会保険診療報酬支払基金 愛知支部');
ok($zip->set_number('4628530')->is_valid_number, '中京スポーツ');
ok($zip->set_number('4628535')->is_valid_number, '株式会社 名古屋三越 OSセンター');
ok($zip->set_number('4628540')->is_valid_number, '株式会社 カケン');
ok($zip->set_number('4628543')->is_valid_number, '名古屋北税務署');
ok($zip->set_number('4628545')->is_valid_number, '名古屋造形大学');
ok($zip->set_number('4628551')->is_valid_number, 'アサダ 株式会社');
ok($zip->set_number('4628555')->is_valid_number, 'ヤマハ中部 株式会社');
ok($zip->set_number('4628558')->is_valid_number, '社会福祉法人 名古屋市社会福祉協議会');
ok($zip->set_number('4628575')->is_valid_number, '社団法人 名北労働基準協会');
ok($zip->set_number('4628576')->is_valid_number, '愛知県 衛生研究所');
ok($zip->set_number('4628577')->is_valid_number, '菅原電気 株式会社 名古屋支店');
ok($zip->set_number('4628580')->is_valid_number, '専門学校 名古屋ウエディング&フラワー・ビューティ学院');
ok($zip->set_number('4628588')->is_valid_number, '株式会社 メイチュー');
ok($zip->set_number('4628666')->is_valid_number, '名古屋北社会保険事務所');
ok($zip->set_number('4628739')->is_valid_number, '愛知学院大学');
ok($zip->set_number('4638501')->is_valid_number, '新栄機工 株式会社');
ok($zip->set_number('4638502')->is_valid_number, '愛知県立大学 看護学部');
ok($zip->set_number('4638503')->is_valid_number, '愛知県立守山高等学校');
ok($zip->set_number('4638505')->is_valid_number, '緑ケ丘カンツリークラブ');
ok($zip->set_number('4638510')->is_valid_number, '守山区役所');
ok($zip->set_number('4638521')->is_valid_number, '金城学院大学');
ok($zip->set_number('4638522')->is_valid_number, 'グリーンシティケーブルテレビ 株式会社');
ok($zip->set_number('4638528')->is_valid_number, '理科研 株式会社');
ok($zip->set_number('4638530')->is_valid_number, '医療法人 香流会 絋仁病院');
ok($zip->set_number('4638533')->is_valid_number, '株式会社 清水屋 藤ケ丘店');
ok($zip->set_number('4638535')->is_valid_number, '株式会社 サガミホールディングス');
ok($zip->set_number('4638536')->is_valid_number, '株式会社 ショクブン');
ok($zip->set_number('4638538')->is_valid_number, 'トーシック 株式会社');
ok($zip->set_number('4638540')->is_valid_number, '株式会社 あらた家庭用品 東海支店');
ok($zip->set_number('4638541')->is_valid_number, '応用地質 株式会社 中部支社');
ok($zip->set_number('4638543')->is_valid_number, '東海大日本印刷 株式会社');
ok($zip->set_number('4638545')->is_valid_number, '丸眞 株式会社');
ok($zip->set_number('4638547')->is_valid_number, '日本コンクリート 株式会社');
ok($zip->set_number('4638548')->is_valid_number, '株式会社 青柳ういろう');
ok($zip->set_number('4638550')->is_valid_number, '大日本印刷 株式会社 中部事業部');
ok($zip->set_number('4638555')->is_valid_number, '尾家産業 株式会社 名古屋支店');
ok($zip->set_number('4638557')->is_valid_number, '株式会社 豊和化成');
ok($zip->set_number('4638560')->is_valid_number, '国立研究開発法人 産業技術総合研究所 中部センター');
ok($zip->set_number('4638561')->is_valid_number, '国立研究開発法人 産業技術総合研究所 中部センター 中部産学官連携研究棟');
ok($zip->set_number('4638565')->is_valid_number, '名古屋手袋 株式会社');
ok($zip->set_number('4638567')->is_valid_number, '名古屋市立 守山市民病院');
ok($zip->set_number('4638571')->is_valid_number, '昌和物産 株式会社');
ok($zip->set_number('4638575')->is_valid_number, 'アサヒロジ 株式会社 名古屋支店');
ok($zip->set_number('4638577')->is_valid_number, '西部機械 株式会社');
ok($zip->set_number('4638580')->is_valid_number, 'アサヒビール 株式会社 名古屋工場');
ok($zip->set_number('4638585')->is_valid_number, '名古屋市衛生研究所');
ok($zip->set_number('4648511')->is_valid_number, 'ユニー千代田橋店');
ok($zip->set_number('4648512')->is_valid_number, '国家公務員共済組合連合会 東海病院');
ok($zip->set_number('4648520')->is_valid_number, '愛知高等学校');
ok($zip->set_number('4648521')->is_valid_number, 'アスティショッピングセンター');
ok($zip->set_number('4648522')->is_valid_number, '名古屋コミュニタス 株式会社');
ok($zip->set_number('4648525')->is_valid_number, '公益財団法人 名古屋産業振興公社');
ok($zip->set_number('4648530')->is_valid_number, '株式会社 油久');
ok($zip->set_number('4648531')->is_valid_number, '株式会社 名古屋医理科商会');
ok($zip->set_number('4648533')->is_valid_number, '学校法人 市邨学園 市邨学園高等学校 市邨学園中学校');
ok($zip->set_number('4648536')->is_valid_number, 'サンスター 株式会社 名古屋支店');
ok($zip->set_number('4648539')->is_valid_number, '株式会社 榎村鐵工所 株式会社 エムラ販売');
ok($zip->set_number('4648540')->is_valid_number, '学校法人 名古屋電気学園');
ok($zip->set_number('4648545')->is_valid_number, '株式会社 八木一');
ok($zip->set_number('4648546')->is_valid_number, '東海物産 株式会社');
ok($zip->set_number('4648547')->is_valid_number, '名古屋市立 東部医療センター');
ok($zip->set_number('4648550')->is_valid_number, 'セキセー 株式会社');
ok($zip->set_number('4648555')->is_valid_number, '千種税務署');
ok($zip->set_number('4648558')->is_valid_number, '中央建材工業 株式会社');
ok($zip->set_number('4648560')->is_valid_number, '株式会社 ニイミ');
ok($zip->set_number('4648561')->is_valid_number, '株式会社 スギヤマ薬品');
ok($zip->set_number('4648566')->is_valid_number, '沖テクノシステムズラボラトリ');
ok($zip->set_number('4648567')->is_valid_number, '株式会社 フューチャーイン');
ok($zip->set_number('4648570')->is_valid_number, 'KDDI 株式会社');
ok($zip->set_number('4648571')->is_valid_number, '株式会社 同和紙業');
ok($zip->set_number('4648577')->is_valid_number, '株式会社 三幸商会');
ok($zip->set_number('4648585')->is_valid_number, '名古屋少年鑑別所');
ok($zip->set_number('4648591')->is_valid_number, 'トヨタモビリティ中京 株式会社');
ok($zip->set_number('4648601')->is_valid_number, '名古屋大学(理、工を除く東山地区)');
ok($zip->set_number('4648602')->is_valid_number, '名古屋大学 理学部');
ok($zip->set_number('4648603')->is_valid_number, '名古屋大学 工学部');
ok($zip->set_number('4648610')->is_valid_number, '学校法人 河合塾');
ok($zip->set_number('4648611')->is_valid_number, '学校法人 河合塾学園 (トライデントスクール)');
ok($zip->set_number('4648613')->is_valid_number, 'フジクリーン工業 株式会社');
ok($zip->set_number('4648615')->is_valid_number, '佐藤製薬 株式会社 名古屋営業所');
ok($zip->set_number('4648616')->is_valid_number, 'あいち造形デザイン専門学校');
ok($zip->set_number('4648617')->is_valid_number, 'ビーシープロダクツ 株式会社');
ok($zip->set_number('4648618')->is_valid_number, '千種保健センター');
ok($zip->set_number('4648631')->is_valid_number, '株式会社 丸の内');
ok($zip->set_number('4648632')->is_valid_number, '大正製薬 株式会社 中日本支店');
ok($zip->set_number('4648633')->is_valid_number, '加藤商事 株式会社');
ok($zip->set_number('4648635')->is_valid_number, '日産プリンス名古屋販売 株式会社');
ok($zip->set_number('4648637')->is_valid_number, 'メーキュー 株式会社');
ok($zip->set_number('4648641')->is_valid_number, '西川印刷 株式会社');
ok($zip->set_number('4648643')->is_valid_number, '日本電子計算 株式会社 名古屋支店');
ok($zip->set_number('4648644')->is_valid_number, '名古屋市千種区役所');
ok($zip->set_number('4648650')->is_valid_number, '学校法人 愛知学院');
ok($zip->set_number('4648651')->is_valid_number, '愛知学院大学歯学部附属病院');
ok($zip->set_number('4648652')->is_valid_number, 'ダイトーエムイー 株式会社');
ok($zip->set_number('4648654')->is_valid_number, '(株) 中部松坂屋ストア');
ok($zip->set_number('4648661')->is_valid_number, '株式会社 名古屋三越星ヶ丘店');
ok($zip->set_number('4648662')->is_valid_number, '学校法人 椙山女学園');
ok($zip->set_number('4648671')->is_valid_number, '学校法人 愛知淑徳学園');
ok($zip->set_number('4648681')->is_valid_number, '愛知県がんセンター');
ok($zip->set_number('4648710')->is_valid_number, '金城軒');
ok($zip->set_number('4658501')->is_valid_number, '株式会社 チヨダ 中部地区本部');
ok($zip->set_number('4658505')->is_valid_number, 'サンコー商事 株式会社');
ok($zip->set_number('4658506')->is_valid_number, '名東保健所');
ok($zip->set_number('4658507')->is_valid_number, '愛知県立 千種高等学校');
ok($zip->set_number('4658508')->is_valid_number, '名東区役所');
ok($zip->set_number('4658510')->is_valid_number, '新統情報センター 株式会社');
ok($zip->set_number('4658511')->is_valid_number, '藤久 株式会社');
ok($zip->set_number('4658515')->is_valid_number, '愛知東邦大学');
ok($zip->set_number('4658516')->is_valid_number, '東邦高等学校');
ok($zip->set_number('4658520')->is_valid_number, '株式会社 コムラ');
ok($zip->set_number('4658550')->is_valid_number, '株式会社 富士');
ok($zip->set_number('4658551')->is_valid_number, '日本圧着端子製造 株式会社 名古屋営業所');
ok($zip->set_number('4658552')->is_valid_number, '株式会社 トヨマック');
ok($zip->set_number('4658555')->is_valid_number, '藤久 株式会社 第2ビル');
ok($zip->set_number('4658558')->is_valid_number, '愛知県 名東警察署');
ok($zip->set_number('4658560')->is_valid_number, '中京三洋 株式会社');
ok($zip->set_number('4658565')->is_valid_number, '株式会社 プロトコーポレーション');
ok($zip->set_number('4658566')->is_valid_number, 'トヨタホーム名古屋 株式会社');
ok($zip->set_number('4658567')->is_valid_number, 'アルフレッサ 株式会社 東海オフィス');
ok($zip->set_number('4658610')->is_valid_number, '名古屋市厚生院');
ok($zip->set_number('4658611')->is_valid_number, '東海コープ事業連合・めいきん生協');
ok($zip->set_number('4658612')->is_valid_number, '株式会社 アトム');
ok($zip->set_number('4658620')->is_valid_number, '国立療養所 東名古屋病院');
ok($zip->set_number('4658622')->is_valid_number, '日本ぱちんこ部品 株式会社');
ok($zip->set_number('4658626')->is_valid_number, '名古屋市 栄市税事務所 上社出張所');
ok($zip->set_number('4658650')->is_valid_number, '公立大学法人 名古屋市立大学 医学部付属 みらい光生病院');
ok($zip->set_number('4658651')->is_valid_number, 'エレックヒシキ 株式会社');
ok($zip->set_number('4658668')->is_valid_number, 'ネットトヨタ中部 株式会社');
ok($zip->set_number('4658670')->is_valid_number, 'トーヨーキッチンアンドリビング 株式会社');
ok($zip->set_number('4668501')->is_valid_number, '愛知県名古屋南部県税事務所 高辻間税課');
ok($zip->set_number('4668502')->is_valid_number, 'トヨタL&F中部 株式会社');
ok($zip->set_number('4668505')->is_valid_number, '白川電気土木 株式会社');
ok($zip->set_number('4668506')->is_valid_number, '宮吉硝子 株式会社');
ok($zip->set_number('4668507')->is_valid_number, '株式会社 木曽路');
ok($zip->set_number('4668510')->is_valid_number, '榊原 株式会社');
ok($zip->set_number('4668511')->is_valid_number, '中央工機 株式会社');
ok($zip->set_number('4668512')->is_valid_number, '竹田印刷 株式会社');
ok($zip->set_number('4668515')->is_valid_number, '安藤 株式会社');
ok($zip->set_number('4668522')->is_valid_number, '日本ペイント販売 株式会社 中部支社');
ok($zip->set_number('4668525')->is_valid_number, '中京大学附属 中京高等学校');
ok($zip->set_number('4668533')->is_valid_number, '株式会社 日伝 名古屋支店');
ok($zip->set_number('4668539')->is_valid_number, '株式会社 一光 名古屋支店');
ok($zip->set_number('4668540')->is_valid_number, '株式会社 ホンダベルノ愛知');
ok($zip->set_number('4668550')->is_valid_number, '名古屋大学 医学部');
ok($zip->set_number('4668554')->is_valid_number, '味の素 株式会社 名古屋支社');
ok($zip->set_number('4668555')->is_valid_number, '名古屋工業大学');
ok($zip->set_number('4668558')->is_valid_number, '愛知県 自動車会館');
ok($zip->set_number('4668560')->is_valid_number, '名古屋大学 医学部 附属病院');
ok($zip->set_number('4668565')->is_valid_number, '一般社団法人 日本自動車連盟 中部本部');
ok($zip->set_number('4668566')->is_valid_number, '公益社団法人 愛知県安全運転管理協議会');
ok($zip->set_number('4668567')->is_valid_number, '日本年金機構 昭和年金事務所');
ok($zip->set_number('4668580')->is_valid_number, '一般社団法人 日本自動車連盟 愛知支部');
ok($zip->set_number('4668585')->is_valid_number, '名古屋市昭和区役所');
ok($zip->set_number('4668588')->is_valid_number, 'パイロットインキ 株式会社');
ok($zip->set_number('4668630')->is_valid_number, '光洋マテリカ 株式会社');
ok($zip->set_number('4668633')->is_valid_number, '聖霊病院');
ok($zip->set_number('4668635')->is_valid_number, '中京テレビ放送 株式会社');
ok($zip->set_number('4668636')->is_valid_number, '株式会社 ATビジネス');
ok($zip->set_number('4668650')->is_valid_number, '名古屋第二赤十字病院');
ok($zip->set_number('4668655')->is_valid_number, '愛知県保険医協会');
ok($zip->set_number('4668656')->is_valid_number, '矢崎総業 株式会社 名古屋支店');
ok($zip->set_number('4668657')->is_valid_number, '大学生協 東海会館');
ok($zip->set_number('4668660')->is_valid_number, '(株) ジョットインターナショナル 名古屋支店');
ok($zip->set_number('4668666')->is_valid_number, '中京大学');
ok($zip->set_number('4668673')->is_valid_number, '南山大学');
ok($zip->set_number('4668688')->is_valid_number, '愛知トヨタEAST 株式会社');
ok($zip->set_number('4668701')->is_valid_number, '愛知トヨタWEST 株式会社');
ok($zip->set_number('4668707')->is_valid_number, '中京テレビ放送 株式会社');
ok($zip->set_number('4668711')->is_valid_number, '辰巳屋興業 株式会社');
ok($zip->set_number('4678501')->is_valid_number, '名古屋市立大学 (経済学部、人文社会学部、教養教育、自然科学研究教育センター、計算センター)');
ok($zip->set_number('4678510')->is_valid_number, '昭和税務署');
ok($zip->set_number('4678511')->is_valid_number, '名古屋大谷高等学校');
ok($zip->set_number('4678520')->is_valid_number, '株式会社 シーテック');
ok($zip->set_number('4678521')->is_valid_number, '瑞穂高等学校');
ok($zip->set_number('4678522')->is_valid_number, 'マドラス 株式会社');
ok($zip->set_number('4678530')->is_valid_number, '日本ガイシ 株式会社');
ok($zip->set_number('4678531')->is_valid_number, '名古屋市瑞穂区役所');
ok($zip->set_number('4678533')->is_valid_number, '丸美産業 株式会社');
ok($zip->set_number('4678555')->is_valid_number, '一般社団法人 愛知県トラック協会');
ok($zip->set_number('4678558')->is_valid_number, '名古屋経済大学高蔵高等学校 名古屋経済大学高蔵中学校');
ok($zip->set_number('4678561')->is_valid_number, 'ブラザー工業 株式会社 本社');
ok($zip->set_number('4678562')->is_valid_number, 'ブラザー工業 株式会社 瑞穂工場');
ok($zip->set_number('4678563')->is_valid_number, '株式会社 中央製作所');
ok($zip->set_number('4678566')->is_valid_number, '株式会社 エクシング');
ok($zip->set_number('4678567')->is_valid_number, '株式会社 エルモ社');
ok($zip->set_number('4678571')->is_valid_number, '石原商事 株式会社');
ok($zip->set_number('4678577')->is_valid_number, 'ブラザー販売 株式会社');
ok($zip->set_number('4678580')->is_valid_number, 'アミテック 株式会社');
ok($zip->set_number('4678581')->is_valid_number, '木村刃物製造 株式会社');
ok($zip->set_number('4678585')->is_valid_number, '株式会社 パロマ');
ok($zip->set_number('4678588')->is_valid_number, '愛知日野自動車 株式会社');
ok($zip->set_number('4678601')->is_valid_number, '公立大学法人 名古屋市立大学');
ok($zip->set_number('4678602')->is_valid_number, '名古屋市立 大学病院');
ok($zip->set_number('4678603')->is_valid_number, '名古屋市立大学 薬学部');
ok($zip->set_number('4678610')->is_valid_number, '名古屋女子大学・名古屋女子大学短期大学部');
ok($zip->set_number('4678611')->is_valid_number, '名古屋女子大学中学校・高等学校');
ok($zip->set_number('4678622')->is_valid_number, '名古屋市総合リハビリテーションセンター');
ok($zip->set_number('4678626')->is_valid_number, '享栄高等学校');
ok($zip->set_number('4678633')->is_valid_number, '(医)新生会 新生会・第一病院');
ok($zip->set_number('4678639')->is_valid_number, '愛知県立昭和高校');
ok($zip->set_number('4678651')->is_valid_number, 'フジパン 株式会社');
ok($zip->set_number('4678686')->is_valid_number, 'フジパンストアー 株式会社');
ok($zip->set_number('4688501')->is_valid_number, 'SMBCファイナンスサービス 株式会社');
ok($zip->set_number('4688502')->is_valid_number, '名城大学');
ok($zip->set_number('4688503')->is_valid_number, '名城大学 薬学部');
ok($zip->set_number('4688505')->is_valid_number, '中日販売 株式会社');
ok($zip->set_number('4688507')->is_valid_number, '名古屋女子大学 天白学舎');
ok($zip->set_number('4688510')->is_valid_number, '天白区役所');
ok($zip->set_number('4688511')->is_valid_number, '豊田工業大学');
ok($zip->set_number('4688512')->is_valid_number, 'リョービ販売 株式会社');
ok($zip->set_number('4688513')->is_valid_number, '愛知県警察運転免許試験場');
ok($zip->set_number('4688514')->is_valid_number, '東海学園大学 名古屋キャンパス');
ok($zip->set_number('4688520')->is_valid_number, '名古屋記念病院');
ok($zip->set_number('4688522')->is_valid_number, 'トヨタホーム名古屋 株式会社');
ok($zip->set_number('4688531')->is_valid_number, '大洋技研工業 株式会社');
ok($zip->set_number('4688532')->is_valid_number, '安藤技建 株式会社');
ok($zip->set_number('4688533')->is_valid_number, 'ナカシャクリエイテブ 株式会社');
ok($zip->set_number('4688534')->is_valid_number, '日本ベターリビング 株式会社');
ok($zip->set_number('4688536')->is_valid_number, '株式会社 瓶屋');
ok($zip->set_number('4688537')->is_valid_number, '自動車安全運転センター 愛知県事務所');
ok($zip->set_number('4688551')->is_valid_number, '名古屋東労働基準監督署');
ok($zip->set_number('4688585')->is_valid_number, '株式会社 丸越');
ok($zip->set_number('4688588')->is_valid_number, '名古屋製酪 株式会社');
ok($zip->set_number('4688626')->is_valid_number, '名古屋市 金山市税事務所 野並出張所');
ok($zip->set_number('4698793')->is_valid_number, '日本郵便 株式会社 東海支社 郵便事業本部 (三種)');
ok($zip->set_number('4698796')->is_valid_number, '東海監査室');
ok($zip->set_number('4698797')->is_valid_number, '日本郵便 株式会社 東海支社');
ok($zip->set_number('4700186')->is_valid_number, 'ららぽーと愛知東郷');
ok($zip->set_number('4700188')->is_valid_number, '中西学園 中央図書館');
ok($zip->set_number('4700192')->is_valid_number, '日進市役所');
ok($zip->set_number('4700193')->is_valid_number, '学校法人 栗本学園 名古屋商科大学');
ok($zip->set_number('4700194')->is_valid_number, 'マスプロ電工 株式会社');
ok($zip->set_number('4700195')->is_valid_number, '愛知学院大学');
ok($zip->set_number('4700196')->is_valid_number, '名古屋学芸大学');
ok($zip->set_number('4700197')->is_valid_number, '名古屋外国語大学');
ok($zip->set_number('4700198')->is_valid_number, '東郷町役場');
ok($zip->set_number('4700292')->is_valid_number, 'NCA');
ok($zip->set_number('4700293')->is_valid_number, 'ノリタケカンパニー');
ok($zip->set_number('4700294')->is_valid_number, '株式会社 三五');
ok($zip->set_number('4700295')->is_valid_number, 'みよし市役所');
ok($zip->set_number('4700297')->is_valid_number, '株式会社 高速 中京営業部');
ok($zip->set_number('4700392')->is_valid_number, '愛知工業大学');
ok($zip->set_number('4700393')->is_valid_number, '中京大学');
ok($zip->set_number('4700394')->is_valid_number, '愛知みずほ大学');
ok($zip->set_number('4700395')->is_valid_number, 'トヨタ紡織 株式会社 猿投工場');
ok($zip->set_number('4700396')->is_valid_number, '愛知県厚生農業協同組合連合会 豊田厚生病院');
ok($zip->set_number('4700492')->is_valid_number, 'アイシン化工 株式会社');
ok($zip->set_number('4700493')->is_valid_number, '豊田市役所 藤岡支所');
ok($zip->set_number('4700495')->is_valid_number, 'あいち豊田農協 藤岡支店');
ok($zip->set_number('4700496')->is_valid_number, '豊和化成 株式会社');
ok($zip->set_number('4700592')->is_valid_number, '豊田市役所 小原支所');
ok($zip->set_number('4701192')->is_valid_number, '藤田保健衛生大学');
ok($zip->set_number('4701193')->is_valid_number, '名古屋短期大学');
ok($zip->set_number('4701194')->is_valid_number, 'ホシザキ電機 株式会社');
ok($zip->set_number('4701195')->is_valid_number, '豊明市役所');
ok($zip->set_number('4701196')->is_valid_number, '笹徳印刷 株式会社');
ok($zip->set_number('4701198')->is_valid_number, '寿がきや食品 株式会社 本社工場');
ok($zip->set_number('4701292')->is_valid_number, 'トヨタ生活 協同組合');
ok($zip->set_number('4701293')->is_valid_number, '豊生ブレーキ工業 株式会社');
ok($zip->set_number('4701294')->is_valid_number, '矢崎総業 株式会社');
ok($zip->set_number('4701295')->is_valid_number, '東洋工業');
ok($zip->set_number('4701296')->is_valid_number, 'シンテックホズミ');
ok($zip->set_number('4702191')->is_valid_number, 'カリモク家具 株式会社 本社');
ok($zip->set_number('4702192')->is_valid_number, '愛知県知多郡東浦町役場');
ok($zip->set_number('4702193')->is_valid_number, 'カリモク家具 株式会社 総張工場');
ok($zip->set_number('4702195')->is_valid_number, 'カリモク家具 株式会社 お客様相談室');
ok($zip->set_number('4702196')->is_valid_number, '住化積水フィルム 株式会社 名古屋工場');
ok($zip->set_number('4702197')->is_valid_number, '株式会社 ティラド名古屋製作所');
ok($zip->set_number('4702198')->is_valid_number, 'トーエイ 株式会社');
ok($zip->set_number('4702292')->is_valid_number, '阿久比町役場');
ok($zip->set_number('4702296')->is_valid_number, '株式会社 デンソーウェーブ');
ok($zip->set_number('4702297')->is_valid_number, '株式会社 デンソーウェーブ');
ok($zip->set_number('4702298')->is_valid_number, '株式会社 デンソー 阿久比製作所');
ok($zip->set_number('4702392')->is_valid_number, '武豊町役場');
ok($zip->set_number('4702393')->is_valid_number, 'ファイザー・ファーマ 株式会社');
ok($zip->set_number('4702394')->is_valid_number, '旭硝子 愛知工場');
ok($zip->set_number('4702395')->is_valid_number, 'ユタカフーズ 株式会社');
ok($zip->set_number('4702398')->is_valid_number, '日本油脂 愛知事業所');
ok($zip->set_number('4702492')->is_valid_number, '美浜町役場');
ok($zip->set_number('4702493')->is_valid_number, '加藤化学 株式会社');
ok($zip->set_number('4703295')->is_valid_number, '日本福祉大学');
ok($zip->set_number('4703296')->is_valid_number, '日本福祉大学 生活協同組合');
ok($zip->set_number('4703495')->is_valid_number, '南知多町役場');
ok($zip->set_number('4718501')->is_valid_number, '豊田市役所');
ok($zip->set_number('4718502')->is_valid_number, '大豊工業 株式会社');
ok($zip->set_number('4718503')->is_valid_number, '愛知県豊田事務所');
ok($zip->set_number('4718506')->is_valid_number, '豊田商工会議所');
ok($zip->set_number('4718507')->is_valid_number, '豊田鉄工 株式会社');
ok($zip->set_number('4718508')->is_valid_number, '住友ゴム工業 株式会社 名古屋工場');
ok($zip->set_number('4718510')->is_valid_number, '株式会社 F T S');
ok($zip->set_number('4718511')->is_valid_number, 'あいち豊田農業協同組合');
ok($zip->set_number('4718512')->is_valid_number, '豊田通商 株式会社 豊田支店');
ok($zip->set_number('4718513')->is_valid_number, 'トヨタ記念病院');
ok($zip->set_number('4718515')->is_valid_number, '株式会社 協豊製作所');
ok($zip->set_number('4718516')->is_valid_number, '豊田市役所 市民課');
ok($zip->set_number('4718517')->is_valid_number, '豊田市役所 市民税課');
ok($zip->set_number('4718518')->is_valid_number, '豊田市役所 生活福祉課');
ok($zip->set_number('4718521')->is_valid_number, '豊田税務署');
ok($zip->set_number('4718522')->is_valid_number, '中部工業 株式会社');
ok($zip->set_number('4718525')->is_valid_number, '豊田工業高等専門学校');
ok($zip->set_number('4718527')->is_valid_number, 'トヨタ輸送 株式会社');
ok($zip->set_number('4718530')->is_valid_number, '株式会社 三菱東京UFJ銀行 豊田支店');
ok($zip->set_number('4718531')->is_valid_number, '合資会社 原田屋');
ok($zip->set_number('4718532')->is_valid_number, '愛知学泉大学');
ok($zip->set_number('4718535')->is_valid_number, 'トリニティ工業 株式会社');
ok($zip->set_number('4718536')->is_valid_number, '三井海上火災保険 株式会社');
ok($zip->set_number('4718537')->is_valid_number, '愛知県豊田加茂県税事務所');
ok($zip->set_number('4718550')->is_valid_number, '光生アルミニューム工業 株式会社');
ok($zip->set_number('4718555')->is_valid_number, '株式会社 ニフコ');
ok($zip->set_number('4718560')->is_valid_number, '株式会社 松坂屋 豊田店');
ok($zip->set_number('4718565')->is_valid_number, '日本赤十字豊田看護大学');
ok($zip->set_number('4718566')->is_valid_number, '愛知県 豊田加茂農林水産事務所');
ok($zip->set_number('4718571')->is_valid_number, 'トヨタ自動車 株式会社');
ok($zip->set_number('4718572')->is_valid_number, 'トヨタ自動車 株式会社(本社技術部門)');
ok($zip->set_number('4718573')->is_valid_number, 'トヨタ自動車 株式会社 元町工場');
ok($zip->set_number('4718574')->is_valid_number, 'トヨタ自動車 株式会社 貞宝工場');
ok($zip->set_number('4718585')->is_valid_number, '名古屋法務局 豊田支局');
ok($zip->set_number('4718588')->is_valid_number, '小島プレス工業 株式会社');
ok($zip->set_number('4718601')->is_valid_number, '豊田信用金庫');
ok($zip->set_number('4718602')->is_valid_number, '豊田社会保険事務所');
ok($zip->set_number('4718603')->is_valid_number, '豊田市農業協同組合');
ok($zip->set_number('4718609')->is_valid_number, '豊田公共職業安定所');
ok($zip->set_number('4728555')->is_valid_number, '(宗) 遍照院');
ok($zip->set_number('4728585')->is_valid_number, '愛知県立 知立高等学校');
ok($zip->set_number('4728639')->is_valid_number, '愛知県立知立東高等学校');
ok($zip->set_number('4728666')->is_valid_number, '知立市役所');
ok($zip->set_number('4728686')->is_valid_number, '株式会社 FUJI');
ok($zip->set_number('4738501')->is_valid_number, 'アイシン高丘 株式会社');
ok($zip->set_number('4738511')->is_valid_number, '富士精工 株式会社');
ok($zip->set_number('4748501')->is_valid_number, '住友重機械工業 株式会社 名古屋製造所');
ok($zip->set_number('4748502')->is_valid_number, '株式会社 新居浜鐵工所 名古屋工場');
ok($zip->set_number('4748503')->is_valid_number, '大府商工会議所');
ok($zip->set_number('4748505')->is_valid_number, '愛協産業 株式会社');
ok($zip->set_number('4748510')->is_valid_number, 'イヅミ工業 株式会社');
ok($zip->set_number('4748511')->is_valid_number, '国立研究開発法人 国立長寿医療研究センター');
ok($zip->set_number('4748535')->is_valid_number, '大和機工 株式会社');
ok($zip->set_number('4748543')->is_valid_number, '株式会社 名南製作所');
ok($zip->set_number('4748550')->is_valid_number, '住友重機械建機クレーン (株) 名古屋工場');
ok($zip->set_number('4748555')->is_valid_number, '住友ナコフォークリフト 株式会社');
ok($zip->set_number('4748557')->is_valid_number, '(株) 東海理機製作所 横根工場');
ok($zip->set_number('4748558')->is_valid_number, '株式会社 東海理機製作所 長根工場');
ok($zip->set_number('4748580')->is_valid_number, 'アイサンコンピュータサービス 株式会社');
ok($zip->set_number('4748581')->is_valid_number, '株式会社 アンセイ');
ok($zip->set_number('4748584')->is_valid_number, '株式会社 八神');
ok($zip->set_number('4748585')->is_valid_number, '株式会社 アペックス');
ok($zip->set_number('4748588')->is_valid_number, '愛三工業 株式会社');
ok($zip->set_number('4748601')->is_valid_number, '株式会社 豊田自動織機製作所 共和工場');
ok($zip->set_number('4748610')->is_valid_number, '株式会社 富士プレス');
ok($zip->set_number('4748611')->is_valid_number, '株式会社 富新住宅設備');
ok($zip->set_number('4748642')->is_valid_number, '東洋クッション 株式会社');
ok($zip->set_number('4748651')->is_valid_number, '至学館大学');
ok($zip->set_number('4748666')->is_valid_number, '(株) 名機製作所');
ok($zip->set_number('4748668')->is_valid_number, '株式会社 豊田自動織機 大府工場');
ok($zip->set_number('4748686')->is_valid_number, '(株) 豊田自動織機製作所 長草工場');
ok($zip->set_number('4748688')->is_valid_number, '東海興業 (株)');
ok($zip->set_number('4748701')->is_valid_number, '愛知県大府市役所');
ok($zip->set_number('4748707')->is_valid_number, '東知多農業 協同組合');
ok($zip->set_number('4748710')->is_valid_number, 'あいち小児保健医療総合センター');
ok($zip->set_number('4748766')->is_valid_number, 'ネットオフ 株式会社 「書籍・CDコース」買取センター');
ok($zip->set_number('4748777')->is_valid_number, 'メダルPJ受付センター');
ok($zip->set_number('4758501')->is_valid_number, '愛知県知多県民センター');
ok($zip->set_number('4758502')->is_valid_number, '半田公共職業安定所');
ok($zip->set_number('4758505')->is_valid_number, '愛知県知多県税事務所');
ok($zip->set_number('4758510')->is_valid_number, '山田紡績 株式会社');
ok($zip->set_number('4758511')->is_valid_number, '社団法人 半田市医師会健康管理センター');
ok($zip->set_number('4758522')->is_valid_number, '社団法人 半田市医師会健康管理センター');
ok($zip->set_number('4758528')->is_valid_number, '株式会社 鶴弥');
ok($zip->set_number('4758541')->is_valid_number, '株式会社 中京医薬品');
ok($zip->set_number('4758550')->is_valid_number, 'ツカサ工業 株式会社');
ok($zip->set_number('4758555')->is_valid_number, '半田法人会');
ok($zip->set_number('4758557')->is_valid_number, '株式会社 イシハラフード');
ok($zip->set_number('4758560')->is_valid_number, '半田労働基準監督署');
ok($zip->set_number('4758574')->is_valid_number, '加藤電機 株式会社');
ok($zip->set_number('4758585')->is_valid_number, '株式会社 中埜酢店');
ok($zip->set_number('4758588')->is_valid_number, '三菱東京UFJ銀行 半田支店');
ok($zip->set_number('4758599')->is_valid_number, '半田市立半田病院');
ok($zip->set_number('4758601')->is_valid_number, '半田社会保険事務所');
ok($zip->set_number('4758611')->is_valid_number, 'JFEスチール 株式会社');
ok($zip->set_number('4758655')->is_valid_number, '半田信用金庫');
ok($zip->set_number('4758666')->is_valid_number, '半田市役所');
ok($zip->set_number('4758668')->is_valid_number, '輸送機工業 株式会社');
ok($zip->set_number('4758686')->is_valid_number, '半田税務署');
ok($zip->set_number('4768501')->is_valid_number, '東邦ガス 株式会社 総合技術研究所');
ok($zip->set_number('4768503')->is_valid_number, '大洋プラスチック');
ok($zip->set_number('4768510')->is_valid_number, '協栄興業株式会社、協栄工機株式会社、協栄運輸株式会社、協栄高圧ガス株式会社');
ok($zip->set_number('4768522')->is_valid_number, 'トヨフジ海運 株式会社');
ok($zip->set_number('4768533')->is_valid_number, '豊田スチールセンター 株式会社');
ok($zip->set_number('4768567')->is_valid_number, '東レ 株式会社 東海工場');
ok($zip->set_number('4768577')->is_valid_number, '株式会社 坂角 総本舗');
ok($zip->set_number('4768585')->is_valid_number, 'カゴメ 株式会社 上野工場');
ok($zip->set_number('4768588')->is_valid_number, '学校法人 名古屋石田学園 星城大学');
ok($zip->set_number('4768601')->is_valid_number, '東海市役所');
ok($zip->set_number('4768666')->is_valid_number, '愛知製鋼 株式会社');
ok($zip->set_number('4768686')->is_valid_number, '新日本製鐵 株式會社 名古屋製鐵所');
ok($zip->set_number('4778521')->is_valid_number, '知多メディアスネットワーク (株)');
ok($zip->set_number('4778522')->is_valid_number, '公立西知多総合病院');
ok($zip->set_number('4788501')->is_valid_number, '日清丸紅飼料 株式会社 知多工場');
ok($zip->set_number('4788502')->is_valid_number, '中部飼料 株式会社');
ok($zip->set_number('4788503')->is_valid_number, 'サンエイ糖化 株式会社');
ok($zip->set_number('4788504')->is_valid_number, 'JX日鉱日石エネルギー 株式会社 知多製造所');
ok($zip->set_number('4788505')->is_valid_number, '株式会社 LIXIL 知多事業所');
ok($zip->set_number('4788555')->is_valid_number, '出光興産 株式会社 愛知製油所');
ok($zip->set_number('4788601')->is_valid_number, '知多市役所');
ok($zip->set_number('4788640')->is_valid_number, '知多市民病院');
ok($zip->set_number('4788641')->is_valid_number, '株式会社 エフエスケー');
ok($zip->set_number('4798501')->is_valid_number, '常滑市ボートレース事業局');
ok($zip->set_number('4798510')->is_valid_number, '常滑市民病院');
ok($zip->set_number('4798511')->is_valid_number, '株式会社 デンソーダイシン');
ok($zip->set_number('4798518')->is_valid_number, '丸茂工業');
ok($zip->set_number('4798555')->is_valid_number, '知多半島ケーブルネットワーク 株式会社');
ok($zip->set_number('4798577')->is_valid_number, 'ジャニス工業 株式会社');
ok($zip->set_number('4798585')->is_valid_number, '株式会社 LIXIL 常滑本社');
ok($zip->set_number('4798586')->is_valid_number, 'INAXライブミュージアム');
ok($zip->set_number('4798587')->is_valid_number, '株式会社 LIXIL 常滑東工場');
ok($zip->set_number('4798588')->is_valid_number, '株式会社 LIXIL 榎戸工場');
ok($zip->set_number('4798589')->is_valid_number, '株式会社 LIXIL 大谷工場');
ok($zip->set_number('4798601')->is_valid_number, 'あいち知多 農業協同組合');
ok($zip->set_number('4798610')->is_valid_number, '常滑市役所');
ok($zip->set_number('4798623')->is_valid_number, '株式会社 マキノ');
ok($zip->set_number('4798668')->is_valid_number, '常滑商工会議所');
ok($zip->set_number('4798701')->is_valid_number, '中部国際空港 株式会社');
ok($zip->set_number('4798702')->is_valid_number, '中部国際空港情報通信 株式会社');
ok($zip->set_number('4798703')->is_valid_number, '中部国際空港施設サービス 株式会社');
ok($zip->set_number('4798704')->is_valid_number, '中部国際空港旅客サービス 株式会社');
ok($zip->set_number('4798705')->is_valid_number, '中部国際空港エネルギー供給 株式会社');
ok($zip->set_number('4798706')->is_valid_number, '中部国際空港給油施設 株式会社');
ok($zip->set_number('4798707')->is_valid_number, '名古屋税関中部空港税関支署(中部空港CIQ庁舎)');
ok($zip->set_number('4798708')->is_valid_number, '名古屋税関中部空港税関支署(中部空港合同庁舎)');
ok($zip->set_number('4798711')->is_valid_number, '中部国際空港 株式会社 総務部人事グループ新卒採用担当');
ok($zip->set_number('4798712')->is_valid_number, '中部国際空港 株式会社 航空営業部貨物営業グループ');
ok($zip->set_number('4798787')->is_valid_number, '国土交通省大阪航空局中部空港事務所');
ok($zip->set_number('4800192')->is_valid_number, '兼房 株式会社');
ok($zip->set_number('4800193')->is_valid_number, 'オークマ 株式会社');
ok($zip->set_number('4800195')->is_valid_number, '株式会社 東海理化電機製作所');
ok($zip->set_number('4800197')->is_valid_number, 'ヤマザキマザック 株式会社');
ok($zip->set_number('4800198')->is_valid_number, '青山製作所 株式会社');
ok($zip->set_number('4800281')->is_valid_number, 'セントライ青果 株式会社');
ok($zip->set_number('4800282')->is_valid_number, 'アピタ名古屋空港店');
ok($zip->set_number('4800287')->is_valid_number, '三菱航空機 株式会社');
ok($zip->set_number('4800288')->is_valid_number, 'エアポートウォーク名古屋');
ok($zip->set_number('4800291')->is_valid_number, '名北魚市場 株式会社');
ok($zip->set_number('4800292')->is_valid_number, '豊山町役場');
ok($zip->set_number('4800293')->is_valid_number, '三菱重工業 株式会社');
ok($zip->set_number('4800294')->is_valid_number, '中日本航空 株式会社');
ok($zip->set_number('4800297')->is_valid_number, '朝日航洋 株式会社 南格納庫');
ok($zip->set_number('4800297')->is_valid_number, 'セントラルヘリコプターサービス 株式会社');
ok($zip->set_number('4800392')->is_valid_number, '愛知県医療療育総合センター');
ok($zip->set_number('4800393')->is_valid_number, '東洋電機 株式会社');
ok($zip->set_number('4800395')->is_valid_number, 'ダイコク電機 (株)');
ok($zip->set_number('4801188')->is_valid_number, '株式会社 ホンダカーズ愛知');
ok($zip->set_number('4801189')->is_valid_number, '日東工業 株式会社');
ok($zip->set_number('4801192')->is_valid_number, '株式会社 豊田中央研究所');
ok($zip->set_number('4801193')->is_valid_number, '愛知県農業総合試験場');
ok($zip->set_number('4801194')->is_valid_number, '愛知県立芸術大学');
ok($zip->set_number('4801195')->is_valid_number, '愛知医科大学');
ok($zip->set_number('4801196')->is_valid_number, '長久手市役所');
ok($zip->set_number('4801197')->is_valid_number, '愛知淑徳大学');
ok($zip->set_number('4801198')->is_valid_number, '愛知県立大学');
ok($zip->set_number('4801298')->is_valid_number, '名古屋学院大学');
ok($zip->set_number('4818501')->is_valid_number, '北名古屋市役所東庁舎');
ok($zip->set_number('4818502')->is_valid_number, '名古屋自由学院');
ok($zip->set_number('4818503')->is_valid_number, '名古屋芸術大学 音楽学部');
ok($zip->set_number('4818504')->is_valid_number, '名古屋自由学院 短期大学');
ok($zip->set_number('4818505')->is_valid_number, '株式会社 フジワラ');
ok($zip->set_number('4818506')->is_valid_number, '株式会社 三菱UFJ銀行 地方税ダイレクト受付センター');
ok($zip->set_number('4818508')->is_valid_number, '日進電気 株式会社');
ok($zip->set_number('4818510')->is_valid_number, '(株) ポッカコーポレーション 名古屋工場');
ok($zip->set_number('4818511')->is_valid_number, '株式会社 長登屋');
ok($zip->set_number('4818513')->is_valid_number, '(株) 三菱UFJ銀行 師勝ビル');
ok($zip->set_number('4818515')->is_valid_number, '(株) ポッカコーポレーション 中央研究所');
ok($zip->set_number('4818526')->is_valid_number, '株式会社 真誠');
ok($zip->set_number('4818531')->is_valid_number, '北名古屋市役所');
ok($zip->set_number('4818533')->is_valid_number, '天野エンザイム 株式会社 名古屋工場');
ok($zip->set_number('4818535')->is_valid_number, '名古屋芸術大学 西キャンパス');
ok($zip->set_number('4818539')->is_valid_number, '大橋鉄工 株式会社');
ok($zip->set_number('4818540')->is_valid_number, '三洋機工 株式会社');
ok($zip->set_number('4818543')->is_valid_number, '天野エンザイム 株式会社 西春工場');
ok($zip->set_number('4818550')->is_valid_number, 'チタカ・インターナショナル・フーズ 株式会社');
ok($zip->set_number('4818555')->is_valid_number, '株式会社 八幡ねじ');
ok($zip->set_number('4818558')->is_valid_number, '株式会社 大一商会');
ok($zip->set_number('4818588')->is_valid_number, '北名古屋市東図書館・北名古屋市歴史民俗資料館');
ok($zip->set_number('4818601')->is_valid_number, 'ゼネラルパッカー 株式会社');
ok($zip->set_number('4818615')->is_valid_number, '株式会社 百五銀行 西春支店');
ok($zip->set_number('4818678')->is_valid_number, '新東工業 株式会社');
ok($zip->set_number('4818681')->is_valid_number, '株式会社 日進医療器');
ok($zip->set_number('4828501')->is_valid_number, '三興石油工業 株式会社');
ok($zip->set_number('4828510')->is_valid_number, '石塚硝子 株式会社 岩倉工場');
ok($zip->set_number('4828511')->is_valid_number, 'ミヨシ油脂 株式会社 名古屋工場');
ok($zip->set_number('4828555')->is_valid_number, '愛知県立 岩倉総合高等学校');
ok($zip->set_number('4828651')->is_valid_number, 'いちい信用金庫 愛北営業部');
ok($zip->set_number('4828652')->is_valid_number, 'カウパック 株式会社');
ok($zip->set_number('4828660')->is_valid_number, '株式会社 ゲオ 岩倉流通');
ok($zip->set_number('4828686')->is_valid_number, '岩倉市役所');
ok($zip->set_number('4838502')->is_valid_number, '株式会社 ミサワテクノ');
ok($zip->set_number('4838505')->is_valid_number, 'JA 愛知北');
ok($zip->set_number('4838507')->is_valid_number, 'アピタ 江南店');
ok($zip->set_number('4838555')->is_valid_number, 'サン電子 株式会社');
ok($zip->set_number('4838701')->is_valid_number, '江南市役所');
ok($zip->set_number('4838704')->is_valid_number, '愛知県厚生農業協同組合連合会 江南厚生病院');
ok($zip->set_number('4838714')->is_valid_number, 'トラスコ中山 株式会社 プラネット名古屋');
ok($zip->set_number('4848501')->is_valid_number, '犬山市役所');
ok($zip->set_number('4848502')->is_valid_number, '村田機械 株式会社 犬山工場');
ok($zip->set_number('4848503')->is_valid_number, '名古屋経済大学 短期大学部');
ok($zip->set_number('4848504')->is_valid_number, '名古屋経済大学');
ok($zip->set_number('4848505')->is_valid_number, 'エナジーサポート 株式会社');
ok($zip->set_number('4848506')->is_valid_number, '京都大学 ヒト行動進化研究センター');
ok($zip->set_number('4848507')->is_valid_number, '(株) 今仙電機製作所');
ok($zip->set_number('4848508')->is_valid_number, '東洋紡 株式会社 犬山工場');
ok($zip->set_number('4848510')->is_valid_number, '犬山商工会議所');
ok($zip->set_number('4848511')->is_valid_number, '医療法人社団 志聖会 犬山中央病院');
ok($zip->set_number('4848512')->is_valid_number, '成田山 大聖寺');
ok($zip->set_number('4848609')->is_valid_number, '犬山公共職業安定所');
ok($zip->set_number('4858505')->is_valid_number, '丸菱工業 株式会社');
ok($zip->set_number('4858510')->is_valid_number, '日本特殊陶業 株式会社 小牧工場');
ok($zip->set_number('4858511')->is_valid_number, '三ツ星ベルト販賣 株式会社 小牧営業所');
ok($zip->set_number('4858512')->is_valid_number, '(株) 三河屋');
ok($zip->set_number('4858516')->is_valid_number, '大日本塗料 株式会社 小牧工場');
ok($zip->set_number('4858520')->is_valid_number, '小牧市民病院');
ok($zip->set_number('4858521')->is_valid_number, '株式会社 国盛化学');
ok($zip->set_number('4858522')->is_valid_number, 'センコー 株式会社 小牧営業所');
ok($zip->set_number('4858523')->is_valid_number, '佐藤食品工業 株式会社');
ok($zip->set_number('4858530')->is_valid_number, 'サカイ創建 株式会社');
ok($zip->set_number('4858531')->is_valid_number, '三友工業 株式会社');
ok($zip->set_number('4858533')->is_valid_number, '愛知陸運 株式会社');
ok($zip->set_number('4858540')->is_valid_number, '株式会社 テクノワシノ');
ok($zip->set_number('4858550')->is_valid_number, '住友理工 株式会社');
ok($zip->set_number('4858551')->is_valid_number, 'CKD 株式会社');
ok($zip->set_number('4858552')->is_valid_number, '小牧商工会議所');
ok($zip->set_number('4858555')->is_valid_number, '(株)松本義肢製作所');
ok($zip->set_number('4858557')->is_valid_number, 'エヌジーケイ・セラミックデバイス 株式会社');
ok($zip->set_number('4858561')->is_valid_number, '三菱重工業 株式会社 名古屋誘導推進システム製作所');
ok($zip->set_number('4858562')->is_valid_number, '株式会社 ホウトク');
ok($zip->set_number('4858563')->is_valid_number, '名古屋造形芸術大学・短期大学');
ok($zip->set_number('4858565')->is_valid_number, '愛知文教大学');
ok($zip->set_number('4858650')->is_valid_number, '小牧市役所');
ok($zip->set_number('4858651')->is_valid_number, '小牧税務署');
ok($zip->set_number('4858652')->is_valid_number, '航空自衛隊 小牧基地');
ok($zip->set_number('4858653')->is_valid_number, '(株) ダイフク小牧事業所');
ok($zip->set_number('4858654')->is_valid_number, '株式会社 クラウンパッケージ');
ok($zip->set_number('4858655')->is_valid_number, '飯田工業 株式会社');
ok($zip->set_number('4858750')->is_valid_number, '中部電力 株式会社 小牧営業所 小牧電力センター');
ok($zip->set_number('4868501')->is_valid_number, '愛知金属工業 株式会社');
ok($zip->set_number('4868510')->is_valid_number, '春日井市民病院');
ok($zip->set_number('4868511')->is_valid_number, '春日井商工会議所');
ok($zip->set_number('4868515')->is_valid_number, '愛知県東尾張県税事務所');
ok($zip->set_number('4868522')->is_valid_number, 'パナソニックエコシステムズ 株式会社');
ok($zip->set_number('4868523')->is_valid_number, 'パナソニックエコシステムズ 株式会社');
ok($zip->set_number('4868540')->is_valid_number, '中部電力パワーグリッド 株式会社 春日井営業所');
ok($zip->set_number('4868550')->is_valid_number, '陸上自衛隊 春日井駐屯地');
ok($zip->set_number('4868555')->is_valid_number, '株式会社 イエローハット 中部エリア');
ok($zip->set_number('4868567')->is_valid_number, '株式会社 イケックス工業');
ok($zip->set_number('4868575')->is_valid_number, '(株) 中日総合サービス 春日井営業所');
ok($zip->set_number('4868585')->is_valid_number, '東洋電機 株式会社 春日井工場');
ok($zip->set_number('4868588')->is_valid_number, '株式会社 ゲオ');
ok($zip->set_number('4868666')->is_valid_number, '愛知電機 株式会社');
ok($zip->set_number('4868686')->is_valid_number, '春日井市役所');
ok($zip->set_number('4878501')->is_valid_number, '中部大学');
ok($zip->set_number('4878622')->is_valid_number, '株式会社 キクチメガネ');
ok($zip->set_number('4878650')->is_valid_number, '中部精機 株式会社');
ok($zip->set_number('4888501')->is_valid_number, '日立オムロンターミナルソリューションズ (株)');
ok($zip->set_number('4888520')->is_valid_number, 'パナソニック スイッチギアシステムズ 株式会社');
ok($zip->set_number('4888555')->is_valid_number, '愛知県森林公園協会');
ok($zip->set_number('4888578')->is_valid_number, '尾張精機 株式会社');
ok($zip->set_number('4888585')->is_valid_number, '独立行政法人 労働者健康福祉機構 旭労災病院');
ok($zip->set_number('4888655')->is_valid_number, '旭精機工業 株式会社');
ok($zip->set_number('4888666')->is_valid_number, '尾張旭市役所');
ok($zip->set_number('4888686')->is_valid_number, '株式会社 アイトー');
ok($zip->set_number('4888688')->is_valid_number, '旭サナック 株式会社');
ok($zip->set_number('4898450')->is_valid_number, '(株) 尾張東部放送');
ok($zip->set_number('4898510')->is_valid_number, 'テクノエイト 株式会社');
ok($zip->set_number('4898511')->is_valid_number, '瀬戸商工会議所');
ok($zip->set_number('4898520')->is_valid_number, '尾張瀬戸税務署');
ok($zip->set_number('4898550')->is_valid_number, '豊精密工業 株式会社');
ok($zip->set_number('4898555')->is_valid_number, '愛知県赤十字血液センター');
ok($zip->set_number('4898567')->is_valid_number, 'インロック社 株式会社 インロック');
ok($zip->set_number('4898585')->is_valid_number, '日本赤十字社 東海北陸ブロック血液センター');
ok($zip->set_number('4898611')->is_valid_number, '河村電器産業 株式会社');
ok($zip->set_number('4898642')->is_valid_number, '公立陶生病院');
ok($zip->set_number('4898645')->is_valid_number, '(株) オプトン');
ok($zip->set_number('4898650')->is_valid_number, '瀬戸信用金庫');
ok($zip->set_number('4898680')->is_valid_number, '株式会社 成田製陶所');
ok($zip->set_number('4898701')->is_valid_number, '瀬戸市役所');
ok($zip->set_number('4898777')->is_valid_number, 'ロック・セールス社');
ok($zip->set_number('4901192')->is_valid_number, '海部郡大治町役場');
ok($zip->set_number('4901193')->is_valid_number, '株式会社 コーワ');
ok($zip->set_number('4901194')->is_valid_number, '株式会社 鎌倉ハム');
ok($zip->set_number('4901198')->is_valid_number, 'あま市役所 甚目寺庁舎');
ok($zip->set_number('4901292')->is_valid_number, 'あま市役所');
ok($zip->set_number('4901293')->is_valid_number, '株式会社 岩月屋');
ok($zip->set_number('4901294')->is_valid_number, '名古屋電機工業 株式会社');
ok($zip->set_number('4901295')->is_valid_number, '美和高等学校');
ok($zip->set_number('4901296')->is_valid_number, '旭中部資材 株式会社');
ok($zip->set_number('4901392')->is_valid_number, '稲沢市 平和支所');
ok($zip->set_number('4910192')->is_valid_number, 'ソニー一宮 株式会社');
ok($zip->set_number('4910392')->is_valid_number, '岩田食品 株式会社');
ok($zip->set_number('4910393')->is_valid_number, '橋本毛織 株式会社');
ok($zip->set_number('4910394')->is_valid_number, 'アイコクアルファ 株式会社 一宮工場');
ok($zip->set_number('4910395')->is_valid_number, '和泉化成 株式会社');
ok($zip->set_number('4918501')->is_valid_number, '一宮市役所');
ok($zip->set_number('4918502')->is_valid_number, '一宮 税務署');
ok($zip->set_number('4918505')->is_valid_number, 'サンファイン 株式会社');
ok($zip->set_number('4918506')->is_valid_number, '愛知県西尾張県税事務所');
ok($zip->set_number('4918508')->is_valid_number, '株式会社 ジェイオーディ');
ok($zip->set_number('4918509')->is_valid_number, '一宮公共職業安定所');
ok($zip->set_number('4918512')->is_valid_number, '株式会社 油伝商店');
ok($zip->set_number('4918513')->is_valid_number, 'ササキセルム 株式会社');
ok($zip->set_number('4918515')->is_valid_number, '株式会社 ファッションヤマグチ');
ok($zip->set_number('4918516')->is_valid_number, '株式会社 滝善');
ok($zip->set_number('4918526')->is_valid_number, '中日本高速道路 株式会社');
ok($zip->set_number('4918528')->is_valid_number, '株式会社 三昭堂');
ok($zip->set_number('4918531')->is_valid_number, '医療法人 山下病院');
ok($zip->set_number('4918532')->is_valid_number, '株式会社 カネスエ');
ok($zip->set_number('4918533')->is_valid_number, '県立一宮高校');
ok($zip->set_number('4918535')->is_valid_number, '株式会社 アバンセコーポレーション');
ok($zip->set_number('4918551')->is_valid_number, '医療法人 大雄会');
ok($zip->set_number('4918553')->is_valid_number, '株式会社 タナカふとんサービス');
ok($zip->set_number('4918555')->is_valid_number, 'ワシズ機械 株式会社');
ok($zip->set_number('4918558')->is_valid_number, '一宮市立市民病院');
ok($zip->set_number('4918561')->is_valid_number, '日本毛織 株式会社 一宮工場');
ok($zip->set_number('4918562')->is_valid_number, '大井田工業 株式会社');
ok($zip->set_number('4918571')->is_valid_number, '中部電力パワーグリッド 株式会社 一宮営業所');
ok($zip->set_number('4918575')->is_valid_number, '株式会社 中日総合サービス');
ok($zip->set_number('4918576')->is_valid_number, '松永 株式会社');
ok($zip->set_number('4918577')->is_valid_number, 'ユニー 一宮店');
ok($zip->set_number('4918585')->is_valid_number, '株式会社 名鉄百貨店 一宮店');
ok($zip->set_number('4918601')->is_valid_number, '株式会社 壱番屋');
ok($zip->set_number('4918608')->is_valid_number, '長大 株式会社');
ok($zip->set_number('4918610')->is_valid_number, 'モリリン 株式会社');
ok($zip->set_number('4918611')->is_valid_number, 'いちい信用金庫');
ok($zip->set_number('4918612')->is_valid_number, '中外国島 株式会社');
ok($zip->set_number('4918686')->is_valid_number, '一宮商工会議所');
ok($zip->set_number('4918688')->is_valid_number, '愛和産業 株式会社');
ok($zip->set_number('4928501')->is_valid_number, '東朋テクノロジー 株式会社');
ok($zip->set_number('4928502')->is_valid_number, 'ARC 株式会社');
ok($zip->set_number('4928510')->is_valid_number, '稲沢市民病院');
ok($zip->set_number('4928512')->is_valid_number, '丸徳産業 株式会社');
ok($zip->set_number('4928513')->is_valid_number, '日軽産業 株式会社');
ok($zip->set_number('4928520')->is_valid_number, '名古屋文理短期大学');
ok($zip->set_number('4928521')->is_valid_number, '愛知文教女子短期大学');
ok($zip->set_number('4928523')->is_valid_number, '三菱東京UFJ銀行');
ok($zip->set_number('4928525')->is_valid_number, '稲沢商工会議所');
ok($zip->set_number('4928528')->is_valid_number, '愛松建設 株式会社');
ok($zip->set_number('4928529')->is_valid_number, '愛知啓成高等学校');
ok($zip->set_number('4928540')->is_valid_number, '豊田合成 株式会社 技術センター');
ok($zip->set_number('4928541')->is_valid_number, '豊田合成 株式会社 北島物流センター');
ok($zip->set_number('4928542')->is_valid_number, '豊田合成 株式会社 稲沢工場');
ok($zip->set_number('4928545')->is_valid_number, 'ソニーイーエムシーエス 株式会社 稲沢サイト');
ok($zip->set_number('4928546')->is_valid_number, '三和式ベンチレーター 株式会社');
ok($zip->set_number('4928547')->is_valid_number, 'イイダ産業 株式会社');
ok($zip->set_number('4928548')->is_valid_number, '中部抵抗器 株式会社');
ok($zip->set_number('4928601')->is_valid_number, 'ユニー 株式会社 リーフウォーク稲沢');
ok($zip->set_number('4928621')->is_valid_number, '株式会社 サカイナゴヤ');
ok($zip->set_number('4928622')->is_valid_number, '株式会社 日立アイイーシステム');
ok($zip->set_number('4928628')->is_valid_number, '東新住建 株式会社');
ok($zip->set_number('4928646')->is_valid_number, '株式会社 ソーゴー');
ok($zip->set_number('4928651')->is_valid_number, 'ユニー 株式会社 アピタ稲沢東店');
ok($zip->set_number('4928680')->is_valid_number, 'ユニー 株式会社');
ok($zip->set_number('4928681')->is_valid_number, 'ユニー 株式会社 アピタ稲沢店');
ok($zip->set_number('4928682')->is_valid_number, '三菱電機 株式会社 稲沢製作所');
ok($zip->set_number('4928685')->is_valid_number, '株式会社 ファミリーマート');
ok($zip->set_number('4928686')->is_valid_number, '株式会社 UCS');
ok($zip->set_number('4948501')->is_valid_number, '株式会社 ソトー 本社');
ok($zip->set_number('4948502')->is_valid_number, '豊田合成 株式会社 尾西工場');
ok($zip->set_number('4948505')->is_valid_number, '尾西市民病院');
ok($zip->set_number('4948507')->is_valid_number, '栗原産業 株式会社');
ok($zip->set_number('4948511')->is_valid_number, '株式会社 山田ドビー');
ok($zip->set_number('4948516')->is_valid_number, '株式会社 ソトー 一宮事業部');
ok($zip->set_number('4948601')->is_valid_number, '一宮市役所 尾西庁舎');
ok($zip->set_number('4948611')->is_valid_number, '尾西信用金庫');
ok($zip->set_number('4948686')->is_valid_number, '加藤産業 株式会社 名古屋支店');
ok($zip->set_number('4958501')->is_valid_number, 'アイコクアルファ 株式会社');
ok($zip->set_number('4958505')->is_valid_number, '愛知県立 杏和高等学校');
ok($zip->set_number('4958510')->is_valid_number, '帝人テクロス 株式会社');
ok($zip->set_number('4958511')->is_valid_number, '稲沢市 祖父江支所');
ok($zip->set_number('4958517')->is_valid_number, '株式会社 コメットカトウ');
ok($zip->set_number('4958531')->is_valid_number, '愛知県 厚生連 尾西病院');
ok($zip->set_number('4958601')->is_valid_number, '王子マテリア 株式会社 祖父江工場');
ok($zip->set_number('4968501')->is_valid_number, '株式会社 義津屋');
ok($zip->set_number('4968503')->is_valid_number, '株式会社 西日本宇佐美 東海支店');
ok($zip->set_number('4968508')->is_valid_number, '株式会社 前田');
ok($zip->set_number('4968531')->is_valid_number, '愛知県海部県民事務所');
ok($zip->set_number('4968532')->is_valid_number, '愛知県 海部農林水産事務所');
ok($zip->set_number('4968533')->is_valid_number, '愛知県海部建設事務所');
ok($zip->set_number('4968534')->is_valid_number, '愛知県 海部教育事務所');
ok($zip->set_number('4968535')->is_valid_number, '愛知県海部福祉相談センター');
ok($zip->set_number('4968537')->is_valid_number, '津島市民病院');
ok($zip->set_number('4968555')->is_valid_number, '愛西市役所');
ok($zip->set_number('4968558')->is_valid_number, '津島商工会議所');
ok($zip->set_number('4968575')->is_valid_number, '(株) 中日総合サービス 津島営業所');
ok($zip->set_number('4968585')->is_valid_number, '株式会社 ユーストア');
ok($zip->set_number('4968601')->is_valid_number, '愛西市役所 佐織庁舎');
ok($zip->set_number('4968633')->is_valid_number, '愛西市役所 立田庁舎');
ok($zip->set_number('4968639')->is_valid_number, '愛西市役所 八開庁舎');
ok($zip->set_number('4968648')->is_valid_number, '海部農協 八開支店');
ok($zip->set_number('4968686')->is_valid_number, '津島市役所');
ok($zip->set_number('4968720')->is_valid_number, '津島税務署');
ok($zip->set_number('4978501')->is_valid_number, '株式会社 加藤建設');
ok($zip->set_number('4978505')->is_valid_number, '七宝病院');
ok($zip->set_number('4978508')->is_valid_number, '株式会社 ヨシヅヤ 蟹江店');
ok($zip->set_number('4978510')->is_valid_number, '株式会社 マツヤ');
ok($zip->set_number('4978511')->is_valid_number, '丸信製粉 株式会社');
ok($zip->set_number('4978512')->is_valid_number, '株式会社 エイビス');
ok($zip->set_number('4978522')->is_valid_number, 'あま市役所 七宝庁舎');
ok($zip->set_number('4978527')->is_valid_number, '高梨産業 株式会社');
ok($zip->set_number('4978531')->is_valid_number, '株式会社 アンレット');
ok($zip->set_number('4978533')->is_valid_number, '加藤軽金属工業 株式会社');
ok($zip->set_number('4978538')->is_valid_number, '中部第一輸送 株式会社');
ok($zip->set_number('4978541')->is_valid_number, 'NTN特殊合金 株式会社');
ok($zip->set_number('4978545')->is_valid_number, '株式会社 松岡');
ok($zip->set_number('4978548')->is_valid_number, '小山 株式会社');
ok($zip->set_number('4978601')->is_valid_number, '蟹江町役場');
ok($zip->set_number('4978602')->is_valid_number, 'あま市役所');
ok($zip->set_number('4988501')->is_valid_number, '弥富市役所');
ok($zip->set_number('4988502')->is_valid_number, '愛知県厚生農業協同組合連合会 海南病院');
ok($zip->set_number('4988503')->is_valid_number, '木曽岬町役場');
ok($zip->set_number('4988505')->is_valid_number, '株式会社 川スミ');
ok($zip->set_number('5008501')->is_valid_number, '岐阜県警察本部');
ok($zip->set_number('5008502')->is_valid_number, '社団法人 岐阜県建設業協会');
ok($zip->set_number('5008503')->is_valid_number, '岐阜県信用保証協会');
ok($zip->set_number('5008504')->is_valid_number, '岐阜県音楽療法研究所');
ok($zip->set_number('5008505')->is_valid_number, '財団法人 岐阜県産業経済振興センター');
ok($zip->set_number('5008507')->is_valid_number, '岐阜県県民ふれあい会館');
ok($zip->set_number('5008508')->is_valid_number, '岐阜県市町村職員共済組合');
ok($zip->set_number('5008510')->is_valid_number, '社団法人 岐阜県医師会');
ok($zip->set_number('5008513')->is_valid_number, '岐阜市民病院');
ok($zip->set_number('5008515')->is_valid_number, 'シンガポール 株式会社');
ok($zip->set_number('5008518')->is_valid_number, '株式会社 市川工務店');
ok($zip->set_number('5008521')->is_valid_number, 'ハートフルスクエアG');
ok($zip->set_number('5008522')->is_valid_number, 'イギン 株式会社');
ok($zip->set_number('5008523')->is_valid_number, '朝日大学歯学部附属村上記念病院');
ok($zip->set_number('5008524')->is_valid_number, '住友生命保険 相互会社 岐阜支社');
ok($zip->set_number('5008525')->is_valid_number, '株式会社 高島屋 岐阜店');
ok($zip->set_number('5008530')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ東海 岐阜支店');
ok($zip->set_number('5008533')->is_valid_number, '東邦ガス 株式会社 岐阜営業所');
ok($zip->set_number('5008535')->is_valid_number, 'ラブリークィーン 株式会社');
ok($zip->set_number('5008540')->is_valid_number, '住友海上火災保険 株式会社 岐阜支店');
ok($zip->set_number('5008541')->is_valid_number, '丸佐 株式会社');
ok($zip->set_number('5008544')->is_valid_number, '吉岡 株式会社');
ok($zip->set_number('5008545')->is_valid_number, '商工組合中央金庫 岐阜支店');
ok($zip->set_number('5008550')->is_valid_number, '株式会社 篠田商会');
ok($zip->set_number('5008552')->is_valid_number, 'SMBC日興証券 株式会社 岐阜支店');
ok($zip->set_number('5008554')->is_valid_number, '日本放送協会 岐阜放送局');
ok($zip->set_number('5008555')->is_valid_number, '大日本土木 株式会社');
ok($zip->set_number('5008556')->is_valid_number, '株式会社 十六ディーシーカード');
ok($zip->set_number('5008557')->is_valid_number, '濃飛倉庫運輸 株式会社');
ok($zip->set_number('5008558')->is_valid_number, 'アピ 株式会社');
ok($zip->set_number('5008560')->is_valid_number, '日建産業 株式会社');
ok($zip->set_number('5008561')->is_valid_number, '株式会社 電算システム');
ok($zip->set_number('5008562')->is_valid_number, '岐阜信用金庫');
ok($zip->set_number('5008565')->is_valid_number, '株式会社 岐阜銀行');
ok($zip->set_number('5008566')->is_valid_number, '大和証券 株式会社 岐阜支店');
ok($zip->set_number('5008567')->is_valid_number, '岐阜南税務署');
ok($zip->set_number('5008570')->is_valid_number, '岐阜県庁');
ok($zip->set_number('5008571')->is_valid_number, '岐阜県庁');
ok($zip->set_number('5008577')->is_valid_number, '株式会社 岐阜新聞社');
ok($zip->set_number('5008588')->is_valid_number, '株式会社 岐阜放送');
ok($zip->set_number('5008601')->is_valid_number, '日本赤十字社 岐阜県支部');
ok($zip->set_number('5008602')->is_valid_number, '株式会社 岐阜魚介');
ok($zip->set_number('5008603')->is_valid_number, '岐果 岐阜青果 株式会社');
ok($zip->set_number('5008605')->is_valid_number, '日本ガード 株式会社');
ok($zip->set_number('5008607')->is_valid_number, '岐阜中央青果 株式会社');
ok($zip->set_number('5008610')->is_valid_number, '岐阜丸魚 株式会社');
ok($zip->set_number('5008615')->is_valid_number, '株式会社 田幸');
ok($zip->set_number('5008616')->is_valid_number, '小林薬品工業 株式会社');
ok($zip->set_number('5008618')->is_valid_number, '株式会社 岐阜セラツク製造所');
ok($zip->set_number('5008620')->is_valid_number, '岐阜日野自動車 株式会社 岐阜支店');
ok($zip->set_number('5008621')->is_valid_number, '五光山彦 株式会社 岐阜支店');
ok($zip->set_number('5008622')->is_valid_number, 'サンラリー 株式会社');
ok($zip->set_number('5008625')->is_valid_number, '富士ゼロックス岐阜 株式会社');
ok($zip->set_number('5008630')->is_valid_number, '株式会社 ヒマラヤ');
ok($zip->set_number('5008635')->is_valid_number, '濃尾電機 株式会社');
ok($zip->set_number('5008636')->is_valid_number, '大和ハウス工業 株式会社 岐阜支社');
ok($zip->set_number('5008637')->is_valid_number, 'トヨタカローラ岐阜 株式会社');
ok($zip->set_number('5008638')->is_valid_number, '株式会社 安部日鋼工業');
ok($zip->set_number('5008639')->is_valid_number, '資生堂化粧品販売 株式会社 岐阜支社');
ok($zip->set_number('5008640')->is_valid_number, '株式会社 スギトー');
ok($zip->set_number('5008645')->is_valid_number, '内藤建設 株式会社');
ok($zip->set_number('5008646')->is_valid_number, '株式会社 マキムラ');
ok($zip->set_number('5008648')->is_valid_number, '株式会社 小林三之助商店');
ok($zip->set_number('5008650')->is_valid_number, '株式会社 ヤマニパッケージ');
ok($zip->set_number('5008655')->is_valid_number, '二幸 株式会社');
ok($zip->set_number('5008657')->is_valid_number, '株式会社 キタガワ');
ok($zip->set_number('5008660')->is_valid_number, '株式会社 若原工機');
ok($zip->set_number('5008666')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('5008667')->is_valid_number, '全国健康保険協会 岐阜支部');
ok($zip->set_number('5008668')->is_valid_number, '丸杉建設 株式会社');
ok($zip->set_number('5008670')->is_valid_number, '日動火災海上保険 株式会社 岐阜支店');
ok($zip->set_number('5008671')->is_valid_number, '東京海上日動火災保険 株式会社 岐阜支店');
ok($zip->set_number('5008672')->is_valid_number, '荒井 株式会社');
ok($zip->set_number('5008676')->is_valid_number, '日産プリンス 岐阜販売 株式会社');
ok($zip->set_number('5008677')->is_valid_number, 'ヒロタ 株式会社');
ok($zip->set_number('5008678')->is_valid_number, '石田 株式会社');
ok($zip->set_number('5008680')->is_valid_number, '日本通運 株式会社 岐阜支店');
ok($zip->set_number('5008681')->is_valid_number, '日通商事 株式会社 岐阜支店');
ok($zip->set_number('5008682')->is_valid_number, '松久 株式会社');
ok($zip->set_number('5008685')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('5008686')->is_valid_number, '株式会社 マンチェス');
ok($zip->set_number('5008687')->is_valid_number, '井上精機 株式会社');
ok($zip->set_number('5008689')->is_valid_number, '梅本 株式会社');
ok($zip->set_number('5008701')->is_valid_number, '岐阜市役所');
ok($zip->set_number('5008702')->is_valid_number, '中部電力パワーグリッド 株式会社 岐阜営業所');
ok($zip->set_number('5008703')->is_valid_number, '昭和コンクリート工業 株式会社');
ok($zip->set_number('5008707')->is_valid_number, '中部電力パワーグリッド 株式会社 岐阜支社');
ok($zip->set_number('5008707')->is_valid_number, '中部電力ミライズ 株式会社 岐阜営業本部');
ok($zip->set_number('5008708')->is_valid_number, '岐阜振興局');
ok($zip->set_number('5008710')->is_valid_number, '岐阜地方裁判所');
ok($zip->set_number('5008711')->is_valid_number, '岐阜北税務署');
ok($zip->set_number('5008715')->is_valid_number, '西日本電信電話 株式会社');
ok($zip->set_number('5008716')->is_valid_number, '財務省 東海財務局 岐阜財務事務所');
ok($zip->set_number('5008717')->is_valid_number, '地方独立行政法人 岐阜県総合医療センター');
ok($zip->set_number('5008718')->is_valid_number, '国立療養所岐阜病院');
ok($zip->set_number('5008721')->is_valid_number, '岐阜プラスチック工業 株式会社');
ok($zip->set_number('5008722')->is_valid_number, '岐阜乗合自動車 株式会社');
ok($zip->set_number('5008723')->is_valid_number, '岐阜労働局');
ok($zip->set_number('5008725')->is_valid_number, '日本信販岐阜 株式会社');
ok($zip->set_number('5008727')->is_valid_number, '岐阜商工会議所');
ok($zip->set_number('5008728')->is_valid_number, '株式会社 パルコ 岐阜店');
ok($zip->set_number('5008729')->is_valid_number, '岐阜地方法務局');
ok($zip->set_number('5008730')->is_valid_number, '株式会社 新岐阜百貨店');
ok($zip->set_number('5008731')->is_valid_number, 'オンダ国際特許事務所');
ok($zip->set_number('5008732')->is_valid_number, '財団法人 岐阜県教職員互助会');
ok($zip->set_number('5008733')->is_valid_number, '丸丹 株式会社');
ok($zip->set_number('5008734')->is_valid_number, '岐阜観光索道 株式会社');
ok($zip->set_number('5008737')->is_valid_number, 'シーシーエヌ (株)');
ok($zip->set_number('5008739')->is_valid_number, '日本年金機構 岐阜事務センター');
ok($zip->set_number('5008740')->is_valid_number, '岐阜県 社会保険診療報酬支払基金');
ok($zip->set_number('5008741')->is_valid_number, '済美高等学校');
ok($zip->set_number('5008742')->is_valid_number, '株式会社 藤田商店');
ok($zip->set_number('5008743')->is_valid_number, '株式会社 岡本');
ok($zip->set_number('5008748')->is_valid_number, '株式会社 丸杉');
ok($zip->set_number('5008750')->is_valid_number, '岐阜県労働金庫');
ok($zip->set_number('5008751')->is_valid_number, '株式会社 日本タクシー');
ok($zip->set_number('5008752')->is_valid_number, '安田 株式会社');
ok($zip->set_number('5008753')->is_valid_number, '株式会社 ニツショー 岐阜支店');
ok($zip->set_number('5008754')->is_valid_number, '日本たばこ産業 株式会社 岐阜営業所');
ok($zip->set_number('5008755')->is_valid_number, '株式会社 ダイテックソリューション');
ok($zip->set_number('5008765')->is_valid_number, '学校法人 富田学園');
ok($zip->set_number('5010192')->is_valid_number, '岐阜市立女子短期大学');
ok($zip->set_number('5010292')->is_valid_number, '西濃信用金庫 本部');
ok($zip->set_number('5010293')->is_valid_number, '瑞穂市役所');
ok($zip->set_number('5010294')->is_valid_number, '三甲 株式会社');
ok($zip->set_number('5010295')->is_valid_number, 'ヤナゲン FAL店');
ok($zip->set_number('5010296')->is_valid_number, '朝日大学');
ok($zip->set_number('5010392')->is_valid_number, '瑞穂市役所 巣南庁舎');
ok($zip->set_number('5010492')->is_valid_number, '北方町役場');
ok($zip->set_number('5010493')->is_valid_number, '本巣市役所 糸貫分庁舎');
ok($zip->set_number('5010494')->is_valid_number, '本巣市役所 真正分庁舎');
ok($zip->set_number('5010495')->is_valid_number, '岐阜工業高等専門学校');
ok($zip->set_number('5010496')->is_valid_number, '魚供養観音菩薩円境寺事務局');
ok($zip->set_number('5010497')->is_valid_number, 'モレラ岐阜');
ok($zip->set_number('5010498')->is_valid_number, 'レシップ 株式会社');
ok($zip->set_number('5010592')->is_valid_number, '大野町役場');
ok($zip->set_number('5010596')->is_valid_number, '東海森紙業 (株) 岐阜事業所');
ok($zip->set_number('5010692')->is_valid_number, '揖斐川町役場');
ok($zip->set_number('5010693')->is_valid_number, 'いび川 農業協同組合 本店');
ok($zip->set_number('5010694')->is_valid_number, '西建産業 株式会社');
ok($zip->set_number('5010695')->is_valid_number, 'イビデン 株式会社 大垣北工場');
ok($zip->set_number('5010696')->is_valid_number, '揖斐厚生病院');
ok($zip->set_number('5010697')->is_valid_number, '西濃建設 株式会社');
ok($zip->set_number('5010698')->is_valid_number, 'いび川農業協同組合 揖斐中央支店');
ok($zip->set_number('5010797')->is_valid_number, '揖斐川町役場 久瀬振興事務所');
ok($zip->set_number('5010798')->is_valid_number, '株式会社 ヤマモト');
ok($zip->set_number('5011192')->is_valid_number, '医療法人社団 誠広会 平野総合病院');
ok($zip->set_number('5011193')->is_valid_number, '岐阜大学');
ok($zip->set_number('5011194')->is_valid_number, '岐阜大学 医学部');
ok($zip->set_number('5011195')->is_valid_number, '株式会社 KVK');
ok($zip->set_number('5011196')->is_valid_number, '岐阜薬科大学');
ok($zip->set_number('5011196')->is_valid_number, '岐阜薬科大学 本部');
ok($zip->set_number('5011198')->is_valid_number, '岐阜中央病院');
ok($zip->set_number('5011292')->is_valid_number, '本巣市役所');
ok($zip->set_number('5011392')->is_valid_number, '揖斐川町谷汲振興事務所');
ok($zip->set_number('5011393')->is_valid_number, '谷汲カントリークラブ');
ok($zip->set_number('5011592')->is_valid_number, '本巣市役所 根尾総合支庁');
ok($zip->set_number('5012192')->is_valid_number, '山県市役所');
ok($zip->set_number('5012292')->is_valid_number, '喜多村合金製作所 株式会社');
ok($zip->set_number('5012592')->is_valid_number, '岐阜女子大学');
ok($zip->set_number('5012695')->is_valid_number, '関市武芸川事務所');
ok($zip->set_number('5012697')->is_valid_number, '株式会社 ナガセインテグレックス');
ok($zip->set_number('5012698')->is_valid_number, '東海理研 株式会社');
ok($zip->set_number('5012892')->is_valid_number, '関市役所 洞戸事務所');
ok($zip->set_number('5013293')->is_valid_number, '関税務署');
ok($zip->set_number('5013295')->is_valid_number, 'トーヨーキッチンアンドリビング 株式会社');
ok($zip->set_number('5013296')->is_valid_number, 'サンサンシティマーゴ');
ok($zip->set_number('5013392')->is_valid_number, '岐阜県加茂郡富加町役場');
ok($zip->set_number('5013393')->is_valid_number, '(株) 喜多村合金製作所 富加工場');
ok($zip->set_number('5013395')->is_valid_number, '野田産業 株式会社');
ok($zip->set_number('5013792')->is_valid_number, '美濃市役所');
ok($zip->set_number('5013892')->is_valid_number, '岐阜医療科学大学 岐阜医療技術科学短期大学');
ok($zip->set_number('5013893')->is_valid_number, '関信用金庫');
ok($zip->set_number('5013894')->is_valid_number, '関市役所');
ok($zip->set_number('5013992')->is_valid_number, 'カイインダストリーズ 株式会社');
ok($zip->set_number('5013993')->is_valid_number, '中部学院大学 中部学院大学短期大学部');
ok($zip->set_number('5013994')->is_valid_number, '(株) マサヒロ');
ok($zip->set_number('5013998')->is_valid_number, '中部学院大学 通信教育部');
ok($zip->set_number('5014192')->is_valid_number, '郡上市 美並地域振興事務所');
ok($zip->set_number('5014193')->is_valid_number, '慈恵中央病院');
ok($zip->set_number('5014292')->is_valid_number, '郡上総合庁舎');
ok($zip->set_number('5014297')->is_valid_number, '郡上市役所');
ok($zip->set_number('5014298')->is_valid_number, '八幡信用金庫');
ok($zip->set_number('5014592')->is_valid_number, '郡上市役所 和良振興事務所');
ok($zip->set_number('5014595')->is_valid_number, '郡上市国保和良病院');
ok($zip->set_number('5015192')->is_valid_number, '郡上市白鳥地域振興事務所');
ok($zip->set_number('5015393')->is_valid_number, '郡上市高鷲地域振興事務所');
ok($zip->set_number('5015492')->is_valid_number, '高山市 荘川支所');
ok($zip->set_number('5015692')->is_valid_number, '白川村役場');
ok($zip->set_number('5016180')->is_valid_number, '岐阜市 柳津地域振興事務所');
ok($zip->set_number('5016181')->is_valid_number, '笠松町役場');
ok($zip->set_number('5016192')->is_valid_number, '岐阜県自動車税事務所');
ok($zip->set_number('5016193')->is_valid_number, 'ジーエフシー 株式会社');
ok($zip->set_number('5016194')->is_valid_number, '岐阜聖徳学園大学');
ok($zip->set_number('5016195')->is_valid_number, 'エーザイ 株式会社 川島工園');
ok($zip->set_number('5016196')->is_valid_number, '株式会社 電算システム');
ok($zip->set_number('5016197')->is_valid_number, '岐南町役場');
ok($zip->set_number('5016198')->is_valid_number, '各務原市 川島振興事務所');
ok($zip->set_number('5016292')->is_valid_number, '羽島市役所');
ok($zip->set_number('5016293')->is_valid_number, '丸栄コンクリート工業 株式会社');
ok($zip->set_number('5016295')->is_valid_number, '岐阜県立 看護大学');
ok($zip->set_number('5028501')->is_valid_number, 'カワボウ 株式会社');
ok($zip->set_number('5028503')->is_valid_number, '岐阜県障がい者総合就労支援センター、ぎふ木遊館');
ok($zip->set_number('5028511')->is_valid_number, '岐阜赤十字病院');
ok($zip->set_number('5028521')->is_valid_number, 'カワボウ 株式会社');
ok($zip->set_number('5028558')->is_valid_number, '独立行政法人国立病院機構長良医療センター');
ok($zip->set_number('5028567')->is_valid_number, '株式会社 岐阜グランドホテル');
ok($zip->set_number('5028585')->is_valid_number, '岐阜薬科大学 三田洞キャンパス');
ok($zip->set_number('5028792')->is_valid_number, '岐阜サービスセンター');
ok($zip->set_number('5030192')->is_valid_number, '大垣市 墨俣地域事務所');
ok($zip->set_number('5030195')->is_valid_number, '三洋電機 株式会社');
ok($zip->set_number('5030198')->is_valid_number, '安八町役場');
ok($zip->set_number('5030292')->is_valid_number, '輪之内町役場');
ok($zip->set_number('5030295')->is_valid_number, '未来工業 株式会社');
ok($zip->set_number('5030392')->is_valid_number, '海津市役所 平田支所');
ok($zip->set_number('5030495')->is_valid_number, '海津市役所 城山支所');
ok($zip->set_number('5030695')->is_valid_number, '海津市役所');
ok($zip->set_number('5031392')->is_valid_number, '養老町役場');
ok($zip->set_number('5031393')->is_valid_number, '玉泉堂酒造 株式会社');
ok($zip->set_number('5031394')->is_valid_number, '西美濃厚生病院');
ok($zip->set_number('5031395')->is_valid_number, '藤井ハウス産業 株式会社');
ok($zip->set_number('5031396')->is_valid_number, '佐竹鉄工 株式会社');
ok($zip->set_number('5031592')->is_valid_number, '関ケ原町役場');
ok($zip->set_number('5031593')->is_valid_number, '株式会社 関ケ原製作所');
ok($zip->set_number('5031595')->is_valid_number, '関ケ原石材 株式会社');
ok($zip->set_number('5031696')->is_valid_number, '株式会社 丸順');
ok($zip->set_number('5032192')->is_valid_number, 'ナブテスコ 株式会社 岐阜工場');
ok($zip->set_number('5032193')->is_valid_number, '垂井町役場');
ok($zip->set_number('5032392')->is_valid_number, '神戸町役場');
ok($zip->set_number('5032393')->is_valid_number, 'コダマ樹脂工業 株式会社');
ok($zip->set_number('5032394')->is_valid_number, '三菱マテリアル 株式会社 岐阜製作所');
ok($zip->set_number('5032395')->is_valid_number, '東レ 株式会社 岐阜工場');
ok($zip->set_number('5032396')->is_valid_number, '丸山工業 株式会社');
ok($zip->set_number('5032397')->is_valid_number, '太平洋工業 株式会社 北大垣工場');
ok($zip->set_number('5032492')->is_valid_number, '池田町役場');
ok($zip->set_number('5032493')->is_valid_number, '平和教会');
ok($zip->set_number('5032494')->is_valid_number, 'タニサケ (株)');
ok($zip->set_number('5032495')->is_valid_number, '岐阜県立 池田高等学校');
ok($zip->set_number('5038501')->is_valid_number, '西濃運輸 株式会社');
ok($zip->set_number('5038502')->is_valid_number, '大垣市民病院');
ok($zip->set_number('5038503')->is_valid_number, 'イビデン 株式会社');
ok($zip->set_number('5038504')->is_valid_number, '日本合成');
ok($zip->set_number('5038505')->is_valid_number, '神鋼造機');
ok($zip->set_number('5038506')->is_valid_number, '日本耐酸壜工業 株式会社');
ok($zip->set_number('5038507')->is_valid_number, '大垣扶桑紡績 株式会社');
ok($zip->set_number('5038508')->is_valid_number, '株式会社 デリカスイト');
ok($zip->set_number('5038509')->is_valid_number, '株式会社 セイノー商事');
ok($zip->set_number('5038511')->is_valid_number, '日本合成化学工業(株)大垣事業所大垣フイルム工場');
ok($zip->set_number('5038512')->is_valid_number, 'セイノー情報サービス');
ok($zip->set_number('5038513')->is_valid_number, '大垣機工');
ok($zip->set_number('5038514')->is_valid_number, '株式会社 川口屋スーパーチェン');
ok($zip->set_number('5038515')->is_valid_number, '大丸松下食品 株式会社');
ok($zip->set_number('5038516')->is_valid_number, '株式会社 宇佐美組');
ok($zip->set_number('5038517')->is_valid_number, '大光');
ok($zip->set_number('5038518')->is_valid_number, 'サンメッセ 株式会社');
ok($zip->set_number('5038519')->is_valid_number, '太平洋精工');
ok($zip->set_number('5038520')->is_valid_number, '大垣西高等学校');
ok($zip->set_number('5038521')->is_valid_number, '大垣工業高等学校');
ok($zip->set_number('5038522')->is_valid_number, '大垣南高等学校');
ok($zip->set_number('5038523')->is_valid_number, '(株) 平和堂東海 鶴見店');
ok($zip->set_number('5038550')->is_valid_number, '岐阜経済大学');
ok($zip->set_number('5038552')->is_valid_number, '揖斐川工業 株式会社');
ok($zip->set_number('5038553')->is_valid_number, 'JA全農ミートフーズ 株式会社 中部営業本部 吉田ハム支店');
ok($zip->set_number('5038554')->is_valid_number, '大垣女子短期大学');
ok($zip->set_number('5038556')->is_valid_number, '大垣税務署');
ok($zip->set_number('5038557')->is_valid_number, '日電精密工業 株式会社');
ok($zip->set_number('5038558')->is_valid_number, 'ヤナゲン');
ok($zip->set_number('5038559')->is_valid_number, 'イビデン 株式会社 河間工場');
ok($zip->set_number('5038560')->is_valid_number, 'イビデングリーンテック 株式会社');
ok($zip->set_number('5038561')->is_valid_number, 'イビケン 株式会社');
ok($zip->set_number('5038562')->is_valid_number, '株式会社 大垣村田製作所');
ok($zip->set_number('5038564')->is_valid_number, 'オーミケンシ 株式会社 大垣工場');
ok($zip->set_number('5038565')->is_valid_number, '大垣商工会議所');
ok($zip->set_number('5038566')->is_valid_number, 'NTT 大垣営業所');
ok($zip->set_number('5038567')->is_valid_number, 'スイトピアセンター');
ok($zip->set_number('5038568')->is_valid_number, '大垣ステーションビル アピオ');
ok($zip->set_number('5038569')->is_valid_number, '公益財団法人 ソフトピアジャパン');
ok($zip->set_number('5038570')->is_valid_number, 'ユニー 株式会社 アピタ大垣店');
ok($zip->set_number('5038571')->is_valid_number, 'ユニー 株式会社 アクアウォーク大垣');
ok($zip->set_number('5038601')->is_valid_number, '大垣市役所');
ok($zip->set_number('5038603')->is_valid_number, '太平洋工業 株式会社');
ok($zip->set_number('5038604')->is_valid_number, 'イビデン 株式会社');
ok($zip->set_number('5048501')->is_valid_number, '岐阜県立 岐阜各務野高等学 校岐女商校舎');
ok($zip->set_number('5048504')->is_valid_number, '東海女子短期大学');
ok($zip->set_number('5048511')->is_valid_number, '東海女子大学');
ok($zip->set_number('5048545')->is_valid_number, '各務原西高校');
ok($zip->set_number('5048551')->is_valid_number, '榎本ビーエー 株式会社');
ok($zip->set_number('5048555')->is_valid_number, '各務原市役所');
ok($zip->set_number('5048585')->is_valid_number, '各務原高校');
ok($zip->set_number('5048601')->is_valid_number, '公立学校共済組合 東海中央病院');
ok($zip->set_number('5048642')->is_valid_number, '天龍ホールディングス 株式会社');
ok($zip->set_number('5048701')->is_valid_number, '航空自衛隊');
ok($zip->set_number('5048702')->is_valid_number, '岐阜プラスチック工業 (株) 生産本部');
ok($zip->set_number('5048710')->is_valid_number, '川崎重工業 株式会社');
ok($zip->set_number('5050392')->is_valid_number, '八百津町役場');
ok($zip->set_number('5058501')->is_valid_number, '坂祝町役場');
ok($zip->set_number('5058503')->is_valid_number, '社会医療法人厚生会 中部脳リハビリテーション病院');
ok($zip->set_number('5058505')->is_valid_number, 'パジェロ製造 株式会社');
ok($zip->set_number('5058508')->is_valid_number, '可茂総合庁舎');
ok($zip->set_number('5058510')->is_valid_number, '社会医療法人厚生会 中部国際医療センター');
ok($zip->set_number('5058603')->is_valid_number, '美濃加茂ディストリビューションセンター');
ok($zip->set_number('5058606')->is_valid_number, '美濃加茂市役所');
ok($zip->set_number('5060192')->is_valid_number, '高山市役所 清見支所');
ok($zip->set_number('5060194')->is_valid_number, 'オーク・ヴィレッジ (株)');
ok($zip->set_number('5061195')->is_valid_number, '飛騨市 神岡振興事務所');
ok($zip->set_number('5061196')->is_valid_number, '神岡鉱業 株式会社');
ok($zip->set_number('5061392')->is_valid_number, '高山市 上宝支所');
ok($zip->set_number('5061492')->is_valid_number, '奥飛騨ガーデンホテル本陣');
ok($zip->set_number('5061493')->is_valid_number, '穂高荘山のホテル');
ok($zip->set_number('5061495')->is_valid_number, '(有) 岡田旅館');
ok($zip->set_number('5061496')->is_valid_number, '株式会社 飛騨湯の花本舗');
ok($zip->set_number('5061498')->is_valid_number, 'ホテル平湯館');
ok($zip->set_number('5062192')->is_valid_number, '高山市丹生川支所');
ok($zip->set_number('5068502')->is_valid_number, '久美愛 厚生病院');
ok($zip->set_number('5068506')->is_valid_number, '飛騨運輸 株式会社');
ok($zip->set_number('5068550')->is_valid_number, '高山赤十字病院');
ok($zip->set_number('5068555')->is_valid_number, '高山市役所');
ok($zip->set_number('5068577')->is_valid_number, '高山短期大学');
ok($zip->set_number('5068585')->is_valid_number, '柏木工 株式会社');
ok($zip->set_number('5068601')->is_valid_number, '高山税務署');
ok($zip->set_number('5068603')->is_valid_number, '飛騨農業協同組合');
ok($zip->set_number('5068666')->is_valid_number, '高山信用金庫');
ok($zip->set_number('5068678')->is_valid_number, '高山商工会議所');
ok($zip->set_number('5068686')->is_valid_number, '飛騨産業 株式会社');
ok($zip->set_number('5068687')->is_valid_number, '飛騨産業 株式会社 本社工場');
ok($zip->set_number('5068688')->is_valid_number, '飛騨県事務所');
ok($zip->set_number('5068690')->is_valid_number, '株式会社 高山市民時報社 ザ・チャンス');
ok($zip->set_number('5078511')->is_valid_number, '社会医療法人厚生会 多治見市民病院');
ok($zip->set_number('5078522')->is_valid_number, '岐阜県立多治見病院');
ok($zip->set_number('5078523')->is_valid_number, '太陽社電気 株式会社');
ok($zip->set_number('5078527')->is_valid_number, '中部電力 株式会社 多治見電力所');
ok($zip->set_number('5078533')->is_valid_number, '株式会社 三菱東京UFJ銀行 多治見支店');
ok($zip->set_number('5078561')->is_valid_number, '株式会社 アンシア');
ok($zip->set_number('5078568')->is_valid_number, 'セレック 株式会社');
ok($zip->set_number('5078585')->is_valid_number, 'アマゾン 多治見FC 入庫係');
ok($zip->set_number('5078601')->is_valid_number, '株式会社 バロー');
ok($zip->set_number('5078602')->is_valid_number, '美濃包材 株式会社');
ok($zip->set_number('5078603')->is_valid_number, '産業文化センター 指定管理者 株式会社');
ok($zip->set_number('5078605')->is_valid_number, '岐阜県立多治見工業高等学校');
ok($zip->set_number('5078607')->is_valid_number, '株式会社 T Y K');
ok($zip->set_number('5078608')->is_valid_number, '多治見商工会議所');
ok($zip->set_number('5078701')->is_valid_number, '前畑陶器 株式会社');
ok($zip->set_number('5078702')->is_valid_number, '東濃信用金庫');
ok($zip->set_number('5078703')->is_valid_number, '多治見市役所');
ok($zip->set_number('5078705')->is_valid_number, '協同組合 日本陶芸チェーン');
ok($zip->set_number('5078706')->is_valid_number, '多治見税務署');
ok($zip->set_number('5078708')->is_valid_number, '東濃西部総合庁舎');
ok($zip->set_number('5078787')->is_valid_number, '多治見市役所 駅北庁舎');
ok($zip->set_number('5080292')->is_valid_number, '中津川市 福岡総合事務所');
ok($zip->set_number('5080494')->is_valid_number, '中津川市 加子母総合事務所');
ok($zip->set_number('5088500')->is_valid_number, '北恵那交通 (株)');
ok($zip->set_number('5088501')->is_valid_number, '中津川市役所');
ok($zip->set_number('5088502')->is_valid_number, '総合病院中津川市民病院');
ok($zip->set_number('5088511')->is_valid_number, '株式会社 吉川工務店');
ok($zip->set_number('5088555')->is_valid_number, '株式会社 トキワ');
ok($zip->set_number('5088585')->is_valid_number, '中央板紙 株式会社');
ok($zip->set_number('5088611')->is_valid_number, '中津川税務署');
ok($zip->set_number('5088666')->is_valid_number, '三菱電機 株式会社 中津川製作所');
ok($zip->set_number('5088686')->is_valid_number, '王子エフテックス 株式会社 中津工場');
ok($zip->set_number('5090192')->is_valid_number, '岐阜車体工業 株式会社');
ok($zip->set_number('5090197')->is_valid_number, '生活協同組合コープぎふ');
ok($zip->set_number('5090198')->is_valid_number, '(株) 八幡ねじ H・I事業部');
ok($zip->set_number('5090289')->is_valid_number, '株式会社 ベルメゾンロジスコ 可児ディストリビューションセンター');
ok($zip->set_number('5090292')->is_valid_number, '可児市役所');
ok($zip->set_number('5090293')->is_valid_number, '岐阜医療科学大学 可児キャンパス');
ok($zip->set_number('5090294')->is_valid_number, 'FMラインウェーブ 株式会社');
ok($zip->set_number('5090295')->is_valid_number, '大王製紙 株式会社 可児工場');
ok($zip->set_number('5090296')->is_valid_number, '株式会社 日特スパークテック東濃');
ok($zip->set_number('5090297')->is_valid_number, 'カヤバ工業 株式会社 岐阜南工場');
ok($zip->set_number('5090298')->is_valid_number, 'カヤバ工業 株式会社 岐阜北工場');
ok($zip->set_number('5090393')->is_valid_number, '川辺町役場');
ok($zip->set_number('5090492')->is_valid_number, '七宗町役場');
ok($zip->set_number('5091192')->is_valid_number, '白川町役場');
ok($zip->set_number('5091193')->is_valid_number, '白川観光開発 株式会社');
ok($zip->set_number('5091392')->is_valid_number, '東白川村役場');
ok($zip->set_number('5091393')->is_valid_number, '東白川村国民健康保険病院');
ok($zip->set_number('5091394')->is_valid_number, '株式会社 岐阜部品');
ok($zip->set_number('5091395')->is_valid_number, '株式会社 ふるさと企画');
ok($zip->set_number('5091396')->is_valid_number, '株式会社 白川物産');
ok($zip->set_number('5091492')->is_valid_number, '(株) ますぶち園');
ok($zip->set_number('5091692')->is_valid_number, '株式会社 マツオカ');
ok($zip->set_number('5091695')->is_valid_number, '下呂市役所 金山振興事務所');
ok($zip->set_number('5092292')->is_valid_number, '地方独立行政法人 岐阜県立 下呂温泉病院');
ok($zip->set_number('5092293')->is_valid_number, '株式会社 ハウテック');
ok($zip->set_number('5092295')->is_valid_number, '下呂市役所');
ok($zip->set_number('5092592')->is_valid_number, '岐阜県 下呂総合庁舎');
ok($zip->set_number('5092593')->is_valid_number, '岐阜県立 益田清風高等学校');
ok($zip->set_number('5092595')->is_valid_number, '下呂市役所 萩原庁舎');
ok($zip->set_number('5092598')->is_valid_number, '金子工業 株式会社');
ok($zip->set_number('5093195')->is_valid_number, '下呂市役所 小坂振興事務所');
ok($zip->set_number('5093292')->is_valid_number, '高山市 久々野支所');
ok($zip->set_number('5094192')->is_valid_number, '高山市 国府支所');
ok($zip->set_number('5094292')->is_valid_number, '飛騨市役所');
ok($zip->set_number('5094392')->is_valid_number, '飛騨市 河合振興事務所');
ok($zip->set_number('5095192')->is_valid_number, '土岐市役所');
ok($zip->set_number('5095193')->is_valid_number, '土岐市立総合病院');
ok($zip->set_number('5095195')->is_valid_number, '協同組合 王将チェーン');
ok($zip->set_number('5095196')->is_valid_number, '土岐プレミアム・アウトレット');
ok($zip->set_number('5095198')->is_valid_number, '株式会社 丸辰');
ok($zip->set_number('5095292')->is_valid_number, '核融合科学研究所');
ok($zip->set_number('5095494')->is_valid_number, '米井データバンク');
ok($zip->set_number('5096192')->is_valid_number, '中京学院大学 瑞浪キャンパス');
ok($zip->set_number('5096193')->is_valid_number, '廣池学園');
ok($zip->set_number('5096194')->is_valid_number, '財団法人 モラロジー研究所');
ok($zip->set_number('5096195')->is_valid_number, '瑞浪市役所');
ok($zip->set_number('5096196')->is_valid_number, '瑞浪高等学校');
ok($zip->set_number('5097292')->is_valid_number, '恵那市役所');
ok($zip->set_number('5097492')->is_valid_number, '恵那市岩村振興事務所');
ok($zip->set_number('5097493')->is_valid_number, '岩村高等学校');
ok($zip->set_number('5097592')->is_valid_number, '恵那市上矢作振興事務所');
ok($zip->set_number('5097692')->is_valid_number, '恵那市役所山岡振興事務所');
ok($zip->set_number('5097693')->is_valid_number, '国土交通省 中部地方整備局 小里川ダム管理所');
ok($zip->set_number('5097792')->is_valid_number, '恵那市明智振興事務所');
ok($zip->set_number('5097793')->is_valid_number, '岐阜県立 恵那南高等学校');
ok($zip->set_number('5097795')->is_valid_number, '明智セラミックス 株式会社');
ok($zip->set_number('5097797')->is_valid_number, '株式会社 明智ゴルフ倶楽部');
ok($zip->set_number('5097892')->is_valid_number, '恵那市串原振興事務所');
ok($zip->set_number('5098392')->is_valid_number, '蛭川総合事務所');
ok($zip->set_number('5099192')->is_valid_number, '恵那峡パークカントリークラブ');
ok($zip->set_number('5099193')->is_valid_number, '岐阜県立中津川工業高等学校');
ok($zip->set_number('5099195')->is_valid_number, '中京学院大学');
ok($zip->set_number('5099292')->is_valid_number, '中津川市 坂下総合事務所');
ok($zip->set_number('5099293')->is_valid_number, '国民健康保険 坂下病院');
ok($zip->set_number('5099295')->is_valid_number, '中津川市川上総合事務所');
ok($zip->set_number('5099296')->is_valid_number, '株式会社 高峰楽器製作所');
ok($zip->set_number('5099298')->is_valid_number, 'ヤマコー 株式会社');
ok($zip->set_number('5100192')->is_valid_number, '四日市市 楠総合支所');
ok($zip->set_number('5100292')->is_valid_number, '株式会社 ケーブルネット鈴鹿');
ok($zip->set_number('5100293')->is_valid_number, '鈴鹿医療科学大学');
ok($zip->set_number('5100294')->is_valid_number, '鈴鹿工業高等専門学校');
ok($zip->set_number('5100295')->is_valid_number, 'モビリティランド 鈴鹿サーキット');
ok($zip->set_number('5100298')->is_valid_number, '鈴鹿国際大学');
ok($zip->set_number('5100392')->is_valid_number, '津市 河芸総合支所');
ok($zip->set_number('5101292')->is_valid_number, '菰野町役場');
ok($zip->set_number('5108502')->is_valid_number, 'KHネオケム 株式会社 四日市工場');
ok($zip->set_number('5108503')->is_valid_number, '住友電装 株式会社');
ok($zip->set_number('5108504')->is_valid_number, 'ドッグイヤー');
ok($zip->set_number('5108505')->is_valid_number, 'コスモ石油サービス 株式会社 三重カンパニー');
ok($zip->set_number('5108510')->is_valid_number, '三重県立 四日市高等学校');
ok($zip->set_number('5108511')->is_valid_number, '三重県四日市庁舎');
ok($zip->set_number('5108512')->is_valid_number, 'ささがわ通り心・身クリニック');
ok($zip->set_number('5108515')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('5108520')->is_valid_number, '出入国手続センター三重');
ok($zip->set_number('5108522')->is_valid_number, '朝日町役場');
ok($zip->set_number('5108525')->is_valid_number, '株式会社 扇港電機');
ok($zip->set_number('5108526')->is_valid_number, '津地方裁判所 四日市支部');
ok($zip->set_number('5108528')->is_valid_number, '住友電装 株式会社');
ok($zip->set_number('5108530')->is_valid_number, '三菱化学 株式会社 四日市事業所');
ok($zip->set_number('5108540')->is_valid_number, '東ソー 株式会社 四日市事業所');
ok($zip->set_number('5108550')->is_valid_number, '三重三菱自動車販売 株式会社');
ok($zip->set_number('5108552')->is_valid_number, 'JSR 株式会社 四日市工場');
ok($zip->set_number('5108555')->is_valid_number, 'トヨタカローラ三重 株式会社');
ok($zip->set_number('5108557')->is_valid_number, '四日市税務署');
ok($zip->set_number('5108560')->is_valid_number, 'パナソニック 株式会社 四日市事業所');
ok($zip->set_number('5108561')->is_valid_number, '三重県立 総合医療センター');
ok($zip->set_number('5108562')->is_valid_number, '三重県立 四日市南高等学校');
ok($zip->set_number('5108567')->is_valid_number, '市立四日市病院');
ok($zip->set_number('5108575')->is_valid_number, '社会医療法人居仁会 総合心療センターひなが');
ok($zip->set_number('5108577')->is_valid_number, '株式会社 オリエントコーポレーション 四日市支店');
ok($zip->set_number('5108580')->is_valid_number, '太陽化学 株式会社');
ok($zip->set_number('5108585')->is_valid_number, '株式会社 中部近鉄百貨店 四日市店');
ok($zip->set_number('5108588')->is_valid_number, '川越町役場');
ok($zip->set_number('5108601')->is_valid_number, '四日市市役所');
ok($zip->set_number('5108604')->is_valid_number, '野村證券 株式会社 四日市支店');
ok($zip->set_number('5108605')->is_valid_number, '伊勢湾倉庫 株式会社');
ok($zip->set_number('5108615')->is_valid_number, '百五リース 株式会社 四日市支店');
ok($zip->set_number('5108616')->is_valid_number, '百五銀行 四日市支店');
ok($zip->set_number('5108621')->is_valid_number, '第一信販 株式会社');
ok($zip->set_number('5108631')->is_valid_number, '富士電機リテイルシステムズ 株式会社 三重工場');
ok($zip->set_number('5108642')->is_valid_number, '商工組合 中央金庫 四日市支店');
ok($zip->set_number('5108651')->is_valid_number, '日本トランスシティ 株式会社');
ok($zip->set_number('5108655')->is_valid_number, '株式会社 みずほ銀行 四日市支店');
ok($zip->set_number('5108666')->is_valid_number, '北伊勢上野信用金庫');
ok($zip->set_number('5108670')->is_valid_number, '株式会社 三十三銀行');
ok($zip->set_number('5110192')->is_valid_number, '富士通セミコンダクター 株式会社 三重工場');
ok($zip->set_number('5110198')->is_valid_number, '多度町総合支所');
ok($zip->set_number('5110292')->is_valid_number, 'いなべ市役所 大安庁舎');
ok($zip->set_number('5110293')->is_valid_number, 'いなべ市役所 員弁庁舎');
ok($zip->set_number('5110294')->is_valid_number, 'TOYO TIRE 株式会社 桑名工場');
ok($zip->set_number('5110295')->is_valid_number, '東員町役場');
ok($zip->set_number('5110296')->is_valid_number, '株式会社 デンソー 大安製作所');
ok($zip->set_number('5110298')->is_valid_number, 'イオンモール 東員');
ok($zip->set_number('5110492')->is_valid_number, 'いなべ市役所 北勢庁舎');
ok($zip->set_number('5110498')->is_valid_number, 'いなべ市役所');
ok($zip->set_number('5110592')->is_valid_number, 'いなべ市役所 藤原庁舎');
ok($zip->set_number('5110593')->is_valid_number, '太平洋セメント 株式会社 藤原工場');
ok($zip->set_number('5111192')->is_valid_number, '長島観光開発 株式会社');
ok($zip->set_number('5118502')->is_valid_number, '桑栄ビル管理組合法人');
ok($zip->set_number('5118510')->is_valid_number, '桑名税務署');
ok($zip->set_number('5118511')->is_valid_number, '日立金属 株式会社 桑名工場');
ok($zip->set_number('5118533')->is_valid_number, 'ヤマモリ 株式会社');
ok($zip->set_number('5118550')->is_valid_number, '森田フードシステム 株式会社');
ok($zip->set_number('5118555')->is_valid_number, '株式会社 柿安本店');
ok($zip->set_number('5118558')->is_valid_number, '扶桑工機 株式会社');
ok($zip->set_number('5118567')->is_valid_number, '桑名県税事務所');
ok($zip->set_number('5118577')->is_valid_number, '桑名商工会議所');
ok($zip->set_number('5118585')->is_valid_number, '株式会社 中部コーポレーション');
ok($zip->set_number('5118588')->is_valid_number, '株式会社 杉山コンテック');
ok($zip->set_number('5118601')->is_valid_number, '桑名市役所');
ok($zip->set_number('5118666')->is_valid_number, '桑名信用金庫');
ok($zip->set_number('5118678')->is_valid_number, 'NTN 株式会社 桑名製作所');
ok($zip->set_number('5118686')->is_valid_number, '株式会社 山本 本店');
ok($zip->set_number('5118711')->is_valid_number, 'ヤマモリ 株式会社 桑名・大山田事業所');
ok($zip->set_number('5118798')->is_valid_number, '東海郵政研修センター');
ok($zip->set_number('5128512')->is_valid_number, '四日市大学');
ok($zip->set_number('5128538')->is_valid_number, '暁学園');
ok($zip->set_number('5128550')->is_valid_number, '東芝メモリ 株式会社 四日市工場');
ok($zip->set_number('5138501')->is_valid_number, '独立行政法人 国立病院機構 鈴鹿病院');
ok($zip->set_number('5138505')->is_valid_number, '鈴鹿回生総合病院');
ok($zip->set_number('5138510')->is_valid_number, '津地方法務局 鈴鹿出張所');
ok($zip->set_number('5138520')->is_valid_number, '鈴鹿短期大学');
ok($zip->set_number('5138530')->is_valid_number, '株式会社 サンケイ');
ok($zip->set_number('5138601')->is_valid_number, '株式会社 ホンダ・エクスプレス');
ok($zip->set_number('5138630')->is_valid_number, '鈴鹿中央総合病院');
ok($zip->set_number('5138631')->is_valid_number, '住友電装 株式会社 鈴鹿製作所');
ok($zip->set_number('5138632')->is_valid_number, '味の素ゼネラルフーヅ 株式会社 鈴鹿工場');
ok($zip->set_number('5138633')->is_valid_number, '富士電機 株式会社 鈴鹿工場');
ok($zip->set_number('5138650')->is_valid_number, '鈴鹿農業 協同組合');
ok($zip->set_number('5138660')->is_valid_number, '旭化成工業 株式会社 鈴鹿工場');
ok($zip->set_number('5138661')->is_valid_number, 'カネボウウール 株式会社 鈴鹿工場');
ok($zip->set_number('5138666')->is_valid_number, '本田技研工業 株式会社 鈴鹿製作所');
ok($zip->set_number('5138670')->is_valid_number, '鈴鹿医療科学大学 白子キャンパス');
ok($zip->set_number('5138680')->is_valid_number, '株式会社 鈴鹿メディアパーク');
ok($zip->set_number('5138686')->is_valid_number, '株式会社 鈴鹿ハンター');
ok($zip->set_number('5138701')->is_valid_number, '鈴鹿市役所');
ok($zip->set_number('5140392')->is_valid_number, '津市 香良洲総合支所');
ok($zip->set_number('5140393')->is_valid_number, 'JFEエンジニアリング 株式会社 津製作所');
ok($zip->set_number('5140395')->is_valid_number, '中部運輸局 三重運輸支局');
ok($zip->set_number('5140396')->is_valid_number, 'KYB 株式会社 三重工場');
ok($zip->set_number('5140397')->is_valid_number, 'UDトラックス 株式会社');
ok($zip->set_number('5140398')->is_valid_number, 'ジャパンマリンユナイテッド 株式会社');
ok($zip->set_number('5141192')->is_valid_number, '津市久居総合支所');
ok($zip->set_number('5141193')->is_valid_number, '中日本高速道路 株式会社 津保全・サービスセンター');
ok($zip->set_number('5141195')->is_valid_number, '全国健康保険協会 三重支部');
ok($zip->set_number('5141292')->is_valid_number, '独立行政法人 国立病院機構 榊原病院');
ok($zip->set_number('5141293')->is_valid_number, '医療法人 しょう純会 榊原温泉病院');
ok($zip->set_number('5141294')->is_valid_number, '横河マニュファクチャリング 株式会社');
ok($zip->set_number('5141295')->is_valid_number, '藤田保健衛生大学 七栗サナトリウム');
ok($zip->set_number('5141296')->is_valid_number, '藤田保健衛生大学 藤田記念七栗研究所');
ok($zip->set_number('5141297')->is_valid_number, 'ユリカ 株式会社');
ok($zip->set_number('5142192')->is_valid_number, '津市 美里総合支所');
ok($zip->set_number('5142292')->is_valid_number, '津市庁 芸濃総合支所');
ok($zip->set_number('5142293')->is_valid_number, '(株)赤塚植物園、赤塚物産(株)、(株)エフエフシー・ジャパン');
ok($zip->set_number('5142294')->is_valid_number, 'ヤマギシズム社会豊里実顕地・ヤマギシズム生活豊里実顕地農事組合法人');
ok($zip->set_number('5142392')->is_valid_number, '独立行政法人 農業・食品産業技術総合研究機構 野菜茶業研究所');
ok($zip->set_number('5142393')->is_valid_number, '津市 安濃総合支所');
ok($zip->set_number('5142395')->is_valid_number, '株式会社 中川製作所');
ok($zip->set_number('5142396')->is_valid_number, '株式会社 中勢ゴム');
ok($zip->set_number('5142398')->is_valid_number, '三恵技研工業 株式会社 安濃工場');
ok($zip->set_number('5148501')->is_valid_number, '伊勢湾飼料畜産 株式会社');
ok($zip->set_number('5148502')->is_valid_number, '三重工事事務所');
ok($zip->set_number('5148503')->is_valid_number, '津地方法務局');
ok($zip->set_number('5148505')->is_valid_number, '三重エフエム放送 株式会社');
ok($zip->set_number('5148507')->is_valid_number, '国立大学法人 三重大学');
ok($zip->set_number('5148508')->is_valid_number, '医療法人 永井病院');
ok($zip->set_number('5148510')->is_valid_number, '三重刑務所');
ok($zip->set_number('5148511')->is_valid_number, 'クレハエラストマー 株式会社');
ok($zip->set_number('5148512')->is_valid_number, '津地方検察庁');
ok($zip->set_number('5148513')->is_valid_number, '株式会社 久居屋');
ok($zip->set_number('5148514')->is_valid_number, '三重県警察本部');
ok($zip->set_number('5148515')->is_valid_number, '一般社団法人 三重県トラック協会');
ok($zip->set_number('5148518')->is_valid_number, '交通部 運転免許センター');
ok($zip->set_number('5148520')->is_valid_number, '東海農政局 三重統計情報事務所');
ok($zip->set_number('5148521')->is_valid_number, '津公共職業安定所');
ok($zip->set_number('5148522')->is_valid_number, '津年金事務所');
ok($zip->set_number('5148524')->is_valid_number, '三重労働局');
ok($zip->set_number('5148526')->is_valid_number, '津地方家庭簡易裁判所');
ok($zip->set_number('5148528')->is_valid_number, '三重県 社会保険診療報酬支払基金');
ok($zip->set_number('5148530')->is_valid_number, '井村屋製菓 株式会社');
ok($zip->set_number('5148531')->is_valid_number, '日本放送協会 津放送局');
ok($zip->set_number('5148532')->is_valid_number, '日産サニー三重販売 (株)');
ok($zip->set_number('5148533')->is_valid_number, 'ナブテスコ 株式会社 津工場');
ok($zip->set_number('5148538')->is_valid_number, '三重県 医師会');
ok($zip->set_number('5148540')->is_valid_number, '三重県労働者住宅生活 協同組合');
ok($zip->set_number('5148543')->is_valid_number, '日本たばこ産業 (株) 津支店');
ok($zip->set_number('5148545')->is_valid_number, '津税務署');
ok($zip->set_number('5148546')->is_valid_number, '関西紙業 株式会社');
ok($zip->set_number('5148550')->is_valid_number, '株式会社 ミエデン');
ok($zip->set_number('5148552')->is_valid_number, '社会福祉法人 三重県社会福祉協議会');
ok($zip->set_number('5148553')->is_valid_number, '三重県 国民健康保険団体連合会');
ok($zip->set_number('5148555')->is_valid_number, '松下電工 株式会社 津工場');
ok($zip->set_number('5148557')->is_valid_number, '株式会社 ZTV');
ok($zip->set_number('5148558')->is_valid_number, '中部電力パワーグリッド 株式会社 三重支社');
ok($zip->set_number('5148558')->is_valid_number, '中部電力ミライズ 株式会社 三重営業本部');
ok($zip->set_number('5148560')->is_valid_number, '東海財務局 津財務事務所');
ok($zip->set_number('5148566')->is_valid_number, '住友生命保険 相互会社');
ok($zip->set_number('5148567')->is_valid_number, '三重県津地方県民局');
ok($zip->set_number('5148568')->is_valid_number, 'イオンリテール 株式会社 イオン津店');
ok($zip->set_number('5148570')->is_valid_number, '三重県庁');
ok($zip->set_number('5148571')->is_valid_number, '日本信販 株式会社');
ok($zip->set_number('5148577')->is_valid_number, '三重県退職教職員互助会');
ok($zip->set_number('5148578')->is_valid_number, '富士フイルムビジネスイノベーションジャパン 株式会社 三重支社');
ok($zip->set_number('5148585')->is_valid_number, '株式会社 トーエネック 三重支店');
ok($zip->set_number('5148586')->is_valid_number, '日本土建 (株)');
ok($zip->set_number('5148588')->is_valid_number, '全日本自治団体労働組合 三重県本部');
ok($zip->set_number('5148601')->is_valid_number, '大和証券 株式会社 津支店');
ok($zip->set_number('5148611')->is_valid_number, '津市役所');
ok($zip->set_number('5148633')->is_valid_number, '三重テレビ放送');
ok($zip->set_number('5148635')->is_valid_number, '三重交通 株式会社');
ok($zip->set_number('5148666')->is_valid_number, '株式会社 百五銀行');
ok($zip->set_number('5148667')->is_valid_number, '株式会社 百五銀行');
ok($zip->set_number('5148668')->is_valid_number, '百五証券 株式会社');
ok($zip->set_number('5148686')->is_valid_number, '商工中金 津支店');
ok($zip->set_number('5150592')->is_valid_number, '株式会社 牛虎');
ok($zip->set_number('5150595')->is_valid_number, '株式会社 伊勢魚類市場');
ok($zip->set_number('5150596')->is_valid_number, 'ヤマナカフーズ 株式会社');
ok($zip->set_number('5150598')->is_valid_number, '三重国分 株式会社');
ok($zip->set_number('5152592')->is_valid_number, '株式会社 おやつカンパニー');
ok($zip->set_number('5152692')->is_valid_number, '日生学園第二高等学校');
ok($zip->set_number('5152693')->is_valid_number, '津市役所 白山総合支所');
ok($zip->set_number('5158501')->is_valid_number, 'マックスバリュー中部 株式会社');
ok($zip->set_number('5158503')->is_valid_number, 'オムロンヘルスケア 株式会社 松阪事業所');
ok($zip->set_number('5158505')->is_valid_number, '(有) パンジィ');
ok($zip->set_number('5158509')->is_valid_number, '松阪公共職業安定所');
ok($zip->set_number('5158510')->is_valid_number, '津地方法務局 松阪支局');
ok($zip->set_number('5158511')->is_valid_number, '三重中京大学');
ok($zip->set_number('5158513')->is_valid_number, 'ヤマモリ 株式会社 松阪工場');
ok($zip->set_number('5158515')->is_valid_number, '松阪市役所');
ok($zip->set_number('5158522')->is_valid_number, '三重中京大学短期大学部');
ok($zip->set_number('5158525')->is_valid_number, '津地方裁判所 松阪支部');
ok($zip->set_number('5158530')->is_valid_number, '株式会社 第三銀行');
ok($zip->set_number('5158533')->is_valid_number, '三重高等学校');
ok($zip->set_number('5158550')->is_valid_number, '松阪税務署');
ok($zip->set_number('5158555')->is_valid_number, 'パナソニックエレクトロニックデバイス 株式会社');
ok($zip->set_number('5158557')->is_valid_number, '済生会 松阪総合病院');
ok($zip->set_number('5158558')->is_valid_number, '宇野重工 株式会社');
ok($zip->set_number('5158566')->is_valid_number, '松阪中央総合病院');
ok($zip->set_number('5158567')->is_valid_number, '株式会社 オークワ');
ok($zip->set_number('5158577')->is_valid_number, '三重県立松阪高等学校');
ok($zip->set_number('5158585')->is_valid_number, '株式会社 三交百貨店');
ok($zip->set_number('5158586')->is_valid_number, '桑名三重信用金庫');
ok($zip->set_number('5158588')->is_valid_number, '和田金');
ok($zip->set_number('5158688')->is_valid_number, '株式会社 中部ハーバー');
ok($zip->set_number('5160192')->is_valid_number, '株式会社 ネットアール');
ok($zip->set_number('5160193')->is_valid_number, '独立行政法人 水産総合研究センター 養殖研究所');
ok($zip->set_number('5160194')->is_valid_number, '南伊勢町役場 南勢庁舎');
ok($zip->set_number('5160198')->is_valid_number, '楓幸房');
ok($zip->set_number('5161192')->is_valid_number, '伊勢電子工業 株式会社');
ok($zip->set_number('5161195')->is_valid_number, 'ウェルサンピア伊勢(三重厚生年金休暇センター)');
ok($zip->set_number('5161196')->is_valid_number, '日本特殊陶業 株式会社 伊勢工場');
ok($zip->set_number('5161198')->is_valid_number, '株式会社 玉木鐵鋼所');
ok($zip->set_number('5161492')->is_valid_number, '南伊勢町役場 南島庁舎');
ok($zip->set_number('5162195')->is_valid_number, '度会町役場');
ok($zip->set_number('5168501')->is_valid_number, '伊勢市御薗総合支所');
ok($zip->set_number('5168502')->is_valid_number, '伊勢市立 御薗中学校');
ok($zip->set_number('5168503')->is_valid_number, '津地方法務局 伊勢支部');
ok($zip->set_number('5168505')->is_valid_number, '有限会社 弥次喜多');
ok($zip->set_number('5168511')->is_valid_number, '伊勢税務署');
ok($zip->set_number('5168512')->is_valid_number, '伊勢赤十字病院');
ok($zip->set_number('5168515')->is_valid_number, '伊勢高等学校');
ok($zip->set_number('5168516')->is_valid_number, 'ジャスコ 株式会社 新伊勢店');
ok($zip->set_number('5168518')->is_valid_number, '猿田彦神社社務所');
ok($zip->set_number('5168520')->is_valid_number, '伊勢市生涯学習センター (いせトピア)');
ok($zip->set_number('5168530')->is_valid_number, '横浜ゴム 株式会社 三重工場');
ok($zip->set_number('5168533')->is_valid_number, '津地方・家庭裁判所伊勢支部 伊勢簡易裁判所');
ok($zip->set_number('5168543')->is_valid_number, '伊勢公共職業安定所');
ok($zip->set_number('5168544')->is_valid_number, '株式会社 神電テクノリサーチ');
ok($zip->set_number('5168545')->is_valid_number, '神電ファクトリーサービス 株式会社');
ok($zip->set_number('5168546')->is_valid_number, '神電メタル 株式会社');
ok($zip->set_number('5168547')->is_valid_number, '株式会社 セルテクノ');
ok($zip->set_number('5168548')->is_valid_number, '株式会社 セルワークス');
ok($zip->set_number('5168549')->is_valid_number, '神電商事 株式会社 流通営業部');
ok($zip->set_number('5168550')->is_valid_number, 'シンフォニアテクノロジー 株式会社 伊勢製作所');
ok($zip->set_number('5168551')->is_valid_number, '株式会社 アイシーエス');
ok($zip->set_number('5168552')->is_valid_number, '神電商事 株式会社 保険営業部');
ok($zip->set_number('5168553')->is_valid_number, '神電エンジニアリング 株式会社');
ok($zip->set_number('5168554')->is_valid_number, '神電商事 株式会社 本部');
ok($zip->set_number('5168555')->is_valid_number, '皇學館大學');
ok($zip->set_number('5168558')->is_valid_number, '株式会社 伊勢福');
ok($zip->set_number('5168566')->is_valid_number, '伊勢県民センター');
ok($zip->set_number('5168567')->is_valid_number, 'ララパーク');
ok($zip->set_number('5168577')->is_valid_number, '皇學館高等学校');
ok($zip->set_number('5168580')->is_valid_number, '中部電力パワーグリッド 株式会社 伊勢営業所');
ok($zip->set_number('5168581')->is_valid_number, '御木本製薬 株式会社');
ok($zip->set_number('5168588')->is_valid_number, '皇學館中学校');
ok($zip->set_number('5168601')->is_valid_number, '伊勢市役所');
ok($zip->set_number('5168602')->is_valid_number, 'ミワネットワークス');
ok($zip->set_number('5168686')->is_valid_number, 'キクカワエンタープライズ 株式会社');
ok($zip->set_number('5170292')->is_valid_number, '株式会社 志摩スペイン村');
ok($zip->set_number('5170494')->is_valid_number, 'ホテル 志摩石亭');
ok($zip->set_number('5170592')->is_valid_number, '志摩市役所');
ok($zip->set_number('5170593')->is_valid_number, '株式会社 賢島宝生苑');
ok($zip->set_number('5178501')->is_valid_number, '国立鳥羽商船高等専門学校');
ok($zip->set_number('5178511')->is_valid_number, '御木本真珠島');
ok($zip->set_number('5178517')->is_valid_number, '鳥羽水族館');
ok($zip->set_number('5180192')->is_valid_number, '桜丘中学校・高等学校');
ok($zip->set_number('5180292')->is_valid_number, '伊賀市役所 青山支所');
ok($zip->set_number('5180293')->is_valid_number, 'JA伊賀南部青山支店');
ok($zip->set_number('5180294')->is_valid_number, '独立行政法人 水資源機構 川上ダム建設所');
ok($zip->set_number('5180295')->is_valid_number, 'メナード青山リゾート');
ok($zip->set_number('5180296')->is_valid_number, '伊賀南部クリーンセンター');
ok($zip->set_number('5180298')->is_valid_number, '独立行政法人 水資源機構川上ダム建設所');
ok($zip->set_number('5180492')->is_valid_number, '名張市役所');
ok($zip->set_number('5180493')->is_valid_number, '日立化成 株式会社 名張事業所');
ok($zip->set_number('5180494')->is_valid_number, 'ニッタ 株式会社 名張工場');
ok($zip->set_number('5180495')->is_valid_number, 'ボルグワーナー・モールステック・ジャパン 株式会社');
ok($zip->set_number('5180496')->is_valid_number, '株式会社 マキシンコー 名張工場');
ok($zip->set_number('5188501')->is_valid_number, '伊賀市役所');
ok($zip->set_number('5188518')->is_valid_number, 'パナソニックライティングシステムズ 株式会社');
ok($zip->set_number('5188533')->is_valid_number, '三重県伊賀庁舎');
ok($zip->set_number('5190193')->is_valid_number, '日東電工 株式会社 亀山事業所');
ok($zip->set_number('5190195')->is_valid_number, '亀山市役所');
ok($zip->set_number('5190196')->is_valid_number, 'カメヤマ 株式会社');
ok($zip->set_number('5190197')->is_valid_number, '株式会社 エイチワン 亀山製作所');
ok($zip->set_number('5190198')->is_valid_number, 'シャープ 株式会社 亀山工場');
ok($zip->set_number('5190292')->is_valid_number, '古河電気工業 株式会社 三重事務所');
ok($zip->set_number('5190393')->is_valid_number, '鈴鹿富士ゼロックス 株式会社');
ok($zip->set_number('5190492')->is_valid_number, '松下電工 株式会社 伊勢工場');
ok($zip->set_number('5190493')->is_valid_number, 'ミマス 株式会社');
ok($zip->set_number('5190495')->is_valid_number, '玉城町役場');
ok($zip->set_number('5190592')->is_valid_number, '伊勢市 小俣総合支所');
ok($zip->set_number('5190593')->is_valid_number, 'ユニチカ 株式会社 宮川工場');
ok($zip->set_number('5190594')->is_valid_number, '株式会社 マスヤ');
ok($zip->set_number('5190595')->is_valid_number, '美和ロック 株式会社 伊勢工場');
ok($zip->set_number('5190696')->is_valid_number, '伊勢市二見総合支所');
ok($zip->set_number('5191192')->is_valid_number, '亀山市関支所');
ok($zip->set_number('5192192')->is_valid_number, 'シャープ 株式会社');
ok($zip->set_number('5192592')->is_valid_number, '大台町役場 宮川総合支所');
ok($zip->set_number('5192593')->is_valid_number, '三重県立 昴学園高等学校');
ok($zip->set_number('5192792')->is_valid_number, '大紀町役場');
ok($zip->set_number('5193292')->is_valid_number, '紀北町役場');
ok($zip->set_number('5193492')->is_valid_number, '紀北町 海山総合支所');
ok($zip->set_number('5193692')->is_valid_number, '尾鷲社会保険事務所');
ok($zip->set_number('5193693')->is_valid_number, '尾鷲総合病院');
ok($zip->set_number('5193694')->is_valid_number, '尾鷲税務署');
ok($zip->set_number('5193695')->is_valid_number, '三重県 紀北県民局');
ok($zip->set_number('5193696')->is_valid_number, '尾鷲市役所');
ok($zip->set_number('5194392')->is_valid_number, '熊野市役所');
ok($zip->set_number('5194393')->is_valid_number, '三重県 熊野庁舎');
ok($zip->set_number('5194394')->is_valid_number, '三重県立木本高等学校');
ok($zip->set_number('5194395')->is_valid_number, '熊野工業高等専門学校');
ok($zip->set_number('5194396')->is_valid_number, '津地方裁判所 熊野支部');
ok($zip->set_number('5195292')->is_valid_number, '御浜町役場');
ok($zip->set_number('5195293')->is_valid_number, '公立紀南病院');
ok($zip->set_number('5200287')->is_valid_number, '滋賀地域センター');
ok($zip->set_number('5200292')->is_valid_number, '東洋紡 株式会社 総合研究所');
ok($zip->set_number('5200580')->is_valid_number, '大津赤十字志賀病院');
ok($zip->set_number('5200588')->is_valid_number, 'BSCウォータースポーツセンター');
ok($zip->set_number('5201188')->is_valid_number, '株式会社 TADコーポレーション');
ok($zip->set_number('5201192')->is_valid_number, '高島市役所 高島支所');
ok($zip->set_number('5201292')->is_valid_number, '高島市役所 安曇川支所');
ok($zip->set_number('5201492')->is_valid_number, '高島市役所 朽木支所');
ok($zip->set_number('5201495')->is_valid_number, '朽木ゴルフ倶楽部');
ok($zip->set_number('5201592')->is_valid_number, '高島市役所');
ok($zip->set_number('5201692')->is_valid_number, '高島市役所 今津支所');
ok($zip->set_number('5201892')->is_valid_number, '高島市役所 マキノ支所');
ok($zip->set_number('5202192')->is_valid_number, '滋賀医科大学');
ok($zip->set_number('5202194')->is_valid_number, '龍谷大学');
ok($zip->set_number('5202392')->is_valid_number, 'ソニーモバイルディスプレイ 株式会社');
ok($zip->set_number('5202393')->is_valid_number, '(株) 村田製作所 野洲事業所');
ok($zip->set_number('5202394')->is_valid_number, '(株) 長府製作所 滋賀工場');
ok($zip->set_number('5202395')->is_valid_number, '野洲市役所 本庁舎');
ok($zip->set_number('5202492')->is_valid_number, '野洲市 市民サービスセンター');
ok($zip->set_number('5202592')->is_valid_number, '竜王町役場');
ok($zip->set_number('5202594')->is_valid_number, '竜王ゴルフコース');
ok($zip->set_number('5202595')->is_valid_number, '積水樹脂 株式会社 滋賀竜王工場滋賀製造所');
ok($zip->set_number('5202596')->is_valid_number, '積水樹脂 株式会社 R&Dプラザ・滋賀竜王工場竜王製造所');
ok($zip->set_number('5203080')->is_valid_number, '三菱重工工作機械 株式会社');
ok($zip->set_number('5203081')->is_valid_number, '積水化学工業 株式会社 滋賀栗東工場');
ok($zip->set_number('5203082')->is_valid_number, '積水ハウス 株式会社 静岡工場関西物流センター');
ok($zip->set_number('5203083')->is_valid_number, '日清食品 株式会社 滋賀工場');
ok($zip->set_number('5203084')->is_valid_number, '日本ジョンクレーン');
ok($zip->set_number('5203085')->is_valid_number, '日本中央競馬会 栗東トレーニングセンター');
ok($zip->set_number('5203088')->is_valid_number, '栗東市役所');
ok($zip->set_number('5203180')->is_valid_number, '日本精工 株式会社 石部工場');
ok($zip->set_number('5203182')->is_valid_number, '株式会社 エム・エス・コミュニケーションズ 大阪物流部 物流センター');
ok($zip->set_number('5203185')->is_valid_number, 'シーアイ化成 株式会社 滋賀事業所');
ok($zip->set_number('5203188')->is_valid_number, '甲賀高分子 株式会社');
ok($zip->set_number('5203189')->is_valid_number, '株式会社 ゴーシュー');
ok($zip->set_number('5203194')->is_valid_number, '社会福祉法人 大木会');
ok($zip->set_number('5203195')->is_valid_number, '湖南市役所 西庁舎');
ok($zip->set_number('5203281')->is_valid_number, 'TOTO 株式会社 滋賀工場');
ok($zip->set_number('5203282')->is_valid_number, '王子製紙 株式会社 滋賀工場');
ok($zip->set_number('5203285')->is_valid_number, '電元社トーア 株式会社 近江工場');
ok($zip->set_number('5203288')->is_valid_number, '湖南市役所 東庁舎');
ok($zip->set_number('5203289')->is_valid_number, '日本ポリスター 株式会社');
ok($zip->set_number('5203393')->is_valid_number, '甲賀市役所 甲南庁舎');
ok($zip->set_number('5203492')->is_valid_number, '甲賀市役所 甲賀支所');
ok($zip->set_number('5203493')->is_valid_number, 'バイエル薬品 株式会社 滋賀工場');
ok($zip->set_number('5208501')->is_valid_number, '滋賀県警察本部');
ok($zip->set_number('5208510')->is_valid_number, '大津税務署');
ok($zip->set_number('5208511')->is_valid_number, '大津赤十字病院');
ok($zip->set_number('5208512')->is_valid_number, '大津地方検察庁');
ok($zip->set_number('5208513')->is_valid_number, '全国健康保険協会 滋賀支部');
ok($zip->set_number('5208515')->is_valid_number, '日本年金機構 滋賀事務センター');
ok($zip->set_number('5208516')->is_valid_number, '大津法務局');
ok($zip->set_number('5208520')->is_valid_number, '大津プリンスホテル');
ok($zip->set_number('5208530')->is_valid_number, '浜大津都市開発 (株)');
ok($zip->set_number('5208550')->is_valid_number, '滋賀県市町村職員共済組合');
ok($zip->set_number('5208555')->is_valid_number, '関西日本電気 株式会社');
ok($zip->set_number('5208558')->is_valid_number, '東レ 株式会社 滋賀事業場');
ok($zip->set_number('5208567')->is_valid_number, '株式会社 東レリサーチセンター');
ok($zip->set_number('5208570')->is_valid_number, '関西電力 (株) 滋賀支店');
ok($zip->set_number('5208575')->is_valid_number, '大津市役所');
ok($zip->set_number('5208577')->is_valid_number, '滋賀県庁');
ok($zip->set_number('5208580')->is_valid_number, '株式会社 西武百貨店 大津店');
ok($zip->set_number('5208585')->is_valid_number, 'びわ湖放送 株式会社');
ok($zip->set_number('5208586')->is_valid_number, '(株) みんなで作る新聞社');
ok($zip->set_number('5208588')->is_valid_number, 'NTT 大津支店');
ok($zip->set_number('5208639')->is_valid_number, '日本電気硝子 (株)');
ok($zip->set_number('5208666')->is_valid_number, '滋賀刑務所');
ok($zip->set_number('5210292')->is_valid_number, '米原市役所 山東庁舎');
ok($zip->set_number('5210392')->is_valid_number, '米原市役所 伊吹庁舎');
ok($zip->set_number('5211192')->is_valid_number, 'ジョイソン・セイフティ・システムズ・ジャパン 株式会社 彦根製造所');
ok($zip->set_number('5211292')->is_valid_number, '東近江市能登川支所');
ok($zip->set_number('5211295')->is_valid_number, '日本電気硝子 株式会社 能登川事業場');
ok($zip->set_number('5211392')->is_valid_number, '近江八幡市 安土町総合支所');
ok($zip->set_number('5211398')->is_valid_number, 'キタイ設計 株式会社');
ok($zip->set_number('5218501')->is_valid_number, '米原市役所 米原庁舎');
ok($zip->set_number('5218511')->is_valid_number, 'ヤンマーホールディングス 株式会社');
ok($zip->set_number('5218601')->is_valid_number, '米原市役所 近江庁舎');
ok($zip->set_number('5220292')->is_valid_number, '大日本スクリーン製造 株式会社 彦根地区事業所');
ok($zip->set_number('5220297')->is_valid_number, '日立化成 株式会社 彦根事業所');
ok($zip->set_number('5228501')->is_valid_number, '彦根市役所');
ok($zip->set_number('5228503')->is_valid_number, '近江鉄道 株式会社');
ok($zip->set_number('5228505')->is_valid_number, 'フジノ食品 株式会社');
ok($zip->set_number('5228511')->is_valid_number, '株式会社 平和堂');
ok($zip->set_number('5228520')->is_valid_number, 'パナソニック 株式会社 ビューティ・パーソナルケア事業部 彦根工場');
ok($zip->set_number('5228522')->is_valid_number, '滋賀大学');
ok($zip->set_number('5228523')->is_valid_number, 'アル・プラザ彦根');
ok($zip->set_number('5228533')->is_valid_number, '滋賀県立大学');
ok($zip->set_number('5228539')->is_valid_number, '彦根市立病院');
ok($zip->set_number('5228540')->is_valid_number, '日本年金機構 彦根年金事務所');
ok($zip->set_number('5228543')->is_valid_number, '株式会社 パリヤ');
ok($zip->set_number('5228585')->is_valid_number, 'KBS 滋賀');
ok($zip->set_number('5228588')->is_valid_number, 'フジテック 株式会社 Big Wing');
ok($zip->set_number('5228655')->is_valid_number, '滋賀中央信用金庫');
ok($zip->set_number('5228666')->is_valid_number, '株式会社 文教スタヂオ');
ok($zip->set_number('5238501')->is_valid_number, '近江八幡市役所');
ok($zip->set_number('5238502')->is_valid_number, '近江八幡税務署');
ok($zip->set_number('5238503')->is_valid_number, '滋賀八幡病院');
ok($zip->set_number('5238507')->is_valid_number, 'トラスコ中山 株式会社 プラネット滋賀 竜王支店');
ok($zip->set_number('5238510')->is_valid_number, '滋賀職業能力開発短期大学校');
ok($zip->set_number('5238515')->is_valid_number, '株式会社 近江兄弟社');
ok($zip->set_number('5238523')->is_valid_number, 'ヴォーリズ記念病院');
ok($zip->set_number('5238533')->is_valid_number, '株式会社 たねや(ラ・コリーナ)');
ok($zip->set_number('5238555')->is_valid_number, '株式会社 日吉');
ok($zip->set_number('5238558')->is_valid_number, '株式会社 たねや 日牟禮ヴィレッジ');
ok($zip->set_number('5238651')->is_valid_number, '滋賀中央信用金庫 本店');
ok($zip->set_number('5240292')->is_valid_number, '株式会社 鮎家');
ok($zip->set_number('5248501')->is_valid_number, 'グンゼ 株式会社 守山工場');
ok($zip->set_number('5248524')->is_valid_number, '滋賀県立 総合病院');
ok($zip->set_number('5248577')->is_valid_number, '立命館守山中学校・高等学校');
ok($zip->set_number('5248585')->is_valid_number, '滋賀県 守山市役所');
ok($zip->set_number('5258501')->is_valid_number, '草津電機 株式会社');
ok($zip->set_number('5258502')->is_valid_number, '松下電器産業 株式会社 カーエアコン部');
ok($zip->set_number('5258505')->is_valid_number, '滋賀県 赤十字血液センター');
ok($zip->set_number('5258511')->is_valid_number, 'キヤノンマシナリー 株式会社');
ok($zip->set_number('5258515')->is_valid_number, '株式会社 草津近鉄百貨店');
ok($zip->set_number('5258520')->is_valid_number, '松下電器産業 株式会社 エアコン事業部');
ok($zip->set_number('5258521')->is_valid_number, '不二電機工業 株式会社');
ok($zip->set_number('5258522')->is_valid_number, '東西電工 株式会社');
ok($zip->set_number('5258525')->is_valid_number, '滋賀県草津県事務所');
ok($zip->set_number('5258526')->is_valid_number, 'ダイキン工業 株式会社 滋賀製作所');
ok($zip->set_number('5258555')->is_valid_number, '松下冷機 株式会社 冷蔵庫事業部');
ok($zip->set_number('5258558')->is_valid_number, '川重冷熱工業 株式会社');
ok($zip->set_number('5258566')->is_valid_number, '学校法人 聖パウロ学園 光泉中学・高等学校');
ok($zip->set_number('5258567')->is_valid_number, '新世代 株式会社');
ok($zip->set_number('5258577')->is_valid_number, '立命館大学 びわこくさつキャンパス');
ok($zip->set_number('5258585')->is_valid_number, '社会医療法人 誠光会 淡海医療センター');
ok($zip->set_number('5258585')->is_valid_number, '社会医療法人 誠光会 淡海ふれあい病院');
ok($zip->set_number('5258588')->is_valid_number, '草津市役所');
ok($zip->set_number('5260292')->is_valid_number, '長浜市役所 浅井支所');
ok($zip->set_number('5260293')->is_valid_number, '株式会社 セネファ');
ok($zip->set_number('5268501')->is_valid_number, '長浜市役所');
ok($zip->set_number('5268545')->is_valid_number, 'タカタ (株) 長浜製造所');
ok($zip->set_number('5268558')->is_valid_number, 'ヤンマー (株) 小形エンジン事業部');
ok($zip->set_number('5268580')->is_valid_number, '市立長浜病院');
ok($zip->set_number('5268585')->is_valid_number, '長浜赤十字病院');
ok($zip->set_number('5268660')->is_valid_number, '三菱ケミカル 株式会社 滋賀事業所');
ok($zip->set_number('5268686')->is_valid_number, '長浜信用金庫');
ok($zip->set_number('5270195')->is_valid_number, '東近江市役所 湖東支所');
ok($zip->set_number('5278501')->is_valid_number, 'パナソニック 株式会社 ランドリー・クリーナー事業部 八日市工場');
ok($zip->set_number('5278505')->is_valid_number, '独立行政法人 国立病院機構 滋賀病院');
ok($zip->set_number('5278508')->is_valid_number, '株式会社 ティラド 滋賀製作所');
ok($zip->set_number('5278511')->is_valid_number, '東近江地域振興局');
ok($zip->set_number('5278512')->is_valid_number, '滋賀県東近江地域振興局 地域健康福祉部');
ok($zip->set_number('5278527')->is_valid_number, '東近江市役所');
ok($zip->set_number('5278542')->is_valid_number, '三光合成 株式会社 滋賀工場');
ok($zip->set_number('5278550')->is_valid_number, '満田工業 株式会社');
ok($zip->set_number('5278554')->is_valid_number, '東近江労働基準監督署');
ok($zip->set_number('5278555')->is_valid_number, '京セラ 株式会社 滋賀八日市工場');
ok($zip->set_number('5278558')->is_valid_number, '株式会社 村田製作所 八日市事業所');
ok($zip->set_number('5278566')->is_valid_number, '凸版印刷 株式会社 エレクトロニクス事業本部');
ok($zip->set_number('5278567')->is_valid_number, '医療法人 敬愛会');
ok($zip->set_number('5278577')->is_valid_number, 'シキボウ 株式会社 八日市工場');
ok($zip->set_number('5278580')->is_valid_number, 'タキロン 株式会社 八日市工場');
ok($zip->set_number('5278585')->is_valid_number, '関西電力 株式会社 八日市営業所');
ok($zip->set_number('5278588')->is_valid_number, '株式会社 ノエビア 滋賀事業所');
ok($zip->set_number('5278687')->is_valid_number, '湖東信用金庫');
ok($zip->set_number('5288501')->is_valid_number, '株式会社 ホタルクス 滋賀工場');
ok($zip->set_number('5288502')->is_valid_number, '甲賀市役所 水口庁舎');
ok($zip->set_number('5288510')->is_valid_number, 'HOYA 株式会社 水口ラボラトリー');
ok($zip->set_number('5288511')->is_valid_number, '滋賀県甲賀環境・総合事務所');
ok($zip->set_number('5288555')->is_valid_number, '水口税務署');
ok($zip->set_number('5288585')->is_valid_number, '積水化学工業 株式会社 滋賀水口工場');
ok($zip->set_number('5288666')->is_valid_number, '甲賀市役所 水口支所');
ok($zip->set_number('5290292')->is_valid_number, '日本電気硝子 株式会社 滋賀高月事業場');
ok($zip->set_number('5290492')->is_valid_number, '長浜市役所 木之本支所');
ok($zip->set_number('5290493')->is_valid_number, '湖北総合病院');
ok($zip->set_number('5290498')->is_valid_number, 'ハヤミ工産 株式会社');
ok($zip->set_number('5290792')->is_valid_number, '長浜市役所 西浅井支所');
ok($zip->set_number('5291195')->is_valid_number, '昭和電工 (株) 彦根事業所');
ok($zip->set_number('5291380')->is_valid_number, '愛荘町役場 愛知川庁舎');
ok($zip->set_number('5291381')->is_valid_number, '青木産商 株式会社');
ok($zip->set_number('5291382')->is_valid_number, 'キユーピー醸造 株式会社 滋賀工場');
ok($zip->set_number('5291383')->is_valid_number, '栗本コンクリート工業 株式会社');
ok($zip->set_number('5291386')->is_valid_number, '株式会社 ユニックス');
ok($zip->set_number('5291388')->is_valid_number, 'ジョイソン・セイフティ・システムズ・ジャパン 株式会社 愛知川製造所');
ok($zip->set_number('5291393')->is_valid_number, '大丸工業 株式会社 滋賀支店');
ok($zip->set_number('5291492')->is_valid_number, '東近江市役所 五個荘支所');
ok($zip->set_number('5291493')->is_valid_number, '藤野商事 株式会社');
ok($zip->set_number('5291495')->is_valid_number, 'フジノ食品 株式会社');
ok($zip->set_number('5291592')->is_valid_number, '東近江市 蒲生支所');
ok($zip->set_number('5291595')->is_valid_number, '京セラ 株式会社 滋賀蒲生工場');
ok($zip->set_number('5291597')->is_valid_number, '株式会社 名神八日市カントリー倶楽部');
ok($zip->set_number('5291598')->is_valid_number, '朝日野カントリー倶楽部');
ok($zip->set_number('5291692')->is_valid_number, '株式会社 ダイフク 滋賀事業所');
ok($zip->set_number('5291698')->is_valid_number, '日野町役場');
ok($zip->set_number('5291892')->is_valid_number, '甲賀市役所 信楽支所');
ok($zip->set_number('5306070')->is_valid_number, '三菱マテリアル 株式会社 大阪支社');
ok($zip->set_number('5308201')->is_valid_number, '大阪市役所');
ok($zip->set_number('5308202')->is_valid_number, '株式会社 大丸松坂屋百貨店 大丸大阪・梅田店');
ok($zip->set_number('5308203')->is_valid_number, 'サントリー 株式会社');
ok($zip->set_number('5308204')->is_valid_number, 'サントリー 株式会社 アネックスビル');
ok($zip->set_number('5308205')->is_valid_number, '旭化成 株式会社');
ok($zip->set_number('5308206')->is_valid_number, '三菱電機 株式会社 関西支社');
ok($zip->set_number('5308207')->is_valid_number, 'キョードー大阪');
ok($zip->set_number('5308209')->is_valid_number, '税務照会事務処理センター');
ok($zip->set_number('5308210')->is_valid_number, '大建工業 株式会社');
ok($zip->set_number('5308211')->is_valid_number, '朝日新聞 大阪本社');
ok($zip->set_number('5308212')->is_valid_number, '株式会社 ニチメン 保険センター');
ok($zip->set_number('5308213')->is_valid_number, '三菱UFJリサーチ&コンサルティング 株式会社');
ok($zip->set_number('5308214')->is_valid_number, '大阪府中小企業信用保証協会');
ok($zip->set_number('5308215')->is_valid_number, '株式会社 エイチ・アイ・エス');
ok($zip->set_number('5308216')->is_valid_number, '大阪市 梅田市税事務所');
ok($zip->set_number('5308217')->is_valid_number, 'JR西日本SC開発 株式会社(LUCUA)');
ok($zip->set_number('5308218')->is_valid_number, '大阪市都市整備局 住宅支援受付窓口');
ok($zip->set_number('5308221')->is_valid_number, '株式会社 フェリシモ');
ok($zip->set_number('5308222')->is_valid_number, '東レ 株式会社 大阪本社');
ok($zip->set_number('5308224')->is_valid_number, '株式会社 阪急阪神百貨店 阪神梅田本店');
ok($zip->set_number('5308226')->is_valid_number, '株式会社 関電システムズ');
ok($zip->set_number('5308227')->is_valid_number, 'プロミス 株式会社');
ok($zip->set_number('5308228')->is_valid_number, '株式会社 電通 関西支社');
ok($zip->set_number('5308230')->is_valid_number, '東洋紡績 株式会社');
ok($zip->set_number('5308232')->is_valid_number, 'サンケイチケットセンター');
ok($zip->set_number('5308234')->is_valid_number, '山発産業 株式会社');
ok($zip->set_number('5308239')->is_valid_number, 'オリックス自動車 株式会社');
ok($zip->set_number('5308240')->is_valid_number, '株式会社 リクルートホールディングス');
ok($zip->set_number('5308241')->is_valid_number, '大和ハウス工業 株式会社');
ok($zip->set_number('5308245')->is_valid_number, 'オリックス 株式会社');
ok($zip->set_number('5308250')->is_valid_number, '株式会社 富士通ビジネスシステム');
ok($zip->set_number('5308251')->is_valid_number, '毎日新聞社');
ok($zip->set_number('5308252')->is_valid_number, '住信・パナソニックフィナンシャルサービス 株式会社');
ok($zip->set_number('5308255')->is_valid_number, '株式会社 アサヒ・ファミリー・ニュース社');
ok($zip->set_number('5308256')->is_valid_number, '鐘紡 株式会社');
ok($zip->set_number('5308260')->is_valid_number, 'キヤノンマーケティングジャパン 株式会社 大阪支店');
ok($zip->set_number('5308262')->is_valid_number, '株式会社 博報堂 関西支社');
ok($zip->set_number('5308263')->is_valid_number, '株式会社 大広');
ok($zip->set_number('5308266')->is_valid_number, '森六ケミカルズ 株式会社 大阪支店');
ok($zip->set_number('5308270')->is_valid_number, '関西電力 株式会社');
ok($zip->set_number('5308278')->is_valid_number, '株式会社 スポーツニッポン新聞社 大阪本社');
ok($zip->set_number('5308280')->is_valid_number, '協和発酵キリン 株式会社');
ok($zip->set_number('5308281')->is_valid_number, 'Be Happy!789');
ok($zip->set_number('5308282')->is_valid_number, '株式会社 日本交通公社 関西営業本部');
ok($zip->set_number('5308283')->is_valid_number, '毎日新聞 大阪開発 株式会社');
ok($zip->set_number('5308287')->is_valid_number, '(株) クレハ 大阪営業所');
ok($zip->set_number('5308288')->is_valid_number, '株式会社 カネカ');
ok($zip->set_number('5308301')->is_valid_number, '武富士 梅田支店');
ok($zip->set_number('5308304')->is_valid_number, '株式会社 MBSメディアホールディングス');
ok($zip->set_number('5308304')->is_valid_number, '株式会社 MBSラジオ');
ok($zip->set_number('5308304')->is_valid_number, '株式会社 毎日放送');
ok($zip->set_number('5308308')->is_valid_number, '株式会社 ダイワエクシード');
ok($zip->set_number('5308310')->is_valid_number, '大阪新阪急ホテル');
ok($zip->set_number('5308318')->is_valid_number, 'JFE商事 株式会社');
ok($zip->set_number('5308321')->is_valid_number, 'ヤンマーアグリジャパン 株式会社');
ok($zip->set_number('5308322')->is_valid_number, 'グンゼ 株式会社');
ok($zip->set_number('5308323')->is_valid_number, 'ダイキン工業 株式会社 本社');
ok($zip->set_number('5308324')->is_valid_number, 'マルニ 株式会社');
ok($zip->set_number('5308327')->is_valid_number, '大阪府 社会保険診療報酬支払基金');
ok($zip->set_number('5308333')->is_valid_number, '関西セルラー電話 株式会社');
ok($zip->set_number('5308334')->is_valid_number, '株式会社 日刊スポーツ新聞西日本');
ok($zip->set_number('5308338')->is_valid_number, '株式会社 ウィルコム');
ok($zip->set_number('5308341')->is_valid_number, '西日本旅客鉄道 株式会社');
ok($zip->set_number('5308346')->is_valid_number, '大阪市役所内郵送事務処理センター');
ok($zip->set_number('5308350')->is_valid_number, '株式会社 阪急百貨店');
ok($zip->set_number('5308353')->is_valid_number, 'JFEスチール 株式会社 大阪支社');
ok($zip->set_number('5308355')->is_valid_number, '株式会社 阪急交通社 トラピックス');
ok($zip->set_number('5308383')->is_valid_number, '株式会社 阪急交通社');
ok($zip->set_number('5308388')->is_valid_number, '株式会社 大阪梅田秘書センター');
ok($zip->set_number('5308389')->is_valid_number, '阪急電鉄 株式会社');
ok($zip->set_number('5308401')->is_valid_number, '大阪市北区役所');
ok($zip->set_number('5308402')->is_valid_number, 'ヤマヒサ');
ok($zip->set_number('5308408')->is_valid_number, '関西テレビ放送 株式会社');
ok($zip->set_number('5308410')->is_valid_number, '株式会社 千趣会');
ok($zip->set_number('5308411')->is_valid_number, '高圧ガス工業 株式会社');
ok($zip->set_number('5308415')->is_valid_number, '東宝 株式会社');
ok($zip->set_number('5308441')->is_valid_number, 'コモライフ 株式会社');
ok($zip->set_number('5308448')->is_valid_number, '伊藤忠商事 株式会社');
ok($zip->set_number('5308475')->is_valid_number, 'ぴあ 株式会社 関西支社');
ok($zip->set_number('5308480')->is_valid_number, '大阪北野病院');
ok($zip->set_number('5308501')->is_valid_number, '弁護士法人 みお綜合法律事務所');
ok($zip->set_number('5308504')->is_valid_number, '株式会社 エスペランス');
ok($zip->set_number('5308506')->is_valid_number, '関西電力 株式会社');
ok($zip->set_number('5308511')->is_valid_number, '象印マホービン 株式会社');
ok($zip->set_number('5308512')->is_valid_number, '株式会社 読売情報開発大阪');
ok($zip->set_number('5308513')->is_valid_number, '三ツワ理化学工業 株式会社');
ok($zip->set_number('5308517')->is_valid_number, '株式会社 鴻池組 大阪本店');
ok($zip->set_number('5308521')->is_valid_number, '大阪高等裁判所');
ok($zip->set_number('5308522')->is_valid_number, '大阪地方裁判所');
ok($zip->set_number('5308523')->is_valid_number, '大阪簡易裁判所');
ok($zip->set_number('5308531')->is_valid_number, '関西フエルトファブリック 株式会社');
ok($zip->set_number('5308535')->is_valid_number, 'デュプロ (株)');
ok($zip->set_number('5308544')->is_valid_number, '国分 株式会社 近畿支社');
ok($zip->set_number('5308550')->is_valid_number, 'エスペック 株式会社');
ok($zip->set_number('5308551')->is_valid_number, '株式会社 読売新聞 大阪本社');
ok($zip->set_number('5308552')->is_valid_number, '参天製薬 株式会社');
ok($zip->set_number('5308553')->is_valid_number, '交洋貿易 株式会社');
ok($zip->set_number('5308555')->is_valid_number, 'ニッセイ同和損害保険 株式会社');
ok($zip->set_number('5308556')->is_valid_number, '全国柔整師協会');
ok($zip->set_number('5308558')->is_valid_number, 'JR西日本SC開発 株式会社(LUCUA 1100(ルクア イーレ))');
ok($zip->set_number('5308560')->is_valid_number, 'FM COCOLO');
ok($zip->set_number('5308565')->is_valid_number, '積水化学工業 株式会社');
ok($zip->set_number('5308566')->is_valid_number, '中西金属工業 株式会社');
ok($zip->set_number('5308567')->is_valid_number, '梅田公共職業安定所');
ok($zip->set_number('5308568')->is_valid_number, '学校法人 常翔学園(大阪工業大学 梅田キャンパス)');
ok($zip->set_number('5308573')->is_valid_number, 'FWD富士生命保険 株式会社');
ok($zip->set_number('5308574')->is_valid_number, '共栄火災海上保険 株式会社');
ok($zip->set_number('5308575')->is_valid_number, '株式会社 日刊現代大阪');
ok($zip->set_number('5308577')->is_valid_number, '株式会社 廣済堂');
ok($zip->set_number('5308578')->is_valid_number, '(株) 近畿しんきんカード');
ok($zip->set_number('5308580')->is_valid_number, '株式会社 FM802');
ok($zip->set_number('5308582')->is_valid_number, '大阪市住宅供給公社');
ok($zip->set_number('5308583')->is_valid_number, 'ゲッツ編集部');
ok($zip->set_number('5308585')->is_valid_number, '北 税務署');
ok($zip->set_number('5308586')->is_valid_number, '株式会社 読売情報開発大阪');
ok($zip->set_number('5308588')->is_valid_number, '株式会社 松村組');
ok($zip->set_number('5308601')->is_valid_number, '日本生命保険 相互会社');
ok($zip->set_number('5308602')->is_valid_number, '三菱商事 株式会社');
ok($zip->set_number('5308605')->is_valid_number, '帝人グループ');
ok($zip->set_number('5308606')->is_valid_number, '日鉄物産 株式会社 大阪支社');
ok($zip->set_number('5308610')->is_valid_number, '読売テレビ放送 株式会社');
ok($zip->set_number('5308611')->is_valid_number, '株式会社 クラレ');
ok($zip->set_number('5308618')->is_valid_number, 'ニチメン 株式会社');
ok($zip->set_number('5308660')->is_valid_number, '日本銀行 大阪支店');
ok($zip->set_number('5308680')->is_valid_number, '株式会社 住友銀行 本店');
ok($zip->set_number('5308688')->is_valid_number, '株式会社 ぎょうせい 関西支社');
ok($zip->set_number('5308689')->is_valid_number, '双日シェアードサービス 株式会社');
ok($zip->set_number('5308791')->is_valid_number, '共通事務センター');
ok($zip->set_number('5308793')->is_valid_number, '日本郵便 株式会社 近畿支社 郵便事業本部 (三種)');
ok($zip->set_number('5308796')->is_valid_number, '大阪監査室');
ok($zip->set_number('5308797')->is_valid_number, '株式会社 ゆうちょ銀行 大阪支店');
ok($zip->set_number('5308797')->is_valid_number, '株式会社 かんぽ生命 大阪支店');
ok($zip->set_number('5308797')->is_valid_number, '日本郵便 株式会社 近畿支社');
ok($zip->set_number('5308798')->is_valid_number, '大阪北逓信病院');
ok($zip->set_number('5316053')->is_valid_number, '積水ハウスリフォーム 株式会社');
ok($zip->set_number('5318501')->is_valid_number, '株式会社 ザ・シンフォニーホール');
ok($zip->set_number('5318502')->is_valid_number, '関電プラント 株式会社');
ok($zip->set_number('5318503')->is_valid_number, 'カバーマーク 株式会社');
ok($zip->set_number('5318510')->is_valid_number, 'ニプロ 株式会社');
ok($zip->set_number('5318511')->is_valid_number, 'ニッポンペイント 株式会社');
ok($zip->set_number('5318519')->is_valid_number, '東急建設 株式会社 関西支店');
ok($zip->set_number('5318526')->is_valid_number, '東罐マテリアル・テクノロジー (株)');
ok($zip->set_number('5318555')->is_valid_number, '三菱電機クレジット 株式会社');
ok($zip->set_number('5318558')->is_valid_number, '報知新聞 大阪本社');
ok($zip->set_number('5318567')->is_valid_number, '株式会社 日本電商');
ok($zip->set_number('5318577')->is_valid_number, '株式会社 インテック');
ok($zip->set_number('5318588')->is_valid_number, '関西電力 株式会社 大阪北支店');
ok($zip->set_number('5318787')->is_valid_number, '大阪地域センター');
ok($zip->set_number('5328501')->is_valid_number, '大阪市淀川区役所');
ok($zip->set_number('5328505')->is_valid_number, '田辺三菱製薬 株式会社 加島事業所');
ok($zip->set_number('5328507')->is_valid_number, '淀川労働基準監督署');
ok($zip->set_number('5328508')->is_valid_number, '株式会社 パールエース 関西支店');
ok($zip->set_number('5328511')->is_valid_number, '株式会社 公文教育研究会');
ok($zip->set_number('5328512')->is_valid_number, '株式会社 ダイヘン');
ok($zip->set_number('5328514')->is_valid_number, 'アステラス製薬 (株) 加島事業場');
ok($zip->set_number('5328515')->is_valid_number, 'オール日本スーパーマーケット 協会');
ok($zip->set_number('5328520')->is_valid_number, '全国金物連合商業協同組合');
ok($zip->set_number('5328524')->is_valid_number, '日清食品 株式会社 本社');
ok($zip->set_number('5328525')->is_valid_number, 'コプロ 株式会社');
ok($zip->set_number('5328535')->is_valid_number, '株式会社 チップワンストップ 関西営業所');
ok($zip->set_number('5328555')->is_valid_number, 'オー・ジー 株式会社 本社/大阪支店');
ok($zip->set_number('5328558')->is_valid_number, '東淀川税務署');
ok($zip->set_number('5328560')->is_valid_number, '株式会社 ニイタカ');
ok($zip->set_number('5328588')->is_valid_number, '株式会社 メディカ出版');
ok($zip->set_number('5328680')->is_valid_number, '株式会社 シェル石油大阪発売所');
ok($zip->set_number('5338501')->is_valid_number, '東淀川区役所');
ok($zip->set_number('5338502')->is_valid_number, '杉本商事 株式会社 本社');
ok($zip->set_number('5338533')->is_valid_number, '大阪経済大学');
ok($zip->set_number('5338555')->is_valid_number, '株式会社 キーエンス');
ok($zip->set_number('5338558')->is_valid_number, 'ライフコーポレーション');
ok($zip->set_number('5338585')->is_valid_number, '株式会社 ダイヤモンドプレス');
ok($zip->set_number('5338651')->is_valid_number, '参天製薬 株式会社');
ok($zip->set_number('5348501')->is_valid_number, '都島区役所');
ok($zip->set_number('5348502')->is_valid_number, '大阪市 京橋市税事務所');
ok($zip->set_number('5348511')->is_valid_number, 'よみうりテレビサービス');
ok($zip->set_number('5348585')->is_valid_number, '大阪拘置所');
ok($zip->set_number('5358501')->is_valid_number, '大阪市旭区役所');
ok($zip->set_number('5358555')->is_valid_number, '旭 税務署');
ok($zip->set_number('5358585')->is_valid_number, '学校法人 常翔学園(大阪工業大学・常翔学園高等学校・常翔学園中学校)');
ok($zip->set_number('5368501')->is_valid_number, '大阪府 なにわ東府税事務所');
ok($zip->set_number('5368503')->is_valid_number, '株式会社 大丸・城東総合センター');
ok($zip->set_number('5368505')->is_valid_number, '大阪府赤十字血液センター');
ok($zip->set_number('5368508')->is_valid_number, '大正製薬 株式会社 大阪支店');
ok($zip->set_number('5368510')->is_valid_number, '大阪市城東区役所');
ok($zip->set_number('5368522')->is_valid_number, '独立行政法人 都市再生機構 西日本支社 大阪住宅管理センター');
ok($zip->set_number('5368523')->is_valid_number, '扶桑薬品工業 株式会社');
ok($zip->set_number('5368527')->is_valid_number, '城東税務署');
ok($zip->set_number('5368536')->is_valid_number, 'タカラスタンダード 株式会社');
ok($zip->set_number('5368550')->is_valid_number, '独立行政法人 都市再生機構 西日本支社');
ok($zip->set_number('5368553')->is_valid_number, '大阪産業技術研究所 森之宮センター');
ok($zip->set_number('5368558')->is_valid_number, 'DoCoMoサービス 関西');
ok($zip->set_number('5368567')->is_valid_number, '大阪府貨物運送健康保険組合');
ok($zip->set_number('5368585')->is_valid_number, '学校法人 大阪信愛女学院');
ok($zip->set_number('5368588')->is_valid_number, '公益財団法人 大阪府保健医療財団 大阪がん循環器病予防センター');
ok($zip->set_number('5368686')->is_valid_number, '牛乳石鹸共進社 株式会社');
ok($zip->set_number('5378501')->is_valid_number, '東成区役所');
ok($zip->set_number('5378686')->is_valid_number, 'コクヨ (株)');
ok($zip->set_number('5378911')->is_valid_number, 'ザ・パック 株式会社');
ok($zip->set_number('5388501')->is_valid_number, '株式会社 タカラ');
ok($zip->set_number('5388510')->is_valid_number, '大阪市鶴見区役所');
ok($zip->set_number('5388555')->is_valid_number, '株式会社 コジット');
ok($zip->set_number('5388585')->is_valid_number, '株式会社 鶴見製作所');
ok($zip->set_number('5388655')->is_valid_number, 'カナヱ塗料 株式会社');
ok($zip->set_number('5388666')->is_valid_number, '株式会社 アサヒペン');
ok($zip->set_number('5388686')->is_valid_number, '株式会社 椿本チエイン');
ok($zip->set_number('5398794')->is_valid_number, '大阪貯金事務センター');
ok($zip->set_number('5406255')->is_valid_number, 'パナソニック 株式会社');
ok($zip->set_number('5408501')->is_valid_number, 'NHK大阪放送局');
ok($zip->set_number('5408505')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('5408507')->is_valid_number, '大阪府中央府税事務所(法人二税)');
ok($zip->set_number('5408508')->is_valid_number, '株式会社 サクラクレパス');
ok($zip->set_number('5408510')->is_valid_number, '株式会社 エイデック');
ok($zip->set_number('5408510')->is_valid_number, '株式会社 センテンス');
ok($zip->set_number('5408510')->is_valid_number, '株式会社 読売テレビエンタープライズ');
ok($zip->set_number('5408510')->is_valid_number, '株式会社 よみうりテレビサービス');
ok($zip->set_number('5408510')->is_valid_number, '株式会社 ytv Nextry');
ok($zip->set_number('5408510')->is_valid_number, '株式会社 ytvメディアデザイン 大阪オフィス');
ok($zip->set_number('5408510')->is_valid_number, '讀賣テレビ放送 株式会社');
ok($zip->set_number('5408511')->is_valid_number, '西日本電信電話 株式会社');
ok($zip->set_number('5408512')->is_valid_number, '住友生命保険 相互会社');
ok($zip->set_number('5408515')->is_valid_number, '西松建設 株式会社 関西支店');
ok($zip->set_number('5408517')->is_valid_number, '年金記録確認大阪地方第三者委員会');
ok($zip->set_number('5408519')->is_valid_number, 'テレビ大阪 株式会社');
ok($zip->set_number('5408521')->is_valid_number, '株式会社 明治 関西支社');
ok($zip->set_number('5408522')->is_valid_number, '伊藤忠食品 株式会社');
ok($zip->set_number('5408526')->is_valid_number, '株式会社 リヒトラブ');
ok($zip->set_number('5408527')->is_valid_number, '大阪労働局');
ok($zip->set_number('5408530')->is_valid_number, '株式会社 マンダム');
ok($zip->set_number('5408533')->is_valid_number, '近畿管区行政評価局');
ok($zip->set_number('5408534')->is_valid_number, 'YKK AP 株式会社');
ok($zip->set_number('5408535')->is_valid_number, '近畿経済産業局');
ok($zip->set_number('5408540')->is_valid_number, '大阪府警察本部');
ok($zip->set_number('5408541')->is_valid_number, '大阪国税局');
ok($zip->set_number('5408544')->is_valid_number, '大阪法務局');
ok($zip->set_number('5408547')->is_valid_number, '株式会社 日経ラジオ社 大阪支社 (ラジオNIKKEI)');
ok($zip->set_number('5408550')->is_valid_number, '近畿財務局');
ok($zip->set_number('5408551')->is_valid_number, '日本電気 株式会社 関西支社');
ok($zip->set_number('5408552')->is_valid_number, '吉岡 株式会社 大阪支店');
ok($zip->set_number('5408553')->is_valid_number, 'パナソニック 株式会社 コネクティッドソリューションズ社 ytv京橋ビル');
ok($zip->set_number('5408555')->is_valid_number, '財団法人 日本中小企業福祉事業財団 (日本フルハップ)');
ok($zip->set_number('5408558')->is_valid_number, '近畿運輸局');
ok($zip->set_number('5408559')->is_valid_number, '大阪航空局');
ok($zip->set_number('5408560')->is_valid_number, '株式会社 関西みらい銀行');
ok($zip->set_number('5408560')->is_valid_number, '株式会社 りそな銀行');
ok($zip->set_number('5408560')->is_valid_number, 'りそなビジネスサービス 株式会社');
ok($zip->set_number('5408566')->is_valid_number, '森下仁丹 株式会社');
ok($zip->set_number('5408570')->is_valid_number, '大阪府庁');
ok($zip->set_number('5408571')->is_valid_number, '大阪府庁 (大阪府教育委員会)');
ok($zip->set_number('5408575')->is_valid_number, 'アルフレッサファーマ 株式会社');
ok($zip->set_number('5408577')->is_valid_number, '株式会社 丸島アクアシステム');
ok($zip->set_number('5408578')->is_valid_number, '株式会社 ニュー・オータニホテル ニューオータニ大阪');
ok($zip->set_number('5408581')->is_valid_number, '日本直販 株式会社');
ok($zip->set_number('5408585')->is_valid_number, '京セラドキュメントソリューションズ 株式会社');
ok($zip->set_number('5408586')->is_valid_number, '国土交通省 近畿地方整備局');
ok($zip->set_number('5408587')->is_valid_number, '大阪司法書士会');
ok($zip->set_number('5408602')->is_valid_number, 'CBC 株式会社 大阪支店');
ok($zip->set_number('5408603')->is_valid_number, '蝶理 株式会社');
ok($zip->set_number('5408604')->is_valid_number, '野村證券 株式会社');
ok($zip->set_number('5408605')->is_valid_number, '和光純薬工業 株式会社');
ok($zip->set_number('5408606')->is_valid_number, '株式会社 ジェーシービー 大阪支社');
ok($zip->set_number('5408607')->is_valid_number, '株式会社 りそな銀行 年金信託部');
ok($zip->set_number('5408608')->is_valid_number, '株式会社 りそなホールディングス');
ok($zip->set_number('5408610')->is_valid_number, '株式会社 関西みらい銀行');
ok($zip->set_number('5408610')->is_valid_number, '株式会社 関西みらいフィナンシャルグループ');
ok($zip->set_number('5408610')->is_valid_number, '株式会社 りそな銀行 大阪本社');
ok($zip->set_number('5408611')->is_valid_number, '塩野義製薬 株式会社');
ok($zip->set_number('5408615')->is_valid_number, '国土交通省 近畿地方整備局 建政部 建設産業第一課');
ok($zip->set_number('5408620')->is_valid_number, '株式会社 住友銀行 本店');
ok($zip->set_number('5408622')->is_valid_number, 'ケイ・オプティコムビル');
ok($zip->set_number('5408630')->is_valid_number, '株式会社 みずほ銀行 大阪支店');
ok($zip->set_number('5408639')->is_valid_number, '三井住友信託銀行 株式会社');
ok($zip->set_number('5408642')->is_valid_number, '三共生興 株式会社');
ok($zip->set_number('5408645')->is_valid_number, '武田薬品工業 株式会社');
ok($zip->set_number('5408660')->is_valid_number, '株式会社 ヤギ');
ok($zip->set_number('5408668')->is_valid_number, '瀧定大阪 株式会社');
ok($zip->set_number('5408670')->is_valid_number, '三菱ウェルファーマ 株式会社');
ok($zip->set_number('5408677')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('5408678')->is_valid_number, 'ユニチカ通商 (株)');
ok($zip->set_number('5408686')->is_valid_number, '村中医療器 株式会社');
ok($zip->set_number('5408795')->is_valid_number, '近畿総合通信局');
ok($zip->set_number('5416666')->is_valid_number, '株式会社 大西');
ok($zip->set_number('5418501')->is_valid_number, '日本生命保険 相互会社');
ok($zip->set_number('5418502')->is_valid_number, '三菱UFJ信託銀行 株式会社 大阪証券代行部');
ok($zip->set_number('5418503')->is_valid_number, '株式会社 プロルート丸光');
ok($zip->set_number('5418505')->is_valid_number, '田辺三菱製薬 株式会社');
ok($zip->set_number('5418506')->is_valid_number, '清原 株式会社');
ok($zip->set_number('5418508')->is_valid_number, '朝日火災海上保険 株式会社');
ok($zip->set_number('5418509')->is_valid_number, '新生フィナンシャル 株式会社');
ok($zip->set_number('5418511')->is_valid_number, '興和 株式会社 大阪支店');
ok($zip->set_number('5418513')->is_valid_number, 'KISCO 株式会社 大阪本社');
ok($zip->set_number('5418515')->is_valid_number, '株式会社 日本経済新聞社 大阪本社');
ok($zip->set_number('5418516')->is_valid_number, 'シキボウ 株式会社');
ok($zip->set_number('5418517')->is_valid_number, '株式会社 森本組');
ok($zip->set_number('5418518')->is_valid_number, '大阪市中央区役所');
ok($zip->set_number('5418519')->is_valid_number, '極東開発工業 株式会社');
ok($zip->set_number('5418520')->is_valid_number, '清水建設 株式会社 大阪支店');
ok($zip->set_number('5418521')->is_valid_number, '岩井コスモ証券 株式会社');
ok($zip->set_number('5418523')->is_valid_number, '関西ペイント 株式会社');
ok($zip->set_number('5418524')->is_valid_number, '大日本住友製薬 株式会社');
ok($zip->set_number('5418525')->is_valid_number, 'DIC 株式会社 大阪支店');
ok($zip->set_number('5418526')->is_valid_number, '小野薬品工業 株式会社');
ok($zip->set_number('5418528')->is_valid_number, '株式会社 日建設計');
ok($zip->set_number('5418529')->is_valid_number, '前田建設工業 株式会社 関西支店');
ok($zip->set_number('5418530')->is_valid_number, '株式会社 三菱UFJ銀行');
ok($zip->set_number('5418531')->is_valid_number, '大阪市職員労働組合');
ok($zip->set_number('5418534')->is_valid_number, '村田長 株式会社');
ok($zip->set_number('5418535')->is_valid_number, '株式会社 三菱東京UFJ銀行 大阪中央支店');
ok($zip->set_number('5418537')->is_valid_number, '三井住友カード 株式会社');
ok($zip->set_number('5418538')->is_valid_number, 'ミズノ 株式会社 大阪店');
ok($zip->set_number('5418540')->is_valid_number, 'NI帝人商事 株式会社');
ok($zip->set_number('5418541')->is_valid_number, 'オーミケンシ 株式会社');
ok($zip->set_number('5418542')->is_valid_number, '野村貿易 株式会社');
ok($zip->set_number('5418543')->is_valid_number, '上野製薬 株式会社');
ok($zip->set_number('5418543')->is_valid_number, '株式会社 ウエノフードテクノ');
ok($zip->set_number('5418545')->is_valid_number, '損保ジャパン日本興亜 株式会社');
ok($zip->set_number('5418547')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('5418550')->is_valid_number, '住友工業 株式会社');
ok($zip->set_number('5418551')->is_valid_number, '大阪市船場法人市税事務所');
ok($zip->set_number('5418553')->is_valid_number, 'サッポログループマネジメント 株式会社');
ok($zip->set_number('5418553')->is_valid_number, 'サッポロビール 株式会社 近畿圏本部');
ok($zip->set_number('5418553')->is_valid_number, '神州一味噌 株式会社');
ok($zip->set_number('5418553')->is_valid_number, 'スターネット 株式会社 近畿圏支社');
ok($zip->set_number('5418553')->is_valid_number, 'スタービバレッジサービス 株式会社');
ok($zip->set_number('5418553')->is_valid_number, 'ポッカサッポロフード&ビバレッジ 株式会社');
ok($zip->set_number('5418556')->is_valid_number, '近畿厚生局');
ok($zip->set_number('5418557')->is_valid_number, '神鋼商事 株式会社');
ok($zip->set_number('5418558')->is_valid_number, '日商岩井 株式会社');
ok($zip->set_number('5418559')->is_valid_number, '日本板硝子 株式会社');
ok($zip->set_number('5418560')->is_valid_number, '兼松 株式会社 大阪支社');
ok($zip->set_number('5418561')->is_valid_number, '株式会社 サンケイリビング新聞社');
ok($zip->set_number('5418563')->is_valid_number, '旭洋 株式会社');
ok($zip->set_number('5418566')->is_valid_number, 'ユニチカ 株式会社');
ok($zip->set_number('5418567')->is_valid_number, '大阪国際がんセンター');
ok($zip->set_number('5418568')->is_valid_number, 'コスモ石油 株式会社 大阪支店');
ok($zip->set_number('5418572')->is_valid_number, 'SMBCファイナンスサービス 株式会社');
ok($zip->set_number('5418575')->is_valid_number, '株式会社 明成商会');
ok($zip->set_number('5418576')->is_valid_number, '住友商事ケミカル 株式会社 関西支社');
ok($zip->set_number('5418578')->is_valid_number, '財団法人 簡易保険加入者協会 近畿地方本部');
ok($zip->set_number('5418581')->is_valid_number, '倉敷紡績 株式会社');
ok($zip->set_number('5418585')->is_valid_number, '阪和興業 株式会社');
ok($zip->set_number('5418587')->is_valid_number, '帝人 株式会社');
ok($zip->set_number('5418589')->is_valid_number, 'オザックス 株式会社');
ok($zip->set_number('5418630')->is_valid_number, '株式会社 大林組');
ok($zip->set_number('5418765')->is_valid_number, 'エレコム 株式会社');
ok($zip->set_number('5428501')->is_valid_number, '株式会社 大丸 大阪心斎橋店');
ok($zip->set_number('5428502')->is_valid_number, '株式会社 ジェイテクト');
ok($zip->set_number('5428503')->is_valid_number, '南海電気鉄道 株式会社');
ok($zip->set_number('5428504')->is_valid_number, '住江織物 株式会社');
ok($zip->set_number('5428510')->is_valid_number, '株式会社 高島屋 大阪店');
ok($zip->set_number('5428511')->is_valid_number, '大和証券 株式会社 難波支店');
ok($zip->set_number('5428522')->is_valid_number, '村本建設 株式会社');
ok($zip->set_number('5428523')->is_valid_number, '日産プリンス大阪販売 株式会社');
ok($zip->set_number('5428525')->is_valid_number, '株式会社 ドウシシャ');
ok($zip->set_number('5428533')->is_valid_number, '株式会社 東急ハンズ 心斎橋店');
ok($zip->set_number('5428542')->is_valid_number, '株式会社 USEN 事務センター 大阪管理課');
ok($zip->set_number('5428550')->is_valid_number, '豊田通商 株式会社 大阪支店');
ok($zip->set_number('5428554')->is_valid_number, '株式会社 カナデン 関西支社');
ok($zip->set_number('5428555')->is_valid_number, '株式会社 そごう 大阪店');
ok($zip->set_number('5428558')->is_valid_number, '稲畑産業 株式会社');
ok($zip->set_number('5428566')->is_valid_number, 'クラブツーリズム 株式会社');
ok($zip->set_number('5428567')->is_valid_number, '冨士火災海上保険 株式会社');
ok($zip->set_number('5428577')->is_valid_number, '株式会社 誠和商会');
ok($zip->set_number('5428580')->is_valid_number, '大阪府医師協同組合');
ok($zip->set_number('5428585')->is_valid_number, '株式会社 エスエスケイ');
ok($zip->set_number('5428586')->is_valid_number, '南税務署');
ok($zip->set_number('5428588')->is_valid_number, '株式会社 日伝');
ok($zip->set_number('5428654')->is_valid_number, '株式会社 関西みらい銀行');
ok($zip->set_number('5428660')->is_valid_number, 'ユアサ商事 株式会社 関西支社');
ok($zip->set_number('5428686')->is_valid_number, '株式会社 福徳銀行');
ok($zip->set_number('5428688')->is_valid_number, '三井住友カード 株式会社');
ok($zip->set_number('5428745')->is_valid_number, '大阪府医師協同組合');
ok($zip->set_number('5438501')->is_valid_number, '大阪市天王寺区役所');
ok($zip->set_number('5438502')->is_valid_number, '大阪警察病院');
ok($zip->set_number('5438503')->is_valid_number, '天王寺税務署');
ok($zip->set_number('5438511')->is_valid_number, '大阪府 大阪自動車税事務所');
ok($zip->set_number('5438533')->is_valid_number, '大阪府 なにわ南府税事務所');
ok($zip->set_number('5438543')->is_valid_number, '株式会社 近鉄百貨店 上本町店');
ok($zip->set_number('5438555')->is_valid_number, '大阪赤十字病院');
ok($zip->set_number('5438558')->is_valid_number, '株式会社 森本組');
ok($zip->set_number('5438585')->is_valid_number, '近畿日本鉄道 株式会社');
ok($zip->set_number('5438588')->is_valid_number, '天王寺年金事務所');
ok($zip->set_number('5438601')->is_valid_number, 'ゼット 株式会社');
ok($zip->set_number('5438666')->is_valid_number, '大阪信用金庫');
ok($zip->set_number('5438686')->is_valid_number, 'ギフコ 株式会社');
ok($zip->set_number('5438688')->is_valid_number, '株式会社 浅沼組 大阪本店');
ok($zip->set_number('5448501')->is_valid_number, '生野区役所');
ok($zip->set_number('5448555')->is_valid_number, '生野税務署');
ok($zip->set_number('5448585')->is_valid_number, '株式会社 モリタホールディングス');
ok($zip->set_number('5448666')->is_valid_number, 'ロート製薬 株式会社');
ok($zip->set_number('5448686')->is_valid_number, '昌栄印刷 株式会社');
ok($zip->set_number('5458501')->is_valid_number, '大阪市阿倍野区役所');
ok($zip->set_number('5458511')->is_valid_number, '大杉製薬 株式会社');
ok($zip->set_number('5458533')->is_valid_number, '大阪市 あべの市税事務所');
ok($zip->set_number('5458545')->is_valid_number, '株式会社 近鉄百貨店');
ok($zip->set_number('5458550')->is_valid_number, '大阪市環境事業局');
ok($zip->set_number('5458555')->is_valid_number, '株式会社 奥村組');
ok($zip->set_number('5458585')->is_valid_number, '大阪市立大学 医学部');
ok($zip->set_number('5458586')->is_valid_number, '大阪市立大学 医学部付属病院');
ok($zip->set_number('5468501')->is_valid_number, '東住吉区役所');
ok($zip->set_number('5478501')->is_valid_number, '東住吉税務署');
ok($zip->set_number('5478510')->is_valid_number, 'シャープマーケティングジャパン 株式会社');
ok($zip->set_number('5478514')->is_valid_number, '株式会社 コアデ');
ok($zip->set_number('5478580')->is_valid_number, '平野区役所');
ok($zip->set_number('5498511')->is_valid_number, '中カウンター 関西空港ターミナル 4F国際線出発ロビー・1F国際線到着ロビー');
ok($zip->set_number('5498522')->is_valid_number, '北カウンター 関西空港ターミナル 4F国際線出発ロビー・1F国際線到着ロビー');
ok($zip->set_number('5498585')->is_valid_number, 'Peach・Aviation 株式会社');
ok($zip->set_number('5508501')->is_valid_number, '大阪市西区役所');
ok($zip->set_number('5508502')->is_valid_number, '杉本商事 株式会社');
ok($zip->set_number('5508503')->is_valid_number, '労働法令新報社');
ok($zip->set_number('5508505')->is_valid_number, '大阪府 なにわ西府税事務所');
ok($zip->set_number('5508508')->is_valid_number, '大日本印刷 株式会社 大阪');
ok($zip->set_number('5508510')->is_valid_number, '全国健康保険協会 大阪支部');
ok($zip->set_number('5508527')->is_valid_number, 'アズワン 株式会社');
ok($zip->set_number('5508530')->is_valid_number, '株式会社 関西ぱど');
ok($zip->set_number('5508538')->is_valid_number, '近畿労働金庫');
ok($zip->set_number('5508541')->is_valid_number, 'サンコーインダストリー 株式会社');
ok($zip->set_number('5508550')->is_valid_number, '住友電設 株式会社');
ok($zip->set_number('5508552')->is_valid_number, '大阪市高速電気軌道 株式会社');
ok($zip->set_number('5508555')->is_valid_number, '株式会社 立花エレテック');
ok($zip->set_number('5508566')->is_valid_number, '大阪市消防局');
ok($zip->set_number('5508567')->is_valid_number, '大阪トヨペット 株式会社');
ok($zip->set_number('5508570')->is_valid_number, 'デイリースポーツ 大阪本社');
ok($zip->set_number('5508575')->is_valid_number, '株式会社 京阪神エルマガジン社');
ok($zip->set_number('5508577')->is_valid_number, '損保ジャパン日本興亜 株式会社');
ok($zip->set_number('5508578')->is_valid_number, '株式会社 オーエムエムジー');
ok($zip->set_number('5508580')->is_valid_number, '株式会社 栗本鐵工所');
ok($zip->set_number('5508585')->is_valid_number, '三木産業 株式会社 大阪支店');
ok($zip->set_number('5508587')->is_valid_number, '帝人グループ');
ok($zip->set_number('5508659')->is_valid_number, '株式会社 オーツー');
ok($zip->set_number('5508660')->is_valid_number, '株式会社 山善');
ok($zip->set_number('5518501')->is_valid_number, '大正区役所');
ok($zip->set_number('5518511')->is_valid_number, '株式会社 エディオンLEC近畿');
ok($zip->set_number('5518551')->is_valid_number, '株式会社 中山製鋼所');
ok($zip->set_number('5528501')->is_valid_number, '大阪放送 株式会社');
ok($zip->set_number('5528510')->is_valid_number, '大阪市港区役所');
ok($zip->set_number('5538501')->is_valid_number, '大阪市福島区役所');
ok($zip->set_number('5538503')->is_valid_number, '朝日放送 株式会社');
ok($zip->set_number('5538511')->is_valid_number, '大阪高等検察庁');
ok($zip->set_number('5538512')->is_valid_number, '大阪地方検察庁');
ok($zip->set_number('5538513')->is_valid_number, '人事院近畿事務局');
ok($zip->set_number('5538550')->is_valid_number, '株式会社 大水');
ok($zip->set_number('5538553')->is_valid_number, '阪神電気鉄道 株式会社');
ok($zip->set_number('5538555')->is_valid_number, '株式会社 うおいち');
ok($zip->set_number('5538558')->is_valid_number, '株式会社 大塚商会 関西支社');
ok($zip->set_number('5538567')->is_valid_number, '大阪福島税務署');
ok($zip->set_number('5538585')->is_valid_number, '福島年金事務所');
ok($zip->set_number('5538588')->is_valid_number, '株式会社 交通タイムス社 大阪事業所');
ok($zip->set_number('5538739')->is_valid_number, '学校法人 創造社学園 創造社デザイン専門学校');
ok($zip->set_number('5548501')->is_valid_number, '大阪市此花区役所');
ok($zip->set_number('5548511')->is_valid_number, '住友電気工業 株式会社 大阪製作所');
ok($zip->set_number('5548585')->is_valid_number, 'ホテル京阪 ユニバーサル・シティ');
ok($zip->set_number('5548588')->is_valid_number, '株式会社 アド・ダイセン');
ok($zip->set_number('5558501')->is_valid_number, '大阪市西淀川区役所');
ok($zip->set_number('5558502')->is_valid_number, '江崎グリコ 株式会社');
ok($zip->set_number('5558503')->is_valid_number, '鴻池運輸 株式会社 西大阪流通センター営業所');
ok($zip->set_number('5558555')->is_valid_number, '国分 株式会社 近畿支社 西淀川流通センター');
ok($zip->set_number('5568501')->is_valid_number, '浪速区役所');
ok($zip->set_number('5568503')->is_valid_number, '南海電気鉄道 株式会社');
ok($zip->set_number('5568510')->is_valid_number, 'fm osaka');
ok($zip->set_number('5568515')->is_valid_number, '株式会社 サンケイリビング新聞社');
ok($zip->set_number('5568516')->is_valid_number, '株式会社 リビングプロシード');
ok($zip->set_number('5568535')->is_valid_number, '株式会社 アプラス');
ok($zip->set_number('5568550')->is_valid_number, '上新電機 株式会社');
ok($zip->set_number('5568555')->is_valid_number, '東洋紙業 株式会社');
ok($zip->set_number('5568558')->is_valid_number, 'エルエイト');
ok($zip->set_number('5568585')->is_valid_number, '難波年金事務所');
ok($zip->set_number('5568601')->is_valid_number, '株式会社 クボタ 本社');
ok($zip->set_number('5568660')->is_valid_number, '株式会社 産業経済新聞社');
ok($zip->set_number('5568663')->is_valid_number, 'サンケイスポーツ');
ok($zip->set_number('5568664')->is_valid_number, '夕刊フジ');
ok($zip->set_number('5568665')->is_valid_number, 'サンケイチケットセンター');
ok($zip->set_number('5568666')->is_valid_number, '産經新聞開発 株式会社');
ok($zip->set_number('5568670')->is_valid_number, '大阪市 なんば市税事務所');
ok($zip->set_number('5578501')->is_valid_number, '大阪市西成区役所');
ok($zip->set_number('5588501')->is_valid_number, '大阪市住吉区役所');
ok($zip->set_number('5588555')->is_valid_number, '住吉税務署');
ok($zip->set_number('5588558')->is_valid_number, '大阪府立 急性期・総合医療センター');
ok($zip->set_number('5588585')->is_valid_number, '大阪市立大学');
ok($zip->set_number('5598501')->is_valid_number, '株式会社 ライカ');
ok($zip->set_number('5598502')->is_valid_number, '舞昆のこうはら');
ok($zip->set_number('5598506')->is_valid_number, '関西電力 株式会社');
ok($zip->set_number('5598510')->is_valid_number, 'ミズノ 株式会社');
ok($zip->set_number('5598511')->is_valid_number, '社団法人 大阪府自動車整備振興会');
ok($zip->set_number('5598519')->is_valid_number, 'いであ 株式会社 大阪支社');
ok($zip->set_number('5598550')->is_valid_number, '津田産業 株式会社');
ok($zip->set_number('5598553')->is_valid_number, '株式会社 ロゴスコーポレーション');
ok($zip->set_number('5598555')->is_valid_number, '大阪府 咲洲庁舎');
ok($zip->set_number('5598558')->is_valid_number, '大阪市水道局');
ok($zip->set_number('5598559')->is_valid_number, '日立造船 株式会社');
ok($zip->set_number('5598560')->is_valid_number, '日本年金機構 玉出年金事務所');
ok($zip->set_number('5598561')->is_valid_number, '株式会社 グルメ杵屋');
ok($zip->set_number('5598585')->is_valid_number, '真生印刷 株式会社');
ok($zip->set_number('5598588')->is_valid_number, 'デジタルプラネット衛星放送');
ok($zip->set_number('5598601')->is_valid_number, '住之江区役所');
ok($zip->set_number('5598602')->is_valid_number, 'インテックス大阪');
ok($zip->set_number('5598604')->is_valid_number, '大阪バイイー');
ok($zip->set_number('5598605')->is_valid_number, '株式会社 ワールドサプライ 大阪営業所');
ok($zip->set_number('5598611')->is_valid_number, '森ノ宮医療大学');
ok($zip->set_number('5598651')->is_valid_number, '三井造船 株式会社 大阪事業所');
ok($zip->set_number('5598658')->is_valid_number, '永大産業 株式会社 本社');
ok($zip->set_number('5598729')->is_valid_number, 'パナソニック 株式会社 エナジー住之江工場');
ok($zip->set_number('5608505')->is_valid_number, '大正製薬 株式会社 関西支店');
ok($zip->set_number('5608506')->is_valid_number, '大正富山医薬品 株式会社 関西支店');
ok($zip->set_number('5608531')->is_valid_number, '大阪大学 基礎工学部/大学院基礎工学研究科');
ok($zip->set_number('5608532')->is_valid_number, '大阪大学 文学部');
ok($zip->set_number('5608543')->is_valid_number, 'パナソニック ホームズ 株式会社');
ok($zip->set_number('5608548')->is_valid_number, 'ANAベースメンテナンステクニクス 株式会社');
ok($zip->set_number('5608550')->is_valid_number, '株式会社 阪急阪神百貨店 千里阪急');
ok($zip->set_number('5608551')->is_valid_number, '阪急バス 株式会社');
ok($zip->set_number('5608552')->is_valid_number, '独立行政法人 国立病院機構 刀根山病院');
ok($zip->set_number('5608555')->is_valid_number, '株式会社 ニッショーストアー事業本部');
ok($zip->set_number('5608560')->is_valid_number, '豊中年金事務所');
ok($zip->set_number('5608561')->is_valid_number, 'NHK 千里営業センター');
ok($zip->set_number('5608565')->is_valid_number, '市立豊中病院');
ok($zip->set_number('5608567')->is_valid_number, '株式会社 廣済堂');
ok($zip->set_number('5608579')->is_valid_number, '株式会社 オートバックスセブン');
ok($zip->set_number('5608580')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('5618501')->is_valid_number, '豊中市役所');
ok($zip->set_number('5618510')->is_valid_number, '株式会社 日本経営');
ok($zip->set_number('5618511')->is_valid_number, '大阪北生活協同組合');
ok($zip->set_number('5618520')->is_valid_number, '摂津水都信用金庫');
ok($zip->set_number('5618530')->is_valid_number, '敷島製パン 株式会社 パスコウエストカンパニー大阪豊中工場');
ok($zip->set_number('5618550')->is_valid_number, '株式会社 イーパック');
ok($zip->set_number('5618555')->is_valid_number, '学校法人 大阪音楽大学');
ok($zip->set_number('5618558')->is_valid_number, '松尾電機 株式会社');
ok($zip->set_number('5618577')->is_valid_number, '学校法人 大商学園 大商学園高等学校');
ok($zip->set_number('5628505')->is_valid_number, 'フィガロ技研 株式会社');
ok($zip->set_number('5628508')->is_valid_number, '宗教法人 勝尾寺');
ok($zip->set_number('5628511')->is_valid_number, '株式会社 ロイネ');
ok($zip->set_number('5628522')->is_valid_number, '宇野 株式会社');
ok($zip->set_number('5628543')->is_valid_number, '学校法人 聖母被昇天学院');
ok($zip->set_number('5628555')->is_valid_number, '株式会社 アラミック');
ok($zip->set_number('5628560')->is_valid_number, '株式会社 理喜');
ok($zip->set_number('5628562')->is_valid_number, '箕面市立病院');
ok($zip->set_number('5628567')->is_valid_number, 'ガラシア病院');
ok($zip->set_number('5628568')->is_valid_number, 'キングベビー 株式会社');
ok($zip->set_number('5628580')->is_valid_number, '大阪青山短期大学・大阪青山大学');
ok($zip->set_number('5628585')->is_valid_number, 'おたふく手袋 株式会社');
ok($zip->set_number('5628586')->is_valid_number, 'ヘンケルジャパン 株式会社');
ok($zip->set_number('5628588')->is_valid_number, 'センコー 株式会社 東大阪支店船場PDセンター');
ok($zip->set_number('5628678')->is_valid_number, '国立大学法人 大阪大学大学院 人文学研究科/外国語学部');
ok($zip->set_number('5628686')->is_valid_number, '一般財団法人 蛋白質研究奨励会、株式会社 千里インターナショナル');
ok($zip->set_number('5630292')->is_valid_number, '豊能町');
ok($zip->set_number('5630392')->is_valid_number, '能勢町役場');
ok($zip->set_number('5638510')->is_valid_number, '市立 池田病院');
ok($zip->set_number('5638567')->is_valid_number, '大阪法務局 池田出張所');
ok($zip->set_number('5638577')->is_valid_number, '独立行政法人 産業技術総合研究所 関西センター');
ok($zip->set_number('5638588')->is_valid_number, '大阪府 豊能府税事務所');
ok($zip->set_number('5648501')->is_valid_number, 'オッペン化粧品');
ok($zip->set_number('5648503')->is_valid_number, '株式会社 ジェフサ');
ok($zip->set_number('5648511')->is_valid_number, '大阪学院大学');
ok($zip->set_number('5648515')->is_valid_number, '吹田税務署');
ok($zip->set_number('5648523')->is_valid_number, '日本システム収納 株式会社');
ok($zip->set_number('5648550')->is_valid_number, '吹田市役所');
ok($zip->set_number('5648551')->is_valid_number, '吹田市水道部');
ok($zip->set_number('5648555')->is_valid_number, '株式会社 日本創造教育研究所');
ok($zip->set_number('5648565')->is_valid_number, '国立研究開発法人 国立循環器病研究センター');
ok($zip->set_number('5648567')->is_valid_number, '地方独立行政法人 市立吹田市民病院');
ok($zip->set_number('5648650')->is_valid_number, '株式会社 モリタ');
ok($zip->set_number('5648651')->is_valid_number, '三井信託銀行 大阪事務センター');
ok($zip->set_number('5648680')->is_valid_number, '関西大学 千里山キャンパス');
ok($zip->set_number('5658511')->is_valid_number, '国立民族学博物館');
ok($zip->set_number('5658540')->is_valid_number, '阪神園芸 株式会社 大阪支店 クリエイティブ阪急事業部');
ok($zip->set_number('5658565')->is_valid_number, '国立循環器病センター');
ok($zip->set_number('5668501')->is_valid_number, '学校法人 薫英学園');
ok($zip->set_number('5668513')->is_valid_number, 'コカ・コーラウエスト 株式会社');
ok($zip->set_number('5668555')->is_valid_number, '摂津市役所');
ok($zip->set_number('5668566')->is_valid_number, '株式会社 梅丹本舗');
ok($zip->set_number('5668585')->is_valid_number, 'ダイキン工業 株式会社 淀川製作所');
ok($zip->set_number('5668686')->is_valid_number, '株式会社 エネゲート 千里丘事業所');
ok($zip->set_number('5678501')->is_valid_number, '株式会社 明治屋食品工場');
ok($zip->set_number('5678502')->is_valid_number, '追手門学院大学');
ok($zip->set_number('5678505')->is_valid_number, '茨木市役所');
ok($zip->set_number('5678507')->is_valid_number, 'アマゾン茨木FC');
ok($zip->set_number('5678510')->is_valid_number, 'フジテック 株式会社');
ok($zip->set_number('5678511')->is_valid_number, '医療法人 恒昭会 藍野病院');
ok($zip->set_number('5678515')->is_valid_number, '大阪府 三島府税事務所');
ok($zip->set_number('5678520')->is_valid_number, 'マルカキカイ 株式会社');
ok($zip->set_number('5678521')->is_valid_number, 'サッポロビール 株式会社 大阪工場');
ok($zip->set_number('5678523')->is_valid_number, '大阪府立 茨木高等学校');
ok($zip->set_number('5678525')->is_valid_number, '株式会社 桜川ポンプ製作所');
ok($zip->set_number('5678530')->is_valid_number, '茨木労働基準監督署');
ok($zip->set_number('5678540')->is_valid_number, '大阪府立 茨木東高等学校');
ok($zip->set_number('5678557')->is_valid_number, 'ゴルフ場用品 株式会社');
ok($zip->set_number('5678565')->is_valid_number, '茨木税務署');
ok($zip->set_number('5678567')->is_valid_number, '日立マクセル 株式会社 本社大阪事業所');
ok($zip->set_number('5678570')->is_valid_number, '立命館大学 大阪いばらきキャンパス');
ok($zip->set_number('5678578')->is_valid_number, '梅花女子大学');
ok($zip->set_number('5678585')->is_valid_number, '大阪府 茨木保健所');
ok($zip->set_number('5678588')->is_valid_number, '茨木商工会議所');
ok($zip->set_number('5678651')->is_valid_number, '摂津水都信用金庫');
ok($zip->set_number('5678680')->is_valid_number, '日東電工 株式会社 茨木事業所');
ok($zip->set_number('5691092')->is_valid_number, '平安女学院大学');
ok($zip->set_number('5691094')->is_valid_number, '学校法人 大阪医科薬科大学薬学部');
ok($zip->set_number('5691095')->is_valid_number, '関西大学 高槻キャンパス');
ok($zip->set_number('5691096')->is_valid_number, '高槻赤十字病院');
ok($zip->set_number('5691098')->is_valid_number, '関西大学 高槻ミューズキャンパス');
ok($zip->set_number('5691192')->is_valid_number, '医療法人 愛仁会 高槻病院');
ok($zip->set_number('5691193')->is_valid_number, 'パナソニックライティングデバイス 株式会社 パナソニックフォト・ライティング 株式会社');
ok($zip->set_number('5691194')->is_valid_number, 'パーソルAVCテクノロジー 株式会社');
ok($zip->set_number('5691195')->is_valid_number, 'サンスター 株式会社');
ok($zip->set_number('5691196')->is_valid_number, '株式会社 西武百貨店 高槻店');
ok($zip->set_number('5691197')->is_valid_number, '医療法人 美喜和会 美喜和会オレンジホスピタル');
ok($zip->set_number('5698501')->is_valid_number, '高槻市役所');
ok($zip->set_number('5698503')->is_valid_number, 'コニカミノルタ 高槻サイト');
ok($zip->set_number('5698505')->is_valid_number, '高槻中学校・高等学校');
ok($zip->set_number('5698510')->is_valid_number, 'アルインコ (株)');
ok($zip->set_number('5698511')->is_valid_number, '関西電力 (株) 高槻営業所');
ok($zip->set_number('5698512')->is_valid_number, 'シンワ (株)');
ok($zip->set_number('5698520')->is_valid_number, '(株) 日新化学研究所');
ok($zip->set_number('5698522')->is_valid_number, '(株) 松坂屋 高槻店');
ok($zip->set_number('5698533')->is_valid_number, 'ムネカタ (株)');
ok($zip->set_number('5698549')->is_valid_number, '太陽エンジニヤ (株)');
ok($zip->set_number('5698551')->is_valid_number, '矢崎化工 株式会社 大阪支店');
ok($zip->set_number('5698555')->is_valid_number, '山下鉄工 (株)');
ok($zip->set_number('5698558')->is_valid_number, 'サンユレック 株式会社');
ok($zip->set_number('5698566')->is_valid_number, '岩谷物流 (株)');
ok($zip->set_number('5698567')->is_valid_number, 'イオン (株) ジャスコシティー 高槻店');
ok($zip->set_number('5698569')->is_valid_number, '大阪ガス (株) 北東部事業本部北部事業所');
ok($zip->set_number('5698570')->is_valid_number, 'アマゾンジャパン高槻FC');
ok($zip->set_number('5698571')->is_valid_number, '株式会社 村上製作所');
ok($zip->set_number('5698575')->is_valid_number, '学校法人 関西金光学園');
ok($zip->set_number('5698577')->is_valid_number, '丸大食品 (株)');
ok($zip->set_number('5698585')->is_valid_number, '医療法人 仙養会 北摂総合病院');
ok($zip->set_number('5698588')->is_valid_number, '港製器工業 (株)');
ok($zip->set_number('5698660')->is_valid_number, '酉島製作所');
ok($zip->set_number('5698686')->is_valid_number, '大阪医科大学');
ok($zip->set_number('5708501')->is_valid_number, '松下電器産業 (株) 技術総務センター');
ok($zip->set_number('5708506')->is_valid_number, '関西医科大学');
ok($zip->set_number('5708507')->is_valid_number, '関西医科大学総合医療センター');
ok($zip->set_number('5708511')->is_valid_number, 'パナソニックエナジー 株式会社');
ok($zip->set_number('5708515')->is_valid_number, 'NTTプリコム 株式会社');
ok($zip->set_number('5708539')->is_valid_number, '奥村機械 (株)');
ok($zip->set_number('5708540')->is_valid_number, '松下電器 健康保険組合・松下記念病院・松下健康管理センター');
ok($zip->set_number('5708555')->is_valid_number, '学校法人 大阪国際学園・大阪国際大学・大阪国際大学短期大学部');
ok($zip->set_number('5708558')->is_valid_number, '株式会社 京阪百貨店');
ok($zip->set_number('5708585')->is_valid_number, '山岡金属工業 株式会社');
ok($zip->set_number('5708588')->is_valid_number, 'いすゞ自動車近畿 株式会社');
ok($zip->set_number('5708634')->is_valid_number, '三洋電機貿易 株式会社');
ok($zip->set_number('5708666')->is_valid_number, '守口市役所');
ok($zip->set_number('5708787')->is_valid_number, '大阪国際中学校高等学校');
ok($zip->set_number('5718502')->is_valid_number, 'パナソニック 株式会社 生産技術本部');
ok($zip->set_number('5718503')->is_valid_number, 'パナソニック (株) AVCネットワークス社');
ok($zip->set_number('5718504')->is_valid_number, 'パナソニック (株) AVCネットワークス社');
ok($zip->set_number('5718507')->is_valid_number, '松下産業機器 株式会社 配電器事業部');
ok($zip->set_number('5718533')->is_valid_number, '株式会社 日伝 西部物流センター');
ok($zip->set_number('5718545')->is_valid_number, '門真税務署');
ok($zip->set_number('5718555')->is_valid_number, '大阪府警察本部交通部門真運転免許試験場');
ok($zip->set_number('5718567')->is_valid_number, '大阪府 中小企業信用保証協会 門真支所');
ok($zip->set_number('5718571')->is_valid_number, 'タイガー魔法瓶 株式会社');
ok($zip->set_number('5718580')->is_valid_number, '東和薬品 株式会社');
ok($zip->set_number('5718585')->is_valid_number, '門真市役所');
ok($zip->set_number('5718620')->is_valid_number, '三井ショッピングパーク ららぽーと門真 三井アウトレットパーク大阪門真');
ok($zip->set_number('5718633')->is_valid_number, '株式会社 アテナ商会');
ok($zip->set_number('5718640')->is_valid_number, '株式会社 全国通販');
ok($zip->set_number('5718686')->is_valid_number, 'パナソニック 株式会社 エコソリューションズ社');
ok($zip->set_number('5728501')->is_valid_number, '日本ペイント 株式会社 寝屋川事業所');
ok($zip->set_number('5728505')->is_valid_number, '株式会社 前田組');
ok($zip->set_number('5728508')->is_valid_number, '摂南大学');
ok($zip->set_number('5728510')->is_valid_number, '株式会社 イトーキ寝屋川工場');
ok($zip->set_number('5728511')->is_valid_number, '寝屋川市教育委員会');
ok($zip->set_number('5728522')->is_valid_number, '大日本エリオ 株式会社 大阪工場');
ok($zip->set_number('5728528')->is_valid_number, '成田山明王院');
ok($zip->set_number('5728530')->is_valid_number, '大阪電気通信大学');
ok($zip->set_number('5728531')->is_valid_number, '聖母女学院中学高等学校・大阪聖母学院小学校');
ok($zip->set_number('5728533')->is_valid_number, '寝屋川市総合センター');
ok($zip->set_number('5728540')->is_valid_number, 'オンキョー 株式会社');
ok($zip->set_number('5728550')->is_valid_number, '関西マネジ興業 株式会社');
ok($zip->set_number('5728551')->is_valid_number, '関西医科大学香里病院');
ok($zip->set_number('5728555')->is_valid_number, '寝屋川市');
ok($zip->set_number('5728558')->is_valid_number, '日本科学冶金 株式会社');
ok($zip->set_number('5728566')->is_valid_number, '寝屋川市立池の里市民交流センター');
ok($zip->set_number('5728567')->is_valid_number, '医療法人 協仁会小松病院');
ok($zip->set_number('5728570')->is_valid_number, '株式会社 エクセディ');
ok($zip->set_number('5728572')->is_valid_number, '大阪府立大学工業高等専門学校');
ok($zip->set_number('5728580')->is_valid_number, 'ネッツトヨタ新大阪 株式会社');
ok($zip->set_number('5728581')->is_valid_number, 'オリエント化学工業 株式会社');
ok($zip->set_number('5728585')->is_valid_number, '同志社香里高等学校');
ok($zip->set_number('5728588')->is_valid_number, '株式会社 三笑堂 大阪支店');
ok($zip->set_number('5728589')->is_valid_number, '株式会社 横井製作所');
ok($zip->set_number('5730193')->is_valid_number, 'JP楽天ロジスティクス 株式会社 楽天フルフィルメントセンター枚方');
ok($zip->set_number('5730195')->is_valid_number, '関西外語大学 穂谷学舎');
ok($zip->set_number('5730196')->is_valid_number, '大阪工業大学 枚方キャンパス');
ok($zip->set_number('5731001')->is_valid_number, '学校法人 関西外国語大学');
ok($zip->set_number('5731004')->is_valid_number, '関西医科大学 看護学部');
ok($zip->set_number('5731007')->is_valid_number, '株式会社 KHD');
ok($zip->set_number('5731008')->is_valid_number, '学校法人 関西外国語大学 御殿山キャンパス・グローバルタウン');
ok($zip->set_number('5731010')->is_valid_number, '関西医科大学');
ok($zip->set_number('5731013')->is_valid_number, '市立ひらかた病院');
ok($zip->set_number('5731030')->is_valid_number, '枚方市上下水道局');
ok($zip->set_number('5731040')->is_valid_number, '(株) 枚方自動車教習所');
ok($zip->set_number('5738505')->is_valid_number, '枚方簡易裁判所');
ok($zip->set_number('5738508')->is_valid_number, 'パナソニック 株式会社 人材開発カンパニー');
ok($zip->set_number('5738510')->is_valid_number, '株式会社 関西ぱど');
ok($zip->set_number('5738511')->is_valid_number, '星ヶ丘厚生年金病院');
ok($zip->set_number('5738534')->is_valid_number, '三洋電機 株式会社 研究開発本部');
ok($zip->set_number('5738556')->is_valid_number, '関西電力 株式会社 枚方営業所');
ok($zip->set_number('5738567')->is_valid_number, '近畿エア・ウォーター 株式会社');
ok($zip->set_number('5738573')->is_valid_number, '株式会社 クボタ 枚方製造所');
ok($zip->set_number('5738588')->is_valid_number, '大阪法務局 枚方出張所');
ok($zip->set_number('5738666')->is_valid_number, '枚方市役所');
ok($zip->set_number('5748501')->is_valid_number, '京セラ 株式会社 大阪大東事業所');
ok($zip->set_number('5748530')->is_valid_number, '大阪産業大学');
ok($zip->set_number('5748531')->is_valid_number, 'アマゾン 大東FC 入庫係');
ok($zip->set_number('5748532')->is_valid_number, 'アマゾン大東FC 小型商品 返送係');
ok($zip->set_number('5748533')->is_valid_number, 'アマゾン大東FC 小型商品 返品係');
ok($zip->set_number('5748534')->is_valid_number, '三洋電機 株式会社');
ok($zip->set_number('5748555')->is_valid_number, '大阪府 大東市役所');
ok($zip->set_number('5748585')->is_valid_number, '朝日電器 株式会社 本社');
ok($zip->set_number('5758501')->is_valid_number, '四條畷市役所');
ok($zip->set_number('5758511')->is_valid_number, '社会医療法人 信愛会 畷生会 脳神経外科病院');
ok($zip->set_number('5758530')->is_valid_number, 'タイガー魔法瓶 株式会社 パーツセンター');
ok($zip->set_number('5758555')->is_valid_number, '大岡広 株式会社');
ok($zip->set_number('5758558')->is_valid_number, '竹本行政書士事務所');
ok($zip->set_number('5758585')->is_valid_number, 'サン電子工業 株式会社');
ok($zip->set_number('5758588')->is_valid_number, '松本引越センター');
ok($zip->set_number('5768501')->is_valid_number, '交野市役所');
ok($zip->set_number('5778502')->is_valid_number, '近畿大学');
ok($zip->set_number('5778503')->is_valid_number, '若井産業 株式会社');
ok($zip->set_number('5778505')->is_valid_number, '学校法人 谷岡学園 大阪商業大学');
ok($zip->set_number('5778509')->is_valid_number, '大阪府 中河内府税事務所');
ok($zip->set_number('5778510')->is_valid_number, '明和グラビア 株式会社');
ok($zip->set_number('5778511')->is_valid_number, '近畿車輛 株式会社');
ok($zip->set_number('5778520')->is_valid_number, 'ハウス食品 株式会社 大阪本社');
ok($zip->set_number('5778521')->is_valid_number, '東大阪市役所');
ok($zip->set_number('5778522')->is_valid_number, '株式会社 エルネット ぱど事業部 東大阪営業部');
ok($zip->set_number('5778533')->is_valid_number, '株式会社 鳴門屋');
ok($zip->set_number('5778537')->is_valid_number, 'ホリアキ 株式会社');
ok($zip->set_number('5778540')->is_valid_number, '株式会社 多磨屋');
ok($zip->set_number('5778550')->is_valid_number, '学校法人 樟蔭学園 大阪樟蔭女子大学 樟蔭高等学校 樟蔭中学校 大阪樟蔭女子大学付属幼稚園');
ok($zip->set_number('5778551')->is_valid_number, '内外電機 株式会社');
ok($zip->set_number('5778554')->is_valid_number, '東大阪社会保険事務所');
ok($zip->set_number('5778555')->is_valid_number, '大阪法務局 東大阪支局');
ok($zip->set_number('5778558')->is_valid_number, '東大阪簡易裁判所');
ok($zip->set_number('5778560')->is_valid_number, '株式会社 ライオン事務器');
ok($zip->set_number('5778566')->is_valid_number, '株式会社 関西電熱');
ok($zip->set_number('5778567')->is_valid_number, '学校法人 村上学園 (東大阪大学 東大阪大学短期大学部 敬愛女子高等学校 東大阪大学付属幼稚園)');
ok($zip->set_number('5778575')->is_valid_number, '(株) ダイモ');
ok($zip->set_number('5778577')->is_valid_number, '株式会社 丸金');
ok($zip->set_number('5778581')->is_valid_number, 'ミカミ工業 株式会社');
ok($zip->set_number('5778582')->is_valid_number, 'トーコー 株式会社');
ok($zip->set_number('5778585')->is_valid_number, '布施公共職業安定所 (ハローワーク布施)');
ok($zip->set_number('5778588')->is_valid_number, '井上定 株式会社');
ok($zip->set_number('5788501')->is_valid_number, 'トラスコ中山 株式会社 大阪支店');
ok($zip->set_number('5788502')->is_valid_number, '大阪ガス 株式会社 北東部事業本部');
ok($zip->set_number('5788511')->is_valid_number, '株式会社 日伝');
ok($zip->set_number('5788515')->is_valid_number, 'ホーチキ 株式会社');
ok($zip->set_number('5788522')->is_valid_number, '株式会社 不二越 西日本支社');
ok($zip->set_number('5788533')->is_valid_number, '株式会社 日伝 西部物流センター');
ok($zip->set_number('5788535')->is_valid_number, 'サンコーインダストリー 株式会社');
ok($zip->set_number('5788555')->is_valid_number, 'トラスコ中山 株式会社');
ok($zip->set_number('5788577')->is_valid_number, '白子 株式会社 大阪支店');
ok($zip->set_number('5788585')->is_valid_number, 'タツタ電線 株式会社');
ok($zip->set_number('5788588')->is_valid_number, '地方独立行政法人 市立東大阪医療センター');
ok($zip->set_number('5798502')->is_valid_number, '三浦工業 株式会社');
ok($zip->set_number('5808501')->is_valid_number, '松原市役所');
ok($zip->set_number('5808502')->is_valid_number, '阪南大学');
ok($zip->set_number('5808503')->is_valid_number, '藤本製薬 株式会社');
ok($zip->set_number('5808504')->is_valid_number, '山崎製パン 株式会社 大阪第二工場');
ok($zip->set_number('5808505')->is_valid_number, '株式会社 犬印本舗');
ok($zip->set_number('5808601')->is_valid_number, 'シャディ 株式会社');
ok($zip->set_number('5818502')->is_valid_number, 'JP楽天ロジスティクス 株式会社 楽天フルフィルメントセンター八尾');
ok($zip->set_number('5818505')->is_valid_number, '三起商行 株式会社');
ok($zip->set_number('5818511')->is_valid_number, '大阪経済法科大学');
ok($zip->set_number('5818539')->is_valid_number, '(株) ヤラカス舘 プロダクトセンター');
ok($zip->set_number('5818558')->is_valid_number, '株式会社 ミキハウス');
ok($zip->set_number('5818585')->is_valid_number, 'シャープ 株式会社 Smart Appliances&Solutions事業本部');
ok($zip->set_number('5818686')->is_valid_number, '株式会社 クボタ 久宝寺事業センター');
ok($zip->set_number('5828501')->is_valid_number, 'パナソニックサイクルテック 株式会社');
ok($zip->set_number('5828555')->is_valid_number, '柏原市役所');
ok($zip->set_number('5828582')->is_valid_number, '大阪教育大学');
ok($zip->set_number('5828585')->is_valid_number, '東大阪大学柏原高等学校');
ok($zip->set_number('5838501')->is_valid_number, '四天王寺大学');
ok($zip->set_number('5838522')->is_valid_number, 'シャープ 株式会社 藤井寺事業所');
ok($zip->set_number('5838533')->is_valid_number, 'アマゾン藤井寺フルフィルメントセンター');
ok($zip->set_number('5838534')->is_valid_number, 'アマゾン藤井寺FC');
ok($zip->set_number('5838535')->is_valid_number, 'アマゾン藤井寺FC KIX4');
ok($zip->set_number('5838550')->is_valid_number, 'ミツワ電機工業 株式会社');
ok($zip->set_number('5838555')->is_valid_number, '大阪公立大学 羽曳野キャンパス');
ok($zip->set_number('5838558')->is_valid_number, '大阪女子短期大学・大阪女子短期大学高等学校');
ok($zip->set_number('5838563')->is_valid_number, 'ニチバン 株式会社 大阪工場');
ok($zip->set_number('5838580')->is_valid_number, '太子町役場');
ok($zip->set_number('5838583')->is_valid_number, '藤井寺市役所');
ok($zip->set_number('5838585')->is_valid_number, '羽曳野市役所');
ok($zip->set_number('5838588')->is_valid_number, '大阪府立 羽曳野病院');
ok($zip->set_number('5848511')->is_valid_number, '富田林市役所');
ok($zip->set_number('5848522')->is_valid_number, '大阪大谷短期大学');
ok($zip->set_number('5848531')->is_valid_number, '大阪府 南河内府税事務所');
ok($zip->set_number('5848540')->is_valid_number, '大阪大谷大学');
ok($zip->set_number('5848585')->is_valid_number, '医療法人 宝生会PL病院');
ok($zip->set_number('5848651')->is_valid_number, 'パーフェクトリバティー教団 (PL)大本庁');
ok($zip->set_number('5858501')->is_valid_number, '千早赤阪村役場');
ok($zip->set_number('5858550')->is_valid_number, '大阪芸術大学 通信教育部');
ok($zip->set_number('5858555')->is_valid_number, '大阪芸術大学');
ok($zip->set_number('5858585')->is_valid_number, '河南町役場');
ok($zip->set_number('5868501')->is_valid_number, '河内長野市役所');
ok($zip->set_number('5868511')->is_valid_number, '大阪千代田短期大学');
ok($zip->set_number('5868521')->is_valid_number, '独立行政法人 国立病院機構 大阪南医療センター');
ok($zip->set_number('5868528')->is_valid_number, '(株) 吉年');
ok($zip->set_number('5868555')->is_valid_number, 'モリ工業 株式会社');
ok($zip->set_number('5868577')->is_valid_number, '学校法人 千代田学園');
ok($zip->set_number('5868585')->is_valid_number, '学校法人 清教学園');
ok($zip->set_number('5878555')->is_valid_number, '学校法人 天満学園 太成学院大学');
ok($zip->set_number('5878577')->is_valid_number, '三井ショッピングパーク ららぽーと堺');
ok($zip->set_number('5878585')->is_valid_number, '美原区役所');
ok($zip->set_number('5878586')->is_valid_number, '美原区役所 別館');
ok($zip->set_number('5898501')->is_valid_number, '大阪狭山市役所');
ok($zip->set_number('5898502')->is_valid_number, '象印チェンブロック 株式会社');
ok($zip->set_number('5898511')->is_valid_number, '近畿大学医学部付属病院');
ok($zip->set_number('5898585')->is_valid_number, '帝塚山学院大学');
ok($zip->set_number('5900481')->is_valid_number, '原子燃料工業 株式会社 熊取事業所');
ok($zip->set_number('5900482')->is_valid_number, '関西鍼灸大学');
ok($zip->set_number('5900493')->is_valid_number, '大阪観光大学');
ok($zip->set_number('5900494')->is_valid_number, '京都大学 原子炉実験所');
ok($zip->set_number('5900495')->is_valid_number, '熊取町役場');
ok($zip->set_number('5900496')->is_valid_number, '学校法人 浪商学園大阪体育大学');
ok($zip->set_number('5900592')->is_valid_number, '大阪府泉南市役所');
ok($zip->set_number('5908501')->is_valid_number, '堺市役所・堺区役所');
ok($zip->set_number('5908502')->is_valid_number, '堺化学工業 株式会社');
ok($zip->set_number('5908503')->is_valid_number, 'コーニングジャパン 株式会社 堺工場');
ok($zip->set_number('5908505')->is_valid_number, '社会医療法人 同仁会 耳原総合病院');
ok($zip->set_number('5908511')->is_valid_number, '大阪地方裁判所 堺支部');
ok($zip->set_number('5908515')->is_valid_number, '関西大学 堺キャンパス');
ok($zip->set_number('5908517')->is_valid_number, '大陽日酸 株式会社 堺浜ファインガスセンター');
ok($zip->set_number('5908522')->is_valid_number, 'シャープ 株式会社 本社・堺事業所');
ok($zip->set_number('5908527')->is_valid_number, 'ナガセケムテックス 株式会社 堺工場');
ok($zip->set_number('5908528')->is_valid_number, '長瀬産業 株式会社 堺営業所');
ok($zip->set_number('5908529')->is_valid_number, '株式会社 堺ガスセンター');
ok($zip->set_number('5908530')->is_valid_number, '生活情報サンロクマル事業部');
ok($zip->set_number('5908531')->is_valid_number, '大阪地方検察庁 堺支部');
ok($zip->set_number('5908540')->is_valid_number, '日本製鉄 株式会社 関西製鉄所');
ok($zip->set_number('5908550')->is_valid_number, '堺税務署');
ok($zip->set_number('5908551')->is_valid_number, 'コニカミノルタ 株式会社 堺サイト');
ok($zip->set_number('5908560')->is_valid_number, '大阪法務局 堺支局');
ok($zip->set_number('5908567')->is_valid_number, '株式会社 泉州銀行 事務統括部');
ok($zip->set_number('5908568')->is_valid_number, 'トラスコ中山 株式会社 プラネット大阪');
ok($zip->set_number('5908576')->is_valid_number, '堺アルミ 株式会社');
ok($zip->set_number('5908577')->is_valid_number, '株式会社 シマノ');
ok($zip->set_number('5908585')->is_valid_number, 'EH 株式会社');
ok($zip->set_number('5908588')->is_valid_number, '真諭商 株式会社');
ok($zip->set_number('5908589')->is_valid_number, 'アマゾン 堺FC 入庫係');
ok($zip->set_number('5908686')->is_valid_number, 'サマーウッド 株式会社');
ok($zip->set_number('5918501')->is_valid_number, '大阪労災病院');
ok($zip->set_number('5918502')->is_valid_number, '堺商工会議所');
ok($zip->set_number('5918505')->is_valid_number, '堺市上下水道局');
ok($zip->set_number('5918511')->is_valid_number, 'ダイキン工業 株式会社 堺製作所 金岡工場');
ok($zip->set_number('5918555')->is_valid_number, '国立療養所 近畿中央病院');
ok($zip->set_number('5918701')->is_valid_number, '堺市市民税管理課 特別徴収係');
ok($zip->set_number('5928550')->is_valid_number, 'ENEOS 株式会社 堺製油所');
ok($zip->set_number('5928585')->is_valid_number, '高石市役所');
ok($zip->set_number('5938504')->is_valid_number, '堺市立総合医療センター');
ok($zip->set_number('5941192')->is_valid_number, '株式会社 国華園');
ok($zip->set_number('5941198')->is_valid_number, '桃山学院大学');
ok($zip->set_number('5948501')->is_valid_number, '和泉市役所');
ok($zip->set_number('5948502')->is_valid_number, '自衛隊 信太山駐屯地');
ok($zip->set_number('5948686')->is_valid_number, '村中医療器 株式会社 総合センター');
ok($zip->set_number('5958555')->is_valid_number, '株式会社 GNN');
ok($zip->set_number('5958585')->is_valid_number, '泉大津税務署');
ok($zip->set_number('5958650')->is_valid_number, '住友ゴム工業 泉大津工場');
ok($zip->set_number('5958686')->is_valid_number, '泉大津市役所');
ok($zip->set_number('5968510')->is_valid_number, '岸和田市役所');
ok($zip->set_number('5968522')->is_valid_number, '医療法人徳洲会 岸和田徳洲会病院');
ok($zip->set_number('5968588')->is_valid_number, 'フジ住宅 株式会社');
ok($zip->set_number('5968624')->is_valid_number, 'フジ住宅 株式会社');
ok($zip->set_number('5968654')->is_valid_number, '株式会社 泉州銀行 本店');
ok($zip->set_number('5968686')->is_valid_number, '泉州信用金庫 本部');
ok($zip->set_number('5978501')->is_valid_number, '株式会社 デザック二色浜製造所');
ok($zip->set_number('5978502')->is_valid_number, '根来産業 株式会社');
ok($zip->set_number('5978511')->is_valid_number, '寺田紡績 株式会社');
ok($zip->set_number('5978515')->is_valid_number, '奥本製粉 株式会社');
ok($zip->set_number('5978522')->is_valid_number, 'マルフク事業 協同組合');
ok($zip->set_number('5978555')->is_valid_number, '住友重機械ギヤボックス 株式会社');
ok($zip->set_number('5978585')->is_valid_number, '貝塚市役所');
ok($zip->set_number('5978588')->is_valid_number, '宮崎鉄工 株式会社');
ok($zip->set_number('5978686')->is_valid_number, '日本年金機構 貝塚年金事務所');
ok($zip->set_number('5988503')->is_valid_number, '泉佐野 税務署');
ok($zip->set_number('5988508')->is_valid_number, 'りんくうプレミアム・アウトレット メインサイド');
ok($zip->set_number('5988509')->is_valid_number, 'りんくうプレミアム・アウトレット シーサイド');
ok($zip->set_number('5988511')->is_valid_number, 'スターゲイトホテル関西エアポート');
ok($zip->set_number('5988522')->is_valid_number, '関西エアポートワシントンホテル');
ok($zip->set_number('5988531')->is_valid_number, '大阪府立大学 りんくうキャンパス');
ok($zip->set_number('5988540')->is_valid_number, '不二製油 株式会社 阪南事業所');
ok($zip->set_number('5988550')->is_valid_number, '泉佐野市役所');
ok($zip->set_number('5988555')->is_valid_number, 'りんくうパピリオ管理事務所');
ok($zip->set_number('5988560')->is_valid_number, '大阪府立 佐野工業高等学校');
ok($zip->set_number('5988566')->is_valid_number, 'ジェイコムウエストメディア事業部りんくうサブセンター');
ok($zip->set_number('5990292')->is_valid_number, '阪南市役所');
ok($zip->set_number('5990392')->is_valid_number, '岬町役場');
ok($zip->set_number('5998531')->is_valid_number, '大阪府立大学');
ok($zip->set_number('6008501')->is_valid_number, '浄土真宗本願寺派宗務所');
ok($zip->set_number('6008502')->is_valid_number, '株式会社 京都西川');
ok($zip->set_number('6008503')->is_valid_number, '株式会社 井筒法衣店');
ok($zip->set_number('6008505')->is_valid_number, '真宗大谷派 (東本願寺) 宗務所');
ok($zip->set_number('6008506')->is_valid_number, '関西電力 株式会社');
ok($zip->set_number('6008511')->is_valid_number, '株式会社 大丸松坂屋百貨店 大丸京都店');
ok($zip->set_number('6008519')->is_valid_number, '株式会社 京都東急ホテル');
ok($zip->set_number('6008520')->is_valid_number, '株式会社 高島屋 京都店');
ok($zip->set_number('6008522')->is_valid_number, '全国健康保険協会 京都支部');
ok($zip->set_number('6008525')->is_valid_number, '株式会社 JTB 西日本団体旅行 京都支店');
ok($zip->set_number('6008526')->is_valid_number, '(株) JTB西日本 団体旅行京都支店');
ok($zip->set_number('6008530')->is_valid_number, 'オムロン (株) 京都事業所');
ok($zip->set_number('6008533')->is_valid_number, '京都産業大学 むすびわざ館');
ok($zip->set_number('6008544')->is_valid_number, 'C.C');
ok($zip->set_number('6008550')->is_valid_number, '株式会社 日本保証');
ok($zip->set_number('6008555')->is_valid_number, '株式会社 ジェイアール西日本伊勢丹');
ok($zip->set_number('6008558')->is_valid_number, '医療法人 財団康生会 武田病院');
ok($zip->set_number('6008565')->is_valid_number, '京都商工会議所');
ok($zip->set_number('6008566')->is_valid_number, '株式会社 エフエム京都');
ok($zip->set_number('6008567')->is_valid_number, '株式会社 丸井 京都マルイ');
ok($zip->set_number('6008570')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('6008577')->is_valid_number, '京都産業大学附属中学校・高等学校');
ok($zip->set_number('6008581')->is_valid_number, '京つけもの 西利');
ok($zip->set_number('6008585')->is_valid_number, '公益財団法人 日本漢字能力検定協会');
ok($zip->set_number('6008586')->is_valid_number, '株式会社 京都パープルサンガ');
ok($zip->set_number('6008588')->is_valid_number, '京都市下京区役所');
ok($zip->set_number('6008652')->is_valid_number, '株式会社 京都銀行');
ok($zip->set_number('6008665')->is_valid_number, '京都中央信用金庫');
ok($zip->set_number('6008686')->is_valid_number, 'タキイ種苗 株式会社');
ok($zip->set_number('6008688')->is_valid_number, '宝ホールディングス 株式会社');
ok($zip->set_number('6008711')->is_valid_number, '株式会社 ジェイアール西日本伊勢丹');
ok($zip->set_number('6008787')->is_valid_number, '京都地域センター');
ok($zip->set_number('6008792')->is_valid_number, '京都サービスセンター');
ok($zip->set_number('6010292')->is_valid_number, '京都市 京北合同庁舎');
ok($zip->set_number('6010797')->is_valid_number, '南丹市役所美山支所');
ok($zip->set_number('6011192')->is_valid_number, '株式会社 川島織物セルコン 市原事業所');
ok($zip->set_number('6011397')->is_valid_number, '京都市伏見区役所 醍醐支所');
ok($zip->set_number('6011495')->is_valid_number, '医療法人 医仁会 武田総合病院');
ok($zip->set_number('6018501')->is_valid_number, '任天堂 株式会社');
ok($zip->set_number('6018502')->is_valid_number, '任天堂 株式会社');
ok($zip->set_number('6018506')->is_valid_number, '株式会社 ワコール 新京都ビル');
ok($zip->set_number('6018510')->is_valid_number, '株式会社 堀場製作所');
ok($zip->set_number('6018511')->is_valid_number, '京都市南区役所');
ok($zip->set_number('6018520')->is_valid_number, '株式会社 GSユアサ');
ok($zip->set_number('6018530')->is_valid_number, '株式会社 ワコール');
ok($zip->set_number('6018533')->is_valid_number, '株式会社 三笑堂');
ok($zip->set_number('6018542')->is_valid_number, 'NTTファイナンス 株式会社 西日本みやこ料金センター');
ok($zip->set_number('6018550')->is_valid_number, '日本新薬 株式会社');
ok($zip->set_number('6018559')->is_valid_number, '西日本電信電話 株式会社 京都支店 京都116センタ みやこIPコールセンタ');
ok($zip->set_number('6018560')->is_valid_number, '株式会社 きんでん 京都支店');
ok($zip->set_number('6018588')->is_valid_number, '橋爪食品 株式会社');
ok($zip->set_number('6018601')->is_valid_number, 'イオンモール京都桂川');
ok($zip->set_number('6028501')->is_valid_number, 'NHK 京都放送局');
ok($zip->set_number('6028510')->is_valid_number, '京都地方検察庁');
ok($zip->set_number('6028511')->is_valid_number, '上京区役所');
ok($zip->set_number('6028520')->is_valid_number, '株式会社 播磨屋本店');
ok($zip->set_number('6028555')->is_valid_number, '上京 税務署');
ok($zip->set_number('6028566')->is_valid_number, '京都府立 医科大学');
ok($zip->set_number('6028570')->is_valid_number, '京都府庁');
ok($zip->set_number('6028580')->is_valid_number, '同志社大学・学校法人 同志社法人部');
ok($zip->set_number('6028585')->is_valid_number, '株式会社 SCREENグラフィックアンドプレシジョンソリューションズ');
ok($zip->set_number('6028585')->is_valid_number, '株式会社 SCREENセミコンダクターソリューションズ');
ok($zip->set_number('6028585')->is_valid_number, '株式会社 SCREENビジネスサポートソリューションズ');
ok($zip->set_number('6028585')->is_valid_number, '株式会社 SCREENファインテックソリューションズ');
ok($zip->set_number('6028585')->is_valid_number, '株式会社 SCREENホールディングス');
ok($zip->set_number('6028585')->is_valid_number, '株式会社 SCREENマニファクチャリングサポートソリューションズ');
ok($zip->set_number('6028588')->is_valid_number, 'KBS京都');
ok($zip->set_number('6028602')->is_valid_number, 'ワタベウェディング 株式会社');
ok($zip->set_number('6028611')->is_valid_number, '宮内庁 京都事務所');
ok($zip->set_number('6038511')->is_valid_number, '京都市北区役所');
ok($zip->set_number('6038522')->is_valid_number, '日本年金機構 上京年金事務所');
ok($zip->set_number('6038555')->is_valid_number, '京都産業大学');
ok($zip->set_number('6038577')->is_valid_number, '立命館大学');
ok($zip->set_number('6038588')->is_valid_number, '株式会社 淡交社');
ok($zip->set_number('6048501')->is_valid_number, '中京税務署');
ok($zip->set_number('6048502')->is_valid_number, '京都国際ホテル');
ok($zip->set_number('6048505')->is_valid_number, '株式会社 OPA 河原町オーパ');
ok($zip->set_number('6048508')->is_valid_number, '全国健康保険協会 京都支部');
ok($zip->set_number('6048510')->is_valid_number, '日本年金機構 中京年金事務所');
ok($zip->set_number('6048511')->is_valid_number, '株式会社 島津製作所');
ok($zip->set_number('6048515')->is_valid_number, '日本放送協会 京都放送局');
ok($zip->set_number('6048520')->is_valid_number, '学校法人 立命館');
ok($zip->set_number('6048550')->is_valid_number, '京都地方裁判所');
ok($zip->set_number('6048551')->is_valid_number, 'NISSHA 株式会社');
ok($zip->set_number('6048555')->is_valid_number, '京都新聞企画事業 株式会社 (週刊T&T)');
ok($zip->set_number('6048556')->is_valid_number, '株式会社 京都新聞印刷');
ok($zip->set_number('6048558')->is_valid_number, '株式会社 京都ホテル');
ok($zip->set_number('6048560')->is_valid_number, '株式会社 京都リビング新聞社');
ok($zip->set_number('6048567')->is_valid_number, '株式会社 京都新聞COM');
ok($zip->set_number('6048571')->is_valid_number, '京都市役所');
ok($zip->set_number('6048577')->is_valid_number, '京都新聞社');
ok($zip->set_number('6048578')->is_valid_number, '京都新聞企画事業 株式会社');
ok($zip->set_number('6048580')->is_valid_number, '上原成商事 株式会社');
ok($zip->set_number('6048585')->is_valid_number, '社団法人 京都府医師会');
ok($zip->set_number('6048588')->is_valid_number, '中京区役所');
ok($zip->set_number('6048666')->is_valid_number, '日本銀行 京都支店');
ok($zip->set_number('6058501')->is_valid_number, '学校法人 京都女子学園(京都女子大学・京都女子短期大学部・京都女子高等学校・京都女子中学校・京都女子大学附属小学校・京都幼稚園)');
ok($zip->set_number('6058511')->is_valid_number, '東山区役所');
ok($zip->set_number('6058686')->is_valid_number, '宗教法人 知恩院');
ok($zip->set_number('6068501')->is_valid_number, '京都大学');
ok($zip->set_number('6068502')->is_valid_number, '京都大学農学部、農学部附属演習林、大学院理学研究科、理学部、基礎物理学研究所、数理解析研究所');
ok($zip->set_number('6068505')->is_valid_number, '京都宝ヶ池プリンスホテル');
ok($zip->set_number('6068507')->is_valid_number, '京都大学医学部附属病院、胸部疾患研究所、ウイルス研究所、生体医療工学研究センター、遺伝子実験施設、医療技術短期大学部');
ok($zip->set_number('6068511')->is_valid_number, '京都市左京区役所');
ok($zip->set_number('6068522')->is_valid_number, '京都府立大学');
ok($zip->set_number('6068536')->is_valid_number, '(財) 京都市国際交流協会');
ok($zip->set_number('6068540')->is_valid_number, '北斗プリント社');
ok($zip->set_number('6068555')->is_valid_number, '左京税務署');
ok($zip->set_number('6068558')->is_valid_number, '同志社中学校・高等学校');
ok($zip->set_number('6068585')->is_valid_number, '京都工芸繊維大学');
ok($zip->set_number('6068588')->is_valid_number, '京都精華大学');
ok($zip->set_number('6078501')->is_valid_number, '株式会社 新学社');
ok($zip->set_number('6078511')->is_valid_number, '京都市 山科区役所');
ok($zip->set_number('6078571')->is_valid_number, '全家研ポピー');
ok($zip->set_number('6100192')->is_valid_number, '星和電機 株式会社');
ok($zip->set_number('6100195')->is_valid_number, '城陽市役所');
ok($zip->set_number('6100196')->is_valid_number, '城陽商工会議所');
ok($zip->set_number('6100281')->is_valid_number, '株式会社 宇治田原製茶場');
ok($zip->set_number('6100287')->is_valid_number, '須河車体 株式会社');
ok($zip->set_number('6100289')->is_valid_number, '宇治田原町役場');
ok($zip->set_number('6100380')->is_valid_number, '株式会社 椿本チエイン 京田辺工場');
ok($zip->set_number('6100393')->is_valid_number, '京田辺市役所');
ok($zip->set_number('6100394')->is_valid_number, '同志社大学');
ok($zip->set_number('6100395')->is_valid_number, '同志社女子大学');
ok($zip->set_number('6100396')->is_valid_number, 'ワタキューセイモア 株式会社');
ok($zip->set_number('6100397')->is_valid_number, 'アマゾン京田辺FC');
ok($zip->set_number('6101192')->is_valid_number, '国際日本文化研究センター');
ok($zip->set_number('6101195')->is_valid_number, '京都経済短期大学 (学校法人 明徳学園)');
ok($zip->set_number('6101197')->is_valid_number, '京都市立芸術大学');
ok($zip->set_number('6101198')->is_valid_number, '京都市西京区役所 洛西支所');
ok($zip->set_number('6118501')->is_valid_number, '宇治市役所');
ok($zip->set_number('6118555')->is_valid_number, 'ユニチカ 株式会社 宇治事業所');
ok($zip->set_number('6118585')->is_valid_number, '松下電子部品 株式会社 コンデンサ事業部');
ok($zip->set_number('6118660')->is_valid_number, '京都中央信用金庫 宇治支店');
ok($zip->set_number('6128501')->is_valid_number, '京セラ 株式会社');
ok($zip->set_number('6128511')->is_valid_number, '京都市伏見区役所');
ok($zip->set_number('6128515')->is_valid_number, '伏見区役所 深草支所');
ok($zip->set_number('6128522')->is_valid_number, '京都教育大学');
ok($zip->set_number('6128530')->is_valid_number, '株式会社 ワコールウイングブランド事業部');
ok($zip->set_number('6128533')->is_valid_number, '株式会社 モリタ製作所');
ok($zip->set_number('6128550')->is_valid_number, '株式会社 近鉄百貨店 桃山店');
ok($zip->set_number('6128555')->is_valid_number, '独立行政法人 国立病院機構 京都医療センター');
ok($zip->set_number('6128558')->is_valid_number, '日本年金機構 京都南年金事務所');
ok($zip->set_number('6128577')->is_valid_number, '龍谷大学');
ok($zip->set_number('6128585')->is_valid_number, '株式会社 京都自動車会館');
ok($zip->set_number('6128602')->is_valid_number, '佐川グローバルロジスティクス 株式会社');
ok($zip->set_number('6128660')->is_valid_number, '月桂冠 株式会社');
ok($zip->set_number('6128677')->is_valid_number, '京都府自動車税管理事務所');
ok($zip->set_number('6128686')->is_valid_number, '村田機械 株式会社');
ok($zip->set_number('6138585')->is_valid_number, '久御山町役場');
ok($zip->set_number('6148501')->is_valid_number, '八幡市役所');
ok($zip->set_number('6148511')->is_valid_number, '城南衛生管理組合');
ok($zip->set_number('6148588')->is_valid_number, '石清水八幡宮');
ok($zip->set_number('6158501')->is_valid_number, '株式会社 たけびし');
ok($zip->set_number('6158510')->is_valid_number, '京都大学 大学院 工学研究科 Aクラスター');
ok($zip->set_number('6158511')->is_valid_number, '京都西社会保険事務所');
ok($zip->set_number('6158520')->is_valid_number, '京都大学 国際融合創造センター');
ok($zip->set_number('6158522')->is_valid_number, '京都市西京区役所');
ok($zip->set_number('6158530')->is_valid_number, '京都大学大学院 工学研究科Bクラスター');
ok($zip->set_number('6158540')->is_valid_number, '京都大学大学院 工学研究科Cクラスター');
ok($zip->set_number('6158555')->is_valid_number, 'サンコール 株式会社');
ok($zip->set_number('6158558')->is_valid_number, '株式会社 京都外大パートナーズ');
ok($zip->set_number('6158558')->is_valid_number, '京都外国語大学');
ok($zip->set_number('6158577')->is_valid_number, '学校法人 京都学園');
ok($zip->set_number('6158585')->is_valid_number, 'ローム 株式会社');
ok($zip->set_number('6158666')->is_valid_number, '明成化学工業 株式会社');
ok($zip->set_number('6158686')->is_valid_number, '日新電機 株式会社');
ok($zip->set_number('6168501')->is_valid_number, '三菱自動車工業 株式会社 パワートレイン製作所');
ok($zip->set_number('6168511')->is_valid_number, '京都市右京区役所');
ok($zip->set_number('6168533')->is_valid_number, '大日本印刷 株式会社 京都工場');
ok($zip->set_number('6168555')->is_valid_number, '日本クリニック 株式会社');
ok($zip->set_number('6168566')->is_valid_number, '美空ひばり館');
ok($zip->set_number('6168585')->is_valid_number, 'ハマナカ 株式会社');
ok($zip->set_number('6168586')->is_valid_number, '東映太秦映画村');
ok($zip->set_number('6168666')->is_valid_number, '京都市証明郵送センター');
ok($zip->set_number('6178501')->is_valid_number, '長岡京市役所');
ok($zip->set_number('6178511')->is_valid_number, '(株) 工進');
ok($zip->set_number('6178520')->is_valid_number, 'ヌヴォトン テクノロジージャパン 株式会社');
ok($zip->set_number('6178530')->is_valid_number, 'サントリー 株式会社 桂ビール工場');
ok($zip->set_number('6178550')->is_valid_number, '三菱電機 株式会社 AV統括事業部');
ok($zip->set_number('6178551')->is_valid_number, 'エイエムジー 株式会社');
ok($zip->set_number('6178555')->is_valid_number, '株式会社 村田製作所');
ok($zip->set_number('6178566')->is_valid_number, '株式会社 村田製作所 長岡事業所');
ok($zip->set_number('6178577')->is_valid_number, '立命館中学校・高等学校');
ok($zip->set_number('6178585')->is_valid_number, '日本輸送機 株式会社');
ok($zip->set_number('6178588')->is_valid_number, '佐川印刷 株式会社');
ok($zip->set_number('6178617')->is_valid_number, '社会福祉法人 恩賜財団済生会 京都済生会病院');
ok($zip->set_number('6178665')->is_valid_number, '向日市役所');
ok($zip->set_number('6178666')->is_valid_number, '三菱製紙 株式会社 京都工場');
ok($zip->set_number('6178772')->is_valid_number, '向日市役所 東向日別館');
ok($zip->set_number('6188501')->is_valid_number, '大山崎町役場');
ok($zip->set_number('6188502')->is_valid_number, '大阪青凌中学校・高等学校');
ok($zip->set_number('6188511')->is_valid_number, '日立建機 株式会社 西日本事業部');
ok($zip->set_number('6188518')->is_valid_number, '社会福祉法人 大阪水上隣保館');
ok($zip->set_number('6188525')->is_valid_number, '日立マクセル 株式会社 アドバンスドテープ事業部・二次電池事業部');
ok($zip->set_number('6188555')->is_valid_number, '株式会社 NEOMAX');
ok($zip->set_number('6188558')->is_valid_number, 'マクセル精器 株式会社');
ok($zip->set_number('6188567')->is_valid_number, '株式会社 東亜セイコー');
ok($zip->set_number('6188570')->is_valid_number, '島本町役場');
ok($zip->set_number('6188585')->is_valid_number, '小野薬品工業 株式会社 水無瀬総合研究所');
ok($zip->set_number('6190280')->is_valid_number, '木津川市役所 山城支所');
ok($zip->set_number('6190282')->is_valid_number, '私のしごと館');
ok($zip->set_number('6190283')->is_valid_number, 'オムロン 株式会社 京阪奈イノベーションセンタ');
ok($zip->set_number('6190284')->is_valid_number, 'サントリーワールドリサーチセンター');
ok($zip->set_number('6190285')->is_valid_number, '精華町役場');
ok($zip->set_number('6190286')->is_valid_number, '木津川市役所');
ok($zip->set_number('6190287')->is_valid_number, '国立国会図書館 関西館');
ok($zip->set_number('6190288')->is_valid_number, '(株) 国際電気通信基礎技術研究所');
ok($zip->set_number('6190289')->is_valid_number, '独立行政法人 情報通信研究機構');
ok($zip->set_number('6190292')->is_valid_number, '財団法人 地球環境産業技術研究機構');
ok($zip->set_number('6190294')->is_valid_number, '関西文化学術研究都市(京都府精華・西木津地区)けいはんなオープンイノベーションセンター(KICK)');
ok($zip->set_number('6190295')->is_valid_number, '株式会社 福寿園');
ok($zip->set_number('6191195')->is_valid_number, '木津川市役所 加茂支所');
ok($zip->set_number('6191295')->is_valid_number, '和束町役場');
ok($zip->set_number('6191393')->is_valid_number, '笠置町役場');
ok($zip->set_number('6201492')->is_valid_number, '福知山市役所 三和支所');
ok($zip->set_number('6201493')->is_valid_number, '京都機械 株式会社');
ok($zip->set_number('6208501')->is_valid_number, '福知山市役所');
ok($zip->set_number('6208502')->is_valid_number, '陸上自衛隊');
ok($zip->set_number('6208503')->is_valid_number, '株式会社 さとう');
ok($zip->set_number('6208504')->is_valid_number, 'JR西日本 福知山支社');
ok($zip->set_number('6208505')->is_valid_number, '市立福知山市民病院');
ok($zip->set_number('6208506')->is_valid_number, '京都ルネス病院');
ok($zip->set_number('6208507')->is_valid_number, '株式会社 雪印アクセス 北近畿支店');
ok($zip->set_number('6208508')->is_valid_number, '有限会社 えいと');
ok($zip->set_number('6218501')->is_valid_number, '亀岡市役所');
ok($zip->set_number('6218555')->is_valid_number, '京都学園大学');
ok($zip->set_number('6218585')->is_valid_number, '亀岡市立病院');
ok($zip->set_number('6218686')->is_valid_number, '宗教法人 大本');
ok($zip->set_number('6220292')->is_valid_number, '京丹波町役場');
ok($zip->set_number('6228651')->is_valid_number, '南丹市役所');
ok($zip->set_number('6238501')->is_valid_number, '綾部市役所');
ok($zip->set_number('6238588')->is_valid_number, '京セラ 株式会社');
ok($zip->set_number('6248555')->is_valid_number, '日本年金機構 舞鶴年金事務所');
ok($zip->set_number('6248686')->is_valid_number, '第八管区海上保安本部');
ok($zip->set_number('6258501')->is_valid_number, '日立造船 株式会社 舞鶴工場');
ok($zip->set_number('6258502')->is_valid_number, '独立行政法人 国立病院機構 舞鶴医療センター');
ok($zip->set_number('6258503')->is_valid_number, '海上保安学校');
ok($zip->set_number('6258510')->is_valid_number, '海上自衛隊 舞鶴地方総監部');
ok($zip->set_number('6258511')->is_valid_number, '舞鶴工業高等専門学校');
ok($zip->set_number('6258555')->is_valid_number, '舞鶴市役所');
ok($zip->set_number('6258585')->is_valid_number, '舞鶴共済病院');
ok($zip->set_number('6258666')->is_valid_number, '日本板硝子 株式会社 舞鶴工場');
ok($zip->set_number('6260493')->is_valid_number, '伊根町役場');
ok($zip->set_number('6268501')->is_valid_number, '宮津市役所');
ok($zip->set_number('6268510')->is_valid_number, '宮津ロイヤルホテル');
ok($zip->set_number('6268571')->is_valid_number, '宮津 税務署');
ok($zip->set_number('6278555')->is_valid_number, '財団法人 丹後中央病院');
ok($zip->set_number('6278567')->is_valid_number, '京丹後市役所');
ok($zip->set_number('6278570')->is_valid_number, '京都府 丹後広域振興局');
ok($zip->set_number('6278688')->is_valid_number, '京都府立 峰山高等学校');
ok($zip->set_number('6290192')->is_valid_number, '泰宏商事');
ok($zip->set_number('6290196')->is_valid_number, '公立 南丹看護専門学校');
ok($zip->set_number('6290197')->is_valid_number, '京都中部総合医療センター');
ok($zip->set_number('6290198')->is_valid_number, '南丹市役所 八木支所');
ok($zip->set_number('6290392')->is_valid_number, '明治国際医療大学');
ok($zip->set_number('6290398')->is_valid_number, '南丹市役所 日吉支所');
ok($zip->set_number('6291192')->is_valid_number, '京丹波町 和知支所');
ok($zip->set_number('6292292')->is_valid_number, '与謝野町役場');
ok($zip->set_number('6292498')->is_valid_number, '与謝野町 加悦庁舎');
ok($zip->set_number('6300192')->is_valid_number, '奈良先端科学技術大学院大学');
ok($zip->set_number('6300288')->is_valid_number, '生駒市役所');
ok($zip->set_number('6300292')->is_valid_number, '近鉄ケーブルネットワーク 株式会社');
ok($zip->set_number('6300293')->is_valid_number, '近畿大学 医学部 奈良病院');
ok($zip->set_number('6302192')->is_valid_number, '社会福祉法人史明会 ボイス');
ok($zip->set_number('6308501')->is_valid_number, '奈良県庁');
ok($zip->set_number('6308502')->is_valid_number, '奈良県 教育委員会');
ok($zip->set_number('6308503')->is_valid_number, '市民生活協同組合 ならコープ');
ok($zip->set_number('6308505')->is_valid_number, '西日本電信電話 株式会社 奈良支店');
ok($zip->set_number('6308506')->is_valid_number, '奈良女子大学');
ok($zip->set_number('6308508')->is_valid_number, '株式会社 ヒラサワ');
ok($zip->set_number('6308512')->is_valid_number, '日本年金機構 奈良年金事務所');
ok($zip->set_number('6308518')->is_valid_number, '近畿セキスイハイム工業 株式会社');
ok($zip->set_number('6308520')->is_valid_number, 'スケーター 株式会社');
ok($zip->set_number('6308522')->is_valid_number, '航空自衛隊 奈良基地');
ok($zip->set_number('6308528')->is_valid_number, '国立大学法人 奈良教育大学');
ok($zip->set_number('6308529')->is_valid_number, '社会保険診療報酬支払基金 奈良支部');
ok($zip->set_number('6308530')->is_valid_number, '関西電力 株式会社 奈良営業所');
ok($zip->set_number('6308533')->is_valid_number, '奈良警察署');
ok($zip->set_number('6308535')->is_valid_number, '全国健康保険協会 奈良支部');
ok($zip->set_number('6308536')->is_valid_number, '朝日新聞 奈良総局');
ok($zip->set_number('6308540')->is_valid_number, 'NHK 奈良放送局');
ok($zip->set_number('6308543')->is_valid_number, '住友生命保険 相互会社 奈良支社');
ok($zip->set_number('6308548')->is_valid_number, '関西電力 株式会社 奈良支店');
ok($zip->set_number('6308550')->is_valid_number, '奈良県農業協同組合中央会');
ok($zip->set_number('6308552')->is_valid_number, '奈良県 共済農業協同連合会');
ok($zip->set_number('6308555')->is_valid_number, '積水化学工業 株式会社 奈良事業所');
ok($zip->set_number('6308558')->is_valid_number, '学校法人 奈良育英学園 奈良育英中学校・高等学校');
ok($zip->set_number('6308563')->is_valid_number, '薬師寺');
ok($zip->set_number('6308566')->is_valid_number, '奈良佐保短期大学');
ok($zip->set_number('6308567')->is_valid_number, '奈良税務署');
ok($zip->set_number('6308570')->is_valid_number, '奈良労働局');
ok($zip->set_number('6308575')->is_valid_number, '奈良テレビ放送 株式会社');
ok($zip->set_number('6308577')->is_valid_number, '独立行政法人 国立文化財機構奈良文化財研究所');
ok($zip->set_number('6308578')->is_valid_number, '奈良県 警察本部');
ok($zip->set_number('6308580')->is_valid_number, '奈良市役所');
ok($zip->set_number('6308581')->is_valid_number, '地方独立行政法人 奈良県立病院機構 奈良県総合医療センター');
ok($zip->set_number('6308585')->is_valid_number, '日本自動車連盟奈良支部');
ok($zip->set_number('6308586')->is_valid_number, '奈良商工会議所');
ok($zip->set_number('6308587')->is_valid_number, '東大寺');
ok($zip->set_number('6308588')->is_valid_number, '草竹コンクリート工業 株式会社');
ok($zip->set_number('6308589')->is_valid_number, '放送大学奈良学習センター');
ok($zip->set_number('6308651')->is_valid_number, '奈良交通 株式会社');
ok($zip->set_number('6308655')->is_valid_number, '奈良県 信用農業協同組合連合会');
ok($zip->set_number('6308666')->is_valid_number, '大和証券 株式会社 奈良支店');
ok($zip->set_number('6308668')->is_valid_number, '奈良県信用保証協会');
ok($zip->set_number('6308670')->is_valid_number, '株式会社 呉竹');
ok($zip->set_number('6308677')->is_valid_number, '株式会社 南都銀行 本店');
ok($zip->set_number('6308686')->is_valid_number, '(株) 奈良新聞社');
ok($zip->set_number('6308688')->is_valid_number, '株式会社 南都銀行 事務センター');
ok($zip->set_number('6318501')->is_valid_number, '帝塚山大学');
ok($zip->set_number('6318502')->is_valid_number, '奈良大学');
ok($zip->set_number('6318503')->is_valid_number, '三和建設 株式会社');
ok($zip->set_number('6318505')->is_valid_number, '近畿大学 農学部');
ok($zip->set_number('6318511')->is_valid_number, '株式会社 近鉄百貨店 奈良店');
ok($zip->set_number('6318522')->is_valid_number, '奈良学園幼稚園・奈良学園小学校・奈良学園登美ヶ丘中学校・奈良学園登美ヶ丘高等学校');
ok($zip->set_number('6318523')->is_valid_number, '奈良文化女子短期大学');
ok($zip->set_number('6318524')->is_valid_number, '奈良学園大学 登美ヶ丘キャンパス');
ok($zip->set_number('6318555')->is_valid_number, '奈良大学附属高等学校');
ok($zip->set_number('6318585')->is_valid_number, '帝塚山短期大学');
ok($zip->set_number('6320292')->is_valid_number, '奈良市 都祁行政センター');
ok($zip->set_number('6328510')->is_valid_number, '天理大学');
ok($zip->set_number('6328540')->is_valid_number, '天理大学附属参考館');
ok($zip->set_number('6328552')->is_valid_number, '天理よろづ相談所');
ok($zip->set_number('6328555')->is_valid_number, '天理市役所');
ok($zip->set_number('6328558')->is_valid_number, '天理市 上下水道局');
ok($zip->set_number('6328567')->is_valid_number, 'シャープ 株式会社');
ok($zip->set_number('6328577')->is_valid_number, '天理大学附属図書館');
ok($zip->set_number('6328585')->is_valid_number, '天理高等学校');
ok($zip->set_number('6328587')->is_valid_number, '株式会社 花の大和');
ok($zip->set_number('6328588')->is_valid_number, '光洋サーモシステム 株式会社');
ok($zip->set_number('6328679')->is_valid_number, '天理教 一れつ会');
ok($zip->set_number('6328688')->is_valid_number, '天理教 少年会本部');
ok($zip->set_number('6330292')->is_valid_number, '宇陀市役所');
ok($zip->set_number('6330298')->is_valid_number, '宇陀市立病院');
ok($zip->set_number('6330392')->is_valid_number, '室生地域事務所');
ok($zip->set_number('6330398')->is_valid_number, '株式会社 室生ロイヤルカントリークラブ');
ok($zip->set_number('6332192')->is_valid_number, '宇陀市大宇陀地域事務所');
ok($zip->set_number('6332492')->is_valid_number, '東吉野村役場');
ok($zip->set_number('6338501')->is_valid_number, '桜井年金事務所');
ok($zip->set_number('6338538')->is_valid_number, '大神神社');
ok($zip->set_number('6338585')->is_valid_number, '桜井市役所');
ok($zip->set_number('6338686')->is_valid_number, '大和信用金庫');
ok($zip->set_number('6348501')->is_valid_number, '橿原警察署');
ok($zip->set_number('6348502')->is_valid_number, '奈良県医師会');
ok($zip->set_number('6348503')->is_valid_number, '奈良県 警察交通反則通告センター');
ok($zip->set_number('6348505')->is_valid_number, 'マルコ 株式会社 本社事務所');
ok($zip->set_number('6348506')->is_valid_number, '中南和県税事務所');
ok($zip->set_number('6348507')->is_valid_number, '奈良県中和保健所');
ok($zip->set_number('6348510')->is_valid_number, 'オカハシ 株式会社');
ok($zip->set_number('6348511')->is_valid_number, '株式会社 近鉄百貨店 橿原店');
ok($zip->set_number('6348521')->is_valid_number, '奈良県立医科大学');
ok($zip->set_number('6348522')->is_valid_number, '奈良県立医科大学付属病院');
ok($zip->set_number('6348523')->is_valid_number, '奈良県立医科大学付属図書館');
ok($zip->set_number('6348524')->is_valid_number, '奈良県立医科大学 看護短期大学部');
ok($zip->set_number('6348550')->is_valid_number, '橿原神宮');
ok($zip->set_number('6348551')->is_valid_number, '株式会社 タカギ');
ok($zip->set_number('6348555')->is_valid_number, '株式会社 ジェイテクト 奈良工場');
ok($zip->set_number('6348560')->is_valid_number, '大和平野土地改良区事務所');
ok($zip->set_number('6348561')->is_valid_number, '奈良県 市町村職員共済組合');
ok($zip->set_number('6348567')->is_valid_number, '佐藤薬品工業 株式会社');
ok($zip->set_number('6348580')->is_valid_number, '株式会社 タカトリ');
ok($zip->set_number('6348585')->is_valid_number, '三和澱粉工業 株式会社');
ok($zip->set_number('6348586')->is_valid_number, '橿原市役所');
ok($zip->set_number('6358501')->is_valid_number, '大和高田市立病院');
ok($zip->set_number('6358502')->is_valid_number, '奈良地方裁判所葛城支部・奈良家庭裁判所葛城支部・葛城簡易裁判所・葛城検察審査会');
ok($zip->set_number('6358511')->is_valid_number, '大和高田市役所');
ok($zip->set_number('6358515')->is_valid_number, '広陵町役場');
ok($zip->set_number('6358520')->is_valid_number, '浪華ゴム工業 株式会社');
ok($zip->set_number('6358528')->is_valid_number, '(株) ナカガワ');
ok($zip->set_number('6358530')->is_valid_number, '奈良文化高等学校');
ok($zip->set_number('6358585')->is_valid_number, 'ハローワーク大和高田 (大和高田公共職業安定所)');
ok($zip->set_number('6358787')->is_valid_number, '奈良地域センター');
ok($zip->set_number('6360192')->is_valid_number, '東洋シール工業 株式会社');
ok($zip->set_number('6360193')->is_valid_number, '株式会社 植嶋');
ok($zip->set_number('6360198')->is_valid_number, '斑鳩町役場');
ok($zip->set_number('6360292')->is_valid_number, '奈良トヨタ自動車 株式会社');
ok($zip->set_number('6360293')->is_valid_number, '株式会社 DNPデータテクノ');
ok($zip->set_number('6360294')->is_valid_number, '旭食品 株式会社 阪奈支店');
ok($zip->set_number('6360295')->is_valid_number, '株式会社 GMB');
ok($zip->set_number('6360298')->is_valid_number, '株式会社 カギオカ');
ok($zip->set_number('6360392')->is_valid_number, '田原本町役場');
ok($zip->set_number('6360393')->is_valid_number, '社会福祉法人 奈良県社会福祉事業団 奈良県心身障害者リハビリテーションセンター');
ok($zip->set_number('6360398')->is_valid_number, '奈良中央信用金庫');
ok($zip->set_number('6368501')->is_valid_number, '河合町役場');
ok($zip->set_number('6368503')->is_valid_number, '奈良産業大学');
ok($zip->set_number('6368511')->is_valid_number, '王寺町役場');
ok($zip->set_number('6368535')->is_valid_number, '三郷町役場');
ok($zip->set_number('6368555')->is_valid_number, 'FM西大和 (株) ・FMハイホー');
ok($zip->set_number('6368585')->is_valid_number, '平群町役場');
ok($zip->set_number('6368798')->is_valid_number, '近畿郵政研修センター');
ok($zip->set_number('6378501')->is_valid_number, '五條市役所');
ok($zip->set_number('6378511')->is_valid_number, '五條病院');
ok($zip->set_number('6380292')->is_valid_number, '黒滝村役場');
ok($zip->set_number('6380392')->is_valid_number, '天川村役場');
ok($zip->set_number('6388501')->is_valid_number, '大淀町役場');
ok($zip->set_number('6388510')->is_valid_number, '下市町役場');
ok($zip->set_number('6388521')->is_valid_number, '町立大淀病院');
ok($zip->set_number('6388551')->is_valid_number, '南和広域医療組合南奈良総合医療センター');
ok($zip->set_number('6388561')->is_valid_number, '南和広域医療組合南奈良看護専門学校');
ok($zip->set_number('6390292')->is_valid_number, '香芝市役所');
ok($zip->set_number('6390293')->is_valid_number, '上牧町役場');
ok($zip->set_number('6390298')->is_valid_number, '樟蔭女子短期大学');
ok($zip->set_number('6391080')->is_valid_number, '奈良工業高等専門学校');
ok($zip->set_number('6391081')->is_valid_number, '岩崎工業 株式会社');
ok($zip->set_number('6391082')->is_valid_number, '奈良信用金庫');
ok($zip->set_number('6391085')->is_valid_number, 'ニッタ 株式会社 奈良工場');
ok($zip->set_number('6391089')->is_valid_number, '株式会社 南都銀行 郡山支店');
ok($zip->set_number('6391093')->is_valid_number, '奈良学園');
ok($zip->set_number('6391095')->is_valid_number, '安堵町役場');
ok($zip->set_number('6391183')->is_valid_number, '株式会社 森精機製作所');
ok($zip->set_number('6391184')->is_valid_number, '奈良県自動車税事務所');
ok($zip->set_number('6391186')->is_valid_number, 'シャープ 株式会社');
ok($zip->set_number('6391188')->is_valid_number, 'パナソニック 株式会社 ホームアプライアンス社');
ok($zip->set_number('6391192')->is_valid_number, '奈良大果 株式会社');
ok($zip->set_number('6391196')->is_valid_number, '株式会社 奈良魚市');
ok($zip->set_number('6391197')->is_valid_number, '奈良中央青果 株式会社');
ok($zip->set_number('6391198')->is_valid_number, '大和郡山市役所');
ok($zip->set_number('6392195')->is_valid_number, '葛城市役所 新庄庁舎');
ok($zip->set_number('6392197')->is_valid_number, '葛城市役所 當麻庁舎');
ok($zip->set_number('6392198')->is_valid_number, 'シャープ 株式会社');
ok($zip->set_number('6392292')->is_valid_number, '塚本産業 株式会社');
ok($zip->set_number('6392295')->is_valid_number, '田村薬品工業 株式会社');
ok($zip->set_number('6392298')->is_valid_number, '御所市役所');
ok($zip->set_number('6393192')->is_valid_number, '吉野町役場');
ok($zip->set_number('6393594')->is_valid_number, '川上村役場');
ok($zip->set_number('6400492')->is_valid_number, '紀の川市 貴志川支所');
ok($zip->set_number('6401192')->is_valid_number, '紀美野町役場');
ok($zip->set_number('6401196')->is_valid_number, '株式会社 クロシオ');
ok($zip->set_number('6408501')->is_valid_number, '和歌山県農業協同組合中央会・和歌山県信用農業協同組合連合会・和歌山県農業協同組合連合会・和歌山県共済農業協同組合連合会');
ok($zip->set_number('6408502')->is_valid_number, '株式会社 長崎屋 和歌山店');
ok($zip->set_number('6408503')->is_valid_number, '株式会社 貴志');
ok($zip->set_number('6408505')->is_valid_number, '独立行政法人 労働者健康福祉機構 和歌山労災病院');
ok($zip->set_number('6408507')->is_valid_number, '和歌山刑務所');
ok($zip->set_number('6408508')->is_valid_number, '南海通信特機 株式会社');
ok($zip->set_number('6408509')->is_valid_number, '日本年金機構 和歌山事務センター');
ok($zip->set_number('6408510')->is_valid_number, '和歌山大学');
ok($zip->set_number('6408511')->is_valid_number, '和歌山市役所');
ok($zip->set_number('6408512')->is_valid_number, '株式会社 雪印アクセス 和歌山支店');
ok($zip->set_number('6408513')->is_valid_number, '和歌山県 赤十字血液センター');
ok($zip->set_number('6408514')->is_valid_number, '和歌山県医師会');
ok($zip->set_number('6408515')->is_valid_number, '株式会社 スズケン 和歌山支店');
ok($zip->set_number('6408516')->is_valid_number, '全国健康保険協会 和歌山支部');
ok($zip->set_number('6408519')->is_valid_number, '西日本電信電話 株式会社 和歌山支店');
ok($zip->set_number('6408520')->is_valid_number, '和歌山税務署');
ok($zip->set_number('6408524')->is_valid_number, '和歌山県 警察本部交通センター');
ok($zip->set_number('6408525')->is_valid_number, '株式会社 大黒');
ok($zip->set_number('6408530')->is_valid_number, '和歌山県 社会保険診療報酬支払基金');
ok($zip->set_number('6408533')->is_valid_number, '株式会社 テレビ和歌山');
ok($zip->set_number('6408535')->is_valid_number, 'パームシティ 和歌山店');
ok($zip->set_number('6408536')->is_valid_number, '和歌山市 選挙管理委員会事務局');
ok($zip->set_number('6408538')->is_valid_number, '東京医療保健大学 和歌山看護学部 雄湊キャンパス');
ok($zip->set_number('6408540')->is_valid_number, '住友生命保険 相互会社 和歌山支社');
ok($zip->set_number('6408541')->is_valid_number, '和歌山東年金事務所');
ok($zip->set_number('6408544')->is_valid_number, '有限会社 ジェイ・ウィング');
ok($zip->set_number('6408545')->is_valid_number, '社会福祉法人 和歌山県社会福祉協議会');
ok($zip->set_number('6408546')->is_valid_number, '株式会社 和歌山近鉄百貨店');
ok($zip->set_number('6408550')->is_valid_number, 'ノーリツプレシジョン 株式会社');
ok($zip->set_number('6408551')->is_valid_number, '株式会社 淺川組');
ok($zip->set_number('6408552')->is_valid_number, '和歌山地方法務局');
ok($zip->set_number('6408555')->is_valid_number, '日本製鉄 株式会社 関西製鉄所');
ok($zip->set_number('6408556')->is_valid_number, '日本放送協会 和歌山放送局');
ok($zip->set_number('6408557')->is_valid_number, '株式会社 和歌山リビング新聞社');
ok($zip->set_number('6408558')->is_valid_number, '日本赤十字社 和歌山医療センター');
ok($zip->set_number('6408560')->is_valid_number, '千代田火災海上保険 株式会社 和歌山支店');
ok($zip->set_number('6408564')->is_valid_number, '株式会社 ゴトウ洋服店');
ok($zip->set_number('6408565')->is_valid_number, '株式会社 山本種苗園');
ok($zip->set_number('6408566')->is_valid_number, '社団法人 和歌山県 経済センター');
ok($zip->set_number('6408567')->is_valid_number, '和歌山商工会議所');
ok($zip->set_number('6408570')->is_valid_number, 'ニュース和歌山 株式会社');
ok($zip->set_number('6408575')->is_valid_number, '株式会社 丸正');
ok($zip->set_number('6408577')->is_valid_number, '株式会社 和歌山放送');
ok($zip->set_number('6408580')->is_valid_number, '花王 株式会社 和歌山工場');
ok($zip->set_number('6408581')->is_valid_number, '和歌山労働局');
ok($zip->set_number('6408582')->is_valid_number, '和歌山労働基準監督署');
ok($zip->set_number('6408585')->is_valid_number, '和歌山県庁');
ok($zip->set_number('6408586')->is_valid_number, '和歌山地方検察庁');
ok($zip->set_number('6408588')->is_valid_number, '和歌山県警察本部');
ok($zip->set_number('6408589')->is_valid_number, '株式会社 日本教育書道研究会');
ok($zip->set_number('6408651')->is_valid_number, '大和証券 株式会社 和歌山支店');
ok($zip->set_number('6408652')->is_valid_number, '泉州銀行 和歌山支店');
ok($zip->set_number('6408653')->is_valid_number, '商工組合中央金庫 和歌山支店');
ok($zip->set_number('6408654')->is_valid_number, '東洋信託銀行 和歌山支店');
ok($zip->set_number('6408655')->is_valid_number, 'きのくに信用金庫');
ok($zip->set_number('6408656')->is_valid_number, '株式会社 紀陽銀行');
ok($zip->set_number('6408657')->is_valid_number, '農林中央金庫 和歌山事務所');
ok($zip->set_number('6408659')->is_valid_number, '株式会社 和歌山銀行');
ok($zip->set_number('6408666')->is_valid_number, '日本生命保険 相互会社 和歌山支社');
ok($zip->set_number('6408668')->is_valid_number, '株式会社 紀陽銀行 向芝オフィス');
ok($zip->set_number('6408686')->is_valid_number, '三菱電機 株式会社 冷熱システム製作所');
ok($zip->set_number('6408687')->is_valid_number, '野村證券 株式会社 和歌山支店');
ok($zip->set_number('6408787')->is_valid_number, '和歌山地域センター');
ok($zip->set_number('6418501')->is_valid_number, '株式会社 オークワ本社');
ok($zip->set_number('6418508')->is_valid_number, 'hi-hoインフォメーションデスク');
ok($zip->set_number('6418509')->is_valid_number, '公立大学法人 和歌山県立 医科大学');
ok($zip->set_number('6418510')->is_valid_number, '和歌山県立 医科大学付属病院');
ok($zip->set_number('6418511')->is_valid_number, '株式会社 島精機製作所');
ok($zip->set_number('6418770')->is_valid_number, 'エフエム和歌山');
ok($zip->set_number('6428501')->is_valid_number, '海南市役所');
ok($zip->set_number('6438501')->is_valid_number, '海南高原被害者の会');
ok($zip->set_number('6441292')->is_valid_number, '日高川町役場 美山支所');
ok($zip->set_number('6448655')->is_valid_number, '国保日高総合病院');
ok($zip->set_number('6448686')->is_valid_number, '御坊市役所');
ok($zip->set_number('6458501')->is_valid_number, '紀州南部ロイヤルホテル');
ok($zip->set_number('6458511')->is_valid_number, '河本食品 株式会社');
ok($zip->set_number('6460292')->is_valid_number, '中田食品 株式会社・株式会社 ナカタ');
ok($zip->set_number('6461192')->is_valid_number, '田辺市 大塔行政局');
ok($zip->set_number('6461492')->is_valid_number, '田辺市 中辺路行政局');
ok($zip->set_number('6468501')->is_valid_number, '紀伊田辺簡易保険保養センター');
ok($zip->set_number('6468511')->is_valid_number, '田辺労働基準監督署');
ok($zip->set_number('6468544')->is_valid_number, '大阪松下ライフエレクトロニクス 株式会社');
ok($zip->set_number('6468545')->is_valid_number, '田辺市役所');
ok($zip->set_number('6468550')->is_valid_number, '丸惣食品');
ok($zip->set_number('6468558')->is_valid_number, '独立行政法人 国立病院機構 南和歌山医療センター');
ok($zip->set_number('6468580')->is_valid_number, '西牟婁振興局');
ok($zip->set_number('6468585')->is_valid_number, '日本電信電話 株式会社 田辺支店');
ok($zip->set_number('6468588')->is_valid_number, '社会保険紀南病院');
ok($zip->set_number('6468660')->is_valid_number, '紀伊民報社');
ok($zip->set_number('6471294')->is_valid_number, '新宮市役所 熊野川行政局');
ok($zip->set_number('6471792')->is_valid_number, '田辺市 本宮行政局');
ok($zip->set_number('6478551')->is_valid_number, '東牟婁振興局');
ok($zip->set_number('6478555')->is_valid_number, '新宮市役所');
ok($zip->set_number('6480198')->is_valid_number, '九度山町役場');
ok($zip->set_number('6480280')->is_valid_number, '学校法人 高野山学園 高野山大学');
ok($zip->set_number('6480281')->is_valid_number, '高野町役場');
ok($zip->set_number('6480282')->is_valid_number, '宗教法人 宿坊大円院');
ok($zip->set_number('6480283')->is_valid_number, '持明院');
ok($zip->set_number('6480284')->is_valid_number, '高野山不動院');
ok($zip->set_number('6480285')->is_valid_number, '高野山苅萱堂 密厳院');
ok($zip->set_number('6480286')->is_valid_number, '竜泉院');
ok($zip->set_number('6480287')->is_valid_number, '西南院');
ok($zip->set_number('6480288')->is_valid_number, '高野山高等学校');
ok($zip->set_number('6480289')->is_valid_number, '西禅院');
ok($zip->set_number('6480292')->is_valid_number, '正智院');
ok($zip->set_number('6480293')->is_valid_number, '普賢院');
ok($zip->set_number('6480294')->is_valid_number, '総本山金剛峯寺');
ok($zip->set_number('6480295')->is_valid_number, '大師陀羅尼製薬');
ok($zip->set_number('6480296')->is_valid_number, '総持院');
ok($zip->set_number('6480297')->is_valid_number, '遍照尊院');
ok($zip->set_number('6480298')->is_valid_number, '宝善院');
ok($zip->set_number('6480392')->is_valid_number, '野迫川村役場');
ok($zip->set_number('6488541')->is_valid_number, '伊都県事務所');
ok($zip->set_number('6488585')->is_valid_number, '橋本市役所');
ok($zip->set_number('6490192')->is_valid_number, '海南市 下津行政局');
ok($zip->set_number('6492192')->is_valid_number, '上富田町役場');
ok($zip->set_number('6492193')->is_valid_number, '有限会社 紀の里食品');
ok($zip->set_number('6492195')->is_valid_number, '熊野高等学校');
ok($zip->set_number('6492198')->is_valid_number, '有限会社 深見梅店');
ok($zip->set_number('6493592')->is_valid_number, '串本町役場');
ok($zip->set_number('6494192')->is_valid_number, '串本町役場 古座分庁舎');
ok($zip->set_number('6496192')->is_valid_number, '紀の川市 桃山支所');
ok($zip->set_number('6496292')->is_valid_number, '岩出市役所');
ok($zip->set_number('6496492')->is_valid_number, '紀の川市役所');
ok($zip->set_number('6496493')->is_valid_number, '近畿大学 生物理工学部');
ok($zip->set_number('6496494')->is_valid_number, '紀の里 農業協同組合');
ok($zip->set_number('6496592')->is_valid_number, '粉河税務署');
ok($zip->set_number('6496593')->is_valid_number, '紀の川市役所 粉河支所');
ok($zip->set_number('6496595')->is_valid_number, '粉河高等学校');
ok($zip->set_number('6496692')->is_valid_number, '紀の川市役所 那賀支所');
ok($zip->set_number('6497192')->is_valid_number, 'かつらぎ町役場');
ok($zip->set_number('6497194')->is_valid_number, '築野食品工業 株式会社');
ok($zip->set_number('6497195')->is_valid_number, '溝端紙工印刷 株式会社');
ok($zip->set_number('6508501')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('6508502')->is_valid_number, '神戸県税事務所');
ok($zip->set_number('6508503')->is_valid_number, '株式会社 メディセオ');
ok($zip->set_number('6508505')->is_valid_number, '株式会社 ファミリア');
ok($zip->set_number('6508506')->is_valid_number, '関西電力 株式会社');
ok($zip->set_number('6508510')->is_valid_number, '兵庫県 警察本部');
ok($zip->set_number('6508511')->is_valid_number, '神戸税務署');
ok($zip->set_number('6508515')->is_valid_number, 'NHK 神戸放送局');
ok($zip->set_number('6508520')->is_valid_number, '大阪ガス 株式会社 兵庫リビング営業部');
ok($zip->set_number('6508521')->is_valid_number, '株式会社 ノエビア');
ok($zip->set_number('6508522')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('6508525')->is_valid_number, '株式会社 フェリシモ');
ok($zip->set_number('6508528')->is_valid_number, '兵庫県 社会保険診療報酬支払基金');
ok($zip->set_number('6508530')->is_valid_number, '兵庫医療大学');
ok($zip->set_number('6508533')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('6508536')->is_valid_number, '株式会社 サンテレビジョン');
ok($zip->set_number('6508539')->is_valid_number, '神戸親和女子大学 通信教育部事務室');
ok($zip->set_number('6508543')->is_valid_number, '神戸商工会議所');
ok($zip->set_number('6508546')->is_valid_number, 'トラスコ中山 株式会社 プラネット神戸');
ok($zip->set_number('6508550')->is_valid_number, '田崎真珠 株式会社');
ok($zip->set_number('6508551')->is_valid_number, '第五管区海上保安本部');
ok($zip->set_number('6508555')->is_valid_number, '株式会社 アシックス');
ok($zip->set_number('6508558')->is_valid_number, 'フジッコ 株式会社');
ok($zip->set_number('6508559')->is_valid_number, 'フジッコ 株式会社 ウェルネス倶楽部');
ok($zip->set_number('6508560')->is_valid_number, '株式会社 ホテルオークラ神戸');
ok($zip->set_number('6508565')->is_valid_number, '神戸簡易裁判所');
ok($zip->set_number('6508566')->is_valid_number, '株式会社 メディセオ 買掛管理グループ');
ok($zip->set_number('6508567')->is_valid_number, '兵庫県庁');
ok($zip->set_number('6508570')->is_valid_number, '神戸市役所');
ok($zip->set_number('6508571')->is_valid_number, '株式会社 神戸新聞社');
ok($zip->set_number('6508575')->is_valid_number, '神戸地方裁判所');
ok($zip->set_number('6508576')->is_valid_number, '株式会社 リーフ・パブリケーションズ 神戸支局 ぱど事業部');
ok($zip->set_number('6508577')->is_valid_number, 'UCC上島珈琲 株式会社');
ok($zip->set_number('6508580')->is_valid_number, '株式会社 ラジオ関西');
ok($zip->set_number('6508584')->is_valid_number, '株式会社 リクルート ホットペッパー神戸版編集部');
ok($zip->set_number('6508585')->is_valid_number, '株式会社 ワールド');
ok($zip->set_number('6508586')->is_valid_number, '神戸学院大学 ポートアイランド キャンパス');
ok($zip->set_number('6508588')->is_valid_number, '株式会社 Jコンテンツ');
ok($zip->set_number('6508589')->is_valid_number, '兵庫エフエム放送 株式会社');
ok($zip->set_number('6508660')->is_valid_number, '株式会社 三井住友銀行');
ok($zip->set_number('6508666')->is_valid_number, '全国農業協同組合連合会 兵庫県本部');
ok($zip->set_number('6508670')->is_valid_number, '川崎重工業 株式会社 神戸工場');
ok($zip->set_number('6508677')->is_valid_number, '宮野医療器 株式会社');
ok($zip->set_number('6508680')->is_valid_number, '川崎重工業 株式会社 神戸本社');
ok($zip->set_number('6508686')->is_valid_number, '神戸信用金庫');
ok($zip->set_number('6508787')->is_valid_number, '株式会社 ゆうちょ銀行 兵庫地域センター');
ok($zip->set_number('6508794')->is_valid_number, '大阪貯金事務センター 神戸分館');
ok($zip->set_number('6510170')->is_valid_number, '株式会社 みなとカード');
ok($zip->set_number('6510171')->is_valid_number, '三井住友海上火災保険 株式会社 神戸支店');
ok($zip->set_number('6510172')->is_valid_number, '三井住友信託銀行 株式会社 神戸三宮支店');
ok($zip->set_number('6510177')->is_valid_number, 'SMBC日興証券 株式会社 神戸支店');
ok($zip->set_number('6510178')->is_valid_number, '神栄 株式会社');
ok($zip->set_number('6510185')->is_valid_number, '住友生命保険 相互会社 神戸支社');
ok($zip->set_number('6510187')->is_valid_number, '株式会社 ノザワ');
ok($zip->set_number('6510188')->is_valid_number, '富永貿易 株式会社');
ok($zip->set_number('6510193')->is_valid_number, 'みなと銀行');
ok($zip->set_number('6510195')->is_valid_number, '兵庫県 信用保証協会');
ok($zip->set_number('6511195')->is_valid_number, '神戸市北区役所');
ok($zip->set_number('6511596')->is_valid_number, '神戸三田プレミアム・アウトレット');
ok($zip->set_number('6512180')->is_valid_number, '神戸学院大学 有瀬キャンパス');
ok($zip->set_number('6512181')->is_valid_number, '総合リハビリテーションセンター');
ok($zip->set_number('6512187')->is_valid_number, '神戸市外国語大学');
ok($zip->set_number('6512188')->is_valid_number, '学校法人中内学園 流通科学大学');
ok($zip->set_number('6512194')->is_valid_number, '神戸市立工業高等専門学校');
ok($zip->set_number('6512196')->is_valid_number, '神戸芸術工科大学');
ok($zip->set_number('6512197')->is_valid_number, '兵庫県立大学 学園都市キャンパス');
ok($zip->set_number('6512295')->is_valid_number, '神戸市西区役所');
ok($zip->set_number('6512492')->is_valid_number, '国立研究開発法人 情報通信研究機構 未来ICT研究所');
ok($zip->set_number('6512494')->is_valid_number, 'ヒラキ 株式会社');
ok($zip->set_number('6518501')->is_valid_number, '日本生命保険 相互会社 神戸支社');
ok($zip->set_number('6518502')->is_valid_number, '三宮オーパ2');
ok($zip->set_number('6518511')->is_valid_number, '神戸阪急');
ok($zip->set_number('6518512')->is_valid_number, '全国健康保険協会 兵庫支部');
ok($zip->set_number('6518514')->is_valid_number, '日本年金機構 兵庫事務センター');
ok($zip->set_number('6518525')->is_valid_number, '株式会社 フェリシモ 交換返品係(日本郵便神戸郵便局留め)');
ok($zip->set_number('6518526')->is_valid_number, '神戸市郵送請求処理センター');
ok($zip->set_number('6518555')->is_valid_number, '社団法人 兵庫県医師会');
ok($zip->set_number('6518567')->is_valid_number, '住友ゴム工業 (株)');
ok($zip->set_number('6518570')->is_valid_number, '神戸市中央区役所');
ok($zip->set_number('6518585')->is_valid_number, '株式会社 神戸製鋼所');
ok($zip->set_number('6518798')->is_valid_number, '神戸逓信病院');
ok($zip->set_number('6528501')->is_valid_number, '神戸トヨペット (株)');
ok($zip->set_number('6528510')->is_valid_number, '株式会社 デンソーテン');
ok($zip->set_number('6528550')->is_valid_number, '兵庫税務署');
ok($zip->set_number('6528555')->is_valid_number, '三菱電機 株式会社 電力産業システム事業所');
ok($zip->set_number('6528570')->is_valid_number, '兵庫区役所');
ok($zip->set_number('6528585')->is_valid_number, '三菱重工業 (株) 神戸造船所');
ok($zip->set_number('6538570')->is_valid_number, '長田区役所');
ok($zip->set_number('6538585')->is_valid_number, '株式会社 ケーブルネット神戸芦屋 J:COM神戸・三木');
ok($zip->set_number('6540192')->is_valid_number, '株式会社 シャルレ');
ok($zip->set_number('6540193')->is_valid_number, 'カネボウ薬品 株式会社 関西配送センター');
ok($zip->set_number('6540195')->is_valid_number, '須磨区役所 北須磨支所');
ok($zip->set_number('6540198')->is_valid_number, '(株) フェリシモ');
ok($zip->set_number('6548570')->is_valid_number, '須磨区役所');
ok($zip->set_number('6548585')->is_valid_number, '神戸女子大学');
ok($zip->set_number('6558570')->is_valid_number, '垂水区役所');
ok($zip->set_number('6560492')->is_valid_number, '南あわじ市役所');
ok($zip->set_number('6560595')->is_valid_number, '株式会社 森長組');
ok($zip->set_number('6561395')->is_valid_number, '洲本市役所 五色庁舎');
ok($zip->set_number('6561592')->is_valid_number, '淡路市 一宮総合事務所');
ok($zip->set_number('6561598')->is_valid_number, '株式会社 大発');
ok($zip->set_number('6561792')->is_valid_number, '淡路市 北淡総合事務所');
ok($zip->set_number('6562193')->is_valid_number, '有限会社 すみ孫');
ok($zip->set_number('6562292')->is_valid_number, '淡路市役所');
ok($zip->set_number('6562392')->is_valid_number, '淡路市 東浦総合事務所');
ok($zip->set_number('6562492')->is_valid_number, '淡路市 岩屋事務所');
ok($zip->set_number('6568555')->is_valid_number, 'パナソニックエナジー 株式会社');
ok($zip->set_number('6568656')->is_valid_number, '洲本税務署');
ok($zip->set_number('6568666')->is_valid_number, '淡陽信用組合');
ok($zip->set_number('6568686')->is_valid_number, '洲本市役所');
ok($zip->set_number('6578501')->is_valid_number, '神戸大学');
ok($zip->set_number('6578570')->is_valid_number, '灘区役所');
ok($zip->set_number('6588501')->is_valid_number, '甲南学園');
ok($zip->set_number('6588555')->is_valid_number, '生活協同組合 コープこうべ');
ok($zip->set_number('6588558')->is_valid_number, '神戸薬科大学');
ok($zip->set_number('6588570')->is_valid_number, '東灘区役所');
ok($zip->set_number('6598501')->is_valid_number, '芦屋市役所');
ok($zip->set_number('6598502')->is_valid_number, '市立 芦屋病院');
ok($zip->set_number('6598503')->is_valid_number, '芦屋税務署');
ok($zip->set_number('6598511')->is_valid_number, '学校法人 芦屋学園');
ok($zip->set_number('6608501')->is_valid_number, '尼崎市役所');
ok($zip->set_number('6608511')->is_valid_number, '独立行政法人 労働者健康福祉機構 関西労災病院');
ok($zip->set_number('6608533')->is_valid_number, '株式会社 大阪チタニウムテクノロジーズ');
ok($zip->set_number('6608540')->is_valid_number, '株式会社 エディオン');
ok($zip->set_number('6608544')->is_valid_number, '尼崎 税務署');
ok($zip->set_number('6608550')->is_valid_number, '兵庫県立尼崎総合医療センター');
ok($zip->set_number('6608555')->is_valid_number, '阪神南県民局 尼崎県税事務所');
ok($zip->set_number('6608558')->is_valid_number, '関西電力送配電 株式会社 阪神配電営業所');
ok($zip->set_number('6608567')->is_valid_number, '木村化工機 株式会社');
ok($zip->set_number('6608580')->is_valid_number, '日本山村硝子 株式会社');
ok($zip->set_number('6608582')->is_valid_number, 'アマゾン尼崎FC');
ok($zip->set_number('6608585')->is_valid_number, 'ヤンマー 株式会社 特機エンジン事業部');
ok($zip->set_number('6608588')->is_valid_number, '兵庫県 阪神南県民局');
ok($zip->set_number('6618501')->is_valid_number, '株式会社 日立プラントテクノロジー尼崎事業所');
ok($zip->set_number('6618510')->is_valid_number, '日本スピンドル製造 株式会社');
ok($zip->set_number('6618511')->is_valid_number, '神東塗料 株式会社');
ok($zip->set_number('6618520')->is_valid_number, '園田学園女子大学・短期大学部');
ok($zip->set_number('6618530')->is_valid_number, '学校法人 英知大学');
ok($zip->set_number('6618550')->is_valid_number, '技研化成 株式会社');
ok($zip->set_number('6618555')->is_valid_number, '関西ペイント 株式会社 尼崎工場');
ok($zip->set_number('6618558')->is_valid_number, 'ジャパン・エア・ガシズ 株式会社');
ok($zip->set_number('6618564')->is_valid_number, 'トーヨーケム 株式会社 尼崎工場');
ok($zip->set_number('6618567')->is_valid_number, '株式会社 クボタ 本社阪神事務所');
ok($zip->set_number('6618577')->is_valid_number, '株式会社 アシックス 関西支社');
ok($zip->set_number('6618585')->is_valid_number, '第一電工 株式会社 尼崎工場');
ok($zip->set_number('6618588')->is_valid_number, '住友ベークライト 株式会社 尼崎工場');
ok($zip->set_number('6618661')->is_valid_number, '三菱電機 株式会社');
ok($zip->set_number('6628501')->is_valid_number, '学校法人 関西学院 (西宮上ケ原キャンパス)');
ok($zip->set_number('6628502')->is_valid_number, '株式会社 新井組');
ok($zip->set_number('6628503')->is_valid_number, '阪神南県民局 西宮県税事務所');
ok($zip->set_number('6628505')->is_valid_number, '学校法人 神戸女学院');
ok($zip->set_number('6628510')->is_valid_number, '辰馬本家酒造 株式会社');
ok($zip->set_number('6628521')->is_valid_number, '日本盛 株式会社');
ok($zip->set_number('6628533')->is_valid_number, '兵庫栄養専門学校');
ok($zip->set_number('6628543')->is_valid_number, '加藤産業 株式会社');
ok($zip->set_number('6628552')->is_valid_number, '大手前大学');
ok($zip->set_number('6628555')->is_valid_number, '夙川学院短期大学');
ok($zip->set_number('6628558')->is_valid_number, 'アサヒパーツ 株式会社');
ok($zip->set_number('6628567')->is_valid_number, '西宮市役所');
ok($zip->set_number('6628580')->is_valid_number, '古野電気 株式会社');
ok($zip->set_number('6628585')->is_valid_number, '西宮税務署');
ok($zip->set_number('6628586')->is_valid_number, '山村硝子 株式会社');
ok($zip->set_number('6638501')->is_valid_number, '学校法人 兵庫医科大学');
ok($zip->set_number('6638510')->is_valid_number, '関電システムソリューションズ 株式会社');
ok($zip->set_number('6638530')->is_valid_number, 'アマゾン鳴尾浜 IXD');
ok($zip->set_number('6638545')->is_valid_number, '極東開発工業 株式会社');
ok($zip->set_number('6638558')->is_valid_number, '学校法人 武庫川学院');
ok($zip->set_number('6638567')->is_valid_number, '日本年金機構 西宮年金事務所');
ok($zip->set_number('6638577')->is_valid_number, 'エスフーズ 株式会社');
ok($zip->set_number('6638585')->is_valid_number, '布亀 株式会社');
ok($zip->set_number('6638586')->is_valid_number, '伊藤ハム 株式会社');
ok($zip->set_number('6638588')->is_valid_number, '加藤産業 株式会社 西近畿支社');
ok($zip->set_number('6638601')->is_valid_number, 'アマゾン西宮フルフィルメントセンター');
ok($zip->set_number('6648501')->is_valid_number, '日東紡績 株式会社 伊丹生産センター');
ok($zip->set_number('6648502')->is_valid_number, 'パスカル 株式会社');
ok($zip->set_number('6648503')->is_valid_number, '伊丹市役所');
ok($zip->set_number('6648505')->is_valid_number, '伊丹税務署');
ok($zip->set_number('6648507')->is_valid_number, 'サカタインクス 株式会社 大阪工場');
ok($zip->set_number('6648508')->is_valid_number, '松谷化学工業 株式会社');
ok($zip->set_number('6648510')->is_valid_number, '伊丹産業 株式会社');
ok($zip->set_number('6648511')->is_valid_number, 'コニカミノルタ 伊丹サイト');
ok($zip->set_number('6648520')->is_valid_number, '日本板硝子 株式会社 技術研究所');
ok($zip->set_number('6648522')->is_valid_number, '兵庫県阪神北県民局 企画調整部 伊丹県税事務所');
ok($zip->set_number('6648533')->is_valid_number, '公立学校共済組合 近畿中央病院');
ok($zip->set_number('6648540')->is_valid_number, '市立 伊丹病院');
ok($zip->set_number('6648545')->is_valid_number, '伊丹簡易裁判所');
ok($zip->set_number('6648558')->is_valid_number, '伊丹コミュニティ放送 株式会社');
ok($zip->set_number('6648588')->is_valid_number, '凸版印刷 株式会社 伊丹工場');
ok($zip->set_number('6648610')->is_valid_number, '東リ 株式会社');
ok($zip->set_number('6648611')->is_valid_number, '住友電気工業 株式会社 伊丹製作所');
ok($zip->set_number('6648615')->is_valid_number, '株式会社 フジコー');
ok($zip->set_number('6648624')->is_valid_number, '小西酒造 株式会社');
ok($zip->set_number('6648641')->is_valid_number, '三菱電機 株式会社 高周波光デバイス製作所');
ok($zip->set_number('6648650')->is_valid_number, '陸上自衛隊 中部方面総監部');
ok($zip->set_number('6658501')->is_valid_number, '株式会社 ハイレックスコーポレーション');
ok($zip->set_number('6658543')->is_valid_number, '株式会社 エフエム宝塚');
ok($zip->set_number('6658550')->is_valid_number, '新明和工業 株式会社 本社');
ok($zip->set_number('6658555')->is_valid_number, '住友化学工業 (株) 農業化学品研究所');
ok($zip->set_number('6658558')->is_valid_number, '阪急電鉄 (株) 宝塚大劇場');
ok($zip->set_number('6658567')->is_valid_number, '阪神北県民局');
ok($zip->set_number('6658585')->is_valid_number, '宝塚歌劇団');
ok($zip->set_number('6658588')->is_valid_number, '大本山 中山寺');
ok($zip->set_number('6658665')->is_valid_number, '宝塚市役所');
ok($zip->set_number('6660292')->is_valid_number, '猪名川町役場');
ok($zip->set_number('6668501')->is_valid_number, '川西市役所');
ok($zip->set_number('6670198')->is_valid_number, '養父市 養父地域局');
ok($zip->set_number('6678555')->is_valid_number, '公立八鹿病院');
ok($zip->set_number('6678651')->is_valid_number, '養父市役所');
ok($zip->set_number('6680292')->is_valid_number, '豊岡市役所 出石総合支所');
ok($zip->set_number('6680293')->is_valid_number, '株式会社 川嶋建設');
ok($zip->set_number('6680298')->is_valid_number, 'パナソニック エレクトロニックデバイス但馬 株式会社');
ok($zip->set_number('6680393')->is_valid_number, '豊岡市役所 但東総合支所');
ok($zip->set_number('6688501')->is_valid_number, '公立豊岡病院組合立豊岡病院');
ok($zip->set_number('6688650')->is_valid_number, '株式会社 但馬銀行');
ok($zip->set_number('6688655')->is_valid_number, '但馬信用金庫 本店');
ok($zip->set_number('6688666')->is_valid_number, '豊岡市');
ok($zip->set_number('6691592')->is_valid_number, '独立行政法人 国立病院機構 兵庫中央病院');
ok($zip->set_number('6691595')->is_valid_number, '三田市役所');
ok($zip->set_number('6692192')->is_valid_number, '丹波篠山市役所 今田支所');
ok($zip->set_number('6692292')->is_valid_number, '丹波篠山市役所 丹南支所');
ok($zip->set_number('6692397')->is_valid_number, '丹波篠山市役所');
ok($zip->set_number('6693192')->is_valid_number, '宗教法人・円応教');
ok($zip->set_number('6693198')->is_valid_number, '丹波市役所 山南支所');
ok($zip->set_number('6693392')->is_valid_number, '柏原税務署');
ok($zip->set_number('6693394')->is_valid_number, '関西電力 (株) 柏原営業所');
ok($zip->set_number('6693395')->is_valid_number, '兵庫県立 柏原病院');
ok($zip->set_number('6693396')->is_valid_number, '丹波市役所 柏原支所');
ok($zip->set_number('6693495')->is_valid_number, '兵庫県立丹波医療センター');
ok($zip->set_number('6693692')->is_valid_number, '丹波市役所');
ok($zip->set_number('6693693')->is_valid_number, '中兵庫信用金庫');
ok($zip->set_number('6693892')->is_valid_number, '丹波市役所 青垣支所');
ok($zip->set_number('6694192')->is_valid_number, '丹波市役所 春日庁舎');
ok($zip->set_number('6694392')->is_valid_number, '丹波市役所 市島支所');
ok($zip->set_number('6695192')->is_valid_number, '朝来市役所 山東支所');
ok($zip->set_number('6695193')->is_valid_number, '但南建設 株式会社');
ok($zip->set_number('6695197')->is_valid_number, '公立朝来梁瀬医療センター');
ok($zip->set_number('6695198')->is_valid_number, '藤井電機 株式会社');
ok($zip->set_number('6695292')->is_valid_number, '朝来市役所');
ok($zip->set_number('6695392')->is_valid_number, '公立豊岡病院 日高医療センター');
ok($zip->set_number('6695395')->is_valid_number, '県立日高高等学校');
ok($zip->set_number('6695398')->is_valid_number, 'フジテック 株式会社 Big Step');
ok($zip->set_number('6696192')->is_valid_number, '日和山観光 株式会社・城崎マリンワールド');
ok($zip->set_number('6696195')->is_valid_number, '豊岡市役所 城崎総合支所');
ok($zip->set_number('6696292')->is_valid_number, '豊岡市役所 竹野総合支所');
ok($zip->set_number('6696592')->is_valid_number, '香美町役場');
ok($zip->set_number('6696792')->is_valid_number, '新温泉町役場');
ok($zip->set_number('6696892')->is_valid_number, '新温泉町役場 温泉総合支所');
ok($zip->set_number('6708501')->is_valid_number, '姫路市役所');
ok($zip->set_number('6708502')->is_valid_number, '関西電力送配電 株式会社 姫路配電営業所');
ok($zip->set_number('6708503')->is_valid_number, '株式会社 播磨リビング新聞社');
ok($zip->set_number('6708505')->is_valid_number, '姫路商工会議所');
ok($zip->set_number('6708506')->is_valid_number, 'むつみ 株式会社');
ok($zip->set_number('6708510')->is_valid_number, '株式会社 タビックスジャパン 姫路営業支店');
ok($zip->set_number('6708511')->is_valid_number, 'ジャスコ 株式会社 西部カンパニー');
ok($zip->set_number('6708517')->is_valid_number, '千代田火災海上保険 株式会社');
ok($zip->set_number('6708520')->is_valid_number, '国立姫路病院');
ok($zip->set_number('6708524')->is_valid_number, '姫路獨協大学');
ok($zip->set_number('6708530')->is_valid_number, '姫路市中央保健所');
ok($zip->set_number('6708533')->is_valid_number, 'セルディア/株式会社 三商');
ok($zip->set_number('6708543')->is_valid_number, '姫路税務署');
ok($zip->set_number('6708544')->is_valid_number, '公益財団法人 姫路市文化国際交流財団');
ok($zip->set_number('6708550')->is_valid_number, '株式会社 富強');
ok($zip->set_number('6708554')->is_valid_number, '株式会社 帝国データバンク 姫路支店');
ok($zip->set_number('6708555')->is_valid_number, '株式会社 ヤマトヤシキ');
ok($zip->set_number('6708558')->is_valid_number, '株式会社 ラボ');
ok($zip->set_number('6708560')->is_valid_number, '兵庫県立 はりま姫路総合医療センター');
ok($zip->set_number('6708566')->is_valid_number, '株式会社 姫路シティエフエム21');
ok($zip->set_number('6708567')->is_valid_number, 'グローリー 株式会社');
ok($zip->set_number('6708570')->is_valid_number, '丸魚水産 株式会社');
ok($zip->set_number('6708575')->is_valid_number, '株式会社 山陽百貨店');
ok($zip->set_number('6708577')->is_valid_number, '関西電力 株式会社 姫路支店');
ok($zip->set_number('6708580')->is_valid_number, '陸上自衛隊 姫路駐屯地');
ok($zip->set_number('6708585')->is_valid_number, 'ジャスコ 株式会社 姫路フォーラス');
ok($zip->set_number('6708588')->is_valid_number, '株式会社 板文');
ok($zip->set_number('6708652')->is_valid_number, '姫路信用金庫');
ok($zip->set_number('6708655')->is_valid_number, '兵庫信用金庫');
ok($zip->set_number('6708660')->is_valid_number, '株式会社さくら銀行 姫路支店');
ok($zip->set_number('6708666')->is_valid_number, '株式会社 サラト');
ok($zip->set_number('6708668')->is_valid_number, '株式会社 神崎組');
ok($zip->set_number('6708675')->is_valid_number, '日本生命保険 相互会社 姫路支社');
ok($zip->set_number('6708677')->is_valid_number, '三菱電機 株式会社 姫路製作所');
ok($zip->set_number('6708680')->is_valid_number, '播州信用金庫');
ok($zip->set_number('6708682')->is_valid_number, '商工組合中央金庫 姫路支店');
ok($zip->set_number('6708689')->is_valid_number, '日本フエルト工業 株式会社');
ok($zip->set_number('6710295')->is_valid_number, '株式会社 寳角ギヤー');
ok($zip->set_number('6711180')->is_valid_number, '日鉄物流広畑 株式会社');
ok($zip->set_number('6711181')->is_valid_number, '株式会社 吉田組');
ok($zip->set_number('6711188')->is_valid_number, '新日本製鐵 株式会社 広畑製鐵所');
ok($zip->set_number('6711192')->is_valid_number, '大和工業 株式会社');
ok($zip->set_number('6711280')->is_valid_number, '西芝電機 株式会社');
ok($zip->set_number('6711281')->is_valid_number, 'ダイセル化学工業姫路製造所');
ok($zip->set_number('6711282')->is_valid_number, '株式会社 日本触媒 姫路製造所');
ok($zip->set_number('6711283')->is_valid_number, '株式会社 ダイセル 総合研究所');
ok($zip->set_number('6711285')->is_valid_number, 'ティー・エフ・ピー・ディー 株式会社');
ok($zip->set_number('6711286')->is_valid_number, '兵庫県立網干高校');
ok($zip->set_number('6711288')->is_valid_number, '大和産業 株式会社');
ok($zip->set_number('6711289')->is_valid_number, '大日本プラスチック 株式会社');
ok($zip->set_number('6711292')->is_valid_number, '(株) 日本触媒 研究企画部');
ok($zip->set_number('6711293')->is_valid_number, 'シーダム 株式会社 姫路工場');
ok($zip->set_number('6711295')->is_valid_number, '株式会社 東芝 姫路工場');
ok($zip->set_number('6711392')->is_valid_number, 'たつの市 御津総合支所');
ok($zip->set_number('6711393')->is_valid_number, 'タキロン 株式会社 網干工場');
ok($zip->set_number('6711592')->is_valid_number, '兵庫県揖保郡太子町役場');
ok($zip->set_number('6711593')->is_valid_number, '株式会社 うかいや');
ok($zip->set_number('6711595')->is_valid_number, '株式会社 東芝姫路工場太子分工場');
ok($zip->set_number('6711680')->is_valid_number, '日本丸天醤油 株式会社');
ok($zip->set_number('6711681')->is_valid_number, 'ダイセル化学工業 株式会社 播磨工場');
ok($zip->set_number('6711682')->is_valid_number, '兵庫西農業協同組合 揖保川支店');
ok($zip->set_number('6711684')->is_valid_number, '揖保川町商工会');
ok($zip->set_number('6711688')->is_valid_number, '医療法人 古橋会 揖保川病院');
ok($zip->set_number('6711692')->is_valid_number, 'たつの市 揖保川総合支所');
ok($zip->set_number('6712192')->is_valid_number, '姫路市夢前事務所');
ok($zip->set_number('6712193')->is_valid_number, '日生学園第三高等学校');
ok($zip->set_number('6712198')->is_valid_number, 'ヤマサ蒲鉾 株式会社');
ok($zip->set_number('6712280')->is_valid_number, '兵庫県立大学');
ok($zip->set_number('6712288')->is_valid_number, '三相電機 株式会社');
ok($zip->set_number('6712593')->is_valid_number, '宍粟市役所');
ok($zip->set_number('6712595')->is_valid_number, '西兵庫信用金庫');
ok($zip->set_number('6712598')->is_valid_number, '宍粟市 山崎市民局');
ok($zip->set_number('6714192')->is_valid_number, '宍粟市 一宮市民局');
ok($zip->set_number('6714193')->is_valid_number, 'ハリマ農業協同組合');
ok($zip->set_number('6728501')->is_valid_number, '医療法人公仁会 姫路中央病院');
ok($zip->set_number('6728550')->is_valid_number, '株式会社 フードサプライジャスコ兵庫事業所');
ok($zip->set_number('6728555')->is_valid_number, '第一燃料工業 株式会社');
ok($zip->set_number('6728558')->is_valid_number, 'トラスコ中山 株式会社 姫路支店');
ok($zip->set_number('6728567')->is_valid_number, '株式会社 アスノ');
ok($zip->set_number('6728585')->is_valid_number, '出光興産 株式会社 兵庫製油所');
ok($zip->set_number('6728588')->is_valid_number, '自動車検査独立行政法人 近畿検査部 姫路事務所');
ok($zip->set_number('6728655')->is_valid_number, '合同製鐵 株式会社 姫路製造所');
ok($zip->set_number('6728666')->is_valid_number, '横田石油 株式会社');
ok($zip->set_number('6728677')->is_valid_number, '山陽特殊製鋼 株式会社');
ok($zip->set_number('6730492')->is_valid_number, '三木市役所');
ok($zip->set_number('6730592')->is_valid_number, '生活協同組合 コープこうべ');
ok($zip->set_number('6731192')->is_valid_number, '三木市吉川支所');
ok($zip->set_number('6731395')->is_valid_number, '加東市役所 東条庁舎');
ok($zip->set_number('6731493')->is_valid_number, '加東市役所 社庁舎');
ok($zip->set_number('6731494')->is_valid_number, '国立大学法人 兵庫教育大学');
ok($zip->set_number('6731495')->is_valid_number, '加東市やしろ国際学習塾');
ok($zip->set_number('6738501')->is_valid_number, '明石市立市民病院');
ok($zip->set_number('6738511')->is_valid_number, '関西電力 株式会社 明石営業所');
ok($zip->set_number('6738522')->is_valid_number, '株式会社 播磨リビング新聞社 明石支社');
ok($zip->set_number('6738585')->is_valid_number, '兵庫県立明石高等学校');
ok($zip->set_number('6738666')->is_valid_number, '川崎重工業 株式会社 明石工場');
ok($zip->set_number('6738686')->is_valid_number, '明石市役所');
ok($zip->set_number('6738688')->is_valid_number, '大和製衡 株式会社');
ok($zip->set_number('6748501')->is_valid_number, '明石工業高等専門学校');
ok($zip->set_number('6748585')->is_valid_number, '日工 株式会社');
ok($zip->set_number('6748686')->is_valid_number, 'キャタピラージャパン 合同会社 明石事業所');
ok($zip->set_number('6750180')->is_valid_number, '川崎重工業 株式会社');
ok($zip->set_number('6750181')->is_valid_number, '日本エア・リキード 株式会社');
ok($zip->set_number('6750182')->is_valid_number, '播磨町役場');
ok($zip->set_number('6750183')->is_valid_number, '住友精化 株式会社');
ok($zip->set_number('6750184')->is_valid_number, '関西熱化学 株式会社');
ok($zip->set_number('6750185')->is_valid_number, '株式会社 神戸製鋼所 加古川製鉄所');
ok($zip->set_number('6750186')->is_valid_number, '滝川工業 株式会社');
ok($zip->set_number('6750188')->is_valid_number, '兵庫県 いなみの学園');
ok($zip->set_number('6750192')->is_valid_number, '多木化学 株式会社');
ok($zip->set_number('6750193')->is_valid_number, '昭和住宅 株式会社');
ok($zip->set_number('6750194')->is_valid_number, '株式会社 大真空');
ok($zip->set_number('6750196')->is_valid_number, '財団法人 加古川総合保健センター');
ok($zip->set_number('6750198')->is_valid_number, 'バンドー化学 株式会社 加古川工場');
ok($zip->set_number('6751192')->is_valid_number, 'キング醸造 株式会社');
ok($zip->set_number('6751297')->is_valid_number, '播磨社会復帰促進センター');
ok($zip->set_number('6751380')->is_valid_number, '小野市役所');
ok($zip->set_number('6751392')->is_valid_number, '北播磨総合医療センター');
ok($zip->set_number('6751395')->is_valid_number, '小野商工会議所');
ok($zip->set_number('6752393')->is_valid_number, '市立加西病院');
ok($zip->set_number('6752395')->is_valid_number, '加西市役所');
ok($zip->set_number('6758501')->is_valid_number, '加古川市役所');
ok($zip->set_number('6758505')->is_valid_number, '株式会社 加古川ヤマトヤシキ');
ok($zip->set_number('6758510')->is_valid_number, '(株) マルアイ');
ok($zip->set_number('6758511')->is_valid_number, '株式会社 テイエルブイ');
ok($zip->set_number('6758519')->is_valid_number, '本州製罐 株式会社 兵庫工場');
ok($zip->set_number('6758522')->is_valid_number, '加古川市 中央消防署');
ok($zip->set_number('6758533')->is_valid_number, '株式会社 コスモライフ');
ok($zip->set_number('6758555')->is_valid_number, '兵庫県立 加古川医療センター');
ok($zip->set_number('6758558')->is_valid_number, '加古川プラスチックス 株式会社');
ok($zip->set_number('6758566')->is_valid_number, '兵庫県 加古川県税事務所');
ok($zip->set_number('6758577')->is_valid_number, '社会福祉法人 加古川市社会福祉協議会');
ok($zip->set_number('6758588')->is_valid_number, '加古川市上下水道局');
ok($zip->set_number('6758611')->is_valid_number, '加古川中央市民病院');
ok($zip->set_number('6758686')->is_valid_number, '但陽信用金庫');
ok($zip->set_number('6758688')->is_valid_number, '株式会社 アプコ');
ok($zip->set_number('6768501')->is_valid_number, '高砂市役所');
ok($zip->set_number('6768510')->is_valid_number, 'キッコーマン 株式会社 高砂工場');
ok($zip->set_number('6768513')->is_valid_number, '黒崎播磨 株式会社');
ok($zip->set_number('6768533')->is_valid_number, 'ヤング開発 株式会社');
ok($zip->set_number('6768540')->is_valid_number, '株式会社 タクマ 播磨工場');
ok($zip->set_number('6768558')->is_valid_number, '高砂商工会議所');
ok($zip->set_number('6768566')->is_valid_number, '丸山印刷 株式会社');
ok($zip->set_number('6768585')->is_valid_number, '高砂市民病院');
ok($zip->set_number('6768655')->is_valid_number, '旭硝子 株式会社 高砂工場');
ok($zip->set_number('6768670')->is_valid_number, '株式会社 神戸製鋼所 高砂製作所');
ok($zip->set_number('6768677')->is_valid_number, '三菱製紙 株式会社 高砂工場');
ok($zip->set_number('6768686')->is_valid_number, '三菱重工業 株式会社 高砂製作所');
ok($zip->set_number('6768688')->is_valid_number, '株式会社 カネカ 高砂工業所');
ok($zip->set_number('6778510')->is_valid_number, '西脇ロイヤルホテル');
ok($zip->set_number('6778511')->is_valid_number, '西脇市役所');
ok($zip->set_number('6780192')->is_valid_number, 'アース製薬 株式会社 赤穂本部');
ok($zip->set_number('6780193')->is_valid_number, '赤穂化成 株式会社');
ok($zip->set_number('6780195')->is_valid_number, '大木産業 株式会社');
ok($zip->set_number('6780292')->is_valid_number, '赤穂市役所');
ok($zip->set_number('6781195')->is_valid_number, '兵庫丸門運輸 株式会社');
ok($zip->set_number('6781198')->is_valid_number, '株式会社 赤穂国際カントリークラブ');
ok($zip->set_number('6781292')->is_valid_number, '上郡町役場');
ok($zip->set_number('6781295')->is_valid_number, '兵庫県 西播磨県民局 上郡県税事務所');
ok($zip->set_number('6781297')->is_valid_number, '兵庫県立大学 理学部');
ok($zip->set_number('6788543')->is_valid_number, '関西電力 (株) 相生発電所');
ok($zip->set_number('6788585')->is_valid_number, '相生市役所');
ok($zip->set_number('6790180')->is_valid_number, '伊東電機 株式会社');
ok($zip->set_number('6790181')->is_valid_number, '椿本チエイン 兵庫工場');
ok($zip->set_number('6790187')->is_valid_number, '財団法人 兵庫県フラワーセンター協会');
ok($zip->set_number('6790188')->is_valid_number, '兵庫みらい農業協同組合');
ok($zip->set_number('6790198')->is_valid_number, '兵庫県立 中央農業技術センター');
ok($zip->set_number('6790292')->is_valid_number, '加東市役所 滝野庁舎');
ok($zip->set_number('6790295')->is_valid_number, '藤井電工 株式会社');
ok($zip->set_number('6791192')->is_valid_number, '多可町役場');
ok($zip->set_number('6791292')->is_valid_number, '多可町役場 加美地域局');
ok($zip->set_number('6792280')->is_valid_number, '福崎町役場');
ok($zip->set_number('6792281')->is_valid_number, '近畿福祉大学');
ok($zip->set_number('6792282')->is_valid_number, '中小企業大学校関西校');
ok($zip->set_number('6792283')->is_valid_number, '凸版印刷 株式会社 福崎工場');
ok($zip->set_number('6792284')->is_valid_number, 'グローリープロダクツ 株式会社');
ok($zip->set_number('6792285')->is_valid_number, '千寿製薬 (株)');
ok($zip->set_number('6792288')->is_valid_number, '福伸電機 株式会社');
ok($zip->set_number('6792289')->is_valid_number, 'エーモン工業 株式会社');
ok($zip->set_number('6792295')->is_valid_number, 'サンライズ工業 株式会社');
ok($zip->set_number('6792392')->is_valid_number, '市川町役場');
ok($zip->set_number('6792493')->is_valid_number, '公立神崎総合病院');
ok($zip->set_number('6793392')->is_valid_number, '朝来市役所 生野支所');
ok($zip->set_number('6793393')->is_valid_number, 'ヒラキ 株式会社 生野事業所');
ok($zip->set_number('6794192')->is_valid_number, 'たつの市役所');
ok($zip->set_number('6794193')->is_valid_number, 'ヒガシマル醤油 株式会社');
ok($zip->set_number('6794195')->is_valid_number, '極東産機 株式会社');
ok($zip->set_number('6794298')->is_valid_number, 'ヤヱガキ 株式会社');
ok($zip->set_number('6794392')->is_valid_number, 'たつの市 新宮総合支所');
ok($zip->set_number('6794393')->is_valid_number, 'ブンセン 株式会社');
ok($zip->set_number('6794395')->is_valid_number, '株式会社 帝国電機製作所');
ok($zip->set_number('6795192')->is_valid_number, '佐用町役場 三日月支所');
ok($zip->set_number('6795198')->is_valid_number, '財団法人 高輝度光科学研究センター');
ok($zip->set_number('6795292')->is_valid_number, '佐用町役場 南光支所');
ok($zip->set_number('6795380')->is_valid_number, '佐用町役場');
ok($zip->set_number('6795381')->is_valid_number, '兵庫県立 佐用高等学校');
ok($zip->set_number('6795382')->is_valid_number, '佐用共立病院');
ok($zip->set_number('6795383')->is_valid_number, '医療法人 聖医会 佐用中央病院');
ok($zip->set_number('6795392')->is_valid_number, '兵庫西農業共同組合 佐用支店');
ok($zip->set_number('6795595')->is_valid_number, '佐用町役場 上月支所');
ok($zip->set_number('6800197')->is_valid_number, '国府町 総合支所');
ok($zip->set_number('6800492')->is_valid_number, '鳥取県立 八頭高等学校');
ok($zip->set_number('6800493')->is_valid_number, '八頭町役場');
ok($zip->set_number('6800495')->is_valid_number, '八頭町役場船岡支所');
ok($zip->set_number('6800792')->is_valid_number, '若桜町役場');
ok($zip->set_number('6801192')->is_valid_number, '鳥取刑務所');
ok($zip->set_number('6808501')->is_valid_number, '鳥取市立病院');
ok($zip->set_number('6808502')->is_valid_number, '全国農業協同組合連合会 鳥取県本部');
ok($zip->set_number('6808510')->is_valid_number, '住友生命保険 相互会社 鳥取支社');
ok($zip->set_number('6808511')->is_valid_number, '大和証券 株式会社 鳥取支店');
ok($zip->set_number('6808517')->is_valid_number, '鳥取赤十字病院');
ok($zip->set_number('6808520')->is_valid_number, '鳥取県警察本部');
ok($zip->set_number('6808522')->is_valid_number, '鳥取労働局');
ok($zip->set_number('6808531')->is_valid_number, '鳥取県 社会保険診療報酬支払基金');
ok($zip->set_number('6808533')->is_valid_number, '株式会社 ナカニシ');
ok($zip->set_number('6808541')->is_valid_number, '鳥取税務署');
ok($zip->set_number('6808550')->is_valid_number, '鳥取大学 本部');
ok($zip->set_number('6808551')->is_valid_number, '鳥取大学 地域学部');
ok($zip->set_number('6808552')->is_valid_number, '鳥取大学 工学部');
ok($zip->set_number('6808553')->is_valid_number, '鳥取大学 農学部');
ok($zip->set_number('6808554')->is_valid_number, '鳥取大学附属図書館');
ok($zip->set_number('6808555')->is_valid_number, '日本海信販 株式会社');
ok($zip->set_number('6808561')->is_valid_number, '日本年金機構 鳥取事務センター');
ok($zip->set_number('6808566')->is_valid_number, '鳥取商工会議所');
ok($zip->set_number('6808570')->is_valid_number, '鳥取県庁');
ok($zip->set_number('6808571')->is_valid_number, '鳥取市役所');
ok($zip->set_number('6808572')->is_valid_number, '日本海テレビジョン放送 株式会社');
ok($zip->set_number('6808575')->is_valid_number, '株式会社 ジャパンディスプレイ');
ok($zip->set_number('6808577')->is_valid_number, '三洋エプソンイメージングデバイス 株式会社 鳥取事業所');
ok($zip->set_number('6808578')->is_valid_number, 'エプソンリペア 株式会社');
ok($zip->set_number('6808585')->is_valid_number, '鳥取県医師会');
ok($zip->set_number('6808588')->is_valid_number, '株式会社 山陰カラー綜合現像所');
ok($zip->set_number('6808601')->is_valid_number, '株式会社 丸由');
ok($zip->set_number('6808611')->is_valid_number, '鳥取信用金庫');
ok($zip->set_number('6808634')->is_valid_number, '株式会社 LIMNO');
ok($zip->set_number('6808644')->is_valid_number, '商工組合中央金庫 鳥取支店');
ok($zip->set_number('6808678')->is_valid_number, '日本生命保険 相互会社 鳥取支社');
ok($zip->set_number('6808686')->is_valid_number, '株式会社 鳥取銀行');
ok($zip->set_number('6808688')->is_valid_number, '株式会社 新日本海新聞社');
ok($zip->set_number('6808701')->is_valid_number, '日本放送協会 鳥取放送局');
ok($zip->set_number('6818501')->is_valid_number, '岩美町役場');
ok($zip->set_number('6820192')->is_valid_number, '岡山大学医学部・歯学部付属病院 三朝医療センター');
ok($zip->set_number('6820193')->is_valid_number, '岡山大学固体地球研究センター');
ok($zip->set_number('6820195')->is_valid_number, '三朝町役場');
ok($zip->set_number('6820197')->is_valid_number, '鳥取県中部医師会立三朝温泉病院');
ok($zip->set_number('6820498')->is_valid_number, '倉吉市役所 関金支所');
ok($zip->set_number('6828501')->is_valid_number, 'オムロン倉吉 株式会社');
ok($zip->set_number('6828505')->is_valid_number, '新日本海新聞社 中部本社');
ok($zip->set_number('6828522')->is_valid_number, '倉吉 税務署');
ok($zip->set_number('6828555')->is_valid_number, '学校法人 藤田学院 鳥取看護大学 鳥取短期大学');
ok($zip->set_number('6828585')->is_valid_number, '有限会社 ホテイ堂');
ok($zip->set_number('6828601')->is_valid_number, '倉吉信用金庫');
ok($zip->set_number('6828611')->is_valid_number, '倉吉市役所');
ok($zip->set_number('6828633')->is_valid_number, '倉吉市役所 第2庁舎');
ok($zip->set_number('6838502')->is_valid_number, '独立行政法人 国立高等専門学校機構 米子工業高等専門学校');
ok($zip->set_number('6838503')->is_valid_number, '国立大学法人 鳥取大学医学部');
ok($zip->set_number('6838504')->is_valid_number, '国立大学法人 鳥取大学医学部 附属病院');
ok($zip->set_number('6838505')->is_valid_number, '株式会社 丸合');
ok($zip->set_number('6838506')->is_valid_number, '株式会社 さんれいフーズ');
ok($zip->set_number('6838508')->is_valid_number, '株式会社 雪印 アクセス山陰支店');
ok($zip->set_number('6838510')->is_valid_number, '株式会社 米子しんまち天満屋');
ok($zip->set_number('6838511')->is_valid_number, '協同組合 やよいデパート');
ok($zip->set_number('6838512')->is_valid_number, '県立米子西高等学校');
ok($zip->set_number('6838516')->is_valid_number, '山陰酸素工業 株式会社');
ok($zip->set_number('6838518')->is_valid_number, '独立行政法人 国立病院機構 米子医療センター');
ok($zip->set_number('6838520')->is_valid_number, '新日本海新聞社 西部本社');
ok($zip->set_number('6838601')->is_valid_number, '米子信用金庫');
ok($zip->set_number('6838602')->is_valid_number, '山陰信販 株式会社');
ok($zip->set_number('6838603')->is_valid_number, '商工組合中央金庫 米子支店');
ok($zip->set_number('6838604')->is_valid_number, '陸上自衛隊 米子駐屯地');
ok($zip->set_number('6838605')->is_valid_number, '独立行政法人 労働者健康福祉機構 山陰労災病院');
ok($zip->set_number('6838670')->is_valid_number, '株式会社 山陰放送');
ok($zip->set_number('6838686')->is_valid_number, '米子市役所');
ok($zip->set_number('6848501')->is_valid_number, '鳥取県 境港市役所');
ok($zip->set_number('6848511')->is_valid_number, '航空自衛隊 美保基地');
ok($zip->set_number('6848555')->is_valid_number, '鳥取県 済生会 境港総合病院');
ok($zip->set_number('6848585')->is_valid_number, '鳥取県立 境水産高等学校');
ok($zip->set_number('6848601')->is_valid_number, '鳥取県立 境高等学校');
ok($zip->set_number('6848686')->is_valid_number, '境港商工会議所');
ok($zip->set_number('6858512')->is_valid_number, '島根県立 隠岐高等学校');
ok($zip->set_number('6858555')->is_valid_number, '隠岐水産高等学校');
ok($zip->set_number('6858585')->is_valid_number, '隠岐の島町役場');
ok($zip->set_number('6858601')->is_valid_number, '隠岐支庁');
ok($zip->set_number('6858666')->is_valid_number, '西郷税務署');
ok($zip->set_number('6890592')->is_valid_number, '鳥取市役所 青谷町総合支所');
ok($zip->set_number('6890595')->is_valid_number, '鳥取県立 青谷高等学校');
ok($zip->set_number('6891192')->is_valid_number, 'ダイヤモンド電機 株式会社');
ok($zip->set_number('6891193')->is_valid_number, '日本セラミック 株式会社');
ok($zip->set_number('6892292')->is_valid_number, '北栄町役場 大栄庁舎');
ok($zip->set_number('6892293')->is_valid_number, '株式会社 サンセキ');
ok($zip->set_number('6892295')->is_valid_number, '鳥取県立 鳥取中央育英高等学校');
ok($zip->set_number('6892298')->is_valid_number, 'JA鳥取中央 大栄支所');
ok($zip->set_number('6892392')->is_valid_number, '琴浦町役場');
ok($zip->set_number('6892393')->is_valid_number, '大山乳業農業 協同組合');
ok($zip->set_number('6892395')->is_valid_number, '東伯町農業 協同組合');
ok($zip->set_number('6893492')->is_valid_number, '米子市 淀江支所');
ok($zip->set_number('6893592')->is_valid_number, '王子製紙 株式会社 米子工場');
ok($zip->set_number('6894292')->is_valid_number, '伯耆町役場 溝口分庁舎');
ok($zip->set_number('6895292')->is_valid_number, '日南町役場');
ok($zip->set_number('6900393')->is_valid_number, '中国電力 株式会社 島根原子力発電所');
ok($zip->set_number('6900396')->is_valid_number, '松江市役所 鹿島支所');
ok($zip->set_number('6901492')->is_valid_number, '有限会社 日本庭園 由志園');
ok($zip->set_number('6902192')->is_valid_number, '松江市役所 八雲支所');
ok($zip->set_number('6902198')->is_valid_number, '小松電機産業 株式会社');
ok($zip->set_number('6908501')->is_valid_number, '島根県庁');
ok($zip->set_number('6908502')->is_valid_number, '島根県 教育委員会');
ok($zip->set_number('6908503')->is_valid_number, '島根県信用保証協会');
ok($zip->set_number('6908504')->is_valid_number, '島根大学');
ok($zip->set_number('6908505')->is_valid_number, '松江税務署');
ok($zip->set_number('6908506')->is_valid_number, '松江赤十字病院');
ok($zip->set_number('6908507')->is_valid_number, '県立松江農林高等学校');
ok($zip->set_number('6908508')->is_valid_number, '株式会社 エフエム山陰');
ok($zip->set_number('6908509')->is_valid_number, '松江市立病院');
ok($zip->set_number('6908510')->is_valid_number, '島根県 警察本部');
ok($zip->set_number('6908511')->is_valid_number, '日本年金機構 松江年金事務所');
ok($zip->set_number('6908512')->is_valid_number, '松江警察署');
ok($zip->set_number('6908513')->is_valid_number, '松江土建 株式会社');
ok($zip->set_number('6908514')->is_valid_number, '中国電力 株式会社 島根支社');
ok($zip->set_number('6908515')->is_valid_number, '中国電力 株式会社 松江営業所');
ok($zip->set_number('6908516')->is_valid_number, '中国労働金庫 島根県営業本部');
ok($zip->set_number('6908517')->is_valid_number, '学校法人 淞南学園');
ok($zip->set_number('6908518')->is_valid_number, '松江工業高等専門学校');
ok($zip->set_number('6908519')->is_valid_number, '県立松江南高等学校');
ok($zip->set_number('6908520')->is_valid_number, '西日本電信電話 株式会社 島根支店');
ok($zip->set_number('6908521')->is_valid_number, '松江市消防本部');
ok($zip->set_number('6908522')->is_valid_number, '松江生協病院');
ok($zip->set_number('6908523')->is_valid_number, '松江地方裁判所');
ok($zip->set_number('6908525')->is_valid_number, '県立松江商業高等学校');
ok($zip->set_number('6908526')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('6908527')->is_valid_number, 'パナソニックエレクトロニックデバイス松江 (株)');
ok($zip->set_number('6908528')->is_valid_number, '県立松江工業高等学校');
ok($zip->set_number('6908530')->is_valid_number, '株式会社 マイカル松江サティ');
ok($zip->set_number('6908531')->is_valid_number, '全国健康保険協会 島根支部');
ok($zip->set_number('6908532')->is_valid_number, '中国電力 株式会社 山陰電力所');
ok($zip->set_number('6908533')->is_valid_number, '島根県 社会保険診療報酬支払基金');
ok($zip->set_number('6908535')->is_valid_number, '島根県医師会');
ok($zip->set_number('6908536')->is_valid_number, '日本年金機構 島根事務センター');
ok($zip->set_number('6908539')->is_valid_number, '株式会社 山陰合同銀行 クレジットカードセンター');
ok($zip->set_number('6908540')->is_valid_number, '松江市役所');
ok($zip->set_number('6908550')->is_valid_number, 'カナツ技建工業 株式会社');
ok($zip->set_number('6908551')->is_valid_number, '島根県 東部県民センター');
ok($zip->set_number('6908552')->is_valid_number, '松江保健生活協同組合');
ok($zip->set_number('6908553')->is_valid_number, '日本銀行 松江支店');
ok($zip->set_number('6908554')->is_valid_number, '松江刑務所');
ok($zip->set_number('6908555')->is_valid_number, '株式会社 一畑百貨店');
ok($zip->set_number('6908556')->is_valid_number, '国立療養所 松江病院');
ok($zip->set_number('6908558')->is_valid_number, '株式会社 ユニコン');
ok($zip->set_number('6908560')->is_valid_number, '全労済島根県本部');
ok($zip->set_number('6908567')->is_valid_number, '協同組合 島根県鐵工会');
ok($zip->set_number('6908577')->is_valid_number, '日本通運 株式会社 松江支店');
ok($zip->set_number('6908580')->is_valid_number, '株式会社 山陰合同銀行 事務センター');
ok($zip->set_number('6908588')->is_valid_number, 'フジキ 学園通り店');
ok($zip->set_number('6908601')->is_valid_number, 'NHK 松江放送局');
ok($zip->set_number('6908611')->is_valid_number, '株式会社 千茶荘');
ok($zip->set_number('6908660')->is_valid_number, '島根県信用農業協同組合連合会');
ok($zip->set_number('6908666')->is_valid_number, '山陰中央テレビジョン放送 株式会社');
ok($zip->set_number('6908668')->is_valid_number, '株式会社 山陰中央新報社');
ok($zip->set_number('6908670')->is_valid_number, '日本郵政グループ 労働組合中国地方本部島根連絡協議会');
ok($zip->set_number('6908677')->is_valid_number, 'ごうぎんリース 株式会社');
ok($zip->set_number('6908686')->is_valid_number, '株式会社 山陰合同銀行');
ok($zip->set_number('6908688')->is_valid_number, '株式会社 島根銀行');
ok($zip->set_number('6908794')->is_valid_number, '島根地域センター');
ok($zip->set_number('6918601')->is_valid_number, '出雲市役所 平田支所');
ok($zip->set_number('6918602')->is_valid_number, '株式会社 ソノ');
ok($zip->set_number('6928506')->is_valid_number, '(株) さんれいフーズ安来営業所');
ok($zip->set_number('6928510')->is_valid_number, '株式会社 フーズマーケットホック');
ok($zip->set_number('6928550')->is_valid_number, '高林商事 株式会社');
ok($zip->set_number('6928601')->is_valid_number, '株式会社 プロテリアル 安来工場');
ok($zip->set_number('6928606')->is_valid_number, '株式会社 プロテリアル安来製作所');
ok($zip->set_number('6928686')->is_valid_number, '安来市役所');
ok($zip->set_number('6938501')->is_valid_number, '島根大学 医学部');
ok($zip->set_number('6938510')->is_valid_number, '中国電力 株式会社 出雲営業所');
ok($zip->set_number('6938511')->is_valid_number, '出雲総務事務所');
ok($zip->set_number('6938523')->is_valid_number, '松江地方裁判所 出雲支部');
ok($zip->set_number('6938530')->is_valid_number, '出雲市役所');
ok($zip->set_number('6938531')->is_valid_number, '出雲市教育委員会');
ok($zip->set_number('6938533')->is_valid_number, '中国電力 株式会社 出雲電力所');
ok($zip->set_number('6938550')->is_valid_number, '島根県立 看護短期大学');
ok($zip->set_number('6938555')->is_valid_number, '島根県立 中央病院');
ok($zip->set_number('6938566')->is_valid_number, '株式会社 一畑百貨店');
ok($zip->set_number('6938585')->is_valid_number, '島根県農業協同組合 出雲地区本部');
ok($zip->set_number('6938587')->is_valid_number, 'いずも農業 協同組合 ラピタ');
ok($zip->set_number('6938601')->is_valid_number, '株式会社 山陰合同銀行 出雲支店');
ok($zip->set_number('6938614')->is_valid_number, '島根中央信用金庫');
ok($zip->set_number('6938686')->is_valid_number, '出雲 税務署');
ok($zip->set_number('6938689')->is_valid_number, '広島国税局業務センター出雲分室');
ok($zip->set_number('6948501')->is_valid_number, '石見大田税務署');
ok($zip->set_number('6948502')->is_valid_number, '大田市役所');
ok($zip->set_number('6958501')->is_valid_number, '江津市役所');
ok($zip->set_number('6958502')->is_valid_number, '江の川高等学校');
ok($zip->set_number('6958505')->is_valid_number, '社会福祉法人 恩賜財団 島根県済生会 江津総合病院');
ok($zip->set_number('6958577')->is_valid_number, '株式会社 しちだ・教育研究所');
ok($zip->set_number('6958585')->is_valid_number, '協同組合 グリーンモール');
ok($zip->set_number('6960192')->is_valid_number, '邑南町役場');
ok($zip->set_number('6960193')->is_valid_number, '公立邑智病院');
ok($zip->set_number('6960195')->is_valid_number, '島根おおち農協 石見基幹支所');
ok($zip->set_number('6960198')->is_valid_number, '矢上高等学校');
ok($zip->set_number('6960393')->is_valid_number, '邑南町役場 瑞穂町支所');
ok($zip->set_number('6960692')->is_valid_number, '邑南町役場 羽須美支所');
ok($zip->set_number('6968510')->is_valid_number, '川本総務事務所');
ok($zip->set_number('6970492')->is_valid_number, '島根あさひ社会復帰促進センター');
ok($zip->set_number('6978501')->is_valid_number, '浜田市');
ok($zip->set_number('6978511')->is_valid_number, '浜田医療センター');
ok($zip->set_number('6978512')->is_valid_number, '浜田医療センター附属看護学校');
ok($zip->set_number('6978585')->is_valid_number, 'NTT西日本電信電話 株式会社 島根西支店 (株) NTTネオメイト 中国浜田営業所');
ok($zip->set_number('6978686')->is_valid_number, '浜田 税務署');
ok($zip->set_number('6978789')->is_valid_number, '島根県立 浜田高等学校 定時制・通信制課程');
ok($zip->set_number('6980292')->is_valid_number, '益田市役所美都総合支所');
ok($zip->set_number('6988501')->is_valid_number, '益田赤十字病院');
ok($zip->set_number('6988503')->is_valid_number, '株式会社 キヌヤ');
ok($zip->set_number('6988504')->is_valid_number, '株式会社 イズミゆめタウン益田');
ok($zip->set_number('6988505')->is_valid_number, '益田サティ');
ok($zip->set_number('6988506')->is_valid_number, 'ソニーネットワークコミュニケーションズ 株式会社');
ok($zip->set_number('6988650')->is_valid_number, '益田市役所');
ok($zip->set_number('6988651')->is_valid_number, '益田 税務署');
ok($zip->set_number('6990192')->is_valid_number, '東出雲町役場');
ok($zip->set_number('6990193')->is_valid_number, 'フジキコーポレーション 株式会社');
ok($zip->set_number('6990292')->is_valid_number, '松江市役所 玉湯支所');
ok($zip->set_number('6990293')->is_valid_number, '独立行政法人 地域医療機能推進機構 玉造病院');
ok($zip->set_number('6990492')->is_valid_number, '島根県立 宍道高等学校');
ok($zip->set_number('6990496')->is_valid_number, '株式会社 原商');
ok($zip->set_number('6990588')->is_valid_number, '一般社団法人 日本アマチュア無線連盟 JARL QSLビューロー');
ok($zip->set_number('6990592')->is_valid_number, '出雲市役所 斐川支所');
ok($zip->set_number('6990593')->is_valid_number, '島根県農業協同組合 斐川地区本部');
ok($zip->set_number('6990696')->is_valid_number, '株式会社 出雲村田製作所');
ok($zip->set_number('6990697')->is_valid_number, 'JA全農 島根県本部');
ok($zip->set_number('6990792')->is_valid_number, '出雲市役所 大社支所');
ok($zip->set_number('6991292')->is_valid_number, '雲南市役所 大東総合センター');
ok($zip->set_number('6991293')->is_valid_number, '公立雲南総合病院');
ok($zip->set_number('6991392')->is_valid_number, '雲南市役所');
ok($zip->set_number('6991393')->is_valid_number, 'ホシザキ電機 株式会社 島根工場');
ok($zip->set_number('6991394')->is_valid_number, '島根三洋電機 株式会社');
ok($zip->set_number('6991395')->is_valid_number, '雲南農業 協同組合');
ok($zip->set_number('6991396')->is_valid_number, '東部県民センター 雲南事務所');
ok($zip->set_number('6991592')->is_valid_number, '奥出雲町役場');
ok($zip->set_number('6991898')->is_valid_number, '島根県立 横田高等学校');
ok($zip->set_number('6992598')->is_valid_number, '大田市役所 温泉津支所');
ok($zip->set_number('6994292')->is_valid_number, '江津市 桜江支所');
ok($zip->set_number('6994298')->is_valid_number, '今井産業 株式会社');
ok($zip->set_number('6994692')->is_valid_number, '美郷町役場');
ok($zip->set_number('6995292')->is_valid_number, '津和野町役場');
ok($zip->set_number('6995695')->is_valid_number, '津和野町 教育委員会');
ok($zip->set_number('7008501')->is_valid_number, '日本年金機構 中国ブロック本部 岡山広域事務センター');
ok($zip->set_number('7008502')->is_valid_number, '株式会社 天満屋ストア');
ok($zip->set_number('7008503')->is_valid_number, '西日本メディカルリンク 株式会社');
ok($zip->set_number('7008504')->is_valid_number, '株式会社 両備システムズ 豊成事業所');
ok($zip->set_number('7008505')->is_valid_number, '川崎医科大学総合医療センター');
ok($zip->set_number('7008506')->is_valid_number, '全国健康保険協会 岡山支部');
ok($zip->set_number('7008507')->is_valid_number, '中国電力 株式会社 岡山営業所');
ok($zip->set_number('7008508')->is_valid_number, '株式会社 両備システムズ');
ok($zip->set_number('7008510')->is_valid_number, 'UFJニコス 株式会社 中四国営業部');
ok($zip->set_number('7008511')->is_valid_number, '岡山済生会総合病院');
ok($zip->set_number('7008512')->is_valid_number, '岡山県警察本部');
ok($zip->set_number('7008514')->is_valid_number, '株式会社 シバタ 岡山支店');
ok($zip->set_number('7008515')->is_valid_number, '株式会社 ホテルグランヴィア岡山');
ok($zip->set_number('7008516')->is_valid_number, 'ノートルダム清心女子大学');
ok($zip->set_number('7008517')->is_valid_number, '自衛隊 岡山地方連絡部');
ok($zip->set_number('7008518')->is_valid_number, '両備ホールディングス 株式会社');
ok($zip->set_number('7008519')->is_valid_number, '西日本電信電話 株式会社 岡山支店');
ok($zip->set_number('7008520')->is_valid_number, '株式会社 岡山高島屋');
ok($zip->set_number('7008521')->is_valid_number, '三井生命保険 株式会社');
ok($zip->set_number('7008522')->is_valid_number, '財団法人 社会保険健康事業財団 岡山県支部');
ok($zip->set_number('7008525')->is_valid_number, '岡山大学大学院 医歯薬学総合研究科(歯学部)、岡山大学病院(歯科)');
ok($zip->set_number('7008526')->is_valid_number, '株式会社 岡山文具');
ok($zip->set_number('7008528')->is_valid_number, '株式会社 カワニシ');
ok($zip->set_number('7008530')->is_valid_number, '岡山大学');
ok($zip->set_number('7008531')->is_valid_number, '三井住友海上火災保険 株式会社 岡山自動車営業部');
ok($zip->set_number('7008532')->is_valid_number, '中国四国農政局');
ok($zip->set_number('7008533')->is_valid_number, '岡山県 社会保険診療報酬支払基金');
ok($zip->set_number('7008534')->is_valid_number, '株式会社 山陽新聞社 編集局');
ok($zip->set_number('7008535')->is_valid_number, '岡山市 農業協同組合');
ok($zip->set_number('7008538')->is_valid_number, '株式会社 トミヤコーポレーション');
ok($zip->set_number('7008539')->is_valid_number, '中国地方整備局 岡山国道事務所');
ok($zip->set_number('7008540')->is_valid_number, '株式会社 荒木組');
ok($zip->set_number('7008544')->is_valid_number, '岡山市役所');
ok($zip->set_number('7008545')->is_valid_number, '株式会社 金辺商会');
ok($zip->set_number('7008546')->is_valid_number, '岡山市保健福祉会館');
ok($zip->set_number('7008549')->is_valid_number, 'コーホク印刷 株式会社');
ok($zip->set_number('7008550')->is_valid_number, '株式会社 大本組');
ok($zip->set_number('7008551')->is_valid_number, '旭電業 株式会社');
ok($zip->set_number('7008552')->is_valid_number, '(株) 三好野本店えきまえミヨシノ');
ok($zip->set_number('7008554')->is_valid_number, '岡山市役所 (分庁舎)');
ok($zip->set_number('7008555')->is_valid_number, '中国財務局 岡山財務事務所');
ok($zip->set_number('7008556')->is_valid_number, '岡山商工会議所');
ok($zip->set_number('7008557')->is_valid_number, '岡山市立市民病院');
ok($zip->set_number('7008558')->is_valid_number, '岡山大学大学院 医歯薬学総合研究科(医学部)、岡山大学病院(医科)');
ok($zip->set_number('7008560')->is_valid_number, '浅野産業 株式会社');
ok($zip->set_number('7008561')->is_valid_number, '株式会社 マイカル岡山ビブレ');
ok($zip->set_number('7008562')->is_valid_number, '株式会社 カイタックトレーディング 問屋町');
ok($zip->set_number('7008567')->is_valid_number, '社団法人 岡山トラック協会');
ok($zip->set_number('7008568')->is_valid_number, '岡山県国民健康保険団体連合会');
ok($zip->set_number('7008569')->is_valid_number, 'こくみん共済coop岡山推進本部');
ok($zip->set_number('7008570')->is_valid_number, '岡山県庁');
ok($zip->set_number('7008571')->is_valid_number, 'あいおいニッセイ同和損害保険 株式会社');
ok($zip->set_number('7008572')->is_valid_number, '日本年金機構 岡山西年金事務所');
ok($zip->set_number('7008575')->is_valid_number, '富士通 株式会社 岡山支店');
ok($zip->set_number('7008577')->is_valid_number, '高塚ライフサイエンス 株式会社');
ok($zip->set_number('7008578')->is_valid_number, '株式会社 タビックスジャパン 岡山支店');
ok($zip->set_number('7008580')->is_valid_number, 'RSK山陽放送 株式会社');
ok($zip->set_number('7008581')->is_valid_number, '株式会社 瀬戸内海放送 岡山本社');
ok($zip->set_number('7008584')->is_valid_number, '真言宗 薬師院');
ok($zip->set_number('7008585')->is_valid_number, '東京海上日動火災保険 株式会社 岡山支店');
ok($zip->set_number('7008586')->is_valid_number, '株式会社 カイタックホールディングス');
ok($zip->set_number('7008589')->is_valid_number, 'ワールドトレーディングサービス&Co');
ok($zip->set_number('7008601')->is_valid_number, '岡山商科大学');
ok($zip->set_number('7008602')->is_valid_number, '岡山県農業共済組合連合会');
ok($zip->set_number('7008603')->is_valid_number, '岡山食品容器 株式会社');
ok($zip->set_number('7008604')->is_valid_number, '岡山県 備前県民局');
ok($zip->set_number('7008605')->is_valid_number, '新生電機 株式会社');
ok($zip->set_number('7008606')->is_valid_number, '大和流通システム 株式会社');
ok($zip->set_number('7008607')->is_valid_number, '総合病院 岡山赤十字病院');
ok($zip->set_number('7008608')->is_valid_number, '蜂谷工業 株式会社');
ok($zip->set_number('7008610')->is_valid_number, '株式会社 イーオン');
ok($zip->set_number('7008611')->is_valid_number, '岡山労働局');
ok($zip->set_number('7008614')->is_valid_number, 'スミクラ 株式会社');
ok($zip->set_number('7008615')->is_valid_number, '岡山社会保険事務局');
ok($zip->set_number('7008616')->is_valid_number, '岡山地方法務局');
ok($zip->set_number('7008617')->is_valid_number, '株式会社 エイト日本技術開発');
ok($zip->set_number('7008618')->is_valid_number, '株式会社 全備');
ok($zip->set_number('7008620')->is_valid_number, '株式会社 夢番地');
ok($zip->set_number('7008621')->is_valid_number, '日本放送協会 岡山放送局');
ok($zip->set_number('7008623')->is_valid_number, '商工中金 岡山支店');
ok($zip->set_number('7008625')->is_valid_number, '株式会社 天満屋 岡山店');
ok($zip->set_number('7008628')->is_valid_number, '株式会社 中国銀行');
ok($zip->set_number('7008634')->is_valid_number, '株式会社 山陽新聞社');
ok($zip->set_number('7008635')->is_valid_number, '岡山放送 株式会社');
ok($zip->set_number('7008639')->is_valid_number, 'おかやま信用金庫');
ok($zip->set_number('7008640')->is_valid_number, '野村証券 株式会社 岡山支店');
ok($zip->set_number('7008645')->is_valid_number, '清水産業 株式会社');
ok($zip->set_number('7008650')->is_valid_number, 'イオンリテール 株式会社 イオン岡山店');
ok($zip->set_number('7008655')->is_valid_number, '岡山東税務署');
ok($zip->set_number('7008657')->is_valid_number, '全日信販 株式会社');
ok($zip->set_number('7008660')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('7008666')->is_valid_number, 'RSK山陽放送 株式会社');
ok($zip->set_number('7008677')->is_valid_number, 'テレビせとうち 株式会社');
ok($zip->set_number('7008678')->is_valid_number, '岡山教育事務所');
ok($zip->set_number('7008680')->is_valid_number, 'トラスコ中山 株式会社 プラネット山陽');
ok($zip->set_number('7008681')->is_valid_number, '広島国税局業務センター岡山西分室');
ok($zip->set_number('7008686')->is_valid_number, '株式会社 ベネッセコーポレーション 本社');
ok($zip->set_number('7008687')->is_valid_number, '株式会社 ベネッセコーポレーション 本社');
ok($zip->set_number('7008688')->is_valid_number, '株式会社 ベネッセコーポレーション 本社');
ok($zip->set_number('7008689')->is_valid_number, '広島国税局業務センター岡山東分室');
ok($zip->set_number('7008701')->is_valid_number, '木原興業 株式会社');
ok($zip->set_number('7008707')->is_valid_number, '日本銀行 岡山支店');
ok($zip->set_number('7008718')->is_valid_number, 'カナリア産業 株式会社');
ok($zip->set_number('7008722')->is_valid_number, '全国農業協同組合連合会 岡山県本部');
ok($zip->set_number('7008727')->is_valid_number, '農林中央金庫 岡山支店');
ok($zip->set_number('7008731')->is_valid_number, '中銀リース 株式会社');
ok($zip->set_number('7008732')->is_valid_number, '岡山県 信用保証協会');
ok($zip->set_number('7008733')->is_valid_number, 'アイサワ工業 株式会社');
ok($zip->set_number('7008734')->is_valid_number, '株式会社 山陽新聞社 新聞製作センター');
ok($zip->set_number('7008738')->is_valid_number, '第一生命保険 株式会社 岡山支社');
ok($zip->set_number('7008761')->is_valid_number, '岡山県立岡山大安寺中等教育学校');
ok($zip->set_number('7008794')->is_valid_number, '岡山地域センター');
ok($zip->set_number('7010192')->is_valid_number, '川崎医科大学');
ok($zip->set_number('7010193')->is_valid_number, '川崎医療福祉大学');
ok($zip->set_number('7010195')->is_valid_number, 'ノートルダム清心学園');
ok($zip->set_number('7010197')->is_valid_number, '中国学園');
ok($zip->set_number('7010292')->is_valid_number, '小橋工業 株式会社');
ok($zip->set_number('7010295')->is_valid_number, '全農岡山県本部総合流通センター');
ok($zip->set_number('7010296')->is_valid_number, '岡山市民生活協同組合');
ok($zip->set_number('7010297')->is_valid_number, '岡山県立 興陽高等学校');
ok($zip->set_number('7010298')->is_valid_number, '岡山県 環境保健センター');
ok($zip->set_number('7010393')->is_valid_number, '株式会社 ハローズ');
ok($zip->set_number('7010398')->is_valid_number, '株式会社 ジップ早島センター');
ok($zip->set_number('7011192')->is_valid_number, '独立行政法人 国立病院機構 岡山医療センター');
ok($zip->set_number('7011195')->is_valid_number, '独立行政法人 国立病院機構 岡山医療センター附属岡山看護学校');
ok($zip->set_number('7011292')->is_valid_number, '黒住教本部');
ok($zip->set_number('7011296')->is_valid_number, '岡山県 工業技術センター');
ok($zip->set_number('7012292')->is_valid_number, '赤磐市 赤坂支所');
ok($zip->set_number('7012595')->is_valid_number, '赤磐市 吉井支所');
ok($zip->set_number('7013292')->is_valid_number, '備前市 日生総合支所');
ok($zip->set_number('7013293')->is_valid_number, '日生信用金庫');
ok($zip->set_number('7014292')->is_valid_number, '瀬戸内市役所');
ok($zip->set_number('7014293')->is_valid_number, '瀬戸内市役所 長船支所');
ok($zip->set_number('7014392')->is_valid_number, '瀬戸内市役所 牛窓支所');
ok($zip->set_number('7014394')->is_valid_number, '日本オリーブ 株式会社');
ok($zip->set_number('7014398')->is_valid_number, '株式会社 元浜組');
ok($zip->set_number('7014592')->is_valid_number, '国立療養所 長島愛生園');
ok($zip->set_number('7014593')->is_valid_number, '国立療養所 邑久光明園');
ok($zip->set_number('7028501')->is_valid_number, '株式会社 源吉兆庵');
ok($zip->set_number('7028502')->is_valid_number, '株式会社 アルファ');
ok($zip->set_number('7028503')->is_valid_number, '岡山県立 岡山芳泉高等学校');
ok($zip->set_number('7028505')->is_valid_number, '岡山労災病院');
ok($zip->set_number('7028506')->is_valid_number, '同和鉱業 株式会社');
ok($zip->set_number('7028507')->is_valid_number, '三井製糖 株式会社 岡山工場');
ok($zip->set_number('7028508')->is_valid_number, '財団法人 慈圭会 慈圭病院');
ok($zip->set_number('7028510')->is_valid_number, 'トラスコ中山 株式会社 岡山支店');
ok($zip->set_number('7028511')->is_valid_number, '株式会社 岡山県水');
ok($zip->set_number('7028512')->is_valid_number, '双葉電機 株式会社');
ok($zip->set_number('7028515')->is_valid_number, 'ヤンマーアグリ 株式会社');
ok($zip->set_number('7028544')->is_valid_number, '岡山市 南区役所');
ok($zip->set_number('7028601')->is_valid_number, '株式会社 クラレ 岡山事業所');
ok($zip->set_number('7028602')->is_valid_number, '株式会社 岡山丸果');
ok($zip->set_number('7028603')->is_valid_number, '岡山宮地弘商事 株式会社');
ok($zip->set_number('7028605')->is_valid_number, 'トリツ機工 株式会社');
ok($zip->set_number('7028606')->is_valid_number, '小林機工 株式会社');
ok($zip->set_number('7028607')->is_valid_number, '株式会社 前嶋');
ok($zip->set_number('7028609')->is_valid_number, '同和工営 株式会社');
ok($zip->set_number('7038501')->is_valid_number, '山陽学園大学.山陽学園短期大学');
ok($zip->set_number('7038502')->is_valid_number, 'オムロン 株式会社 岡山事業所');
ok($zip->set_number('7038505')->is_valid_number, 'オハヨー乳業 株式会社');
ok($zip->set_number('7038508')->is_valid_number, '財団法人 岡山県教育会');
ok($zip->set_number('7038510')->is_valid_number, '中国セキスイ工業 株式会社');
ok($zip->set_number('7038511')->is_valid_number, '総合病院 岡山協立病院');
ok($zip->set_number('7038516')->is_valid_number, '就実大学.就実短期大学');
ok($zip->set_number('7038520')->is_valid_number, '財団法人 林精神医学研究所 附属林道倫精神科神経科病院');
ok($zip->set_number('7038530')->is_valid_number, '株式会社 ヒラタ');
ok($zip->set_number('7038533')->is_valid_number, '日本年金機構 岡山東年金事務所');
ok($zip->set_number('7038544')->is_valid_number, '中区役所');
ok($zip->set_number('7038550')->is_valid_number, '岡山県 学校生活協同組合');
ok($zip->set_number('7038555')->is_valid_number, '社会福祉法人 旭川荘');
ok($zip->set_number('7038558')->is_valid_number, '西日本積水工業 株式会社 岡山製造所');
ok($zip->set_number('7038560')->is_valid_number, '旭川荘厚生専門学院');
ok($zip->set_number('7038566')->is_valid_number, '岡山市中区福祉事務所');
ok($zip->set_number('7038570')->is_valid_number, '株式会社 岡山農栄社');
ok($zip->set_number('7038573')->is_valid_number, '岡山県立 岡山操山高等学校');
ok($zip->set_number('7038574')->is_valid_number, '岡山県立 岡山操山高等学校 通信制課程');
ok($zip->set_number('7038575')->is_valid_number, '岡山中央警察署');
ok($zip->set_number('7038580')->is_valid_number, 'ナカウン 株式会社');
ok($zip->set_number('7038585')->is_valid_number, '岡山四国共和 株式会社');
ok($zip->set_number('7038586')->is_valid_number, '一般社団法人 日本自動車連盟 岡山支部');
ok($zip->set_number('7038588')->is_valid_number, '内山工業 株式会社');
ok($zip->set_number('7038655')->is_valid_number, '株式会社 ジョセイ新聞社');
ok($zip->set_number('7038686')->is_valid_number, '株式会社 中国銀行事務センター');
ok($zip->set_number('7038750')->is_valid_number, '岡山県 学校生活協同組合');
ok($zip->set_number('7048501')->is_valid_number, 'JA西大寺 西大寺農業協同組合');
ok($zip->set_number('7048502')->is_valid_number, '岡山学芸館高等学校');
ok($zip->set_number('7048510')->is_valid_number, '日本エクスラン工業 株式会社 西大寺工場');
ok($zip->set_number('7048555')->is_valid_number, '東区役所');
ok($zip->set_number('7048588')->is_valid_number, 'カーツ 株式会社 本部');
ok($zip->set_number('7058501')->is_valid_number, '市立備前病院');
ok($zip->set_number('7058502')->is_valid_number, '岡山東農業協同組合 備前支店');
ok($zip->set_number('7058507')->is_valid_number, '岡山県立 備前緑陽高等学校');
ok($zip->set_number('7058510')->is_valid_number, 'NTN 株式会社 岡山製作所');
ok($zip->set_number('7058555')->is_valid_number, '岡山大鵬薬品 株式会社');
ok($zip->set_number('7058558')->is_valid_number, '備前商工会議所');
ok($zip->set_number('7058575')->is_valid_number, '宗教法人 熊山油滝神社');
ok($zip->set_number('7058577')->is_valid_number, '品川リフラクトリーズ 株式会社 技術研究所');
ok($zip->set_number('7058585')->is_valid_number, 'パナソニック 株式会社 オートモーティブ&インダストリアルシステムズ社 セミコンダクター事業部 岡山工場');
ok($zip->set_number('7058588')->is_valid_number, '日生運輸 株式会社');
ok($zip->set_number('7058602')->is_valid_number, '備前市役所');
ok($zip->set_number('7058603')->is_valid_number, '備前信用金庫');
ok($zip->set_number('7058614')->is_valid_number, '興亜耐火工業 株式会社');
ok($zip->set_number('7058615')->is_valid_number, '品川リフラクトリーズ 株式会社 岡山工場');
ok($zip->set_number('7068501')->is_valid_number, '三井造船生活 協同組合');
ok($zip->set_number('7068510')->is_valid_number, '玉野市役所');
ok($zip->set_number('7068511')->is_valid_number, '三井金属鉱業株式会社 金属事業部 日比製煉所');
ok($zip->set_number('7068531')->is_valid_number, '地方独立行政法人 玉野医療センター 玉野市民病院');
ok($zip->set_number('7068533')->is_valid_number, '玉野商工会議所');
ok($zip->set_number('7068555')->is_valid_number, '岡山県立玉野高等学校');
ok($zip->set_number('7068588')->is_valid_number, '三菱重工マリタイムシステムズ 株式会社');
ok($zip->set_number('7068651')->is_valid_number, '株式会社 三井E&Sホールディングス玉野総合事務所');
ok($zip->set_number('7068655')->is_valid_number, '玉野税務署');
ok($zip->set_number('7078501')->is_valid_number, '美作市役所');
ok($zip->set_number('7078502')->is_valid_number, 'みまさか商工会');
ok($zip->set_number('7078585')->is_valid_number, '岡山県 美作県民局 勝英支局');
ok($zip->set_number('7080392')->is_valid_number, '鏡野町役場');
ok($zip->set_number('7080393')->is_valid_number, '株式会社 山田養蜂場');
ok($zip->set_number('7080698')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構 人形峠環境技術センター');
ok($zip->set_number('7081193')->is_valid_number, 'トーステ 株式会社 サニタリー事業本部');
ok($zip->set_number('7081198')->is_valid_number, '山陽ロード工業 株式会社');
ok($zip->set_number('7081392')->is_valid_number, '奈義町役場');
ok($zip->set_number('7081393')->is_valid_number, '陸上自衛隊 日本原駐屯地');
ok($zip->set_number('7088501')->is_valid_number, '津山市役所');
ok($zip->set_number('7088502')->is_valid_number, '津山卸センター');
ok($zip->set_number('7088503')->is_valid_number, '津山総合食品卸売市場');
ok($zip->set_number('7088505')->is_valid_number, '株式会社 マルイ');
ok($zip->set_number('7088506')->is_valid_number, '岡山県美作県民局');
ok($zip->set_number('7088507')->is_valid_number, 'ナンバ 株式会社');
ok($zip->set_number('7088509')->is_valid_number, '津山工業高等専門学校');
ok($zip->set_number('7088510')->is_valid_number, '津山教育事務所');
ok($zip->set_number('7088511')->is_valid_number, '美作大学');
ok($zip->set_number('7088512')->is_valid_number, '小原産業 株式会社');
ok($zip->set_number('7088515')->is_valid_number, 'イズミ津山店');
ok($zip->set_number('7088516')->is_valid_number, '津山商工会議所');
ok($zip->set_number('7088517')->is_valid_number, 'パナソニック インダストリー 株式会社');
ok($zip->set_number('7088518')->is_valid_number, '作陽高等学校');
ok($zip->set_number('7088519')->is_valid_number, '株式会社 天満屋 津山店');
ok($zip->set_number('7088520')->is_valid_number, 'アルネ・津山');
ok($zip->set_number('7088609')->is_valid_number, '津山公共職業安定所');
ok($zip->set_number('7088652')->is_valid_number, '日本植生 株式会社');
ok($zip->set_number('7088653')->is_valid_number, '中国銀行 津山支店');
ok($zip->set_number('7088654')->is_valid_number, '中国電力 津山営業所');
ok($zip->set_number('7088657')->is_valid_number, '津山 税務署');
ok($zip->set_number('7090492')->is_valid_number, '岡山県備前県民局 東備支局');
ok($zip->set_number('7090494')->is_valid_number, '岡山東農業協同組合 和気支店');
ok($zip->set_number('7090495')->is_valid_number, '和気町役場');
ok($zip->set_number('7090496')->is_valid_number, '株式会社 徳永こいのぼり');
ok($zip->set_number('7090497')->is_valid_number, '北川病院');
ok($zip->set_number('7090498')->is_valid_number, '平病院');
ok($zip->set_number('7090792')->is_valid_number, '赤磐市 熊山支所');
ok($zip->set_number('7090892')->is_valid_number, 'みのる産業 株式会社');
ok($zip->set_number('7090895')->is_valid_number, 'キリンビール 株式会社 岡山工場');
ok($zip->set_number('7090897')->is_valid_number, '岡山市 瀬戸支所');
ok($zip->set_number('7090898')->is_valid_number, '赤磐市役所');
ok($zip->set_number('7091292')->is_valid_number, '南区役所');
ok($zip->set_number('7092192')->is_valid_number, '岡山県 運転免許センター');
ok($zip->set_number('7092196')->is_valid_number, 'カバヤ食品 株式会社');
ok($zip->set_number('7092198')->is_valid_number, '岡山市役所 御津支所');
ok($zip->set_number('7092393')->is_valid_number, '吉備高原学園高等学校');
ok($zip->set_number('7092398')->is_valid_number, '吉備中央町役場 加茂川庁舎');
ok($zip->set_number('7093198')->is_valid_number, '岡山市 北区役所 建部支所');
ok($zip->set_number('7093494')->is_valid_number, '岡山県 総合畜産センター');
ok($zip->set_number('7093497')->is_valid_number, '津山農業協同組合 旭支店');
ok($zip->set_number('7093498')->is_valid_number, '美咲町 旭総合支所');
ok($zip->set_number('7094292')->is_valid_number, '美作市役所 作東総合支所');
ok($zip->set_number('7094392')->is_valid_number, '株式会社 ミルキーエイジ');
ok($zip->set_number('7100292')->is_valid_number, '学校法人 作陽学園');
ok($zip->set_number('7100293')->is_valid_number, '倉敷市 船穂支所');
ok($zip->set_number('7100294')->is_valid_number, 'JA岡山西 農業協同組合 船穂支店');
ok($zip->set_number('7100298')->is_valid_number, '株式会社 北原産業');
ok($zip->set_number('7101398')->is_valid_number, '倉敷市役所 真備支所');
ok($zip->set_number('7108501')->is_valid_number, '萩原 株式会社');
ok($zip->set_number('7108505')->is_valid_number, '丸五ゴム工業 株式会社');
ok($zip->set_number('7108511')->is_valid_number, '岡山学院大学・岡山短期大学');
ok($zip->set_number('7108520')->is_valid_number, '岡山地方法務局 倉敷支局');
ok($zip->set_number('7108522')->is_valid_number, '財団法人 倉敷成人病センター');
ok($zip->set_number('7108525')->is_valid_number, '株式会社 帝国データバンク 倉敷支店');
ok($zip->set_number('7108528')->is_valid_number, '株式会社 エフエムくらしき');
ok($zip->set_number('7108530')->is_valid_number, '岡山県 備中県民局');
ok($zip->set_number('7108535')->is_valid_number, '倉敷中央天寿会');
ok($zip->set_number('7108543')->is_valid_number, '中国電力 株式会社 倉敷営業所');
ok($zip->set_number('7108550')->is_valid_number, '株式会社 天満屋 倉敷店');
ok($zip->set_number('7108555')->is_valid_number, '株式会社 日之出運輸');
ok($zip->set_number('7108558')->is_valid_number, '倉敷簡易裁判所');
ok($zip->set_number('7108560')->is_valid_number, 'イオン倉敷ショッピングセンター');
ok($zip->set_number('7108565')->is_valid_number, '倉敷市役所');
ok($zip->set_number('7108575')->is_valid_number, '(財) 大原美術館');
ok($zip->set_number('7108581')->is_valid_number, '倉敷木材 株式会社');
ok($zip->set_number('7108585')->is_valid_number, '倉敷商工会議所');
ok($zip->set_number('7108588')->is_valid_number, '明治乳業 株式会社 中国支店 岡山オフィス');
ok($zip->set_number('7108601')->is_valid_number, '株式会社 中国銀行 倉敷駅前支店');
ok($zip->set_number('7108602')->is_valid_number, '財団法人 倉敷中央病院');
ok($zip->set_number('7108605')->is_valid_number, '日本生命保険相互会社 倉敷支社');
ok($zip->set_number('7108611')->is_valid_number, 'カモ井加工紙 株式会社');
ok($zip->set_number('7108615')->is_valid_number, '株式会社 中国銀行 倉敷支店');
ok($zip->set_number('7108622')->is_valid_number, '株式会社 クラレ 倉敷事業所');
ok($zip->set_number('7108638')->is_valid_number, '平松エンタープライズ 株式会社');
ok($zip->set_number('7108648')->is_valid_number, '倉敷 税務署');
ok($zip->set_number('7108666')->is_valid_number, '藤徳物産 株式会社');
ok($zip->set_number('7108678')->is_valid_number, 'カモ井食品工業 株式会社');
ok($zip->set_number('7108686')->is_valid_number, '株式会社 トクラ');
ok($zip->set_number('7118510')->is_valid_number, '旭化成ケミカルズ 株式会社 水島製造所');
ok($zip->set_number('7118511')->is_valid_number, '日本ゼオン 株式会社 水島工場');
ok($zip->set_number('7118520')->is_valid_number, '瀬戸埠頭 株式会社');
ok($zip->set_number('7118555')->is_valid_number, '倉敷ファッションセンター 株式会社');
ok($zip->set_number('7118565')->is_valid_number, '倉敷市 児島支所');
ok($zip->set_number('7118567')->is_valid_number, '倉敷市 競艇事業局');
ok($zip->set_number('7118588')->is_valid_number, '株式会社 サノヤス・ヒシノ明昌水島製造所');
ok($zip->set_number('7118611')->is_valid_number, '明石被服興業 株式会社');
ok($zip->set_number('7118622')->is_valid_number, '尾崎商事 株式会社');
ok($zip->set_number('7118686')->is_valid_number, '株式会社 ビッグジョン');
ok($zip->set_number('7118688')->is_valid_number, '難波プレス工業 株式会社');
ok($zip->set_number('7128501')->is_valid_number, '三菱自動車工業 株式会社 生産・物流本部 水島製作所');
ok($zip->set_number('7128502')->is_valid_number, '萩原工業 株式会社');
ok($zip->set_number('7128505')->is_valid_number, '倉敷芸術科学大学 倉敷 食と器 専門学校');
ok($zip->set_number('7128511')->is_valid_number, 'JFEスチール 株式会社 西日本製鉄所 倉敷地区');
ok($zip->set_number('7128512')->is_valid_number, 'JFE物流 株式会社');
ok($zip->set_number('7128513')->is_valid_number, '水島合金鉄 株式会社');
ok($zip->set_number('7128514')->is_valid_number, 'JFEシステムズ 株式会社');
ok($zip->set_number('7128525')->is_valid_number, '三菱ガス化学 株式会社 水島工場');
ok($zip->set_number('7128533')->is_valid_number, '関東電化工業 株式会社 水島工場');
ok($zip->set_number('7128534')->is_valid_number, 'トルク 株式会社 山陽支店');
ok($zip->set_number('7128550')->is_valid_number, '株式会社 仁科百貨店 本部');
ok($zip->set_number('7128555')->is_valid_number, '倉敷化工 株式会社');
ok($zip->set_number('7128558')->is_valid_number, 'JX日鉱日石エネルギー 株式会社 水島製油所');
ok($zip->set_number('7128565')->is_valid_number, '倉敷市 水島支所');
ok($zip->set_number('7128567')->is_valid_number, '総合病院 水島協同病院');
ok($zip->set_number('7128577')->is_valid_number, '中国電力 株式会社 水島発電所');
ok($zip->set_number('7128585')->is_valid_number, '東京製鐵 株式会社 岡山工場');
ok($zip->set_number('7128588')->is_valid_number, 'JX日鉱日石エネルギー 株式会社 水島製油所');
ok($zip->set_number('7128611')->is_valid_number, '水島ガス 株式会社');
ok($zip->set_number('7128633')->is_valid_number, '旭化成ケミカルズ 株式会社 水島製造所');
ok($zip->set_number('7128686')->is_valid_number, '水島信用金庫');
ok($zip->set_number('7138501')->is_valid_number, '住友重機械工業 株式会社 岡山製造所');
ok($zip->set_number('7138550')->is_valid_number, '株式会社 クラレ 倉敷事業所 (玉島)');
ok($zip->set_number('7138565')->is_valid_number, '倉敷市 玉島支所');
ok($zip->set_number('7138577')->is_valid_number, '立花容器 株式会社');
ok($zip->set_number('7138588')->is_valid_number, '作陽学園高等学校');
ok($zip->set_number('7138601')->is_valid_number, '玉島 税務署');
ok($zip->set_number('7138666')->is_valid_number, '株式会社 鯛惣');
ok($zip->set_number('7138668')->is_valid_number, '岡山県立 玉島高等学校');
ok($zip->set_number('7138686')->is_valid_number, '玉島信用金庫');
ok($zip->set_number('7138713')->is_valid_number, '赤澤屋 株式会社');
ok($zip->set_number('7140192')->is_valid_number, '浅口市役所 寄島総合支所');
ok($zip->set_number('7141297')->is_valid_number, '矢掛町役場');
ok($zip->set_number('7141298')->is_valid_number, '冨士ベークライト 株式会社');
ok($zip->set_number('7148585')->is_valid_number, 'ローム・ワコー 株式会社');
ok($zip->set_number('7148601')->is_valid_number, '笠岡市役所');
ok($zip->set_number('7158501')->is_valid_number, 'シーピー化成 株式会社');
ok($zip->set_number('7158502')->is_valid_number, '片山工業 株式会社');
ok($zip->set_number('7158503')->is_valid_number, 'タカヤ 株式会社 事業本部');
ok($zip->set_number('7158601')->is_valid_number, '井原市役所');
ok($zip->set_number('7158602')->is_valid_number, 'フェニテック セミコンダクター 株式会社');
ok($zip->set_number('7158603')->is_valid_number, 'タツモ 株式会社');
ok($zip->set_number('7160192')->is_valid_number, '住友電工焼結合金 株式会社');
ok($zip->set_number('7160295')->is_valid_number, '高梁市川上地域局');
ok($zip->set_number('7160396')->is_valid_number, '高梁市備中地域局');
ok($zip->set_number('7161192')->is_valid_number, '吉備中央町役場');
ok($zip->set_number('7161392')->is_valid_number, '高梁市有漢地域局');
ok($zip->set_number('7168501')->is_valid_number, '高梁市役所');
ok($zip->set_number('7168508')->is_valid_number, '学校法人 高梁学園');
ok($zip->set_number('7168511')->is_valid_number, 'イーグル工業 株式会社 岡山事業場');
ok($zip->set_number('7168585')->is_valid_number, '岡山県 高梁地方振興局');
ok($zip->set_number('7168601')->is_valid_number, '高梁商工会議所');
ok($zip->set_number('7178501')->is_valid_number, '美作県民局 真庭支局');
ok($zip->set_number('7180392')->is_valid_number, '公設国際貢献大学校');
ok($zip->set_number('7188501')->is_valid_number, '新見市役所');
ok($zip->set_number('7188510')->is_valid_number, '新見税務署');
ok($zip->set_number('7188530')->is_valid_number, '阿新農業協同組合');
ok($zip->set_number('7188550')->is_valid_number, '岡山県 備中県民局 新見支局');
ok($zip->set_number('7188585')->is_valid_number, '公立大学法人 新見公立大学');
ok($zip->set_number('7190192')->is_valid_number, '浅口市役所 金光総合支所');
ok($zip->set_number('7190195')->is_valid_number, '株式会社 サニーマスコット');
ok($zip->set_number('7190295')->is_valid_number, '浅口市役所');
ok($zip->set_number('7190392')->is_valid_number, '三陽機器 株式会社');
ok($zip->set_number('7190393')->is_valid_number, '天野実業 (株) 里庄第一工場');
ok($zip->set_number('7190398')->is_valid_number, '里庄町役場');
ok($zip->set_number('7191192')->is_valid_number, '総社市役所');
ok($zip->set_number('7191193')->is_valid_number, '吉備信用金庫');
ok($zip->set_number('7191195')->is_valid_number, 'ユニチカ 株式会社 常盤工場');
ok($zip->set_number('7191196')->is_valid_number, 'アマゾン岡山フルフィルメントセンター');
ok($zip->set_number('7191197')->is_valid_number, '岡山県立大学');
ok($zip->set_number('7191198')->is_valid_number, '山崎製パン 株式会社 岡山工場');
ok($zip->set_number('7193192')->is_valid_number, 'ランデス 株式会社');
ok($zip->set_number('7193193')->is_valid_number, '金田病院');
ok($zip->set_number('7193194')->is_valid_number, '真庭市役所 落合庁舎');
ok($zip->set_number('7193195')->is_valid_number, '医療法人 福寿会 河本医院');
ok($zip->set_number('7193197')->is_valid_number, '医療法人社団井口会 総合病院落合病院');
ok($zip->set_number('7193292')->is_valid_number, '真庭市役所');
ok($zip->set_number('7200392')->is_valid_number, '福山市役所 沼隈支所');
ok($zip->set_number('7200397')->is_valid_number, '常石鉄工 株式会社');
ok($zip->set_number('7200398')->is_valid_number, '常石商事 株式会社');
ok($zip->set_number('7202192')->is_valid_number, '株式会社 サンエス');
ok($zip->set_number('7202195')->is_valid_number, '福山市役所 神辺支所');
ok($zip->set_number('7208501')->is_valid_number, '福山市役所');
ok($zip->set_number('7208502')->is_valid_number, '広島県立福山明王台高等学校');
ok($zip->set_number('7208503')->is_valid_number, '福山労働基準監督署');
ok($zip->set_number('7208504')->is_valid_number, '盈進学園');
ok($zip->set_number('7208507')->is_valid_number, '富士建設 株式会社');
ok($zip->set_number('7208508')->is_valid_number, '株式会社 鈴木工務店');
ok($zip->set_number('7208509')->is_valid_number, '広島県トラック協会 福山支部');
ok($zip->set_number('7208510')->is_valid_number, '株式会社 福山臨床検査センター');
ok($zip->set_number('7208511')->is_valid_number, '広島県 東部建設事務所');
ok($zip->set_number('7208511')->is_valid_number, '広島県 東部県税事務所');
ok($zip->set_number('7208511')->is_valid_number, '広島県 東部厚生環境事務所 福山支所');
ok($zip->set_number('7208511')->is_valid_number, '広島県 東部総務事務所');
ok($zip->set_number('7208511')->is_valid_number, '広島県 東部農林水産事務所');
ok($zip->set_number('7208512')->is_valid_number, '福山すこやかセンター');
ok($zip->set_number('7208515')->is_valid_number, '株式会社 栄工社');
ok($zip->set_number('7208517')->is_valid_number, '株式会社 テラダ');
ok($zip->set_number('7208518')->is_valid_number, 'NHK 広島放送局 福山支局');
ok($zip->set_number('7208520')->is_valid_number, '独立行政法人 国立病院機構 福山医療センター');
ok($zip->set_number('7208522')->is_valid_number, '福山YMCA');
ok($zip->set_number('7208524')->is_valid_number, '株式会社 イズミ ゆめタウン福山');
ok($zip->set_number('7208525')->is_valid_number, 'タカヤ商事 株式会社');
ok($zip->set_number('7208526')->is_valid_number, '福山市上下水道局');
ok($zip->set_number('7208527')->is_valid_number, '藤野商事 株式会社');
ok($zip->set_number('7208531')->is_valid_number, '福山東警察署');
ok($zip->set_number('7208535')->is_valid_number, 'あいおい損害保険 株式会社 福山サービスセンター');
ok($zip->set_number('7208536')->is_valid_number, '公立学校共済組合 中国中央病院');
ok($zip->set_number('7208555')->is_valid_number, '(株) エフエムふくやま');
ok($zip->set_number('7208601')->is_valid_number, '株式会社 ジーベック');
ok($zip->set_number('7208636')->is_valid_number, '株式会社 天満屋 福山店');
ok($zip->set_number('7208637')->is_valid_number, '福山ゴム工業 株式会社');
ok($zip->set_number('7208638')->is_valid_number, '池田糖化工業 株式会社');
ok($zip->set_number('7208639')->is_valid_number, '株式会社 広島銀行 福山営業本部');
ok($zip->set_number('7208640')->is_valid_number, '早川ゴム 株式会社');
ok($zip->set_number('7208641')->is_valid_number, '大和證券 株式会社 福山支店');
ok($zip->set_number('7208643')->is_valid_number, '株式会社 みずほ銀行 福山中央支店');
ok($zip->set_number('7208645')->is_valid_number, '商工組合 中央金庫 福山支店');
ok($zip->set_number('7208647')->is_valid_number, '三菱電機 株式会社 福山製作所');
ok($zip->set_number('7208650')->is_valid_number, 'ホーコス 株式会社');
ok($zip->set_number('7218501')->is_valid_number, 'リンクス 株式会社');
ok($zip->set_number('7218502')->is_valid_number, '学校法人 広島加計学園 英数学館小学中学高等学校');
ok($zip->set_number('7218505')->is_valid_number, '株式会社 シーケイエス・チューキ');
ok($zip->set_number('7218510')->is_valid_number, 'JFEスチール 株式会社');
ok($zip->set_number('7218511')->is_valid_number, '福山市民病院');
ok($zip->set_number('7218514')->is_valid_number, '近畿中国四国農業研究センター');
ok($zip->set_number('7218515')->is_valid_number, '株式会社 栄光');
ok($zip->set_number('7218522')->is_valid_number, 'シャープ 株式会社 LSI事業本部');
ok($zip->set_number('7218528')->is_valid_number, '有限会社 柿原銘板製作所');
ok($zip->set_number('7218540')->is_valid_number, '早川ゴム 株式会社');
ok($zip->set_number('7218541')->is_valid_number, '株式会社 フォーデック 福山支社');
ok($zip->set_number('7218543')->is_valid_number, '深江特殊鋼 株式会社');
ok($zip->set_number('7218545')->is_valid_number, '福山暁の星学院');
ok($zip->set_number('7218550')->is_valid_number, 'JFE 三番館');
ok($zip->set_number('7218551')->is_valid_number, '広島大学附属福山中・高等学校');
ok($zip->set_number('7218555')->is_valid_number, '福山通運 株式会社');
ok($zip->set_number('7218556')->is_valid_number, '青山商事 株式会社');
ok($zip->set_number('7218558')->is_valid_number, '池田糖化工業 株式会社');
ok($zip->set_number('7218564')->is_valid_number, 'トラスコ中山 株式会社 福山営業所');
ok($zip->set_number('7218567')->is_valid_number, '日本化薬 株式会社 福山工場');
ok($zip->set_number('7218575')->is_valid_number, '株式会社 シギヤ精機製作所');
ok($zip->set_number('7218576')->is_valid_number, '明和産業 株式会社');
ok($zip->set_number('7218577')->is_valid_number, 'アシード 株式会社');
ok($zip->set_number('7218585')->is_valid_number, 'JFE 二番館');
ok($zip->set_number('7218586')->is_valid_number, '藤井商事 株式会社');
ok($zip->set_number('7218588')->is_valid_number, '社団法人 福山労働会館');
ok($zip->set_number('7218601')->is_valid_number, '福山瓦斯 株式会社');
ok($zip->set_number('7218607')->is_valid_number, '株式会社 エフピコ');
ok($zip->set_number('7218631')->is_valid_number, '丸富 株式会社');
ok($zip->set_number('7218688')->is_valid_number, '山陽染工 株式会社');
ok($zip->set_number('7220392')->is_valid_number, '尾道市役所 御調支所');
ok($zip->set_number('7220393')->is_valid_number, '公立 みつぎ総合病院');
ok($zip->set_number('7221192')->is_valid_number, '世羅町役場');
ok($zip->set_number('7221193')->is_valid_number, '広島県立世羅高等学校');
ok($zip->set_number('7221492')->is_valid_number, '三原市 久井支所');
ok($zip->set_number('7221792')->is_valid_number, '世羅町役場 せらにし支所');
ok($zip->set_number('7222192')->is_valid_number, '万田発酵 株式会社');
ok($zip->set_number('7222193')->is_valid_number, '株式会社 三和ドック');
ok($zip->set_number('7222198')->is_valid_number, '因島鉄工業団地内');
ok($zip->set_number('7222392')->is_valid_number, '尾道市 因島総合支所');
ok($zip->set_number('7222393')->is_valid_number, '日立造船 株式会社 因島工場');
ok($zip->set_number('7222492')->is_valid_number, '尾道市役所 瀬戸田支所');
ok($zip->set_number('7222493')->is_valid_number, '内海造船 株式会社');
ok($zip->set_number('7222494')->is_valid_number, '株式会社 テスビック');
ok($zip->set_number('7228501')->is_valid_number, '尾道市役所');
ok($zip->set_number('7228502')->is_valid_number, '共和工機 株式会社 本社');
ok($zip->set_number('7228503')->is_valid_number, '尾道市立市民病院');
ok($zip->set_number('7228505')->is_valid_number, '尾道税務署');
ok($zip->set_number('7228506')->is_valid_number, '尾道大学');
ok($zip->set_number('7228507')->is_valid_number, '大信産業 株式会社');
ok($zip->set_number('7228508')->is_valid_number, '広島県厚生農業 協同組合連合会 尾道総合病院');
ok($zip->set_number('7228510')->is_valid_number, '尾道市役所 向島支所');
ok($zip->set_number('7228601')->is_valid_number, '丸善製薬 株式会社');
ok($zip->set_number('7228602')->is_valid_number, '尾道造船 株式会社');
ok($zip->set_number('7228604')->is_valid_number, '日立造船 株式会社 向島工場');
ok($zip->set_number('7228605')->is_valid_number, '向島ドック 株式会社');
ok($zip->set_number('7238501')->is_valid_number, '学校法人 山中学園 如水館高等学校 如水館中学校');
ok($zip->set_number('7238510')->is_valid_number, '三原社会保険事務所');
ok($zip->set_number('7238511')->is_valid_number, '三原 税務署');
ok($zip->set_number('7238512')->is_valid_number, '総合病院 三原赤十字病院');
ok($zip->set_number('7238515')->is_valid_number, '広島法務局 三原出張所');
ok($zip->set_number('7238520')->is_valid_number, '広島県 尾三地域事務所');
ok($zip->set_number('7238555')->is_valid_number, '三原商工会議所');
ok($zip->set_number('7238601')->is_valid_number, '三原市役所');
ok($zip->set_number('7238610')->is_valid_number, 'しまなみ信用金庫');
ok($zip->set_number('7238611')->is_valid_number, '帝人 株式会社 三原事業所');
ok($zip->set_number('7238686')->is_valid_number, '興生総合病院');
ok($zip->set_number('7258666')->is_valid_number, '竹原市役所');
ok($zip->set_number('7258686')->is_valid_number, '竹原 税務署');
ok($zip->set_number('7268501')->is_valid_number, '地方独立行政法人 府中市病院機構 府中市民病院');
ok($zip->set_number('7268502')->is_valid_number, '府中市 保健福祉総合センター');
ok($zip->set_number('7268505')->is_valid_number, '株式会社 ジーベック');
ok($zip->set_number('7268515')->is_valid_number, '松岡家具製造 株式会社');
ok($zip->set_number('7268555')->is_valid_number, 'サダシゲ特殊合板 株式会社');
ok($zip->set_number('7268601')->is_valid_number, '府中市役所');
ok($zip->set_number('7268603')->is_valid_number, 'ニチマン 株式会社');
ok($zip->set_number('7268609')->is_valid_number, '両備 信用組合');
ok($zip->set_number('7268610')->is_valid_number, '株式会社 北川鉄工所');
ok($zip->set_number('7268614')->is_valid_number, 'ヒロボー 株式会社');
ok($zip->set_number('7268628')->is_valid_number, 'リョービ 株式会社');
ok($zip->set_number('7268632')->is_valid_number, 'ヤスハラケミカル 株式会社');
ok($zip->set_number('7278501')->is_valid_number, '庄原市役所');
ok($zip->set_number('7288501')->is_valid_number, '三次市役所');
ok($zip->set_number('7288502')->is_valid_number, '市立三次中央病院');
ok($zip->set_number('7288503')->is_valid_number, '三次農業 協同組合');
ok($zip->set_number('7288511')->is_valid_number, 'ミヨシ電子 株式会社');
ok($zip->set_number('7290292')->is_valid_number, '福山大学');
ok($zip->set_number('7290393')->is_valid_number, '三菱重工業 株式会社 三原製作所');
ok($zip->set_number('7290492')->is_valid_number, '株式会社 古川製作所');
ok($zip->set_number('7290495')->is_valid_number, '三原市 本郷支所');
ok($zip->set_number('7291492')->is_valid_number, '三原市 大和支所');
ok($zip->set_number('7291493')->is_valid_number, '学校法人 広島三育学院');
ok($zip->set_number('7292292')->is_valid_number, '幸陽船渠 株式会社');
ok($zip->set_number('7292392')->is_valid_number, 'アヲハタ 株式会社');
ok($zip->set_number('7292393')->is_valid_number, '株式会社 アヲハタエフエムサプライ');
ok($zip->set_number('7292394')->is_valid_number, '電源開発 株式会社 竹原火力発電所');
ok($zip->set_number('7293192')->is_valid_number, '福山市新市支所');
ok($zip->set_number('7293193')->is_valid_number, '株式会社 自重堂');
ok($zip->set_number('7293198')->is_valid_number, '株式会社 コーコス信岡');
ok($zip->set_number('7293492')->is_valid_number, '府中市役所上下支所');
ok($zip->set_number('7293497')->is_valid_number, '株式会社 大昌');
ok($zip->set_number('7293498')->is_valid_number, '中元クリーニング 株式会社');
ok($zip->set_number('7293592')->is_valid_number, '神石高原町役場 神石支所');
ok($zip->set_number('7294295')->is_valid_number, '三次市役所吉舎支所');
ok($zip->set_number('7295792')->is_valid_number, '庄原市役所 西城支所');
ok($zip->set_number('7308501')->is_valid_number, '株式会社そごう広島店');
ok($zip->set_number('7308502')->is_valid_number, '西日本電信電話株式会社 広島支店');
ok($zip->set_number('7308503')->is_valid_number, '広島県国民健康保険団体連合会');
ok($zip->set_number('7308504')->is_valid_number, '株式会社 中国放送');
ok($zip->set_number('7308507')->is_valid_number, '広島県 警察本部');
ok($zip->set_number('7308508')->is_valid_number, '株式会社 広島東洋カープ');
ok($zip->set_number('7308509')->is_valid_number, '広島県議会事務局');
ok($zip->set_number('7308510')->is_valid_number, '広島商工会議所');
ok($zip->set_number('7308511')->is_valid_number, '広島県庁');
ok($zip->set_number('7308513')->is_valid_number, 'ハローワーク 広島公共職業安定所');
ok($zip->set_number('7308514')->is_valid_number, '広島県教育委員会');
ok($zip->set_number('7308515')->is_valid_number, '日本年金機構 広島東年金事務所');
ok($zip->set_number('7308518')->is_valid_number, '広島市立広島市民病院');
ok($zip->set_number('7308520')->is_valid_number, '中国財務局');
ok($zip->set_number('7308521')->is_valid_number, '広島国税局');
ok($zip->set_number('7308522')->is_valid_number, '丸紅 株式会社 中国支社');
ok($zip->set_number('7308523')->is_valid_number, '広島YMCA');
ok($zip->set_number('7308527')->is_valid_number, '出光興産 (株) 中国支店');
ok($zip->set_number('7308528')->is_valid_number, '広島中央労働基準監督署');
ok($zip->set_number('7308530')->is_valid_number, '国土交通省 中国地方整備局');
ok($zip->set_number('7308531')->is_valid_number, '中国経済産業局');
ok($zip->set_number('7308532')->is_valid_number, '圭冠寮');
ok($zip->set_number('7308533')->is_valid_number, '株式会社 鴻池組 広島支店');
ok($zip->set_number('7308535')->is_valid_number, '清水建設 株式会社 広島支店');
ok($zip->set_number('7308536')->is_valid_number, '広島法務局');
ok($zip->set_number('7308538')->is_valid_number, '広島労働局');
ok($zip->set_number('7308539')->is_valid_number, '広島地方検察庁');
ok($zip->set_number('7308540')->is_valid_number, '天満屋 八丁堀ビル');
ok($zip->set_number('7308541')->is_valid_number, '岩谷産業 株式会社 中国支社');
ok($zip->set_number('7308542')->is_valid_number, '五洋建設 株式会社 中国支店');
ok($zip->set_number('7308543')->is_valid_number, 'KDDI 株式会社 中国総支社');
ok($zip->set_number('7308544')->is_valid_number, '中国運輸局');
ok($zip->set_number('7308545')->is_valid_number, '株式会社 三越 広島店');
ok($zip->set_number('7308548')->is_valid_number, '株式会社 福屋');
ok($zip->set_number('7308550')->is_valid_number, '株式会社 ウィルコム 中四国支店');
ok($zip->set_number('7308551')->is_valid_number, 'ボーダフォン 株式会社');
ok($zip->set_number('7308552')->is_valid_number, '株式会社 広島ホームテレビ');
ok($zip->set_number('7308558')->is_valid_number, '新日本法規出版 株式会社 広島支社');
ok($zip->set_number('7308559')->is_valid_number, '株式会社 広島リビング新聞社');
ok($zip->set_number('7308561')->is_valid_number, 'ユアサ商事 株式会社 中国支社');
ok($zip->set_number('7308562')->is_valid_number, '中国電力 株式会社 中電病院');
ok($zip->set_number('7308563')->is_valid_number, '三井物産 株式会社 中国支社');
ok($zip->set_number('7308565')->is_valid_number, '広島市中区役所厚生部');
ok($zip->set_number('7308566')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ中国');
ok($zip->set_number('7308567')->is_valid_number, '広島市役所 財政局 収納対策部');
ok($zip->set_number('7308570')->is_valid_number, '株式会社 合人社計画研究所');
ok($zip->set_number('7308571')->is_valid_number, 'NTT 広島支店 料金サービスセンタ');
ok($zip->set_number('7308575')->is_valid_number, '広島テレビ放送 株式会社');
ok($zip->set_number('7308576')->is_valid_number, '三菱商事 株式会社 中国支社');
ok($zip->set_number('7308577')->is_valid_number, 'パナソニック広島中町ビル');
ok($zip->set_number('7308580')->is_valid_number, 'あいおい損害保険 株式会社 中国・四国業務部');
ok($zip->set_number('7308582')->is_valid_number, '国民生活金融公庫広島支店');
ok($zip->set_number('7308583')->is_valid_number, '国分 株式会社 中国支社');
ok($zip->set_number('7308585')->is_valid_number, 'テルウェル西日本 株式会社 中国支店');
ok($zip->set_number('7308586')->is_valid_number, '広島市役所');
ok($zip->set_number('7308587')->is_valid_number, '広島市中区役所');
ok($zip->set_number('7308589')->is_valid_number, '西松建設 株式会社 中国支店');
ok($zip->set_number('7308601')->is_valid_number, '社団法人 広島県薬剤師会');
ok($zip->set_number('7308603')->is_valid_number, '株式会社 大進本店');
ok($zip->set_number('7308605')->is_valid_number, '中国電力ネットワーク 株式会社 広島ネットワークセンター');
ok($zip->set_number('7308606')->is_valid_number, '東芝電機サービス 株式会社 中国支店');
ok($zip->set_number('7308608')->is_valid_number, '協同組合 広県繊');
ok($zip->set_number('7308609')->is_valid_number, 'アクサ生命保険 株式会社 中国営業所');
ok($zip->set_number('7308610')->is_valid_number, '広島電鉄 株式会社');
ok($zip->set_number('7308611')->is_valid_number, '広島市医師会 臨床検査センター');
ok($zip->set_number('7308612')->is_valid_number, 'コカ・コーラウエスト 株式会社');
ok($zip->set_number('7308619')->is_valid_number, '広島赤十字・原爆病院');
ok($zip->set_number('7308620')->is_valid_number, '株式会社 エディオン');
ok($zip->set_number('7308622')->is_valid_number, '株式会社 大信商会');
ok($zip->set_number('7308626')->is_valid_number, '広島県後期高齢者医療広域連合');
ok($zip->set_number('7308630')->is_valid_number, '広島トヨタ自動車 株式会社');
ok($zip->set_number('7308631')->is_valid_number, '一般財団法人 広島県環境保健協会');
ok($zip->set_number('7308641')->is_valid_number, 'エムイーシーエンジニアリングサービス 株式会社');
ok($zip->set_number('7308642')->is_valid_number, '三菱重工業 株式会社 広島製作所');
ok($zip->set_number('7308643')->is_valid_number, 'ひろしまPステーション');
ok($zip->set_number('7308646')->is_valid_number, '協同組合 リビンズ');
ok($zip->set_number('7308650')->is_valid_number, 'ウオクニ 株式会社 広島支社');
ok($zip->set_number('7308651')->is_valid_number, '広島刑務所');
ok($zip->set_number('7308652')->is_valid_number, '株式会社 JMS');
ok($zip->set_number('7308653')->is_valid_number, '株式会社 ウイング');
ok($zip->set_number('7308654')->is_valid_number, '日本年金機構 中国ブロック本部');
ok($zip->set_number('7308655')->is_valid_number, '医療法人 あかね会 土谷総合病院');
ok($zip->set_number('7308656')->is_valid_number, 'トヨタカローラ広島 株式会社');
ok($zip->set_number('7308657')->is_valid_number, '三菱電機 株式会社 中国支社');
ok($zip->set_number('7308658')->is_valid_number, '菅野 株式会社');
ok($zip->set_number('7308661')->is_valid_number, '三島食品 株式会社');
ok($zip->set_number('7308662')->is_valid_number, '株式会社 シンギ');
ok($zip->set_number('7308666')->is_valid_number, '広川 株式会社');
ok($zip->set_number('7308667')->is_valid_number, '株式会社 サンポール');
ok($zip->set_number('7308668')->is_valid_number, '鈴木 株式会社');
ok($zip->set_number('7308670')->is_valid_number, 'マツダ 株式会社');
ok($zip->set_number('7308672')->is_valid_number, '日本放送協会 広島放送局');
ok($zip->set_number('7308675')->is_valid_number, '農林中央金庫 広島支店');
ok($zip->set_number('7308677')->is_valid_number, '株式会社 中国新聞社');
ok($zip->set_number('7308678')->is_valid_number, '株式会社 もみじ銀行');
ok($zip->set_number('7308680')->is_valid_number, '郵便局 カタログ販売センター(中国)');
ok($zip->set_number('7308686')->is_valid_number, '西日本電信電話 株式会社 中国情報システムセンタ');
ok($zip->set_number('7308687')->is_valid_number, '株式会社 ぎょうせい 中国支社');
ok($zip->set_number('7308701')->is_valid_number, '中国電力 株式会社');
ok($zip->set_number('7308702')->is_valid_number, '中国電力ネットワーク 株式会社');
ok($zip->set_number('7308706')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('7308707')->is_valid_number, '広島信用金庫');
ok($zip->set_number('7308720')->is_valid_number, 'ニッセイ同和損害保険株式会社 西中国支店');
ok($zip->set_number('7308730')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('7308787')->is_valid_number, '広島市文化交流会館');
ok($zip->set_number('7308794')->is_valid_number, '広島貯金事務センター');
ok($zip->set_number('7308795')->is_valid_number, '中国総合通信局');
ok($zip->set_number('7308796')->is_valid_number, '広島監査室');
ok($zip->set_number('7308797')->is_valid_number, '株式会社 ゆうちょ銀行 広島支店');
ok($zip->set_number('7308797')->is_valid_number, '株式会社 かんぽ生命 広島支店');
ok($zip->set_number('7308797')->is_valid_number, '日本郵便 株式会社 中国支社');
ok($zip->set_number('7310192')->is_valid_number, '広島経済大学');
ok($zip->set_number('7310193')->is_valid_number, '安佐南区役所');
ok($zip->set_number('7310194')->is_valid_number, '広島市安佐南区 総合福祉センター');
ok($zip->set_number('7310195')->is_valid_number, '株式会社 天満屋 広島緑井店');
ok($zip->set_number('7310196')->is_valid_number, 'イオンモール 株式会社 イオンモール祇園');
ok($zip->set_number('7310197')->is_valid_number, '大進物流センター');
ok($zip->set_number('7310198')->is_valid_number, '株式会社 山貴');
ok($zip->set_number('7310292')->is_valid_number, '広島市安佐北区役所');
ok($zip->set_number('7310293')->is_valid_number, '広島市立北部医療センター安佐市民病院');
ok($zip->set_number('7310295')->is_valid_number, '広島文教大学');
ok($zip->set_number('7310592')->is_valid_number, '安芸高田市役所');
ok($zip->set_number('7310593')->is_valid_number, '吉田町税務署');
ok($zip->set_number('7310595')->is_valid_number, '吉田総合病院');
ok($zip->set_number('7310692')->is_valid_number, '安芸高田市役所 美土里支所');
ok($zip->set_number('7311595')->is_valid_number, '北広島町役場');
ok($zip->set_number('7311597')->is_valid_number, '株式会社 やまびこ 広島事業所');
ok($zip->set_number('7311795')->is_valid_number, '北広島町役場 豊平支所');
ok($zip->set_number('7312195')->is_valid_number, '北広島町役場 大朝支所');
ok($zip->set_number('7312198')->is_valid_number, '学校法人 広島県新庄学園');
ok($zip->set_number('7313192')->is_valid_number, '沼田自動車学校');
ok($zip->set_number('7313193')->is_valid_number, '山星屋');
ok($zip->set_number('7313194')->is_valid_number, '広島市立大学');
ok($zip->set_number('7313195')->is_valid_number, '広島修道大学');
ok($zip->set_number('7313196')->is_valid_number, '株式会社 山豊');
ok($zip->set_number('7313198')->is_valid_number, '株式会社 中国シジシー');
ok($zip->set_number('7313393')->is_valid_number, '株式会社 ユーメックス');
ok($zip->set_number('7313395')->is_valid_number, '株式会社 ポプラ');
ok($zip->set_number('7313398')->is_valid_number, 'IGL健康福祉専門学校');
ok($zip->set_number('7313595')->is_valid_number, '安芸太田町役場 加計支所');
ok($zip->set_number('7314292')->is_valid_number, '熊野町役場');
ok($zip->set_number('7314293')->is_valid_number, '筆の里工房');
ok($zip->set_number('7314294')->is_valid_number, '熊野中公民館');
ok($zip->set_number('7314392')->is_valid_number, '三菱ふそうトラック・バス 株式会社 広島ふそう');
ok($zip->set_number('7314393')->is_valid_number, '広島県安芸郡坂町役場');
ok($zip->set_number('7314396')->is_valid_number, '株式会社 クラタクリエイト');
ok($zip->set_number('7314397')->is_valid_number, '広島日野自動車 株式会社 坂支店');
ok($zip->set_number('7314398')->is_valid_number, '株式会社 電通資材');
ok($zip->set_number('7315193')->is_valid_number, '広島工業大学');
ok($zip->set_number('7315195')->is_valid_number, '佐伯区役所');
ok($zip->set_number('7315196')->is_valid_number, 'イオンモール 株式会社 THE OUTLETS HIROSHIMA');
ok($zip->set_number('7315197')->is_valid_number, '株式会社 ヒロテック');
ok($zip->set_number('7315198')->is_valid_number, '広島県 運転免許センター');
ok($zip->set_number('7328501')->is_valid_number, '株式会社 広島東洋カープ');
ok($zip->set_number('7328503')->is_valid_number, '株式会社 ヒロテック 温品工場');
ok($zip->set_number('7328504')->is_valid_number, '生活協同組合連合会 コープ中国四国事業連合');
ok($zip->set_number('7328505')->is_valid_number, '全労済広島県本部');
ok($zip->set_number('7328507')->is_valid_number, '広島県 学校生活協同組合');
ok($zip->set_number('7328508')->is_valid_number, '創価学会 広島池田平和記念会館');
ok($zip->set_number('7328509')->is_valid_number, '比治山大学・比治山大学短期大学部');
ok($zip->set_number('7328510')->is_valid_number, '広島市東区役所');
ok($zip->set_number('7328511')->is_valid_number, '株式会社 福屋 広島駅前店');
ok($zip->set_number('7328512')->is_valid_number, '全国健康保険協会 広島支部');
ok($zip->set_number('7328555')->is_valid_number, '株式会社 イズミ');
ok($zip->set_number('7328564')->is_valid_number, '中国電機製造 株式会社');
ok($zip->set_number('7328565')->is_valid_number, '株式会社 京屋');
ok($zip->set_number('7328566')->is_valid_number, '中国労働金庫');
ok($zip->set_number('7328570')->is_valid_number, '株式会社 ゆめカード');
ok($zip->set_number('7328575')->is_valid_number, '広島テレビ放送 株式会社');
ok($zip->set_number('7328580')->is_valid_number, '株式会社 ユアーズ');
ok($zip->set_number('7328652')->is_valid_number, '大正製薬 株式会社 広島支店');
ok($zip->set_number('7328765')->is_valid_number, 'DNT山陽ケミカル 株式会社');
ok($zip->set_number('7338501')->is_valid_number, '株式会社 松田組');
ok($zip->set_number('7338509')->is_valid_number, 'LECT');
ok($zip->set_number('7338510')->is_valid_number, '西川ゴム工業 株式会社');
ok($zip->set_number('7338511')->is_valid_number, '崇徳高等学校');
ok($zip->set_number('7338512')->is_valid_number, '株式会社 広交本社');
ok($zip->set_number('7338513')->is_valid_number, '広島交通 株式会社');
ok($zip->set_number('7338514')->is_valid_number, '広交観光 株式会社');
ok($zip->set_number('7338520')->is_valid_number, '株式会社 山善 広島支社');
ok($zip->set_number('7338521')->is_valid_number, '第一学習社');
ok($zip->set_number('7338525')->is_valid_number, '小田億');
ok($zip->set_number('7338528')->is_valid_number, '株式会社 広島音工');
ok($zip->set_number('7338530')->is_valid_number, '広島市西区役所');
ok($zip->set_number('7338531')->is_valid_number, '大昌工芸 株式会社');
ok($zip->set_number('7338533')->is_valid_number, '広島工業大学専門学校');
ok($zip->set_number('7338535')->is_valid_number, '広島市 西区役所 厚生部生活課');
ok($zip->set_number('7338540')->is_valid_number, '広島県 医師会');
ok($zip->set_number('7338543')->is_valid_number, '一般社団法人 広島市医師会');
ok($zip->set_number('7338545')->is_valid_number, '株式会社 フタバ図書');
ok($zip->set_number('7338548')->is_valid_number, '広島市医師会 看護専門学校');
ok($zip->set_number('7338550')->is_valid_number, '日産プリンス広島販売 株式会社');
ok($zip->set_number('7338551')->is_valid_number, '広島山陽学園 山陽高等学校');
ok($zip->set_number('7338552')->is_valid_number, '株式会社 白菱');
ok($zip->set_number('7338553')->is_valid_number, '三菱重工業 株式会社 広島製作所');
ok($zip->set_number('7338555')->is_valid_number, '広島西 税務署');
ok($zip->set_number('7338558')->is_valid_number, 'トヨタオート広島 株式会社');
ok($zip->set_number('7338601')->is_valid_number, '三菱重工業 株式会社 広島製作所 第一観音寮');
ok($zip->set_number('7338608')->is_valid_number, '株式会社 広電ストア');
ok($zip->set_number('7338610')->is_valid_number, '社団法人 日本自動車連盟 広島支部');
ok($zip->set_number('7338611')->is_valid_number, '株式会社 スパーク');
ok($zip->set_number('7338616')->is_valid_number, '丸井産業 株式会社');
ok($zip->set_number('7338621')->is_valid_number, '広島工業大学高等学校');
ok($zip->set_number('7338622')->is_valid_number, '広島修道大学ひろしま協創中学校・高等学校');
ok($zip->set_number('7338623')->is_valid_number, '鈴峰女子短期大学');
ok($zip->set_number('7338624')->is_valid_number, 'アルパーク東棟');
ok($zip->set_number('7338625')->is_valid_number, '株式会社 アルパーク天満屋');
ok($zip->set_number('7338626')->is_valid_number, 'アルパーク北棟');
ok($zip->set_number('7338627')->is_valid_number, 'アルパーク西棟');
ok($zip->set_number('7338630')->is_valid_number, '株式会社 奥山商会');
ok($zip->set_number('7338633')->is_valid_number, 'ティーエスアルフレッサ 株式会社');
ok($zip->set_number('7338641')->is_valid_number, '株式会社 アスティ');
ok($zip->set_number('7338642')->is_valid_number, '株式会社 ヤマニシ');
ok($zip->set_number('7338643')->is_valid_number, '加藤産業 株式会社 広島支店');
ok($zip->set_number('7338646')->is_valid_number, '株式会社 ユニカ');
ok($zip->set_number('7338647')->is_valid_number, '株式会社 シージーシー 中国本部');
ok($zip->set_number('7338648')->is_valid_number, '株式会社 シージーシー 中国本部');
ok($zip->set_number('7338650')->is_valid_number, '広島市衛生研究所');
ok($zip->set_number('7338651')->is_valid_number, '株式会社 モンテカルロ');
ok($zip->set_number('7338660')->is_valid_number, '株式会社 セイエル');
ok($zip->set_number('7338669')->is_valid_number, '日本酒類販売 株式会社 中四国支社');
ok($zip->set_number('7338670')->is_valid_number, 'オタフクソース 株式会社');
ok($zip->set_number('7338675')->is_valid_number, '(株) エル・コ 西広島タイムス事業部');
ok($zip->set_number('7338677')->is_valid_number, '株式会社 あじかん');
ok($zip->set_number('7338678')->is_valid_number, 'オタフクソース 株式会社 中国支店');
ok($zip->set_number('7338689')->is_valid_number, '広島国税局業務センター');
ok($zip->set_number('7338701')->is_valid_number, '株式会社 ヒロテックス');
ok($zip->set_number('7348510')->is_valid_number, '中電技術コンサルタント 株式会社');
ok($zip->set_number('7348513')->is_valid_number, '岡部 株式会社 中四国支店');
ok($zip->set_number('7348515')->is_valid_number, '瀬戸内海汽船 株式会社');
ok($zip->set_number('7348522')->is_valid_number, '広島市南区役所');
ok($zip->set_number('7348530')->is_valid_number, '広島県立 広島病院');
ok($zip->set_number('7348543')->is_valid_number, '広島プリンスホテル');
ok($zip->set_number('7348558')->is_valid_number, '県立広島大学');
ok($zip->set_number('7348560')->is_valid_number, '第六管区海上保安本部');
ok($zip->set_number('7348567')->is_valid_number, '株式会社 熊平製作所');
ok($zip->set_number('7348570')->is_valid_number, '山根木材 株式会社');
ok($zip->set_number('7348798')->is_valid_number, '中国郵政研修センター');
ok($zip->set_number('7358501')->is_valid_number, 'デルタ工業');
ok($zip->set_number('7358510')->is_valid_number, 'キリンビール 株式会社 中国地区本部');
ok($zip->set_number('7358511')->is_valid_number, '株式会社 サンリブ広島地区店舗運営部');
ok($zip->set_number('7358555')->is_valid_number, '明光堂');
ok($zip->set_number('7358577')->is_valid_number, 'イオン 株式会社 ジャスコ広島府中店');
ok($zip->set_number('7358588')->is_valid_number, 'ダイヤモンドシティ ソレイユ');
ok($zip->set_number('7358670')->is_valid_number, '株式会社 マツダ');
ok($zip->set_number('7358686')->is_valid_number, '府中町役場');
ok($zip->set_number('7368501')->is_valid_number, '広島市安芸区役所');
ok($zip->set_number('7368502')->is_valid_number, '陸上自衛隊 海田市駐屯地');
ok($zip->set_number('7368504')->is_valid_number, '株式会社 ユアーズ');
ok($zip->set_number('7368505')->is_valid_number, '海田 税務署');
ok($zip->set_number('7368506')->is_valid_number, '株式会社 やま磯');
ok($zip->set_number('7368507')->is_valid_number, '株式会社 日本アクセス 広島支店');
ok($zip->set_number('7368508')->is_valid_number, '広島市立安芸区図書館');
ok($zip->set_number('7368509')->is_valid_number, '安芸区民文化センター');
ok($zip->set_number('7368510')->is_valid_number, '広島日野自動車 株式会社');
ok($zip->set_number('7368555')->is_valid_number, '安芸区総合福祉センター');
ok($zip->set_number('7368601')->is_valid_number, '海田町役場');
ok($zip->set_number('7368602')->is_valid_number, '株式会社 日本製鋼所 広島製作所');
ok($zip->set_number('7370182')->is_valid_number, '広島文化学園大学 呉 郷原キャンパス');
ok($zip->set_number('7370192')->is_valid_number, '中国工業 株式会社');
ok($zip->set_number('7370193')->is_valid_number, '中国労災病院');
ok($zip->set_number('7370195')->is_valid_number, '中国木材 株式会社');
ok($zip->set_number('7370198')->is_valid_number, '株式会社 ディスコ 広島事業所');
ok($zip->set_number('7372193')->is_valid_number, '江田島市役所 江田島支所');
ok($zip->set_number('7372195')->is_valid_number, '海上自衛隊 第一術科学校');
ok($zip->set_number('7372293')->is_valid_number, '古澤建設工業 株式会社');
ok($zip->set_number('7372295')->is_valid_number, '江田島市福祉事務所');
ok($zip->set_number('7372297')->is_valid_number, '江田島市役所');
ok($zip->set_number('7372393')->is_valid_number, '江田島市役所 沖美支所');
ok($zip->set_number('7372397')->is_valid_number, '江田島市役所 能美支所');
ok($zip->set_number('7378501')->is_valid_number, '呉市役所');
ok($zip->set_number('7378502')->is_valid_number, '大之木建設 株式会社');
ok($zip->set_number('7378503')->is_valid_number, '株式会社 大之木ダイモ');
ok($zip->set_number('7378504')->is_valid_number, '広島県呉地域事務所長');
ok($zip->set_number('7378505')->is_valid_number, '国家公務員共済組合連合会 呉共済病院');
ok($zip->set_number('7378506')->is_valid_number, '呉工業高等専門学校');
ok($zip->set_number('7378507')->is_valid_number, '中国化薬 株式会社');
ok($zip->set_number('7378508')->is_valid_number, '三菱重工業 株式会社 呉工場');
ok($zip->set_number('7378509')->is_valid_number, '呉市教育委員会');
ok($zip->set_number('7378512')->is_valid_number, '海上保安大学校');
ok($zip->set_number('7378513')->is_valid_number, '株式会社 ダイクレ');
ok($zip->set_number('7378516')->is_valid_number, '株式会社 シーエックスアール');
ok($zip->set_number('7378517')->is_valid_number, '社会福祉法人 呉市社会福祉協議会');
ok($zip->set_number('7378518')->is_valid_number, 'クレトイシ 株式会社');
ok($zip->set_number('7378520')->is_valid_number, '日新製鋼 株式会社 呉製鉄所');
ok($zip->set_number('7378541')->is_valid_number, '株式会社 ユーシン');
ok($zip->set_number('7378554')->is_valid_number, '海上自衛隊 呉基地 業務隊');
ok($zip->set_number('7378609')->is_valid_number, '呉公共職業安定所');
ok($zip->set_number('7378611')->is_valid_number, '株式会社 もみじ銀行 呉営業部');
ok($zip->set_number('7378650')->is_valid_number, '株式会社 山口銀行 呉支店');
ok($zip->set_number('7378651')->is_valid_number, '株式会社 増岡組');
ok($zip->set_number('7378652')->is_valid_number, '呉 税務署');
ok($zip->set_number('7378653')->is_valid_number, '呉農業協同組合');
ok($zip->set_number('7378686')->is_valid_number, '呉信用金庫');
ok($zip->set_number('7380292')->is_valid_number, '廿日市市役所 佐伯支所');
ok($zip->set_number('7388501')->is_valid_number, '廿日市市役所');
ok($zip->set_number('7388502')->is_valid_number, '株式会社 ウッドワン');
ok($zip->set_number('7388503')->is_valid_number, '広島総合病院');
ok($zip->set_number('7388504')->is_valid_number, '学校法人 山陽女学園');
ok($zip->set_number('7388505')->is_valid_number, '国立病院機構 原病院');
ok($zip->set_number('7388506')->is_valid_number, '中国バンドー 株式会社');
ok($zip->set_number('7388507')->is_valid_number, '中国電力 株式会社 廿日市営業所');
ok($zip->set_number('7388508')->is_valid_number, 'カルビー 株式会社 広島工場');
ok($zip->set_number('7388509')->is_valid_number, 'はつかいち文化ホール さくらぴあ');
ok($zip->set_number('7388512')->is_valid_number, '廿日市市 総合健康福祉センター');
ok($zip->set_number('7388601')->is_valid_number, '廿日市 税務署');
ok($zip->set_number('7388602')->is_valid_number, '中国醸造 株式会社');
ok($zip->set_number('7388603')->is_valid_number, '株式会社 マルニ');
ok($zip->set_number('7390192')->is_valid_number, 'シャープ 株式会社 通信システム事業本部');
ok($zip->set_number('7390193')->is_valid_number, '大協 株式会社');
ok($zip->set_number('7390198')->is_valid_number, '広島エルピーダ メモリ株式会社');
ok($zip->set_number('7390481')->is_valid_number, '海の見える杜美術館');
ok($zip->set_number('7390492')->is_valid_number, '廿日市市役所 大野支所');
ok($zip->set_number('7390494')->is_valid_number, 'フマキラー 株式会社');
ok($zip->set_number('7390495')->is_valid_number, '生活協同組合 広島');
ok($zip->set_number('7390496')->is_valid_number, '生活協同組合連合会 コープ中国四国事業連合');
ok($zip->set_number('7390497')->is_valid_number, 'チチヤス 株式会社');
ok($zip->set_number('7390592')->is_valid_number, '(宗) 大聖院');
ok($zip->set_number('7390595')->is_valid_number, '廿日市市役所 宮島支所');
ok($zip->set_number('7390692')->is_valid_number, '大竹市役所');
ok($zip->set_number('7390693')->is_valid_number, '三菱レイヨン 株式会社 大竹事業所');
ok($zip->set_number('7390695')->is_valid_number, '株式会社 ダイセル 大竹工場');
ok($zip->set_number('7390696')->is_valid_number, '独立行政法人 国立病院機構 広島西医療センター');
ok($zip->set_number('7390698')->is_valid_number, '中川製袋化工 株式会社');
ok($zip->set_number('7391192')->is_valid_number, '安芸高田市役所 甲田支所');
ok($zip->set_number('7391195')->is_valid_number, '湧永製薬 (株) 広島事業所');
ok($zip->set_number('7391292')->is_valid_number, '安芸高田市 向原支所');
ok($zip->set_number('7391293')->is_valid_number, '株式会社 山口製作所');
ok($zip->set_number('7391792')->is_valid_number, '株式会社 研創');
ok($zip->set_number('7391794')->is_valid_number, '株式会社 モルテン 高陽工場');
ok($zip->set_number('7392492')->is_valid_number, '東広島市 安芸津支所');
ok($zip->set_number('7392494')->is_valid_number, '独立行政法人 農業・食品産業技術総合研究機構 果樹研究所ブドウ・カキ研究拠点');
ok($zip->set_number('7392498')->is_valid_number, '芸南 農業協同組合');
ok($zip->set_number('7392692')->is_valid_number, '東広島市 黒瀬支所');
ok($zip->set_number('7392693')->is_valid_number, '独立行政法人 国立病院機構 賀茂精神医療センター');
ok($zip->set_number('7392695')->is_valid_number, '広島国際大学');
ok($zip->set_number('7398501')->is_valid_number, '株式会社 大創産業');
ok($zip->set_number('7398511')->is_valid_number, '広島大学 事務局 (保健管理センター)');
ok($zip->set_number('7398512')->is_valid_number, '広島大学 附属図書館(広島大学高等教育研究開発センター)');
ok($zip->set_number('7398513')->is_valid_number, '広島大学 中央廃液処理施設');
ok($zip->set_number('7398514')->is_valid_number, '広島大学 学生プラザ');
ok($zip->set_number('7398521')->is_valid_number, '広島大学 総合科学部 (外国語教育研究センター)(情報教育研究センター)');
ok($zip->set_number('7398522')->is_valid_number, '広島大学 文学部 (総合地誌研究資料センター)');
ok($zip->set_number('7398524')->is_valid_number, '広島大学 教育学部');
ok($zip->set_number('7398525')->is_valid_number, '広島大学 法学部・経済学部');
ok($zip->set_number('7398526')->is_valid_number, '広島大学 理学部 (アイソトープ総合センター)');
ok($zip->set_number('7398526')->is_valid_number, '広島大学 理学部 (機器分析センター)');
ok($zip->set_number('7398526')->is_valid_number, '広島大学 理学部 (総合情報処理処理センター)');
ok($zip->set_number('7398526')->is_valid_number, '広島大学 理学部 (低温センター)');
ok($zip->set_number('7398526')->is_valid_number, '広島大学 理学部 (放射光科学研究センター)');
ok($zip->set_number('7398527')->is_valid_number, '広島大学 工学部 (遺伝子実験施設)');
ok($zip->set_number('7398527')->is_valid_number, '広島大学 工学部(ナノデバイス・システム研究センター)');
ok($zip->set_number('7398527')->is_valid_number, '広島大学 工学部(ベンチャー・ビジネス・ラボラトリー)');
ok($zip->set_number('7398528')->is_valid_number, '広島大学 生物生産学部');
ok($zip->set_number('7398529')->is_valid_number, '広島大学大学院 国際協力研究科');
ok($zip->set_number('7398530')->is_valid_number, '広島大学大学院 先端物質科学研究科');
ok($zip->set_number('7398601')->is_valid_number, '東広島市役所');
ok($zip->set_number('7398602')->is_valid_number, '株式会社 サタケ');
ok($zip->set_number('7398603')->is_valid_number, '株式会社 広島銀行 西条支店');
ok($zip->set_number('7398615')->is_valid_number, '西条 税務署');
ok($zip->set_number('7398616')->is_valid_number, '株式会社 プレスネット');
ok($zip->set_number('7408501')->is_valid_number, '和木町役場');
ok($zip->set_number('7408510')->is_valid_number, '独立行政法人 国立病院機構 岩国医療センター');
ok($zip->set_number('7408511')->is_valid_number, '帝人 株式会社 岩国事業所');
ok($zip->set_number('7408516')->is_valid_number, '山口県 岩国県税事務所');
ok($zip->set_number('7408535')->is_valid_number, '三晃特殊金属工業 株式会社');
ok($zip->set_number('7408555')->is_valid_number, '海上自衛隊 岩国航空基地隊');
ok($zip->set_number('7408567')->is_valid_number, '東洋紡 株式会社 岩国工場');
ok($zip->set_number('7408585')->is_valid_number, '岩国市役所');
ok($zip->set_number('7408611')->is_valid_number, '岩国 税務署');
ok($zip->set_number('7408639')->is_valid_number, '岩国商工会議所');
ok($zip->set_number('7408642')->is_valid_number, '中国電力 株式会社 岩国営業所');
ok($zip->set_number('7408646')->is_valid_number, '有限会社 詩仙堂');
ok($zip->set_number('7408686')->is_valid_number, '日本年金機構 岩国年金事務所');
ok($zip->set_number('7418585')->is_valid_number, '医療法人 新生会 いしい記念病院');
ok($zip->set_number('7420392')->is_valid_number, '岩国市 玖珂支所');
ok($zip->set_number('7420492')->is_valid_number, '岩国市 周東総合支所');
ok($zip->set_number('7421192')->is_valid_number, '永大産業 株式会社 山口・平生事業所');
ok($zip->set_number('7421193')->is_valid_number, '医療法人.光輝会 光輝病院');
ok($zip->set_number('7421194')->is_valid_number, '三新化学工業 株式会社 平生工場');
ok($zip->set_number('7421195')->is_valid_number, '平生町役場');
ok($zip->set_number('7421196')->is_valid_number, '柳井紙工 株式会社');
ok($zip->set_number('7421398')->is_valid_number, '井森工業 株式会社');
ok($zip->set_number('7421592')->is_valid_number, '田布施町役場');
ok($zip->set_number('7421598')->is_valid_number, '大晃機械工業 株式会社');
ok($zip->set_number('7422192')->is_valid_number, '周防大島町役場');
ok($zip->set_number('7422193')->is_valid_number, '大島商船高等専門学校');
ok($zip->set_number('7428510')->is_valid_number, '(株) イズミ 柳井店');
ok($zip->set_number('7428511')->is_valid_number, '中国電力 柳井発電所');
ok($zip->set_number('7428555')->is_valid_number, '株式会社 フジマ');
ok($zip->set_number('7428576')->is_valid_number, '三新化学工業 株式会社');
ok($zip->set_number('7428605')->is_valid_number, '柳井 税務署');
ok($zip->set_number('7428608')->is_valid_number, '井森工業');
ok($zip->set_number('7428622')->is_valid_number, '株式会社 エム・オン');
ok($zip->set_number('7428625')->is_valid_number, '中国電力 株式会社 柳井営業所');
ok($zip->set_number('7428645')->is_valid_number, '柳井商工会議所');
ok($zip->set_number('7428646')->is_valid_number, 'JA 南すおう');
ok($zip->set_number('7428666')->is_valid_number, '株式会社 柳井クルーズホテル');
ok($zip->set_number('7428669')->is_valid_number, '株式会社 山口銀行 柳井支店');
ok($zip->set_number('7428688')->is_valid_number, '東山口信用金庫');
ok($zip->set_number('7428714')->is_valid_number, '柳井市役所');
ok($zip->set_number('7428787')->is_valid_number, 'やまぐちフラワーランド 財団法人 やない花のまちづくり振興財団');
ok($zip->set_number('7430192')->is_valid_number, '光市立 大和総合病院');
ok($zip->set_number('7430193')->is_valid_number, '光市役所 大和支所');
ok($zip->set_number('7438501')->is_valid_number, '光市役所');
ok($zip->set_number('7438502')->is_valid_number, '武田薬品工業 株式会社 光工場');
ok($zip->set_number('7438510')->is_valid_number, '新日本製鐵 株式会社 光製鐵所');
ok($zip->set_number('7438550')->is_valid_number, '新日鐵住金ステンレス 株式会社 製造本部光製造所');
ok($zip->set_number('7438561')->is_valid_number, '光市立光総合病院');
ok($zip->set_number('7438577')->is_valid_number, '光 税務署');
ok($zip->set_number('7448521')->is_valid_number, '下松商業開発 株式会社');
ok($zip->set_number('7448585')->is_valid_number, '下松市役所');
ok($zip->set_number('7448601')->is_valid_number, '株式会社 日立製作所 笠戸事業所');
ok($zip->set_number('7448611')->is_valid_number, '東洋鋼鈑 株式会社 下松工場');
ok($zip->set_number('7450696')->is_valid_number, '株式会社 新光');
ok($zip->set_number('7450698')->is_valid_number, '周南市役所 熊毛総合支所');
ok($zip->set_number('7458510')->is_valid_number, 'オープンシステム総合病院 徳山医師会病院');
ok($zip->set_number('7458522')->is_valid_number, '総合病院社会保険 徳山中央病院');
ok($zip->set_number('7458529')->is_valid_number, '周南市社会福祉協議会');
ok($zip->set_number('7458547')->is_valid_number, '防長交通 株式会社');
ok($zip->set_number('7458566')->is_valid_number, '徳山大学');
ok($zip->set_number('7458567')->is_valid_number, '株式会社 近鉄松下百貨店');
ok($zip->set_number('7458585')->is_valid_number, '徳山工業高等専門学校');
ok($zip->set_number('7458601')->is_valid_number, '株式会社 西京銀行');
ok($zip->set_number('7458611')->is_valid_number, '大和証券 株式会社 徳山支店');
ok($zip->set_number('7458613')->is_valid_number, '出光興産 株式会社 徳山製油所');
ok($zip->set_number('7458622')->is_valid_number, '徳山 税務署');
ok($zip->set_number('7458648')->is_valid_number, '株式会社 トクヤマ');
ok($zip->set_number('7458655')->is_valid_number, '周南市役所');
ok($zip->set_number('7458656')->is_valid_number, '商工組合中央金庫 徳山支店');
ok($zip->set_number('7458666')->is_valid_number, '徳山社会保険事務所');
ok($zip->set_number('7458686')->is_valid_number, '山口放送 株式会社');
ok($zip->set_number('7468501')->is_valid_number, '東ソー (株) 南陽工場');
ok($zip->set_number('7468601')->is_valid_number, '山口銀行 富田支店');
ok($zip->set_number('7468666')->is_valid_number, '日鉄ステンレス 株式会社 製造本部 周南製鋼所');
ok($zip->set_number('7470292')->is_valid_number, '山口市 徳地総合支所');
ok($zip->set_number('7478501')->is_valid_number, '防府市役所');
ok($zip->set_number('7478509')->is_valid_number, '株式会社 丸久');
ok($zip->set_number('7478511')->is_valid_number, '地方独立行政法人 山口県立病院機構 山口県立総合医療センター');
ok($zip->set_number('7478522')->is_valid_number, '協和発酵工業 株式会社 防府工場');
ok($zip->set_number('7478533')->is_valid_number, '広島国税局業務センター防府分室');
ok($zip->set_number('7478555')->is_valid_number, '航空自衛隊 防府南基地');
ok($zip->set_number('7478567')->is_valid_number, '航空自衛隊 防府北基地');
ok($zip->set_number('7478585')->is_valid_number, '建設省山口工事事務所');
ok($zip->set_number('7478588')->is_valid_number, '大村印刷 株式会社');
ok($zip->set_number('7478611')->is_valid_number, '防府税務署');
ok($zip->set_number('7478622')->is_valid_number, '株式会社 三友');
ok($zip->set_number('7478686')->is_valid_number, '山口銀行 防府支店');
ok($zip->set_number('7490195')->is_valid_number, '柳井市役所 大畠総合支所');
ok($zip->set_number('7500692')->is_valid_number, '美祢社会復帰促進センター宿舎');
ok($zip->set_number('7500693')->is_valid_number, '美祢社会復帰促進センター');
ok($zip->set_number('7501192')->is_valid_number, '株式会社 シマノ 下関工場');
ok($zip->set_number('7501193')->is_valid_number, '日本セレモニー');
ok($zip->set_number('7508501')->is_valid_number, '前田海産 株式会社');
ok($zip->set_number('7508502')->is_valid_number, '住友生命保険 相互会社 山口支社');
ok($zip->set_number('7508503')->is_valid_number, '株式会社 下関大丸');
ok($zip->set_number('7508505')->is_valid_number, '三菱重工業 株式会社 下関造船所');
ok($zip->set_number('7508506')->is_valid_number, '株式会社 みなと山口合同新聞社');
ok($zip->set_number('7508507')->is_valid_number, '山口地方裁判所 下関支部');
ok($zip->set_number('7508508')->is_valid_number, '学校法人 河野学園');
ok($zip->set_number('7508510')->is_valid_number, 'サンデン交通 株式会社');
ok($zip->set_number('7508511')->is_valid_number, '学校法人 梅光学院');
ok($zip->set_number('7508512')->is_valid_number, '株式会社 松岡');
ok($zip->set_number('7508513')->is_valid_number, '下関商工会議所');
ok($zip->set_number('7508515')->is_valid_number, '株式会社 日本無線電機サービス社');
ok($zip->set_number('7508517')->is_valid_number, '林兼産業 株式会社 飼料事業部');
ok($zip->set_number('7508518')->is_valid_number, '山口ダイハツ販売 株式会社');
ok($zip->set_number('7508520')->is_valid_number, '下関市立市民病院');
ok($zip->set_number('7508521')->is_valid_number, '下関市役所');
ok($zip->set_number('7508524')->is_valid_number, '早鞆高等学校');
ok($zip->set_number('7508525')->is_valid_number, '下関市水道局');
ok($zip->set_number('7508601')->is_valid_number, '日本銀行 下関支店');
ok($zip->set_number('7508602')->is_valid_number, '日本生命保険 相互会社 山口支社');
ok($zip->set_number('7508603')->is_valid_number, '株式会社 山口銀行');
ok($zip->set_number('7508607')->is_valid_number, '下関社会保険事務所');
ok($zip->set_number('7508608')->is_valid_number, '林兼産業 株式会社');
ok($zip->set_number('7508610')->is_valid_number, '中国電力ネットワーク 株式会社 下関ネットワークセンター');
ok($zip->set_number('7518503')->is_valid_number, '東亜大学');
ok($zip->set_number('7518508')->is_valid_number, '山口合同ガス 株式会社');
ok($zip->set_number('7518510')->is_valid_number, '下関市立大学');
ok($zip->set_number('7518630')->is_valid_number, '株式会社 毎日メディアサービス山口');
ok($zip->set_number('7528501')->is_valid_number, 'コタベ 株式会社');
ok($zip->set_number('7528510')->is_valid_number, '独立行政法人 国立病院機構 関門医療センター');
ok($zip->set_number('7528511')->is_valid_number, '下関競艇場');
ok($zip->set_number('7528555')->is_valid_number, '株式会社 長府製作所');
ok($zip->set_number('7528558')->is_valid_number, '株式会社 小澤');
ok($zip->set_number('7528585')->is_valid_number, '株式会社 和田又');
ok($zip->set_number('7528601')->is_valid_number, '山口銀行 事務センター');
ok($zip->set_number('7528609')->is_valid_number, '株式会社 コプロス');
ok($zip->set_number('7530292')->is_valid_number, 'テレビ山口 株式会社 (TYS)');
ok($zip->set_number('7530293')->is_valid_number, 'TYSハウジングプラザ山口「サエラ」');
ok($zip->set_number('7538501')->is_valid_number, '山口県庁');
ok($zip->set_number('7538502')->is_valid_number, '公立大学法人 山口県立大学');
ok($zip->set_number('7538503')->is_valid_number, '陸上自衛隊 山口駐屯地 業務隊');
ok($zip->set_number('7538504')->is_valid_number, '山口県警察 本部');
ok($zip->set_number('7538506')->is_valid_number, '中国電力 株式会社 山口支社');
ok($zip->set_number('7538508')->is_valid_number, '山口県立 山口高等学校');
ok($zip->set_number('7538509')->is_valid_number, '山口税務署');
ok($zip->set_number('7538510')->is_valid_number, '山口労働局');
ok($zip->set_number('7538511')->is_valid_number, '国立大学法人 山口大学 本部');
ok($zip->set_number('7538517')->is_valid_number, '済生会 山口総合病院');
ok($zip->set_number('7538518')->is_valid_number, '中国電力ネットワーク 株式会社 山口ネットワークセンター');
ok($zip->set_number('7538519')->is_valid_number, '綜合病院 山口赤十字病院');
ok($zip->set_number('7538520')->is_valid_number, '山口県 国民健康保険団体連合会');
ok($zip->set_number('7538521')->is_valid_number, '株式会社 FM山口');
ok($zip->set_number('7538522')->is_valid_number, '山口県社会保険診療報酬支払基金');
ok($zip->set_number('7538525')->is_valid_number, '山口刑務所');
ok($zip->set_number('7538526')->is_valid_number, '中国財務局 山口財務事務所');
ok($zip->set_number('7538528')->is_valid_number, '山口県 町村会');
ok($zip->set_number('7538529')->is_valid_number, '山口県市町村職員 共済組合');
ok($zip->set_number('7538530')->is_valid_number, '山口中村学園 中村女子高等学校');
ok($zip->set_number('7538531')->is_valid_number, '山口県立 西京高等学校');
ok($zip->set_number('7538533')->is_valid_number, '株式会社 文栄堂');
ok($zip->set_number('7538534')->is_valid_number, '山口県赤十字血液センター');
ok($zip->set_number('7538535')->is_valid_number, '自由民主党 山口県支部連合会');
ok($zip->set_number('7538536')->is_valid_number, 'パナソニックエレクトロニックデバイスジャパン 株式会社 アルミキャパシタディビジョン');
ok($zip->set_number('7538537')->is_valid_number, '山口県農業協同組合 山口統括本部');
ok($zip->set_number('7538538')->is_valid_number, '山口ケーブルビジョン 株式会社');
ok($zip->set_number('7538555')->is_valid_number, '山口県社会福祉事業団');
ok($zip->set_number('7538558')->is_valid_number, '医療法人 和同会 山口リハビリテーション病院');
ok($zip->set_number('7538570')->is_valid_number, 'YAB 山口朝日放送');
ok($zip->set_number('7538577')->is_valid_number, '山口地方法務局');
ok($zip->set_number('7538588')->is_valid_number, '山口県 山口健康福祉センター');
ok($zip->set_number('7538650')->is_valid_number, '山口市役所');
ok($zip->set_number('7538653')->is_valid_number, '山口銀行 山口支店');
ok($zip->set_number('7538654')->is_valid_number, '山口県 信用保証協会');
ok($zip->set_number('7540291')->is_valid_number, '美祢市 美東総合支所');
ok($zip->set_number('7541192')->is_valid_number, '山口市 秋穂総合支所');
ok($zip->set_number('7541193')->is_valid_number, '東洋ヒューム管 株式会社');
ok($zip->set_number('7541292')->is_valid_number, '山口市 阿知須総合支所');
ok($zip->set_number('7548501')->is_valid_number, '山口トヨタ自動車 株式会社');
ok($zip->set_number('7548511')->is_valid_number, '山口市小郡総合支所');
ok($zip->set_number('7548522')->is_valid_number, '全国健康保険協会 山口支部');
ok($zip->set_number('7548535')->is_valid_number, '山口県 共済農業協同組合連合会');
ok($zip->set_number('7548555')->is_valid_number, '山口県 経済農業協同組合連合会');
ok($zip->set_number('7548585')->is_valid_number, '山口県 農業協同組合中央会');
ok($zip->set_number('7548601')->is_valid_number, '三菱ふそうトラック・バス 株式会社 山口ふそう');
ok($zip->set_number('7548610')->is_valid_number, '吉南信用金庫 本店');
ok($zip->set_number('7548611')->is_valid_number, '山口県信用農業協同組合 連合会');
ok($zip->set_number('7550192')->is_valid_number, '株式会社 ぎじろくセンター');
ok($zip->set_number('7550195')->is_valid_number, '山口県産業技術センター');
ok($zip->set_number('7558501')->is_valid_number, 'EJホールディングス 株式会社 宇部事業所');
ok($zip->set_number('7558502')->is_valid_number, '山口銀行 宇部支店');
ok($zip->set_number('7558505')->is_valid_number, '山口大学 医学部');
ok($zip->set_number('7558510')->is_valid_number, '宇部マテリアルズ 株式会社');
ok($zip->set_number('7558511')->is_valid_number, '太陽家具百貨店 株式会社');
ok($zip->set_number('7558522')->is_valid_number, 'ウェルサンピア');
ok($zip->set_number('7558543')->is_valid_number, '宇部日報');
ok($zip->set_number('7558550')->is_valid_number, '宇部フロンティア大学 (短期大学部)');
ok($zip->set_number('7558554')->is_valid_number, '山口大学 医学部附属病院');
ok($zip->set_number('7558555')->is_valid_number, '宇部工業高等専門学校');
ok($zip->set_number('7558557')->is_valid_number, '宇部日報報道センター');
ok($zip->set_number('7558560')->is_valid_number, '宇部フロンティア大学 (付属中学校・香川高等学校)');
ok($zip->set_number('7558566')->is_valid_number, '株式会社 井上書店');
ok($zip->set_number('7558567')->is_valid_number, 'チタン工業 株式会社 宇部工場');
ok($zip->set_number('7558580')->is_valid_number, 'テクノUMG 株式会社');
ok($zip->set_number('7558585')->is_valid_number, '山口県 信用保証協会 宇部支所');
ok($zip->set_number('7558588')->is_valid_number, '株式会社 ユービーイーホテルズ');
ok($zip->set_number('7558601')->is_valid_number, '宇部市役所');
ok($zip->set_number('7558609')->is_valid_number, 'ハローワーク');
ok($zip->set_number('7558610')->is_valid_number, 'UBE 株式会社 恩田長沢寮');
ok($zip->set_number('7558611')->is_valid_number, '山口大学 工学部');
ok($zip->set_number('7558622')->is_valid_number, '(株) 宇部情報システム');
ok($zip->set_number('7558625')->is_valid_number, '宇部税務署');
ok($zip->set_number('7558633')->is_valid_number, 'UBE 株式会社');
ok($zip->set_number('7558642')->is_valid_number, '山口情報ビジネス専門学校');
ok($zip->set_number('7568501')->is_valid_number, '富士商 株式会社');
ok($zip->set_number('7568502')->is_valid_number, '株式会社 パオ');
ok($zip->set_number('7568585')->is_valid_number, '小野田商業開発 株式会社');
ok($zip->set_number('7568601')->is_valid_number, '山陽小野田市役所');
ok($zip->set_number('7568602')->is_valid_number, '嶋田工業');
ok($zip->set_number('7570292')->is_valid_number, '宇部市 楠総合支所');
ok($zip->set_number('7570298')->is_valid_number, '山口日本電気 株式会社');
ok($zip->set_number('7578511')->is_valid_number, '長州産業 株式会社');
ok($zip->set_number('7578585')->is_valid_number, 'NJコンポーネント 株式会社 山陽事業所');
ok($zip->set_number('7578634')->is_valid_number, '山陽小野田市 山陽総合事務所');
ok($zip->set_number('7578686')->is_valid_number, '日本化薬 株式会社 厚狭工場');
ok($zip->set_number('7588555')->is_valid_number, '萩市役所');
ok($zip->set_number('7588570')->is_valid_number, '萩社会保険事務所');
ok($zip->set_number('7588585')->is_valid_number, '至誠館大学');
ok($zip->set_number('7588615')->is_valid_number, '中国電力ネットワーク 株式会社 萩ネットワークセンター');
ok($zip->set_number('7588645')->is_valid_number, '山口県立 萩養護学校');
ok($zip->set_number('7588648')->is_valid_number, '萩 税務署');
ok($zip->set_number('7588686')->is_valid_number, '山口銀行 萩支店');
ok($zip->set_number('7590292')->is_valid_number, '常盤薬品 株式会社');
ok($zip->set_number('7590293')->is_valid_number, '山口銀行 西宇部支店');
ok($zip->set_number('7590295')->is_valid_number, '宇部工業 株式会社');
ok($zip->set_number('7590297')->is_valid_number, '新光産業 株式会社');
ok($zip->set_number('7592292')->is_valid_number, '美祢市役所');
ok($zip->set_number('7594192')->is_valid_number, '長門市役所');
ok($zip->set_number('7594194')->is_valid_number, '山口県厚生農業 協同組合 連合会 長門総合病院');
ok($zip->set_number('7594196')->is_valid_number, '株式会社 フジ 長門店');
ok($zip->set_number('7594198')->is_valid_number, '有限会社 まるみストアー');
ok($zip->set_number('7595592')->is_valid_number, '下関市役所 豊北総合支所');
ok($zip->set_number('7596592')->is_valid_number, '海上自衛隊 下関基地隊');
ok($zip->set_number('7596595')->is_valid_number, '独立行政法人 水産大学校');
ok($zip->set_number('7608502')->is_valid_number, 'セーラー広告 株式会社');
ok($zip->set_number('7608503')->is_valid_number, '西松建設 (株) 四国支店');
ok($zip->set_number('7608504')->is_valid_number, '生活協同組合 コープかがわ');
ok($zip->set_number('7608505')->is_valid_number, '株式会社ニシやマー');
ok($zip->set_number('7608507')->is_valid_number, '日立キャピタル 株式会社 高松支店');
ok($zip->set_number('7608508')->is_valid_number, '高松法務局');
ok($zip->set_number('7608510')->is_valid_number, '富士通 株式会社 四国支社');
ok($zip->set_number('7608511')->is_valid_number, '高松北警察署');
ok($zip->set_number('7608512')->is_valid_number, '四国経済産業局');
ok($zip->set_number('7608513')->is_valid_number, 'ナイスタウン出版 株式会社');
ok($zip->set_number('7608514')->is_valid_number, '香川県広域水道企業団');
ok($zip->set_number('7608515')->is_valid_number, '高松商工会議所');
ok($zip->set_number('7608516')->is_valid_number, '株式会社 高松天満屋');
ok($zip->set_number('7608517')->is_valid_number, '豊田通商 株式会社 高松営業所');
ok($zip->set_number('7608518')->is_valid_number, '四国機器 株式会社');
ok($zip->set_number('7608520')->is_valid_number, '株式会社 穴吹工務店');
ok($zip->set_number('7608521')->is_valid_number, '国立大学法人 香川大学 事務局');
ok($zip->set_number('7608522')->is_valid_number, '国立大学法人 香川大学 教育学部');
ok($zip->set_number('7608523')->is_valid_number, '国立大学法人 香川大学 法学部・経済学部');
ok($zip->set_number('7608524')->is_valid_number, '日本年金機構 高松広域事務センター');
ok($zip->set_number('7608525')->is_valid_number, '国立大学法人 香川大学 附属図書館');
ok($zip->set_number('7608527')->is_valid_number, '東京海上日動火災保険 株式会社 高松支店');
ok($zip->set_number('7608530')->is_valid_number, '高松平和病院');
ok($zip->set_number('7608533')->is_valid_number, '清水建設 株式会社 四国支店');
ok($zip->set_number('7608534')->is_valid_number, '社団法人 香川県医師会');
ok($zip->set_number('7608536')->is_valid_number, '新日本法規出版 株式会社 高松支社');
ok($zip->set_number('7608537')->is_valid_number, '香川県 社会保険診療報酬支払基金');
ok($zip->set_number('7608538')->is_valid_number, '四電ビジネス 株式会社');
ok($zip->set_number('7608539')->is_valid_number, '富士火災海上保険 株式会社');
ok($zip->set_number('7608545')->is_valid_number, '株式会社 高松リビング新聞社');
ok($zip->set_number('7608546')->is_valid_number, '国土交通省 香川河川国道事務所');
ok($zip->set_number('7608547')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ 四国支社');
ok($zip->set_number('7608550')->is_valid_number, '四国財務局');
ok($zip->set_number('7608551')->is_valid_number, '扶桑建設工業 株式会社');
ok($zip->set_number('7608552')->is_valid_number, '株式会社 河野');
ok($zip->set_number('7608554')->is_valid_number, '四国地方整備局');
ok($zip->set_number('7608555')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ 四国支社');
ok($zip->set_number('7608557')->is_valid_number, '香川県立 中央病院');
ok($zip->set_number('7608558')->is_valid_number, '中商事 株式会社');
ok($zip->set_number('7608559')->is_valid_number, '四電ビジネス 株式会社');
ok($zip->set_number('7608560')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('7608561')->is_valid_number, '鹿島建設 株式会社 四国支店');
ok($zip->set_number('7608562')->is_valid_number, '香川県 中小企業団体中央会');
ok($zip->set_number('7608564')->is_valid_number, '全国健康保険協会 香川支部');
ok($zip->set_number('7608566')->is_valid_number, '住友生命保険相互会社 高松支社');
ok($zip->set_number('7608567')->is_valid_number, '四国医療器 株式会社');
ok($zip->set_number('7608568')->is_valid_number, '香川トヨタ自動車 (株) 本社');
ok($zip->set_number('7608569')->is_valid_number, 'ネスレ日本 (株) 高松支店');
ok($zip->set_number('7608570')->is_valid_number, '香川県庁');
ok($zip->set_number('7608571')->is_valid_number, '高松市役所');
ok($zip->set_number('7608572')->is_valid_number, '株式会社 四国新聞社');
ok($zip->set_number('7608573')->is_valid_number, '四国電力株式会社 本店');
ok($zip->set_number('7608574')->is_valid_number, '株式会社 百十四銀行');
ok($zip->set_number('7608575')->is_valid_number, '西日本放送 株式会社');
ok($zip->set_number('7608576')->is_valid_number, '株式会社 香川銀行');
ok($zip->set_number('7608579')->is_valid_number, '香川県 警察本部');
ok($zip->set_number('7608580')->is_valid_number, '四国旅客鉄道 株式会社');
ok($zip->set_number('7608582')->is_valid_number, '香川県教育委員会');
ok($zip->set_number('7608583')->is_valid_number, 'ティーメックス 株式会社');
ok($zip->set_number('7608585')->is_valid_number, '高松家庭裁判所');
ok($zip->set_number('7608586')->is_valid_number, '高松地方裁判所');
ok($zip->set_number('7608588')->is_valid_number, '株式会社 四電工 香川支店');
ok($zip->set_number('7608589')->is_valid_number, '株式会社 高松三越');
ok($zip->set_number('7608590')->is_valid_number, '日本年金機構 中央年金センター');
ok($zip->set_number('7608601')->is_valid_number, '日本生命保険 相互会社 高松支社');
ok($zip->set_number('7608603')->is_valid_number, '株式会社 四国銀行 高松支店');
ok($zip->set_number('7608604')->is_valid_number, '野村證券株式会社高松支店');
ok($zip->set_number('7608607')->is_valid_number, '香川証券');
ok($zip->set_number('7608608')->is_valid_number, '農林中央金庫 高松支店');
ok($zip->set_number('7608610')->is_valid_number, '四国電力送配電 株式会社');
ok($zip->set_number('7608614')->is_valid_number, '(株) 伊予銀行 高松支店');
ok($zip->set_number('7608615')->is_valid_number, '高松税務署内 土庄税務署 集中処理担当');
ok($zip->set_number('7608618')->is_valid_number, '信金中央金庫 四国支店');
ok($zip->set_number('7608620')->is_valid_number, '日本銀行 高松支店');
ok($zip->set_number('7608621')->is_valid_number, '株式会社 愛媛銀行 高松支店');
ok($zip->set_number('7608623')->is_valid_number, '商工組合中央金庫 高松支店');
ok($zip->set_number('7608624')->is_valid_number, '日新火災海上保険 株式会社 四国統括サービス部');
ok($zip->set_number('7608625')->is_valid_number, 'SMBC日興証券 株式会社 高松支店');
ok($zip->set_number('7608626')->is_valid_number, '徳島銀行 高松支店');
ok($zip->set_number('7608630')->is_valid_number, '株式会社 三菱東京UFJ銀行 高松支店');
ok($zip->set_number('7608634')->is_valid_number, '三菱商事 株式会社 四国支店');
ok($zip->set_number('7608636')->is_valid_number, '簡易保険加入者協会');
ok($zip->set_number('7608638')->is_valid_number, '株式会社 百十四銀行 高松支店');
ok($zip->set_number('7608639')->is_valid_number, '株式会社 三越 高松店');
ok($zip->set_number('7608644')->is_valid_number, '香川県 信用農業協同組合連合会');
ok($zip->set_number('7608648')->is_valid_number, '四国興業 株式会社');
ok($zip->set_number('7608650')->is_valid_number, '百十四ワークサポート 株式会社');
ok($zip->set_number('7608655')->is_valid_number, '第一生命保険相互会社 高松支社');
ok($zip->set_number('7608660')->is_valid_number, '四国総合信用 株式会社');
ok($zip->set_number('7608661')->is_valid_number, '香川県 信用保証協会');
ok($zip->set_number('7608667')->is_valid_number, '株式会社 中国銀行 高松支店');
ok($zip->set_number('7608668')->is_valid_number, '高松信用金庫');
ok($zip->set_number('7608671')->is_valid_number, '株式会社 阿波銀行 高松支店');
ok($zip->set_number('7608686')->is_valid_number, '日本放送協会 高松放送局');
ok($zip->set_number('7608687')->is_valid_number, '日本通運 (株) 四国支店');
ok($zip->set_number('7608688')->is_valid_number, '株式会社 帝国データバンク 高松支店');
ok($zip->set_number('7610185')->is_valid_number, '(株) タダノ');
ok($zip->set_number('7610186')->is_valid_number, '香川県厚生農業協同組合連合会');
ok($zip->set_number('7610186')->is_valid_number, '香川県厚生農業協同組合連合会 屋島総合病院');
ok($zip->set_number('7610187')->is_valid_number, '高松市役所 庵治支所');
ok($zip->set_number('7610188')->is_valid_number, '高松市役所 牟礼支所');
ok($zip->set_number('7610189')->is_valid_number, '大豊産業 (株)');
ok($zip->set_number('7610192')->is_valid_number, '四国総合研究所');
ok($zip->set_number('7610193')->is_valid_number, '高松東病院');
ok($zip->set_number('7610194')->is_valid_number, '四国高松学園');
ok($zip->set_number('7610195')->is_valid_number, '株式会社 STNet');
ok($zip->set_number('7610196')->is_valid_number, '鎌長製衡 (株)');
ok($zip->set_number('7610197')->is_valid_number, '四国コカ・コーラボトリング (株)');
ok($zip->set_number('7610198')->is_valid_number, '国立療養所 大島青松園');
ok($zip->set_number('7610393')->is_valid_number, '香川県立図書館');
ok($zip->set_number('7610394')->is_valid_number, '谷口建設興業 株式会社');
ok($zip->set_number('7610395')->is_valid_number, '国立研究開発法人 産業技術総合研究所四国センター');
ok($zip->set_number('7610396')->is_valid_number, '香川大学 工学部');
ok($zip->set_number('7610397')->is_valid_number, 'トーヨースギウエ 株式会社');
ok($zip->set_number('7610492')->is_valid_number, '(株) カナック');
ok($zip->set_number('7610493')->is_valid_number, '吉野川電線 株式会社');
ok($zip->set_number('7610692')->is_valid_number, '三木町役場');
ok($zip->set_number('7610793')->is_valid_number, '香川大学 医学部');
ok($zip->set_number('7610795')->is_valid_number, '香川大学 農学部');
ok($zip->set_number('7611492')->is_valid_number, '高松空港事務所');
ok($zip->set_number('7611493')->is_valid_number, '高松市役所 香南支所');
ok($zip->set_number('7611494')->is_valid_number, '株式会社 レクザム 香川工場');
ok($zip->set_number('7611592')->is_valid_number, '高松市 塩江支所');
ok($zip->set_number('7611792')->is_valid_number, '四国松下設備機器 株式会社');
ok($zip->set_number('7611793')->is_valid_number, '四国繊維販売 (株)');
ok($zip->set_number('7611794')->is_valid_number, '香川県立 香川中央高等学校');
ok($zip->set_number('7611795')->is_valid_number, '高松市役所 香川支所');
ok($zip->set_number('7612392')->is_valid_number, '綾川町役場');
ok($zip->set_number('7612393')->is_valid_number, '香川県厚生農業協同組合連合会 滝宮総合病院');
ok($zip->set_number('7612395')->is_valid_number, '香川県立 農業経営高等学校');
ok($zip->set_number('7612396')->is_valid_number, '香川松下電工 株式会社');
ok($zip->set_number('7612492')->is_valid_number, '丸亀市 綾歌市民総合センター');
ok($zip->set_number('7612493')->is_valid_number, 'ニューレオマワールド');
ok($zip->set_number('7614192')->is_valid_number, '土庄町役場');
ok($zip->set_number('7614193')->is_valid_number, '土庄高等学校');
ok($zip->set_number('7614194')->is_valid_number, 'タカラ繊維 (株)');
ok($zip->set_number('7614388')->is_valid_number, '小豆島町役場');
ok($zip->set_number('7614392')->is_valid_number, '小豆島総合食品 株式会社');
ok($zip->set_number('7614393')->is_valid_number, '株式会社 ナガセ');
ok($zip->set_number('7614395')->is_valid_number, '有限会社 井上誠耕園');
ok($zip->set_number('7614396')->is_valid_number, '丸善製麺工場 有限会社');
ok($zip->set_number('7614397')->is_valid_number, '小豆島手延素麺協同組合');
ok($zip->set_number('7614398')->is_valid_number, '東洋オリーブ 株式会社');
ok($zip->set_number('7614489')->is_valid_number, '中国電力ネットワーク 株式会社 小豆島ネットワークセンター');
ok($zip->set_number('7614492')->is_valid_number, '小豆島町役場 分庁舎(内海庁舎)');
ok($zip->set_number('7614493')->is_valid_number, '宝食品 株式会社');
ok($zip->set_number('7614494')->is_valid_number, '島乃香 株式会社');
ok($zip->set_number('7614495')->is_valid_number, '丸島醤油 株式会社');
ok($zip->set_number('7614496')->is_valid_number, '株式会社 亜味撰');
ok($zip->set_number('7614497')->is_valid_number, '株式会社 島一');
ok($zip->set_number('7614498')->is_valid_number, '盛田 株式会社 小豆島工場');
ok($zip->set_number('7618501')->is_valid_number, '株式会社 アスティス');
ok($zip->set_number('7618511')->is_valid_number, '高松南警察署');
ok($zip->set_number('7618520')->is_valid_number, '株式会社 菱屋');
ok($zip->set_number('7618533')->is_valid_number, 'ユアサ商事 株式会社 四国支店');
ok($zip->set_number('7618538')->is_valid_number, '高松市立みんなの病院');
ok($zip->set_number('7618541')->is_valid_number, '四電エンジニアリング 株式会社');
ok($zip->set_number('7618550')->is_valid_number, '四国電力 株式会社 高松支店');
ok($zip->set_number('7618551')->is_valid_number, '株式会社 フソウ 四国支店');
ok($zip->set_number('7618555')->is_valid_number, '株式会社 トーカイ');
ok($zip->set_number('7618558')->is_valid_number, '株式会社 一誠社');
ok($zip->set_number('7618565')->is_valid_number, '(株) 四電工 本店');
ok($zip->set_number('7618566')->is_valid_number, '高松公共職業安定所');
ok($zip->set_number('7618567')->is_valid_number, '松野不動産 株式会社');
ok($zip->set_number('7618577')->is_valid_number, '株式会社 セシール 志度ロジスティクスセンター');
ok($zip->set_number('7618578')->is_valid_number, '株式会社 セシール 香川オフィス');
ok($zip->set_number('7618581')->is_valid_number, '株式会社 瀬戸内海放送');
ok($zip->set_number('7618582')->is_valid_number, '株式会社 サンキ');
ok($zip->set_number('7618584')->is_valid_number, '株式会社 エフエム香川');
ok($zip->set_number('7618585')->is_valid_number, 'マックスバリュ西日本 株式会社 四国事務所');
ok($zip->set_number('7618586')->is_valid_number, '株式会社 ナカノ');
ok($zip->set_number('7618588')->is_valid_number, '株式会社 Jコンテンツ');
ok($zip->set_number('7618589')->is_valid_number, '株式会社 アイム');
ok($zip->set_number('7618601')->is_valid_number, '株式会社 幸燿');
ok($zip->set_number('7618777')->is_valid_number, '株式会社 セシール');
ok($zip->set_number('7628502')->is_valid_number, '香川シームレス (株)');
ok($zip->set_number('7628503')->is_valid_number, 'コスモ石油 株式会社 坂出物流基地');
ok($zip->set_number('7628505')->is_valid_number, 'イオンリテール 株式会社 イオン坂出支店');
ok($zip->set_number('7628507')->is_valid_number, '(株) 川崎造船坂出工場');
ok($zip->set_number('7628508')->is_valid_number, '坂出商工会議所');
ok($zip->set_number('7628510')->is_valid_number, '三菱化学 株式会社 坂出事業所');
ok($zip->set_number('7628511')->is_valid_number, '株式会社 石垣');
ok($zip->set_number('7628515')->is_valid_number, '飯山市民総合センター');
ok($zip->set_number('7628550')->is_valid_number, '総合病院 坂出市立病院');
ok($zip->set_number('7628601')->is_valid_number, '坂出市役所');
ok($zip->set_number('7628602')->is_valid_number, '鎌田醤油 株式会社');
ok($zip->set_number('7638501')->is_valid_number, '丸亀市役所');
ok($zip->set_number('7638502')->is_valid_number, '香川労災病院');
ok($zip->set_number('7638503')->is_valid_number, '三船病院');
ok($zip->set_number('7638504')->is_valid_number, '四国化成工業 株式会社');
ok($zip->set_number('7638507')->is_valid_number, 'まるがめ医療センター');
ok($zip->set_number('7638508')->is_valid_number, '大倉工業 株式会社');
ok($zip->set_number('7638510')->is_valid_number, '株式会社 カンペ共販四国');
ok($zip->set_number('7638511')->is_valid_number, '今治造船 (株) 丸亀事業本部');
ok($zip->set_number('7638512')->is_valid_number, '香川県立 丸亀高等学校');
ok($zip->set_number('7638513')->is_valid_number, '香川県立高等技術学校丸亀校');
ok($zip->set_number('7638516')->is_valid_number, '三菱電機 株式会社 受配電システム製作所');
ok($zip->set_number('7638518')->is_valid_number, '香川県立 丸亀病院');
ok($zip->set_number('7638603')->is_valid_number, '富士産業 株式会社');
ok($zip->set_number('7638605')->is_valid_number, '株式会社 伏見製薬所');
ok($zip->set_number('7638608')->is_valid_number, '大正製薬 株式会社 中四国支店 四国事業所');
ok($zip->set_number('7648501')->is_valid_number, '多度津町役場・地域交流センター');
ok($zip->set_number('7648502')->is_valid_number, '四国計測工業 株式会社');
ok($zip->set_number('7648503')->is_valid_number, '波止浜造船 (株)');
ok($zip->set_number('7648505')->is_valid_number, '(株) 英弘チエン');
ok($zip->set_number('7648507')->is_valid_number, '四変テック (株)');
ok($zip->set_number('7648508')->is_valid_number, '多度津商工会議所');
ok($zip->set_number('7648510')->is_valid_number, '株式会社 長府製作所 香川工場');
ok($zip->set_number('7648511')->is_valid_number, '宗教法人 金剛禅総本山少林寺');
ok($zip->set_number('7648520')->is_valid_number, '川田工業 株式会社');
ok($zip->set_number('7658502')->is_valid_number, '陸上自衛隊 善通寺駐屯地');
ok($zip->set_number('7658503')->is_valid_number, '香川県 善通寺市役所');
ok($zip->set_number('7658505')->is_valid_number, '四国学院大学');
ok($zip->set_number('7658506')->is_valid_number, '総本山善通寺');
ok($zip->set_number('7658507')->is_valid_number, '独立行政法人 国立病院機構四国こどもとおとなの医療センター');
ok($zip->set_number('7658508')->is_valid_number, '国立研究開発法人 農研機構善通寺研究拠点');
ok($zip->set_number('7668501')->is_valid_number, '金刀比羅宮');
ok($zip->set_number('7668502')->is_valid_number, '琴平町役場');
ok($zip->set_number('7678507')->is_valid_number, '丸善');
ok($zip->set_number('7678510')->is_valid_number, '三豊市立 西香川病院');
ok($zip->set_number('7678513')->is_valid_number, '四国学院大学 香川西高等学校');
ok($zip->set_number('7678585')->is_valid_number, '三豊市役所');
ok($zip->set_number('7680192')->is_valid_number, '(株) 志満秀');
ok($zip->set_number('7680195')->is_valid_number, '三豊市 山本支所');
ok($zip->set_number('7688601')->is_valid_number, '観音寺市役所');
ok($zip->set_number('7688602')->is_valid_number, '株式会社 サムソン');
ok($zip->set_number('7690192')->is_valid_number, '高松市役所 国分寺支所');
ok($zip->set_number('7690193')->is_valid_number, '四国アルフレッサ 株式会社');
ok($zip->set_number('7690194')->is_valid_number, '四国松下ライフエレクトロニクス 株式会社');
ok($zip->set_number('7690195')->is_valid_number, '加藤産業 株式会社 高松支店');
ok($zip->set_number('7690197')->is_valid_number, '(株) カワイ');
ok($zip->set_number('7690198')->is_valid_number, '株式会社 マルヨシセンター');
ok($zip->set_number('7690292')->is_valid_number, '宇多津町役場');
ok($zip->set_number('7690293')->is_valid_number, 'YKKAP 株式会社 四国事業所');
ok($zip->set_number('7690295')->is_valid_number, 'トラスコ中山 (株) 高松営業所');
ok($zip->set_number('7690296')->is_valid_number, '郷照寺');
ok($zip->set_number('7691192')->is_valid_number, '香川高等専門学校 詫間キャンパス');
ok($zip->set_number('7691593')->is_valid_number, '三豊市役所 豊中庁舎');
ok($zip->set_number('7691695')->is_valid_number, '三豊総合病院');
ok($zip->set_number('7691696')->is_valid_number, '第一衛材 株式会社');
ok($zip->set_number('7691698')->is_valid_number, '森孵卵場 株式会社');
ok($zip->set_number('7692192')->is_valid_number, 'キャスコ (株)');
ok($zip->set_number('7692193')->is_valid_number, '徳島文理大学 香川校');
ok($zip->set_number('7692195')->is_valid_number, 'さぬき市役所');
ok($zip->set_number('7692395')->is_valid_number, 'さぬき市役所 (寒川庁舎)');
ok($zip->set_number('7692396')->is_valid_number, 'さぬき市教育委員会');
ok($zip->set_number('7692492')->is_valid_number, 'さぬき市 (津田出張所)');
ok($zip->set_number('7692692')->is_valid_number, 'ひとの駅さんぼんまつ');
ok($zip->set_number('7692693')->is_valid_number, '株式会社 トーコー');
ok($zip->set_number('7692695')->is_valid_number, '帝國製薬 株式会社');
ok($zip->set_number('7692696')->is_valid_number, '株式会社 オールインワン');
ok($zip->set_number('7692788')->is_valid_number, '香川県立 白鳥病院');
ok($zip->set_number('7692792')->is_valid_number, '東かがわ市役所');
ok($zip->set_number('7692793')->is_valid_number, '四国化工 株式会社 西山第一工場');
ok($zip->set_number('7692794')->is_valid_number, '四国化工 株式会社');
ok($zip->set_number('7692795')->is_valid_number, '(株) スワニー');
ok($zip->set_number('7692796')->is_valid_number, '(株) ナイガイ');
ok($zip->set_number('7692797')->is_valid_number, '四国化工 株式会社');
ok($zip->set_number('7692992')->is_valid_number, '東かがわ市役所 引田庁舎');
ok($zip->set_number('7708501')->is_valid_number, '徳島大学 事務局');
ok($zip->set_number('7708502')->is_valid_number, '徳島大学 総合科学部');
ok($zip->set_number('7708503')->is_valid_number, '徳島大学 医学部');
ok($zip->set_number('7708503')->is_valid_number, '徳島大学先端酵素学研究所');
ok($zip->set_number('7708503')->is_valid_number, '徳島大学病院');
ok($zip->set_number('7708504')->is_valid_number, '徳島大学 歯学部');
ok($zip->set_number('7708505')->is_valid_number, '徳島大学 薬学部');
ok($zip->set_number('7708506')->is_valid_number, '徳島大学 工学部');
ok($zip->set_number('7708506')->is_valid_number, '徳島大学 理工学部');
ok($zip->set_number('7708507')->is_valid_number, '徳島大学 附属図書館');
ok($zip->set_number('7708508')->is_valid_number, '徳島大学 附属図書館 蔵本分館');
ok($zip->set_number('7708509')->is_valid_number, '徳島大学 医学部 保健学科');
ok($zip->set_number('7708510')->is_valid_number, '徳島県 警察本部');
ok($zip->set_number('7708511')->is_valid_number, '株式会社 徳島そごう');
ok($zip->set_number('7708512')->is_valid_number, '徳島地方法務局');
ok($zip->set_number('7708513')->is_valid_number, '徳島大学 生物資源産業学部');
ok($zip->set_number('7708514')->is_valid_number, '徳島文理大学');
ok($zip->set_number('7708515')->is_valid_number, '日本年金機構 徳島事務センター');
ok($zip->set_number('7708516')->is_valid_number, '徳島県 漁業協同組合連合会');
ok($zip->set_number('7708518')->is_valid_number, '三協商事 株式会社');
ok($zip->set_number('7708520')->is_valid_number, '東京海上日動火災保険 株式会社 徳島支店');
ok($zip->set_number('7708521')->is_valid_number, '日本電信電話 株式会社 徳島支店');
ok($zip->set_number('7708522')->is_valid_number, '日本年金機構 徳島北年金事務所');
ok($zip->set_number('7708523')->is_valid_number, '株式会社 新学社 徳島支社');
ok($zip->set_number('7708524')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ四国 徳島支店');
ok($zip->set_number('7708525')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('7708526')->is_valid_number, '阿波銀リース 株式会社');
ok($zip->set_number('7708528')->is_valid_number, '徳島地方(簡易・家庭)裁判所・徳島検察審査会');
ok($zip->set_number('7708529')->is_valid_number, '株式会社 メディコム');
ok($zip->set_number('7708530')->is_valid_number, '徳島商工会議所');
ok($zip->set_number('7708531')->is_valid_number, '株式会社 稲垣');
ok($zip->set_number('7708532')->is_valid_number, '社団法人 徳島県薬剤師会');
ok($zip->set_number('7708533')->is_valid_number, '徳島労働基準監督署');
ok($zip->set_number('7708535')->is_valid_number, '株式会社 あわわ');
ok($zip->set_number('7708536')->is_valid_number, '株式会社 フナコシ');
ok($zip->set_number('7708537')->is_valid_number, '全国農業協同組合連合会 徳島県本部');
ok($zip->set_number('7708538')->is_valid_number, 'ナカイ 株式会社');
ok($zip->set_number('7708539')->is_valid_number, '徳島県立 中央病院');
ok($zip->set_number('7708540')->is_valid_number, '株式会社 三井');
ok($zip->set_number('7708541')->is_valid_number, '全国健康保険協会 徳島支部');
ok($zip->set_number('7708544')->is_valid_number, '日本放送協会 徳島放送局');
ok($zip->set_number('7708546')->is_valid_number, '富士スレート 株式会社');
ok($zip->set_number('7708547')->is_valid_number, '徳島健康生活協同組合本部');
ok($zip->set_number('7708547')->is_valid_number, '徳島健生病院');
ok($zip->set_number('7708548')->is_valid_number, '社会医療法人川島会 川島病院');
ok($zip->set_number('7708550')->is_valid_number, '徳島県中小企業団体中央会');
ok($zip->set_number('7708551')->is_valid_number, '徳島県市町村職員共済組合');
ok($zip->set_number('7708552')->is_valid_number, 'ケーブルテレビ徳島 株式会社');
ok($zip->set_number('7708554')->is_valid_number, '国土交通省四国地方整備局 徳島河川国道事務所');
ok($zip->set_number('7708555')->is_valid_number, '四国電力 株式会社 徳島支店');
ok($zip->set_number('7708558')->is_valid_number, '株式会社 よんやく徳島');
ok($zip->set_number('7708560')->is_valid_number, '学校法人 村崎学園 徳島文理大学 学園本部');
ok($zip->set_number('7708563')->is_valid_number, '徳島製粉 株式会社');
ok($zip->set_number('7708565')->is_valid_number, '徳島県 医師会');
ok($zip->set_number('7708567')->is_valid_number, '株式会社 エフエム徳島');
ok($zip->set_number('7708570')->is_valid_number, '徳島県庁');
ok($zip->set_number('7708571')->is_valid_number, '徳島市役所');
ok($zip->set_number('7708572')->is_valid_number, '社団法人 徳島新聞社');
ok($zip->set_number('7708573')->is_valid_number, '四国放送 株式会社');
ok($zip->set_number('7708585')->is_valid_number, '株式会社 エフエムびざん');
ok($zip->set_number('7708588')->is_valid_number, 'レディスファイブ');
ok($zip->set_number('7708601')->is_valid_number, '株式会社 阿波銀行');
ok($zip->set_number('7708605')->is_valid_number, '株式会社 岡田組');
ok($zip->set_number('7708610')->is_valid_number, '株式会社 姫野組');
ok($zip->set_number('7708648')->is_valid_number, '徳島銀行 本店');
ok($zip->set_number('7708787')->is_valid_number, '徳島地域センター');
ok($zip->set_number('7708794')->is_valid_number, '徳島貯金事務センター');
ok($zip->set_number('7708798')->is_valid_number, '徳島逓信病院');
ok($zip->set_number('7710182')->is_valid_number, '大塚製薬 株式会社 徳島第二工場');
ok($zip->set_number('7710183')->is_valid_number, '大塚食品 株式会社');
ok($zip->set_number('7710185')->is_valid_number, '株式会社 大一器械');
ok($zip->set_number('7710186')->is_valid_number, '港産業 株式会社');
ok($zip->set_number('7710187')->is_valid_number, '日清紡績 株式会社 徳島工場');
ok($zip->set_number('7710188')->is_valid_number, '東亞合成株式会社徳島工場');
ok($zip->set_number('7710189')->is_valid_number, '株式会社 ジャストシステム 本社');
ok($zip->set_number('7710192')->is_valid_number, '大塚製薬 株式会社 徳島本部');
ok($zip->set_number('7710193')->is_valid_number, '大塚化学 株式会社 徳島工場');
ok($zip->set_number('7710194')->is_valid_number, '大鵬薬品工業 株式会社 徳島工場');
ok($zip->set_number('7710195')->is_valid_number, '大塚製薬 株式会社 診断事業部');
ok($zip->set_number('7710196')->is_valid_number, '株式会社 幸燿');
ok($zip->set_number('7710197')->is_valid_number, '四国アルフレッサ 株式会社');
ok($zip->set_number('7710198')->is_valid_number, '株式会社 キョーエイ');
ok($zip->set_number('7710281')->is_valid_number, '大塚ビジネスサポート 株式会社');
ok($zip->set_number('7710282')->is_valid_number, '大塚ホールデングス 株式会社 大塚ビジネスサポートセンター');
ok($zip->set_number('7710283')->is_valid_number, 'はーとふる川内 株式会社');
ok($zip->set_number('7710284')->is_valid_number, '大塚製薬健康保険組合');
ok($zip->set_number('7710285')->is_valid_number, '北島町役場');
ok($zip->set_number('7710287')->is_valid_number, '四国化工機 (株)');
ok($zip->set_number('7710288')->is_valid_number, '四国化成工業 (株) 徳島第二工場');
ok($zip->set_number('7710289')->is_valid_number, '生活協同組合 とくしま生協');
ok($zip->set_number('7710292')->is_valid_number, '海上自衛隊徳島教育航空群');
ok($zip->set_number('7710293')->is_valid_number, '旭食品 (株) 徳島支店');
ok($zip->set_number('7710294')->is_valid_number, '株式会社 フジモト');
ok($zip->set_number('7710295')->is_valid_number, '松茂町役場');
ok($zip->set_number('7710296')->is_valid_number, '株式会社 大塚製薬工場 松茂工場');
ok($zip->set_number('7710298')->is_valid_number, '赤松化成工業 株式会社');
ok($zip->set_number('7711192')->is_valid_number, '学校法人 四国大学');
ok($zip->set_number('7711193')->is_valid_number, '徳島県 自動車税事務所');
ok($zip->set_number('7711289')->is_valid_number, '(株) メディング');
ok($zip->set_number('7711292')->is_valid_number, '藍住町役場');
ok($zip->set_number('7711294')->is_valid_number, '(株) ジェイテクト 徳島工場');
ok($zip->set_number('7711295')->is_valid_number, '(株) ジェイテクトシーリングテクノ');
ok($zip->set_number('7711297')->is_valid_number, 'かねこみそ (株)');
ok($zip->set_number('7711298')->is_valid_number, 'ヤマク食品 (株)');
ok($zip->set_number('7711392')->is_valid_number, '上板町役場');
ok($zip->set_number('7711492')->is_valid_number, '阿波市 吉野支所');
ok($zip->set_number('7711493')->is_valid_number, '徳島県立 阿波高等学校');
ok($zip->set_number('7711494')->is_valid_number, '佐々木建設 株式会社');
ok($zip->set_number('7711498')->is_valid_number, '株式会社 エスティック');
ok($zip->set_number('7711592')->is_valid_number, '阿波市 土成支所');
ok($zip->set_number('7711695')->is_valid_number, '阿波市役所');
ok($zip->set_number('7711792')->is_valid_number, '阿波市 阿波支所');
ok($zip->set_number('7712195')->is_valid_number, '美馬市美馬町市民サービスセンター');
ok($zip->set_number('7712395')->is_valid_number, '三好市役所 三野総合支所');
ok($zip->set_number('7712595')->is_valid_number, '東みよし町役場 三好庁舎');
ok($zip->set_number('7713395')->is_valid_number, '神山町役場');
ok($zip->set_number('7714195')->is_valid_number, '佐那河内村役場');
ok($zip->set_number('7714395')->is_valid_number, '勝浦町役場');
ok($zip->set_number('7715295')->is_valid_number, '那賀町役場');
ok($zip->set_number('7715495')->is_valid_number, '那賀町役場 相生庁舎');
ok($zip->set_number('7716192')->is_valid_number, '那賀町役場 木沢支所');
ok($zip->set_number('7716495')->is_valid_number, '那賀町役場 木頭支所');
ok($zip->set_number('7728501')->is_valid_number, '鳴門市役所');
ok($zip->set_number('7728502')->is_valid_number, '鳴門教育大学');
ok($zip->set_number('7728503')->is_valid_number, '健康保険 鳴門病院');
ok($zip->set_number('7728510')->is_valid_number, '鳴門市 競艇部');
ok($zip->set_number('7728511')->is_valid_number, '大塚包装工業 株式会社');
ok($zip->set_number('7728515')->is_valid_number, '医療法人 久仁会 鳴門山上病院');
ok($zip->set_number('7728520')->is_valid_number, '鳴門塩業 (株)');
ok($zip->set_number('7728601')->is_valid_number, '(株) 大塚製薬工場');
ok($zip->set_number('7738501')->is_valid_number, '小松島市役所');
ok($zip->set_number('7738502')->is_valid_number, '徳島 赤十字病院');
ok($zip->set_number('7738504')->is_valid_number, 'ニホンフラッシュ 株式会社');
ok($zip->set_number('7738601')->is_valid_number, '海上自衛隊 小松島航空隊');
ok($zip->set_number('7748501')->is_valid_number, '阿南市役所');
ok($zip->set_number('7748601')->is_valid_number, '日亜化学工業 株式会社');
ok($zip->set_number('7750295')->is_valid_number, '海陽町役場');
ok($zip->set_number('7750395')->is_valid_number, '海陽町役場 海部庁舎');
ok($zip->set_number('7750595')->is_valid_number, '海陽町役場 宍喰庁舎');
ok($zip->set_number('7758570')->is_valid_number, '牟岐町役場');
ok($zip->set_number('7768501')->is_valid_number, '株式会社 高橋ふとん店');
ok($zip->set_number('7768511')->is_valid_number, 'JA徳島厚生連 吉野川医療センター');
ok($zip->set_number('7768555')->is_valid_number, 'コロナ工業 株式会社');
ok($zip->set_number('7768582')->is_valid_number, '野田ハニー食品工業 (株)');
ok($zip->set_number('7768583')->is_valid_number, '野田養蜂場 (株)');
ok($zip->set_number('7768585')->is_valid_number, '国立 療養所 徳島病院');
ok($zip->set_number('7768588')->is_valid_number, '鴨島病院');
ok($zip->set_number('7768611')->is_valid_number, '吉野川市役所');
ok($zip->set_number('7768686')->is_valid_number, '株式会社 マルハヤ');
ok($zip->set_number('7770395')->is_valid_number, '美馬市 木屋平総合支所');
ok($zip->set_number('7778577')->is_valid_number, '美馬市役所');
ok($zip->set_number('7780195')->is_valid_number, '三好市役所 西祖谷総合支所');
ok($zip->set_number('7780295')->is_valid_number, '三好市役所 東祖谷総合支所');
ok($zip->set_number('7788501')->is_valid_number, '三好市役所');
ok($zip->set_number('7788503')->is_valid_number, '徳島県立 三好病院');
ok($zip->set_number('7788504')->is_valid_number, '四国電力 株式会社 池田支店');
ok($zip->set_number('7788505')->is_valid_number, '株式会社 セイア');
ok($zip->set_number('7788506')->is_valid_number, '徳島県立 池田高等学校');
ok($zip->set_number('7788507')->is_valid_number, '株式会社 マナベ商事');
ok($zip->set_number('7790192')->is_valid_number, '板野町役場');
ok($zip->set_number('7790193')->is_valid_number, '国立療養所 東徳島病院');
ok($zip->set_number('7790194')->is_valid_number, '冨士ファニチア 株式会社');
ok($zip->set_number('7790195')->is_valid_number, '大塚製薬 株式会社 徳島板野工場');
ok($zip->set_number('7791195')->is_valid_number, '阿南市 羽ノ浦支所');
ok($zip->set_number('7791292')->is_valid_number, 'バイオ科学 株式会社');
ok($zip->set_number('7791293')->is_valid_number, '株式会社 コート・ベール徳島 ゴルフクラブ');
ok($zip->set_number('7791295')->is_valid_number, '阿南市 那賀川支所');
ok($zip->set_number('7792195')->is_valid_number, '美波町 由岐支所');
ok($zip->set_number('7792395')->is_valid_number, '美波町役場');
ok($zip->set_number('7793295')->is_valid_number, '石井町役場');
ok($zip->set_number('7793298')->is_valid_number, '加賀屋醤油 株式会社');
ok($zip->set_number('7793393')->is_valid_number, '株式会社 ヨコタ・コーポレーション');
ok($zip->set_number('7793394')->is_valid_number, '日本フネン 株式会社');
ok($zip->set_number('7793395')->is_valid_number, '吉野川市 川島支所');
ok($zip->set_number('7793495')->is_valid_number, '吉野川市 山川支所');
ok($zip->set_number('7793595')->is_valid_number, '吉野川市 美郷支所');
ok($zip->set_number('7793695')->is_valid_number, '美馬市脇町市民サービスセンター');
ok($zip->set_number('7794193')->is_valid_number, '日本年金機構 阿波半田年金事務所');
ok($zip->set_number('7794195')->is_valid_number, 'つるぎ町役場');
ok($zip->set_number('7794495')->is_valid_number, 'つるぎ町役場 半田支所');
ok($zip->set_number('7794795')->is_valid_number, '東みよし町役場');
ok($zip->set_number('7794895')->is_valid_number, '三好市役所 井川総合支所');
ok($zip->set_number('7795395')->is_valid_number, '三好市役所 山城総合支所');
ok($zip->set_number('7808501')->is_valid_number, '全国健康保険協会 高知支部');
ok($zip->set_number('7808502')->is_valid_number, '高知県 社会保険診療報酬支払基金');
ok($zip->set_number('7808503')->is_valid_number, '医療法人 瑞洋会 田中整形外科病院');
ok($zip->set_number('7808504')->is_valid_number, '大家建材 株式会社');
ok($zip->set_number('7808507')->is_valid_number, '独立行政法人 国立病院機構 高知病院');
ok($zip->set_number('7808508')->is_valid_number, '松田医薬品 株式会社');
ok($zip->set_number('7808509')->is_valid_number, '高知地方法務局');
ok($zip->set_number('7808510')->is_valid_number, '高知パレスホテル');
ok($zip->set_number('7808512')->is_valid_number, 'NHK 高知放送局');
ok($zip->set_number('7808514')->is_valid_number, '社団法人 高知県医師会');
ok($zip->set_number('7808515')->is_valid_number, '高知県立大学 永国寺キャンパス');
ok($zip->set_number('7808516')->is_valid_number, '高知短期大学');
ok($zip->set_number('7808517')->is_valid_number, '株式会社 サニーマート');
ok($zip->set_number('7808520')->is_valid_number, '国立大学法人 高知大学');
ok($zip->set_number('7808522')->is_valid_number, '医療法人 近森会');
ok($zip->set_number('7808527')->is_valid_number, '株式会社 エヌ・シー・ビー');
ok($zip->set_number('7808528')->is_valid_number, '四国森林管理局');
ok($zip->set_number('7808530')->is_valid_number, '日本年金機構 高知西年金事務所');
ok($zip->set_number('7808532')->is_valid_number, '株式会社 エフエム高知');
ok($zip->set_number('7808534')->is_valid_number, '日本年金機構 高知事務センター');
ok($zip->set_number('7808535')->is_valid_number, '細木病院・細木ユニティ病院');
ok($zip->set_number('7808536')->is_valid_number, '高知県 国民健康保険団体連合会');
ok($zip->set_number('7808539')->is_valid_number, '損害保険ジャパン日本興亜 株式会社 高知支店');
ok($zip->set_number('7808540')->is_valid_number, '株式会社 キタムラ');
ok($zip->set_number('7808541')->is_valid_number, 'エヌ・ティ・ティ四国移動通信網 株式会社 高知支店');
ok($zip->set_number('7808544')->is_valid_number, '高知県警察本部');
ok($zip->set_number('7808545')->is_valid_number, '四国電力 (株) 高知支店');
ok($zip->set_number('7808550')->is_valid_number, '株式会社 高知放送');
ok($zip->set_number('7808553')->is_valid_number, '大旺建設 株式会社');
ok($zip->set_number('7808554')->is_valid_number, '高知地方検察庁・高知区検察庁');
ok($zip->set_number('7808555')->is_valid_number, 'UFJニコス 株式会社 高知支店');
ok($zip->set_number('7808558')->is_valid_number, '高知地方裁判所');
ok($zip->set_number('7808559')->is_valid_number, '住友生命保険 相互会社 高知支社');
ok($zip->set_number('7808561')->is_valid_number, '株式会社 高知新阪急ホテル');
ok($zip->set_number('7808562')->is_valid_number, '高知赤十字病院');
ok($zip->set_number('7808565')->is_valid_number, '財団法人高知県老人クラブ連合会');
ok($zip->set_number('7808566')->is_valid_number, '株式会社 高知大丸');
ok($zip->set_number('7808567')->is_valid_number, 'ふくし交流プラザ');
ok($zip->set_number('7808568')->is_valid_number, '宮地電気 (株) 本社総務部');
ok($zip->set_number('7808570')->is_valid_number, '高知県庁');
ok($zip->set_number('7808571')->is_valid_number, '高知市役所');
ok($zip->set_number('7808572')->is_valid_number, '株式会社 高知新聞社');
ok($zip->set_number('7808577')->is_valid_number, '株式会社 テレビ高知');
ok($zip->set_number('7808601')->is_valid_number, '日本生命保険 相互会社 高知支社');
ok($zip->set_number('7808602')->is_valid_number, '株式会社 高知銀行');
ok($zip->set_number('7808605')->is_valid_number, '株式会社 四国銀行');
ok($zip->set_number('7808660')->is_valid_number, '商工組合中央金庫 高知支店');
ok($zip->set_number('7808661')->is_valid_number, '国民生活金融公庫 高知支店');
ok($zip->set_number('7808663')->is_valid_number, '株式会社 三翠園');
ok($zip->set_number('7808665')->is_valid_number, 'SMBC日興証券 株式会社 高知支店');
ok($zip->set_number('7808666')->is_valid_number, '株式会社 高知新聞企業');
ok($zip->set_number('7808668')->is_valid_number, '高知税務署内 伊野税務署集中処理担当');
ok($zip->set_number('7808670')->is_valid_number, '幡多信用金庫 高知支店');
ok($zip->set_number('7808676')->is_valid_number, '株式会社 阿波銀行 高知支店');
ok($zip->set_number('7808677')->is_valid_number, '日本銀行 高知支店');
ok($zip->set_number('7808686')->is_valid_number, 'アクサ損害保険 株式会社');
ok($zip->set_number('7808787')->is_valid_number, '株式会社 ゆうちょ銀行 高知地域センター');
ok($zip->set_number('7810392')->is_valid_number, '高知市 春野庁舎');
ok($zip->set_number('7811192')->is_valid_number, '土佐市役所');
ok($zip->set_number('7811592')->is_valid_number, '仁淀川町役場');
ok($zip->set_number('7811892')->is_valid_number, '仁淀川町役場 仁淀総合支所');
ok($zip->set_number('7812192')->is_valid_number, 'いの町役場');
ok($zip->set_number('7812193')->is_valid_number, 'いの町立国民健康保険仁淀病院');
ok($zip->set_number('7812194')->is_valid_number, '日高村役場');
ok($zip->set_number('7812492')->is_valid_number, 'いの町役場 吾北総合支所');
ok($zip->set_number('7813492')->is_valid_number, '土佐町役場');
ok($zip->set_number('7813493')->is_valid_number, 'JA土佐れいほく');
ok($zip->set_number('7813692')->is_valid_number, '本山町役場');
ok($zip->set_number('7814292')->is_valid_number, '香美市役所 香北支所');
ok($zip->set_number('7815192')->is_valid_number, '旭食品株式会社 高知東支店');
ok($zip->set_number('7815195')->is_valid_number, '株式会社 技研製作所');
ok($zip->set_number('7815292')->is_valid_number, '香南市役所');
ok($zip->set_number('7815295')->is_valid_number, '土佐香美農業協同組合');
ok($zip->set_number('7815495')->is_valid_number, '陸上自衛隊 高知駐屯地');
ok($zip->set_number('7815792')->is_valid_number, '芸西村役場');
ok($zip->set_number('7815793')->is_valid_number, '土佐あき 農業協同組合 芸西支所');
ok($zip->set_number('7817185')->is_valid_number, '室戸市役所');
ok($zip->set_number('7818510')->is_valid_number, '高知県農業協同組合購買事業本部');
ok($zip->set_number('7818511')->is_valid_number, '宗教法人 霊波之光 高知支部');
ok($zip->set_number('7818515')->is_valid_number, '高知県立大学 池キャンパス');
ok($zip->set_number('7818521')->is_valid_number, '株式会社 エス・シー');
ok($zip->set_number('7818543')->is_valid_number, '土佐ガス 株式会社');
ok($zip->set_number('7818551')->is_valid_number, '高知市農業協同組合');
ok($zip->set_number('7818552')->is_valid_number, '高知県立 高知東高等学校');
ok($zip->set_number('7818555')->is_valid_number, '高知医療センター');
ok($zip->set_number('7818557')->is_valid_number, '東芝クレジット (株) 高知営業所');
ok($zip->set_number('7818560')->is_valid_number, '高知公共職業安定所');
ok($zip->set_number('7818588')->is_valid_number, '高知東警察署');
ok($zip->set_number('7819506')->is_valid_number, '篠原化学薬品 株式会社');
ok($zip->set_number('7819511')->is_valid_number, '高知県施設農業協同組合連合会');
ok($zip->set_number('7819513')->is_valid_number, '財団法人 高知県総合保健協会');
ok($zip->set_number('7819519')->is_valid_number, 'ブルーチップ 高知センター 商品交換受付係');
ok($zip->set_number('7819525')->is_valid_number, '東洋電化工業 株式会社');
ok($zip->set_number('7819526')->is_valid_number, '高知労働基準監督署');
ok($zip->set_number('7819529')->is_valid_number, '高知市文化プラザ(かるぽーと)');
ok($zip->set_number('7819533')->is_valid_number, '高知さんさんテレビ 株式会社');
ok($zip->set_number('7819537')->is_valid_number, '高知ケーブルテレビ 株式会社');
ok($zip->set_number('7819538')->is_valid_number, 'セルヴィ21〔知寄町〕管理組合');
ok($zip->set_number('7819548')->is_valid_number, '高知労働局');
ok($zip->set_number('7819556')->is_valid_number, '日本年金機構 高知東年金事務所');
ok($zip->set_number('7819683')->is_valid_number, '丸仁商事 株式会社');
ok($zip->set_number('7819684')->is_valid_number, '(株) シーメック');
ok($zip->set_number('7819685')->is_valid_number, '株式会社 スリーキューブ');
ok($zip->set_number('7819686')->is_valid_number, '高知県文具 (株)');
ok($zip->set_number('7819687')->is_valid_number, '関 株式会社');
ok($zip->set_number('7819688')->is_valid_number, '弘進商事 (株)');
ok($zip->set_number('7819689')->is_valid_number, '丸美商事 (株)');
ok($zip->set_number('7828502')->is_valid_number, '高知工科大学');
ok($zip->set_number('7838501')->is_valid_number, '南国市役所');
ok($zip->set_number('7838502')->is_valid_number, '高知大学 農学部');
ok($zip->set_number('7838505')->is_valid_number, '高知大学 医学部');
ok($zip->set_number('7838506')->is_valid_number, '高知大学 附属図書館 医学部分室');
ok($zip->set_number('7838507')->is_valid_number, '日本年金機構 南国年金事務所');
ok($zip->set_number('7838508')->is_valid_number, '高知工業高等専門学校');
ok($zip->set_number('7838509')->is_valid_number, 'JA高知病院');
ok($zip->set_number('7838510')->is_valid_number, '株式会社 サニーマート 生鮮・惣菜工場');
ok($zip->set_number('7838511')->is_valid_number, '株式会社 JAエナジーこうち');
ok($zip->set_number('7838555')->is_valid_number, '旭食品 株式会社 四国支社');
ok($zip->set_number('7838555')->is_valid_number, '旭食品 株式会社 本社');
ok($zip->set_number('7838585')->is_valid_number, '中澤氏家薬業 株式会社');
ok($zip->set_number('7848501')->is_valid_number, '安芸市役所');
ok($zip->set_number('7848503')->is_valid_number, '高知県農業協同組合 安芸地区本部');
ok($zip->set_number('7848505')->is_valid_number, '高知県立 安芸高等学校');
ok($zip->set_number('7850195')->is_valid_number, '学校法人 明徳義塾');
ok($zip->set_number('7850595')->is_valid_number, '津野町役場 西庁舎');
ok($zip->set_number('7850695')->is_valid_number, '梼原町役場');
ok($zip->set_number('7858501')->is_valid_number, '医療法人 五月会須崎くろしお病院');
ok($zip->set_number('7858511')->is_valid_number, '須崎労働基準監督署');
ok($zip->set_number('7858520')->is_valid_number, '土佐くろしお農業協同組合 (本所)');
ok($zip->set_number('7858533')->is_valid_number, '高知県立 須崎工業高等学校');
ok($zip->set_number('7858570')->is_valid_number, '高知県 須崎農業改良晋及センター');
ok($zip->set_number('7858574')->is_valid_number, '須崎県税事務所');
ok($zip->set_number('7858576')->is_valid_number, '須崎耕地事務所');
ok($zip->set_number('7858577')->is_valid_number, '高知県 須崎林業事務所');
ok($zip->set_number('7858578')->is_valid_number, '流域林業活性化センター四万十');
ok($zip->set_number('7858585')->is_valid_number, '高知県須崎福祉保健所');
ok($zip->set_number('7858601')->is_valid_number, '須崎市役所');
ok($zip->set_number('7860393')->is_valid_number, '四万十町役場 大正地域振興局');
ok($zip->set_number('7868501')->is_valid_number, '四万十町役場');
ok($zip->set_number('7870392')->is_valid_number, '土佐清水市役所');
ok($zip->set_number('7870892')->is_valid_number, '三原村役場');
ok($zip->set_number('7878501')->is_valid_number, '四万十市役所');
ok($zip->set_number('7888501')->is_valid_number, '旭食品 宿毛販売 株式会社');
ok($zip->set_number('7888686')->is_valid_number, '宿毛市役所');
ok($zip->set_number('7890392')->is_valid_number, '大豊町役場');
ok($zip->set_number('7891292')->is_valid_number, '佐川町役場');
ok($zip->set_number('7891795')->is_valid_number, '黒潮町役場 佐賀総合支所');
ok($zip->set_number('7891992')->is_valid_number, '黒潮町役場');
ok($zip->set_number('7908501')->is_valid_number, '日本放送協会 松山放送局');
ok($zip->set_number('7908502')->is_valid_number, '愛媛県中予地方局');
ok($zip->set_number('7908505')->is_valid_number, '松山地方法務局');
ok($zip->set_number('7908508')->is_valid_number, '株式会社 二神組');
ok($zip->set_number('7908509')->is_valid_number, '株式会社 愛媛CATV');
ok($zip->set_number('7908510')->is_valid_number, '南海放送 株式会社');
ok($zip->set_number('7908511')->is_valid_number, '株式会社 愛媛新聞社');
ok($zip->set_number('7908512')->is_valid_number, '松山西社会保険事務所');
ok($zip->set_number('7908513')->is_valid_number, 'こくみん共済coop愛媛推進本部');
ok($zip->set_number('7908514')->is_valid_number, '株式会社 伊予銀行');
ok($zip->set_number('7908516')->is_valid_number, '株式会社 一六');
ok($zip->set_number('7908519')->is_valid_number, '中四国農政局 愛媛農政事務所');
ok($zip->set_number('7908520')->is_valid_number, '松山総合開発 株式会社 松山全日空ホテル');
ok($zip->set_number('7908524')->is_valid_number, '総合病院 松山赤十字病院');
ok($zip->set_number('7908525')->is_valid_number, '株式会社 愛媛朝日テレビ');
ok($zip->set_number('7908528')->is_valid_number, '郵便局 株式会社 カタログ販売センター');
ok($zip->set_number('7908529')->is_valid_number, '株式会社 あいテレビ');
ok($zip->set_number('7908530')->is_valid_number, '愛媛県立 松山商業高等学校');
ok($zip->set_number('7908531')->is_valid_number, '学校法人 松山東雲学園 松山東雲女子大学 松山東雲短期大学');
ok($zip->set_number('7908532')->is_valid_number, '株式会社 三越松山店');
ok($zip->set_number('7908533')->is_valid_number, 'アカマツ 株式会社');
ok($zip->set_number('7908534')->is_valid_number, '医療法人仁友会 南松山病院');
ok($zip->set_number('7908535')->is_valid_number, '(株)エイ・ビー・エム');
ok($zip->set_number('7908537')->is_valid_number, '株式会社 テレビ愛媛');
ok($zip->set_number('7908539')->is_valid_number, '松山地方裁判所');
ok($zip->set_number('7908540')->is_valid_number, '四国電力 株式会社 松山支店');
ok($zip->set_number('7908541')->is_valid_number, '松山東雲中学校 松山東雲高等学校');
ok($zip->set_number('7908542')->is_valid_number, '西日本電信電話 株式会社 愛媛支店');
ok($zip->set_number('7908543')->is_valid_number, '生活協同組合 コープえひめ');
ok($zip->set_number('7908545')->is_valid_number, '財団法人 愛媛県教育会');
ok($zip->set_number('7908546')->is_valid_number, '全国健康保険協会 愛媛支部');
ok($zip->set_number('7908551')->is_valid_number, '松山東警察署');
ok($zip->set_number('7908553')->is_valid_number, '社会福祉法人 愛媛県社会福祉協議会');
ok($zip->set_number('7908554')->is_valid_number, '県農えひめ 果実販売課');
ok($zip->set_number('7908555')->is_valid_number, 'JA愛媛');
ok($zip->set_number('7908556')->is_valid_number, '株式会社 レディ薬局');
ok($zip->set_number('7908557')->is_valid_number, '聖カタリナ女子高等学校');
ok($zip->set_number('7908560')->is_valid_number, '学校法人 済美学園');
ok($zip->set_number('7908561')->is_valid_number, '東京海上日動火災保険 株式会社 愛媛支店');
ok($zip->set_number('7908565')->is_valid_number, '株式会社 エフエム愛媛');
ok($zip->set_number('7908566')->is_valid_number, '愛媛大学 農学部');
ok($zip->set_number('7908567')->is_valid_number, '株式会社 フジ');
ok($zip->set_number('7908570')->is_valid_number, '愛媛県庁');
ok($zip->set_number('7908571')->is_valid_number, '松山市役所');
ok($zip->set_number('7908573')->is_valid_number, '愛媛県 警察本部');
ok($zip->set_number('7908574')->is_valid_number, '国土交通省 四国地方整備局 松山河川国道事務所');
ok($zip->set_number('7908575')->is_valid_number, '松山地方検察庁');
ok($zip->set_number('7908577')->is_valid_number, '愛媛大学');
ok($zip->set_number('7908578')->is_valid_number, '学校法人 松山大学');
ok($zip->set_number('7908580')->is_valid_number, '株式会社 愛媛銀行');
ok($zip->set_number('7908581')->is_valid_number, '愛媛建材 株式會社');
ok($zip->set_number('7908583')->is_valid_number, '株式会社 えひめリビング新聞社');
ok($zip->set_number('7908584')->is_valid_number, '株式会社 ニッシン');
ok($zip->set_number('7908585')->is_valid_number, '愛媛県 医師会');
ok($zip->set_number('7908586')->is_valid_number, '株式会社 エス・ピー・シー');
ok($zip->set_number('7908587')->is_valid_number, '株式会社 伊予鉄 高島屋');
ok($zip->set_number('7908588')->is_valid_number, '株式会社 えるく');
ok($zip->set_number('7908589')->is_valid_number, '積水ハウス 株式会社 松山支店');
ok($zip->set_number('7908590')->is_valid_number, '松山市公営企業局');
ok($zip->set_number('7908595')->is_valid_number, 'NEC松山テクノセンター');
ok($zip->set_number('7908601')->is_valid_number, '一般社団法人 松山市医師会');
ok($zip->set_number('7908632')->is_valid_number, '株式会社 日産サティオ愛媛');
ok($zip->set_number('7908650')->is_valid_number, '大和證券 株式会社 松山支店');
ok($zip->set_number('7908651')->is_valid_number, '愛媛県 信用保証協会');
ok($zip->set_number('7908652')->is_valid_number, '愛媛信用金庫');
ok($zip->set_number('7908653')->is_valid_number, 'メルファム 四国');
ok($zip->set_number('7908655')->is_valid_number, '株式会社 ぎょうせい四国支社');
ok($zip->set_number('7908656')->is_valid_number, '株式会社 明屋書店');
ok($zip->set_number('7908658')->is_valid_number, '株式会社 阿波銀行 松山支店');
ok($zip->set_number('7908659')->is_valid_number, '株式会社 帝国データバンク 松山支店');
ok($zip->set_number('7908660')->is_valid_number, 'みずほ銀行 松山支店');
ok($zip->set_number('7908661')->is_valid_number, '損害保険ジャパン 株式会社 松山支店');
ok($zip->set_number('7908665')->is_valid_number, '商工組合中央金庫 松山支店');
ok($zip->set_number('7908666')->is_valid_number, 'SMBC日興証券 株式会社 松山支店');
ok($zip->set_number('7908667')->is_valid_number, '株式会社 百十四銀行 松山支店');
ok($zip->set_number('7908677')->is_valid_number, '二浪証券 株式会社');
ok($zip->set_number('7908678')->is_valid_number, '愛媛県市町村職員共済組合');
ok($zip->set_number('7908686')->is_valid_number, 'セキ 株式会社');
ok($zip->set_number('7908688')->is_valid_number, '株式会社 香川銀行 松山支店');
ok($zip->set_number('7908787')->is_valid_number, '愛媛地域センター');
ok($zip->set_number('7908791')->is_valid_number, '共通事務センター');
ok($zip->set_number('7908793')->is_valid_number, '日本郵便 株式会社 四国支社 郵便事業本部 (三種)');
ok($zip->set_number('7908795')->is_valid_number, '四国総合通信局');
ok($zip->set_number('7908796')->is_valid_number, '愛媛監査室');
ok($zip->set_number('7908797')->is_valid_number, '株式会社 かんぽ生命 松山支店');
ok($zip->set_number('7908797')->is_valid_number, '株式会社 ゆうちょ銀行 四国エリア本部');
ok($zip->set_number('7908797')->is_valid_number, '日本郵便 株式会社 四国支社');
ok($zip->set_number('7910280')->is_valid_number, '四国がんセンター');
ok($zip->set_number('7910281')->is_valid_number, '独立行政法人 国立病院機構 愛媛病院');
ok($zip->set_number('7910288')->is_valid_number, '四国西濃運輸 株式会社');
ok($zip->set_number('7910292')->is_valid_number, '東温市役所');
ok($zip->set_number('7910295')->is_valid_number, '愛媛大学 医学部');
ok($zip->set_number('7910297')->is_valid_number, '株式会社 ヒカリ');
ok($zip->set_number('7910385')->is_valid_number, '財団法人 積善会 愛媛十全医療学院');
ok($zip->set_number('7910392')->is_valid_number, '(株) レジャーライフ');
ok($zip->set_number('7910393')->is_valid_number, '東温市 川内支所');
ok($zip->set_number('7910394')->is_valid_number, 'フジ四国物流センター');
ok($zip->set_number('7910395')->is_valid_number, 'PHC 株式会社');
ok($zip->set_number('7910397')->is_valid_number, '四国乳業 (株)');
ok($zip->set_number('7910398')->is_valid_number, '遠赤青汁 (株)');
ok($zip->set_number('7910593')->is_valid_number, '周桑農協');
ok($zip->set_number('7910594')->is_valid_number, '東予園芸');
ok($zip->set_number('7911192')->is_valid_number, '加藤産業 (株) 松山支店');
ok($zip->set_number('7911792')->is_valid_number, '久万高原町役場 面河支所');
ok($zip->set_number('7912191')->is_valid_number, '愛媛県立 とべ動物園');
ok($zip->set_number('7912193')->is_valid_number, '井関農機');
ok($zip->set_number('7912195')->is_valid_number, '砥部町役場');
ok($zip->set_number('7913192')->is_valid_number, '松前町役場');
ok($zip->set_number('7913193')->is_valid_number, '東レ 株式会社 愛媛工場');
ok($zip->set_number('7913194')->is_valid_number, 'サンタ 株式会社');
ok($zip->set_number('7913195')->is_valid_number, '義農味噌 (株)');
ok($zip->set_number('7913196')->is_valid_number, '扇屋食品 株式会社');
ok($zip->set_number('7913197')->is_valid_number, '愛媛日商プロパン 株式会社');
ok($zip->set_number('7913198')->is_valid_number, '増永食品 株式会社');
ok($zip->set_number('7913292')->is_valid_number, '伊予市役所 中山地域事務所');
ok($zip->set_number('7913293')->is_valid_number, '伊予中山農業協同組合');
ok($zip->set_number('7913295')->is_valid_number, '中山高等学校');
ok($zip->set_number('7913392')->is_valid_number, '内子町役場 内子分庁舎');
ok($zip->set_number('7913592')->is_valid_number, '内子町役場 小田支所');
ok($zip->set_number('7914592')->is_valid_number, '松山市 中島支所');
ok($zip->set_number('7918501')->is_valid_number, '学校法人 愛光学園');
ok($zip->set_number('7918502')->is_valid_number, 'トラスコ中山 株式会社 松山営業所');
ok($zip->set_number('7918505')->is_valid_number, '株式会社 ハート');
ok($zip->set_number('7918506')->is_valid_number, '東芝ファイナンス (株) 愛媛営業所');
ok($zip->set_number('7918507')->is_valid_number, '(株) パステムマツザワ');
ok($zip->set_number('7918508')->is_valid_number, '北四国商事 (株)');
ok($zip->set_number('7918510')->is_valid_number, '四国名鉄運輸 株式会社');
ok($zip->set_number('7918511')->is_valid_number, 'トヨタカローラ愛媛 (株)');
ok($zip->set_number('7918512')->is_valid_number, '愛媛トヨペット 株式会社');
ok($zip->set_number('7918513')->is_valid_number, 'TMTマシナリー 株式会社 松山工場');
ok($zip->set_number('7918516')->is_valid_number, 'コスモ松山石油 (株)');
ok($zip->set_number('7918517')->is_valid_number, 'ダイキ 株式会社');
ok($zip->set_number('7918518')->is_valid_number, 'フジケンエンジニアリング (株)');
ok($zip->set_number('7918523')->is_valid_number, '松山労働基準監督署');
ok($zip->set_number('7918524')->is_valid_number, '(株) アテックス');
ok($zip->set_number('7918525')->is_valid_number, '株式会社 大阪ソーダ 松山工場');
ok($zip->set_number('7918527')->is_valid_number, '尾家産業 (株) 松山営業所');
ok($zip->set_number('7918528')->is_valid_number, '(株)日本文具');
ok($zip->set_number('7918530')->is_valid_number, '帝人 (株) 松山事業所');
ok($zip->set_number('7918531')->is_valid_number, 'ダイヤアルミ (株)');
ok($zip->set_number('7918535')->is_valid_number, 'コマツカスタマーサポート 株式会社');
ok($zip->set_number('7918536')->is_valid_number, '帝人株式会社 松山事業所');
ok($zip->set_number('7918538')->is_valid_number, '(株) 城西');
ok($zip->set_number('7918550')->is_valid_number, '愛媛県国民健康保険団体連合会');
ok($zip->set_number('7918551')->is_valid_number, '新田青雲中等教育学校');
ok($zip->set_number('7918555')->is_valid_number, 'おおぞら病院');
ok($zip->set_number('7918603')->is_valid_number, '株式会社 えひめ飲料');
ok($zip->set_number('7918604')->is_valid_number, '新田高等学校');
ok($zip->set_number('7918671')->is_valid_number, '(株) 一色本店');
ok($zip->set_number('7918672')->is_valid_number, '株式会社 カナックス');
ok($zip->set_number('7918675')->is_valid_number, '株式会社 松宮');
ok($zip->set_number('7918677')->is_valid_number, '丸温松山中央青果 株式会社');
ok($zip->set_number('7928501')->is_valid_number, '大和証券 株式会社 新居浜支店');
ok($zip->set_number('7928505')->is_valid_number, '森実運輸 株式会社');
ok($zip->set_number('7928510')->is_valid_number, '旭食品 株式会社 新居浜支店');
ok($zip->set_number('7928511')->is_valid_number, 'NTT 新居浜支店');
ok($zip->set_number('7928518')->is_valid_number, '株式会社 エイワ');
ok($zip->set_number('7928520')->is_valid_number, '住友共同電力株式会社');
ok($zip->set_number('7928521')->is_valid_number, '住友化学工業 株式会社 愛媛工場');
ok($zip->set_number('7928543')->is_valid_number, '住友別子病院');
ok($zip->set_number('7928550')->is_valid_number, '愛媛労災病院');
ok($zip->set_number('7928555')->is_valid_number, '住友金属鉱山 株式会社 別子事業所');
ok($zip->set_number('7928567')->is_valid_number, '住友建設 株式会社 四国支店');
ok($zip->set_number('7928580')->is_valid_number, '新居浜工業高等専門学校');
ok($zip->set_number('7928585')->is_valid_number, '新居浜市役所');
ok($zip->set_number('7928586')->is_valid_number, '財団法人 積善会附属十全総合病院');
ok($zip->set_number('7928588')->is_valid_number, '住友重機械工業 株式会社');
ok($zip->set_number('7928614')->is_valid_number, '株式会社 伊予銀行 新居浜支店');
ok($zip->set_number('7928670')->is_valid_number, '東予信用金庫');
ok($zip->set_number('7928686')->is_valid_number, '新居浜社会保険事務所');
ok($zip->set_number('7938501')->is_valid_number, '株式会社 ルネサステクノロジ 西条事業所');
ok($zip->set_number('7938509')->is_valid_number, '愛媛県立 西条高等学校');
ok($zip->set_number('7938510')->is_valid_number, 'パナソニック四国エレクトロニクス (株) 西条地区');
ok($zip->set_number('7938515')->is_valid_number, '今治造船 (株) 西条工場');
ok($zip->set_number('7938516')->is_valid_number, '愛媛県東予地方局');
ok($zip->set_number('7938555')->is_valid_number, '宗教法人 石鎚神社');
ok($zip->set_number('7938585')->is_valid_number, '株式会社 クラレ 西条工場');
ok($zip->set_number('7938601')->is_valid_number, '西条市役所');
ok($zip->set_number('7940192')->is_valid_number, '今治市役所 玉川支所');
ok($zip->set_number('7940193')->is_valid_number, '越智今治農業協同組合 玉川支所');
ok($zip->set_number('7941192')->is_valid_number, '今治市役所 関前支所');
ok($zip->set_number('7941392')->is_valid_number, '今治市役所 大三島支所');
ok($zip->set_number('7941393')->is_valid_number, '大山祇神社社務所');
ok($zip->set_number('7941492')->is_valid_number, '今治市役所 上浦支所');
ok($zip->set_number('7942192')->is_valid_number, '今治市役所 吉海支所');
ok($zip->set_number('7942292')->is_valid_number, '今治市役所 宮窪支所');
ok($zip->set_number('7942392')->is_valid_number, '今治市役所 伯方支所');
ok($zip->set_number('7942395')->is_valid_number, '伯方造船 株式会社');
ok($zip->set_number('7942492')->is_valid_number, '上島町役場 岩城総合支所');
ok($zip->set_number('7942592')->is_valid_number, '上島町役場');
ok($zip->set_number('7942593')->is_valid_number, '弓削商船高等専門学校');
ok($zip->set_number('7948502')->is_valid_number, '今治地方局');
ok($zip->set_number('7948508')->is_valid_number, '今治(地方・簡易・家庭)裁判所');
ok($zip->set_number('7948510')->is_valid_number, '東芝ライテック 株式会社 今治事業所');
ok($zip->set_number('7948511')->is_valid_number, '今治市役所');
ok($zip->set_number('7948518')->is_valid_number, '日本食研 (株)');
ok($zip->set_number('7948555')->is_valid_number, '岡山理科大学 今治キャンパス');
ok($zip->set_number('7948565')->is_valid_number, '日本食研製造 株式会社 シェーンブルン宮殿工場/日本食研スマイルパートナーズ 株式会社 愛媛事業所');
ok($zip->set_number('7948582')->is_valid_number, '渦潮電機 株式会社 みらい工場');
ok($zip->set_number('7948601')->is_valid_number, '四国通建 (株) 本社');
ok($zip->set_number('7948602')->is_valid_number, '今治税務署');
ok($zip->set_number('7948611')->is_valid_number, '四国ガス (株) 本店');
ok($zip->set_number('7948614')->is_valid_number, '株式会社 伊予銀行 今治支店');
ok($zip->set_number('7950392')->is_valid_number, '内子町役場 本庁');
ok($zip->set_number('7958501')->is_valid_number, '市立大洲病院');
ok($zip->set_number('7958502')->is_valid_number, '愛媛県立 大洲高等学校');
ok($zip->set_number('7958504')->is_valid_number, '愛媛県南予地方局大洲庁舎');
ok($zip->set_number('7958505')->is_valid_number, '喜多医師会病院');
ok($zip->set_number('7958506')->is_valid_number, '愛媛たいき農業協同組合 本所');
ok($zip->set_number('7958507')->is_valid_number, '大洲中央病院');
ok($zip->set_number('7958508')->is_valid_number, '丸三産業 株式会社');
ok($zip->set_number('7958510')->is_valid_number, '大洲記念病院');
ok($zip->set_number('7958601')->is_valid_number, '大洲市役所');
ok($zip->set_number('7958603')->is_valid_number, '西田興産');
ok($zip->set_number('7960292')->is_valid_number, '八幡浜市役所 保内庁舎');
ok($zip->set_number('7960293')->is_valid_number, '西南開発 株式会社');
ok($zip->set_number('7960295')->is_valid_number, '株式会社 あわしま堂');
ok($zip->set_number('7960495')->is_valid_number, '四国電力 (株) 伊方発電所');
ok($zip->set_number('7968501')->is_valid_number, '八幡浜市役所');
ok($zip->set_number('7968502')->is_valid_number, '市立 八幡浜総合病院');
ok($zip->set_number('7970292')->is_valid_number, '西予市 明浜総合支所');
ok($zip->set_number('7971292')->is_valid_number, '西予市 野村総合支所');
ok($zip->set_number('7971592')->is_valid_number, '大洲市役所 肱川支所');
ok($zip->set_number('7971792')->is_valid_number, '西予市 城川総合支所');
ok($zip->set_number('7978501')->is_valid_number, '西予市役所');
ok($zip->set_number('7978511')->is_valid_number, '愛媛県歴史文化博物館');
ok($zip->set_number('7981192')->is_valid_number, '宇和島市役所 三間支所');
ok($zip->set_number('7981392')->is_valid_number, '鬼北町立 北宇和病院');
ok($zip->set_number('7981393')->is_valid_number, '旭川荘南愛媛病院・南愛媛養育センター');
ok($zip->set_number('7981395')->is_valid_number, '鬼北町役場');
ok($zip->set_number('7981397')->is_valid_number, '愛媛県立 北宇和高等学校');
ok($zip->set_number('7982192')->is_valid_number, '松野町役場');
ok($zip->set_number('7983392')->is_valid_number, '宇和島市役所 津島支所');
ok($zip->set_number('7983393')->is_valid_number, '宇和島市立 津島病院');
ok($zip->set_number('7983792')->is_valid_number, '愛南町役場 内海支所');
ok($zip->set_number('7984192')->is_valid_number, '南宇和高校');
ok($zip->set_number('7984193')->is_valid_number, 'えひめ南農業協同組合 南宇和支所');
ok($zip->set_number('7984194')->is_valid_number, '愛媛県南予地方局 愛南庁舎');
ok($zip->set_number('7984195')->is_valid_number, '愛南町役場 御荘支所');
ok($zip->set_number('7984196')->is_valid_number, '愛南町役場');
ok($zip->set_number('7984197')->is_valid_number, '伊予銀行 城辺支店');
ok($zip->set_number('7984292')->is_valid_number, '愛南町役場 西海支所');
ok($zip->set_number('7984495')->is_valid_number, '松下寿電子工業 株式会社 HDDビジネスユニット');
ok($zip->set_number('7988510')->is_valid_number, '市立 宇和島病院');
ok($zip->set_number('7988511')->is_valid_number, '宇和島地方局');
ok($zip->set_number('7988601')->is_valid_number, '宇和島市役所');
ok($zip->set_number('7988611')->is_valid_number, '宇和島信用金庫');
ok($zip->set_number('7988614')->is_valid_number, '伊予銀行 宇和島支店');
ok($zip->set_number('7990192')->is_valid_number, '四国中央市 川之江総合支所');
ok($zip->set_number('7990193')->is_valid_number, '公立学校共済組合 四国中央病院');
ok($zip->set_number('7990194')->is_valid_number, '梅錦山川 株式会社');
ok($zip->set_number('7990195')->is_valid_number, '川之江造機 株式会社');
ok($zip->set_number('7990196')->is_valid_number, '丸住製紙 株式会社');
ok($zip->set_number('7990197')->is_valid_number, '新タック化成 株式会社');
ok($zip->set_number('7990492')->is_valid_number, '大王製紙 株式会社');
ok($zip->set_number('7990493')->is_valid_number, '大黒工業 株式会社');
ok($zip->set_number('7990495')->is_valid_number, '福助工業 株式会社');
ok($zip->set_number('7990496')->is_valid_number, 'リュウグウ 株式会社');
ok($zip->set_number('7990497')->is_valid_number, '四国中央市役所');
ok($zip->set_number('7990498')->is_valid_number, '伊予三島商工会議所');
ok($zip->set_number('7991198')->is_valid_number, '西条市役所 小松総合支所');
ok($zip->set_number('7991392')->is_valid_number, '株式会社 田窪工業所');
ok($zip->set_number('7991393')->is_valid_number, '住友重機械工業 株式会社');
ok($zip->set_number('7991394')->is_valid_number, '西条市役所 東予総合支所');
ok($zip->set_number('7991395')->is_valid_number, '四国開発フェリー 株式会社');
ok($zip->set_number('7991581')->is_valid_number, '第一印刷 株式会社');
ok($zip->set_number('7991582')->is_valid_number, '日本食研 株式会社');
ok($zip->set_number('7991588')->is_valid_number, 'ワールドプラザ');
ok($zip->set_number('7991592')->is_valid_number, '社会福祉法人 恩賜財団 済生会今治病院');
ok($zip->set_number('7991593')->is_valid_number, '株式会社原商会');
ok($zip->set_number('7991594')->is_valid_number, '株式会社 ハラプレックス');
ok($zip->set_number('7991595')->is_valid_number, '(株) 橘屋');
ok($zip->set_number('7991596')->is_valid_number, '愛媛県立 今治東高等学校');
ok($zip->set_number('7991598')->is_valid_number, '財団法人 正光会 今治病院');
ok($zip->set_number('7991692')->is_valid_number, '今治市役所 朝倉支所');
ok($zip->set_number('7992192')->is_valid_number, '今治市役所 波方支所');
ok($zip->set_number('7992195')->is_valid_number, '今治造船 株式会社');
ok($zip->set_number('7992292')->is_valid_number, '今治市役所 大西支所');
ok($zip->set_number('7992293')->is_valid_number, '株式会社 新来島どっく');
ok($zip->set_number('7992294')->is_valid_number, '渦潮電機 株式会社');
ok($zip->set_number('7992392')->is_valid_number, '今治市役所 菊間支所');
ok($zip->set_number('7992393')->is_valid_number, '太陽石油 株式会社 四国事業所');
ok($zip->set_number('7992492')->is_valid_number, '松山市役所 北条支所');
ok($zip->set_number('7992493')->is_valid_number, '愛媛県立 北条高等学校');
ok($zip->set_number('7992496')->is_valid_number, '聖カタリナ大学・聖カタリナ短期大学');
ok($zip->set_number('7992692')->is_valid_number, '井関農機 株式会社');
ok($zip->set_number('7992696')->is_valid_number, '三浦工業 株式会社');
ok($zip->set_number('7993192')->is_valid_number, 'マルトモ 株式会社');
ok($zip->set_number('7993193')->is_valid_number, '伊予市役所');
ok($zip->set_number('7993194')->is_valid_number, 'ヤマキ 株式会社');
ok($zip->set_number('7993195')->is_valid_number, '株式会社 オカベ');
ok($zip->set_number('7993196')->is_valid_number, '四国アルフレッサ 株式会社');
ok($zip->set_number('7993198')->is_valid_number, '株式会社 植西運送 松山物流センター');
ok($zip->set_number('7993292')->is_valid_number, '伊予市役所 双海地域事務所');
ok($zip->set_number('7993792')->is_valid_number, '宇和島市役所 吉田支所');
ok($zip->set_number('7993793')->is_valid_number, '宇和青果農業協同組合');
ok($zip->set_number('8000281')->is_valid_number, 'クラレイ 株式会社');
ok($zip->set_number('8000282')->is_valid_number, '明治屋商事 株式会社 北九州店');
ok($zip->set_number('8000285')->is_valid_number, 'サニーサイドモール 小倉');
ok($zip->set_number('8000286')->is_valid_number, 'サンデー北九州');
ok($zip->set_number('8000288')->is_valid_number, '株式会社 サンリブサンリブシティ 小倉');
ok($zip->set_number('8000293')->is_valid_number, 'TOTO 株式会社 小倉第二工場');
ok($zip->set_number('8000294')->is_valid_number, '小倉南社会保険事務所');
ok($zip->set_number('8000296')->is_valid_number, '九州労災病院');
ok($zip->set_number('8000297')->is_valid_number, '株式会社 七尾製菓');
ok($zip->set_number('8000298')->is_valid_number, '九州栄養福祉大学 小倉南区キャンパス');
ok($zip->set_number('8000392')->is_valid_number, '苅田町役場');
ok($zip->set_number('8000393')->is_valid_number, '日立金属 株式会社 九州工場');
ok($zip->set_number('8000394')->is_valid_number, '西日本工業大学');
ok($zip->set_number('8000395')->is_valid_number, '日産自動車 株式会社 九州工場');
ok($zip->set_number('8000396')->is_valid_number, '三菱マテリアル 株式会社 九州工場');
ok($zip->set_number('8008510')->is_valid_number, '池田興業 株式会社');
ok($zip->set_number('8008550')->is_valid_number, '高藤建設 株式会社');
ok($zip->set_number('8008555')->is_valid_number, '株式会社 マツモト');
ok($zip->set_number('8008585')->is_valid_number, 'ニッカウヰスキー 株式会社 門司工場');
ok($zip->set_number('8008601')->is_valid_number, '岡野バルブ製造 株式会社');
ok($zip->set_number('8008603')->is_valid_number, '株式会社 福岡銀行 門司駅前支店');
ok($zip->set_number('8008611')->is_valid_number, '株式会社 西日本シティ銀行 門司駅前支店');
ok($zip->set_number('8008686')->is_valid_number, '大分銀行 門司駅前支店');
ok($zip->set_number('8018502')->is_valid_number, '九州労災病院門司メディカルセンター');
ok($zip->set_number('8018503')->is_valid_number, '株式会社 門司港ホテル');
ok($zip->set_number('8018507')->is_valid_number, '第7管区海上保安本部');
ok($zip->set_number('8018510')->is_valid_number, '北九州市 門司区役所');
ok($zip->set_number('8018511')->is_valid_number, '門司税関');
ok($zip->set_number('8018550')->is_valid_number, '社団法人 日本海員掖済会門司病院');
ok($zip->set_number('8018555')->is_valid_number, '北九州市港湾局');
ok($zip->set_number('8018585')->is_valid_number, '九州運輸局 福岡運輸支局(門司港庁舎)');
ok($zip->set_number('8018601')->is_valid_number, '門司税務署');
ok($zip->set_number('8028501')->is_valid_number, '福岡ひびき信用金庫 事務センター');
ok($zip->set_number('8028502')->is_valid_number, '小倉ターミナルビル 株式会社');
ok($zip->set_number('8028507')->is_valid_number, '小倉公共職業安定所');
ok($zip->set_number('8028508')->is_valid_number, '株式会社 コレット井筒屋');
ok($zip->set_number('8028510')->is_valid_number, '北九州市 小倉南区役所');
ok($zip->set_number('8028511')->is_valid_number, '株式会社 井筒屋');
ok($zip->set_number('8028512')->is_valid_number, '石川金属工業 株式会社');
ok($zip->set_number('8028515')->is_valid_number, '第一交通産業 株式会社 本社');
ok($zip->set_number('8028517')->is_valid_number, '北九州総合病院');
ok($zip->set_number('8028521')->is_valid_number, '九州電力 株式会社 北九州支店');
ok($zip->set_number('8028522')->is_valid_number, '北九州商工会議所');
ok($zip->set_number('8028524')->is_valid_number, '九州電力 株式会社 小倉営業所');
ok($zip->set_number('8028533')->is_valid_number, '独立行政法人 国立病院機構 小倉医療センター');
ok($zip->set_number('8028540')->is_valid_number, '株式会社 タカギ');
ok($zip->set_number('8028543')->is_valid_number, '小倉興産 株式会社');
ok($zip->set_number('8028545')->is_valid_number, '東京海上日動火災保険 株式会社 北九州支店');
ok($zip->set_number('8028550')->is_valid_number, '住友生命保険 相互会社 北九州支社');
ok($zip->set_number('8028555')->is_valid_number, '小倉記念病院');
ok($zip->set_number('8028558')->is_valid_number, '西日本新聞 北九州本社');
ok($zip->set_number('8028560')->is_valid_number, '北九州市総合保健福祉センター');
ok($zip->set_number('8028561')->is_valid_number, '北九州市立医療センター');
ok($zip->set_number('8028566')->is_valid_number, 'リビング北九州');
ok($zip->set_number('8028567')->is_valid_number, '陸上自衛隊 小倉駐屯地');
ok($zip->set_number('8028570')->is_valid_number, '株式会社 CROSS FM');
ok($zip->set_number('8028571')->is_valid_number, '読売新聞 北九州総本部');
ok($zip->set_number('8028577')->is_valid_number, '北九州市立大学');
ok($zip->set_number('8028580')->is_valid_number, '西日本電信電話 株式会社 北九州支店');
ok($zip->set_number('8028581')->is_valid_number, '日本エイ・デイ・アール 株式会社');
ok($zip->set_number('8028585')->is_valid_number, '株式会社 サンレー');
ok($zip->set_number('8028601')->is_valid_number, 'TOTO 株式会社');
ok($zip->set_number('8028604')->is_valid_number, '野村證券株式会社北九州支店');
ok($zip->set_number('8028642')->is_valid_number, '株式会社 ナカノテツ');
ok($zip->set_number('8028651')->is_valid_number, '毎日新聞 西部本社');
ok($zip->set_number('8028677')->is_valid_number, '日本生命保険 相互会社 北九州支社');
ok($zip->set_number('8028686')->is_valid_number, '株式会社 住友金属 小倉');
ok($zip->set_number('8028701')->is_valid_number, '株式会社 山口銀行 北九州本部');
ok($zip->set_number('8038501')->is_valid_number, '北九州市役所');
ok($zip->set_number('8038504')->is_valid_number, '株式会社 パルテック');
ok($zip->set_number('8038505')->is_valid_number, '国家公務員共済組合連合会 新小倉病院');
ok($zip->set_number('8038508')->is_valid_number, '株式会社 丸和');
ok($zip->set_number('8038510')->is_valid_number, '北九州市 小倉北区役所');
ok($zip->set_number('8038511')->is_valid_number, '東筑紫短期大学・九州栄養福祉大学');
ok($zip->set_number('8038512')->is_valid_number, '福岡県 小倉県税事務所');
ok($zip->set_number('8038513')->is_valid_number, '福岡法務局 北九州支局');
ok($zip->set_number('8038517')->is_valid_number, '新日本非破壊検査 株式会社');
ok($zip->set_number('8038520')->is_valid_number, '大平紙業 株式会社');
ok($zip->set_number('8038530')->is_valid_number, '株式会社安川電機 技術開発センタ');
ok($zip->set_number('8038531')->is_valid_number, '福岡地方裁判所 小倉支部');
ok($zip->set_number('8038532')->is_valid_number, '福岡家庭裁判所 小倉支部');
ok($zip->set_number('8038533')->is_valid_number, '山田港運倉庫 株式会社');
ok($zip->set_number('8038535')->is_valid_number, '北九州市役所 区政事務センター');
ok($zip->set_number('8038543')->is_valid_number, '健和会 大手町病院');
ok($zip->set_number('8038550')->is_valid_number, '株式会社 CGC 九州本部');
ok($zip->set_number('8038555')->is_valid_number, 'NHK 北九州放送局');
ok($zip->set_number('8038558')->is_valid_number, '小野建 株式会社 小倉支店');
ok($zip->set_number('8038561')->is_valid_number, '株式会社 セントラルユニ');
ok($zip->set_number('8038567')->is_valid_number, '小倉北警察署');
ok($zip->set_number('8038580')->is_valid_number, '九州歯科大学');
ok($zip->set_number('8038586')->is_valid_number, '朝日新聞 西部本社');
ok($zip->set_number('8038588')->is_valid_number, '小倉北社会保険事務所');
ok($zip->set_number('8038602')->is_valid_number, '小倉税務署');
ok($zip->set_number('8038630')->is_valid_number, '株式会社 ゼンリン');
ok($zip->set_number('8038660')->is_valid_number, '株式会社 サンリブ');
ok($zip->set_number('8038666')->is_valid_number, '西部ガス 株式会社 北九州事業本部');
ok($zip->set_number('8038686')->is_valid_number, '株式会社 東芝 北九州工場');
ok($zip->set_number('8038787')->is_valid_number, '西日本工業大学');
ok($zip->set_number('8048501')->is_valid_number, '日本製鉄 株式会社 九州製鉄所 八幡地区');
ok($zip->set_number('8048503')->is_valid_number, '日鉄ケミカル&マテリアル 株式会社 九州製造所');
ok($zip->set_number('8048505')->is_valid_number, '日鉄エンジニアリング 株式会社 北九州技術センター 北九州総務室');
ok($zip->set_number('8048510')->is_valid_number, '北九州市 戸畑区役所');
ok($zip->set_number('8048520')->is_valid_number, '旭硝子 株式会社 北九州工場');
ok($zip->set_number('8048538')->is_valid_number, '山九 株式会社 八幡支店');
ok($zip->set_number('8048539')->is_valid_number, '山九 株式会社 北九州支店');
ok($zip->set_number('8048550')->is_valid_number, '九州工業大学');
ok($zip->set_number('8048558')->is_valid_number, '学校法人 明治学園');
ok($zip->set_number('8048560')->is_valid_number, '日鉄テックスエンジ 株式会社 八幡支店');
ok($zip->set_number('8048577')->is_valid_number, '日本水産 株式会社 戸畑工場');
ok($zip->set_number('8048588')->is_valid_number, '日鉄テックスエンジ 株式会社 八幡電計事業センター');
ok($zip->set_number('8048601')->is_valid_number, '東洋製罐 株式会社 戸畑工場');
ok($zip->set_number('8058501')->is_valid_number, '吉川工業 株式会社');
ok($zip->set_number('8058503')->is_valid_number, '三島光産 株式会社');
ok($zip->set_number('8058505')->is_valid_number, '独立行政法人 国際協力機構 九州国際センター');
ok($zip->set_number('8058507')->is_valid_number, '株式会社 アステック入江');
ok($zip->set_number('8058508')->is_valid_number, '医療法人社団 新日鐵八幡記念病院');
ok($zip->set_number('8058509')->is_valid_number, 'ムロオカ商事 株式会社');
ok($zip->set_number('8058510')->is_valid_number, '北九州市 八幡東区役所');
ok($zip->set_number('8058512')->is_valid_number, '九州国際大学');
ok($zip->set_number('8058513')->is_valid_number, '学校法人 九州国際大学');
ok($zip->set_number('8058514')->is_valid_number, '株式会社 山本工作所');
ok($zip->set_number('8058516')->is_valid_number, '日鉄住金物流八幡 株式会社');
ok($zip->set_number('8058518')->is_valid_number, '東亜非破壊検査 株式会社');
ok($zip->set_number('8058520')->is_valid_number, '福岡ひびき信用金庫');
ok($zip->set_number('8058521')->is_valid_number, '月星商事 株式会社');
ok($zip->set_number('8058527')->is_valid_number, '社会福祉法人 恩賜財団済生会支部 福岡県済生会八幡総合病院');
ok($zip->set_number('8058528')->is_valid_number, '株式会社 スピナ');
ok($zip->set_number('8058530')->is_valid_number, '太平工業 株式会社 八幡支店');
ok($zip->set_number('8058531')->is_valid_number, '株式会社 奥村組 九州支店');
ok($zip->set_number('8058533')->is_valid_number, '九築工業 株式会社');
ok($zip->set_number('8058534')->is_valid_number, '北九州市立八幡病院');
ok($zip->set_number('8058535')->is_valid_number, '株式会社 菅原');
ok($zip->set_number('8058536')->is_valid_number, '寒川商事 株式会社');
ok($zip->set_number('8058538')->is_valid_number, '株式会社 有薗製作所');
ok($zip->set_number('8058539')->is_valid_number, '株式会社 タカミヤ');
ok($zip->set_number('8058555')->is_valid_number, '日鉄テックスエンジ 株式会社 北九州事業センター');
ok($zip->set_number('8058585')->is_valid_number, '株式会社 スペースワールド');
ok($zip->set_number('8058606')->is_valid_number, '八幡税務署');
ok($zip->set_number('8058625')->is_valid_number, 'みずほ銀行 北九州支店 八幡出張所');
ok($zip->set_number('8068501')->is_valid_number, '九州厚生年金病院');
ok($zip->set_number('8068509')->is_valid_number, '八幡公共職業安定所');
ok($zip->set_number('8068510')->is_valid_number, '北九州市 八幡西区役所');
ok($zip->set_number('8068511')->is_valid_number, '株式会社 井筒屋 黒崎店');
ok($zip->set_number('8068540')->is_valid_number, '北九州西労働基準監督署');
ok($zip->set_number('8068543')->is_valid_number, '株式会社 メイト黒崎');
ok($zip->set_number('8068555')->is_valid_number, '八幡社会保険事務所');
ok($zip->set_number('8068558')->is_valid_number, '学校法人 能美学園 星琳高等学校');
ok($zip->set_number('8068567')->is_valid_number, '株式会社 高田工業所');
ok($zip->set_number('8068570')->is_valid_number, '国民生活金融公庫 八幡支店');
ok($zip->set_number('8068585')->is_valid_number, 'ホテルクラウンパレス');
ok($zip->set_number('8068586')->is_valid_number, '黒崎播磨 株式会社');
ok($zip->set_number('8068612')->is_valid_number, '株式会社 西日本シティ銀行 黒崎中央支店');
ok($zip->set_number('8068666')->is_valid_number, '株式会社 山口銀行 八幡支店');
ok($zip->set_number('8068679')->is_valid_number, '株式会社 西日本シティ銀行 黒崎支店');
ok($zip->set_number('8068686')->is_valid_number, '株式会社 福岡銀行 黒崎支店');
ok($zip->set_number('8070192')->is_valid_number, '航空自衛隊 芦屋基地');
ok($zip->set_number('8070198')->is_valid_number, '芦屋町役場');
ok($zip->set_number('8071392')->is_valid_number, '鞍手町役場');
ok($zip->set_number('8078501')->is_valid_number, '水巻町役場');
ok($zip->set_number('8078555')->is_valid_number, '産業医科大学');
ok($zip->set_number('8078556')->is_valid_number, '産業医科大学病院');
ok($zip->set_number('8078585')->is_valid_number, '九州共立大学');
ok($zip->set_number('8078586')->is_valid_number, '九州女子大学・九州女子短期大学');
ok($zip->set_number('8078588')->is_valid_number, '株式会社 三井ハイテック');
ok($zip->set_number('8080196')->is_valid_number, '九州工業大学大学院 生命体工学研究科');
ok($zip->set_number('8088501')->is_valid_number, '株式会社 サンリブ');
ok($zip->set_number('8088502')->is_valid_number, '鶴丸海運 株式会社');
ok($zip->set_number('8088505')->is_valid_number, '東紅食品 株式会社');
ok($zip->set_number('8088510')->is_valid_number, '北九州市 若松区役所');
ok($zip->set_number('8088514')->is_valid_number, '清和鋼業 株式会社 九州支店');
ok($zip->set_number('8088515')->is_valid_number, '株式会社 やきとりカンパニー');
ok($zip->set_number('8088550')->is_valid_number, '不二貿易 株式会社');
ok($zip->set_number('8088555')->is_valid_number, '協同組合 若松商連');
ok($zip->set_number('8088558')->is_valid_number, '株式会社 プロテリアル若松');
ok($zip->set_number('8088585')->is_valid_number, '社団法人 若松法人会');
ok($zip->set_number('8088588')->is_valid_number, '信和鋼板');
ok($zip->set_number('8088606')->is_valid_number, '若松税務署');
ok($zip->set_number('8098501')->is_valid_number, '中間市役所');
ok($zip->set_number('8108501')->is_valid_number, '株式会社 サニー');
ok($zip->set_number('8108502')->is_valid_number, '戸田建設 株式会社 九州支店');
ok($zip->set_number('8108503')->is_valid_number, '株式会社 ヤマウ');
ok($zip->set_number('8108504')->is_valid_number, '総合メディカル 株式会社');
ok($zip->set_number('8108506')->is_valid_number, '松尾建設 株式会社 福岡支店');
ok($zip->set_number('8108507')->is_valid_number, '株式会社 ユキワ 九州統括支社');
ok($zip->set_number('8108508')->is_valid_number, '株式会社 ぎょうせい九州支社');
ok($zip->set_number('8108509')->is_valid_number, '九州労働金庫');
ok($zip->set_number('8108511')->is_valid_number, '大成建設 株式会社 九州支店');
ok($zip->set_number('8108512')->is_valid_number, '株式会社 上組福岡支店');
ok($zip->set_number('8108513')->is_valid_number, '福岡法務局');
ok($zip->set_number('8108514')->is_valid_number, '出光カーリース 事務センター');
ok($zip->set_number('8108515')->is_valid_number, '福岡県 西福岡県税事務所');
ok($zip->set_number('8108516')->is_valid_number, '天神エフエム 株式会社');
ok($zip->set_number('8108517')->is_valid_number, '株式会社 ゲームテック');
ok($zip->set_number('8108518')->is_valid_number, '住友林業株式会社 営業本部九州支店');
ok($zip->set_number('8108519')->is_valid_number, '東武トップツアーズ 株式会社 福岡支店 九州国内旅行センター');
ok($zip->set_number('8108520')->is_valid_number, '株式会社 フタタ');
ok($zip->set_number('8108521')->is_valid_number, '福岡市消防局');
ok($zip->set_number('8108522')->is_valid_number, '株式会社 日立ビルシステム 九州支社');
ok($zip->set_number('8108523')->is_valid_number, '株式会社 ジョー・コーポレーション高木');
ok($zip->set_number('8108524')->is_valid_number, '株式会社 西新広福岡');
ok($zip->set_number('8108525')->is_valid_number, '株式会社 シティ情報ふくおか');
ok($zip->set_number('8108527')->is_valid_number, '三井松島産業 株式会社');
ok($zip->set_number('8108528')->is_valid_number, '株式会社 エフエム九州');
ok($zip->set_number('8108530')->is_valid_number, '松下電工 株式会社 九州地区担当部');
ok($zip->set_number('8108531')->is_valid_number, '日本総合信用 株式会社 福岡支店');
ok($zip->set_number('8108532')->is_valid_number, 'キリンビール 株式会社 九州支社');
ok($zip->set_number('8108533')->is_valid_number, 'コスモ石油 株式会社 福岡支店');
ok($zip->set_number('8108535')->is_valid_number, '西日本電信電話 株式会社 福岡支店');
ok($zip->set_number('8108537')->is_valid_number, '麻生商事 株式会社');
ok($zip->set_number('8108538')->is_valid_number, '福岡県住宅供給公社');
ok($zip->set_number('8108539')->is_valid_number, '国家公務員共済組合連合会 浜の町病院');
ok($zip->set_number('8108540')->is_valid_number, '西日本プラント工業 株式会社');
ok($zip->set_number('8108541')->is_valid_number, '福岡郵便貯金会館');
ok($zip->set_number('8108543')->is_valid_number, '株式会社 丸美');
ok($zip->set_number('8108544')->is_valid_number, '株式会社 岩田屋三越 福岡三越');
ok($zip->set_number('8108545')->is_valid_number, '株式会社 ダイレクトマーケティングシステム');
ok($zip->set_number('8108546')->is_valid_number, '有限会社 サウンドトラック');
ok($zip->set_number('8108551')->is_valid_number, '毎日新聞社 福岡総局');
ok($zip->set_number('8108553')->is_valid_number, '大同生命保険 相互会社 福岡支社');
ok($zip->set_number('8108555')->is_valid_number, '株式会社 東芝 九州支社');
ok($zip->set_number('8108556')->is_valid_number, 'アーサーヒューマネット 株式会社');
ok($zip->set_number('8108557')->is_valid_number, '株式会社 リクルート 九州支社');
ok($zip->set_number('8108558')->is_valid_number, '株式会社 西日本新聞広告社');
ok($zip->set_number('8108560')->is_valid_number, '九州大学 六本松地区部局(大学教育研究センター、大学院比較社会文化研究科、言語文化部)');
ok($zip->set_number('8108561')->is_valid_number, '株式会社 JTB九州');
ok($zip->set_number('8108563')->is_valid_number, '国立病院機構 九州医療センター');
ok($zip->set_number('8108565')->is_valid_number, '株式会社九州国際エフエム(LOVE FM76.1)');
ok($zip->set_number('8108566')->is_valid_number, '富士産業 株式会社 福岡支店');
ok($zip->set_number('8108567')->is_valid_number, 'カネツ商事 株式会社 福岡支店');
ok($zip->set_number('8108568')->is_valid_number, '株式会社 ウィルコム 九州支店');
ok($zip->set_number('8108570')->is_valid_number, '西日本鉄道 株式会社');
ok($zip->set_number('8108571')->is_valid_number, '九州朝日放送 株式会社');
ok($zip->set_number('8108571')->is_valid_number, 'KBCグループホールディングス 株式会社');
ok($zip->set_number('8108575')->is_valid_number, '株式会社 エフエム福岡');
ok($zip->set_number('8108577')->is_valid_number, '日本放送協会 福岡放送局');
ok($zip->set_number('8108578')->is_valid_number, 'オー・ジー 株式会社 九州支店');
ok($zip->set_number('8108581')->is_valid_number, '読売新聞 西部本社');
ok($zip->set_number('8108583')->is_valid_number, '都久志会館');
ok($zip->set_number('8108584')->is_valid_number, '株式会社 博多東急イン');
ok($zip->set_number('8108585')->is_valid_number, '株式会社 西日本リビング新聞社');
ok($zip->set_number('8108587')->is_valid_number, '株式会社 西鉄グランドホテル');
ok($zip->set_number('8108588')->is_valid_number, 'キューサイ 株式会社');
ok($zip->set_number('8108589')->is_valid_number, '株式会社 阪急交通社 福岡支店');
ok($zip->set_number('8108601')->is_valid_number, '月刊うるとらマンボウ 株式会社 アートライン');
ok($zip->set_number('8108603')->is_valid_number, 'トヨタカローラ福岡 株式会社');
ok($zip->set_number('8108604')->is_valid_number, '株式会社 福岡玉屋');
ok($zip->set_number('8108605')->is_valid_number, '福岡中央労働基準監督署');
ok($zip->set_number('8108606')->is_valid_number, 'キューサイ 株式会社');
ok($zip->set_number('8108607')->is_valid_number, '清水建設 株式会社 九州支店');
ok($zip->set_number('8108608')->is_valid_number, '福岡高等裁判所');
ok($zip->set_number('8108609')->is_valid_number, '福岡中央公共職業安定所');
ok($zip->set_number('8108610')->is_valid_number, '独立行政法人 都市再生機構 九州支社');
ok($zip->set_number('8108611')->is_valid_number, 'こくみん共済 COOP 福岡推進本部');
ok($zip->set_number('8108617')->is_valid_number, '九州通信ネットワーク 株式会社');
ok($zip->set_number('8108619')->is_valid_number, '学校法人 河合塾 福岡校');
ok($zip->set_number('8108620')->is_valid_number, '福岡市役所');
ok($zip->set_number('8108621')->is_valid_number, '福岡市教育委員会');
ok($zip->set_number('8108622')->is_valid_number, '福岡市 中央区役所');
ok($zip->set_number('8108625')->is_valid_number, '雪印乳業 株式会社 九州支社');
ok($zip->set_number('8108627')->is_valid_number, '株式会社 ジェーシービー 九州支社');
ok($zip->set_number('8108629')->is_valid_number, '株式会社 ふくや');
ok($zip->set_number('8108631')->is_valid_number, '株式会社東食 福岡支店');
ok($zip->set_number('8108633')->is_valid_number, '株式会社 キシヤ');
ok($zip->set_number('8108634')->is_valid_number, '株式会社 三好不動産');
ok($zip->set_number('8108636')->is_valid_number, '九州三菱自動車販売 株式会社');
ok($zip->set_number('8108637')->is_valid_number, 'AIG損害保険 株式会社 九州・沖縄地域事業本部');
ok($zip->set_number('8108639')->is_valid_number, 'MARK IS 福岡ももち');
ok($zip->set_number('8108642')->is_valid_number, '株式会社 情報センター福岡');
ok($zip->set_number('8108648')->is_valid_number, '株式会社 トクスイコーポレーション');
ok($zip->set_number('8108650')->is_valid_number, 'ヒルトン福岡シーホーク');
ok($zip->set_number('8108651')->is_valid_number, '福岡地方検察庁');
ok($zip->set_number('8108652')->is_valid_number, '福岡家庭裁判所');
ok($zip->set_number('8108653')->is_valid_number, '福岡地方裁判所');
ok($zip->set_number('8108654')->is_valid_number, '福岡簡易裁判所');
ok($zip->set_number('8108655')->is_valid_number, '株式会社 福岡放送');
ok($zip->set_number('8108656')->is_valid_number, '株式会社 福岡放送');
ok($zip->set_number('8108660')->is_valid_number, '福岡PayPayドーム');
ok($zip->set_number('8108662')->is_valid_number, '株式会社 ホークスタウン ホークスタウンモール');
ok($zip->set_number('8108663')->is_valid_number, '新日本法規出版 株式会社 福岡支社');
ok($zip->set_number('8108664')->is_valid_number, '株式会社 キョードー西日本');
ok($zip->set_number('8108665')->is_valid_number, '株式会社 システムソフト');
ok($zip->set_number('8108666')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('8108667')->is_valid_number, '株式会社 河村家具');
ok($zip->set_number('8108669')->is_valid_number, '株式会社 ユニカ');
ok($zip->set_number('8108670')->is_valid_number, '資生堂化粧品販売 株式会社 福岡支社');
ok($zip->set_number('8108673')->is_valid_number, '福岡酒類販売 株式会社');
ok($zip->set_number('8108674')->is_valid_number, '福岡国税局業務センター室');
ok($zip->set_number('8108675')->is_valid_number, '株式会社 電通九州');
ok($zip->set_number('8108676')->is_valid_number, '株式会社 福岡中央銀行');
ok($zip->set_number('8108677')->is_valid_number, '株式会社 福岡魚市場');
ok($zip->set_number('8108680')->is_valid_number, '株式会社 岩田屋三越 岩田屋本店');
ok($zip->set_number('8108683')->is_valid_number, '三井住友海上火災保険 株式会社');
ok($zip->set_number('8108685')->is_valid_number, '新日本石油 株式会社 九州支店');
ok($zip->set_number('8108686')->is_valid_number, '三菱電機 株式会社 九州支社');
ok($zip->set_number('8108688')->is_valid_number, '丸紅 株式会社 九州支社');
ok($zip->set_number('8108689')->is_valid_number, '福岡税務署');
ok($zip->set_number('8108701')->is_valid_number, '株式会社 みずほ銀行 福岡支店');
ok($zip->set_number('8108705')->is_valid_number, '九州電力送配電 株式会社 本店');
ok($zip->set_number('8108707')->is_valid_number, '日本生命保険 相互会社 福岡総支社');
ok($zip->set_number('8108710')->is_valid_number, '三菱信託銀行 株式会社 福岡支店');
ok($zip->set_number('8108716')->is_valid_number, '株式会社 ユニック');
ok($zip->set_number('8108717')->is_valid_number, '株式会社 博多大丸');
ok($zip->set_number('8108718')->is_valid_number, 'アサヒビール 株式会社');
ok($zip->set_number('8108720')->is_valid_number, '九州電力 株式会社');
ok($zip->set_number('8108721')->is_valid_number, '株式会社 西日本新聞社');
ok($zip->set_number('8108722')->is_valid_number, '福岡トヨタ自動車 株式会社');
ok($zip->set_number('8108725')->is_valid_number, 'UFJ信託銀行 株式会社 福岡支店');
ok($zip->set_number('8108727')->is_valid_number, '株式会社 福岡銀行');
ok($zip->set_number('8108731')->is_valid_number, '児島洋紙 株式会社');
ok($zip->set_number('8108734')->is_valid_number, '親和銀行 福岡営業部');
ok($zip->set_number('8108798')->is_valid_number, '福岡逓信病院');
ok($zip->set_number('8110192')->is_valid_number, '新宮町役場');
ok($zip->set_number('8110193')->is_valid_number, '株式会社 フランソア');
ok($zip->set_number('8110194')->is_valid_number, '株式会社 ニューイングベーカリー九州');
ok($zip->set_number('8110195')->is_valid_number, 'プリマハム 株式会社 九州支店');
ok($zip->set_number('8110196')->is_valid_number, '株式会社 筑豊製作所');
ok($zip->set_number('8110197')->is_valid_number, '株式会社 はぴねすくらぶ');
ok($zip->set_number('8110295')->is_valid_number, '学校法人 福岡工業大学');
ok($zip->set_number('8111292')->is_valid_number, '那珂川市役所');
ok($zip->set_number('8111392')->is_valid_number, '福岡自動車試験場');
ok($zip->set_number('8111393')->is_valid_number, '照栄建設 株式会社');
ok($zip->set_number('8111394')->is_valid_number, '独立行政法人 国立病院機構 福岡病院');
ok($zip->set_number('8111395')->is_valid_number, '国立病院九州がんセンター');
ok($zip->set_number('8111396')->is_valid_number, '自動車安全運転センター 福岡県事務所');
ok($zip->set_number('8112192')->is_valid_number, '宇美町役場');
ok($zip->set_number('8112193')->is_valid_number, '須惠町役場');
ok($zip->set_number('8112194')->is_valid_number, 'ダイレックス福岡マザーセンター');
ok($zip->set_number('8112195')->is_valid_number, 'サンドラッグ 福岡物流センター');
ok($zip->set_number('8112196')->is_valid_number, '佐川グローバルロジスティクス 株式会社 九州支店 須恵営業所');
ok($zip->set_number('8112292')->is_valid_number, '志免町役場');
ok($zip->set_number('8112293')->is_valid_number, '株式会社 西友 志免店');
ok($zip->set_number('8112294')->is_valid_number, '株式会社 サカグチ');
ok($zip->set_number('8112295')->is_valid_number, '技研工業 株式会社');
ok($zip->set_number('8112297')->is_valid_number, '福岡県立 須恵高等学校');
ok($zip->set_number('8112298')->is_valid_number, '医療法人社団 正信会 水戸病院');
ok($zip->set_number('8112392')->is_valid_number, '粕屋町役場');
ok($zip->set_number('8112393')->is_valid_number, 'JP楽天ロジスティクス 株式会社 楽天フルフィルメントセンター福岡');
ok($zip->set_number('8112395')->is_valid_number, '佐川グローバルロジスティクス 株式会社');
ok($zip->set_number('8112398')->is_valid_number, '株式会社 ゼネラルアサヒ');
ok($zip->set_number('8112492')->is_valid_number, '篠栗町役場');
ok($zip->set_number('8112495')->is_valid_number, 'エフコープ 生活協同組合');
ok($zip->set_number('8112496')->is_valid_number, '生活協同組合連合会 コープ九州事業連合');
ok($zip->set_number('8112498')->is_valid_number, '株式会社 やまやコミュニケーションズ');
ok($zip->set_number('8112592')->is_valid_number, '久山町役場');
ok($zip->set_number('8113192')->is_valid_number, '古賀市役所');
ok($zip->set_number('8113193')->is_valid_number, '西部電機 株式会社');
ok($zip->set_number('8113195')->is_valid_number, '国立病院機構 福岡東医療センタ-');
ok($zip->set_number('8113197')->is_valid_number, '株式会社 正興電機製作所');
ok($zip->set_number('8113198')->is_valid_number, '山崎製パン 株式会社 福岡工場');
ok($zip->set_number('8113293')->is_valid_number, '福津市役所');
ok($zip->set_number('8113295')->is_valid_number, '医療法人 恵愛会 福間病院');
ok($zip->set_number('8113296')->is_valid_number, '名糖産業 株式会社 福岡工場');
ok($zip->set_number('8113298')->is_valid_number, '社会医療法人水光会 宗像水光会総合病院');
ok($zip->set_number('8113492')->is_valid_number, '宗像市役所');
ok($zip->set_number('8113598')->is_valid_number, '宗像市玄海支所');
ok($zip->set_number('8114192')->is_valid_number, '福岡教育大学');
ok($zip->set_number('8114193')->is_valid_number, '東海大学 第五高等学校');
ok($zip->set_number('8114195')->is_valid_number, '株式会社 くりえいと/日創開発 株式会社');
ok($zip->set_number('8114198')->is_valid_number, '東海大学 福岡短期大学');
ok($zip->set_number('8114292')->is_valid_number, '遠賀信用金庫 本部');
ok($zip->set_number('8114392')->is_valid_number, '遠賀町役場');
ok($zip->set_number('8114393')->is_valid_number, '株式会社 釣研');
ok($zip->set_number('8115192')->is_valid_number, '壱岐市役所');
ok($zip->set_number('8128501')->is_valid_number, 'ブリヂストンタイヤ九州販売 株式会社');
ok($zip->set_number('8128502')->is_valid_number, 'MPアグロ 株式会社');
ok($zip->set_number('8128503')->is_valid_number, 'KDDI 株式会社 au九州支店');
ok($zip->set_number('8128504')->is_valid_number, '株式会社 ヴァーナル');
ok($zip->set_number('8128505')->is_valid_number, '福岡商工会議所');
ok($zip->set_number('8128506')->is_valid_number, '株式会社 毎日メディアサービス');
ok($zip->set_number('8128507')->is_valid_number, '中華航空公司 福岡辨事處');
ok($zip->set_number('8128508')->is_valid_number, 'ヤマハ 株式会社 九州支店');
ok($zip->set_number('8128509')->is_valid_number, '森永乳業九州 株式会社');
ok($zip->set_number('8128510')->is_valid_number, '富士通 株式会社');
ok($zip->set_number('8128511')->is_valid_number, '朝日新聞 福岡本部');
ok($zip->set_number('8128512')->is_valid_number, '福岡市 博多区役所');
ok($zip->set_number('8128513')->is_valid_number, '鹿島建設 株式会社 九州支店');
ok($zip->set_number('8128514')->is_valid_number, '博多区保険福祉センター');
ok($zip->set_number('8128515')->is_valid_number, '株式会社 日産ファイナンシャルサービス');
ok($zip->set_number('8128516')->is_valid_number, '株式会社 ホリデー 福岡支店');
ok($zip->set_number('8128517')->is_valid_number, '株式会社 ホリデー');
ok($zip->set_number('8128518')->is_valid_number, '大成建設 株式会社 九州支店');
ok($zip->set_number('8128519')->is_valid_number, '一般財団法人 福岡県退職教職員協会');
ok($zip->set_number('8128520')->is_valid_number, '日商岩井 株式会社 九州支社');
ok($zip->set_number('8128521')->is_valid_number, '福岡県国民健康保険団体連合会');
ok($zip->set_number('8128522')->is_valid_number, '日本製鉄 株式会社 九州支店');
ok($zip->set_number('8128523')->is_valid_number, '株式会社ダイテック 九州センター');
ok($zip->set_number('8128524')->is_valid_number, 'PayPayカード 株式会社');
ok($zip->set_number('8128525')->is_valid_number, '株式会社 武富士 福岡支社管理室');
ok($zip->set_number('8128526')->is_valid_number, '株式会社 新栄商会');
ok($zip->set_number('8128527')->is_valid_number, 'エフコープ生活協同組合');
ok($zip->set_number('8128528')->is_valid_number, '伊藤忠エネクス 株式会社');
ok($zip->set_number('8128529')->is_valid_number, '日本製粉 株式会社 福岡営業部・福岡食品営業部');
ok($zip->set_number('8128530')->is_valid_number, '株式会社 にしけい');
ok($zip->set_number('8128531')->is_valid_number, 'パナソニックシステムネットワークス 株式会社');
ok($zip->set_number('8128532')->is_valid_number, '福岡県 社会保険診療報酬支払基金');
ok($zip->set_number('8128533')->is_valid_number, '株式会社 文榮出版社');
ok($zip->set_number('8128534')->is_valid_number, '日本年金機構 九州ブロック本部');
ok($zip->set_number('8128535')->is_valid_number, 'ニビシ醤油 株式会社');
ok($zip->set_number('8128536')->is_valid_number, 'エスエス製薬 株式会社 九州支店');
ok($zip->set_number('8128537')->is_valid_number, 'ユアサ商事 株式会社 九州支社');
ok($zip->set_number('8128538')->is_valid_number, '日本タングステン株式会社 本社');
ok($zip->set_number('8128539')->is_valid_number, 'ニシム電子工業 株式会社');
ok($zip->set_number('8128540')->is_valid_number, '日本年金機構 博多年金事務所');
ok($zip->set_number('8128541')->is_valid_number, '九州総合信用 株式会社');
ok($zip->set_number('8128542')->is_valid_number, '福岡県博多県税事務所');
ok($zip->set_number('8128543')->is_valid_number, '福岡県東福岡県税事務所');
ok($zip->set_number('8128544')->is_valid_number, '西部ガスリビング (株)');
ok($zip->set_number('8128545')->is_valid_number, 'エヌ・ティ・ティ九州移動通信網 株式会社 営業本部 PHSサービスセンター');
ok($zip->set_number('8128546')->is_valid_number, '九州経済産業局');
ok($zip->set_number('8128547')->is_valid_number, '福岡国税局');
ok($zip->set_number('8128548')->is_valid_number, 'ヤマエ久野 株式会社');
ok($zip->set_number('8128550')->is_valid_number, '財団法人 社会保険健康事業財団 福岡県支部');
ok($zip->set_number('8128551')->is_valid_number, '社団法人 福岡県医師会');
ok($zip->set_number('8128552')->is_valid_number, '株式会社 オーニシ');
ok($zip->set_number('8128553')->is_valid_number, '株式会社 菱熱');
ok($zip->set_number('8128554')->is_valid_number, 'KDDI 株式会社au九州支社');
ok($zip->set_number('8128555')->is_valid_number, '福岡県 信用保証協会');
ok($zip->set_number('8128556')->is_valid_number, '株式会社 南陽');
ok($zip->set_number('8128557')->is_valid_number, '株式会社 ドイ');
ok($zip->set_number('8128558')->is_valid_number, '日野出 株式会社');
ok($zip->set_number('8128559')->is_valid_number, '株式会社 西部日刊スポーツ新聞社');
ok($zip->set_number('8128560')->is_valid_number, '岩谷産業 株式会社 九州支社');
ok($zip->set_number('8128561')->is_valid_number, '生活協同組合連合会 グリーンコープ連合');
ok($zip->set_number('8128562')->is_valid_number, '株式会社 間組 九州支店');
ok($zip->set_number('8128563')->is_valid_number, '資生堂ジャパン 株式会社 福岡オフィス');
ok($zip->set_number('8128564')->is_valid_number, '佐藤工業 株式会社 九州支店');
ok($zip->set_number('8128565')->is_valid_number, '西部電気工業 株式会社 福岡本社');
ok($zip->set_number('8128566')->is_valid_number, '九州旅客鉄道 株式会社');
ok($zip->set_number('8128568')->is_valid_number, '株式会社 フジタ 九州支店');
ok($zip->set_number('8128569')->is_valid_number, '国土交通省 九州地方整備局 建政部 建設産業課');
ok($zip->set_number('8128570')->is_valid_number, '株式会社 TVQ九州放送');
ok($zip->set_number('8128571')->is_valid_number, '株式会社 菱食 九州支社');
ok($zip->set_number('8128572')->is_valid_number, 'ソフトバンクテレコム 株式会社 レターコンタクトセンター');
ok($zip->set_number('8128573')->is_valid_number, '九州管区警察局');
ok($zip->set_number('8128574')->is_valid_number, '福岡県議会事務局');
ok($zip->set_number('8128575')->is_valid_number, '福岡県教育庁');
ok($zip->set_number('8128576')->is_valid_number, '福岡県警察本部');
ok($zip->set_number('8128577')->is_valid_number, '福岡県庁');
ok($zip->set_number('8128578')->is_valid_number, '株式会社 山善 九州営業本部');
ok($zip->set_number('8128579')->is_valid_number, '日本年金機構 福岡広域事務センター');
ok($zip->set_number('8128580')->is_valid_number, '株式会社 プレナス');
ok($zip->set_number('8128581')->is_valid_number, '九州大学箱崎地区部局');
ok($zip->set_number('8128582')->is_valid_number, '九州大学病院地区部局');
ok($zip->set_number('8128583')->is_valid_number, '福岡日野自動車 株式会社');
ok($zip->set_number('8128584')->is_valid_number, '株式会社 ベストサービス');
ok($zip->set_number('8128584')->is_valid_number, '株式会社 ベスト電器');
ok($zip->set_number('8128584')->is_valid_number, '株式会社 リペア・デポ');
ok($zip->set_number('8128585')->is_valid_number, '株式会社 ヤクシン');
ok($zip->set_number('8128586')->is_valid_number, '株式会社 あらた 福岡支店');
ok($zip->set_number('8128587')->is_valid_number, '昭和鉄工 株式会社');
ok($zip->set_number('8128588')->is_valid_number, '明治屋商事 株式会社 福岡支店');
ok($zip->set_number('8128589')->is_valid_number, '三菱ふそうトラック・バス 株式会社 九州ふそう');
ok($zip->set_number('8128601')->is_valid_number, 'サッポロビール 株式会社 九州本部');
ok($zip->set_number('8128602')->is_valid_number, '株式会社 大塚商会 福岡支店');
ok($zip->set_number('8128603')->is_valid_number, '武田薬品工業 株式会社 福岡事務所');
ok($zip->set_number('8128604')->is_valid_number, '創価学会 九州文化会館');
ok($zip->set_number('8128605')->is_valid_number, '三菱HCキャピタル 株式会社');
ok($zip->set_number('8128606')->is_valid_number, '株式会社 東急コミュニティー 九州支店');
ok($zip->set_number('8128607')->is_valid_number, '三菱UFJニコス 株式会社');
ok($zip->set_number('8128608')->is_valid_number, '東急建設 株式会社 九州支店');
ok($zip->set_number('8128609')->is_valid_number, '西部日本信販 株式会社');
ok($zip->set_number('8128610')->is_valid_number, '株式会社 セントラルファイナンス 福岡管理センター');
ok($zip->set_number('8128611')->is_valid_number, '株式会社 松村組 九州支店');
ok($zip->set_number('8128612')->is_valid_number, '株式会社 マイカル九州');
ok($zip->set_number('8128613')->is_valid_number, '株式会社 レイメイ藤井');
ok($zip->set_number('8128614')->is_valid_number, '五洋建設 株式会社 九州支店');
ok($zip->set_number('8128615')->is_valid_number, '株式会社 博多座');
ok($zip->set_number('8128616')->is_valid_number, '三洋信販 株式会社');
ok($zip->set_number('8128617')->is_valid_number, '九州松下ライフエレクトロニクス 株式会社');
ok($zip->set_number('8128618')->is_valid_number, '国分 株式会社 九州支社');
ok($zip->set_number('8128620')->is_valid_number, '福岡市港湾空港局');
ok($zip->set_number('8128621')->is_valid_number, '三洋信販 株式会社');
ok($zip->set_number('8128622')->is_valid_number, '独立行政法人 鉄道建設・運輸施設整備支援機構 九州新幹線建設局');
ok($zip->set_number('8128624')->is_valid_number, '伊藤忠食品 株式会社 九州支店');
ok($zip->set_number('8128625')->is_valid_number, 'ヒノマル 株式会社 福岡支店');
ok($zip->set_number('8128626')->is_valid_number, '日本電気 株式会社 九州支社');
ok($zip->set_number('8128627')->is_valid_number, '三井ショッピングパーク ららぽーと福岡');
ok($zip->set_number('8128628')->is_valid_number, 'ジー・イー・キャピタル・エジソン生命保険 株式会社 福岡支社');
ok($zip->set_number('8128629')->is_valid_number, '株式会社 ゲームテック');
ok($zip->set_number('8128630')->is_valid_number, '株式会社 中陽');
ok($zip->set_number('8128631')->is_valid_number, '福岡日産自動車 株式会社');
ok($zip->set_number('8128632')->is_valid_number, '福岡日産自動車 株式会社');
ok($zip->set_number('8128633')->is_valid_number, '総合病院 千鳥橋病院');
ok($zip->set_number('8128634')->is_valid_number, '三洋信販 株式会社');
ok($zip->set_number('8128635')->is_valid_number, '福岡コンピューターサービス 株式会社');
ok($zip->set_number('8128636')->is_valid_number, '日之出水道機器 株式会社');
ok($zip->set_number('8128637')->is_valid_number, '西部ガス情報システム 株式会社');
ok($zip->set_number('8128638')->is_valid_number, '九州カシオ販売 (株)');
ok($zip->set_number('8128639')->is_valid_number, '福博綜合印刷 株式会社');
ok($zip->set_number('8128640')->is_valid_number, '株式会社祭原九州支社');
ok($zip->set_number('8128641')->is_valid_number, 'ヤマハ九州 株式会社');
ok($zip->set_number('8128642')->is_valid_number, '九州松下システム 株式会社');
ok($zip->set_number('8128643')->is_valid_number, 'ピップフジモト 株式会社 福岡支店');
ok($zip->set_number('8128645')->is_valid_number, '株式会社ワイヨット 福岡店');
ok($zip->set_number('8128646')->is_valid_number, '三菱重工九州販売 株式会社');
ok($zip->set_number('8128647')->is_valid_number, '福祉乗車券等郵送受付センター');
ok($zip->set_number('8128648')->is_valid_number, '九州松下アイティーモバイル 株式会社');
ok($zip->set_number('8128650')->is_valid_number, 'コカ・コーラウエスト 株式会社');
ok($zip->set_number('8128651')->is_valid_number, '福岡県立図書館');
ok($zip->set_number('8128652')->is_valid_number, '株式会社 原田貞良商店');
ok($zip->set_number('8128653')->is_valid_number, '福岡市 東区役所');
ok($zip->set_number('8128654')->is_valid_number, '株式会社 かねふく');
ok($zip->set_number('8128655')->is_valid_number, '宗教法人 筥崎宮');
ok($zip->set_number('8128656')->is_valid_number, '日本食品 株式会社');
ok($zip->set_number('8128657')->is_valid_number, '日本年金機構 東福岡年金事務所');
ok($zip->set_number('8128659')->is_valid_number, 'タイキ薬品工業 株式会社');
ok($zip->set_number('8128660')->is_valid_number, '富士ゼロックス 株式会社 西日本営業事業部');
ok($zip->set_number('8128661')->is_valid_number, '株式会社 かねふく めんたい通');
ok($zip->set_number('8128662')->is_valid_number, '住友商事 株式会社 九州支社');
ok($zip->set_number('8128665')->is_valid_number, '鹿島道路 株式会社 九州支店');
ok($zip->set_number('8128666')->is_valid_number, '日本経済新聞社');
ok($zip->set_number('8128668')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('8128669')->is_valid_number, '株式会社 味の素コミュニケーションズ 九州・中国グループ');
ok($zip->set_number('8128670')->is_valid_number, '全国健康保険協会 福岡支部');
ok($zip->set_number('8128672')->is_valid_number, 'リックス 株式会社');
ok($zip->set_number('8128675')->is_valid_number, '日本生命保険 相互会社 福岡法人サービス課');
ok($zip->set_number('8128676')->is_valid_number, '住友海上火災保険株式会社九州支店・福岡支店');
ok($zip->set_number('8128677')->is_valid_number, '伊藤忠商事 株式会社 九州支社');
ok($zip->set_number('8128678')->is_valid_number, '株式会社 博多井筒屋');
ok($zip->set_number('8128680')->is_valid_number, '福岡県共済生活協同組合');
ok($zip->set_number('8128681')->is_valid_number, '株式会社 翔薬');
ok($zip->set_number('8128683')->is_valid_number, '味の素 株式会社 九州支社');
ok($zip->set_number('8128684')->is_valid_number, '東京海上事務アウトソーシング (株) 福岡センター');
ok($zip->set_number('8128686')->is_valid_number, '株式会社 ベネッセコーポレーション 九州支社');
ok($zip->set_number('8128687')->is_valid_number, '株式会社 福岡シティ銀行');
ok($zip->set_number('8128689')->is_valid_number, '株式会社 日本政策金融公庫 福岡支店 国民生活事業');
ok($zip->set_number('8128705')->is_valid_number, '東京海上日動火災保険 株式会社 九州業務支援部');
ok($zip->set_number('8128706')->is_valid_number, '博多税務署');
ok($zip->set_number('8128707')->is_valid_number, '西部ガス 株式会社');
ok($zip->set_number('8128708')->is_valid_number, '三井信託銀行 株式会社 福岡支店');
ok($zip->set_number('8128709')->is_valid_number, '九宏薬品 株式会社');
ok($zip->set_number('8128717')->is_valid_number, '株式会社 新出光');
ok($zip->set_number('8128718')->is_valid_number, '株式会社 渡辺藤吉本店');
ok($zip->set_number('8128735')->is_valid_number, '独立行政法人 住宅金融支援機構 九州支店');
ok($zip->set_number('8128792')->is_valid_number, '福岡サービスセンター');
ok($zip->set_number('8128794')->is_valid_number, '福岡貯金事務センター');
ok($zip->set_number('8129502')->is_valid_number, '株式会社 翔薬 板付分室');
ok($zip->set_number('8129503')->is_valid_number, '株式会社 九州合食');
ok($zip->set_number('8129505')->is_valid_number, '九州電力 株式会社 福岡南営業所');
ok($zip->set_number('8129511')->is_valid_number, '株式会社 スズケン 福岡支店');
ok($zip->set_number('8129520')->is_valid_number, 'トヨタ部品福岡共販 株式会社');
ok($zip->set_number('8129540')->is_valid_number, '精華女子短期大学');
ok($zip->set_number('8129551')->is_valid_number, '株式会社 日伝 九州支店');
ok($zip->set_number('8129552')->is_valid_number, '株式会社 アトル');
ok($zip->set_number('8129588')->is_valid_number, '不二精機 株式会社');
ok($zip->set_number('8129589')->is_valid_number, 'DICグラフィックス 株式会社 九州支店');
ok($zip->set_number('8138501')->is_valid_number, '国家公務員等共済組合連合会 千早病院');
ok($zip->set_number('8138503')->is_valid_number, '学校法人 中村産業学園 九州産業大学');
ok($zip->set_number('8138513')->is_valid_number, '九州電力 株式会社 福岡東営業所');
ok($zip->set_number('8138519')->is_valid_number, '商工組合中央金庫 福岡流通センター出張所');
ok($zip->set_number('8138529')->is_valid_number, '福岡女子大学');
ok($zip->set_number('8138533')->is_valid_number, '株式会社 ルルアーク');
ok($zip->set_number('8138555')->is_valid_number, '株式会社 アトル');
ok($zip->set_number('8138577')->is_valid_number, '九州運輸局 福岡運輸支局');
ok($zip->set_number('8138585')->is_valid_number, 'アビスパ福岡 株式会社');
ok($zip->set_number('8138588')->is_valid_number, '医療法人 原土井病院');
ok($zip->set_number('8138609')->is_valid_number, '福岡東公共職業安定所');
ok($zip->set_number('8138623')->is_valid_number, '日産ディーゼル福岡販売 株式会社');
ok($zip->set_number('8138626')->is_valid_number, 'ユニーク 株式会社');
ok($zip->set_number('8138680')->is_valid_number, '株式会社トーホー 九州支店');
ok($zip->set_number('8138681')->is_valid_number, '香椎税務署');
ok($zip->set_number('8140180')->is_valid_number, '福岡大学');
ok($zip->set_number('8140192')->is_valid_number, '福岡市 城南区役所');
ok($zip->set_number('8140193')->is_valid_number, '福岡学園');
ok($zip->set_number('8140198')->is_valid_number, '中村学園');
ok($zip->set_number('8148501')->is_valid_number, '福岡市 早良区役所');
ok($zip->set_number('8148503')->is_valid_number, '福岡拘置所');
ok($zip->set_number('8148505')->is_valid_number, '社団法人 日本自動車連盟 九州本部');
ok($zip->set_number('8148510')->is_valid_number, '福岡県立 修猷館高等学校');
ok($zip->set_number('8148511')->is_valid_number, '学校法人 西南学院');
ok($zip->set_number('8148512')->is_valid_number, '西南学院中学校・高等学校');
ok($zip->set_number('8148520')->is_valid_number, '福岡県立 福岡工業高等学校');
ok($zip->set_number('8148522')->is_valid_number, '福岡大学西新病院');
ok($zip->set_number('8148524')->is_valid_number, '福岡法務局 西新出張所');
ok($zip->set_number('8148525')->is_valid_number, '医療法人 大成会福岡記念病院');
ok($zip->set_number('8148550')->is_valid_number, 'ボーダフォン 株式会社');
ok($zip->set_number('8148553')->is_valid_number, '株式会社 シティビジネスサービス');
ok($zip->set_number('8148554')->is_valid_number, '株式会社 シティアスコム');
ok($zip->set_number('8148555')->is_valid_number, '株式会社 テレビ西日本');
ok($zip->set_number('8148556')->is_valid_number, '株式会社 TNC放送会館');
ok($zip->set_number('8148565')->is_valid_number, '株式会社 TNC企画');
ok($zip->set_number('8148577')->is_valid_number, '株式会社 日立製作所 九州支社');
ok($zip->set_number('8148585')->is_valid_number, 'RKB毎日放送 株式会社');
ok($zip->set_number('8148585')->is_valid_number, '株式会社 RKB毎日ホールディングス');
ok($zip->set_number('8148588')->is_valid_number, '富士通 九州R&Dセンター');
ok($zip->set_number('8148602')->is_valid_number, '西福岡税務署');
ok($zip->set_number('8148651')->is_valid_number, '株式会社 福岡銀行');
ok($zip->set_number('8148798')->is_valid_number, '九州郵政研修センター');
ok($zip->set_number('8158501')->is_valid_number, '福岡市 南区役所');
ok($zip->set_number('8158503')->is_valid_number, '日本赤十字社 福岡県支部');
ok($zip->set_number('8158510')->is_valid_number, '学校法人 純真学園');
ok($zip->set_number('8158511')->is_valid_number, '第一薬科大学');
ok($zip->set_number('8158520')->is_valid_number, '九州電力 株式会社 総合研究所');
ok($zip->set_number('8158529')->is_valid_number, '八洲産業 株式会社');
ok($zip->set_number('8158533')->is_valid_number, '株式会社 FCCテクノ');
ok($zip->set_number('8158540')->is_valid_number, '九州大学 芸術工学部');
ok($zip->set_number('8158546')->is_valid_number, 'パナホーム 株式会社 福岡支社');
ok($zip->set_number('8158550')->is_valid_number, '株式会社 山口油屋福太郎');
ok($zip->set_number('8158555')->is_valid_number, '福岡赤十字病院');
ok($zip->set_number('8158588')->is_valid_number, '公立学校共済組合 九州中央病院');
ok($zip->set_number('8158601')->is_valid_number, '株式会社 九州自然館');
ok($zip->set_number('8158666')->is_valid_number, '出光クレジット 株式会社 福岡分室');
ok($zip->set_number('8158686')->is_valid_number, '株式会社 やずや');
ok($zip->set_number('8168501')->is_valid_number, '春日市役所');
ok($zip->set_number('8168510')->is_valid_number, '大野城市役所');
ok($zip->set_number('8168511')->is_valid_number, '春日警察署');
ok($zip->set_number('8168530')->is_valid_number, '株式会社 アシュラン');
ok($zip->set_number('8168550')->is_valid_number, '三省製薬 株式会社');
ok($zip->set_number('8168555')->is_valid_number, '株式会社 リョーユーパン');
ok($zip->set_number('8168567')->is_valid_number, '株式会社 マルキョウ');
ok($zip->set_number('8168577')->is_valid_number, '福岡南公共職業安定所');
ok($zip->set_number('8168580')->is_valid_number, '九州大学 筑紫地区事務部');
ok($zip->set_number('8168585')->is_valid_number, '明光電子 株式会社');
ok($zip->set_number('8168666')->is_valid_number, '陸上自衛隊 福岡駐屯地');
ok($zip->set_number('8171292')->is_valid_number, '対馬市役所 豊玉支所');
ok($zip->set_number('8171692')->is_valid_number, '対馬市 上県支所');
ok($zip->set_number('8171797')->is_valid_number, '航空自衛隊 第19警戒隊');
ok($zip->set_number('8178510')->is_valid_number, '対馬市役所');
ok($zip->set_number('8178517')->is_valid_number, '対馬いづはら病院');
ok($zip->set_number('8178520')->is_valid_number, '長崎県 対馬振興局');
ok($zip->set_number('8180192')->is_valid_number, '筑紫女学園大学 筑紫女学園短期大学');
ok($zip->set_number('8180193')->is_valid_number, '学校法人 九州学園 福岡女子短期大学');
ok($zip->set_number('8180194')->is_valid_number, '第一福祉大学');
ok($zip->set_number('8180195')->is_valid_number, '太宰府天満宮');
ok($zip->set_number('8180197')->is_valid_number, '日本経済大学・福岡こども短期大学');
ok($zip->set_number('8180198')->is_valid_number, '太宰府市役所');
ok($zip->set_number('8188501')->is_valid_number, '日本たばこ産業 株式会社 九州工場');
ok($zip->set_number('8188502')->is_valid_number, '福岡大学 筑紫病院');
ok($zip->set_number('8188503')->is_valid_number, '九州電力 株式会社 二日市営業所');
ok($zip->set_number('8188516')->is_valid_number, '福岡県済生会 二日市病院');
ok($zip->set_number('8188540')->is_valid_number, '福岡県 工業技術センター');
ok($zip->set_number('8188549')->is_valid_number, '福岡県 農業総合試験場');
ok($zip->set_number('8188555')->is_valid_number, '国際経営 株式会社');
ok($zip->set_number('8188567')->is_valid_number, '福岡法務局 筑紫支局');
ok($zip->set_number('8188571')->is_valid_number, '株式会社 イズミ ゆめタウン筑紫野');
ok($zip->set_number('8188577')->is_valid_number, '筑紫野市商工会');
ok($zip->set_number('8188578')->is_valid_number, '株式会社 ダイエー福岡プロセスセンター');
ok($zip->set_number('8188585')->is_valid_number, '九州産業大学付属 九州産業高等学校');
ok($zip->set_number('8188588')->is_valid_number, '福岡県 赤十字血液センター');
ok($zip->set_number('8188642')->is_valid_number, '筑紫農業協同組合 本店');
ok($zip->set_number('8188666')->is_valid_number, '筑紫税務署');
ok($zip->set_number('8188668')->is_valid_number, '株式会社 薬師堂');
ok($zip->set_number('8188686')->is_valid_number, '筑紫野市役所');
ok($zip->set_number('8190192')->is_valid_number, '三菱電機 株式会社 福岡事業所');
ok($zip->set_number('8190193')->is_valid_number, '株式会社 マルタイ');
ok($zip->set_number('8190395')->is_valid_number, '国立大学法人 九州大学');
ok($zip->set_number('8191192')->is_valid_number, '糸島市役所 本庁舎');
ok($zip->set_number('8191193')->is_valid_number, '糸島農業協同組合');
ok($zip->set_number('8191195')->is_valid_number, '九星飲料工業 株式会社');
ok($zip->set_number('8191392')->is_valid_number, '糸島市役所 志摩庁舎');
ok($zip->set_number('8191692')->is_valid_number, '糸島市役所 二丈庁舎');
ok($zip->set_number('8198501')->is_valid_number, '福岡市 西区役所');
ok($zip->set_number('8198502')->is_valid_number, '日本年金機構 西福岡年金事務所');
ok($zip->set_number('8198504')->is_valid_number, '九州電力 株式会社 福岡西営業所');
ok($zip->set_number('8198511')->is_valid_number, '社会医療法人財団 白十字会 白十字病院');
ok($zip->set_number('8198533')->is_valid_number, '医療法人 南川整形外科病院');
ok($zip->set_number('8198550')->is_valid_number, '社会福祉法人 博仁会 リハモール福岡');
ok($zip->set_number('8198551')->is_valid_number, '医療法人 博仁会 福岡リハビリテーション病院');
ok($zip->set_number('8198552')->is_valid_number, '福岡西公共職業安定所');
ok($zip->set_number('8198555')->is_valid_number, '医療法人 西福岡病院');
ok($zip->set_number('8198558')->is_valid_number, '西南自動車工業 株式会社');
ok($zip->set_number('8198585')->is_valid_number, '医療法人財団 華林会 村上華林堂病院');
ok($zip->set_number('8198611')->is_valid_number, '社会医療法人財団 白十字会 白十字リハビリテーション病院');
ok($zip->set_number('8200292')->is_valid_number, '嘉麻市役所 本庁');
ok($zip->set_number('8200392')->is_valid_number, '嘉麻市 嘉穂総合支所');
ok($zip->set_number('8200592')->is_valid_number, '嘉麻市役所 碓井庁舎');
ok($zip->set_number('8200693')->is_valid_number, '桂川町総合福祉センター 「ひまわりの里」');
ok($zip->set_number('8200696')->is_valid_number, '桂川町役場');
ok($zip->set_number('8200792')->is_valid_number, '飯塚市 筑穂支所');
ok($zip->set_number('8201192')->is_valid_number, '小竹町役場');
ok($zip->set_number('8201193')->is_valid_number, '飯塚市役所 頴田支所');
ok($zip->set_number('8208501')->is_valid_number, '飯塚市役所');
ok($zip->set_number('8208502')->is_valid_number, '九州工業大学 情報工学部');
ok($zip->set_number('8208505')->is_valid_number, '飯塚病院');
ok($zip->set_number('8208506')->is_valid_number, '福岡地方裁判所 飯塚支部');
ok($zip->set_number('8208507')->is_valid_number, '飯塚商工会議所');
ok($zip->set_number('8208508')->is_valid_number, '総合せき損センター');
ok($zip->set_number('8208510')->is_valid_number, '近畿大学附属 福岡高等学校');
ok($zip->set_number('8208512')->is_valid_number, '九州電力 株式会社 飯塚営業所');
ok($zip->set_number('8208513')->is_valid_number, '近畿大学 九州短期大学');
ok($zip->set_number('8208516')->is_valid_number, '株式会社 南風堂');
ok($zip->set_number('8208517')->is_valid_number, '財団法人 飯塚研究開発機構');
ok($zip->set_number('8208520')->is_valid_number, '株式会社 華三樂');
ok($zip->set_number('8208533')->is_valid_number, 'ミツミ電機 株式会社 九州事業所');
ok($zip->set_number('8208540')->is_valid_number, '飯塚公共職業安定所');
ok($zip->set_number('8208550')->is_valid_number, 'ケンコーコム 株式会社 福岡物流センター');
ok($zip->set_number('8208555')->is_valid_number, '近畿大学 産業理工学部');
ok($zip->set_number('8208601')->is_valid_number, '一番食品 株式会社');
ok($zip->set_number('8208602')->is_valid_number, '飯塚信用金庫');
ok($zip->set_number('8208603')->is_valid_number, '飯塚税務署');
ok($zip->set_number('8208605')->is_valid_number, '飯塚市役所 穂波支所');
ok($zip->set_number('8208607')->is_valid_number, '陸上自衛隊 飯塚駐屯地');
ok($zip->set_number('8218501')->is_valid_number, '嘉麻市 山田総合支所');
ok($zip->set_number('8221192')->is_valid_number, '株式会社 津田商事');
ok($zip->set_number('8221193')->is_valid_number, '福智町役場 赤池支所');
ok($zip->set_number('8221292')->is_valid_number, '福智町役場');
ok($zip->set_number('8221293')->is_valid_number, '福智町役場 方城支所');
ok($zip->set_number('8221296')->is_valid_number, 'マクセル 株式会社 九州事業所');
ok($zip->set_number('8221492')->is_valid_number, '香春町役場');
ok($zip->set_number('8228501')->is_valid_number, '直方市役所');
ok($zip->set_number('8228555')->is_valid_number, '日本年金機構 直方年金事務所');
ok($zip->set_number('8228585')->is_valid_number, '株式会社 もち吉');
ok($zip->set_number('8228666')->is_valid_number, '直方税務署');
ok($zip->set_number('8238555')->is_valid_number, '東芝LSIパッケージソリューション 株式会社');
ok($zip->set_number('8240192')->is_valid_number, 'みやこ町役場 豊津支所');
ok($zip->set_number('8240292')->is_valid_number, 'みやこ町役場 犀川支所');
ok($zip->set_number('8240892')->is_valid_number, 'みやこ町役場');
ok($zip->set_number('8248510')->is_valid_number, 'TOTOハイリビング 株式会社 行橋工場');
ok($zip->set_number('8248511')->is_valid_number, '株式会社 安川電機 行橋工場');
ok($zip->set_number('8248555')->is_valid_number, 'ローム・アポロ 株式会社(行橋工場)');
ok($zip->set_number('8248601')->is_valid_number, '行橋市役所');
ok($zip->set_number('8248611')->is_valid_number, '行橋税務署');
ok($zip->set_number('8258501')->is_valid_number, '田川市役所');
ok($zip->set_number('8258567')->is_valid_number, '田川市立病院');
ok($zip->set_number('8258577')->is_valid_number, '福岡県 田川保健福祉事務所');
ok($zip->set_number('8258585')->is_valid_number, '福岡県立大学');
ok($zip->set_number('8258588')->is_valid_number, '田川農業協同組合');
ok($zip->set_number('8258601')->is_valid_number, '田川税務署');
ok($zip->set_number('8268529')->is_valid_number, '九州電力 株式会社 田川営業所');
ok($zip->set_number('8268555')->is_valid_number, '松尾製菓 株式会社');
ok($zip->set_number('8268567')->is_valid_number, '福岡地方裁判所 田川支部');
ok($zip->set_number('8268585')->is_valid_number, '社会保険田川病院');
ok($zip->set_number('8268609')->is_valid_number, '田川公共職業安定所');
ok($zip->set_number('8278501')->is_valid_number, '川崎町役場');
ok($zip->set_number('8288501')->is_valid_number, '豊前市役所');
ok($zip->set_number('8290192')->is_valid_number, '築上町役場 築城支所');
ok($zip->set_number('8290392')->is_valid_number, '築上町役場');
ok($zip->set_number('8290393')->is_valid_number, '東九州コミュニティー放送 株式会社');
ok($zip->set_number('8300192')->is_valid_number, '久留米市 三潴総合支所');
ok($zip->set_number('8300292')->is_valid_number, '久留米市 城島総合支所');
ok($zip->set_number('8301192')->is_valid_number, '久留米市 北野総合支所');
ok($zip->set_number('8301193')->is_valid_number, 'トラスコ中山 (株) 久留米営業所');
ok($zip->set_number('8301195')->is_valid_number, '合名会社 山口酒造場');
ok($zip->set_number('8301196')->is_valid_number, '柏鉄工 株式会社');
ok($zip->set_number('8301298')->is_valid_number, '大刀洗町役場');
ok($zip->set_number('8306528')->is_valid_number, '航空自衛隊 高良台分屯基地');
ok($zip->set_number('8306587')->is_valid_number, '株式会社 原武商店');
ok($zip->set_number('8308501')->is_valid_number, '久留米社会保険事務所');
ok($zip->set_number('8308503')->is_valid_number, '株式会社 月刊くるめ');
ok($zip->set_number('8308505')->is_valid_number, '久留米公共職業安定所');
ok($zip->set_number('8308510')->is_valid_number, '株式会社 岩田屋三越 久留米店');
ok($zip->set_number('8308511')->is_valid_number, '大電 株式会社');
ok($zip->set_number('8308512')->is_valid_number, '福岡家庭裁判所 久留米支部');
ok($zip->set_number('8308515')->is_valid_number, '株式会社 ケンコントロールズ');
ok($zip->set_number('8308520')->is_valid_number, '久留米市役所');
ok($zip->set_number('8308521')->is_valid_number, '社会保険 久留米第一病院');
ok($zip->set_number('8308522')->is_valid_number, '医療法人 天神会 古賀クリニック');
ok($zip->set_number('8308530')->is_valid_number, '福岡地方裁判所 久留米支部');
ok($zip->set_number('8308533')->is_valid_number, '三洋信販 株式会社 久留米帳票チーム');
ok($zip->set_number('8308540')->is_valid_number, '住友生命保険 相互会社 久留米支社');
ok($zip->set_number('8308541')->is_valid_number, '株式会社 野田清商店');
ok($zip->set_number('8308543')->is_valid_number, '医療法人 雪ノ聖母会 聖マリア病院');
ok($zip->set_number('8308555')->is_valid_number, '国立 久留米工業高等専門学校');
ok($zip->set_number('8308558')->is_valid_number, '学校法人聖マリア学院');
ok($zip->set_number('8308567')->is_valid_number, '筑後川河川事務所');
ok($zip->set_number('8308570')->is_valid_number, '九州地方整備局 九州技術事務所');
ok($zip->set_number('8308577')->is_valid_number, '医療法人 天神会 新古賀病院');
ok($zip->set_number('8308585')->is_valid_number, 'NTTマーケティングアクト九州 久留米支店');
ok($zip->set_number('8308588')->is_valid_number, '有限会社 マルハ');
ok($zip->set_number('8308601')->is_valid_number, 'モデルクレジット 株式会社');
ok($zip->set_number('8308602')->is_valid_number, '株式会社 西日本シティ銀行 久留米営業部');
ok($zip->set_number('8308603')->is_valid_number, '株式会社 りそな銀行 久留米支店');
ok($zip->set_number('8308606')->is_valid_number, '喜多村石油 株式会社');
ok($zip->set_number('8308611')->is_valid_number, '株式会社 稲屋');
ok($zip->set_number('8308612')->is_valid_number, '久留米運送 株式会社');
ok($zip->set_number('8308622')->is_valid_number, '株式会社 ムーンスター');
ok($zip->set_number('8308629')->is_valid_number, 'アサヒシューズ 株式会社');
ok($zip->set_number('8308630')->is_valid_number, '株式会社 赤ちゃんの城');
ok($zip->set_number('8308631')->is_valid_number, '佐藤 株式会社');
ok($zip->set_number('8308666')->is_valid_number, '財団法人 簡易保険加入者協会 九州地方本部 久留米出張所');
ok($zip->set_number('8308667')->is_valid_number, '商工組合中央金庫 久留米支店');
ok($zip->set_number('8308668')->is_valid_number, '田中藍 株式会社');
ok($zip->set_number('8308677')->is_valid_number, '株式会社 筑邦銀行');
ok($zip->set_number('8308686')->is_valid_number, '日本生命保険 相互会社 久留米支社');
ok($zip->set_number('8308688')->is_valid_number, '久留米税務署');
ok($zip->set_number('8318501')->is_valid_number, '国際医療福祉大学 福岡大川キャンパス');
ok($zip->set_number('8318601')->is_valid_number, '大川市役所');
ok($zip->set_number('8318686')->is_valid_number, '大川税務署');
ok($zip->set_number('8328555')->is_valid_number, '柳川市役所 三橋庁舎');
ok($zip->set_number('8328601')->is_valid_number, '柳川市役所 柳川庁舎');
ok($zip->set_number('8338601')->is_valid_number, '筑後市役所');
ok($zip->set_number('8340192')->is_valid_number, '日之出紙器工業 株式会社');
ok($zip->set_number('8340193')->is_valid_number, '福岡八女農協 中広川支所');
ok($zip->set_number('8340194')->is_valid_number, 'マル厨工業 株式会社');
ok($zip->set_number('8340195')->is_valid_number, '株式会社 オーレック');
ok($zip->set_number('8340196')->is_valid_number, '株式会社 中島田鉄工所');
ok($zip->set_number('8340198')->is_valid_number, '久留米印刷 株式会社');
ok($zip->set_number('8340292')->is_valid_number, '八女市 星野支所');
ok($zip->set_number('8341292')->is_valid_number, '八女市 黒木総合支所');
ok($zip->set_number('8341492')->is_valid_number, '八女市 矢部支所');
ok($zip->set_number('8348555')->is_valid_number, '八女市 立花支所');
ok($zip->set_number('8348585')->is_valid_number, '八女市役所');
ok($zip->set_number('8350192')->is_valid_number, 'みやま市役所 山川支所');
ok($zip->set_number('8358501')->is_valid_number, '南筑後農業協同組合');
ok($zip->set_number('8358601')->is_valid_number, 'みやま市役所');
ok($zip->set_number('8368502')->is_valid_number, '大牟田労働基準監督署');
ok($zip->set_number('8368505')->is_valid_number, '帝京大学 福岡キャンパス');
ok($zip->set_number('8368510')->is_valid_number, '電気化学工業 株式会社 大牟田工場');
ok($zip->set_number('8368512')->is_valid_number, '株式会社 有明新報社');
ok($zip->set_number('8368531')->is_valid_number, '三池港物流 株式会社');
ok($zip->set_number('8368533')->is_valid_number, '大牟田柳川信用金庫');
ok($zip->set_number('8368566')->is_valid_number, '社会保険 大牟田天領病院');
ok($zip->set_number('8368567')->is_valid_number, '地方独立行政法人 大牟田市立病院');
ok($zip->set_number('8368577')->is_valid_number, '福岡県立三池工業高等学校');
ok($zip->set_number('8368585')->is_valid_number, '有明工業高等専門学校');
ok($zip->set_number('8368588')->is_valid_number, '株式会社 三井三池製作所 九州事業所');
ok($zip->set_number('8368610')->is_valid_number, '三井化学株式会社大牟田工場');
ok($zip->set_number('8368666')->is_valid_number, '大牟田市役所');
ok($zip->set_number('8368686')->is_valid_number, '大牟田税務署');
ok($zip->set_number('8378501')->is_valid_number, '親仁会 米の山病院');
ok($zip->set_number('8380193')->is_valid_number, '陸上自衛隊 小郡駐屯地');
ok($zip->set_number('8380197')->is_valid_number, '学校法人 平岡学園');
ok($zip->set_number('8380198')->is_valid_number, '小郡市役所');
ok($zip->set_number('8380298')->is_valid_number, '筑前町役場');
ok($zip->set_number('8381397')->is_valid_number, '朝倉地域生涯学習センター');
ok($zip->set_number('8381398')->is_valid_number, '朝倉地域行政センター');
ok($zip->set_number('8381592')->is_valid_number, '朝倉市 杷木地域行政センター');
ok($zip->set_number('8381692')->is_valid_number, '東峰村役場 小石原庁舎');
ok($zip->set_number('8381792')->is_valid_number, '東峰村役場 宝珠山庁舎');
ok($zip->set_number('8381793')->is_valid_number, '有限会社 カネダイ');
ok($zip->set_number('8388512')->is_valid_number, '合資会社 四ヶ所印刷所');
ok($zip->set_number('8388515')->is_valid_number, '朝倉公共職業安定所');
ok($zip->set_number('8388585')->is_valid_number, '筑前町役場 総合支所');
ok($zip->set_number('8388601')->is_valid_number, '朝倉市役所');
ok($zip->set_number('8388602')->is_valid_number, '筑前あさくら農業協同組合');
ok($zip->set_number('8388666')->is_valid_number, 'オーケー食品工業 株式会社');
ok($zip->set_number('8388677')->is_valid_number, '甘木税務署');
ok($zip->set_number('8388686')->is_valid_number, 'キリンビール 株式会社 福岡工場');
ok($zip->set_number('8390292')->is_valid_number, 'みやま市役所 高田支所');
ok($zip->set_number('8390293')->is_valid_number, '柳川市役所 大和庁舎');
ok($zip->set_number('8390295')->is_valid_number, '医療法人 弘恵会ヨコクラ病院');
ok($zip->set_number('8391298')->is_valid_number, '久留米市 田主丸 総合支所');
ok($zip->set_number('8391393')->is_valid_number, 'うきは市役所 吉井庁舎');
ok($zip->set_number('8391394')->is_valid_number, '合資会社 鳥志商店');
ok($zip->set_number('8391395')->is_valid_number, '株式会社 栗木商店');
ok($zip->set_number('8391396')->is_valid_number, '株式会社 筑水キャニコム');
ok($zip->set_number('8391493')->is_valid_number, 'にじ農業協同組合 御幸支所');
ok($zip->set_number('8391497')->is_valid_number, 'うきは市役所 浮羽庁舎');
ok($zip->set_number('8391498')->is_valid_number, '株式会社 ユニ・スター');
ok($zip->set_number('8398501')->is_valid_number, '久留米市企業局水道ガス部');
ok($zip->set_number('8398502')->is_valid_number, '久留米大学御井学舎');
ok($zip->set_number('8398505')->is_valid_number, '陸上自衛隊 幹部候補生学校');
ok($zip->set_number('8398506')->is_valid_number, '公益財団法人 福岡県すこやか健康事業団総合検診センター');
ok($zip->set_number('8398508')->is_valid_number, '学校法人 久留米信愛女学院');
ok($zip->set_number('8398540')->is_valid_number, 'コマツ西日本 株式会社');
ok($zip->set_number('8400292')->is_valid_number, '佐賀市 大和支所');
ok($zip->set_number('8400598')->is_valid_number, '佐賀市 富士支所');
ok($zip->set_number('8401192')->is_valid_number, 'みやき町役場 三根庁舎');
ok($zip->set_number('8402192')->is_valid_number, '佐賀市 諸富支所');
ok($zip->set_number('8402193')->is_valid_number, '味の素 株式会社 九州工場');
ok($zip->set_number('8402195')->is_valid_number, '医療法人社団 博文会 小柳記念病院');
ok($zip->set_number('8402197')->is_valid_number, 'ディープロ 株式会社');
ok($zip->set_number('8402295')->is_valid_number, '佐賀市 川副支所');
ok($zip->set_number('8408501')->is_valid_number, '佐賀市役所');
ok($zip->set_number('8408502')->is_valid_number, '佐賀大学');
ok($zip->set_number('8408508')->is_valid_number, '佐賀県酒造組合');
ok($zip->set_number('8408511')->is_valid_number, '株式会社 北島');
ok($zip->set_number('8408520')->is_valid_number, '株式会社 佐電工');
ok($zip->set_number('8408530')->is_valid_number, '佐賀南警察署');
ok($zip->set_number('8408540')->is_valid_number, '佐賀県 警察本部');
ok($zip->set_number('8408550')->is_valid_number, '学校法人 旭学園佐賀女子短期大学');
ok($zip->set_number('8408551')->is_valid_number, 'モラージュ佐賀');
ok($zip->set_number('8408552')->is_valid_number, '株式会社 九州西友 佐賀巨勢店');
ok($zip->set_number('8408555')->is_valid_number, '佐賀ダイハツ販売 株式会社');
ok($zip->set_number('8408558')->is_valid_number, '株式会社 サガテレビ');
ok($zip->set_number('8408560')->is_valid_number, '全国健康保険協会 佐賀支部');
ok($zip->set_number('8408570')->is_valid_number, '佐賀県庁');
ok($zip->set_number('8408571')->is_valid_number, '地方独立行政法人 佐賀県医療センター 好生館');
ok($zip->set_number('8408580')->is_valid_number, '株式会社 佐賀玉屋');
ok($zip->set_number('8408585')->is_valid_number, '佐賀新聞社');
ok($zip->set_number('8408588')->is_valid_number, '株式会社 中野建設');
ok($zip->set_number('8408601')->is_valid_number, '日本放送協会 佐賀放送局');
ok($zip->set_number('8408602')->is_valid_number, '株式会社 佐賀共栄銀行');
ok($zip->set_number('8408611')->is_valid_number, '佐賀税務署');
ok($zip->set_number('8408627')->is_valid_number, '株式会社 佐賀銀行');
ok($zip->set_number('8408666')->is_valid_number, '松尾建設 株式会社');
ok($zip->set_number('8408686')->is_valid_number, '株式会社 ミゾタ');
ok($zip->set_number('8408688')->is_valid_number, '佐賀商工会議所');
ok($zip->set_number('8408689')->is_valid_number, '佐賀県 信用保証協会');
ok($zip->set_number('8418501')->is_valid_number, 'パナソニックコミュニケーションズ 株式会社');
ok($zip->set_number('8418502')->is_valid_number, 'トラスコ中山 株式会社 プラネット九州');
ok($zip->set_number('8418503')->is_valid_number, '株式会社 アクティブトライ 鳥栖営業所');
ok($zip->set_number('8418504')->is_valid_number, '鳥栖プレミアム・アウトレット');
ok($zip->set_number('8418505')->is_valid_number, 'アマゾン 鳥栖FC 入庫係');
ok($zip->set_number('8418511')->is_valid_number, '鳥栖市役所');
ok($zip->set_number('8418585')->is_valid_number, 'アイリスオーヤマ (株) 鳥栖第二工場');
ok($zip->set_number('8418601')->is_valid_number, '鳥栖税務署');
ok($zip->set_number('8418602')->is_valid_number, '株式会社 ヨコオ');
ok($zip->set_number('8418611')->is_valid_number, '株式会社 森光商店');
ok($zip->set_number('8418686')->is_valid_number, '久光製薬 株式会社');
ok($zip->set_number('8420192')->is_valid_number, '独立行政法人 国立病院機構 肥前精神医療センター');
ok($zip->set_number('8420193')->is_valid_number, '吉野ヶ里町役場 東脊振庁舎');
ok($zip->set_number('8420195')->is_valid_number, '大塚製薬 株式会社 佐賀栄養製品研究所');
ok($zip->set_number('8420197')->is_valid_number, '大塚製薬 株式会社 佐賀工場');
ok($zip->set_number('8420292')->is_valid_number, '神埼市 脊振総合支所');
ok($zip->set_number('8420293')->is_valid_number, '航空自衛隊 脊振山分屯基地');
ok($zip->set_number('8428501')->is_valid_number, '吉野ヶ里町役場');
ok($zip->set_number('8428502')->is_valid_number, '神埼市 千代田総合支所');
ok($zip->set_number('8428585')->is_valid_number, '西九州大学');
ok($zip->set_number('8428601')->is_valid_number, '神埼市役所');
ok($zip->set_number('8430392')->is_valid_number, '嬉野市役所 嬉野総合支所');
ok($zip->set_number('8430393')->is_valid_number, '独立行政法人 国立病院機構 嬉野医療センター');
ok($zip->set_number('8430394')->is_valid_number, '医療法人財団 友朋会');
ok($zip->set_number('8438501')->is_valid_number, '医療法人 雄邦会介護老人保健施設 たんぽぽ');
ok($zip->set_number('8438550')->is_valid_number, '株式会社 オサダ');
ok($zip->set_number('8438555')->is_valid_number, '九州電力 株式会社 武雄営業所');
ok($zip->set_number('8438585')->is_valid_number, '株式会社 デュエル');
ok($zip->set_number('8438588')->is_valid_number, '武雄社会保険事務所');
ok($zip->set_number('8438639')->is_valid_number, '武雄市役所');
ok($zip->set_number('8438686')->is_valid_number, '武雄税務署');
ok($zip->set_number('8448501')->is_valid_number, '有限会社 瑞祥');
ok($zip->set_number('8448555')->is_valid_number, '岩尾磁器工業 株式会社');
ok($zip->set_number('8448585')->is_valid_number, '佐賀県立九州陶磁文化館');
ok($zip->set_number('8448601')->is_valid_number, '株式会社 香蘭社');
ok($zip->set_number('8448602')->is_valid_number, '深川製磁 株式会社');
ok($zip->set_number('8448616')->is_valid_number, '株式会社 賞美堂 本店');
ok($zip->set_number('8448625')->is_valid_number, '株式会社 銘品堂');
ok($zip->set_number('8458501')->is_valid_number, '小城市役所 小城庁舎');
ok($zip->set_number('8458510')->is_valid_number, '竹下製菓 株式会社');
ok($zip->set_number('8458511')->is_valid_number, '小城市役所 三日月庁舎');
ok($zip->set_number('8468501')->is_valid_number, '多久市役所');
ok($zip->set_number('8470192')->is_valid_number, '金子産業 株式会社');
ok($zip->set_number('8470193')->is_valid_number, '天生水産 株式会社');
ok($zip->set_number('8470392')->is_valid_number, '唐津市 呼子支所');
ok($zip->set_number('8470393')->is_valid_number, '唐津農業協同組合 上場地区営農本部');
ok($zip->set_number('8471292')->is_valid_number, '唐津市役所 北波多支所');
ok($zip->set_number('8478511')->is_valid_number, '唐津市役所');
ok($zip->set_number('8478555')->is_valid_number, 'シフトプラス 株式会社 佐賀営業所');
ok($zip->set_number('8478588')->is_valid_number, '日本赤十字社 唐津赤十字病院');
ok($zip->set_number('8478601')->is_valid_number, '唐津税務署');
ok($zip->set_number('8480492')->is_valid_number, '松浦市役所 福島支所');
ok($zip->set_number('8488501')->is_valid_number, '伊万里市役所');
ok($zip->set_number('8490592')->is_valid_number, '江北町役場');
ok($zip->set_number('8490597')->is_valid_number, '三菱住友シリコン 株式会社');
ok($zip->set_number('8491192')->is_valid_number, '白石町役場 白石支所');
ok($zip->set_number('8491392')->is_valid_number, '医療法人 祐愛会 織田病院');
ok($zip->set_number('8491393')->is_valid_number, '祐徳薬品工業 株式会社');
ok($zip->set_number('8491394')->is_valid_number, '祐徳稲荷神社');
ok($zip->set_number('8491492')->is_valid_number, '嬉野市役所');
ok($zip->set_number('8491698')->is_valid_number, '太良町役場');
ok($zip->set_number('8492392')->is_valid_number, '九州製鋼 株式会社 佐賀工場');
ok($zip->set_number('8492393')->is_valid_number, '武雄市役所 山内支所');
ok($zip->set_number('8492395')->is_valid_number, '清本鉄工 株式会社 佐賀支社');
ok($zip->set_number('8493192')->is_valid_number, '唐津市役所 厳木支所');
ok($zip->set_number('8493193')->is_valid_number, '佐賀県立 厳木高等学校');
ok($zip->set_number('8493292')->is_valid_number, '唐津市役所 相知支所');
ok($zip->set_number('8493293')->is_valid_number, '佐賀松浦 農業協同組合');
ok($zip->set_number('8494192')->is_valid_number, '有田町庁舎');
ok($zip->set_number('8494193')->is_valid_number, '伊万里有田共立病院');
ok($zip->set_number('8494194')->is_valid_number, '深川製磁 株式会社 営業本部 西有田工場');
ok($zip->set_number('8494195')->is_valid_number, '深川製磁 株式会社 チャイナ・オン・ザ・パーク');
ok($zip->set_number('8495192')->is_valid_number, '唐津市役所 浜玉支所');
ok($zip->set_number('8495193')->is_valid_number, '唐津農業共同組合');
ok($zip->set_number('8495198')->is_valid_number, '株式会社 吉森');
ok($zip->set_number('8498501')->is_valid_number, '佐賀大学 医学部');
ok($zip->set_number('8498502')->is_valid_number, '佐賀北警察署');
ok($zip->set_number('8498503')->is_valid_number, '佐賀社会保険事務所');
ok($zip->set_number('8498514')->is_valid_number, '佐賀県医師会');
ok($zip->set_number('8498522')->is_valid_number, '社団法人 全国社会保険協会連合会 佐賀社会保険病院');
ok($zip->set_number('8498555')->is_valid_number, '佐賀県税事務所');
ok($zip->set_number('8498558')->is_valid_number, '佐賀市水道局');
ok($zip->set_number('8498577')->is_valid_number, '独立行政法人 国立病院機構 佐賀病院');
ok($zip->set_number('8498585')->is_valid_number, '佐賀県 佐賀中部保健所');
ok($zip->set_number('8498588')->is_valid_number, '株式会社 鈴花');
ok($zip->set_number('8508501')->is_valid_number, '長崎自動車 株式会社');
ok($zip->set_number('8508503')->is_valid_number, '長崎地方裁判所');
ok($zip->set_number('8508504')->is_valid_number, '株式会社 長崎国際テレビ');
ok($zip->set_number('8508505')->is_valid_number, '株式会社 東美');
ok($zip->set_number('8508506')->is_valid_number, '長崎大学 経済学部');
ok($zip->set_number('8508507')->is_valid_number, '長崎地方法務局');
ok($zip->set_number('8508508')->is_valid_number, '株式会社 丸本');
ok($zip->set_number('8508510')->is_valid_number, '株式会社 浜屋百貨店');
ok($zip->set_number('8508511')->is_valid_number, '一般社団法人 長崎市医師会');
ok($zip->set_number('8508512')->is_valid_number, '長崎女子短期大学');
ok($zip->set_number('8508515')->is_valid_number, '学校法人 活水学院');
ok($zip->set_number('8508518')->is_valid_number, '住友生命保険 相互会社 長崎支社');
ok($zip->set_number('8508520')->is_valid_number, '三菱商事 株式会社 長崎支店');
ok($zip->set_number('8508521')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('8508522')->is_valid_number, '有限会社 ザ・ながさき');
ok($zip->set_number('8508523')->is_valid_number, '国立療養所 長崎病院');
ok($zip->set_number('8508525')->is_valid_number, 'ジブラルタ生命保険 株式会社');
ok($zip->set_number('8508530')->is_valid_number, '株式会社 タナカヤ');
ok($zip->set_number('8508531')->is_valid_number, '長崎船用品 株式会社');
ok($zip->set_number('8508536')->is_valid_number, '東洋漁業 株式会社');
ok($zip->set_number('8508537')->is_valid_number, '全国健康保険協会 長崎支部');
ok($zip->set_number('8508540')->is_valid_number, 'メットライフ生命保険 株式会社');
ok($zip->set_number('8508541')->is_valid_number, '長崎商工会議所');
ok($zip->set_number('8508543')->is_valid_number, '東京海上日動火災保険 株式会社 長崎支店');
ok($zip->set_number('8508545')->is_valid_number, '株式会社 長崎県酒販');
ok($zip->set_number('8508547')->is_valid_number, '長崎県 信用保証協会');
ok($zip->set_number('8508548')->is_valid_number, '長崎県 警察本部');
ok($zip->set_number('8508550')->is_valid_number, '株式会社 エフエム長崎');
ok($zip->set_number('8508551')->is_valid_number, '株式会社 テレビ長崎');
ok($zip->set_number('8508555')->is_valid_number, '長崎市立市民病院');
ok($zip->set_number('8508558')->is_valid_number, '松藤商事 株式会社');
ok($zip->set_number('8508560')->is_valid_number, '長崎地方検察庁');
ok($zip->set_number('8508563')->is_valid_number, '長崎市上下水道局');
ok($zip->set_number('8508566')->is_valid_number, '一般財団法人 長崎県教職員互助組合');
ok($zip->set_number('8508567')->is_valid_number, '安達 株式会社');
ok($zip->set_number('8508570')->is_valid_number, '長崎県庁');
ok($zip->set_number('8508575')->is_valid_number, '日本赤十字社 長崎県支部');
ok($zip->set_number('8508577')->is_valid_number, '株式会社 佐世保玉屋 長崎支店');
ok($zip->set_number('8508580')->is_valid_number, '株式会社 博多大丸 長崎店');
ok($zip->set_number('8508585')->is_valid_number, 'ひぐち企業グループ');
ok($zip->set_number('8508586')->is_valid_number, '学校法人 海星学園 海星中学校・海星高等学校');
ok($zip->set_number('8508588')->is_valid_number, '日昇観光 株式会社');
ok($zip->set_number('8508602')->is_valid_number, '株式会社 橋本商会');
ok($zip->set_number('8508603')->is_valid_number, 'NHK 長崎放送局');
ok($zip->set_number('8508606')->is_valid_number, '第一生命保険 株式会社 長崎支社');
ok($zip->set_number('8508610')->is_valid_number, '三菱重工業 株式会社 長崎造船所');
ok($zip->set_number('8508611')->is_valid_number, '株式会社 エヌ・ティ・ティ・マーケティングアクト九州');
ok($zip->set_number('8508618')->is_valid_number, '株式会社 十八銀行');
ok($zip->set_number('8508622')->is_valid_number, '日本通運 株式会社 長崎支店');
ok($zip->set_number('8508645')->is_valid_number, '日本銀行 長崎支店');
ok($zip->set_number('8508650')->is_valid_number, '長崎放送 株式会社');
ok($zip->set_number('8508662')->is_valid_number, '日本生命保険 相互会社 長崎支社');
ok($zip->set_number('8508666')->is_valid_number, '株式会社 長崎銀行');
ok($zip->set_number('8508668')->is_valid_number, '長崎運送 株式会社');
ok($zip->set_number('8508677')->is_valid_number, '西日本菱重興産 株式会社');
ok($zip->set_number('8508678')->is_valid_number, '長崎税務署');
ok($zip->set_number('8508685')->is_valid_number, '長崎市役所');
ok($zip->set_number('8508686')->is_valid_number, '長崎県 漁業協同組合連合会');
ok($zip->set_number('8508687')->is_valid_number, '株式会社 親和銀行 長崎支店');
ok($zip->set_number('8508688')->is_valid_number, '株式会社 テレビ長崎');
ok($zip->set_number('8510193')->is_valid_number, '学校法人 長崎総合科学大学');
ok($zip->set_number('8510195')->is_valid_number, '藤村薬品 株式会社');
ok($zip->set_number('8510198')->is_valid_number, '株式会社 たらみ');
ok($zip->set_number('8510392')->is_valid_number, '三菱重工業 株式会社 技術本部長崎研究所');
ok($zip->set_number('8510395')->is_valid_number, '長崎市役所 香焼行政センター');
ok($zip->set_number('8510492')->is_valid_number, '医療法人 共生会 長崎友愛病院');
ok($zip->set_number('8510493')->is_valid_number, '医療法人 清潮会 老人保健施設 みどりの里');
ok($zip->set_number('8510494')->is_valid_number, '医療法人 清潮会 三和病院');
ok($zip->set_number('8510497')->is_valid_number, '三和みのり園');
ok($zip->set_number('8510498')->is_valid_number, '長崎市役所 三和行政センター');
ok($zip->set_number('8510592')->is_valid_number, '長崎市役所 野母崎行政センター');
ok($zip->set_number('8512185')->is_valid_number, '長与町役場');
ok($zip->set_number('8512195')->is_valid_number, '県立 長崎シーボルト大学');
ok($zip->set_number('8512196')->is_valid_number, '長崎外国語大学');
ok($zip->set_number('8512197')->is_valid_number, '学校法人 青雲学園(青雲高等学校.青雲中学校)');
ok($zip->set_number('8512198')->is_valid_number, '時津町役場');
ok($zip->set_number('8512292')->is_valid_number, '長崎魚市 株式会社');
ok($zip->set_number('8512298')->is_valid_number, '株式会社 ヤマス');
ok($zip->set_number('8512492')->is_valid_number, '長崎市役所 外海行政センター');
ok($zip->set_number('8513292')->is_valid_number, '長崎市役所 琴海行政センター');
ok($zip->set_number('8513392')->is_valid_number, '西海市役所 西彼総合支所');
ok($zip->set_number('8513394')->is_valid_number, '宗教法人 「生長の家」総本山');
ok($zip->set_number('8513592')->is_valid_number, '西海市役所 西海総合支所');
ok($zip->set_number('8528501')->is_valid_number, '長崎大学医学部附属病院');
ok($zip->set_number('8528507')->is_valid_number, '九州電力 株式会社 長崎お客様センター');
ok($zip->set_number('8528508')->is_valid_number, '九州電力送配電 株式会社 長崎支社');
ok($zip->set_number('8528509')->is_valid_number, '九州電力 株式会社 長崎支社');
ok($zip->set_number('8528510')->is_valid_number, '九州電力 株式会社 長崎営業所');
ok($zip->set_number('8528511')->is_valid_number, '日本赤十字社 長崎原爆病院');
ok($zip->set_number('8528515')->is_valid_number, '純心女子高等学校');
ok($zip->set_number('8528520')->is_valid_number, '長崎大学医療技術短期大学部');
ok($zip->set_number('8528521')->is_valid_number, '長崎大学');
ok($zip->set_number('8528522')->is_valid_number, '長崎公共職業安定所');
ok($zip->set_number('8528523')->is_valid_number, '長崎大学 医学部');
ok($zip->set_number('8528527')->is_valid_number, '長崎文化放送 株式会社');
ok($zip->set_number('8528528')->is_valid_number, '株式会社 ジョイフルサンショッピングプラザ');
ok($zip->set_number('8528532')->is_valid_number, '長崎県 医師会');
ok($zip->set_number('8528542')->is_valid_number, '長崎労働基準監督署');
ok($zip->set_number('8528544')->is_valid_number, '学校法人 長崎南山学園');
ok($zip->set_number('8528555')->is_valid_number, '長崎県 社会福祉協議会');
ok($zip->set_number('8528558')->is_valid_number, '長崎純心大学');
ok($zip->set_number('8528566')->is_valid_number, '活水中学校・高等学校');
ok($zip->set_number('8528577')->is_valid_number, '株式会社 西友 道の尾店');
ok($zip->set_number('8528588')->is_valid_number, '長崎大学歯学部・長崎大学歯学部附属病院');
ok($zip->set_number('8528601')->is_valid_number, '株式会社 長崎新聞社');
ok($zip->set_number('8528794')->is_valid_number, '長崎事務所');
ok($zip->set_number('8530692')->is_valid_number, '五島市 三井楽支所');
ok($zip->set_number('8532292')->is_valid_number, '五島市 奈留支所');
ok($zip->set_number('8532392')->is_valid_number, '新上五島町役場 若松支所');
ok($zip->set_number('8538501')->is_valid_number, '五島市役所');
ok($zip->set_number('8538502')->is_valid_number, '長崎県 五島支庁');
ok($zip->set_number('8538601')->is_valid_number, '長崎県立 五島高等学校');
ok($zip->set_number('8540292')->is_valid_number, '諫早市役所 森山支所');
ok($zip->set_number('8540492')->is_valid_number, '雲仙市 千々石総合支所');
ok($zip->set_number('8540592')->is_valid_number, '雲仙市 小浜総合支所');
ok($zip->set_number('8540593')->is_valid_number, '公立 新小浜病院');
ok($zip->set_number('8540595')->is_valid_number, '長崎県立 小浜高等学校');
ok($zip->set_number('8540692')->is_valid_number, '株式会社 宮崎旅館');
ok($zip->set_number('8540696')->is_valid_number, '有限会社 雲仙富貴屋');
ok($zip->set_number('8540697')->is_valid_number, '有限会社 雲仙九州ホテル');
ok($zip->set_number('8540698')->is_valid_number, '株式会社 東洋館');
ok($zip->set_number('8548501')->is_valid_number, '健康保険 諫早総合病院');
ok($zip->set_number('8548509')->is_valid_number, '九州電力 株式会社 諫早営業所');
ok($zip->set_number('8548540')->is_valid_number, '諫早社会保険事務所');
ok($zip->set_number('8548555')->is_valid_number, '株式会社 日本ベネックス');
ok($zip->set_number('8548601')->is_valid_number, '諫早市役所');
ok($zip->set_number('8548650')->is_valid_number, '長崎刑務所');
ok($zip->set_number('8548666')->is_valid_number, '諫早税務署');
ok($zip->set_number('8558501')->is_valid_number, '長崎県島原振興局');
ok($zip->set_number('8558550')->is_valid_number, '島原商工会議所');
ok($zip->set_number('8558555')->is_valid_number, '島原市役所');
ok($zip->set_number('8558686')->is_valid_number, '島原税務署');
ok($zip->set_number('8568516')->is_valid_number, '陸上自衛隊 大村駐屯地');
ok($zip->set_number('8568555')->is_valid_number, 'SUMCO TECHXIV 株式会社 長崎工場');
ok($zip->set_number('8568560')->is_valid_number, '株式会社 大村浜屋');
ok($zip->set_number('8568561')->is_valid_number, '社団法人 地域医療振興協会 市立大村市民病院');
ok($zip->set_number('8568562')->is_valid_number, '独立行政法人 国立病院機構 長崎医療センター');
ok($zip->set_number('8568568')->is_valid_number, '貞松病院');
ok($zip->set_number('8568577')->is_valid_number, '九州教具 株式会社');
ok($zip->set_number('8568585')->is_valid_number, '海上自衛隊 大村航空基地');
ok($zip->set_number('8568601')->is_valid_number, '大村商工会議所');
ok($zip->set_number('8568609')->is_valid_number, '大村公共職業安定所');
ok($zip->set_number('8568670')->is_valid_number, '大村市 農業協同組合');
ok($zip->set_number('8568686')->is_valid_number, '大村市役所');
ok($zip->set_number('8570192')->is_valid_number, '東七 株式会社');
ok($zip->set_number('8570392')->is_valid_number, '佐々町役場');
ok($zip->set_number('8570492')->is_valid_number, '小佐々行政センター');
ok($zip->set_number('8571192')->is_valid_number, '協和商工 株式会社');
ok($zip->set_number('8571193')->is_valid_number, '佐世保工業高等専門学校');
ok($zip->set_number('8571194')->is_valid_number, '陸上自衛隊 崎辺分屯地');
ok($zip->set_number('8571195')->is_valid_number, '医療法人 白十字会');
ok($zip->set_number('8571197')->is_valid_number, '株式会社 ジャパネットたかた');
ok($zip->set_number('8571198')->is_valid_number, '株式会社 エレナ');
ok($zip->set_number('8572392')->is_valid_number, '西海市役所');
ok($zip->set_number('8572492')->is_valid_number, '西海市役所 大島総合支所');
ok($zip->set_number('8572494')->is_valid_number, '株式会社 大島造船所');
ok($zip->set_number('8574495')->is_valid_number, '新上五島町役場');
ok($zip->set_number('8574592')->is_valid_number, '新上五島町役場 新魚目支所');
ok($zip->set_number('8578501')->is_valid_number, '佐世保重工業株式会社 佐世保造船所');
ok($zip->set_number('8578502')->is_valid_number, '長崎県県北振興局');
ok($zip->set_number('8578503')->is_valid_number, 'ながさき西海 農業協同組合');
ok($zip->set_number('8578508')->is_valid_number, '玉屋商事 株式会社');
ok($zip->set_number('8578510')->is_valid_number, '株式会社 西沢本店');
ok($zip->set_number('8578511')->is_valid_number, '地方独立行政法人 佐世保市総合医療センター');
ok($zip->set_number('8578533')->is_valid_number, '山下医科器械 株式会社');
ok($zip->set_number('8578558')->is_valid_number, '九州電力 株式会社 佐世保営業所');
ok($zip->set_number('8578566')->is_valid_number, '九州テレ・コミュニケーションズ 株式会社 テレビ佐世保');
ok($zip->set_number('8578575')->is_valid_number, '佐世保共済病院');
ok($zip->set_number('8578577')->is_valid_number, '佐世保商工会議所');
ok($zip->set_number('8578585')->is_valid_number, '佐世保市役所');
ok($zip->set_number('8578588')->is_valid_number, '株式会社 佐世保玉屋');
ok($zip->set_number('8578611')->is_valid_number, '佐世保税務署');
ok($zip->set_number('8578666')->is_valid_number, '株式会社 親和銀行');
ok($zip->set_number('8578686')->is_valid_number, '商工組合中央金庫 佐世保支店');
ok($zip->set_number('8588501')->is_valid_number, '株式会社 相浦機械');
ok($zip->set_number('8588555')->is_valid_number, '陸上自衛隊 相浦駐屯地');
ok($zip->set_number('8588580')->is_valid_number, '長崎県立大学');
ok($zip->set_number('8588585')->is_valid_number, '九州電力 株式会社 相浦発電所');
ok($zip->set_number('8588588')->is_valid_number, '佐世保実業高等学校');
ok($zip->set_number('8588589')->is_valid_number, '株式会社 九十九島観光ホテル');
ok($zip->set_number('8590192')->is_valid_number, '諫早市役所 高来支所');
ok($zip->set_number('8590193')->is_valid_number, '社会福祉法人 聖家族会 みさかえの園');
ok($zip->set_number('8590492')->is_valid_number, '長崎県 学校生活協同組合');
ok($zip->set_number('8590495')->is_valid_number, '諫早市役所 多良見支所');
ok($zip->set_number('8590497')->is_valid_number, '日本赤十字社 長崎原爆 諫早病院');
ok($zip->set_number('8590498')->is_valid_number, '加藤産業 株式会社 長崎支店');
ok($zip->set_number('8591292')->is_valid_number, '雲仙市 瑞穂総合支所');
ok($zip->set_number('8591392')->is_valid_number, '雲仙市 国見総合支所');
ok($zip->set_number('8591492')->is_valid_number, '島原市役所 有明支所');
ok($zip->set_number('8591592')->is_valid_number, '日本トータルテレマーケティング 株式会社');
ok($zip->set_number('8593292')->is_valid_number, 'ハウステンボス 株式会社');
ok($zip->set_number('8593293')->is_valid_number, 'ハウステンボス 株式会社 ホテル本部');
ok($zip->set_number('8593298')->is_valid_number, '長崎国際大学');
ok($zip->set_number('8593692')->is_valid_number, '川棚町役場');
ok($zip->set_number('8593792')->is_valid_number, '西日本陶器 株式会社');
ok($zip->set_number('8593793')->is_valid_number, '長崎キヤノン 株式会社');
ok($zip->set_number('8593797')->is_valid_number, '長崎県立 波佐見高等学校');
ok($zip->set_number('8593798')->is_valid_number, '西海陶器 株式会社');
ok($zip->set_number('8594595')->is_valid_number, '電源開発 株式会社 松浦火力発電所');
ok($zip->set_number('8594596')->is_valid_number, '九州電力 株式会社 松浦発電所');
ok($zip->set_number('8594597')->is_valid_number, 'ながさき西海 農業協同組合 松浦営農経済センター');
ok($zip->set_number('8594598')->is_valid_number, '松浦市役所');
ok($zip->set_number('8594892')->is_valid_number, '平戸市役所 田平支所');
ok($zip->set_number('8595192')->is_valid_number, '平戸市役所');
ok($zip->set_number('8595392')->is_valid_number, '長崎県立 平戸高等学校');
ok($zip->set_number('8595393')->is_valid_number, '国民健康保険 平戸市民病院');
ok($zip->set_number('8596292')->is_valid_number, '佐世保市役所 鹿町行政センター');
ok($zip->set_number('8596492')->is_valid_number, '佐世保市役所 世知原行政センター');
ok($zip->set_number('8608501')->is_valid_number, '株式会社 熊本銀行 中央支店');
ok($zip->set_number('8608502')->is_valid_number, '全国健康保険協会 熊本支部');
ok($zip->set_number('8608503')->is_valid_number, '熊本市農業協同組合');
ok($zip->set_number('8608504')->is_valid_number, 'テルウェル西日本 (株) 九州支店 中九州営業支店');
ok($zip->set_number('8608505')->is_valid_number, '日本郵政スタッフ 株式会社');
ok($zip->set_number('8608506')->is_valid_number, '株式会社 熊本日日新聞社');
ok($zip->set_number('8608507')->is_valid_number, '熊本酒井物産 株式会社 熊本営業所');
ok($zip->set_number('8608508')->is_valid_number, '金剛 株式会社');
ok($zip->set_number('8608509')->is_valid_number, '株式会社 紙弘');
ok($zip->set_number('8608510')->is_valid_number, '富士通 株式会社 熊本支店');
ok($zip->set_number('8608511')->is_valid_number, '株式会社 熊本リビング新聞社');
ok($zip->set_number('8608512')->is_valid_number, '楽天KC 株式会社 熊本支店');
ok($zip->set_number('8608513')->is_valid_number, '熊本地方裁判所');
ok($zip->set_number('8608514')->is_valid_number, '熊本労働局');
ok($zip->set_number('8608515')->is_valid_number, '医療法人 金澤会 青磁野リハビリテーション病院');
ok($zip->set_number('8608516')->is_valid_number, '熊本朝日放送 株式会社');
ok($zip->set_number('8608517')->is_valid_number, 'ホテルメルパルク熊本');
ok($zip->set_number('8608518')->is_valid_number, '社会医療法人 寿量会(熊本機能病院/介護老人保健施設 清雅苑/熊本健康・体力づくりセンター)');
ok($zip->set_number('8608519')->is_valid_number, 'NTT西日本 熊本支店');
ok($zip->set_number('8608520')->is_valid_number, '学校法人 九州ルーテル学院');
ok($zip->set_number('8608521')->is_valid_number, '鶴原吉井 株式会社');
ok($zip->set_number('8608522')->is_valid_number, '株式会社 熊本県民テレビ');
ok($zip->set_number('8608523')->is_valid_number, '株式会社 レイメイ藤井');
ok($zip->set_number('8608524')->is_valid_number, '公益財団法人 日本無線協会 九州支部');
ok($zip->set_number('8608525')->is_valid_number, '株式会社 アステム 熊本営業部');
ok($zip->set_number('8608526')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('8608527')->is_valid_number, '九州農政局');
ok($zip->set_number('8608528')->is_valid_number, '熊本県 経済農業協同組合連合会');
ok($zip->set_number('8608530')->is_valid_number, 'サンリブシティくまなん');
ok($zip->set_number('8608531')->is_valid_number, '熊本簡易裁判所');
ok($zip->set_number('8608533')->is_valid_number, '熊本県社会保険診療報酬支払基金');
ok($zip->set_number('8608534')->is_valid_number, '熊本西年金事務所');
ok($zip->set_number('8608536')->is_valid_number, '株式会社 熊日会館');
ok($zip->set_number('8608539')->is_valid_number, '株式会社 トリニティ');
ok($zip->set_number('8608540')->is_valid_number, 'コマツ西日本 株式会社');
ok($zip->set_number('8608541')->is_valid_number, '株式会社 帝国データバンク 熊本支店');
ok($zip->set_number('8608543')->is_valid_number, 'NTTファイナンス 株式会社 南九州支店');
ok($zip->set_number('8608545')->is_valid_number, '株式会社 ユニマットライフ ユニマットレディス 熊本店');
ok($zip->set_number('8608547')->is_valid_number, '熊本商工会議所');
ok($zip->set_number('8608550')->is_valid_number, '木村医療器 株式会社');
ok($zip->set_number('8608551')->is_valid_number, '熊本県信用保証協会');
ok($zip->set_number('8608552')->is_valid_number, 'くまもと経済');
ok($zip->set_number('8608554')->is_valid_number, 'くまもと県民交流館 パレア');
ok($zip->set_number('8608555')->is_valid_number, '熊本大学');
ok($zip->set_number('8608556')->is_valid_number, '熊本大学医学部附属病院');
ok($zip->set_number('8608557')->is_valid_number, '学校法人 熊本信愛女学院');
ok($zip->set_number('8608558')->is_valid_number, '学校法人 加寿美学園 熊本中央高等学校');
ok($zip->set_number('8608565')->is_valid_number, '株式会社 熊本ホテルキャッスル');
ok($zip->set_number('8608566')->is_valid_number, '九州電力 株式会社 熊本西営業所');
ok($zip->set_number('8608567')->is_valid_number, '株式会社 セルモ');
ok($zip->set_number('8608568')->is_valid_number, 'KMバイオロジクス 株式会社');
ok($zip->set_number('8608570')->is_valid_number, '熊本県熊本総合庁舎');
ok($zip->set_number('8608575')->is_valid_number, '株式会社 ニュースカイホテル');
ok($zip->set_number('8608577')->is_valid_number, '熊本交通センター');
ok($zip->set_number('8608580')->is_valid_number, '株式会社 八尾日進堂');
ok($zip->set_number('8608581')->is_valid_number, '日清医療食品 株式会社 南九州支店');
ok($zip->set_number('8608584')->is_valid_number, '株式会社 パルコ');
ok($zip->set_number('8608585')->is_valid_number, '九州財務局');
ok($zip->set_number('8608586')->is_valid_number, '株式会社 鶴屋百貨店');
ok($zip->set_number('8608587')->is_valid_number, '住友生命保険 相互会社 熊本支社');
ok($zip->set_number('8608588')->is_valid_number, '株式会社 カリーノ');
ok($zip->set_number('8608601')->is_valid_number, '熊本市役所');
ok($zip->set_number('8608602')->is_valid_number, '日本放送協会 熊本放送局');
ok($zip->set_number('8608603')->is_valid_number, '熊本国税局');
ok($zip->set_number('8608604')->is_valid_number, '野村證券 株式会社 熊本支店');
ok($zip->set_number('8608605')->is_valid_number, '日本生命保険 相互会社 熊本支社');
ok($zip->set_number('8608606')->is_valid_number, '株式会社 福岡銀行 熊本支店');
ok($zip->set_number('8608608')->is_valid_number, '株式会社 古荘本店');
ok($zip->set_number('8608611')->is_valid_number, '株式会社 熊本放送');
ok($zip->set_number('8608615')->is_valid_number, '株式会社 肥後銀行');
ok($zip->set_number('8608618')->is_valid_number, '中央区役所');
ok($zip->set_number('8608619')->is_valid_number, '株式会社 九州しんきんクレジットサービス');
ok($zip->set_number('8608622')->is_valid_number, '株式会社 エヌシーくまもと');
ok($zip->set_number('8608624')->is_valid_number, '熊本西税務署');
ok($zip->set_number('8608625')->is_valid_number, '熊本製粉 株式会社');
ok($zip->set_number('8608650')->is_valid_number, '財団法人 簡易保険加入者協会 九州地方本部');
ok($zip->set_number('8608655')->is_valid_number, '熊本信用金庫');
ok($zip->set_number('8608660')->is_valid_number, '商工組合中央金庫 熊本支店');
ok($zip->set_number('8608668')->is_valid_number, '株式会社 県民百貨店');
ok($zip->set_number('8608681')->is_valid_number, '熊本第一信用金庫');
ok($zip->set_number('8608686')->is_valid_number, '株式会社 日専連ファイナンス');
ok($zip->set_number('8608688')->is_valid_number, '大和証券 株式会社 熊本支店');
ok($zip->set_number('8608739')->is_valid_number, '熊本YMCA');
ok($zip->set_number('8608792')->is_valid_number, '九州物流センター');
ok($zip->set_number('8608795')->is_valid_number, '総務省 九州総合通信局');
ok($zip->set_number('8608796')->is_valid_number, '熊本監査室');
ok($zip->set_number('8608797')->is_valid_number, '株式会社 ゆうちょ銀行 熊本支店');
ok($zip->set_number('8608797')->is_valid_number, '株式会社 かんぽ生命 熊本支店');
ok($zip->set_number('8608797')->is_valid_number, '日本郵便 株式会社 九州支社');
ok($zip->set_number('8610195')->is_valid_number, '北区役所');
ok($zip->set_number('8610198')->is_valid_number, '平田機工 (株)');
ok($zip->set_number('8610392')->is_valid_number, '山鹿市役所 鹿本市民センター');
ok($zip->set_number('8610592')->is_valid_number, '山鹿市役所');
ok($zip->set_number('8610593')->is_valid_number, '山鹿市民医療センター');
ok($zip->set_number('8610594')->is_valid_number, '熊本県 鹿本事務所');
ok($zip->set_number('8610595')->is_valid_number, '鹿本農業協同組合');
ok($zip->set_number('8610596')->is_valid_number, 'オムロンリレーアンドデバイス 株式会社');
ok($zip->set_number('8610598')->is_valid_number, '城北高等学校');
ok($zip->set_number('8610692')->is_valid_number, '山鹿市役所 鹿北市民センター');
ok($zip->set_number('8610698')->is_valid_number, '株式会社 フォレスト');
ok($zip->set_number('8610892')->is_valid_number, '熊本県立 南関高等学校');
ok($zip->set_number('8610898')->is_valid_number, '南関町役場');
ok($zip->set_number('8610992')->is_valid_number, '和水町役場 三加和総合支所');
ok($zip->set_number('8611192')->is_valid_number, '九州沖縄 農業研究センター');
ok($zip->set_number('8611193')->is_valid_number, '合志市役所 西合志庁舎');
ok($zip->set_number('8611195')->is_valid_number, '合志市役所');
ok($zip->set_number('8611197')->is_valid_number, '三菱電機 株式会社 熊本工場');
ok($zip->set_number('8611198')->is_valid_number, '株式会社 アドバンスト・ディスプレイ');
ok($zip->set_number('8611295')->is_valid_number, '菊池市役所 泗水総合支所');
ok($zip->set_number('8611392')->is_valid_number, '菊池市役所');
ok($zip->set_number('8611394')->is_valid_number, '菊池市役所 七城支所');
ok($zip->set_number('8612192')->is_valid_number, '熊本県 畜産農業協同組合連合会');
ok($zip->set_number('8612293')->is_valid_number, '井関熊本製造所');
ok($zip->set_number('8612295')->is_valid_number, '益城町役場');
ok($zip->set_number('8612296')->is_valid_number, '城野印刷所');
ok($zip->set_number('8612297')->is_valid_number, '井関農機 (株) 九州支店');
ok($zip->set_number('8612492')->is_valid_number, '西原村役場');
ok($zip->set_number('8613192')->is_valid_number, '嘉島町役場');
ok($zip->set_number('8613193')->is_valid_number, '医療法人 回生会 リハビリテーションセンター 熊本回生会病院');
ok($zip->set_number('8613194')->is_valid_number, '株式会社 清永宇蔵商店');
ok($zip->set_number('8613195')->is_valid_number, '白熊商事 株式会社');
ok($zip->set_number('8613196')->is_valid_number, '株式会社 野島鉄鋼店');
ok($zip->set_number('8613295')->is_valid_number, '平成音楽大学');
ok($zip->set_number('8613296')->is_valid_number, '御船町役場');
ok($zip->set_number('8613592')->is_valid_number, '山都町役場');
ok($zip->set_number('8614189')->is_valid_number, '南区役所');
ok($zip->set_number('8614192')->is_valid_number, '南九州コカ・コーラボトリング 株式会社');
ok($zip->set_number('8614193')->is_valid_number, '社会福祉法人 恩賜財団 済生会熊本病院');
ok($zip->set_number('8614195')->is_valid_number, 'ルネサスセミコンダクタマニュファクチュアリング 株式会社 川尻工場');
ok($zip->set_number('8614196')->is_valid_number, '阿蘇健康 株式会社');
ok($zip->set_number('8614198')->is_valid_number, '熊本ヤマハ 株式会社');
ok($zip->set_number('8614392')->is_valid_number, '宇城市役所 豊野支所');
ok($zip->set_number('8614492')->is_valid_number, '美里町役場');
ok($zip->set_number('8614696')->is_valid_number, '甲佐町役場');
ok($zip->set_number('8615292')->is_valid_number, '西区役所');
ok($zip->set_number('8615492')->is_valid_number, '玉名市役所 天水総合支所');
ok($zip->set_number('8615493')->is_valid_number, '玉名市教育委員会 天水出張所');
ok($zip->set_number('8615494')->is_valid_number, '玉名農業協同組合 天水支所');
ok($zip->set_number('8615495')->is_valid_number, '株式会社 天水');
ok($zip->set_number('8615592')->is_valid_number, '株式会社 テレビ熊本');
ok($zip->set_number('8615598')->is_valid_number, '熊本保健科学大学');
ok($zip->set_number('8616195')->is_valid_number, '有限会社 熊本小型船舶教習所');
ok($zip->set_number('8616395')->is_valid_number, '天草市役所 栖本支所');
ok($zip->set_number('8617292')->is_valid_number, '天草市役所 有明支所');
ok($zip->set_number('8618501')->is_valid_number, '熊本リコー 株式会社');
ok($zip->set_number('8618514')->is_valid_number, '熊本果実農業協同組合連合会');
ok($zip->set_number('8618520')->is_valid_number, '熊本赤十字病院');
ok($zip->set_number('8618528')->is_valid_number, '日赤熊本健康管理センター');
ok($zip->set_number('8618529')->is_valid_number, '陸上自衛隊 北熊本駐屯地');
ok($zip->set_number('8618538')->is_valid_number, '学校法人 尚絅学園 尚絅大学');
ok($zip->set_number('8628502')->is_valid_number, '熊本県立大学');
ok($zip->set_number('8628504')->is_valid_number, '株式会社 熊本県民テレビ');
ok($zip->set_number('8628505')->is_valid_number, '熊本市立熊本市民病院');
ok($zip->set_number('8628508')->is_valid_number, 'ファミリー音楽産業 株式会社');
ok($zip->set_number('8628510')->is_valid_number, '熊本東警察署');
ok($zip->set_number('8628555')->is_valid_number, '東区役所');
ok($zip->set_number('8628570')->is_valid_number, '熊本県庁');
ok($zip->set_number('8628571')->is_valid_number, '熊本県県央広域本部税務部');
ok($zip->set_number('8628585')->is_valid_number, '西日本電信電話 株式会社 熊本支店');
ok($zip->set_number('8628601')->is_valid_number, '株式会社 熊本銀行');
ok($zip->set_number('8628603')->is_valid_number, '湧心館高等学校');
ok($zip->set_number('8628609')->is_valid_number, '熊本県教育庁');
ok($zip->set_number('8628610')->is_valid_number, '熊本県 警察本部');
ok($zip->set_number('8628611')->is_valid_number, '株式会社 ナカムラ 熊本支店');
ok($zip->set_number('8628612')->is_valid_number, '熊本県立図書館');
ok($zip->set_number('8628620')->is_valid_number, '熊本市水道局');
ok($zip->set_number('8628622')->is_valid_number, '蔵野 株式会社');
ok($zip->set_number('8628633')->is_valid_number, '株式会社 ヤマックス');
ok($zip->set_number('8628635')->is_valid_number, '九州産交運輸 株式会社');
ok($zip->set_number('8628639')->is_valid_number, '熊本県国民健康保険団体連合会');
ok($zip->set_number('8628651')->is_valid_number, '三井海上火災保険 株式会社 熊本支店');
ok($zip->set_number('8628652')->is_valid_number, '東海大学 熊本校舎');
ok($zip->set_number('8628655')->is_valid_number, '医療法人 創起会 くまもと森都総合病院');
ok($zip->set_number('8628660')->is_valid_number, '九州セキスイ商事インフラテック 株式会社');
ok($zip->set_number('8628666')->is_valid_number, '住友海上火災保険 株式会社 熊本支店');
ok($zip->set_number('8628676')->is_valid_number, '九州学院');
ok($zip->set_number('8628677')->is_valid_number, '開新高等学校');
ok($zip->set_number('8628678')->is_valid_number, '学校法人 尚絅学園');
ok($zip->set_number('8628680')->is_valid_number, '熊本学園大学');
ok($zip->set_number('8628688')->is_valid_number, '熊本労働基準監督署');
ok($zip->set_number('8628701')->is_valid_number, '九州伊藤忠食品 株式会社');
ok($zip->set_number('8628702')->is_valid_number, '熊本東税務署');
ok($zip->set_number('8628710')->is_valid_number, '防衛庁陸上自衛隊 西部方面総監部');
ok($zip->set_number('8628716')->is_valid_number, '(財) ポスタルサービスセンター 九州地方本部');
ok($zip->set_number('8628720')->is_valid_number, '防衛庁陸上自衛隊 健軍駐屯地');
ok($zip->set_number('8628721')->is_valid_number, '熊本国税局業務センター');
ok($zip->set_number('8628744')->is_valid_number, '株式会社 再春館製薬所');
ok($zip->set_number('8628793')->is_valid_number, '日本郵便 株式会社 九州支社 郵便事業本部 (三種)');
ok($zip->set_number('8628794')->is_valid_number, '日本郵政 株式会社 共通事務管理事務所');
ok($zip->set_number('8628794')->is_valid_number, '日本郵政スタッフ 株式会社 九州BPOセンター');
ok($zip->set_number('8631992')->is_valid_number, '天草市役所 牛深支所');
ok($zip->set_number('8632292')->is_valid_number, '天草市役所 五和支所');
ok($zip->set_number('8632895')->is_valid_number, '天草市役所 天草支所');
ok($zip->set_number('8638555')->is_valid_number, '九州電力 株式会社 天草営業所');
ok($zip->set_number('8638585')->is_valid_number, '熊本地方裁判所 天草支部');
ok($zip->set_number('8638631')->is_valid_number, '天草市役所');
ok($zip->set_number('8638686')->is_valid_number, '天草税務署');
ok($zip->set_number('8648501')->is_valid_number, '五木食品 株式会社 荒尾工場');
ok($zip->set_number('8648611')->is_valid_number, '第一製網 株式会社');
ok($zip->set_number('8648686')->is_valid_number, '荒尾市役所');
ok($zip->set_number('8650192')->is_valid_number, '和水町役場');
ok($zip->set_number('8650193')->is_valid_number, 'パナソニックプレシジョンデバイス 株式会社');
ok($zip->set_number('8658501')->is_valid_number, '玉名市役所');
ok($zip->set_number('8658511')->is_valid_number, '玉名女子高等学校');
ok($zip->set_number('8658533')->is_valid_number, '蓮華院 誕生寺');
ok($zip->set_number('8658550')->is_valid_number, '学校法人 松本学園');
ok($zip->set_number('8658555')->is_valid_number, '玉名農業協同組合');
ok($zip->set_number('8658577')->is_valid_number, '司観光開発 株式会社');
ok($zip->set_number('8660195')->is_valid_number, '上天草市 姫戸統括支所');
ok($zip->set_number('8660292')->is_valid_number, '上天草市 龍ヶ岳統括支所');
ok($zip->set_number('8660293')->is_valid_number, '上天草市立 上天草総合病院');
ok($zip->set_number('8660295')->is_valid_number, '上天草看護専門学校');
ok($zip->set_number('8668501')->is_valid_number, '熊本高等専門学校 八代キャンパス');
ok($zip->set_number('8668502')->is_valid_number, '学校法人 八商学園中九州短期大学');
ok($zip->set_number('8668503')->is_valid_number, '八代社会保険事務所');
ok($zip->set_number('8668510')->is_valid_number, '白石製菓 株式会社');
ok($zip->set_number('8668511')->is_valid_number, 'YKK 株式会社 九州工場');
ok($zip->set_number('8668533')->is_valid_number, '独立行政法人 労働者健康福祉機構 熊本労災病院');
ok($zip->set_number('8668555')->is_valid_number, '熊本県八代事務所');
ok($zip->set_number('8668585')->is_valid_number, '熊本地方裁判所八代支部・八代簡易裁判所');
ok($zip->set_number('8668601')->is_valid_number, '八代市役所');
ok($zip->set_number('8668602')->is_valid_number, '日本製紙 株式会社 八代工場');
ok($zip->set_number('8668605')->is_valid_number, '八代税務署');
ok($zip->set_number('8668660')->is_valid_number, '独立行政法人 地域医療機能推進機構 熊本総合病院');
ok($zip->set_number('8668686')->is_valid_number, '株式会社 興人 八代工場');
ok($zip->set_number('8678501')->is_valid_number, 'JNC 株式会社 水俣研究所');
ok($zip->set_number('8678501')->is_valid_number, 'JNC 株式会社 水俣製造所');
ok($zip->set_number('8678501')->is_valid_number, 'チッソ 株式会社 水俣本部');
ok($zip->set_number('8678555')->is_valid_number, '水俣市役所');
ok($zip->set_number('8678585')->is_valid_number, '生活協同組合 水光社');
ok($zip->set_number('8680392')->is_valid_number, '錦町役場');
ok($zip->set_number('8680393')->is_valid_number, '九州武蔵精密 株式会社');
ok($zip->set_number('8680592')->is_valid_number, '味岡建設 株式会社');
ok($zip->set_number('8680593')->is_valid_number, '合資会社 高橋酒造本店');
ok($zip->set_number('8680595')->is_valid_number, '多良木町役場');
ok($zip->set_number('8680597')->is_valid_number, '酒井物産 株式会社');
ok($zip->set_number('8680598')->is_valid_number, '球磨郡公立 多良木病院');
ok($zip->set_number('8680795')->is_valid_number, '水上村役場');
ok($zip->set_number('8688501')->is_valid_number, '相良村役場');
ok($zip->set_number('8688502')->is_valid_number, '山江村役場');
ok($zip->set_number('8688503')->is_valid_number, '熊本県球磨事務所');
ok($zip->set_number('8688505')->is_valid_number, '高橋酒造 株式会社');
ok($zip->set_number('8688508')->is_valid_number, '株式会社 バイオ・コーポレーション');
ok($zip->set_number('8688511')->is_valid_number, '熊本県立 人吉高等学校');
ok($zip->set_number('8688515')->is_valid_number, '熊本県立 球磨工業高等学校');
ok($zip->set_number('8688555')->is_valid_number, '健康保険人吉総合病院');
ok($zip->set_number('8688601')->is_valid_number, '人吉市役所');
ok($zip->set_number('8690192')->is_valid_number, '不二ライトメタル 株式会社');
ok($zip->set_number('8690193')->is_valid_number, '日立造船ディーゼルアンドエンジニアリング 株式会社');
ok($zip->set_number('8690198')->is_valid_number, '長洲町役場');
ok($zip->set_number('8690292')->is_valid_number, '岱明町総合支所');
ok($zip->set_number('8690293')->is_valid_number, '専修大学玉名高等学校');
ok($zip->set_number('8690295')->is_valid_number, '熊本県立 玉名工業高等学校');
ok($zip->set_number('8690492')->is_valid_number, '宇土市役所');
ok($zip->set_number('8690493')->is_valid_number, '宇土 税務署');
ok($zip->set_number('8690494')->is_valid_number, '西田鉄工 株式会社');
ok($zip->set_number('8690592')->is_valid_number, '宇城市役所');
ok($zip->set_number('8690593')->is_valid_number, '独立行政法人 国立病院機構 熊本南病院');
ok($zip->set_number('8690598')->is_valid_number, '山崎製パン 株式会社 熊本工場');
ok($zip->set_number('8690696')->is_valid_number, '宇城市役所 小川支所');
ok($zip->set_number('8691192')->is_valid_number, '菊陽町役場');
ok($zip->set_number('8691193')->is_valid_number, '阿蘇製薬 株式会社');
ok($zip->set_number('8691292')->is_valid_number, '大津町役場');
ok($zip->set_number('8691293')->is_valid_number, '本田技研工業 株式会社 熊本製作所');
ok($zip->set_number('8691295')->is_valid_number, '菊池市役所 旭志総合支所');
ok($zip->set_number('8691298')->is_valid_number, 'KMバイオロジクス 株式会社 菊池研究所');
ok($zip->set_number('8692492')->is_valid_number, '南小国町役場');
ok($zip->set_number('8692493')->is_valid_number, '三愛観光 株式会社');
ok($zip->set_number('8692592')->is_valid_number, '小国町役場');
ok($zip->set_number('8692593')->is_valid_number, '熊本県立 小国高等学校');
ok($zip->set_number('8692595')->is_valid_number, '阿蘇小国郷農業協同組合');
ok($zip->set_number('8692598')->is_valid_number, '株式会社 杖立観光ホテルひぜんや');
ok($zip->set_number('8692692')->is_valid_number, '国立 阿蘇青年の家');
ok($zip->set_number('8692693')->is_valid_number, '阿蘇税務署');
ok($zip->set_number('8692695')->is_valid_number, '阿蘇市役所');
ok($zip->set_number('8692696')->is_valid_number, 'オムロン阿蘇 (株)');
ok($zip->set_number('8693296')->is_valid_number, '宇城市役所 三角支所');
ok($zip->set_number('8693692')->is_valid_number, '上天草市役所 大矢野庁舎');
ok($zip->set_number('8694292')->is_valid_number, '八代市 鏡支所');
ok($zip->set_number('8695392')->is_valid_number, '芦北町役場 田浦基幹支所');
ok($zip->set_number('8695393')->is_valid_number, '東海カーボン 株式会社 田浦工場');
ok($zip->set_number('8695498')->is_valid_number, '芦北町役場');
ok($zip->set_number('8695692')->is_valid_number, '津奈木町役場');
ok($zip->set_number('8700189')->is_valid_number, '昭和電工 株式会社 大分事務所');
ok($zip->set_number('8700192')->is_valid_number, '医療法人 敬和会 大分岡病院');
ok($zip->set_number('8700193')->is_valid_number, '(財) 西日本産業衛生会 大分労働衛生管理センター');
ok($zip->set_number('8700194')->is_valid_number, '住友化学工業 株式会社 大分工場');
ok($zip->set_number('8700195')->is_valid_number, '王子製紙 (株) 大分工場');
ok($zip->set_number('8700196')->is_valid_number, '鶴崎海陸運輸 株式会社');
ok($zip->set_number('8700197')->is_valid_number, '株式会社 ジャパンセミコンダクター 大分事業所');
ok($zip->set_number('8700198')->is_valid_number, '江藤酸素 株式会社');
ok($zip->set_number('8700292')->is_valid_number, '大分キヤノン 株式会社 大分事業所');
ok($zip->set_number('8700392')->is_valid_number, '旭化成工業 株式会社 大分工場');
ok($zip->set_number('8700393')->is_valid_number, '大分県立 大分東高等学校');
ok($zip->set_number('8700395')->is_valid_number, '株式会社 三井E&Sマシナリー 大分工場');
ok($zip->set_number('8700396')->is_valid_number, '旭化成メディカルMT 株式会社');
ok($zip->set_number('8700397')->is_valid_number, '日本文理大学');
ok($zip->set_number('8700398')->is_valid_number, 'TOTO 株式会社 大分工場');
ok($zip->set_number('8700401')->is_valid_number, '大分県運転免許センター');
ok($zip->set_number('8700992')->is_valid_number, '日本製鉄 株式会社 九州製鉄所大分地区');
ok($zip->set_number('8701192')->is_valid_number, '大分大学');
ok($zip->set_number('8701195')->is_valid_number, '大分市医師会立 アルメイダ病院');
ok($zip->set_number('8701198')->is_valid_number, '株式会社 トキハ稙田店');
ok($zip->set_number('8701292')->is_valid_number, '大分市役所 野津原支所');
ok($zip->set_number('8708501')->is_valid_number, '大分県庁');
ok($zip->set_number('8708502')->is_valid_number, '大分県 警察本部');
ok($zip->set_number('8708503')->is_valid_number, '大分県 教育庁');
ok($zip->set_number('8708504')->is_valid_number, '大分市役所');
ok($zip->set_number('8708506')->is_valid_number, '大分市保健所');
ok($zip->set_number('8708510')->is_valid_number, '大分地方検察庁');
ok($zip->set_number('8708511')->is_valid_number, '大分県立病院');
ok($zip->set_number('8708513')->is_valid_number, '大分地方法務局');
ok($zip->set_number('8708521')->is_valid_number, '福岡入国管理局 大分出張所');
ok($zip->set_number('8708523')->is_valid_number, '大分保護観察所');
ok($zip->set_number('8708524')->is_valid_number, '大分朝日放送 株式会社');
ok($zip->set_number('8708525')->is_valid_number, '大分県立 爽風館高等学校');
ok($zip->set_number('8708535')->is_valid_number, '株式会社 マルショク');
ok($zip->set_number('8708538')->is_valid_number, '大分トヨペット 株式会社');
ok($zip->set_number('8708541')->is_valid_number, 'フジボウファイバー 株式会社 大分工場');
ok($zip->set_number('8708544')->is_valid_number, '社会保険診療報酬支払基金 大分支部');
ok($zip->set_number('8708550')->is_valid_number, 'JRおおいたシティ');
ok($zip->set_number('8708551')->is_valid_number, '富士通 株式会社 大分システムラボラトリ');
ok($zip->set_number('8708555')->is_valid_number, '大分公共職業安定所 (ハローワーク大分)');
ok($zip->set_number('8708558')->is_valid_number, '株式会社 エフエム大分');
ok($zip->set_number('8708560')->is_valid_number, '大分県立 大分西高等学校');
ok($zip->set_number('8708562')->is_valid_number, '東京海上日動火災保険 株式会社 大分支店');
ok($zip->set_number('8708563')->is_valid_number, '大分県医師会');
ok($zip->set_number('8708564')->is_valid_number, '大分地方裁判所');
ok($zip->set_number('8708570')->is_valid_number, '全国健康保険協会 大分支部');
ok($zip->set_number('8708585')->is_valid_number, 'ヤマキ 株式会社');
ok($zip->set_number('8708588')->is_valid_number, '大分刑務所');
ok($zip->set_number('8708601')->is_valid_number, '株式会社 大分銀行');
ok($zip->set_number('8708602')->is_valid_number, '株式会社 アステム');
ok($zip->set_number('8708605')->is_valid_number, '大分合同新聞社');
ok($zip->set_number('8708611')->is_valid_number, '株式会社 佐伯建設');
ok($zip->set_number('8708616')->is_valid_number, '大分税務署');
ok($zip->set_number('8708619')->is_valid_number, '大分県酒類卸 株式会社');
ok($zip->set_number('8708620')->is_valid_number, '株式会社 大分放送');
ok($zip->set_number('8708627')->is_valid_number, '株式会社 大分銀行事務センター');
ok($zip->set_number('8708634')->is_valid_number, '大分県 信用農業協同組合連合会');
ok($zip->set_number('8708635')->is_valid_number, '全国農業協同組合連合会 大分県本部');
ok($zip->set_number('8708636')->is_valid_number, '株式会社 テレビ大分');
ok($zip->set_number('8708646')->is_valid_number, '大分信用金庫');
ok($zip->set_number('8708658')->is_valid_number, '学校法人 平松学園');
ok($zip->set_number('8708660')->is_valid_number, 'NHK 大分放送局');
ok($zip->set_number('8708665')->is_valid_number, '株式会社 オーシー');
ok($zip->set_number('8708676')->is_valid_number, '株式会社 サン・ダイコー');
ok($zip->set_number('8708677')->is_valid_number, '梅林建設 株式会社');
ok($zip->set_number('8708686')->is_valid_number, '株式会社 豊和銀行');
ok($zip->set_number('8708687')->is_valid_number, '大分県信用組合');
ok($zip->set_number('8708688')->is_valid_number, '株式会社 トキハ (大分店)');
ok($zip->set_number('8710192')->is_valid_number, '中津市役所 三光支所');
ok($zip->set_number('8710295')->is_valid_number, '中津市役所 本耶馬溪支所');
ok($zip->set_number('8710795')->is_valid_number, '中津市役所 山国支所');
ok($zip->set_number('8710992')->is_valid_number, '上毛町役場');
ok($zip->set_number('8710993')->is_valid_number, '上毛町 大平支所');
ok($zip->set_number('8718501')->is_valid_number, '中津市役所');
ok($zip->set_number('8718502')->is_valid_number, '九州電力 中津営業所');
ok($zip->set_number('8718510')->is_valid_number, '中津市商工会議所');
ok($zip->set_number('8718511')->is_valid_number, '中津市民病院');
ok($zip->set_number('8718521')->is_valid_number, '株式会社 井筒屋 中津店');
ok($zip->set_number('8718550')->is_valid_number, '三菱ウエルファーマ 株式会社 吉富工場');
ok($zip->set_number('8718555')->is_valid_number, 'TOTOサニテクノ 株式会社');
ok($zip->set_number('8718577')->is_valid_number, 'サンリブ中津');
ok($zip->set_number('8718585')->is_valid_number, '吉富町役場');
ok($zip->set_number('8718609')->is_valid_number, '中津公共職業安定所');
ok($zip->set_number('8718629')->is_valid_number, '株式会社 大分銀行 中津支店');
ok($zip->set_number('8718642')->is_valid_number, '中津税務署');
ok($zip->set_number('8718666')->is_valid_number, '株式会社 中野産業機械');
ok($zip->set_number('8718686')->is_valid_number, '中津鋼管工業 株式会社');
ok($zip->set_number('8718688')->is_valid_number, '八光産業 株式会社 中津工場');
ok($zip->set_number('8720592')->is_valid_number, '宇佐市役所 安心院支所');
ok($zip->set_number('8730292')->is_valid_number, '大分キヤノン 株式会社');
ok($zip->set_number('8730293')->is_valid_number, '安岐総合支所');
ok($zip->set_number('8730298')->is_valid_number, '国東市民病院');
ok($zip->set_number('8730498')->is_valid_number, '武蔵総合支所');
ok($zip->set_number('8738501')->is_valid_number, '大分キヤノンマテリアル 株式会社');
ok($zip->set_number('8748501')->is_valid_number, '学校法人 別府大学');
ok($zip->set_number('8748511')->is_valid_number, '別府市役所');
ok($zip->set_number('8748538')->is_valid_number, '国家公務員共済組合連合会 新別府病院');
ok($zip->set_number('8748555')->is_valid_number, '別府社会保険事務所');
ok($zip->set_number('8748557')->is_valid_number, 'CTBメディア 株式会社');
ok($zip->set_number('8748558')->is_valid_number, '株式会社 トキハ 別府店');
ok($zip->set_number('8748567')->is_valid_number, '学校法人 溝部学園');
ok($zip->set_number('8748577')->is_valid_number, '立命館アジア太平洋大学');
ok($zip->set_number('8748585')->is_valid_number, '大分県 厚生農業協同組合連合会');
ok($zip->set_number('8748588')->is_valid_number, '別府商工会議所');
ok($zip->set_number('8748611')->is_valid_number, '社会福祉法人 農協共済 別府リハビリテーションセンター');
ok($zip->set_number('8748639')->is_valid_number, '大分みらい信用金庫');
ok($zip->set_number('8748660')->is_valid_number, '株式会社 大分銀行 別府支店');
ok($zip->set_number('8748666')->is_valid_number, '株式会社 西日本後楽園');
ok($zip->set_number('8748686')->is_valid_number, '別府税務署');
ok($zip->set_number('8748688')->is_valid_number, 'べっぷ日出農業協同組合');
ok($zip->set_number('8750292')->is_valid_number, '臼杵市役所 野津庁舎');
ok($zip->set_number('8758501')->is_valid_number, '臼杵市役所');
ok($zip->set_number('8758612')->is_valid_number, 'フンドーキン醤油 株式会社');
ok($zip->set_number('8758616')->is_valid_number, '富士甚醤油 株式会社');
ok($zip->set_number('8758686')->is_valid_number, '臼杵税務署');
ok($zip->set_number('8762492')->is_valid_number, '佐伯市 蒲江振興局');
ok($zip->set_number('8768555')->is_valid_number, '九州電力 株式会社 佐伯営業所');
ok($zip->set_number('8768580')->is_valid_number, '株式会社 興人 佐伯工場');
ok($zip->set_number('8768585')->is_valid_number, '佐伯市役所');
ok($zip->set_number('8768601')->is_valid_number, '佐伯税務署');
ok($zip->set_number('8768666')->is_valid_number, '佐伯信用金庫');
ok($zip->set_number('8770296')->is_valid_number, '大分大山町農業協同組合');
ok($zip->set_number('8770392')->is_valid_number, '日田市役所 中津江振興局');
ok($zip->set_number('8770393')->is_valid_number, '日田市役所 上津江振興局');
ok($zip->set_number('8771292')->is_valid_number, '大分県 済生会 日田病院');
ok($zip->set_number('8778501')->is_valid_number, '中央発条工業 株式会社');
ok($zip->set_number('8778555')->is_valid_number, 'ニッポー物流サービス 株式会社');
ok($zip->set_number('8778601')->is_valid_number, '日田市役所');
ok($zip->set_number('8778686')->is_valid_number, '日田商工会議所');
ok($zip->set_number('8788555')->is_valid_number, '竹田市役所');
ok($zip->set_number('8790492')->is_valid_number, '宇佐市役所');
ok($zip->set_number('8790493')->is_valid_number, 'パナソニックコミュニケーションズ 株式会社 デバイスカンパニー大分');
ok($zip->set_number('8790495')->is_valid_number, '三和酒類 株式会社');
ok($zip->set_number('8790498')->is_valid_number, '宇佐 税務署');
ok($zip->set_number('8790692')->is_valid_number, '豊後高田市役所');
ok($zip->set_number('8791592')->is_valid_number, '日出町役場');
ok($zip->set_number('8791593')->is_valid_number, 'ホンダ太陽 株式会社');
ok($zip->set_number('8791595')->is_valid_number, '日本テキサス・インスツルメンツ 株式会社 日出工場');
ok($zip->set_number('8791598')->is_valid_number, '株式会社 ハーモニーランド');
ok($zip->set_number('8792692')->is_valid_number, '佐伯市 上浦振興局');
ok($zip->set_number('8794194')->is_valid_number, '九州電力 株式会社 日田電力所');
ok($zip->set_number('8794292')->is_valid_number, '日田市役所 天瀬町振興局');
ok($zip->set_number('8794492')->is_valid_number, '玖珠町役場');
ok($zip->set_number('8794498')->is_valid_number, '陸上自衛隊玖珠駐屯地');
ok($zip->set_number('8794692')->is_valid_number, '八鹿酒造 株式会社');
ok($zip->set_number('8795192')->is_valid_number, '由布市役所 湯布院庁舎');
ok($zip->set_number('8795193')->is_valid_number, '湯布院病院');
ok($zip->set_number('8795195')->is_valid_number, '陸上自衛隊 湯布院駐屯地');
ok($zip->set_number('8795196')->is_valid_number, '有限会社 山水館');
ok($zip->set_number('8795197')->is_valid_number, '株式会社 玉の湯');
ok($zip->set_number('8795198')->is_valid_number, '株式会社 亀の井別荘');
ok($zip->set_number('8795498')->is_valid_number, '由布市役所 庄内庁舎');
ok($zip->set_number('8795592')->is_valid_number, '由布市役所 挾間庁舎');
ok($zip->set_number('8795593')->is_valid_number, '大分大学 医学部');
ok($zip->set_number('8795595')->is_valid_number, '大分大学 医学部附属図書館');
ok($zip->set_number('8796192')->is_valid_number, '竹田市 荻支所');
ok($zip->set_number('8796692')->is_valid_number, '豊後大野市民病院');
ok($zip->set_number('8797192')->is_valid_number, '三重税務署');
ok($zip->set_number('8797198')->is_valid_number, '豊後大野市役所');
ok($zip->set_number('8800293')->is_valid_number, '株式会社 ホンダロック');
ok($zip->set_number('8800294')->is_valid_number, '株式会社 ホンダロック 広瀬工場');
ok($zip->set_number('8800295')->is_valid_number, '九州中川ヒューム管工業 株式会社');
ok($zip->set_number('8800297')->is_valid_number, '宮崎市役所 佐土原総合支所');
ok($zip->set_number('8800298')->is_valid_number, '宮崎松下電器 株式会社');
ok($zip->set_number('8801192')->is_valid_number, '国富町役場');
ok($zip->set_number('8801193')->is_valid_number, '国富町 農業協同組合');
ok($zip->set_number('8801195')->is_valid_number, '協同紙工 株式会社');
ok($zip->set_number('8801196')->is_valid_number, '九州オリンピア工業 株式会社');
ok($zip->set_number('8801392')->is_valid_number, '綾町役場');
ok($zip->set_number('8801398')->is_valid_number, '綾町農業協同組合');
ok($zip->set_number('8802292')->is_valid_number, '宮崎市役所 高岡総合支所');
ok($zip->set_number('8802293')->is_valid_number, '宮崎刑務所');
ok($zip->set_number('8808501')->is_valid_number, '宮崎県庁');
ok($zip->set_number('8808502')->is_valid_number, '宮崎県教育委員会');
ok($zip->set_number('8808503')->is_valid_number, '学校法人 宮崎学園 宮崎学園高等学校');
ok($zip->set_number('8808505')->is_valid_number, '宮崎市役所');
ok($zip->set_number('8808507')->is_valid_number, '宮崎市水道局');
ok($zip->set_number('8808508')->is_valid_number, '住友生命保険 相互会社 宮崎支社');
ok($zip->set_number('8808509')->is_valid_number, '宮崎県 警察本部');
ok($zip->set_number('8808510')->is_valid_number, '県立宮崎病院');
ok($zip->set_number('8808511')->is_valid_number, '東京海上日動火災保険 株式会社 宮崎支店');
ok($zip->set_number('8808512')->is_valid_number, '宮崎観光ホテル');
ok($zip->set_number('8808513')->is_valid_number, '宮崎地方法務局');
ok($zip->set_number('8808515')->is_valid_number, '社会福祉法人 宮崎県社会福祉協議会');
ok($zip->set_number('8808517')->is_valid_number, '宮崎シティエフエム 株式会社');
ok($zip->set_number('8808518')->is_valid_number, '宮崎県 赤十字血液センター');
ok($zip->set_number('8808519')->is_valid_number, '社団法人 宮崎県トラック協会');
ok($zip->set_number('8808520')->is_valid_number, '宮崎公立大学');
ok($zip->set_number('8808522')->is_valid_number, '宮崎ガス 株式会社');
ok($zip->set_number('8808523')->is_valid_number, '国土交通省 九州地方整備局 宮崎河川国道事務所');
ok($zip->set_number('8808525')->is_valid_number, '宮崎県 市町村職員共済組合');
ok($zip->set_number('8808527')->is_valid_number, 'ヤマエ久野 株式会社 宮崎支店');
ok($zip->set_number('8808530')->is_valid_number, '生活協同組合 コープみやざき');
ok($zip->set_number('8808532')->is_valid_number, '南日本信販 株式会社 宮崎支店');
ok($zip->set_number('8808533')->is_valid_number, '宮崎公共職業安定所');
ok($zip->set_number('8808535')->is_valid_number, '株式会社 テレビ宮崎');
ok($zip->set_number('8808539')->is_valid_number, '西日本電信電話 株式会社 宮崎支店');
ok($zip->set_number('8808543')->is_valid_number, '宮崎地方裁判所');
ok($zip->set_number('8808544')->is_valid_number, '九州電力 株式会社 宮崎支店');
ok($zip->set_number('8808545')->is_valid_number, 'フェニックスリゾート 株式会社');
ok($zip->set_number('8808546')->is_valid_number, '全国健康保険協会 宮崎支部');
ok($zip->set_number('8808550')->is_valid_number, '株式会社 志多組');
ok($zip->set_number('8808551')->is_valid_number, '有限会社 鉱脈社');
ok($zip->set_number('8808555')->is_valid_number, '宮崎県警察本部運転免許課');
ok($zip->set_number('8808556')->is_valid_number, '宮崎県 経済農業協同組合連合会');
ok($zip->set_number('8808557')->is_valid_number, '財団法人 宮崎県立 芸術劇場');
ok($zip->set_number('8808558')->is_valid_number, '宮崎ゴルフ 株式会社');
ok($zip->set_number('8808559')->is_valid_number, '株式会社 ライフ 宮崎支店');
ok($zip->set_number('8808561')->is_valid_number, 'ホテル マリックス');
ok($zip->set_number('8808566')->is_valid_number, '宮崎地方検察庁');
ok($zip->set_number('8808567')->is_valid_number, '宮崎県立 宮崎工業高等学校');
ok($zip->set_number('8808570')->is_valid_number, '株式会社 宮崎日日新聞社');
ok($zip->set_number('8808575')->is_valid_number, '宮崎交通 株式会社');
ok($zip->set_number('8808576')->is_valid_number, '株式会社 宮崎サンシャインエフエム');
ok($zip->set_number('8808577')->is_valid_number, 'ジャスコ宮崎店');
ok($zip->set_number('8808580')->is_valid_number, '独立行政法人 航空大学校');
ok($zip->set_number('8808581')->is_valid_number, '宮崎県 国民健康保険団体連合会');
ok($zip->set_number('8808583')->is_valid_number, '株式会社 エフエム宮崎');
ok($zip->set_number('8808586')->is_valid_number, '株式会社 橘百貨店');
ok($zip->set_number('8808588')->is_valid_number, '宮崎社会保険事務所');
ok($zip->set_number('8808601')->is_valid_number, '株式会社 宮崎銀行');
ok($zip->set_number('8808602')->is_valid_number, '株式会社 宮崎山形屋');
ok($zip->set_number('8808604')->is_valid_number, '宮崎第一信用金庫');
ok($zip->set_number('8808605')->is_valid_number, '株式会社 宮崎信販');
ok($zip->set_number('8808606')->is_valid_number, '株式会社 宮崎太陽銀行');
ok($zip->set_number('8808610')->is_valid_number, '第一生命保険 株式会社 宮崎支社');
ok($zip->set_number('8808625')->is_valid_number, 'SMBC日興証券 株式会社 宮崎支店');
ok($zip->set_number('8808633')->is_valid_number, 'NHK 宮崎放送局');
ok($zip->set_number('8808639')->is_valid_number, '株式会社 宮崎放送');
ok($zip->set_number('8808649')->is_valid_number, '日本生命保険 相互会社 宮崎支社');
ok($zip->set_number('8808666')->is_valid_number, '宮崎 税務署');
ok($zip->set_number('8808668')->is_valid_number, '雲海酒造 株式会社');
ok($zip->set_number('8808725')->is_valid_number, 'SMBC日興証券 株式会社 宮崎支店');
ok($zip->set_number('8818501')->is_valid_number, '西都市役所');
ok($zip->set_number('8818567')->is_valid_number, '西都農業協同組合');
ok($zip->set_number('8820192')->is_valid_number, '延岡市 北方町総合支所');
ok($zip->set_number('8821192')->is_valid_number, '高千穂町役場');
ok($zip->set_number('8821293')->is_valid_number, '雲海酒造 株式会社 本社工場');
ok($zip->set_number('8821294')->is_valid_number, '高千穂地区農業協同組合 五ケ瀬支所');
ok($zip->set_number('8821295')->is_valid_number, '五ヶ瀬町役場');
ok($zip->set_number('8828503')->is_valid_number, '日本年金機構 延岡年金事務所');
ok($zip->set_number('8828508')->is_valid_number, '九州保健福祉大学');
ok($zip->set_number('8828585')->is_valid_number, '宮崎地方裁判所延岡支部');
ok($zip->set_number('8828611')->is_valid_number, '宮崎銀行 延岡支店');
ok($zip->set_number('8828666')->is_valid_number, '延岡税務署');
ok($zip->set_number('8828678')->is_valid_number, '国民生活金融公庫 延岡支店');
ok($zip->set_number('8828686')->is_valid_number, '延岡市役所');
ok($zip->set_number('8828688')->is_valid_number, '旭有機材工業 株式会社');
ok($zip->set_number('8830192')->is_valid_number, '日向市役所 東郷町地域自治センター');
ok($zip->set_number('8831392')->is_valid_number, '諸塚村役場');
ok($zip->set_number('8838501')->is_valid_number, '日向農業協同組合');
ok($zip->set_number('8838510')->is_valid_number, '放送大学 宮崎地域学習センター');
ok($zip->set_number('8838533')->is_valid_number, '九州電力 (株) 日向電力所');
ok($zip->set_number('8838555')->is_valid_number, '日向市役所');
ok($zip->set_number('8838585')->is_valid_number, '日向製錬所');
ok($zip->set_number('8838588')->is_valid_number, '九州電力 株式会社 日向営業所');
ok($zip->set_number('8848601')->is_valid_number, '高鍋税務署');
ok($zip->set_number('8848611')->is_valid_number, '宮崎キヤノン 株式会社 本社高鍋事業所');
ok($zip->set_number('8848655')->is_valid_number, '高鍋町役場');
ok($zip->set_number('8848666')->is_valid_number, '高鍋信用金庫');
ok($zip->set_number('8851292')->is_valid_number, '株式会社 シンコー');
ok($zip->set_number('8851295')->is_valid_number, '都城市 高城総合支所');
ok($zip->set_number('8851298')->is_valid_number, '宮崎県立 高城高等学校');
ok($zip->set_number('8858501')->is_valid_number, '都城社会保険事務所');
ok($zip->set_number('8858502')->is_valid_number, '都城高等学校');
ok($zip->set_number('8858511')->is_valid_number, 'エヌ・ティ・ティマーケティングアクト南九州 株式会社 都城営業所');
ok($zip->set_number('8858533')->is_valid_number, '株式会社 シティエフエム都城');
ok($zip->set_number('8858555')->is_valid_number, '都城市役所');
ok($zip->set_number('8858567')->is_valid_number, '都城工業高等専門学校');
ok($zip->set_number('8858585')->is_valid_number, '九州電力 株式会社 都城営業所');
ok($zip->set_number('8858588')->is_valid_number, '霧島酒造 株式会社');
ok($zip->set_number('8858601')->is_valid_number, '大浦 株式会社');
ok($zip->set_number('8858610')->is_valid_number, '宮崎銀行 都城支店');
ok($zip->set_number('8858611')->is_valid_number, '都城商工会議所');
ok($zip->set_number('8858618')->is_valid_number, '都城税務署');
ok($zip->set_number('8858636')->is_valid_number, '吉原建設株式会社');
ok($zip->set_number('8860192')->is_valid_number, '小林市 須木庁舎');
ok($zip->set_number('8860292')->is_valid_number, '小林市 野尻庁舎');
ok($zip->set_number('8868501')->is_valid_number, '小林市役所');
ok($zip->set_number('8868502')->is_valid_number, '小林商工会議所');
ok($zip->set_number('8868503')->is_valid_number, '小林市民病院');
ok($zip->set_number('8868505')->is_valid_number, '宮崎県立 小林高等学校');
ok($zip->set_number('8868506')->is_valid_number, '小林工業高等学校');
ok($zip->set_number('8868510')->is_valid_number, '児玉商事 株式会社');
ok($zip->set_number('8868511')->is_valid_number, '九州グンゼ 株式会社 宮崎工場');
ok($zip->set_number('8868512')->is_valid_number, '株式会社 ロンフレ');
ok($zip->set_number('8868520')->is_valid_number, 'こばやし農業協同組合');
ok($zip->set_number('8868588')->is_valid_number, '小林西高等学校');
ok($zip->set_number('8868601')->is_valid_number, '小林税務署');
ok($zip->set_number('8868602')->is_valid_number, '宮崎銀行 小林支店');
ok($zip->set_number('8868611')->is_valid_number, '高鍋信用金庫 小林支店');
ok($zip->set_number('8878585')->is_valid_number, '日南市役所');
ok($zip->set_number('8878686')->is_valid_number, '日南税務署');
ok($zip->set_number('8888555')->is_valid_number, '串間市役所');
ok($zip->set_number('8890192')->is_valid_number, '延岡市 北川町総合支所');
ok($zip->set_number('8890392')->is_valid_number, '延岡市 北浦町総合支所');
ok($zip->set_number('8890592')->is_valid_number, '株式会社 三和');
ok($zip->set_number('8890595')->is_valid_number, '清本鐵工 株式会社');
ok($zip->set_number('8890692')->is_valid_number, '済生会支部 宮崎県済生会 日向病院');
ok($zip->set_number('8890693')->is_valid_number, '宮崎県立 門川農業高等学校');
ok($zip->set_number('8890695')->is_valid_number, '医療法人 浩洋会 田中病院');
ok($zip->set_number('8890696')->is_valid_number, '門川町役場');
ok($zip->set_number('8890697')->is_valid_number, '安井 株式会社');
ok($zip->set_number('8890698')->is_valid_number, 'イチマル産業 株式会社');
ok($zip->set_number('8891192')->is_valid_number, '日本ホワイトファーム 株式会社');
ok($zip->set_number('8891492')->is_valid_number, '航空自衛隊新田原基地');
ok($zip->set_number('8891493')->is_valid_number, '新富町役場');
ok($zip->set_number('8891495')->is_valid_number, '株式会社 吉川アールエフセミコン');
ok($zip->set_number('8891498')->is_valid_number, '宮崎県立 富養園');
ok($zip->set_number('8891692')->is_valid_number, '宮崎大学 医学部');
ok($zip->set_number('8891693')->is_valid_number, 'SUMCO TECHXIV 株式会社 宮崎工場');
ok($zip->set_number('8891695')->is_valid_number, 'ラピスセミコンダクタ宮崎 株式会社');
ok($zip->set_number('8891696')->is_valid_number, '宮崎市 清武総合支所');
ok($zip->set_number('8891795')->is_valid_number, '田野総合支所');
ok($zip->set_number('8891892')->is_valid_number, '都城市総合支所');
ok($zip->set_number('8891994')->is_valid_number, '大悟病院');
ok($zip->set_number('8891995')->is_valid_number, '三股町役場');
ok($zip->set_number('8891996')->is_valid_number, '都城東高校');
ok($zip->set_number('8891997')->is_valid_number, 'ひろせ本店');
ok($zip->set_number('8892192')->is_valid_number, '宮崎大学');
ok($zip->set_number('8892492')->is_valid_number, '日南市 北郷町総合支所');
ok($zip->set_number('8894292')->is_valid_number, 'えびの市役所');
ok($zip->set_number('8894392')->is_valid_number, '陸上自衛隊えびの駐屯地');
ok($zip->set_number('8894492')->is_valid_number, '高原町役場');
ok($zip->set_number('8894592')->is_valid_number, '都城市 高崎総合支所');
ok($zip->set_number('8908501')->is_valid_number, '日本ガス 株式会社');
ok($zip->set_number('8908502')->is_valid_number, '鹿児島県立 鶴丸高等学校');
ok($zip->set_number('8908503')->is_valid_number, '鹿児島銀行 業務集中部');
ok($zip->set_number('8908504')->is_valid_number, '志學館大学');
ok($zip->set_number('8908505')->is_valid_number, '竹下清蔵商店 株式会社');
ok($zip->set_number('8908506')->is_valid_number, '鹿児島大学医療技術短期大学');
ok($zip->set_number('8908507')->is_valid_number, '日本たばこ産業 株式会社 南九州支社');
ok($zip->set_number('8908508')->is_valid_number, '鹿児島綜合警備保障 株式会社');
ok($zip->set_number('8908509')->is_valid_number, 'NTT西日本 加入権センタ鹿児島');
ok($zip->set_number('8908510')->is_valid_number, '第十管区海上保安本部');
ok($zip->set_number('8908511')->is_valid_number, '鹿児島県民総合保健センター');
ok($zip->set_number('8908512')->is_valid_number, '株式会社 鹿児島県建設センター');
ok($zip->set_number('8908515')->is_valid_number, 'JA鹿児島県中央会・信連・経済連・共済連・鹿児島県農業協同組合中央会');
ok($zip->set_number('8908517')->is_valid_number, '鹿児島県 社会福祉協議会');
ok($zip->set_number('8908518')->is_valid_number, '鹿児島地方法務局');
ok($zip->set_number('8908520')->is_valid_number, '鹿児島大学医学部医学部附属病院');
ok($zip->set_number('8908521')->is_valid_number, '日本生命保険 相互会社 鹿児島支社');
ok($zip->set_number('8908522')->is_valid_number, '鹿児島純心女子中学校・高等学校');
ok($zip->set_number('8908523')->is_valid_number, '日進包装 株式会社');
ok($zip->set_number('8908524')->is_valid_number, '鹿児島県立鹿児島西高等学校');
ok($zip->set_number('8908525')->is_valid_number, '鹿児島純心女子短期大学');
ok($zip->set_number('8908527')->is_valid_number, '鹿児島県市町村職員共済組合');
ok($zip->set_number('8908530')->is_valid_number, '株式会社 渕紙');
ok($zip->set_number('8908531')->is_valid_number, 'セイカ食品 株式会社');
ok($zip->set_number('8908532')->is_valid_number, '鹿児島大学附属図書館 桜ヶ丘分館');
ok($zip->set_number('8908533')->is_valid_number, '日本年金機構 鹿児島南年金事務所');
ok($zip->set_number('8908535')->is_valid_number, '株式会社 加根又本店住器建材鹿児島支店');
ok($zip->set_number('8908540')->is_valid_number, '鹿児島県 信用漁業協同組合連合会');
ok($zip->set_number('8908541')->is_valid_number, '自衛隊 鹿児島地方協力本部');
ok($zip->set_number('8908543')->is_valid_number, '鹿児島市中央保健所');
ok($zip->set_number('8908544')->is_valid_number, '鹿児島大学 歯学部');
ok($zip->set_number('8908545')->is_valid_number, '鹿児島労働基準監督署');
ok($zip->set_number('8908550')->is_valid_number, '株式会社 迫田');
ok($zip->set_number('8908552')->is_valid_number, '鹿児島県 社会保険診療報酬支払基金');
ok($zip->set_number('8908555')->is_valid_number, '鹿児島公共職業安定所');
ok($zip->set_number('8908558')->is_valid_number, '九州電力 株式会社 鹿児島支店');
ok($zip->set_number('8908560')->is_valid_number, '株式会社 アリマコーポレーション');
ok($zip->set_number('8908565')->is_valid_number, '鹿児島女子短期大学');
ok($zip->set_number('8908566')->is_valid_number, '鹿児島県 警察本部');
ok($zip->set_number('8908567')->is_valid_number, '南国殖産株式会社 鴨池事業所');
ok($zip->set_number('8908570')->is_valid_number, '株式会社 南日本放送');
ok($zip->set_number('8908571')->is_valid_number, '株式会社 鹿児島放送');
ok($zip->set_number('8908574')->is_valid_number, '株式会社 鹿児島讀賣テレビ');
ok($zip->set_number('8908575')->is_valid_number, 'かごしま電工 株式会社');
ok($zip->set_number('8908577')->is_valid_number, '鹿児島県庁');
ok($zip->set_number('8908578')->is_valid_number, '協立商事株式会社 (贈りもののデパート協立)');
ok($zip->set_number('8908580')->is_valid_number, '鹿児島大学 本部');
ok($zip->set_number('8908581')->is_valid_number, '鹿児島国際観光株式会社 鹿児島サンロイヤルホテル');
ok($zip->set_number('8908585')->is_valid_number, '鹿児島市水道局');
ok($zip->set_number('8908586')->is_valid_number, '城山観光 株式会社');
ok($zip->set_number('8908588')->is_valid_number, '長島商事 株式会社');
ok($zip->set_number('8908589')->is_valid_number, '社団法人 鹿児島県薬剤師会');
ok($zip->set_number('8908601')->is_valid_number, '株式会社 ナカムラ');
ok($zip->set_number('8908603')->is_valid_number, '株式会社 南日本新聞社');
ok($zip->set_number('8908610')->is_valid_number, '株式会社 三越 鹿児島店');
ok($zip->set_number('8908666')->is_valid_number, '鹿児島テレビ放送 株式会社');
ok($zip->set_number('8908686')->is_valid_number, '鹿児島県立鹿児島聾学校');
ok($zip->set_number('8908760')->is_valid_number, '鹿児島市立病院');
ok($zip->set_number('8908794')->is_valid_number, '鹿児島事務所');
ok($zip->set_number('8908798')->is_valid_number, '鹿児島逓信病院');
ok($zip->set_number('8910180')->is_valid_number, '鹿児島実業高等学校');
ok($zip->set_number('8910182')->is_valid_number, '山形屋商事 株式会社');
ok($zip->set_number('8910183')->is_valid_number, '株式会社 ミスミ');
ok($zip->set_number('8910184')->is_valid_number, '株式会社 レイメイ藤井 鹿児島支店');
ok($zip->set_number('8910186')->is_valid_number, '財団法人 鹿児島県交通安全協会');
ok($zip->set_number('8910187')->is_valid_number, 'ヒノマル 株式会社 鹿児島支店');
ok($zip->set_number('8910188')->is_valid_number, 'イーライフ共和 株式会社');
ok($zip->set_number('8910189')->is_valid_number, '三州産業 株式会社');
ok($zip->set_number('8910192')->is_valid_number, 'ラ・サール学園');
ok($zip->set_number('8910193')->is_valid_number, '阪東機工 株式会社');
ok($zip->set_number('8910194')->is_valid_number, '鹿児島市役所 谷山支所');
ok($zip->set_number('8910195')->is_valid_number, '株式会社 タイヨー');
ok($zip->set_number('8910196')->is_valid_number, '株式会社 サナス');
ok($zip->set_number('8910197')->is_valid_number, '鹿児島国際大学');
ok($zip->set_number('8910198')->is_valid_number, '鹿児島県立 開陽高等学校');
ok($zip->set_number('8910493')->is_valid_number, 'いわさきホテルズ 株式会社');
ok($zip->set_number('8910497')->is_valid_number, '指宿市役所');
ok($zip->set_number('8910498')->is_valid_number, '独立行政法人 国立病院機構 指宿病院');
ok($zip->set_number('8910692')->is_valid_number, '指宿市役所 開聞支所');
ok($zip->set_number('8910792')->is_valid_number, '南九州市役所 頴娃支所');
ok($zip->set_number('8911192')->is_valid_number, '鹿児島市郡山支所');
ok($zip->set_number('8911392')->is_valid_number, '鹿児島市役所 吉田支所');
ok($zip->set_number('8911393')->is_valid_number, '鹿児島県 総合教育センター');
ok($zip->set_number('8911394')->is_valid_number, '株式会社 新日本科学');
ok($zip->set_number('8911395')->is_valid_number, '南九州国分 株式会社');
ok($zip->set_number('8911592')->is_valid_number, 'ふるさと観光ホテル');
ok($zip->set_number('8912192')->is_valid_number, '垂水市役所');
ok($zip->set_number('8912393')->is_valid_number, '鹿屋体育大学');
ok($zip->set_number('8912396')->is_valid_number, '国立 大隅少年自然の家');
ok($zip->set_number('8913192')->is_valid_number, '鹿児島県庁 熊毛支庁');
ok($zip->set_number('8913193')->is_valid_number, '西之表市役所');
ok($zip->set_number('8913194')->is_valid_number, '種子島 税務署');
ok($zip->set_number('8913195')->is_valid_number, '鹿児島県立 種子島高等学校');
ok($zip->set_number('8913196')->is_valid_number, '鹿児島県立 種子島実業高等学校');
ok($zip->set_number('8913198')->is_valid_number, '田上病院');
ok($zip->set_number('8913692')->is_valid_number, '中種子町役場');
ok($zip->set_number('8913693')->is_valid_number, '鹿児島くまげ農業協同組合');
ok($zip->set_number('8913792')->is_valid_number, '南種子町役場');
ok($zip->set_number('8913793')->is_valid_number, '宇宙航空研究開発機構 鹿児島宇宙センター');
ok($zip->set_number('8914292')->is_valid_number, '屋久島町役場');
ok($zip->set_number('8916292')->is_valid_number, '喜界町役場');
ok($zip->set_number('8917192')->is_valid_number, '徳之島町役場');
ok($zip->set_number('8917692')->is_valid_number, '天城町役場');
ok($zip->set_number('8918293')->is_valid_number, '伊仙町役場');
ok($zip->set_number('8919192')->is_valid_number, '和泊町役場');
ok($zip->set_number('8919292')->is_valid_number, '航空自衛隊第55警戒群');
ok($zip->set_number('8919293')->is_valid_number, '鹿児島県立 沖永良部高等学校');
ok($zip->set_number('8919294')->is_valid_number, 'あまみ農業協同組合 知名事業本部');
ok($zip->set_number('8919295')->is_valid_number, '知名町役場');
ok($zip->set_number('8919296')->is_valid_number, '沖永良部徳洲会病院');
ok($zip->set_number('8928501')->is_valid_number, '鹿児島地方裁判所・鹿児島家庭裁判所・鹿児島簡易裁判所・鹿児島検察審査会');
ok($zip->set_number('8928502')->is_valid_number, '公益社団法人 昭和会 今給黎総合病院');
ok($zip->set_number('8928505')->is_valid_number, 'LEAP出版 株式会社');
ok($zip->set_number('8928512')->is_valid_number, '社団法人 鹿児島共済会 南風病院');
ok($zip->set_number('8928515')->is_valid_number, '株式会社 南日本リビング新聞社');
ok($zip->set_number('8928520')->is_valid_number, '鹿児島地域振興局 総務企画部');
ok($zip->set_number('8928530')->is_valid_number, '株式会社 十字屋');
ok($zip->set_number('8928531')->is_valid_number, '株式会社 さつま屋');
ok($zip->set_number('8928533')->is_valid_number, '九州労働金庫 鹿児島県本部');
ok($zip->set_number('8928535')->is_valid_number, '鹿児島労働局');
ok($zip->set_number('8928539')->is_valid_number, '白露カンパニー 株式会社');
ok($zip->set_number('8928540')->is_valid_number, '全国健康保険協会 鹿児島支部');
ok($zip->set_number('8928543')->is_valid_number, '鹿児島県 土地改良事業団体連合会');
ok($zip->set_number('8928550')->is_valid_number, '社団法人 鹿児島県労働基準協会');
ok($zip->set_number('8928555')->is_valid_number, '高島屋開発 株式会社');
ok($zip->set_number('8928558')->is_valid_number, '西日本電信電話 株式会社 鹿児島支店');
ok($zip->set_number('8928563')->is_valid_number, 'MBC開発 株式会社');
ok($zip->set_number('8928566')->is_valid_number, '株式会社 明昭堂');
ok($zip->set_number('8928567')->is_valid_number, '東京海上日動火災保険 株式会社 鹿児島支店');
ok($zip->set_number('8928585')->is_valid_number, '株式会社 ハルタ');
ok($zip->set_number('8928586')->is_valid_number, '鹿児島信用金庫');
ok($zip->set_number('8928588')->is_valid_number, '鹿児島商工会議所');
ok($zip->set_number('8928601')->is_valid_number, '株式会社 山形屋');
ok($zip->set_number('8928603')->is_valid_number, 'NHK 鹿児島放送局');
ok($zip->set_number('8928611')->is_valid_number, '株式会社 南日本銀行');
ok($zip->set_number('8928626')->is_valid_number, '国民生活金融公庫');
ok($zip->set_number('8928633')->is_valid_number, '大和証券 株式会社 鹿児島支店');
ok($zip->set_number('8928650')->is_valid_number, '株式会社 鹿児島銀行');
ok($zip->set_number('8928677')->is_valid_number, '鹿児島市役所');
ok($zip->set_number('8928688')->is_valid_number, 'NCガイドショップ');
ok($zip->set_number('8930292')->is_valid_number, '鹿屋市役所 輝北総合支所');
ok($zip->set_number('8931192')->is_valid_number, '鹿屋市役所 吾平総合支所');
ok($zip->set_number('8931198')->is_valid_number, '鹿児島部品 株式会社');
ok($zip->set_number('8931298')->is_valid_number, '山佐産業 株式会社');
ok($zip->set_number('8931692')->is_valid_number, '鹿屋市役所 串良総合支所');
ok($zip->set_number('8931693')->is_valid_number, '東串良町役場');
ok($zip->set_number('8932392')->is_valid_number, '錦江町役場');
ok($zip->set_number('8932492')->is_valid_number, '錦江町役場 田代支所');
ok($zip->set_number('8938501')->is_valid_number, '鹿屋市役所');
ok($zip->set_number('8938502')->is_valid_number, '国立療養所星塚敬愛園');
ok($zip->set_number('8938510')->is_valid_number, '海上自衛隊');
ok($zip->set_number('8938611')->is_valid_number, '有限会社 財宝');
ok($zip->set_number('8940192')->is_valid_number, '龍郷町役場');
ok($zip->set_number('8940595')->is_valid_number, '奄美市 笠利総合支所');
ok($zip->set_number('8941292')->is_valid_number, '奄美市 住用総合支所');
ok($zip->set_number('8941592')->is_valid_number, '瀬戸内町役場');
ok($zip->set_number('8943192')->is_valid_number, '大和村役場');
ok($zip->set_number('8943392')->is_valid_number, '宇検村役場');
ok($zip->set_number('8948501')->is_valid_number, '鹿児島県 大島支庁');
ok($zip->set_number('8948507')->is_valid_number, '大島教育事務局');
ok($zip->set_number('8948511')->is_valid_number, '有村商事 株式会社');
ok($zip->set_number('8948555')->is_valid_number, '奄美市役所');
ok($zip->set_number('8948567')->is_valid_number, '鹿児島県立 奄美高等学校');
ok($zip->set_number('8948585')->is_valid_number, '株式会社 楠田書店');
ok($zip->set_number('8948588')->is_valid_number, '鹿児島県立 大島高等学校');
ok($zip->set_number('8948601')->is_valid_number, '株式会社 南海日日新聞社');
ok($zip->set_number('8948655')->is_valid_number, '内山商事 株式会社');
ok($zip->set_number('8948677')->is_valid_number, '大島税務署');
ok($zip->set_number('8948688')->is_valid_number, '村上建設 株式会社');
ok($zip->set_number('8950292')->is_valid_number, '京セラ 株式会社 鹿児島川内工場');
ok($zip->set_number('8951292')->is_valid_number, '薩摩川内市樋脇支所');
ok($zip->set_number('8951293')->is_valid_number, '薩摩川内市樋脇教育事務所');
ok($zip->set_number('8951295')->is_valid_number, '田苑酒造 株式会社');
ok($zip->set_number('8951296')->is_valid_number, 'ホテルグリーンヒル、グリーンヒルカントリークラブ');
ok($zip->set_number('8951492')->is_valid_number, '薩摩川内市 入来支所');
ok($zip->set_number('8951493')->is_valid_number, '富士通インテグレーテッドマイクロテクノロジ');
ok($zip->set_number('8951595')->is_valid_number, '薩摩川内市 祁答院支所');
ok($zip->set_number('8952292')->is_valid_number, 'さつま町 薩摩総合支所');
ok($zip->set_number('8952298')->is_valid_number, 'インターナショナルゴルフリゾート 京セラ');
ok($zip->set_number('8958501')->is_valid_number, '川内総務事務所');
ok($zip->set_number('8958502')->is_valid_number, '北薩福祉事務所');
ok($zip->set_number('8958503')->is_valid_number, '川薩農林事務所');
ok($zip->set_number('8958504')->is_valid_number, '川薩耕地事務所');
ok($zip->set_number('8958505')->is_valid_number, '川内土木事務所');
ok($zip->set_number('8958506')->is_valid_number, '北薩教育事務所');
ok($zip->set_number('8958515')->is_valid_number, '学校法人 川内純心女子学園');
ok($zip->set_number('8958519')->is_valid_number, '西日本電信電話 株式会社 川内支店');
ok($zip->set_number('8958540')->is_valid_number, '中越パルプ工業株式会社 川内工場');
ok($zip->set_number('8958555')->is_valid_number, '株式会社 大和');
ok($zip->set_number('8958588')->is_valid_number, '株式会社 植村組');
ok($zip->set_number('8958601')->is_valid_number, '川内税務署');
ok($zip->set_number('8958650')->is_valid_number, '薩摩川内市役所');
ok($zip->set_number('8958686')->is_valid_number, '九州電力 株式会社 川内営業所');
ok($zip->set_number('8961192')->is_valid_number, '薩摩川内市 里支所');
ok($zip->set_number('8961392')->is_valid_number, '薩摩川内市 鹿島支所');
ok($zip->set_number('8961696')->is_valid_number, '薩摩川内市下甑支所');
ok($zip->set_number('8968601')->is_valid_number, 'いちき串木野市役所');
ok($zip->set_number('8968686')->is_valid_number, '学校法人 神村学園 (高等部・中等部・附属幼稚園・医療福祉専門学校)');
ok($zip->set_number('8970392')->is_valid_number, '南九州市役所');
ok($zip->set_number('8970393')->is_valid_number, '知覧税務署');
ok($zip->set_number('8978501')->is_valid_number, '南さつま市役所');
ok($zip->set_number('8988501')->is_valid_number, '枕崎市役所');
ok($zip->set_number('8990292')->is_valid_number, '出水市役所');
ok($zip->set_number('8990293')->is_valid_number, 'NEC液晶テクノロジー 株式会社 鹿児島工場');
ok($zip->set_number('8990295')->is_valid_number, '住化積水フィルム 株式会社 出水工場');
ok($zip->set_number('8990297')->is_valid_number, 'マルイ事業協同組合');
ok($zip->set_number('8990298')->is_valid_number, '出水 税務署');
ok($zip->set_number('8990492')->is_valid_number, '出水市役所 高尾野支所');
ok($zip->set_number('8991395')->is_valid_number, '長島町役場 指江庁舎');
ok($zip->set_number('8991498')->is_valid_number, '長島町役場');
ok($zip->set_number('8991696')->is_valid_number, '阿久根市役所');
ok($zip->set_number('8992192')->is_valid_number, 'いちき串木野市役所 市来庁舎');
ok($zip->set_number('8992292')->is_valid_number, '日置市役所 東市来支所');
ok($zip->set_number('8992592')->is_valid_number, '日置市役所');
ok($zip->set_number('8992593')->is_valid_number, '鹿児島 城西高等学校');
ok($zip->set_number('8992594')->is_valid_number, '株式会社 ヒガシマル');
ok($zip->set_number('8992595')->is_valid_number, 'パナソニック デバイスオプティカルセミコンダクター 株式会社');
ok($zip->set_number('8992596')->is_valid_number, 'さつま日置 農業協同組合');
ok($zip->set_number('8992792')->is_valid_number, '鹿児島市役所松元支所');
ok($zip->set_number('8993192')->is_valid_number, '日置市役所 日吉支所');
ok($zip->set_number('8993492')->is_valid_number, '南さつま市 金峰支所');
ok($zip->set_number('8994192')->is_valid_number, '曽於市役所 財部支所');
ok($zip->set_number('8994292')->is_valid_number, '霧島市 霧島総合支所');
ok($zip->set_number('8994392')->is_valid_number, '自衛隊国分駐屯地');
ok($zip->set_number('8994393')->is_valid_number, 'ソニー国分 株式会社');
ok($zip->set_number('8994394')->is_valid_number, '霧島市役所');
ok($zip->set_number('8994395')->is_valid_number, '都築教育学園 第一工業大学');
ok($zip->set_number('8994396')->is_valid_number, '京セラ 株式会社 鹿児島国分工場');
ok($zip->set_number('8995192')->is_valid_number, '霧島市 隼人総合支所');
ok($zip->set_number('8995193')->is_valid_number, '鹿児島工業高等専門学校');
ok($zip->set_number('8995195')->is_valid_number, '京セラ 株式会社 鹿児島隼人工場');
ok($zip->set_number('8995292')->is_valid_number, '加治木社会保険事務所');
ok($zip->set_number('8995293')->is_valid_number, '国立療養所 南九州病院');
ok($zip->set_number('8995294')->is_valid_number, '姶良市役所 加治木総合支所');
ok($zip->set_number('8995392')->is_valid_number, '姶良市役所 蒲生総合支所');
ok($zip->set_number('8995492')->is_valid_number, '姶良市役所');
ok($zip->set_number('8995495')->is_valid_number, '株式会社 マイカル南九州サンシティリブレ');
ok($zip->set_number('8995693')->is_valid_number, '医療法人 青雲病院');
ok($zip->set_number('8995694')->is_valid_number, '株式会社 ランドアート');
ok($zip->set_number('8995698')->is_valid_number, '株式会社 イケダパン');
ok($zip->set_number('8996192')->is_valid_number, '湧水町役場 吉松庁舎');
ok($zip->set_number('8996193')->is_valid_number, '鹿児島刑務所');
ok($zip->set_number('8996292')->is_valid_number, '湧水町役場');
ok($zip->set_number('8996293')->is_valid_number, 'ヤマハ鹿児島 セミコンダクタ 株式会社');
ok($zip->set_number('8996492')->is_valid_number, '国土交通省 大阪航空局 鹿児島空港事務所');
ok($zip->set_number('8996493')->is_valid_number, '霧島市 溝辺総合支所');
ok($zip->set_number('8996494')->is_valid_number, '鹿児島空港ビルディング 株式会社');
ok($zip->set_number('8996495')->is_valid_number, '日本エアコミューター 株式会社');
ok($zip->set_number('8996592')->is_valid_number, '霧島市 牧園総合支所');
ok($zip->set_number('8997192')->is_valid_number, '志布志市役所 志布志支所');
ok($zip->set_number('8997492')->is_valid_number, '志布志市役所');
ok($zip->set_number('8997692')->is_valid_number, '志布志市役所 松山支所');
ok($zip->set_number('8998192')->is_valid_number, '大隅税務署');
ok($zip->set_number('8998692')->is_valid_number, '曽於市役所');
ok($zip->set_number('9008501')->is_valid_number, '沖縄県議会事務局');
ok($zip->set_number('9008503')->is_valid_number, '株式会社 リウボウインダストリー');
ok($zip->set_number('9008504')->is_valid_number, 'ザ・テラスホテルズ 株式会社 コクワ流通サービスカンパニー');
ok($zip->set_number('9008505')->is_valid_number, '株式会社 國場組');
ok($zip->set_number('9008510')->is_valid_number, '琉球朝日放送 株式会社');
ok($zip->set_number('9008512')->is_valid_number, '全国健康保険協会 沖縄支部');
ok($zip->set_number('9008513')->is_valid_number, '住友生命保険 相互会社 沖縄支社');
ok($zip->set_number('9008514')->is_valid_number, '株式会社 トヨタレンタリース沖縄');
ok($zip->set_number('9008516')->is_valid_number, '株式会社 琉球光和');
ok($zip->set_number('9008517')->is_valid_number, '沖縄気象台');
ok($zip->set_number('9008520')->is_valid_number, '沖縄振興開発金融公庫');
ok($zip->set_number('9008522')->is_valid_number, '沖縄電力 株式会社 那覇支店');
ok($zip->set_number('9008524')->is_valid_number, '富士ゼロックス 株式会社 沖縄営業所');
ok($zip->set_number('9008525')->is_valid_number, '株式会社 琉球新報社');
ok($zip->set_number('9008527')->is_valid_number, '金秀建設 株式会社');
ok($zip->set_number('9008530')->is_valid_number, '内閣府沖縄総合事務局');
ok($zip->set_number('9008531')->is_valid_number, '沖縄県町村会');
ok($zip->set_number('9008533')->is_valid_number, '株式会社 ざまみ');
ok($zip->set_number('9008534')->is_valid_number, '株式会社 おきぎんジェーシービー');
ok($zip->set_number('9008535')->is_valid_number, 'NHK沖縄放送局');
ok($zip->set_number('9008540')->is_valid_number, '沖縄セルラー電話 株式会社');
ok($zip->set_number('9008543')->is_valid_number, '那覇税務署');
ok($zip->set_number('9008544')->is_valid_number, '那覇地方法務局');
ok($zip->set_number('9008545')->is_valid_number, 'NTT 沖縄支店');
ok($zip->set_number('9008547')->is_valid_number, '第11管区 海上保安本部');
ok($zip->set_number('9008548')->is_valid_number, '那覇海上保安部');
ok($zip->set_number('9008550')->is_valid_number, '株式会社 琉球リース');
ok($zip->set_number('9008551')->is_valid_number, 'KDDI沖縄 株式会社');
ok($zip->set_number('9008552')->is_valid_number, '財団法人 沖縄県交通安全協会連合会');
ok($zip->set_number('9008553')->is_valid_number, '那覇市教育委員会');
ok($zip->set_number('9008554')->is_valid_number, '沖縄国税事務所');
ok($zip->set_number('9008555')->is_valid_number, '沖縄県立那覇高等学校');
ok($zip->set_number('9008556')->is_valid_number, '医療法人 祥杏会 おもろまちメディカルセンター');
ok($zip->set_number('9008557')->is_valid_number, '沖縄県立 那覇商業高等学校');
ok($zip->set_number('9008558')->is_valid_number, '沖縄協同病院');
ok($zip->set_number('9008559')->is_valid_number, '沖縄県国民健康保険団体連合会');
ok($zip->set_number('9008560')->is_valid_number, '上原労務管理事務所');
ok($zip->set_number('9008567')->is_valid_number, '那覇地方裁判所 総務課');
ok($zip->set_number('9008570')->is_valid_number, '沖縄県庁');
ok($zip->set_number('9008571')->is_valid_number, '沖縄県 教育委員会');
ok($zip->set_number('9008575')->is_valid_number, 'パナホーム 株式会社 カスタマー受付センター');
ok($zip->set_number('9008577')->is_valid_number, '沖縄県 住宅供給公社');
ok($zip->set_number('9008578')->is_valid_number, '那覇地方検察庁');
ok($zip->set_number('9008581')->is_valid_number, '財団法人 ポスタルサービスセンター 沖縄地方本部');
ok($zip->set_number('9008585')->is_valid_number, '那覇市役所');
ok($zip->set_number('9008586')->is_valid_number, '大同火災海上保険 株式会社');
ok($zip->set_number('9008588')->is_valid_number, '沖縄テレビ放送 株式会社');
ok($zip->set_number('9008601')->is_valid_number, '那覇公共職業安定所');
ok($zip->set_number('9008602')->is_valid_number, '沖縄ツーリスト 株式会社');
ok($zip->set_number('9008603')->is_valid_number, '那覇家庭裁判所 総務課');
ok($zip->set_number('9008604')->is_valid_number, '株式会社 ラジオ沖縄');
ok($zip->set_number('9008605')->is_valid_number, '沖縄ガス 株式会社');
ok($zip->set_number('9008608')->is_valid_number, '全保連 株式会社');
ok($zip->set_number('9008609')->is_valid_number, '\x87梶@OCS');
ok($zip->set_number('9008610')->is_valid_number, '沖縄県立泊高等学校');
ok($zip->set_number('9008650')->is_valid_number, '沖縄県信用農業 協同組合連合会');
ok($zip->set_number('9008651')->is_valid_number, '株式会社 沖縄銀行');
ok($zip->set_number('9008654')->is_valid_number, '株式会社 沖縄三越');
ok($zip->set_number('9008666')->is_valid_number, '日本銀行 那覇支店');
ok($zip->set_number('9008678')->is_valid_number, '株式会社 沖縄タイムス');
ok($zip->set_number('9008686')->is_valid_number, '沖縄海邦銀行');
ok($zip->set_number('9008688')->is_valid_number, '株式会社 琉球銀行');
ok($zip->set_number('9008701')->is_valid_number, '商工組合中央金庫 那覇支店');
ok($zip->set_number('9008711')->is_valid_number, '琉球放送 株式会社');
ok($zip->set_number('9008735')->is_valid_number, 'ヘリオス酒造 株式会社');
ok($zip->set_number('9008794')->is_valid_number, 'ゆうちょ銀行 那覇支店 貯金事務管理部');
ok($zip->set_number('9008795')->is_valid_number, '総務省 沖縄総合通信事務所');
ok($zip->set_number('9008796')->is_valid_number, '沖縄監査室');
ok($zip->set_number('9008797')->is_valid_number, '株式会社 ゆうちょ銀行 那覇支店');
ok($zip->set_number('9008797')->is_valid_number, '株式会社 かんぽ生命 那覇支店');
ok($zip->set_number('9008797')->is_valid_number, '日本郵便 株式会社 沖縄支社');
ok($zip->set_number('9010192')->is_valid_number, '陸上自衛隊 那覇駐屯地');
ok($zip->set_number('9010193')->is_valid_number, '海上自衛隊 那覇基地');
ok($zip->set_number('9010194')->is_valid_number, '航空自衛隊 那覇基地');
ok($zip->set_number('9010196')->is_valid_number, 'MRO Japan 株式会社');
ok($zip->set_number('9010197')->is_valid_number, '自衛隊那覇病院');
ok($zip->set_number('9010292')->is_valid_number, '豊見城市役所');
ok($zip->set_number('9010294')->is_valid_number, '沖縄医療生活協同組合');
ok($zip->set_number('9010295')->is_valid_number, '豊見城中央病院');
ok($zip->set_number('9010392')->is_valid_number, '糸満市役所');
ok($zip->set_number('9010393')->is_valid_number, '株式会社 ざまみダンボール');
ok($zip->set_number('9010492')->is_valid_number, '八重瀬町役場');
ok($zip->set_number('9010493')->is_valid_number, '特定医療法人 沖縄徳洲会 南部徳洲会病院');
ok($zip->set_number('9010494')->is_valid_number, '南部水道企業団');
ok($zip->set_number('9010495')->is_valid_number, '沖縄県農業協同組合 東風平支店');
ok($zip->set_number('9010496')->is_valid_number, '陸上自衛隊 与座分屯地');
ok($zip->set_number('9010592')->is_valid_number, '八重瀬町役場 具志頭出張所');
ok($zip->set_number('9011192')->is_valid_number, '財団法人 沖縄県総合保健協会');
ok($zip->set_number('9011193')->is_valid_number, '沖縄県立 南部医療センター・こども医療センター');
ok($zip->set_number('9011195')->is_valid_number, '南風原町役場');
ok($zip->set_number('9011196')->is_valid_number, '霊波之光 沖縄支部');
ok($zip->set_number('9011292')->is_valid_number, '南城市役所 大里庁舎');
ok($zip->set_number('9011392')->is_valid_number, '与那原町役場');
ok($zip->set_number('9011393')->is_valid_number, '沖縄リハビリテーション福祉学院');
ok($zip->set_number('9011492')->is_valid_number, '南城市役所 佐敷庁舎');
ok($zip->set_number('9011495')->is_valid_number, '南城市役所');
ok($zip->set_number('9011595')->is_valid_number, '南城市役所 知念庁舎');
ok($zip->set_number('9012392')->is_valid_number, '北中城村役場');
ok($zip->set_number('9012393')->is_valid_number, '中部徳洲会病院');
ok($zip->set_number('9012395')->is_valid_number, '北中城若松病院');
ok($zip->set_number('9012492')->is_valid_number, 'ハートライフ病院');
ok($zip->set_number('9012493')->is_valid_number, '中城村役場');
ok($zip->set_number('9012495')->is_valid_number, '沖縄ホーメル');
ok($zip->set_number('9012496')->is_valid_number, '株式会社 スピア');
ok($zip->set_number('9012501')->is_valid_number, '浦添市役所');
ok($zip->set_number('9012502')->is_valid_number, '沖縄明治乳業 株式会社');
ok($zip->set_number('9012506')->is_valid_number, '沖縄県 自動車税事務所');
ok($zip->set_number('9012507')->is_valid_number, 'サンエー浦添西海岸 パルコ シティ');
ok($zip->set_number('9012510')->is_valid_number, '合資会社 富士物産');
ok($zip->set_number('9012511')->is_valid_number, '株式会社 伊禮産業');
ok($zip->set_number('9012512')->is_valid_number, '琉球セメント 株式会社');
ok($zip->set_number('9012515')->is_valid_number, '沖縄マツダ (株)');
ok($zip->set_number('9012520')->is_valid_number, 'NTT 沖縄支店');
ok($zip->set_number('9012521')->is_valid_number, 'NTT 沖縄支店');
ok($zip->set_number('9012525')->is_valid_number, 'FM沖縄');
ok($zip->set_number('9012526')->is_valid_number, '沖縄薬品 株式会社');
ok($zip->set_number('9012530')->is_valid_number, 'ジーマ 株式会社');
ok($zip->set_number('9012531')->is_valid_number, '株式会社 ジーマックス');
ok($zip->set_number('9012540')->is_valid_number, '株式会社 ヤナセ沖縄');
ok($zip->set_number('9012550')->is_valid_number, '北那覇税務署');
ok($zip->set_number('9012551')->is_valid_number, 'オリオンビール (株)');
ok($zip->set_number('9012552')->is_valid_number, '沖縄国際センター');
ok($zip->set_number('9012553')->is_valid_number, '平安病院');
ok($zip->set_number('9012555')->is_valid_number, '沖縄コカ・コーラボトリング 株式会社');
ok($zip->set_number('9012556')->is_valid_number, '福山商事 (株)');
ok($zip->set_number('9012557')->is_valid_number, '松下電工 株式会社 沖縄営業所');
ok($zip->set_number('9012558')->is_valid_number, '沖縄食料 株式会社');
ok($zip->set_number('9012559')->is_valid_number, '株式会社 メイクマン');
ok($zip->set_number('9012560')->is_valid_number, 'ファーストライディングテクノロジー 株式会社');
ok($zip->set_number('9012566')->is_valid_number, '島袋 (株)');
ok($zip->set_number('9012567')->is_valid_number, '浦添市商工会議所');
ok($zip->set_number('9012569')->is_valid_number, '沖縄県 花卉園芸農業協同組合');
ok($zip->set_number('9012588')->is_valid_number, '生活協同組合 コープおきなわ');
ok($zip->set_number('9012597')->is_valid_number, 'JA沖縄経済連');
ok($zip->set_number('9012601')->is_valid_number, '沖縄松下ライフエレクトロニクス 株式会社');
ok($zip->set_number('9012602')->is_valid_number, '沖縄電力 株式会社 本店');
ok($zip->set_number('9012607')->is_valid_number, 'パイオニア電設 株式会社');
ok($zip->set_number('9012610')->is_valid_number, 'フォーモストブルーシール 株式会社');
ok($zip->set_number('9012611')->is_valid_number, '沖縄電力 (株) お客さま本部 浦添支店');
ok($zip->set_number('9012686')->is_valid_number, '株式会社 琉薬');
ok($zip->set_number('9012701')->is_valid_number, '沖縄国際大学');
ok($zip->set_number('9012710')->is_valid_number, '宜野湾市役所');
ok($zip->set_number('9012733')->is_valid_number, '株式会社 サンエー');
ok($zip->set_number('9013192')->is_valid_number, '久米島町役場 具志川庁舎');
ok($zip->set_number('9013193')->is_valid_number, '久米島町役場 仲里庁舎');
ok($zip->set_number('9013496')->is_valid_number, '座間味村役場');
ok($zip->set_number('9013592')->is_valid_number, '渡嘉敷村役場');
ok($zip->set_number('9013595')->is_valid_number, '国立 沖縄青少年交流の家');
ok($zip->set_number('9013692')->is_valid_number, '渡名喜村役場');
ok($zip->set_number('9013792')->is_valid_number, '粟国村役場');
ok($zip->set_number('9013895')->is_valid_number, '南大東村役場');
ok($zip->set_number('9013992')->is_valid_number, '北大東村役場');
ok($zip->set_number('9028510')->is_valid_number, 'NTT 那覇営業所');
ok($zip->set_number('9028511')->is_valid_number, '那覇市立病院');
ok($zip->set_number('9028512')->is_valid_number, '那覇市保健所');
ok($zip->set_number('9028513')->is_valid_number, '沖縄県立看護大学');
ok($zip->set_number('9028521')->is_valid_number, '沖縄大学');
ok($zip->set_number('9028550')->is_valid_number, '那覇警察署');
ok($zip->set_number('9028555')->is_valid_number, '那覇市役所 真和志支所');
ok($zip->set_number('9028570')->is_valid_number, '那覇市水道局');
ok($zip->set_number('9028571')->is_valid_number, '医療法人 おもと会 大浜第一病院');
ok($zip->set_number('9028585')->is_valid_number, '沖縄県 社会保険診療報酬支払基金');
ok($zip->set_number('9028588')->is_valid_number, '沖縄赤十字病院');
ok($zip->set_number('9030201')->is_valid_number, 'アドベンチストメディカルセンター');
ok($zip->set_number('9030203')->is_valid_number, 'オキコ 株式会社');
ok($zip->set_number('9030204')->is_valid_number, '金秀アルミ工業 株式会社');
ok($zip->set_number('9030205')->is_valid_number, '金秀鋼材');
ok($zip->set_number('9030206')->is_valid_number, '金秀商事 株式会社');
ok($zip->set_number('9030207')->is_valid_number, '学校法人 沖縄キリスト教学院 沖縄キリスト教短期大学');
ok($zip->set_number('9030210')->is_valid_number, '南西石油 (株)');
ok($zip->set_number('9030211')->is_valid_number, '丸正印刷 株式会社');
ok($zip->set_number('9030213')->is_valid_number, '国立大学法人 琉球大学 総務部 総務課');
ok($zip->set_number('9030214')->is_valid_number, '国立大学法人 琉球大学 付属図書館');
ok($zip->set_number('9030215')->is_valid_number, '国立大学法人 琉球大学 医学部・医学部付属病院');
ok($zip->set_number('9030217')->is_valid_number, '東洋コンクリート 株式会社');
ok($zip->set_number('9030218')->is_valid_number, '沖縄県立 西原高等学校');
ok($zip->set_number('9030220')->is_valid_number, '西原町役場');
ok($zip->set_number('9038601')->is_valid_number, '株式会社 琉球ホテルリゾート那覇 ダブルツリーbyヒルトン那覇首里城');
ok($zip->set_number('9038602')->is_valid_number, '沖縄県立芸術大学');
ok($zip->set_number('9038603')->is_valid_number, '社会福祉法人 沖縄県社会福祉協議会');
ok($zip->set_number('9040192')->is_valid_number, '北谷町役場');
ok($zip->set_number('9040193')->is_valid_number, '北谷町水道課');
ok($zip->set_number('9040194')->is_valid_number, 'ちゃたんニライセンター生涯学習プラザ');
ok($zip->set_number('9040195')->is_valid_number, '北谷町消防本部');
ok($zip->set_number('9040293')->is_valid_number, '嘉手納町役場');
ok($zip->set_number('9040295')->is_valid_number, '沖縄防衛局');
ok($zip->set_number('9040392')->is_valid_number, '読谷村役場');
ok($zip->set_number('9040393')->is_valid_number, 'ホテル日航アリビラ');
ok($zip->set_number('9040394')->is_valid_number, '沖縄残波岬ロイヤルホテル');
ok($zip->set_number('9040395')->is_valid_number, '読谷高等学校');
ok($zip->set_number('9040398')->is_valid_number, '沖縄県介護保険広域連合');
ok($zip->set_number('9040492')->is_valid_number, '恩納村役場');
ok($zip->set_number('9040493')->is_valid_number, '万座ビーチホテル&リゾート');
ok($zip->set_number('9040494')->is_valid_number, 'サンマリーナホテル');
ok($zip->set_number('9040495')->is_valid_number, '学校法人 沖縄科学技術大学院大学学園');
ok($zip->set_number('9040496')->is_valid_number, 'リザンシーパークホテル 谷茶ベイ');
ok($zip->set_number('9040497')->is_valid_number, '学校法人 沖縄科学技術大学院大学学園 OIST住居エリア HousingArea');
ok($zip->set_number('9041192')->is_valid_number, 'うるま市役所 石川庁舎');
ok($zip->set_number('9041292')->is_valid_number, '金武町役場');
ok($zip->set_number('9041293')->is_valid_number, '金武町教育委員会');
ok($zip->set_number('9041294')->is_valid_number, '金武地区消防衛生組合');
ok($zip->set_number('9041392')->is_valid_number, '宜野座村役場');
ok($zip->set_number('9042192')->is_valid_number, '医療法人 ちゅうざん会 ちゅうざん病院');
ok($zip->set_number('9042193')->is_valid_number, '沖縄税務署');
ok($zip->set_number('9042194')->is_valid_number, '那覇地方裁判所 沖縄支部・沖縄簡易裁判所・那覇家庭裁判所 沖縄支部');
ok($zip->set_number('9042196')->is_valid_number, '沖縄市水道局');
ok($zip->set_number('9042292')->is_valid_number, 'うるま市役所');
ok($zip->set_number('9042293')->is_valid_number, '沖縄県立 中部病院');
ok($zip->set_number('9042294')->is_valid_number, '株式会社 スピア');
ok($zip->set_number('9042392')->is_valid_number, 'うるま市役所 勝連庁舎');
ok($zip->set_number('9042393')->is_valid_number, 'うるま市役所 与那城庁舎');
ok($zip->set_number('9042394')->is_valid_number, '海上自衛隊 沖縄基地隊');
ok($zip->set_number('9048501')->is_valid_number, '沖縄市役所');
ok($zip->set_number('9048511')->is_valid_number, 'NTT コザ営業所');
ok($zip->set_number('9048585')->is_valid_number, '中部徳洲会');
ok($zip->set_number('9048686')->is_valid_number, '(株) 沖縄タイムス社 中部支社');
ok($zip->set_number('9050292')->is_valid_number, '本部町役場');
ok($zip->set_number('9050492')->is_valid_number, '今帰仁村役場');
ok($zip->set_number('9050592')->is_valid_number, '伊江村役場');
ok($zip->set_number('9050593')->is_valid_number, 'JA伊江村');
ok($zip->set_number('9050594')->is_valid_number, '伊江中学校');
ok($zip->set_number('9050595')->is_valid_number, '伊江小学校');
ok($zip->set_number('9050596')->is_valid_number, '西小学校');
ok($zip->set_number('9050695')->is_valid_number, '伊是名村役場');
ok($zip->set_number('9050792')->is_valid_number, '伊平屋村農業協同組合');
ok($zip->set_number('9050793')->is_valid_number, '伊平屋村役場');
ok($zip->set_number('9050794')->is_valid_number, '伊平屋村教育委員会');
ok($zip->set_number('9050795')->is_valid_number, '伊平屋小学校');
ok($zip->set_number('9050796')->is_valid_number, '伊平屋中学校');
ok($zip->set_number('9051292')->is_valid_number, '東村役場');
ok($zip->set_number('9051392')->is_valid_number, '大宜味村役場');
ok($zip->set_number('9051495')->is_valid_number, '国頭村役場');
ok($zip->set_number('9052192')->is_valid_number, '沖縄工業高等専門学校');
ok($zip->set_number('9058501')->is_valid_number, '沖縄総合事務局 北部ダム事務所');
ok($zip->set_number('9058512')->is_valid_number, '県立 北部病院');
ok($zip->set_number('9058540')->is_valid_number, '名護市役所');
ok($zip->set_number('9058585')->is_valid_number, '学校法人 名護総合学園 名桜大学');
ok($zip->set_number('9058611')->is_valid_number, '北部地区医師会病院');
ok($zip->set_number('9058668')->is_valid_number, '名護税務署');
ok($zip->set_number('9060292')->is_valid_number, '航空自衛隊 宮古島');
ok($zip->set_number('9060592')->is_valid_number, '宮古島市 伊良部総合支所');
ok($zip->set_number('9060692')->is_valid_number, '多良間村役場');
ok($zip->set_number('9068501')->is_valid_number, '宮古島市役所');
ok($zip->set_number('9068550')->is_valid_number, '沖縄県立宮古病院');
ok($zip->set_number('9068601')->is_valid_number, '平良税務署');
ok($zip->set_number('9071292')->is_valid_number, '株式会社 はいむるぶし');
ok($zip->set_number('9071892')->is_valid_number, '与那国町役場');
ok($zip->set_number('9078501')->is_valid_number, '石垣市役所');
ok($zip->set_number('9078502')->is_valid_number, '石垣税務署');
ok($zip->set_number('9078503')->is_valid_number, '竹富町役場');
ok($zip->set_number('9100292')->is_valid_number, '坂井市役所 丸岡総合支所');
ok($zip->set_number('9100293')->is_valid_number, '福井県立 丸岡高等学校');
ok($zip->set_number('9100296')->is_valid_number, 'ふくい産業支援センター');
ok($zip->set_number('9100297')->is_valid_number, '福井コンピュータ 株式会社');
ok($zip->set_number('9100298')->is_valid_number, '公益財団法人 丸岡文化財団');
ok($zip->set_number('9100392')->is_valid_number, '三谷商事 株式会社 イメージシステム部');
ok($zip->set_number('9100393')->is_valid_number, '三谷コンピュータ 株式会社');
ok($zip->set_number('9101192')->is_valid_number, '永平寺町役場');
ok($zip->set_number('9101193')->is_valid_number, '福井大学 医学部');
ok($zip->set_number('9101194')->is_valid_number, '福井大学 医学図書館');
ok($zip->set_number('9101195')->is_valid_number, '福井県立大学');
ok($zip->set_number('9101292')->is_valid_number, '永平寺町役場 永平寺支所');
ok($zip->set_number('9101293')->is_valid_number, 'フレッグ食品工業 株式会社');
ok($zip->set_number('9101294')->is_valid_number, '大本山 永平寺');
ok($zip->set_number('9101295')->is_valid_number, '株式会社 西村組');
ok($zip->set_number('9101392')->is_valid_number, '永平寺町役場 上志比支所');
ok($zip->set_number('9102392')->is_valid_number, '福井市 美山連絡所');
ok($zip->set_number('9103692')->is_valid_number, '福井市 清水連絡所');
ok($zip->set_number('9104193')->is_valid_number, 'グランディア芳泉');
ok($zip->set_number('9104195')->is_valid_number, 'あわらグランドホテル');
ok($zip->set_number('9104196')->is_valid_number, 'まつや千千');
ok($zip->set_number('9104197')->is_valid_number, 'ケアハイツ芦原');
ok($zip->set_number('9104198')->is_valid_number, '清風荘');
ok($zip->set_number('9108501')->is_valid_number, 'あおい商事 株式会社');
ok($zip->set_number('9108502')->is_valid_number, 'パナソニック 株式会社 デバイスソリューション事業部(森田)');
ok($zip->set_number('9108503')->is_valid_number, '福井街角放送 株式会社');
ok($zip->set_number('9108504')->is_valid_number, '福井地方法務局');
ok($zip->set_number('9108507')->is_valid_number, '福井大学');
ok($zip->set_number('9108508')->is_valid_number, '株式会社 ツチハシ');
ok($zip->set_number('9108509')->is_valid_number, '福井公共職業安定所');
ok($zip->set_number('9108510')->is_valid_number, '三谷商事 株式会社');
ok($zip->set_number('9108511')->is_valid_number, '福井市役所');
ok($zip->set_number('9108512')->is_valid_number, '福井経編興業 株式会社');
ok($zip->set_number('9108513')->is_valid_number, '特別養護老人ホーム藤島園');
ok($zip->set_number('9108514')->is_valid_number, '福井トヨペット 株式会社');
ok($zip->set_number('9108515')->is_valid_number, '福井県警察本部');
ok($zip->set_number('9108516')->is_valid_number, '社会福祉法人 福井県社会福祉協議会');
ok($zip->set_number('9108517')->is_valid_number, '北島商事 株式会社');
ok($zip->set_number('9108519')->is_valid_number, '福井財務事務所');
ok($zip->set_number('9108520')->is_valid_number, '坂川建設 株式会社');
ok($zip->set_number('9108521')->is_valid_number, '福井コンピューター');
ok($zip->set_number('9108522')->is_valid_number, '福井市役所 企業局');
ok($zip->set_number('9108523')->is_valid_number, 'やなぎや企業グループ');
ok($zip->set_number('9108524')->is_valid_number, '福井地方裁判所、福井家庭裁判所');
ok($zip->set_number('9108525')->is_valid_number, '福井大学 生活協同組合');
ok($zip->set_number('9108526')->is_valid_number, '福井県立病院');
ok($zip->set_number('9108527')->is_valid_number, 'カラヤ 株式会社 福井水道機材営業所');
ok($zip->set_number('9108528')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('9108530')->is_valid_number, '株式会社 松浦機械製作所');
ok($zip->set_number('9108532')->is_valid_number, '日本銀行 福井事務所');
ok($zip->set_number('9108533')->is_valid_number, '硝和硝子 株式会社');
ok($zip->set_number('9108535')->is_valid_number, '株式会社 ユース');
ok($zip->set_number('9108536')->is_valid_number, '株式会社 山口伊三郎家具');
ok($zip->set_number('9108537')->is_valid_number, '福井市中央卸売市場');
ok($zip->set_number('9108538')->is_valid_number, 'アロック・サンワ 株式会社');
ok($zip->set_number('9108539')->is_valid_number, '株式会社 法美社');
ok($zip->set_number('9108540')->is_valid_number, '石黒建設 株式会社');
ok($zip->set_number('9108541')->is_valid_number, '全国健康保険協会 福井支部');
ok($zip->set_number('9108542')->is_valid_number, '福井労働基準監督署');
ok($zip->set_number('9108543')->is_valid_number, '京福電気鉄道 株式会社');
ok($zip->set_number('9108544')->is_valid_number, '財団法人 福井県教育センター');
ok($zip->set_number('9108545')->is_valid_number, '株式会社 シバタ 福井支店');
ok($zip->set_number('9108548')->is_valid_number, '日本電信電話 株式会社 福井支店');
ok($zip->set_number('9108550')->is_valid_number, '大電産業 株式会社');
ok($zip->set_number('9108551')->is_valid_number, '福井県 衛生環境研究センター');
ok($zip->set_number('9108552')->is_valid_number, '株式会社 福井新聞社');
ok($zip->set_number('9108553')->is_valid_number, '福井エフエム放送 株式会社');
ok($zip->set_number('9108554')->is_valid_number, '福井県 市町村職員共済組合');
ok($zip->set_number('9108555')->is_valid_number, '福井県税事務所');
ok($zip->set_number('9108557')->is_valid_number, '福井県民生活協同組合');
ok($zip->set_number('9108558')->is_valid_number, '旭化成インターテキスタイルズ 株式会社');
ok($zip->set_number('9108559')->is_valid_number, '福井労働局');
ok($zip->set_number('9108560')->is_valid_number, '株式会社 ミルコン');
ok($zip->set_number('9108561')->is_valid_number, '福井総合病院');
ok($zip->set_number('9108562')->is_valid_number, '株式会社 メディアプラス風丸');
ok($zip->set_number('9108564')->is_valid_number, '福井県 厚生農業協同組合連合会');
ok($zip->set_number('9108565')->is_valid_number, '北陸電力 株式会社 福井支店');
ok($zip->set_number('9108566')->is_valid_number, '福井税務署');
ok($zip->set_number('9108567')->is_valid_number, '株式会社 日刊県民福井');
ok($zip->set_number('9108568')->is_valid_number, '株式会社 田中與商店');
ok($zip->set_number('9108571')->is_valid_number, '三谷セキサン 株式会社');
ok($zip->set_number('9108575')->is_valid_number, '税理士法人 合同経営会計事務所');
ok($zip->set_number('9108576')->is_valid_number, '飛島建設 株式会社 北陸支店');
ok($zip->set_number('9108578')->is_valid_number, '福井中央魚市 株式会社');
ok($zip->set_number('9108579')->is_valid_number, '福井日野自動車 株式会社');
ok($zip->set_number('9108580')->is_valid_number, '福井県庁');
ok($zip->set_number('9108581')->is_valid_number, '株式会社 ヤスサキ');
ok($zip->set_number('9108582')->is_valid_number, '(株) 西武百貨店 だるまや西武');
ok($zip->set_number('9108583')->is_valid_number, '福井地方検察庁');
ok($zip->set_number('9108584')->is_valid_number, '株式会社 明治屋 福井支店');
ok($zip->set_number('9108585')->is_valid_number, '株式会社 大西商事');
ok($zip->set_number('9108586')->is_valid_number, '株式会社 八木熊');
ok($zip->set_number('9108587')->is_valid_number, '日本テレシス 株式会社 中部福井本社');
ok($zip->set_number('9108588')->is_valid_number, '福井放送 株式会社');
ok($zip->set_number('9108589')->is_valid_number, '日本電信電話 株式会社 福井支店');
ok($zip->set_number('9108601')->is_valid_number, '大和證券 株式会社 福井支店');
ok($zip->set_number('9108603')->is_valid_number, '福井県農業協同組合中央会');
ok($zip->set_number('9108606')->is_valid_number, '(株) 福邦銀行');
ok($zip->set_number('9108610')->is_valid_number, '福井県信用漁業協同組合連合会');
ok($zip->set_number('9108611')->is_valid_number, '日本生命保険 相互会社 福井支社');
ok($zip->set_number('9108622')->is_valid_number, '吉岡幸 株式会社');
ok($zip->set_number('9108630')->is_valid_number, '住友生命保険 相互会社 福井支社');
ok($zip->set_number('9108650')->is_valid_number, '福井信用金庫');
ok($zip->set_number('9108655')->is_valid_number, '伊藤忠商事 株式会社 福井支店');
ok($zip->set_number('9108660')->is_valid_number, '株式会社 福井銀行');
ok($zip->set_number('9108665')->is_valid_number, '福井三菱自動車販売 株式会社');
ok($zip->set_number('9108666')->is_valid_number, '福井県 信用農業協同組合連合会');
ok($zip->set_number('9108670')->is_valid_number, '日華化学 株式会社');
ok($zip->set_number('9108678')->is_valid_number, '株式会社 かゞみや');
ok($zip->set_number('9108680')->is_valid_number, '日本放送協会 福井放送局');
ok($zip->set_number('9108686')->is_valid_number, '商工組合中央金庫 福井支店');
ok($zip->set_number('9108688')->is_valid_number, '福井県 共済農業協同組合連合会');
ok($zip->set_number('9108730')->is_valid_number, 'アクサ損害保険 株式会社 福井センター');
ok($zip->set_number('9118501')->is_valid_number, '勝山市役所');
ok($zip->set_number('9118510')->is_valid_number, 'ケイテー・テクシーノ 株式会社');
ok($zip->set_number('9118531')->is_valid_number, '松文産業 株式会社');
ok($zip->set_number('9118540')->is_valid_number, '福井県立 勝山高等学校');
ok($zip->set_number('9118555')->is_valid_number, '勝山ファーマ 株式会社');
ok($zip->set_number('9118558')->is_valid_number, '福井社会保険病院');
ok($zip->set_number('9118585')->is_valid_number, '株式会社 一本義久保本店');
ok($zip->set_number('9118601')->is_valid_number, '福井県立 恐竜博物館');
ok($zip->set_number('9120292')->is_valid_number, '大野市 和泉支所');
ok($zip->set_number('9128524')->is_valid_number, '大野簡易裁判所');
ok($zip->set_number('9128540')->is_valid_number, 'テラル越前農業共同組合');
ok($zip->set_number('9128555')->is_valid_number, '大野税務署');
ok($zip->set_number('9128567')->is_valid_number, '協同組合 大野商業開発 ショッピングモールVio');
ok($zip->set_number('9128585')->is_valid_number, '大野ショッピングセンター リブレ');
ok($zip->set_number('9128666')->is_valid_number, '大野市役所');
ok($zip->set_number('9128686')->is_valid_number, '越前信用金庫');
ok($zip->set_number('9138501')->is_valid_number, '坂井市役所 三国総合支所');
ok($zip->set_number('9138511')->is_valid_number, '坂井県税事務所');
ok($zip->set_number('9138533')->is_valid_number, '越前三国競艇企業団');
ok($zip->set_number('9138555')->is_valid_number, '福井県立 三国高等学校');
ok($zip->set_number('9138577')->is_valid_number, '三国観光産業 株式会社');
ok($zip->set_number('9138585')->is_valid_number, '三国税務署');
ok($zip->set_number('9138588')->is_valid_number, '古河スカイ (株) 福井工場');
ok($zip->set_number('9138611')->is_valid_number, '坂井市立 三国病院');
ok($zip->set_number('9140192')->is_valid_number, '財団法人 若狭湾エネルギー研究センター');
ok($zip->set_number('9140195')->is_valid_number, '独立行政法人 国立病院機構 福井病院');
ok($zip->set_number('9140198')->is_valid_number, '昭英高等学校');
ok($zip->set_number('9148501')->is_valid_number, '敦賀市役所');
ok($zip->set_number('9148502')->is_valid_number, '市立敦賀病院');
ok($zip->set_number('9148510')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構 原子炉廃止措置研究開発センター');
ok($zip->set_number('9148524')->is_valid_number, '福井地方裁判所敦賀支部、福井家庭裁判所敦賀支部、敦賀簡易裁判所、敦賀検察審査会');
ok($zip->set_number('9148540')->is_valid_number, '敦賀税務署');
ok($zip->set_number('9148550')->is_valid_number, '東洋紡 株式会社 敦賀事業所');
ok($zip->set_number('9148555')->is_valid_number, '日本原子力発電 株式会社 敦賀発電所');
ok($zip->set_number('9148558')->is_valid_number, '学校法人 嶺南学園敦賀気比高等学校');
ok($zip->set_number('9148567')->is_valid_number, '若狭松下電器 株式会社');
ok($zip->set_number('9148580')->is_valid_number, '福井社会保険事務局 敦賀事務所');
ok($zip->set_number('9148585')->is_valid_number, '国立研究開発法人 日本原子力研究開発機構 敦賀事業本部');
ok($zip->set_number('9148609')->is_valid_number, '敦賀公共職業安定所');
ok($zip->set_number('9148666')->is_valid_number, '株式会社 日本ピーエス');
ok($zip->set_number('9148686')->is_valid_number, '敦賀セメント 株式会社');
ok($zip->set_number('9148688')->is_valid_number, '敦賀信用金庫 本店');
ok($zip->set_number('9150292')->is_valid_number, '越前市 今立総合支所');
ok($zip->set_number('9151195')->is_valid_number, '南越前町 河野総合事務所');
ok($zip->set_number('9158501')->is_valid_number, '株式会社 ふじや食品');
ok($zip->set_number('9158510')->is_valid_number, '福井県 南越県税事務所');
ok($zip->set_number('9158511')->is_valid_number, '医療法人 林病院');
ok($zip->set_number('9158515')->is_valid_number, '信越化学工業 株式会社 武生工場');
ok($zip->set_number('9158520')->is_valid_number, '株式会社 アイシン福井');
ok($zip->set_number('9158524')->is_valid_number, '福井地方裁判所武生支部、福井家庭裁判所武生支部、武生簡易裁判所');
ok($zip->set_number('9158530')->is_valid_number, '越前市役所');
ok($zip->set_number('9158533')->is_valid_number, '武生税務署');
ok($zip->set_number('9158555')->is_valid_number, 'オリオン電機 株式会社');
ok($zip->set_number('9158577')->is_valid_number, 'キョーセー 株式会社');
ok($zip->set_number('9158585')->is_valid_number, '木原建設 株式会社');
ok($zip->set_number('9158586')->is_valid_number, '仁愛大学');
ok($zip->set_number('9158588')->is_valid_number, '丹南ケーブルテレビ 株式会社');
ok($zip->set_number('9158666')->is_valid_number, '株式会社 武生製麺');
ok($zip->set_number('9160192')->is_valid_number, '越前町役場');
ok($zip->set_number('9160292')->is_valid_number, '越前町役場織田総合事務所');
ok($zip->set_number('9160293')->is_valid_number, '越前町役場宮崎総合事務所');
ok($zip->set_number('9160295')->is_valid_number, '株式会社 福井村田製作所 宮崎工場');
ok($zip->set_number('9160492')->is_valid_number, '越前町役場 越前総合事務所');
ok($zip->set_number('9161198')->is_valid_number, '株式会社 福井クラフト');
ok($zip->set_number('9168501')->is_valid_number, '福井丹南農業協同組合 本店');
ok($zip->set_number('9168505')->is_valid_number, '青山眼鏡 株式会社');
ok($zip->set_number('9168507')->is_valid_number, '福井工業高等専門学校');
ok($zip->set_number('9168508')->is_valid_number, '福井めがね工業 株式会社');
ok($zip->set_number('9168510')->is_valid_number, '福井県立 鯖江高等学校');
ok($zip->set_number('9168515')->is_valid_number, '公立丹南病院');
ok($zip->set_number('9168550')->is_valid_number, 'ウラセ 株式会社');
ok($zip->set_number('9168555')->is_valid_number, '株式会社 シャルマン');
ok($zip->set_number('9168558')->is_valid_number, '株式会社 サンリーブ');
ok($zip->set_number('9168567')->is_valid_number, '有限会社 宝屋');
ok($zip->set_number('9168585')->is_valid_number, '社会福祉法人 光道園');
ok($zip->set_number('9168588')->is_valid_number, '鯖江商工会議所');
ok($zip->set_number('9168601')->is_valid_number, '株式会社 BBC');
ok($zip->set_number('9168646')->is_valid_number, '福井信用金庫 鯖江営業部');
ok($zip->set_number('9168666')->is_valid_number, '鯖江市役所');
ok($zip->set_number('9168686')->is_valid_number, '株式会社 キャンパック');
ok($zip->set_number('9170198')->is_valid_number, '国立 若狭湾青少年自然の家');
ok($zip->set_number('9170293')->is_valid_number, '福井県立 若狭東高等学校');
ok($zip->set_number('9170297')->is_valid_number, '福井県 嶺南振興局');
ok($zip->set_number('9170298')->is_valid_number, '有限会社 せいわ箸店');
ok($zip->set_number('9170398')->is_valid_number, '名田庄商会');
ok($zip->set_number('9178505')->is_valid_number, '株式会社 津田孫兵衛');
ok($zip->set_number('9178507')->is_valid_number, '若狭高等学校');
ok($zip->set_number('9178511')->is_valid_number, '小浜税務署');
ok($zip->set_number('9178512')->is_valid_number, 'ママーストアー');
ok($zip->set_number('9178524')->is_valid_number, '小浜簡易裁判所');
ok($zip->set_number('9178533')->is_valid_number, '小浜商工会議所');
ok($zip->set_number('9178544')->is_valid_number, '小浜公共職業安定所 (ハローワークおばま)');
ok($zip->set_number('9178550')->is_valid_number, '小浜海産物 株式会社');
ok($zip->set_number('9178555')->is_valid_number, '小浜水産高等学校');
ok($zip->set_number('9178558')->is_valid_number, '関西電力 株式会社 小浜営業所');
ok($zip->set_number('9178561')->is_valid_number, '有限会社 宇田川印刷');
ok($zip->set_number('9178567')->is_valid_number, '公立小浜病院');
ok($zip->set_number('9178577')->is_valid_number, '芝浦ハイテック 株式会社 小浜事業所');
ok($zip->set_number('9178580')->is_valid_number, '有限会社 田村長');
ok($zip->set_number('9178584')->is_valid_number, '株式会社 マツ勘');
ok($zip->set_number('9178585')->is_valid_number, '小浜市役所');
ok($zip->set_number('9178588')->is_valid_number, '日本電産テクノモータ 株式会社');
ok($zip->set_number('9178601')->is_valid_number, '小浜信用金庫');
ok($zip->set_number('9178686')->is_valid_number, '株式会社 福邦銀行 小浜支店');
ok($zip->set_number('9188501')->is_valid_number, '福井赤十字病院');
ok($zip->set_number('9188502')->is_valid_number, 'オー・ジー 株式会社 北陸支店');
ok($zip->set_number('9188503')->is_valid_number, '福井県 済生会病院');
ok($zip->set_number('9188505')->is_valid_number, 'アイローグ協同組合');
ok($zip->set_number('9188508')->is_valid_number, '株式会社 アイビックス');
ok($zip->set_number('9188509')->is_valid_number, '江守グループホールディングス 株式会社');
ok($zip->set_number('9188510')->is_valid_number, '興和江守 株式会社');
ok($zip->set_number('9188511')->is_valid_number, '山金工業 株式会社');
ok($zip->set_number('9188515')->is_valid_number, '清川メッキ工業 株式会社');
ok($zip->set_number('9188518')->is_valid_number, '福井県 社会保険診療報酬支払基金');
ok($zip->set_number('9188520')->is_valid_number, 'エネックス 株式会社');
ok($zip->set_number('9188522')->is_valid_number, '日本マイヤー 株式会社');
ok($zip->set_number('9188523')->is_valid_number, '福井日産自動車 株式会社');
ok($zip->set_number('9188525')->is_valid_number, '株式会社 サンワコン');
ok($zip->set_number('9188530')->is_valid_number, 'サカイオーベックス 株式会社');
ok($zip->set_number('9188533')->is_valid_number, 'フクイボウ 株式会社');
ok($zip->set_number('9188537')->is_valid_number, '医療法人 厚生会 福井厚生病院');
ok($zip->set_number('9188540')->is_valid_number, '福井健康福祉センター');
ok($zip->set_number('9188543')->is_valid_number, '株式会社 北川');
ok($zip->set_number('9188550')->is_valid_number, '轟産業 株式会社');
ok($zip->set_number('9188552')->is_valid_number, '株式会社 山内');
ok($zip->set_number('9188555')->is_valid_number, '北陸農政局 福井農政事務所');
ok($zip->set_number('9188556')->is_valid_number, '株式会社 ミタス');
ok($zip->set_number('9188558')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('9188560')->is_valid_number, 'セーレン 株式会社');
ok($zip->set_number('9188565')->is_valid_number, '産建機械リース 株式会社');
ok($zip->set_number('9188566')->is_valid_number, '中島管材鋼機 株式会社');
ok($zip->set_number('9188567')->is_valid_number, '福井県 森林組合連合会');
ok($zip->set_number('9188568')->is_valid_number, '福井トヨタ自動車 株式会社');
ok($zip->set_number('9188570')->is_valid_number, '株式会社 ニッセン 福井ロジスティックセンター');
ok($zip->set_number('9188575')->is_valid_number, '福井県立 道守高等学校');
ok($zip->set_number('9188577')->is_valid_number, 'ショッピングシティ ベル');
ok($zip->set_number('9188578')->is_valid_number, '塩田食品 株式会社');
ok($zip->set_number('9188580')->is_valid_number, '福井商工会議所');
ok($zip->set_number('9188583')->is_valid_number, '株式会社 パスポート');
ok($zip->set_number('9188585')->is_valid_number, 'フクビ化学工業 株式会社');
ok($zip->set_number('9188586')->is_valid_number, 'アピタ 福井店');
ok($zip->set_number('9188588')->is_valid_number, '株式会社 アタゴ');
ok($zip->set_number('9188668')->is_valid_number, '広撚 株式会社');
ok($zip->set_number('9188681')->is_valid_number, '株式会社 ミツノリ');
ok($zip->set_number('9188686')->is_valid_number, '株式会社 福井銀行事務センター');
ok($zip->set_number('9188688')->is_valid_number, '福井テレビジョン放送 株式会社');
ok($zip->set_number('9190192')->is_valid_number, '南越前町 今庄総合事務所');
ok($zip->set_number('9190292')->is_valid_number, '南越前町役場');
ok($zip->set_number('9190492')->is_valid_number, '坂井市役所 春江総合支所');
ok($zip->set_number('9190592')->is_valid_number, '坂井市役所');
ok($zip->set_number('9190594')->is_valid_number, '株式会社 村井物流センター');
ok($zip->set_number('9190595')->is_valid_number, '株式会社 村井');
ok($zip->set_number('9190597')->is_valid_number, '福井県農業協同組合 坂井基幹支店');
ok($zip->set_number('9190598')->is_valid_number, '株式会社 ソディック 福井事業所');
ok($zip->set_number('9190692')->is_valid_number, 'あわら市役所');
ok($zip->set_number('9190695')->is_valid_number, '株式会社 エイチアンドエフ');
ok($zip->set_number('9190697')->is_valid_number, 'パナソニックエレクトロニックデバイス福井 株式会社');
ok($zip->set_number('9190698')->is_valid_number, 'レンゴー 株式会社 金津事業所');
ok($zip->set_number('9190898')->is_valid_number, '福井鋲螺 株式会社');
ok($zip->set_number('9191192')->is_valid_number, '美浜町役場');
ok($zip->set_number('9191392')->is_valid_number, 'レイクヒルズ美方病院');
ok($zip->set_number('9191393')->is_valid_number, '若狭町役場 三方庁舎');
ok($zip->set_number('9191395')->is_valid_number, '福井県立 美方高等学校');
ok($zip->set_number('9191396')->is_valid_number, '株式会社 前田産業');
ok($zip->set_number('9191397')->is_valid_number, 'デンヨー 株式会社 福井工場');
ok($zip->set_number('9191592')->is_valid_number, '若狭町役場 上中庁舎');
ok($zip->set_number('9192292')->is_valid_number, '高浜町役場');
ok($zip->set_number('9192293')->is_valid_number, '若狭高浜病院');
ok($zip->set_number('9192294')->is_valid_number, '高浜社会保険介護老人保健施設');
ok($zip->set_number('9192392')->is_valid_number, '関西電力 株式会社 高浜発電所');
ok($zip->set_number('9200192')->is_valid_number, '独立行政法人 国立病院機構 医王病院');
ok($zip->set_number('9200292')->is_valid_number, '内灘町役場');
ok($zip->set_number('9200293')->is_valid_number, '金沢医科大学');
ok($zip->set_number('9200295')->is_valid_number, '株式会社 ファイネス');
ok($zip->set_number('9200381')->is_valid_number, '北菱電興 株式会社');
ok($zip->set_number('9200383')->is_valid_number, '石川県 農業会館');
ok($zip->set_number('9200385')->is_valid_number, '丸文通商 株式会社');
ok($zip->set_number('9200386')->is_valid_number, 'テレビ金沢');
ok($zip->set_number('9200387')->is_valid_number, '石川テレメッセージ');
ok($zip->set_number('9200388')->is_valid_number, '石川テレビ放送 株式会社');
ok($zip->set_number('9200392')->is_valid_number, '明祥 株式会社');
ok($zip->set_number('9200393')->is_valid_number, '北陸朝日放送 株式会社');
ok($zip->set_number('9200395')->is_valid_number, '金沢トラックターミナル');
ok($zip->set_number('9200396')->is_valid_number, '日成ビルド工業 株式会社');
ok($zip->set_number('9200398')->is_valid_number, '株式会社 石川コンピュータセンター');
ok($zip->set_number('9201180')->is_valid_number, '北陸大学');
ok($zip->set_number('9201181')->is_valid_number, '北陸大学 薬学部');
ok($zip->set_number('9201182')->is_valid_number, '金沢刑務所');
ok($zip->set_number('9201184')->is_valid_number, 'イオンリテール 株式会社 イオンもりの里店');
ok($zip->set_number('9201185')->is_valid_number, '医療法人 十全会');
ok($zip->set_number('9201192')->is_valid_number, '金沢大学 (角間キャンパス)');
ok($zip->set_number('9201392')->is_valid_number, '金沢学院大学');
ok($zip->set_number('9201393')->is_valid_number, '金沢学院大学付属高等学校');
ok($zip->set_number('9201396')->is_valid_number, '北陸学院短期大学');
ok($zip->set_number('9201397')->is_valid_number, '石川県立 辰巳丘高等学校');
ok($zip->set_number('9202192')->is_valid_number, '白山市鶴来支所');
ok($zip->set_number('9202195')->is_valid_number, '中村留精密工業 株式会社');
ok($zip->set_number('9202196')->is_valid_number, '中村留精密工業 株式会社 エヌテック事業部');
ok($zip->set_number('9202392')->is_valid_number, '白山市 河内市民サービスセンター');
ok($zip->set_number('9202393')->is_valid_number, '白山市 鳥越市民サービスセンター');
ok($zip->set_number('9202394')->is_valid_number, '白山市 吉野谷市民サービスセンター');
ok($zip->set_number('9202395')->is_valid_number, '白山市 尾口市民サービスセンター');
ok($zip->set_number('9203198')->is_valid_number, '石川県 農業総合研究センター');
ok($zip->set_number('9208501')->is_valid_number, '富士フイルムビジネスイノベーションジャパン 株式会社');
ok($zip->set_number('9208502')->is_valid_number, '荒木商事 株式会社');
ok($zip->set_number('9208503')->is_valid_number, 'ヤギコーポレーション');
ok($zip->set_number('9208504')->is_valid_number, '丸与商事 株式会社');
ok($zip->set_number('9208505')->is_valid_number, '金沢税務署');
ok($zip->set_number('9208507')->is_valid_number, '大正製薬 株式会社 中日本支店 金沢事業所');
ok($zip->set_number('9208508')->is_valid_number, '北陸鉄道 株式会社');
ok($zip->set_number('9208509')->is_valid_number, '金沢21世紀美術館');
ok($zip->set_number('9208510')->is_valid_number, '東和工業 株式会社');
ok($zip->set_number('9208511')->is_valid_number, 'NTT西日本 金沢支店 パーソナルユーザ営業部 コレクティングセンタ');
ok($zip->set_number('9208512')->is_valid_number, 'アイ・オー・データ機器 本社');
ok($zip->set_number('9208513')->is_valid_number, '株式会社 アイ・オー・データ機器');
ok($zip->set_number('9208515')->is_valid_number, '株式会社 ほくつう');
ok($zip->set_number('9208516')->is_valid_number, 'イオンリテール 株式会社 金沢フォーラス');
ok($zip->set_number('9208517')->is_valid_number, '石川県 社会保険診療報酬支払基金');
ok($zip->set_number('9208518')->is_valid_number, 'ANAクラウンプラザホテル金沢');
ok($zip->set_number('9208520')->is_valid_number, '金沢合繊 株式会社');
ok($zip->set_number('9208521')->is_valid_number, '(株) 平和堂アル・プラザ金沢');
ok($zip->set_number('9208522')->is_valid_number, '株式会社 東京ストアー');
ok($zip->set_number('9208525')->is_valid_number, '疋田産業 株式会社');
ok($zip->set_number('9208530')->is_valid_number, '石川県立 中央病院');
ok($zip->set_number('9208531')->is_valid_number, 'ウロコ水産 株式会社');
ok($zip->set_number('9208533')->is_valid_number, '金沢市保健所');
ok($zip->set_number('9208535')->is_valid_number, '株式会社 ヨシカワ');
ok($zip->set_number('9208536')->is_valid_number, '東京海上火災保険 株式会社');
ok($zip->set_number('9208537')->is_valid_number, 'ジャパンプレミアム 株式会社');
ok($zip->set_number('9208538')->is_valid_number, '松村物産 株式会社');
ok($zip->set_number('9208539')->is_valid_number, '冨木医療器 株式会社');
ok($zip->set_number('9208540')->is_valid_number, '北邦医薬 株式会社');
ok($zip->set_number('9208541')->is_valid_number, 'アパ 株式会社');
ok($zip->set_number('9208543')->is_valid_number, '北村電機産業 株式会社');
ok($zip->set_number('9208544')->is_valid_number, '全労済 石川県本部');
ok($zip->set_number('9208550')->is_valid_number, '大和 香林坊店');
ok($zip->set_number('9208551')->is_valid_number, '聖霊病院');
ok($zip->set_number('9208552')->is_valid_number, '北陸労働金庫 本店営業部');
ok($zip->set_number('9208553')->is_valid_number, '石川県警察本部');
ok($zip->set_number('9208554')->is_valid_number, '学校法人 飛翔 金沢情報ビジネス専門学校');
ok($zip->set_number('9208555')->is_valid_number, '石川県 市町村職員共済組合');
ok($zip->set_number('9208556')->is_valid_number, '株式会社 北陸アイティエス');
ok($zip->set_number('9208557')->is_valid_number, '石川県 社会福祉会館');
ok($zip->set_number('9208558')->is_valid_number, '損害保険ジャパン 株式会社 北陸保険金サービス部北陸車両保険金サービス課');
ok($zip->set_number('9208560')->is_valid_number, '北陸放送 株式会社');
ok($zip->set_number('9208563')->is_valid_number, '北陸学院高等学校');
ok($zip->set_number('9208565')->is_valid_number, '寿観光 株式会社');
ok($zip->set_number('9208566')->is_valid_number, '北陸農政局');
ok($zip->set_number('9208567')->is_valid_number, '株式会社 シミズシンテック');
ok($zip->set_number('9208568')->is_valid_number, 'ヨシダ宣伝 株式会社');
ok($zip->set_number('9208570')->is_valid_number, '清水建設 株式会社 北陸支店');
ok($zip->set_number('9208573')->is_valid_number, '中日新聞社 北陸本社');
ok($zip->set_number('9208575')->is_valid_number, '石川県教育委員会');
ok($zip->set_number('9208577')->is_valid_number, '金沢市役所');
ok($zip->set_number('9208580')->is_valid_number, '石川県庁');
ok($zip->set_number('9208583')->is_valid_number, '金沢名鉄丸越百貨店');
ok($zip->set_number('9208585')->is_valid_number, '石川県 金沢県税事務所');
ok($zip->set_number('9208586')->is_valid_number, '金沢国税局');
ok($zip->set_number('9208587')->is_valid_number, '積水ハウス 株式会社');
ok($zip->set_number('9208588')->is_valid_number, '株式会社 北國新聞社');
ok($zip->set_number('9208601')->is_valid_number, '株式会社 石川トヨペットカローラ');
ok($zip->set_number('9208602')->is_valid_number, '丸紅 株式会社');
ok($zip->set_number('9208605')->is_valid_number, '株式会社 エフエム石川');
ok($zip->set_number('9208606')->is_valid_number, '株式会社 浅村');
ok($zip->set_number('9208607')->is_valid_number, '石川三菱自動車販売 株式会社');
ok($zip->set_number('9208609')->is_valid_number, '金沢公共職業安定所 (ハローワーク金沢)');
ok($zip->set_number('9208610')->is_valid_number, '独立行政法人 地域医療機能推進機構 金沢病院');
ok($zip->set_number('9208611')->is_valid_number, '株式会社 ADI.G');
ok($zip->set_number('9208612')->is_valid_number, '株式会社 ナルックス');
ok($zip->set_number('9208613')->is_valid_number, 'イオン金沢示野ショッピングセンター');
ok($zip->set_number('9208614')->is_valid_number, '北陸労働金庫');
ok($zip->set_number('9208615')->is_valid_number, '能崎物産 株式会社');
ok($zip->set_number('9208616')->is_valid_number, '城北病院');
ok($zip->set_number('9208619')->is_valid_number, '株式会社 エヌ・ティ・ティ・データ北陸');
ok($zip->set_number('9208620')->is_valid_number, '学校法人 稲置学園 金沢星稜大学');
ok($zip->set_number('9208621')->is_valid_number, '浅ノ川総合病院');
ok($zip->set_number('9208622')->is_valid_number, '加州建設 株式会社');
ok($zip->set_number('9208623')->is_valid_number, '株式会社 日産サティオ石川');
ok($zip->set_number('9208625')->is_valid_number, '株式会社 南商店');
ok($zip->set_number('9208628')->is_valid_number, '株式会社 ヰセキ関西中部北陸支社');
ok($zip->set_number('9208630')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ北陸');
ok($zip->set_number('9208631')->is_valid_number, '三井海上火災保険 株式会社');
ok($zip->set_number('9208632')->is_valid_number, '住友生命保険 相互会社 金沢支社');
ok($zip->set_number('9208633')->is_valid_number, '一村産業 株式会社');
ok($zip->set_number('9208637')->is_valid_number, '住宅金融支援機構 北陸支店');
ok($zip->set_number('9208638')->is_valid_number, '株式会社 福光屋');
ok($zip->set_number('9208639')->is_valid_number, '金沢商工会議所');
ok($zip->set_number('9208640')->is_valid_number, '金沢大学 医学部');
ok($zip->set_number('9208641')->is_valid_number, '金沢大学 附属病院');
ok($zip->set_number('9208642')->is_valid_number, '日立クレジット 株式会社 北信越営業本部');
ok($zip->set_number('9208644')->is_valid_number, '日本放送協会 金沢放送局');
ok($zip->set_number('9208648')->is_valid_number, '国土交通省 北陸地方整備局 金沢工事事務所');
ok($zip->set_number('9208650')->is_valid_number, '独立行政法人 国立病院機構金沢医療センター');
ok($zip->set_number('9208654')->is_valid_number, '医療法人財団 松原愛育会 松原病院');
ok($zip->set_number('9208655')->is_valid_number, '金沢家庭裁判所');
ok($zip->set_number('9208655')->is_valid_number, '金沢簡易裁判所');
ok($zip->set_number('9208655')->is_valid_number, '金沢検察審査会');
ok($zip->set_number('9208655')->is_valid_number, '金沢地方裁判所');
ok($zip->set_number('9208655')->is_valid_number, '名古屋高等裁判所 金沢支部');
ok($zip->set_number('9208656')->is_valid_number, '金沢美術工芸大学');
ok($zip->set_number('9208657')->is_valid_number, 'ユニベール 株式会社');
ok($zip->set_number('9208658')->is_valid_number, 'シンコール 株式会社');
ok($zip->set_number('9208660')->is_valid_number, '石川県医師会');
ok($zip->set_number('9208661')->is_valid_number, '株式会社 ウィルコム金沢営業所');
ok($zip->set_number('9208665')->is_valid_number, '株式会社 山越');
ok($zip->set_number('9208666')->is_valid_number, '日動火災海上保険 株式会社 金沢支店');
ok($zip->set_number('9208670')->is_valid_number, '株式会社 FDアドバイザリー');
ok($zip->set_number('9208670')->is_valid_number, '株式会社 CCイノベーション');
ok($zip->set_number('9208670')->is_valid_number, '株式会社 北國銀行');
ok($zip->set_number('9208670')->is_valid_number, '株式会社 北國フィナンシャルホールディングス');
ok($zip->set_number('9208671')->is_valid_number, '商工組合中央金庫 金沢支店');
ok($zip->set_number('9208674')->is_valid_number, 'はくさん信用金庫');
ok($zip->set_number('9208676')->is_valid_number, '蝶理 株式会社 北陸支店');
ok($zip->set_number('9208677')->is_valid_number, '前多 株式会社');
ok($zip->set_number('9208678')->is_valid_number, '日本銀行 金沢支店');
ok($zip->set_number('9208681')->is_valid_number, '澁谷工業 株式会社');
ok($zip->set_number('9208685')->is_valid_number, '三谷産業 株式会社');
ok($zip->set_number('9208686')->is_valid_number, '株式会社 北陸銀行 金沢支店');
ok($zip->set_number('9208688')->is_valid_number, '株式会社 金沢ニューグランドホテル');
ok($zip->set_number('9208701')->is_valid_number, '大和証券 株式会社 金沢支店');
ok($zip->set_number('9208707')->is_valid_number, '伊藤忠商事 株式会社 金沢支店');
ok($zip->set_number('9208710')->is_valid_number, '金沢信用金庫');
ok($zip->set_number('9208711')->is_valid_number, 'ホクショー 株式会社');
ok($zip->set_number('9208718')->is_valid_number, '三井住友信託銀行 株式会社 金沢支店');
ok($zip->set_number('9208719')->is_valid_number, '丸果石川中央青果 株式会社');
ok($zip->set_number('9208721')->is_valid_number, '株式会社 熊谷組 北陸支店');
ok($zip->set_number('9208728')->is_valid_number, '真柄建設 株式会社');
ok($zip->set_number('9208729')->is_valid_number, '信金中央金庫 北陸支店');
ok($zip->set_number('9208730')->is_valid_number, '野村證券 (株) 金沢支店');
ok($zip->set_number('9208767')->is_valid_number, '全国健康保険協会 石川支部');
ok($zip->set_number('9208777')->is_valid_number, '財団法人 ポスタルサービスセンター 北陸地方本部');
ok($zip->set_number('9208777')->is_valid_number, '郵便局 株式会社 カタログ販売センター');
ok($zip->set_number('9208793')->is_valid_number, '日本郵便 株式会社 北陸支社 郵便事業本部 (三種)');
ok($zip->set_number('9208794')->is_valid_number, '金沢貯金事務センター');
ok($zip->set_number('9208795')->is_valid_number, '北陸総合通信局');
ok($zip->set_number('9208796')->is_valid_number, '石川監査室');
ok($zip->set_number('9208797')->is_valid_number, '株式会社 ゆうちょ銀行 金沢支店');
ok($zip->set_number('9208797')->is_valid_number, '株式会社 かんぽ生命 金沢支店');
ok($zip->set_number('9208797')->is_valid_number, '日本郵便 株式会社 北陸支社');
ok($zip->set_number('9218501')->is_valid_number, '学校法人 金沢工業大学');
ok($zip->set_number('9218505')->is_valid_number, '金沢地方法務局');
ok($zip->set_number('9218506')->is_valid_number, '自衛隊 石川地方協力本部');
ok($zip->set_number('9218507')->is_valid_number, '北陸農政局 土地改良技術事務所');
ok($zip->set_number('9218508')->is_valid_number, '北陸財務局');
ok($zip->set_number('9218510')->is_valid_number, '野々市市役所');
ok($zip->set_number('9218511')->is_valid_number, '社団法人 石川県自動車整備振興会');
ok($zip->set_number('9218512')->is_valid_number, 'K.K. えふえむ・エヌ・ワン');
ok($zip->set_number('9218515')->is_valid_number, '学校法人 金沢高等学校');
ok($zip->set_number('9218517')->is_valid_number, '石川県立 金沢泉丘高等学校');
ok($zip->set_number('9218518')->is_valid_number, '株式会社 ヤマチク');
ok($zip->set_number('9218520')->is_valid_number, '陸上自衛隊 金沢駐屯地');
ok($zip->set_number('9218523')->is_valid_number, '株式会社 味の近岡屋');
ok($zip->set_number('9218525')->is_valid_number, '有限会社 ゴルフ情報センター');
ok($zip->set_number('9218526')->is_valid_number, '菱機工業 株式会社');
ok($zip->set_number('9218527')->is_valid_number, '株式会社 カンポトラベル');
ok($zip->set_number('9218529')->is_valid_number, '津田駒工業 株式会社 野々市工場');
ok($zip->set_number('9218530')->is_valid_number, '倉庫精練 株式会社');
ok($zip->set_number('9218531')->is_valid_number, '株式会社 ジェスクホリウチ');
ok($zip->set_number('9218532')->is_valid_number, '喜多ハウジング 株式会社');
ok($zip->set_number('9218536')->is_valid_number, '第一電機工業 株式会社');
ok($zip->set_number('9218539')->is_valid_number, '北陸スバル自動車 株式会社');
ok($zip->set_number('9218541')->is_valid_number, '株式会社 四十萬谷本舗');
ok($zip->set_number('9218544')->is_valid_number, '株式会社 モリワン');
ok($zip->set_number('9218546')->is_valid_number, 'ヨシダ印刷 株式会社');
ok($zip->set_number('9218548')->is_valid_number, '株式会社 柴舟 小出');
ok($zip->set_number('9218550')->is_valid_number, '株式会社 長府製作所 金沢営業所');
ok($zip->set_number('9218552')->is_valid_number, '東亜電機工業 株式会社');
ok($zip->set_number('9218555')->is_valid_number, '株式会社 辻さく');
ok($zip->set_number('9218560')->is_valid_number, '株式会社 太陽ゴルフ');
ok($zip->set_number('9218561')->is_valid_number, '株式会社 金太');
ok($zip->set_number('9218562')->is_valid_number, '(株) 金沢倶楽部');
ok($zip->set_number('9218564')->is_valid_number, '株式会社 高井製作所');
ok($zip->set_number('9218565')->is_valid_number, '株式会社 浅田屋金沢国際ホテル');
ok($zip->set_number('9218571')->is_valid_number, '株式会社 シンヤ (ふくら屋)');
ok($zip->set_number('9218572')->is_valid_number, '石川トヨタ自動車 株式会社');
ok($zip->set_number('9218573')->is_valid_number, '株式会社 石川トヨペットカローラ トヨタカローラ石川会社');
ok($zip->set_number('9218574')->is_valid_number, '協和道路 株式会社');
ok($zip->set_number('9218575')->is_valid_number, '株式会社 アイワホーム');
ok($zip->set_number('9218576')->is_valid_number, '株式会社 プロ保険');
ok($zip->set_number('9218577')->is_valid_number, '株式会社 大日製作所');
ok($zip->set_number('9218579')->is_valid_number, 'パナホーム 株式会社 北陸支店');
ok($zip->set_number('9218580')->is_valid_number, '株式会社 カヨウ');
ok($zip->set_number('9218581')->is_valid_number, '株式会社 みやもり');
ok($zip->set_number('9218582')->is_valid_number, '株式会社 ハチバン');
ok($zip->set_number('9218583')->is_valid_number, 'オートバックス 入江店');
ok($zip->set_number('9218584')->is_valid_number, '北川ヒューテック 株式会社');
ok($zip->set_number('9218585')->is_valid_number, '株式会社 うつのみや');
ok($zip->set_number('9218588')->is_valid_number, '米沢電気工事 株式会社');
ok($zip->set_number('9218589')->is_valid_number, '株式会社 ぶった農産');
ok($zip->set_number('9218601')->is_valid_number, '金沢工業高等専門学校');
ok($zip->set_number('9218616')->is_valid_number, '北陸ミサワホーム 株式会社 西金沢支店');
ok($zip->set_number('9218620')->is_valid_number, 'ネッツトヨタ石川 株式会社');
ok($zip->set_number('9218621')->is_valid_number, '東大セミナー金沢校');
ok($zip->set_number('9218630')->is_valid_number, '倉庫精練 株式会社 第二事業部 (米丸工場)');
ok($zip->set_number('9218637')->is_valid_number, '東大セミナー高等部');
ok($zip->set_number('9218639')->is_valid_number, '宗教法人 妙立寺');
ok($zip->set_number('9218650')->is_valid_number, '津田駒工業 株式会社');
ok($zip->set_number('9218798')->is_valid_number, '北陸郵政研修センター');
ok($zip->set_number('9220192')->is_valid_number, '加賀市 山中温泉支所');
ok($zip->set_number('9220193')->is_valid_number, '山中温泉ぬくもり診療所');
ok($zip->set_number('9220293')->is_valid_number, '雄山閣');
ok($zip->set_number('9220294')->is_valid_number, '湯快リゾート 株式会社 山代温泉 彩朝楽');
ok($zip->set_number('9220295')->is_valid_number, 'よろづや観光 (株) 瑠璃光');
ok($zip->set_number('9220297')->is_valid_number, '加賀の本陣 山下家');
ok($zip->set_number('9220298')->is_valid_number, 'ゆのくに天祥');
ok($zip->set_number('9220495')->is_valid_number, '協同組合 加賀ターミナルセンター');
ok($zip->set_number('9220497')->is_valid_number, '加賀農業協同組合');
ok($zip->set_number('9220595')->is_valid_number, '株式会社 ソディック 加賀事業所');
ok($zip->set_number('9228501')->is_valid_number, '久藤病院');
ok($zip->set_number('9228510')->is_valid_number, '石川県立 大聖寺高等学校');
ok($zip->set_number('9228511')->is_valid_number, '月うさぎの里');
ok($zip->set_number('9228522')->is_valid_number, '加賀市医療センター');
ok($zip->set_number('9228525')->is_valid_number, '大聖寺実業高等学校');
ok($zip->set_number('9228530')->is_valid_number, '鹿野漆器 株式会社');
ok($zip->set_number('9228550')->is_valid_number, '九谷宗山');
ok($zip->set_number('9228555')->is_valid_number, '株式会社 正和');
ok($zip->set_number('9228566')->is_valid_number, '九谷満月');
ok($zip->set_number('9228570')->is_valid_number, '株式会社 DMM.com Base');
ok($zip->set_number('9228585')->is_valid_number, 'フジセイカ');
ok($zip->set_number('9228588')->is_valid_number, '黒田建設 (株)');
ok($zip->set_number('9228609')->is_valid_number, '加賀公共職業安定所');
ok($zip->set_number('9228611')->is_valid_number, '株式会社 月星製作所');
ok($zip->set_number('9228622')->is_valid_number, '加賀市役所');
ok($zip->set_number('9228650')->is_valid_number, '加賀商工会議所');
ok($zip->set_number('9228678')->is_valid_number, '株式会社 江沼チェン製作所');
ok($zip->set_number('9228686')->is_valid_number, '大同工業');
ok($zip->set_number('9230392')->is_valid_number, 'コマツ粟津工場');
ok($zip->set_number('9230393')->is_valid_number, 'ゆのくにの森');
ok($zip->set_number('9230398')->is_valid_number, '加賀芙蓉カントリー倶楽部');
ok($zip->set_number('9231198')->is_valid_number, '能美市役所 寺井庁舎');
ok($zip->set_number('9231292')->is_valid_number, '北陸先端科学技術大学院大学');
ok($zip->set_number('9231293')->is_valid_number, '加賀東芝エレクトロニクス 株式会社');
ok($zip->set_number('9231294')->is_valid_number, '東レ 株式会社 石川工場');
ok($zip->set_number('9231295')->is_valid_number, '川北町役場');
ok($zip->set_number('9231296')->is_valid_number, '株式会社 ジャパンディスプレイ 石川工場');
ok($zip->set_number('9231297')->is_valid_number, '能美市役所 辰口庁舎');
ok($zip->set_number('9238501')->is_valid_number, '小松市立高等学校');
ok($zip->set_number('9238502')->is_valid_number, 'コマニー 株式会社');
ok($zip->set_number('9238503')->is_valid_number, '(株) 板尾鉄工所');
ok($zip->set_number('9238505')->is_valid_number, '森康 株式会社');
ok($zip->set_number('9238507')->is_valid_number, '医療法人社団 さくら会 森田病院');
ok($zip->set_number('9238510')->is_valid_number, '医療法人社団 東野会 東野病院');
ok($zip->set_number('9238511')->is_valid_number, '公立大学法人 公立小松大学');
ok($zip->set_number('9238520')->is_valid_number, '東亜電機工業 株式会社 P&Dセンター');
ok($zip->set_number('9238521')->is_valid_number, '株式会社 コマテック');
ok($zip->set_number('9238525')->is_valid_number, '三島石油 株式会社');
ok($zip->set_number('9238528')->is_valid_number, '北陸ジャスコ 新小松店');
ok($zip->set_number('9238530')->is_valid_number, '小松教習所 (株) 粟津センタ');
ok($zip->set_number('9238531')->is_valid_number, '石川県立 小松北高等学校');
ok($zip->set_number('9238533')->is_valid_number, 'KBセーレン 株式会社');
ok($zip->set_number('9238541')->is_valid_number, '金沢地方裁判所 小松支部');
ok($zip->set_number('9238544')->is_valid_number, 'アパ 株式会社 小松店');
ok($zip->set_number('9238545')->is_valid_number, '石川県立 小松明峰高等学校');
ok($zip->set_number('9238546')->is_valid_number, '株式会社 NTTデータNJK 北陸事業所');
ok($zip->set_number('9238550')->is_valid_number, '帝人加工糸 株式会社');
ok($zip->set_number('9238551')->is_valid_number, 'やわたメディカルセンター');
ok($zip->set_number('9238552')->is_valid_number, '特定医療法人社団 勝木会 芦城クリニック');
ok($zip->set_number('9238555')->is_valid_number, '石川県立 小松商業高等学校');
ok($zip->set_number('9238557')->is_valid_number, '株式会社 ワイエムシイ 小松事業所');
ok($zip->set_number('9238560')->is_valid_number, '小松市民病院');
ok($zip->set_number('9238565')->is_valid_number, 'イオンモール新小松');
ok($zip->set_number('9238566')->is_valid_number, '小松商工会議所');
ok($zip->set_number('9238567')->is_valid_number, '石川県立 小松工業高等学校');
ok($zip->set_number('9238570')->is_valid_number, '小松税務署');
ok($zip->set_number('9238575')->is_valid_number, 'ジェイ・バス 株式会社');
ok($zip->set_number('9238578')->is_valid_number, '第二松寿園');
ok($zip->set_number('9238580')->is_valid_number, 'ブレクスプロダクツ 株式会社');
ok($zip->set_number('9238581')->is_valid_number, '大京 株式会社');
ok($zip->set_number('9238586')->is_valid_number, '航空自衛隊 小松基地');
ok($zip->set_number('9238588')->is_valid_number, '株式会社 小松電業所');
ok($zip->set_number('9238601')->is_valid_number, '北陸体力科学研究所');
ok($zip->set_number('9238603')->is_valid_number, '株式会社 室戸鉄工所');
ok($zip->set_number('9238605')->is_valid_number, 'コマツエンジニアリング 株式会社');
ok($zip->set_number('9238606')->is_valid_number, '小松織物工業協同組合');
ok($zip->set_number('9238609')->is_valid_number, '小松公共職業安定所 (ハローワーク小松)');
ok($zip->set_number('9238610')->is_valid_number, 'サイエンスヒルズこまつ');
ok($zip->set_number('9238611')->is_valid_number, '小松市農業協同組合');
ok($zip->set_number('9238615')->is_valid_number, 'カナカン 株式会社 酒類小松営業所');
ok($zip->set_number('9238616')->is_valid_number, '篠岡建設 株式会社');
ok($zip->set_number('9238620')->is_valid_number, '株式会社 共和工業所');
ok($zip->set_number('9238626')->is_valid_number, '株式会社 小松村田製作所');
ok($zip->set_number('9238630')->is_valid_number, '財団法人 こまつ看護学校');
ok($zip->set_number('9238633')->is_valid_number, '日本電信電話 株式会社 小松支店');
ok($zip->set_number('9238639')->is_valid_number, '小松鋼機 株式会社');
ok($zip->set_number('9238640')->is_valid_number, 'Komatsu A×Z Square');
ok($zip->set_number('9238642')->is_valid_number, '小松電子 株式会社');
ok($zip->set_number('9238643')->is_valid_number, '小松ウオール工業 株式会社');
ok($zip->set_number('9238644')->is_valid_number, 'アル・プラザ小松');
ok($zip->set_number('9238646')->is_valid_number, '石川県立 小松高等学校');
ok($zip->set_number('9238650')->is_valid_number, '小松市役所');
ok($zip->set_number('9238666')->is_valid_number, 'コマツ小松工場');
ok($zip->set_number('9238686')->is_valid_number, '小倉織物 株式会社');
ok($zip->set_number('9238688')->is_valid_number, '株式会社 北國銀行 小松支店');
ok($zip->set_number('9248510')->is_valid_number, '株式会社 クスリのアオキ');
ok($zip->set_number('9248511')->is_valid_number, '金城大学');
ok($zip->set_number('9248522')->is_valid_number, '冨士工業 株式会社');
ok($zip->set_number('9248533')->is_valid_number, 'アイレムソフトウェアエンジニアリング 株式会社');
ok($zip->set_number('9248544')->is_valid_number, '石川県立 翠星高等学校');
ok($zip->set_number('9248555')->is_valid_number, '株式会社 パルタック 金沢支店');
ok($zip->set_number('9248558')->is_valid_number, '高松機械工業 株式会社');
ok($zip->set_number('9248560')->is_valid_number, '株式会社 別川製作所');
ok($zip->set_number('9248566')->is_valid_number, 'EIZO 株式会社');
ok($zip->set_number('9248577')->is_valid_number, '東邦ゴム工業 株式会社');
ok($zip->set_number('9248580')->is_valid_number, '株式会社 トランテックス');
ok($zip->set_number('9248585')->is_valid_number, '松任税務署');
ok($zip->set_number('9248588')->is_valid_number, '公立松任石川中央病院');
ok($zip->set_number('9248686')->is_valid_number, 'ニッコー 株式会社');
ok($zip->set_number('9248688')->is_valid_number, '白山市役所');
ok($zip->set_number('9248777')->is_valid_number, 'イオンモール白山');
ok($zip->set_number('9250193')->is_valid_number, '石川サンケン 株式会社 志賀工場');
ok($zip->set_number('9250198')->is_valid_number, '志賀町役場');
ok($zip->set_number('9250392')->is_valid_number, '株式会社 能登金剛センター');
ok($zip->set_number('9250498')->is_valid_number, '志賀町役場富来支所');
ok($zip->set_number('9250697')->is_valid_number, '平鍛造 株式会社');
ok($zip->set_number('9258501')->is_valid_number, '羽咋市役所');
ok($zip->set_number('9258502')->is_valid_number, '公立羽咋病院');
ok($zip->set_number('9258505')->is_valid_number, '羽咋郡市広域圏事務組合');
ok($zip->set_number('9258506')->is_valid_number, '社会福祉法人 羽咋市社会福祉協議会');
ok($zip->set_number('9258508')->is_valid_number, '千里浜観光開発 株式会社 千里浜レストハウス');
ok($zip->set_number('9258511')->is_valid_number, '羽咋郡市広域圏事務組合消防本部');
ok($zip->set_number('9258521')->is_valid_number, '石川県立 羽咋工業高等学校');
ok($zip->set_number('9258525')->is_valid_number, '能登千里浜国民休暇村');
ok($zip->set_number('9258530')->is_valid_number, '独立行政法人 国立青少年教育振興機構 国立能登青少年交流の家');
ok($zip->set_number('9258550')->is_valid_number, '石川県立 羽咋高等学校');
ok($zip->set_number('9258555')->is_valid_number, '株式会社 ハクイ村田製作所');
ok($zip->set_number('9258566')->is_valid_number, 'エイゾーナナオエムエス 株式会社');
ok($zip->set_number('9258567')->is_valid_number, '羽咋警察署');
ok($zip->set_number('9258585')->is_valid_number, '羽咋市商工会');
ok($zip->set_number('9258609')->is_valid_number, '羽咋公共職業安定所(ハローワーク羽咋)');
ok($zip->set_number('9258610')->is_valid_number, '株式会社 北陸銀行 羽咋支店');
ok($zip->set_number('9258620')->is_valid_number, '株式会社 北國銀行 羽咋支店');
ok($zip->set_number('9258688')->is_valid_number, '株式会社 朱鷺の台カントリー');
ok($zip->set_number('9260192')->is_valid_number, '株式会社 加賀屋');
ok($zip->set_number('9260292')->is_valid_number, '七尾市役所 能登島支所');
ok($zip->set_number('9260293')->is_valid_number, '能登島リゾート開発 株式会社');
ok($zip->set_number('9268501')->is_valid_number, '林ベニヤ 株式会社 七尾工場');
ok($zip->set_number('9268511')->is_valid_number, '日本年金機構 七尾年金事務所');
ok($zip->set_number('9268520')->is_valid_number, '金沢地方法務局 七尾支局');
ok($zip->set_number('9268531')->is_valid_number, '国立療養所 七尾病院');
ok($zip->set_number('9268540')->is_valid_number, 'NTT 七尾支店');
ok($zip->set_number('9268541')->is_valid_number, '金沢家庭裁判所 七尾支部');
ok($zip->set_number('9268541')->is_valid_number, '金沢地方裁判所 七尾支部');
ok($zip->set_number('9268541')->is_valid_number, '七尾簡易裁判所');
ok($zip->set_number('9268541')->is_valid_number, '七尾検察審査会');
ok($zip->set_number('9268545')->is_valid_number, '石川県立 七尾養護学校');
ok($zip->set_number('9268550')->is_valid_number, '七尾サンライフプラザ');
ok($zip->set_number('9268555')->is_valid_number, '石川県立 七尾東雲高等学校');
ok($zip->set_number('9268558')->is_valid_number, '北陸乳業 株式会社');
ok($zip->set_number('9268566')->is_valid_number, 'エイゾーナナオエスムス 株式会社');
ok($zip->set_number('9268585')->is_valid_number, '北陸電力 株式会社 七尾支店');
ok($zip->set_number('9268586')->is_valid_number, '石川県 中能登土木総合事務所');
ok($zip->set_number('9268588')->is_valid_number, '北陸電力 七尾大田火力発電所');
ok($zip->set_number('9268601')->is_valid_number, 'のと共栄信用金庫');
ok($zip->set_number('9268602')->is_valid_number, '株式会社 北国銀行 七尾支店');
ok($zip->set_number('9268603')->is_valid_number, '株式会社 スギヨ 本社事務所・北陸工場');
ok($zip->set_number('9268605')->is_valid_number, '社会医療法人財団 董仙会 恵寿総合病院');
ok($zip->set_number('9268609')->is_valid_number, '七尾公共職業安定所(ハローワーク七尾)');
ok($zip->set_number('9268610')->is_valid_number, '公立能登総合病院');
ok($zip->set_number('9268611')->is_valid_number, '七尾市役所');
ok($zip->set_number('9268642')->is_valid_number, '七尾商工会議所');
ok($zip->set_number('9268650')->is_valid_number, '株式会社 在沢組');
ok($zip->set_number('9268666')->is_valid_number, '株式会社 北陸銀行 七尾支店');
ok($zip->set_number('9268686')->is_valid_number, '七尾税務署');
ok($zip->set_number('9270292')->is_valid_number, '蔵谷工務店 株式会社');
ok($zip->set_number('9270293')->is_valid_number, '坂上電機製作所');
ok($zip->set_number('9270492')->is_valid_number, '能登町役場');
ok($zip->set_number('9270493')->is_valid_number, '興能信用金庫');
ok($zip->set_number('9270495')->is_valid_number, '公立宇出津総合病院');
ok($zip->set_number('9270695')->is_valid_number, '能登町役場 内浦総合支所');
ok($zip->set_number('9271295')->is_valid_number, '珠洲市役所');
ok($zip->set_number('9271297')->is_valid_number, '珠洲簡易裁判所 金沢家庭裁判所 珠洲出張所');
ok($zip->set_number('9272192')->is_valid_number, '輪島市役所 門前総合支所');
ok($zip->set_number('9272193')->is_valid_number, '石川県立 門前高等学校');
ok($zip->set_number('9278601')->is_valid_number, '穴水町役場');
ok($zip->set_number('9280392')->is_valid_number, '能登町役場 柳田総合支所');
ok($zip->set_number('9280393')->is_valid_number, '柳田温泉病院');
ok($zip->set_number('9280395')->is_valid_number, '社会福祉法人 清祥会 特別養護老人ホーム こすもす');
ok($zip->set_number('9288501')->is_valid_number, '輪島税務署');
ok($zip->set_number('9288502')->is_valid_number, '航空自衛隊 第23警戒群');
ok($zip->set_number('9288525')->is_valid_number, '輪島市役所');
ok($zip->set_number('9288541')->is_valid_number, '金沢家庭裁判所 輪島支部');
ok($zip->set_number('9288541')->is_valid_number, '金沢地方裁判所 輪島支部');
ok($zip->set_number('9288585')->is_valid_number, '市立輪島病院');
ok($zip->set_number('9288609')->is_valid_number, '穴水公共職業安定所 輪島出張所(ハローワーク輪島)');
ok($zip->set_number('9290192')->is_valid_number, '能美市役所 根上庁舎');
ok($zip->set_number('9290193')->is_valid_number, 'デクセリアルズ 株式会社 根上事業所');
ok($zip->set_number('9290198')->is_valid_number, '株式会社 富士精工本社');
ok($zip->set_number('9290292')->is_valid_number, '白山市美川支所');
ok($zip->set_number('9290296')->is_valid_number, 'DIC 株式会社 北陸工場');
ok($zip->set_number('9290392')->is_valid_number, '石川工業高等専門学校');
ok($zip->set_number('9290393')->is_valid_number, '津幡町役場');
ok($zip->set_number('9290492')->is_valid_number, '倶利伽羅不動寺');
ok($zip->set_number('9290493')->is_valid_number, 'シブヤアシナリー 株式会社');
ok($zip->set_number('9290494')->is_valid_number, 'タカラスタンダード 株式会社 北陸工場');
ok($zip->set_number('9290495')->is_valid_number, '有限会社 倶利伽羅そば普及協会');
ok($zip->set_number('9291192')->is_valid_number, '株式会社 PFU');
ok($zip->set_number('9291193')->is_valid_number, 'かほく市 七塚庁舎');
ok($zip->set_number('9291195')->is_valid_number, 'かほく市役所');
ok($zip->set_number('9291196')->is_valid_number, '株式会社 富士通ITプロダクツ');
ok($zip->set_number('9291198')->is_valid_number, '(株) イオンかほくショッピングセンター');
ok($zip->set_number('9291287')->is_valid_number, '株式会社 PFU ProDeSセンター');
ok($zip->set_number('9291292')->is_valid_number, 'かほく市高松庁舎');
ok($zip->set_number('9291293')->is_valid_number, '石川県立 こころの病院');
ok($zip->set_number('9291392')->is_valid_number, '宝逹志水町役場 押水庁舎');
ok($zip->set_number('9291393')->is_valid_number, '能登カントリークラブ');
ok($zip->set_number('9291394')->is_valid_number, '石川県立 宝達高等学校');
ok($zip->set_number('9291395')->is_valid_number, '三東観光 株式会社 千里浜カントリークラブ');
ok($zip->set_number('9291396')->is_valid_number, '見砂酒造 株式会社');
ok($zip->set_number('9291397')->is_valid_number, '株式会社 トミナガ');
ok($zip->set_number('9291492')->is_valid_number, '宝達志水町役場');
ok($zip->set_number('9291493')->is_valid_number, '三協マテリアル 株式会社 石川工場');
ok($zip->set_number('9291494')->is_valid_number, '参天製薬 株式会社 能登工場');
ok($zip->set_number('9291692')->is_valid_number, '中能登町役場 鹿西庁舎');
ok($zip->set_number('9291792')->is_valid_number, '中能登町役場 鳥屋庁舎');
ok($zip->set_number('9291892')->is_valid_number, '中能登町役場 鹿島庁舎');
ok($zip->set_number('9292192')->is_valid_number, '七尾市役所 田鶴浜支所');
ok($zip->set_number('9292195')->is_valid_number, '石川県立 田鶴浜高等学校');
ok($zip->set_number('9292292')->is_valid_number, '七尾市役所 中島支所');
ok($zip->set_number('9292392')->is_valid_number, '石川県 奥能登総合事務所');
ok($zip->set_number('9300193')->is_valid_number, '富山短期大学');
ok($zip->set_number('9300194')->is_valid_number, '富山大学杉谷(医薬系)キャンパス');
ok($zip->set_number('9300195')->is_valid_number, '富山大学附属図書館医薬学図書館');
ok($zip->set_number('9300196')->is_valid_number, '富山国際大学');
ok($zip->set_number('9300198')->is_valid_number, '株式会社 サンプラス');
ok($zip->set_number('9300292')->is_valid_number, '立山町役場');
ok($zip->set_number('9300293')->is_valid_number, '佐藤鉄工 株式会社');
ok($zip->set_number('9300298')->is_valid_number, '中越合金鋳工 株式会社');
ok($zip->set_number('9300393')->is_valid_number, '上市町役場');
ok($zip->set_number('9300394')->is_valid_number, '株式会社 池田模範堂');
ok($zip->set_number('9300395')->is_valid_number, '細川機業 株式会社');
ok($zip->set_number('9300397')->is_valid_number, '富士化学工業 株式会社');
ok($zip->set_number('9301292')->is_valid_number, '富山国際大学');
ok($zip->set_number('9301295')->is_valid_number, '株式会社 市川ゴルフ興業');
ok($zip->set_number('9301298')->is_valid_number, '富山国際職藝学園');
ok($zip->set_number('9301392')->is_valid_number, '富山市大山会館(大山行政サービスセンター・大山保健福祉センター)');
ok($zip->set_number('9302198')->is_valid_number, '富山市山田総合行政センター');
ok($zip->set_number('9308501')->is_valid_number, '富山県庁');
ok($zip->set_number('9308504')->is_valid_number, '住友生命保険 相互会社 富山支社');
ok($zip->set_number('9308505')->is_valid_number, '株式会社 大和 富山店');
ok($zip->set_number('9308506')->is_valid_number, '日本年金機構 富山事務センター');
ok($zip->set_number('9308507')->is_valid_number, '財団法人 北陸経済研究所');
ok($zip->set_number('9308508')->is_valid_number, '富山化学工業 (株) 富山事業所');
ok($zip->set_number('9308509')->is_valid_number, '富山労働局');
ok($zip->set_number('9308510')->is_valid_number, '富山市役所');
ok($zip->set_number('9308511')->is_valid_number, '株式会社 不二越');
ok($zip->set_number('9308512')->is_valid_number, '株式会社 宮本工業所');
ok($zip->set_number('9308513')->is_valid_number, '関西電力 (株) 北陸支社');
ok($zip->set_number('9308515')->is_valid_number, '佐藤工業 株式会社 北陸支店');
ok($zip->set_number('9308516')->is_valid_number, 'ネッツトヨタ富山 株式会社');
ok($zip->set_number('9308517')->is_valid_number, '富山県 市町村職員共済組合');
ok($zip->set_number('9308518')->is_valid_number, '北陸通信工業');
ok($zip->set_number('9308520')->is_valid_number, '富山新聞社');
ok($zip->set_number('9308521')->is_valid_number, '株式会社 西野');
ok($zip->set_number('9308522')->is_valid_number, '東京海上日動火災 株式会社 富山支店');
ok($zip->set_number('9308525')->is_valid_number, '北銀リース 株式会社');
ok($zip->set_number('9308526')->is_valid_number, '株式会社 日立ハウステック 富山工場');
ok($zip->set_number('9308527')->is_valid_number, '富山市立富山まちなか病院');
ok($zip->set_number('9308530')->is_valid_number, '富山税務署');
ok($zip->set_number('9308531')->is_valid_number, '株式会社 アピアシティ');
ok($zip->set_number('9308532')->is_valid_number, 'NTT 富山支店');
ok($zip->set_number('9308533')->is_valid_number, '国民金融公庫');
ok($zip->set_number('9308535')->is_valid_number, '富山県 経済農業協同組合連合会');
ok($zip->set_number('9308536')->is_valid_number, 'あいおい損害保険 株式会社');
ok($zip->set_number('9308537')->is_valid_number, '国土交通省 北陸地方整備局 富山河川国道事務所');
ok($zip->set_number('9308538')->is_valid_number, '富山県 国民健康保険団体連合会');
ok($zip->set_number('9308539')->is_valid_number, 'チューリップテレビ');
ok($zip->set_number('9308540')->is_valid_number, '富山県立 富山商業高等学校');
ok($zip->set_number('9308543')->is_valid_number, '北陸電力 株式会社 富山支店');
ok($zip->set_number('9308544')->is_valid_number, '県共済農業連合会');
ok($zip->set_number('9308545')->is_valid_number, '(株) シー・エー・ピー');
ok($zip->set_number('9308548')->is_valid_number, '富山県 総合県税事務所');
ok($zip->set_number('9308550')->is_valid_number, '県立中央病院');
ok($zip->set_number('9308552')->is_valid_number, 'ユアサ商事 株式会社');
ok($zip->set_number('9308554')->is_valid_number, '北陸財務局 富山財務事務所');
ok($zip->set_number('9308555')->is_valid_number, '富山大学');
ok($zip->set_number('9308556')->is_valid_number, '富山大学 教育学部附属学校');
ok($zip->set_number('9308558')->is_valid_number, '立山黒部貫光 株式会社');
ok($zip->set_number('9308560')->is_valid_number, '財団法人 富山県教職員厚生会');
ok($zip->set_number('9308561')->is_valid_number, '全国健康保険協会 富山支部');
ok($zip->set_number('9308562')->is_valid_number, '富山赤十字病院');
ok($zip->set_number('9308563')->is_valid_number, '全労済 富山県本部');
ok($zip->set_number('9308565')->is_valid_number, '富山県 信用保証協会');
ok($zip->set_number('9308566')->is_valid_number, '金岡忠商事 株式会社');
ok($zip->set_number('9308567')->is_valid_number, '富山FM放送');
ok($zip->set_number('9308570')->is_valid_number, '富山県警察本部');
ok($zip->set_number('9308571')->is_valid_number, '日本年金機構 富山年金事務所');
ok($zip->set_number('9308573')->is_valid_number, 'インテック');
ok($zip->set_number('9308575')->is_valid_number, '小竹金物 株式会社');
ok($zip->set_number('9308577')->is_valid_number, 'ITホールディングスグループ健康保険組合');
ok($zip->set_number('9308577')->is_valid_number, 'インテック企業年金基金');
ok($zip->set_number('9308577')->is_valid_number, '株式会社 インテック');
ok($zip->set_number('9308578')->is_valid_number, '富山県 市町村会館管理組合');
ok($zip->set_number('9308580')->is_valid_number, '株式会社 廣貫堂');
ok($zip->set_number('9308581')->is_valid_number, '富山商工会議所');
ok($zip->set_number('9308583')->is_valid_number, '日医工 株式会社');
ok($zip->set_number('9308585')->is_valid_number, '北日本放送 株式会社');
ok($zip->set_number('9308586')->is_valid_number, '有限会社 月世界本舗');
ok($zip->set_number('9308587')->is_valid_number, '河上金物 株式会社');
ok($zip->set_number('9308588')->is_valid_number, '日本海ガス 株式会社');
ok($zip->set_number('9308589')->is_valid_number, '内外薬品');
ok($zip->set_number('9308603')->is_valid_number, '丸三開発工機 株式会社');
ok($zip->set_number('9308604')->is_valid_number, '野村證券 株式会社 富山支店');
ok($zip->set_number('9308605')->is_valid_number, '株式会社 富山第一銀行');
ok($zip->set_number('9308610')->is_valid_number, '日本生命保険 相互会社 富山支社');
ok($zip->set_number('9308611')->is_valid_number, '大和証券 株式会社 富山支店');
ok($zip->set_number('9308630')->is_valid_number, '株式会社 富山第一銀行 本店');
ok($zip->set_number('9308636')->is_valid_number, '富山地方鉄道 (株)');
ok($zip->set_number('9308637')->is_valid_number, '株式会社 北陸銀行');
ok($zip->set_number('9308642')->is_valid_number, '株式会社 富山銀行 富山支店');
ok($zip->set_number('9308644')->is_valid_number, '株式会社 第四銀行 富山支店');
ok($zip->set_number('9308650')->is_valid_number, '北日本新聞社 営業局');
ok($zip->set_number('9308656')->is_valid_number, '株式会社 教育統計会');
ok($zip->set_number('9308660')->is_valid_number, '商工組合中央金庫 富山支店');
ok($zip->set_number('9308666')->is_valid_number, '明祥 株式会社');
ok($zip->set_number('9308667')->is_valid_number, '富山地鉄サービス 株式会社');
ok($zip->set_number('9308668')->is_valid_number, 'サカヰ産業 株式会社');
ok($zip->set_number('9308680')->is_valid_number, '株式会社 北日本新聞社');
ok($zip->set_number('9308681')->is_valid_number, '富山県 信用組合');
ok($zip->set_number('9308686')->is_valid_number, '北陸電力 株式会社 本店');
ok($zip->set_number('9308687')->is_valid_number, '北陸電力送配電 株式会社');
ok($zip->set_number('9318501')->is_valid_number, '富山医療生活協同組合');
ok($zip->set_number('9318502')->is_valid_number, '富山県立 富山東高等学校');
ok($zip->set_number('9318508')->is_valid_number, '日本通運 株式会社 富山港支店');
ok($zip->set_number('9318510')->is_valid_number, '東ソー 株式会社 富山事務所');
ok($zip->set_number('9318511')->is_valid_number, '株式会社 不二越マテリアル製造所');
ok($zip->set_number('9318515')->is_valid_number, '第一薬品工業 株式会社');
ok($zip->set_number('9318517')->is_valid_number, '富山県 高志リハビリテーション病院');
ok($zip->set_number('9318522')->is_valid_number, '日本海石油 株式会社');
ok($zip->set_number('9318523')->is_valid_number, 'UDトラックス 株式会社');
ok($zip->set_number('9318533')->is_valid_number, '富山県 済生会富山病院');
ok($zip->set_number('9318540')->is_valid_number, 'なのはな農業協同組合');
ok($zip->set_number('9318543')->is_valid_number, '株式会社 アライドマテリアル 富山製作所');
ok($zip->set_number('9318555')->is_valid_number, '大平洋ランダム 株式会社');
ok($zip->set_number('9318558')->is_valid_number, '富山県立 富山北部高等学校');
ok($zip->set_number('9318562')->is_valid_number, '富山県 運転教育センター');
ok($zip->set_number('9318571')->is_valid_number, '新日本海重工業 株式会社');
ok($zip->set_number('9318577')->is_valid_number, '昭和電工セラミックス 株式会社 富山工場');
ok($zip->set_number('9318585')->is_valid_number, '富山通運 株式会社');
ok($zip->set_number('9318588')->is_valid_number, '日本海コンクリート工業 株式会社');
ok($zip->set_number('9318601')->is_valid_number, '三菱ケミカル 株式会社 富山事業所');
ok($zip->set_number('9318688')->is_valid_number, '富山港湾運送 株式会社');
ok($zip->set_number('9320193')->is_valid_number, '株式会社 ゴールドウイン');
ok($zip->set_number('9320198')->is_valid_number, '株式会社 スズキ部品富山');
ok($zip->set_number('9320292')->is_valid_number, '南砺市役所 井波庁舎・南砺市 井波行政センター');
ok($zip->set_number('9320293')->is_valid_number, '南砺市地域包括医療ケア部');
ok($zip->set_number('9320298')->is_valid_number, '大建工業 株式会社');
ok($zip->set_number('9320392')->is_valid_number, '庄川温泉観光ホテル');
ok($zip->set_number('9320393')->is_valid_number, '砺波市 庄川支所');
ok($zip->set_number('9320395')->is_valid_number, '庄川町商工会');
ok($zip->set_number('9320396')->is_valid_number, '三楽園');
ok($zip->set_number('9320398')->is_valid_number, '第一編物');
ok($zip->set_number('9328501')->is_valid_number, 'アラセレース 株式会社');
ok($zip->set_number('9328502')->is_valid_number, '株式会社 エイゼット');
ok($zip->set_number('9328503')->is_valid_number, '公立学校共済組合 北陸中央病院');
ok($zip->set_number('9328505')->is_valid_number, '泉洋化工 株式会社');
ok($zip->set_number('9328508')->is_valid_number, '小矢部公共職業安定所');
ok($zip->set_number('9328510')->is_valid_number, 'ティ・エフ・シー 株式会社 北陸工場');
ok($zip->set_number('9328511')->is_valid_number, '小矢部大家病院');
ok($zip->set_number('9328512')->is_valid_number, '石動証券 株式会社');
ok($zip->set_number('9328515')->is_valid_number, '開田運輸 株式会社');
ok($zip->set_number('9328518')->is_valid_number, '介護老人保健施設 ゆうゆうハウス');
ok($zip->set_number('9328520')->is_valid_number, '黒田化学 株式会社 小矢部工場');
ok($zip->set_number('9328522')->is_valid_number, '加越木工 株式会社');
ok($zip->set_number('9328525')->is_valid_number, '松岡病院');
ok($zip->set_number('9328528')->is_valid_number, 'パナソニック エコシステムズ小矢部 株式会社');
ok($zip->set_number('9328533')->is_valid_number, '小矢部市立石動小学校');
ok($zip->set_number('9328538')->is_valid_number, '三井アウトレットパーク 北陸小矢部');
ok($zip->set_number('9328540')->is_valid_number, '富山県立 石動高等学校');
ok($zip->set_number('9328550')->is_valid_number, '菱光サイジング 株式会社');
ok($zip->set_number('9328551')->is_valid_number, '株式会社 野手組');
ok($zip->set_number('9328555')->is_valid_number, '大和トランスポート 株式会社');
ok($zip->set_number('9328558')->is_valid_number, '株式会社 吉田組');
ok($zip->set_number('9328567')->is_valid_number, '北栄電設 株式会社');
ok($zip->set_number('9328575')->is_valid_number, '石黒建設 株式会社 北陸支社');
ok($zip->set_number('9328585')->is_valid_number, '朝日化工 株式会社');
ok($zip->set_number('9328588')->is_valid_number, '株式会社 ミヤモリ');
ok($zip->set_number('9328611')->is_valid_number, '小矢部市役所');
ok($zip->set_number('9330192')->is_valid_number, '伏木海陸運送 株式会社');
ok($zip->set_number('9330193')->is_valid_number, '日本製紙 株式会社 伏木工場');
ok($zip->set_number('9330195')->is_valid_number, '東亞合成 株式会社 高岡工場');
ok($zip->set_number('9330293')->is_valid_number, '富山高等専門学校 射水キャンパス');
ok($zip->set_number('9330295')->is_valid_number, '東洋ガスメーター 株式会社');
ok($zip->set_number('9330392')->is_valid_number, '三協マテリアル (株) 高岡西工場');
ok($zip->set_number('9330393')->is_valid_number, '北陸アルミニウム 株式会社');
ok($zip->set_number('9330395')->is_valid_number, '株式会社 ファイネス 高岡支店');
ok($zip->set_number('9330396')->is_valid_number, '株式会社 ヘネフレックス');
ok($zip->set_number('9330397')->is_valid_number, '北陸コカ・コーラボトリング 株式会社');
ok($zip->set_number('9330398')->is_valid_number, '株式会社 ヒスコムHLC事業本部');
ok($zip->set_number('9338501')->is_valid_number, '株式会社 大和 高岡店');
ok($zip->set_number('9338502')->is_valid_number, '高岡市農業協同組合');
ok($zip->set_number('9338506')->is_valid_number, '高岡西高等学校');
ok($zip->set_number('9338507')->is_valid_number, '日本曹達 株式会社 高岡工場');
ok($zip->set_number('9338508')->is_valid_number, '高岡第一高等学校');
ok($zip->set_number('9338510')->is_valid_number, '高岡商業高等学校');
ok($zip->set_number('9338511')->is_valid_number, '第一ファインケミカル 株式会社');
ok($zip->set_number('9338515')->is_valid_number, 'NTTビジネスソリューションズ 株式会社 高岡営業担当');
ok($zip->set_number('9338516')->is_valid_number, '日本ゼオン (株) 高岡工場');
ok($zip->set_number('9338518')->is_valid_number, '富山県立 高岡工芸高等学校');
ok($zip->set_number('9338520')->is_valid_number, '富山県立 高岡高等学校');
ok($zip->set_number('9338523')->is_valid_number, '富山県高岡厚生センター');
ok($zip->set_number('9338525')->is_valid_number, '富山県 済生会高岡病院');
ok($zip->set_number('9338526')->is_valid_number, '中越パルプ工業 (株) 二塚工場');
ok($zip->set_number('9338527')->is_valid_number, '助野 株式会社');
ok($zip->set_number('9338528')->is_valid_number, '(株) マイカル 北陸高岡サティ');
ok($zip->set_number('9338530')->is_valid_number, '富山県立 二上工業高等学校');
ok($zip->set_number('9338531')->is_valid_number, '(株) 島屋');
ok($zip->set_number('9338532')->is_valid_number, '(株) 矢野');
ok($zip->set_number('9338533')->is_valid_number, '中越パルプ工業 株式会社 能町工場');
ok($zip->set_number('9338535')->is_valid_number, 'ホクアハウスウエア 株式会社');
ok($zip->set_number('9338537')->is_valid_number, 'アリタ (株)');
ok($zip->set_number('9338538')->is_valid_number, '学校法人 荒井学園高岡向陵高等学校');
ok($zip->set_number('9338540')->is_valid_number, '高岡税務署');
ok($zip->set_number('9338543')->is_valid_number, '読売新聞 北陸支社');
ok($zip->set_number('9338550')->is_valid_number, '高岡市民病院');
ok($zip->set_number('9338558')->is_valid_number, '金森産業 株式会社');
ok($zip->set_number('9338563')->is_valid_number, '(株) 谷道');
ok($zip->set_number('9338566')->is_valid_number, 'トナミ運輸 株式会社');
ok($zip->set_number('9338567')->is_valid_number, '高岡商工会議所');
ok($zip->set_number('9338585')->is_valid_number, '日本年金機構 高岡年金事務所');
ok($zip->set_number('9338588')->is_valid_number, '富山大学 高岡キャンパス');
ok($zip->set_number('9338601')->is_valid_number, '高岡市役所');
ok($zip->set_number('9338603')->is_valid_number, '株式会社 光伸製作所');
ok($zip->set_number('9338605')->is_valid_number, '富源商事 株式会社');
ok($zip->set_number('9338606')->is_valid_number, '株式会社 富山銀行 本店');
ok($zip->set_number('9338610')->is_valid_number, '三協立山 株式会社');
ok($zip->set_number('9338611')->is_valid_number, '高岡信用金庫 本店');
ok($zip->set_number('9338628')->is_valid_number, '株式会社 タカギセイコー');
ok($zip->set_number('9338666')->is_valid_number, '第一物産 株式会社');
ok($zip->set_number('9338688')->is_valid_number, '株式会社 北陸銀行 高岡支店');
ok($zip->set_number('9338777')->is_valid_number, '株式会社 インテック');
ok($zip->set_number('9338788')->is_valid_number, 'トナミホールディングス 株式会社');
ok($zip->set_number('9348501')->is_valid_number, '黒谷 株式会社');
ok($zip->set_number('9348502')->is_valid_number, '日本高周波鋼業 株式会社 富山製造所');
ok($zip->set_number('9348511')->is_valid_number, '三協立山 株式会社 新湊工場');
ok($zip->set_number('9348515')->is_valid_number, '富山合金 株式会社');
ok($zip->set_number('9348522')->is_valid_number, '富山住友電工 株式会社');
ok($zip->set_number('9348531')->is_valid_number, '三精工業 株式会社');
ok($zip->set_number('9348534')->is_valid_number, '燐化学工業 株式会社');
ok($zip->set_number('9348550')->is_valid_number, 'JFEマテリアル 株式会社');
ok($zip->set_number('9348558')->is_valid_number, '株式会社 TAN-EI-SYA');
ok($zip->set_number('9348567')->is_valid_number, '大谷製鉄 株式会社');
ok($zip->set_number('9348568')->is_valid_number, '共栄コンクリート 株式会社');
ok($zip->set_number('9348577')->is_valid_number, '三協立山 株式会社 射水工場');
ok($zip->set_number('9348580')->is_valid_number, '株式会社 タカギセイコー');
ok($zip->set_number('9348585')->is_valid_number, '富山県立 新湊高等学校');
ok($zip->set_number('9348588')->is_valid_number, 'アイシン軽金属 株式会社');
ok($zip->set_number('9348611')->is_valid_number, '新湊信用金庫 本店');
ok($zip->set_number('9348651')->is_valid_number, '株式会社 富山第一銀行 新湊支店');
ok($zip->set_number('9348686')->is_valid_number, '石友ホーム 株式会社');
ok($zip->set_number('9348688')->is_valid_number, '株式会社 四方組');
ok($zip->set_number('9358501')->is_valid_number, 'コマツキヤステックス 株式会社');
ok($zip->set_number('9358531')->is_valid_number, '金沢医科大学 氷見市民病院');
ok($zip->set_number('9358535')->is_valid_number, '富山県立 氷見高等学校');
ok($zip->set_number('9358555')->is_valid_number, '有限会社永芳閣');
ok($zip->set_number('9358601')->is_valid_number, '氷見伏木信用金庫');
ok($zip->set_number('9358686')->is_valid_number, '氷見市役所');
ok($zip->set_number('9368501')->is_valid_number, '三晶技研 株式会社');
ok($zip->set_number('9368502')->is_valid_number, '有限会社 ウスイ興産');
ok($zip->set_number('9368507')->is_valid_number, '富山県立 滑川高等学校');
ok($zip->set_number('9368536')->is_valid_number, '富山県 水産試験場');
ok($zip->set_number('9368555')->is_valid_number, '日本カーバイド工業 株式会社 早月工場');
ok($zip->set_number('9368558')->is_valid_number, '北陸電機製造 株式会社');
ok($zip->set_number('9368577')->is_valid_number, '株式会社 スギノマシン 早月工場');
ok($zip->set_number('9368585')->is_valid_number, '厚生連 滑川病院');
ok($zip->set_number('9368588')->is_valid_number, '株式会社 スギノマシン 滑川工場');
ok($zip->set_number('9368601')->is_valid_number, '滑川市役所');
ok($zip->set_number('9368608')->is_valid_number, 'にいかわ信用金庫 滑川営業部');
ok($zip->set_number('9368686')->is_valid_number, '株式会社 北陸銀行 滑川支店');
ok($zip->set_number('9378503')->is_valid_number, '魚津社会保険事務所');
ok($zip->set_number('9378511')->is_valid_number, '株式会社 スギノマシン');
ok($zip->set_number('9378555')->is_valid_number, '魚津市役所');
ok($zip->set_number('9378566')->is_valid_number, 'ビニフレーム工業 株式会社');
ok($zip->set_number('9378567')->is_valid_number, '日本カーバイド工業 株式会社 魚津工場');
ok($zip->set_number('9378585')->is_valid_number, 'パナソニック・タワージャズセミコンダクター 株式会社');
ok($zip->set_number('9378585')->is_valid_number, 'パナソニックセミコンダクターソリューションズ 株式会社');
ok($zip->set_number('9378601')->is_valid_number, '魚津税務署');
ok($zip->set_number('9378660')->is_valid_number, '株式会社 北陸銀行 魚津支店');
ok($zip->set_number('9378678')->is_valid_number, 'にいかわ信用金庫');
ok($zip->set_number('9380292')->is_valid_number, '黒部市役所 宇奈月庁舎');
ok($zip->set_number('9380293')->is_valid_number, '黒部峡谷鉄道 株式会社');
ok($zip->set_number('9388502')->is_valid_number, '黒部市民病院');
ok($zip->set_number('9388505')->is_valid_number, '富山県立 桜井高等学校');
ok($zip->set_number('9388555')->is_valid_number, '黒部市役所 黒部庁舎');
ok($zip->set_number('9388585')->is_valid_number, '株式会社 トヨックス');
ok($zip->set_number('9388601')->is_valid_number, 'YKK 株式会社 黒部事業所');
ok($zip->set_number('9388602')->is_valid_number, 'YKK 株式会社 黒部牧野工場');
ok($zip->set_number('9388610')->is_valid_number, 'YKK AP株式会社 黒部事業所');
ok($zip->set_number('9388611')->is_valid_number, 'YKK AP 株式会社 黒部製造所(素材)');
ok($zip->set_number('9388612')->is_valid_number, 'YKK AP 株式会社 黒部荻生製造所');
ok($zip->set_number('9388613')->is_valid_number, 'YKK AP 株式会社 黒部越湖製造所');
ok($zip->set_number('9390192')->is_valid_number, '高岡市役所 福岡庁舎');
ok($zip->set_number('9390292')->is_valid_number, '射水市役所 大島分庁舎');
ok($zip->set_number('9390293')->is_valid_number, '北陸紙器 株式会社');
ok($zip->set_number('9390294')->is_valid_number, '射水市役所');
ok($zip->set_number('9390295')->is_valid_number, '東洋紡 株式会社 富山事業所');
ok($zip->set_number('9390296')->is_valid_number, '大栄建材 株式会社');
ok($zip->set_number('9390392')->is_valid_number, '富山県立 大学生活協同組合');
ok($zip->set_number('9390395')->is_valid_number, '宗教法人 浄土真宗親鸞会');
ok($zip->set_number('9390398')->is_valid_number, '富山県立大学');
ok($zip->set_number('9390592')->is_valid_number, '株式会社 リッチェル');
ok($zip->set_number('9390693')->is_valid_number, '入善町役場');
ok($zip->set_number('9390792')->is_valid_number, '小川建設工業 株式会社');
ok($zip->set_number('9390793')->is_valid_number, '朝日町役場');
ok($zip->set_number('9390795')->is_valid_number, 'あさひ野小学校');
ok($zip->set_number('9390798')->is_valid_number, 'あさひ総合病院');
ok($zip->set_number('9391192')->is_valid_number, 'キタムラ機械');
ok($zip->set_number('9391193')->is_valid_number, '高岡法科大学');
ok($zip->set_number('9391392')->is_valid_number, '砺波地方介護保険組合');
ok($zip->set_number('9391393')->is_valid_number, '砺波 税務署');
ok($zip->set_number('9391394')->is_valid_number, '株式会社 ヒスコム');
ok($zip->set_number('9391395')->is_valid_number, '市立砺波総合病院');
ok($zip->set_number('9391396')->is_valid_number, '富山県花卉球根農業協同組合');
ok($zip->set_number('9391397')->is_valid_number, '富山社会保険事務局 砺波事務所');
ok($zip->set_number('9391398')->is_valid_number, '砺波市役所');
ok($zip->set_number('9391492')->is_valid_number, '大和リゾート (株) 砺波ロイヤルホテル');
ok($zip->set_number('9391592')->is_valid_number, '第一交易 株式会社');
ok($zip->set_number('9391593')->is_valid_number, '川田工業 株式会社');
ok($zip->set_number('9391595')->is_valid_number, 'コマツNTC 株式会社');
ok($zip->set_number('9391596')->is_valid_number, '南砺市役所 福野庁舎・南砺市 福野行政センター');
ok($zip->set_number('9391692')->is_valid_number, '南砺市役所 福光庁舎・南砺市 福光行政センター');
ok($zip->set_number('9391693')->is_valid_number, 'ささら屋 本店');
ok($zip->set_number('9391694')->is_valid_number, '日の出屋製菓産業 株式会社');
ok($zip->set_number('9391698')->is_valid_number, '三光合成 株式会社');
ok($zip->set_number('9391892')->is_valid_number, '南砺市役所 城端庁舎・南砺市城端行政センター');
ok($zip->set_number('9391893')->is_valid_number, '国立療養所北陸病院');
ok($zip->set_number('9391895')->is_valid_number, 'トナミロイヤルゴルフ倶楽部・トナミロイヤルゴルフ 株式会社');
ok($zip->set_number('9391897')->is_valid_number, '(株) 日本抵抗器製作所');
ok($zip->set_number('9391898')->is_valid_number, '南砺市 井口行政センター');
ok($zip->set_number('9391997')->is_valid_number, '南砺市 平行政センター');
ok($zip->set_number('9391998')->is_valid_number, '南砺市 上平行政センター');
ok($zip->set_number('9392192')->is_valid_number, '富山市細入中核型地区センター');
ok($zip->set_number('9392292')->is_valid_number, '北陸電気工業 株式会社');
ok($zip->set_number('9392293')->is_valid_number, '富山市大沢野行政サービスセンター');
ok($zip->set_number('9392295')->is_valid_number, '富山小林製薬 株式会社');
ok($zip->set_number('9392297')->is_valid_number, '株式会社 富山ゴルフ');
ok($zip->set_number('9392298')->is_valid_number, '社会福祉法人 セーナー苑');
ok($zip->set_number('9392392')->is_valid_number, '富士通 株式会社');
ok($zip->set_number('9392393')->is_valid_number, '株式会社 KOKUSAI ELECTRIC 富山事業所');
ok($zip->set_number('9392398')->is_valid_number, '富山市八尾総合行政センター');
ok($zip->set_number('9392595')->is_valid_number, '南砺市 利賀行政センター');
ok($zip->set_number('9392692')->is_valid_number, '独立行政法人 国立病院機構 富山病院');
ok($zip->set_number('9392694')->is_valid_number, '富山簡易保険保養センター');
ok($zip->set_number('9392798')->is_valid_number, '富山市婦中総合行政センター');
ok($zip->set_number('9393593')->is_valid_number, '株式会社 セキノ興産');
ok($zip->set_number('9398501')->is_valid_number, '生活協同組合 CO・OPとやま');
ok($zip->set_number('9398502')->is_valid_number, '富山地方裁判所・富山家庭裁判所・富山簡易裁判所・富山検察審査会');
ok($zip->set_number('9398507')->is_valid_number, '株式会社 OSCAR');
ok($zip->set_number('9398510')->is_valid_number, '富山地方検察庁');
ok($zip->set_number('9398511')->is_valid_number, '富山市立 富山市民病院');
ok($zip->set_number('9398515')->is_valid_number, '日清紡績 株式会社 富山工場');
ok($zip->set_number('9398517')->is_valid_number, '株式会社 オスカー アソシエ');
ok($zip->set_number('9398521')->is_valid_number, '冨木医療器 株式会社 富山支店');
ok($zip->set_number('9398550')->is_valid_number, '富山テレビ放送 株式会社');
ok($zip->set_number('9398555')->is_valid_number, '財団法人 富山県総合健康増進事業団 富山県健康増進センター');
ok($zip->set_number('9398558')->is_valid_number, 'ネッツ トヨタノヴェルとやま 株式会社');
ok($zip->set_number('9398567')->is_valid_number, 'ダイト 株式会社');
ok($zip->set_number('9398571')->is_valid_number, '北陸電気工事 株式会社');
ok($zip->set_number('9398572')->is_valid_number, '北陸電気工事 株式会社');
ok($zip->set_number('9398580')->is_valid_number, '株式会社 アイバック');
ok($zip->set_number('9398585')->is_valid_number, '富山スガキ 株式会社');
ok($zip->set_number('9398588')->is_valid_number, '富山市保健所');
ok($zip->set_number('9398601')->is_valid_number, '株式会社 フレット 富山支店');
ok($zip->set_number('9398610')->is_valid_number, '株式会社 ホクタテ');
ok($zip->set_number('9398611')->is_valid_number, 'タカノホーム 株式会社');
ok($zip->set_number('9398630')->is_valid_number, '富山高等専門学校 本郷キャンパス');
ok($zip->set_number('9398636')->is_valid_number, '富山県立 近代美術館');
ok($zip->set_number('9398640')->is_valid_number, '社会福祉法人 富山市社会福祉協議会');
ok($zip->set_number('9398642')->is_valid_number, '中田図書販売 株式会社');
ok($zip->set_number('9398650')->is_valid_number, '五洲薬品 株式会社');
ok($zip->set_number('9400292')->is_valid_number, '鈴倉インダストリー 株式会社');
ok($zip->set_number('9400293')->is_valid_number, '新潟県立 栃尾高等学校');
ok($zip->set_number('9400294')->is_valid_number, '栃尾郷病院');
ok($zip->set_number('9400295')->is_valid_number, '栃尾商工会');
ok($zip->set_number('9400296')->is_valid_number, 'JA越後ながおか 栃尾中央店');
ok($zip->set_number('9400297')->is_valid_number, '長岡市 福祉事務所');
ok($zip->set_number('9400298')->is_valid_number, '長岡市役所 栃尾支所');
ok($zip->set_number('9401193')->is_valid_number, '長岡保養園');
ok($zip->set_number('9401194')->is_valid_number, '株式会社 ヤヨイサンフーズ 長岡工場');
ok($zip->set_number('9401195')->is_valid_number, 'TDKラムダ 株式会社 長岡テクニカルセンター');
ok($zip->set_number('9401196')->is_valid_number, '株式会社 新潟味のれん本舗');
ok($zip->set_number('9401198')->is_valid_number, '新潟県立 長岡農業高等学校');
ok($zip->set_number('9402081')->is_valid_number, '長岡西病院');
ok($zip->set_number('9402082')->is_valid_number, '(財) 公園緑地管理 越後公園管理センター');
ok($zip->set_number('9402083')->is_valid_number, '新潟県立 近代美術館');
ok($zip->set_number('9402085')->is_valid_number, '長岡赤十字病院');
ok($zip->set_number('9402088')->is_valid_number, '長岡造形大学');
ok($zip->set_number('9402093')->is_valid_number, 'リバーサイド千秋 アピタ・モール');
ok($zip->set_number('9402181')->is_valid_number, '国分関信越 株式会社 新潟支社 長岡支店');
ok($zip->set_number('9402182')->is_valid_number, '近藤産業 株式会社');
ok($zip->set_number('9402183')->is_valid_number, '崇徳会 田宮病院');
ok($zip->set_number('9402184')->is_valid_number, '新潟県立長岡向陵高等学校');
ok($zip->set_number('9402186')->is_valid_number, '株式会社 中越興業');
ok($zip->set_number('9402188')->is_valid_number, '長岡技術科学大学');
ok($zip->set_number('9402192')->is_valid_number, '株式会社 ピーコック');
ok($zip->set_number('9402195')->is_valid_number, '株式会社 新村');
ok($zip->set_number('9402198')->is_valid_number, '株式会社 田村商店');
ok($zip->set_number('9402392')->is_valid_number, '長岡市役所 三島支所');
ok($zip->set_number('9402492')->is_valid_number, '長岡市役所与板支所');
ok($zip->set_number('9402592')->is_valid_number, '長岡市役所寺泊支所');
ok($zip->set_number('9402595')->is_valid_number, '角上魚類ホールディングス 株式会社');
ok($zip->set_number('9408501')->is_valid_number, '長岡市役所');
ok($zip->set_number('9408508')->is_valid_number, 'ヘアドクター発毛科学研究所');
ok($zip->set_number('9408510')->is_valid_number, '株式会社 シマキュウ');
ok($zip->set_number('9408511')->is_valid_number, '住友生命保険 相互会社 長岡支社');
ok($zip->set_number('9408521')->is_valid_number, '株式会社 大石組');
ok($zip->set_number('9408522')->is_valid_number, 'ミツワ電機 株式会社 長岡営業所');
ok($zip->set_number('9408530')->is_valid_number, '新潟大学附属学校部長岡附属学校');
ok($zip->set_number('9408532')->is_valid_number, '長岡工業高等専門学校');
ok($zip->set_number('9408550')->is_valid_number, '越後ながおか農業協同組合');
ok($zip->set_number('9408554')->is_valid_number, '新潟県 教育庁中越教育事務所');
ok($zip->set_number('9408555')->is_valid_number, '石油資源開発 株式会社 長岡鉱業所');
ok($zip->set_number('9408558')->is_valid_number, '株式会社 ダイクラ');
ok($zip->set_number('9408567')->is_valid_number, '新潟県 長岡地域振興局');
ok($zip->set_number('9408570')->is_valid_number, '長岡警察署');
ok($zip->set_number('9408572')->is_valid_number, 'アルプス電気 株式会社');
ok($zip->set_number('9408577')->is_valid_number, '船山 株式会社');
ok($zip->set_number('9408580')->is_valid_number, '日本精機 株式会社');
ok($zip->set_number('9408583')->is_valid_number, '新潟トーヨー 株式会社');
ok($zip->set_number('9408585')->is_valid_number, '中越高等学校');
ok($zip->set_number('9408586')->is_valid_number, '株式会社 大和 長岡店');
ok($zip->set_number('9408588')->is_valid_number, '丸紅 株式会社 長岡支店');
ok($zip->set_number('9408602')->is_valid_number, '玉川マシナリー 株式会社');
ok($zip->set_number('9408603')->is_valid_number, '倉敷機械 株式会社');
ok($zip->set_number('9408605')->is_valid_number, '株式会社 大原鉄工所');
ok($zip->set_number('9408610')->is_valid_number, '岩塚製菓 株式会社');
ok($zip->set_number('9408611')->is_valid_number, '岩塚製菓 株式会社');
ok($zip->set_number('9408612')->is_valid_number, '岩塚製菓 株式会社');
ok($zip->set_number('9408620')->is_valid_number, 'しなの産業 株式会社');
ok($zip->set_number('9408621')->is_valid_number, '医療法人 立川メディカルセンター 立川綜合病院');
ok($zip->set_number('9408622')->is_valid_number, '越後製菓 株式会社');
ok($zip->set_number('9408630')->is_valid_number, '株式会社 ツガミ長岡工場');
ok($zip->set_number('9408631')->is_valid_number, '丸専繊維 株式会社');
ok($zip->set_number('9408633')->is_valid_number, '株式会社 NTT東日本-新潟');
ok($zip->set_number('9408641')->is_valid_number, '株式会社 吉原組');
ok($zip->set_number('9408650')->is_valid_number, '株式会社 北越銀行 本店');
ok($zip->set_number('9408651')->is_valid_number, '株式会社 大光銀行');
ok($zip->set_number('9408653')->is_valid_number, '長岡中央綜合病院');
ok($zip->set_number('9408654')->is_valid_number, '長岡税務署');
ok($zip->set_number('9408660')->is_valid_number, '長岡信用金庫');
ok($zip->set_number('9408686')->is_valid_number, '日本生命保険 相互会社 長岡支社');
ok($zip->set_number('9408707')->is_valid_number, '東北電力 株式会社 長岡営業所');
ok($zip->set_number('9418501')->is_valid_number, '糸魚川市役所');
ok($zip->set_number('9418502')->is_valid_number, '糸魚川総合病院');
ok($zip->set_number('9418601')->is_valid_number, '糸魚川商工会議所');
ok($zip->set_number('9418611')->is_valid_number, '糸魚川税務署');
ok($zip->set_number('9418686')->is_valid_number, '株式会社 タナベ');
ok($zip->set_number('9420192')->is_valid_number, '頸城区総合事務所');
ok($zip->set_number('9420193')->is_valid_number, '直江津電子工業 株式会社');
ok($zip->set_number('9420194')->is_valid_number, '三光サービス (株)');
ok($zip->set_number('9420195')->is_valid_number, '新潟運輸 株式会社 上越主管支店上越支店');
ok($zip->set_number('9420196')->is_valid_number, '株式会社 新潟リョーショク 上越支店');
ok($zip->set_number('9420392')->is_valid_number, '浦川原地区公民館');
ok($zip->set_number('9420393')->is_valid_number, '上越市役所 浦川原区総合事務所');
ok($zip->set_number('9420398')->is_valid_number, 'いきいきセンター');
ok($zip->set_number('9420492')->is_valid_number, '上越市役所 安塚区総合事務所');
ok($zip->set_number('9421492')->is_valid_number, '十日町市役所 松之山支所');
ok($zip->set_number('9428501')->is_valid_number, 'NTT上越営業支店');
ok($zip->set_number('9428502')->is_valid_number, '新潟労災病院');
ok($zip->set_number('9428505')->is_valid_number, '新潟県立 直江津高等学校');
ok($zip->set_number('9428508')->is_valid_number, '頚城自動車 株式会社');
ok($zip->set_number('9428563')->is_valid_number, '上越市教育委員会');
ok($zip->set_number('9428601')->is_valid_number, '信越化学工業 株式会社 直江津工場');
ok($zip->set_number('9428611')->is_valid_number, '三菱化学 株式会社 直江津事業所');
ok($zip->set_number('9428666')->is_valid_number, '上越信用金庫 本店');
ok($zip->set_number('9430192')->is_valid_number, '新潟県立 中央病院');
ok($zip->set_number('9430193')->is_valid_number, '独立行政法人 農業技術研究機構中央農業総合研究センター 北陸研究センター');
ok($zip->set_number('9430595')->is_valid_number, '上越市役所 清里区総合事務所');
ok($zip->set_number('9430692')->is_valid_number, '牧村役場');
ok($zip->set_number('9438501')->is_valid_number, '陸上自衛隊高田駐屯地');
ok($zip->set_number('9438502')->is_valid_number, '上越商工会議所');
ok($zip->set_number('9438503')->is_valid_number, '新潟県立 高田工業高等学校');
ok($zip->set_number('9438505')->is_valid_number, '田中産業 株式会社');
ok($zip->set_number('9438510')->is_valid_number, '高倉商事 株式会社');
ok($zip->set_number('9438512')->is_valid_number, '上越教育大学');
ok($zip->set_number('9438515')->is_valid_number, '新潟県立 高田高等学校');
ok($zip->set_number('9438520')->is_valid_number, '株式会社 ジョーセン');
ok($zip->set_number('9438521')->is_valid_number, '株式会社 一印上越魚市場');
ok($zip->set_number('9438522')->is_valid_number, '上越ケーブルビジョン 株式会社');
ok($zip->set_number('9438525')->is_valid_number, '新潟県立 高田北城高等学校');
ok($zip->set_number('9438530')->is_valid_number, '医療法人 三交病院');
ok($zip->set_number('9438531')->is_valid_number, '上越地域医療センター病院');
ok($zip->set_number('9438533')->is_valid_number, '三井企画 株式会社');
ok($zip->set_number('9438534')->is_valid_number, '上越社会保険事務所');
ok($zip->set_number('9438540')->is_valid_number, '株式会社 サトコウ');
ok($zip->set_number('9438544')->is_valid_number, '株式会社 みながわ製菓');
ok($zip->set_number('9438545')->is_valid_number, '新潟日報 上越支社');
ok($zip->set_number('9438551')->is_valid_number, '上越地域振興局');
ok($zip->set_number('9438552')->is_valid_number, '新潟県立高田南城高等学校');
ok($zip->set_number('9438555')->is_valid_number, '一般社団法人 上越医師会');
ok($zip->set_number('9438561')->is_valid_number, '学校法人 関根学園');
ok($zip->set_number('9438585')->is_valid_number, '株式会社 上越タイムス社');
ok($zip->set_number('9438588')->is_valid_number, '高田税務署内申告書等集中処理担当部署(糸魚川税務署)');
ok($zip->set_number('9438601')->is_valid_number, '上越市役所');
ok($zip->set_number('9438604')->is_valid_number, '高田税務署');
ok($zip->set_number('9438607')->is_valid_number, '高田信用金庫');
ok($zip->set_number('9438610')->is_valid_number, '株式会社 有沢製作所');
ok($zip->set_number('9438616')->is_valid_number, '株式会社 上越商会');
ok($zip->set_number('9440192')->is_valid_number, '上越市役所 板倉区総合事務所');
ok($zip->set_number('9448501')->is_valid_number, 'けいなん総合病院');
ok($zip->set_number('9448550')->is_valid_number, '株式会社 ダイセル 新井工場');
ok($zip->set_number('9448555')->is_valid_number, 'パナソニック 株式会社 オートモーティブ&インダストリアルシステムズ社 セミコンダクター事業部 北陸工場 新井地区');
ok($zip->set_number('9448588')->is_valid_number, '新光電気工業 株式会社 新井工場');
ok($zip->set_number('9448601')->is_valid_number, '新井信用金庫');
ok($zip->set_number('9448686')->is_valid_number, '妙高市役所');
ok($zip->set_number('9450192')->is_valid_number, '柏崎ユーエステック 株式会社');
ok($zip->set_number('9450193')->is_valid_number, '株式会社 アドバネクス');
ok($zip->set_number('9450194')->is_valid_number, 'カトウスプリング 株式会社');
ok($zip->set_number('9450395')->is_valid_number, '日本ドレッサー 株式会社 刈羽事業所');
ok($zip->set_number('9450397')->is_valid_number, '刈羽村役場');
ok($zip->set_number('9451195')->is_valid_number, '新潟工科大学');
ok($zip->set_number('9451392')->is_valid_number, '柏崎厚生病院');
ok($zip->set_number('9451393')->is_valid_number, '新潟産業大学');
ok($zip->set_number('9451395')->is_valid_number, '株式会社 サイカワ');
ok($zip->set_number('9451397')->is_valid_number, '新潟産業大学附属高等学校');
ok($zip->set_number('9451398')->is_valid_number, '富士ゼロックスマニュファクチュアリング 株式会社 新潟事業所');
ok($zip->set_number('9451595')->is_valid_number, '柏崎市役所 高柳町事務所');
ok($zip->set_number('9458501')->is_valid_number, '柏崎公共職業安定所、柏崎労働基準監督署、経済産業省資源エネルギー庁原子力安全・保安院柏崎刈羽原子力保安検査官事務所、新潟地方法務局柏崎支局');
ok($zip->set_number('9458501')->is_valid_number, '通商産業省資源エネルギー庁柏崎刈羽運転管理専門事務所・新潟地方法務局柏崎支局');
ok($zip->set_number('9458511')->is_valid_number, '柏崎市役所');
ok($zip->set_number('9458535')->is_valid_number, '柏崎総合医療センター');
ok($zip->set_number('9458540')->is_valid_number, '株式会社 植木組');
ok($zip->set_number('9458555')->is_valid_number, '株式会社 リケン');
ok($zip->set_number('9458558')->is_valid_number, '柏崎財務事務所・柏崎地域福祉センター・柏崎土木事務所・柏崎農地事務所・刈羽農業改良普及センター');
ok($zip->set_number('9458585')->is_valid_number, '国立病院機構 新潟病院');
ok($zip->set_number('9458601')->is_valid_number, '東京電力 株式会社 柏崎刈羽原子力発電所');
ok($zip->set_number('9458611')->is_valid_number, '株式会社 ブルボン');
ok($zip->set_number('9458688')->is_valid_number, '柏崎税務署');
ok($zip->set_number('9460292')->is_valid_number, '魚沼市役所 北部庁舎');
ok($zip->set_number('9468513')->is_valid_number, 'アルプス電気 株式会社 磁気応用事業部 小出工場');
ok($zip->set_number('9468601')->is_valid_number, '魚沼市役所 本庁舎');
ok($zip->set_number('9470192')->is_valid_number, '越後製菓 株式会社 片貝工場');
ok($zip->set_number('9470193')->is_valid_number, '越後製菓 株式会社 高梨工場');
ok($zip->set_number('9470198')->is_valid_number, '株式会社 フーゲツ');
ok($zip->set_number('9478501')->is_valid_number, '小千谷市役所');
ok($zip->set_number('9478502')->is_valid_number, '新潟三洋電子 株式会社');
ok($zip->set_number('9478503')->is_valid_number, '日本ベアリング 株式会社');
ok($zip->set_number('9478504')->is_valid_number, '三陽工業 株式会社');
ok($zip->set_number('9478506')->is_valid_number, '株式会社 タカハシキカイ');
ok($zip->set_number('9478540')->is_valid_number, '小千谷税務署');
ok($zip->set_number('9478555')->is_valid_number, '理研精機 (株)');
ok($zip->set_number('9478585')->is_valid_number, '阿部幸製菓 株式会社');
ok($zip->set_number('9478701')->is_valid_number, '小千谷総合病院');
ok($zip->set_number('9478765')->is_valid_number, 'ジャスコ小千谷店');
ok($zip->set_number('9480192')->is_valid_number, '十日町市役所 川西支所');
ok($zip->set_number('9488501')->is_valid_number, '十日町市役所');
ok($zip->set_number('9488502')->is_valid_number, '十日町税務署');
ok($zip->set_number('9488503')->is_valid_number, '株式会社 関芳');
ok($zip->set_number('9488504')->is_valid_number, '東北電力ネットワーク 株式会社 十日町電力センター');
ok($zip->set_number('9488602')->is_valid_number, '株式会社 新川屋');
ok($zip->set_number('9490392')->is_valid_number, '糸魚川市役所 青海事務所');
ok($zip->set_number('9490393')->is_valid_number, '電気化学工業 株式会社 青海工場');
ok($zip->set_number('9490398')->is_valid_number, '田辺工業 株式会社 青海支店');
ok($zip->set_number('9492192')->is_valid_number, '妙高市 妙高高原支所');
ok($zip->set_number('9492193')->is_valid_number, '中央電気工業 株式会社 田口工場');
ok($zip->set_number('9492194')->is_valid_number, '第一電工 株式会社 田口工場');
ok($zip->set_number('9492392')->is_valid_number, '日本曹達 株式会社 二本木工場');
ok($zip->set_number('9492394')->is_valid_number, '上越市役所 中郷区総合事務所');
ok($zip->set_number('9493192')->is_valid_number, '上越市役所 大潟区総合事務所');
ok($zip->set_number('9493193')->is_valid_number, '独立行政法人 国立病院機構 さいがた病院');
ok($zip->set_number('9493194')->is_valid_number, '丸大食品 株式会社 新潟工場');
ok($zip->set_number('9493292')->is_valid_number, '上越市役所 柿崎区総合事務所');
ok($zip->set_number('9493293')->is_valid_number, '株式会社 柿崎機械');
ok($zip->set_number('9493294')->is_valid_number, '理研製鋼 株式会社');
ok($zip->set_number('9493296')->is_valid_number, '新貝工業 株式会社');
ok($zip->set_number('9493298')->is_valid_number, 'ウエノテックス 株式会社');
ok($zip->set_number('9493494')->is_valid_number, '上越市役所 吉川区総合事務所');
ok($zip->set_number('9494192')->is_valid_number, '永井コンクリート工業 株式会社');
ok($zip->set_number('9494193')->is_valid_number, '柏崎市役所 西山町事務所');
ok($zip->set_number('9494194')->is_valid_number, 'いきいき館');
ok($zip->set_number('9494392')->is_valid_number, '出雲崎町役場');
ok($zip->set_number('9494397')->is_valid_number, '社会福祉法人 中越老人福祉協会 やすらぎの里');
ok($zip->set_number('9494398')->is_valid_number, 'グループホームかめさんの家');
ok($zip->set_number('9495292')->is_valid_number, '長岡市役所 小国支所');
ok($zip->set_number('9495492')->is_valid_number, '岩塚製菓 株式会社');
ok($zip->set_number('9495493')->is_valid_number, '長岡市役所 越路支所');
ok($zip->set_number('9495494')->is_valid_number, '朝日酒造 株式会社');
ok($zip->set_number('9496192')->is_valid_number, '湯沢町役場');
ok($zip->set_number('9496292')->is_valid_number, '苗場プリンスホテル');
ok($zip->set_number('9496492')->is_valid_number, '南魚沼市役所 塩沢庁舎');
ok($zip->set_number('9496692')->is_valid_number, '日本年金機構 六日町年金事務所');
ok($zip->set_number('9496695')->is_valid_number, '株式会社 雪国まいたけ');
ok($zip->set_number('9496696')->is_valid_number, '南魚沼市役所 本庁舎');
ok($zip->set_number('9496797')->is_valid_number, '株式会社 エム・エフ・テック');
ok($zip->set_number('9497277')->is_valid_number, '国際大学');
ok($zip->set_number('9497392')->is_valid_number, '南魚沼市役所大和庁舎');
ok($zip->set_number('9497492')->is_valid_number, 'ホリカフーズ 株式会社');
ok($zip->set_number('9497494')->is_valid_number, '魚沼市役所 堀之内庁舎');
ok($zip->set_number('9497495')->is_valid_number, '堀之内小学校');
ok($zip->set_number('9497496')->is_valid_number, '堀之内中学校');
ok($zip->set_number('9497592')->is_valid_number, '長岡市役所 川口支所');
ok($zip->set_number('9497594')->is_valid_number, '信越工業 株式会社');
ok($zip->set_number('9498492')->is_valid_number, '十日町市役所 中里支所');
ok($zip->set_number('9500192')->is_valid_number, '亀田製菓 株式会社 亀田工場');
ok($zip->set_number('9500193')->is_valid_number, 'トヨタカローラ新潟 株式会社');
ok($zip->set_number('9500195')->is_valid_number, '新潟市江南区役所');
ok($zip->set_number('9500196')->is_valid_number, 'カーロッツ新潟');
ok($zip->set_number('9500198')->is_valid_number, '亀田製菓 株式会社 本社');
ok($zip->set_number('9500292')->is_valid_number, '新潟市江南区役所 横越出張所');
ok($zip->set_number('9501179')->is_valid_number, '株式会社 新潟日報メディアネット');
ok($zip->set_number('9501181')->is_valid_number, '株式会社 ホクエー');
ok($zip->set_number('9501182')->is_valid_number, '新潟スバル自動車 株式会社');
ok($zip->set_number('9501183')->is_valid_number, '新潟県立 新潟翠江高等学校 通信制');
ok($zip->set_number('9501186')->is_valid_number, '新潟日野自動車 株式会社');
ok($zip->set_number('9501187')->is_valid_number, '社団法人 新潟県労働衛生医学協会 新潟ウェルネス');
ok($zip->set_number('9501188')->is_valid_number, '株式会社 新潟廣瀬組');
ok($zip->set_number('9501189')->is_valid_number, '株式会社 ニューメディア新潟センター');
ok($zip->set_number('9501192')->is_valid_number, '新潟県 総合生活協同組合 生活事業部');
ok($zip->set_number('9501193')->is_valid_number, '全国農業協同組合連合会 新潟県本部');
ok($zip->set_number('9501194')->is_valid_number, '生活協同組合 コープにいがた');
ok($zip->set_number('9501195')->is_valid_number, '中日本キャタピラー三菱建機販売 株式会社');
ok($zip->set_number('9501196')->is_valid_number, '新潟市西区役所 黒埼出張所');
ok($zip->set_number('9501197')->is_valid_number, '新潟市民病院');
ok($zip->set_number('9501292')->is_valid_number, '新潟市南区役所');
ok($zip->set_number('9501293')->is_valid_number, '白根健生病院');
ok($zip->set_number('9501294')->is_valid_number, '新潟市南区役所 味方出張所');
ok($zip->set_number('9501295')->is_valid_number, 'ダイニチ工業 株式会社');
ok($zip->set_number('9501296')->is_valid_number, '株式会社 ヰセキ関東甲信越');
ok($zip->set_number('9501298')->is_valid_number, 'JA新潟かがやき 営農部・経済部');
ok($zip->set_number('9501492')->is_valid_number, '株式会社 コメリ 本社');
ok($zip->set_number('9501495')->is_valid_number, 'ダイニチ工業 株式会社');
ok($zip->set_number('9501498')->is_valid_number, 'JA新潟かがやき フルーツフラワーしろね');
ok($zip->set_number('9502082')->is_valid_number, '宏商物産 株式会社');
ok($zip->set_number('9502084')->is_valid_number, '株式会社 佐藤商会');
ok($zip->set_number('9502085')->is_valid_number, '国立療養所 西新潟中央病院');
ok($zip->set_number('9502086')->is_valid_number, '学校法人 明倫学園 明倫短期大学');
ok($zip->set_number('9502087')->is_valid_number, '信楽園病院');
ok($zip->set_number('9502088')->is_valid_number, '株式会社 新潟リョーショク');
ok($zip->set_number('9502089')->is_valid_number, '神山物産 株式会社');
ok($zip->set_number('9502092')->is_valid_number, '株式会社 マルタケ');
ok($zip->set_number('9502093')->is_valid_number, '新潟企業 株式会社');
ok($zip->set_number('9502095')->is_valid_number, 'あきら工業 株式会社');
ok($zip->set_number('9502096')->is_valid_number, '株式会社 田代');
ok($zip->set_number('9502097')->is_valid_number, '新潟市西区役所');
ok($zip->set_number('9502181')->is_valid_number, '新潟大学');
ok($zip->set_number('9502188')->is_valid_number, '萬代電業 株式会社');
ok($zip->set_number('9502192')->is_valid_number, '泉商事 株式会社');
ok($zip->set_number('9502195')->is_valid_number, '株式会社 ハマキン');
ok($zip->set_number('9502198')->is_valid_number, 'アスカ商事 株式会社');
ok($zip->set_number('9502292')->is_valid_number, '新潟国際情報大学');
ok($zip->set_number('9503195')->is_valid_number, '三幸製菓 株式会社');
ok($zip->set_number('9503197')->is_valid_number, '新潟食料農業大学 新潟キャンパス');
ok($zip->set_number('9503198')->is_valid_number, '新潟医療福祉大学');
ok($zip->set_number('9508501')->is_valid_number, '五洋建設 株式会社 北陸支店');
ok($zip->set_number('9508502')->is_valid_number, '社団法人 新潟県年金福祉協会');
ok($zip->set_number('9508503')->is_valid_number, '株式会社 第四銀行 新潟駅前支店');
ok($zip->set_number('9508504')->is_valid_number, '三菱電機 株式会社 新潟支店');
ok($zip->set_number('9508505')->is_valid_number, '住友生命保険 相互会社 新潟支社');
ok($zip->set_number('9508507')->is_valid_number, 'KNT近畿日本ツーリスト (株) 信越仕入メイトセンター');
ok($zip->set_number('9508510')->is_valid_number, '松下電器産業 株式会社 新潟支店');
ok($zip->set_number('9508511')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('9508512')->is_valid_number, '国際石油開発帝石 株式会社 国内事業本部');
ok($zip->set_number('9508513')->is_valid_number, '全国健康保険協会新潟支部');
ok($zip->set_number('9508514')->is_valid_number, '株式会社 東芝 新潟支店');
ok($zip->set_number('9508518')->is_valid_number, '日本信販 株式会社 新潟統括部');
ok($zip->set_number('9508520')->is_valid_number, '伊藤忠商事 株式会社 新潟支店');
ok($zip->set_number('9508522')->is_valid_number, '住友商事');
ok($zip->set_number('9508523')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('9508524')->is_valid_number, 'ネスレ日本');
ok($zip->set_number('9508530')->is_valid_number, '麒麟麦酒 株式会社 新潟支社');
ok($zip->set_number('9508531')->is_valid_number, '株式会社 ホテル新潟');
ok($zip->set_number('9508532')->is_valid_number, '新潟公共職業安定所');
ok($zip->set_number('9508533')->is_valid_number, '株式会社 シルバーホテル');
ok($zip->set_number('9508535')->is_valid_number, '新潟日報社');
ok($zip->set_number('9508537')->is_valid_number, '国土交通省 北陸信越運輸局');
ok($zip->set_number('9508539')->is_valid_number, '日通商事 株式会社 新潟支店');
ok($zip->set_number('9508540')->is_valid_number, '株式会社 リンコーコーポレーション');
ok($zip->set_number('9508541')->is_valid_number, '株式会社 トーメン 新潟支店');
ok($zip->set_number('9508543')->is_valid_number, '第九管区海上保安本部');
ok($zip->set_number('9508544')->is_valid_number, '新潟交通 株式会社');
ok($zip->set_number('9508545')->is_valid_number, '東京海上日動火災保険 株式会社 新潟支店');
ok($zip->set_number('9508547')->is_valid_number, '株式会社 新潟日報メディアネット');
ok($zip->set_number('9508548')->is_valid_number, '株式会社 新潟放送 事業局');
ok($zip->set_number('9508550')->is_valid_number, '鹿島建設 株式会社 北陸支店');
ok($zip->set_number('9508551')->is_valid_number, '新潟県 市町村職員共済組合');
ok($zip->set_number('9508552')->is_valid_number, '日本年金機構 新潟東年金事務所');
ok($zip->set_number('9508553')->is_valid_number, '新潟県 警察本部');
ok($zip->set_number('9508555')->is_valid_number, '株式会社 テレビ新潟放送網');
ok($zip->set_number('9508556')->is_valid_number, '医療法人 仁愛会 新潟中央病院');
ok($zip->set_number('9508557')->is_valid_number, 'セコム上信越 株式会社');
ok($zip->set_number('9508558')->is_valid_number, '連合新潟');
ok($zip->set_number('9508559')->is_valid_number, 'セコムジャスティック上信越 株式会社');
ok($zip->set_number('9508560')->is_valid_number, '新潟県 国民健康保険団体連合会');
ok($zip->set_number('9508565')->is_valid_number, '株式会社 興和');
ok($zip->set_number('9508566')->is_valid_number, '新潟県 総合生活協同組合');
ok($zip->set_number('9508567')->is_valid_number, '新潟県 社会保険診療報酬支払基金');
ok($zip->set_number('9508570')->is_valid_number, '新潟県庁');
ok($zip->set_number('9508571')->is_valid_number, '新潟青果協会');
ok($zip->set_number('9508572')->is_valid_number, '株式会社 新潟総合テレビ');
ok($zip->set_number('9508575')->is_valid_number, '社会福祉法人 新潟県社会福祉協議会');
ok($zip->set_number('9508576')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ 新潟支店');
ok($zip->set_number('9508577')->is_valid_number, '株式会社 新潟クボタ');
ok($zip->set_number('9508579')->is_valid_number, '新潟県民エフエム 株式会社');
ok($zip->set_number('9508580')->is_valid_number, '新潟通信機 株式会社');
ok($zip->set_number('9508581')->is_valid_number, '株式会社 エフエムラジオ新潟');
ok($zip->set_number('9508582')->is_valid_number, '第一建設工業 株式会社');
ok($zip->set_number('9508583')->is_valid_number, '新潟中央青果 株式会社');
ok($zip->set_number('9508584')->is_valid_number, '新潟万代病院');
ok($zip->set_number('9508585')->is_valid_number, '大成建設 株式会社 北信越支店');
ok($zip->set_number('9508586')->is_valid_number, '株式会社 加賀田組');
ok($zip->set_number('9508588')->is_valid_number, '藤田金属 株式会社');
ok($zip->set_number('9508589')->is_valid_number, '株式会社 新潟伊勢丹');
ok($zip->set_number('9508601')->is_valid_number, '医療法人 恒仁会 新潟南病院');
ok($zip->set_number('9508602')->is_valid_number, '新潟県立 図書館・新潟県立 生涯学習推進センタ・新潟県立 文書館');
ok($zip->set_number('9508603')->is_valid_number, '東日本システム建設 株式会社 新潟事業本部');
ok($zip->set_number('9508605')->is_valid_number, '新潟トヨタ自動車 株式会社');
ok($zip->set_number('9508606')->is_valid_number, '東芝コンシューマーマーケティング 株式会社 新潟支店');
ok($zip->set_number('9508608')->is_valid_number, '新潟工販 株式会社');
ok($zip->set_number('9508610')->is_valid_number, '新潟運輸 株式会社');
ok($zip->set_number('9508619')->is_valid_number, '株式会社 新潟東急イン');
ok($zip->set_number('9508620')->is_valid_number, '東急観光 株式会社 新潟支店');
ok($zip->set_number('9508621')->is_valid_number, '中越運送 株式会社');
ok($zip->set_number('9508622')->is_valid_number, '本間薬品 株式会社');
ok($zip->set_number('9508623')->is_valid_number, '関東財務局 新潟財務事務所');
ok($zip->set_number('9508624')->is_valid_number, '新潟労働基準監督署');
ok($zip->set_number('9508625')->is_valid_number, '新潟労働局');
ok($zip->set_number('9508626')->is_valid_number, 'YKKAP 株式会社');
ok($zip->set_number('9508629')->is_valid_number, '北栄建設 株式会社');
ok($zip->set_number('9508630')->is_valid_number, '新潟いすゞ自動車 株式会社');
ok($zip->set_number('9508633')->is_valid_number, '新潟綜合警備保障 株式会社');
ok($zip->set_number('9508639')->is_valid_number, '新潟県立 新潟東高等学校');
ok($zip->set_number('9508640')->is_valid_number, '株式会社 ダイヤメット');
ok($zip->set_number('9508641')->is_valid_number, '東日本旅客鉄道 株式会社 新潟支社');
ok($zip->set_number('9508650')->is_valid_number, '株式会社 オリエントコーポレーション 新潟支店');
ok($zip->set_number('9508651')->is_valid_number, '丸新照明 株式会社');
ok($zip->set_number('9508654')->is_valid_number, '株式会社 キョードー北陸');
ok($zip->set_number('9508655')->is_valid_number, '昭栄産業 株式会社');
ok($zip->set_number('9508660')->is_valid_number, '株式会社 ウオロク');
ok($zip->set_number('9508661')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('9508666')->is_valid_number, '新潟市立 万代高等学校');
ok($zip->set_number('9508668')->is_valid_number, '住友林業 株式会社 住宅事業本部 新潟支店');
ok($zip->set_number('9508677')->is_valid_number, '新潟県立 新潟養護学校');
ok($zip->set_number('9508678')->is_valid_number, 'ジャスコ 株式会社 新潟東支店');
ok($zip->set_number('9508680')->is_valid_number, '公立大学法人 新潟県立大学');
ok($zip->set_number('9508681')->is_valid_number, '(株) ニューズ・ライン');
ok($zip->set_number('9508701')->is_valid_number, 'クロスウィルメディカル 株式会社');
ok($zip->set_number('9508707')->is_valid_number, '株式会社 新潟日立');
ok($zip->set_number('9508708')->is_valid_number, '白新商会');
ok($zip->set_number('9508709')->is_valid_number, '新潟市東区役所');
ok($zip->set_number('9508710')->is_valid_number, '新潟万代島総合企画 株式会社');
ok($zip->set_number('9508711')->is_valid_number, '新潟商工会議所');
ok($zip->set_number('9508715')->is_valid_number, '株式会社 ナビック');
ok($zip->set_number('9508716')->is_valid_number, '新潟地域振興局');
ok($zip->set_number('9508717')->is_valid_number, '新潟トヨペット 株式会社');
ok($zip->set_number('9508718')->is_valid_number, '新潟県 土地改良事業団体連合会');
ok($zip->set_number('9508720')->is_valid_number, '白勢商事 株式会社');
ok($zip->set_number('9508721')->is_valid_number, '新潟刑務所');
ok($zip->set_number('9508722')->is_valid_number, 'トヨタカローラ新潟 株式会社 新潟桜木店');
ok($zip->set_number('9508723')->is_valid_number, '出光興産 株式会社 新潟石油製品輸入基地');
ok($zip->set_number('9508724')->is_valid_number, '第一印刷所');
ok($zip->set_number('9508725')->is_valid_number, '社会医療法人 新潟臨港保健会 新潟臨港病院');
ok($zip->set_number('9508727')->is_valid_number, '株式会社 レックス');
ok($zip->set_number('9508730')->is_valid_number, 'サトウ食品 株式会社');
ok($zip->set_number('9508732')->is_valid_number, '大塚製薬 株式会社 新潟出張所');
ok($zip->set_number('9508733')->is_valid_number, '清水商事 株式会社');
ok($zip->set_number('9508735')->is_valid_number, '一正蒲鉾 株式会社');
ok($zip->set_number('9508736')->is_valid_number, '市民生協にいがた生活協同組合');
ok($zip->set_number('9508737')->is_valid_number, 'ユアサ商事 株式会社 新潟支店');
ok($zip->set_number('9508738')->is_valid_number, '丸運建設 株式会社');
ok($zip->set_number('9508740')->is_valid_number, '菱機工業 株式会社 新潟支店');
ok($zip->set_number('9508741')->is_valid_number, '株式会社 芳樹園');
ok($zip->set_number('9508742')->is_valid_number, '山市');
ok($zip->set_number('9508744')->is_valid_number, '東北電力 株式会社 新潟火力発電所');
ok($zip->set_number('9508745')->is_valid_number, '新潟日産自動車 株式会社');
ok($zip->set_number('9508746')->is_valid_number, '株式会社 第四銀行');
ok($zip->set_number('9508747')->is_valid_number, '第四銀行 事務センター');
ok($zip->set_number('9508748')->is_valid_number, '北陸ガス 株式会社');
ok($zip->set_number('9508749')->is_valid_number, '第四ビジネスサービス 株式会社');
ok($zip->set_number('9508750')->is_valid_number, '三菱商事 株式会社 新潟支店');
ok($zip->set_number('9508751')->is_valid_number, '日本生命保険 相互会社 新潟支社');
ok($zip->set_number('9508753')->is_valid_number, '株式会社 エヌ・シー・エス');
ok($zip->set_number('9508755')->is_valid_number, '三井住友海上火災保険 株式会社 新潟支店');
ok($zip->set_number('9508759')->is_valid_number, '損害保険ジャパン 株式会社');
ok($zip->set_number('9508794')->is_valid_number, '新潟地域センター');
ok($zip->set_number('9508798')->is_valid_number, '新潟逓信病院');
ok($zip->set_number('9508801')->is_valid_number, '国土交通省 北陸地方整備局');
ok($zip->set_number('9518502')->is_valid_number, '新潟地方検察庁');
ok($zip->set_number('9518503')->is_valid_number, '福田道路 株式会社');
ok($zip->set_number('9518504')->is_valid_number, '新潟地方法務局');
ok($zip->set_number('9518507')->is_valid_number, '新潟地下開発 株式会社');
ok($zip->set_number('9518508')->is_valid_number, '新潟放送局(NHK 新潟放送局)');
ok($zip->set_number('9518510')->is_valid_number, '新潟大学 医学部');
ok($zip->set_number('9518511')->is_valid_number, '新潟地方裁判所');
ok($zip->set_number('9518512')->is_valid_number, '新潟簡易裁判所');
ok($zip->set_number('9518513')->is_valid_number, '新潟家庭裁判所');
ok($zip->set_number('9518514')->is_valid_number, '新潟大学 歯学部・歯学部附属病院');
ok($zip->set_number('9518518')->is_valid_number, '新潟大学 医学部保健学科');
ok($zip->set_number('9518519')->is_valid_number, '東日本電信電話 株式会社 新潟支店');
ok($zip->set_number('9518520')->is_valid_number, '新潟大学 医歯学総合病院');
ok($zip->set_number('9518521')->is_valid_number, '株式会社 新潟テレビ21');
ok($zip->set_number('9518528')->is_valid_number, '環境をサポートする 株式会社 キラメキ');
ok($zip->set_number('9518530')->is_valid_number, '株式会社 三越 新潟店');
ok($zip->set_number('9518531')->is_valid_number, '新和証券 株式会社');
ok($zip->set_number('9518533')->is_valid_number, 'ミサワホーム北越 株式会社');
ok($zip->set_number('9518535')->is_valid_number, '新潟大学教育学部附属学校');
ok($zip->set_number('9518536')->is_valid_number, '日本通運 (株) 新潟支店');
ok($zip->set_number('9518540')->is_valid_number, '東光商事 株式会社');
ok($zip->set_number('9518544')->is_valid_number, '新潟県立 新潟高等学校 通信制');
ok($zip->set_number('9518550')->is_valid_number, '新潟市役所');
ok($zip->set_number('9518551')->is_valid_number, '読売新聞社 新潟支局');
ok($zip->set_number('9518552')->is_valid_number, '新潟市郵送証明センター');
ok($zip->set_number('9518553')->is_valid_number, '新潟市中央区役所');
ok($zip->set_number('9518554')->is_valid_number, '新潟市役所 ふるまち庁舎');
ok($zip->set_number('9518555')->is_valid_number, '新潟市水族館 マリンピア日本海');
ok($zip->set_number('9518556')->is_valid_number, '新潟市美術館');
ok($zip->set_number('9518560')->is_valid_number, '新潟市水道局');
ok($zip->set_number('9518566')->is_valid_number, '新潟県立 がんセンター新潟病院');
ok($zip->set_number('9518567')->is_valid_number, '源川医科器械 株式会社');
ok($zip->set_number('9518570')->is_valid_number, '新潟県 信用農業協同組合連合会');
ok($zip->set_number('9518580')->is_valid_number, '日本歯科大学 新潟歯学部');
ok($zip->set_number('9518581')->is_valid_number, '社団法人 新潟県医師会');
ok($zip->set_number('9518585')->is_valid_number, '新潟大学 脳研究所');
ok($zip->set_number('9518586')->is_valid_number, '北陸瓦斯 株式会社 新潟営業所');
ok($zip->set_number('9518601')->is_valid_number, '株式会社 第四銀行');
ok($zip->set_number('9518610')->is_valid_number, '敦井産業 株式会社');
ok($zip->set_number('9518611')->is_valid_number, '大和證券 株式会社 新潟支店');
ok($zip->set_number('9518612')->is_valid_number, '株式会社 加島屋');
ok($zip->set_number('9518620')->is_valid_number, '株式会社 新潟日報社');
ok($zip->set_number('9518622')->is_valid_number, '日本銀行 新潟支店');
ok($zip->set_number('9518629')->is_valid_number, '新潟県 農業団体健康保険組合');
ok($zip->set_number('9518630')->is_valid_number, '三井住友信託銀行 株式会社 新潟支店');
ok($zip->set_number('9518632')->is_valid_number, '株式会社 高助');
ok($zip->set_number('9518633')->is_valid_number, '東北電力 株式会社 新潟支店');
ok($zip->set_number('9518640')->is_valid_number, '新潟県信用保証協会');
ok($zip->set_number('9518650')->is_valid_number, '株式会社 本間組');
ok($zip->set_number('9518655')->is_valid_number, '株式会社 新潟放送');
ok($zip->set_number('9518666')->is_valid_number, '新潟信用金庫');
ok($zip->set_number('9518668')->is_valid_number, '株式会社 福田組');
ok($zip->set_number('9518678')->is_valid_number, '新潟県 経済農業協合組合連合会');
ok($zip->set_number('9518680')->is_valid_number, '財団法人 新潟県保健衛生センター');
ok($zip->set_number('9518685')->is_valid_number, '新潟税務署');
ok($zip->set_number('9518686')->is_valid_number, '新潟縣 信用組合');
ok($zip->set_number('9521292')->is_valid_number, '佐渡市役所');
ok($zip->set_number('9521393')->is_valid_number, '佐渡市役所 佐和田行政サービスセンター');
ok($zip->set_number('9521592')->is_valid_number, '佐渡市役所 相川支所');
ok($zip->set_number('9521593')->is_valid_number, '佐渡税務署');
ok($zip->set_number('9528501')->is_valid_number, '佐渡市役所 両津支所');
ok($zip->set_number('9528502')->is_valid_number, '佐渡農業協同組合');
ok($zip->set_number('9530192')->is_valid_number, '新潟市西蒲区役所 岩室出張所');
ok($zip->set_number('9530193')->is_valid_number, '株式会社 末広製菓');
ok($zip->set_number('9538501')->is_valid_number, '株式会社 伸和');
ok($zip->set_number('9538503')->is_valid_number, '新潟かがやき農業協同組合');
ok($zip->set_number('9538601')->is_valid_number, '巻税務署');
ok($zip->set_number('9538602')->is_valid_number, '北越農事 株式会社');
ok($zip->set_number('9538666')->is_valid_number, '新潟市西蒲区役所');
ok($zip->set_number('9540192')->is_valid_number, '長岡市役所 中之島支所');
ok($zip->set_number('9540195')->is_valid_number, '(株) カネタ馬場長');
ok($zip->set_number('9548619')->is_valid_number, '株式会社 近藤商店');
ok($zip->set_number('9548658')->is_valid_number, '株式会社 スノーピーク');
ok($zip->set_number('9548686')->is_valid_number, '見附市役所');
ok($zip->set_number('9550192')->is_valid_number, '三条市役所 下田庁舎');
ok($zip->set_number('9558501')->is_valid_number, 'アークランズ 株式会社');
ok($zip->set_number('9558503')->is_valid_number, '清水商事 株式会社');
ok($zip->set_number('9558505')->is_valid_number, 'マルソー 株式会社');
ok($zip->set_number('9558510')->is_valid_number, '株式会社 コロナ');
ok($zip->set_number('9558511')->is_valid_number, '新潟県 済生会 三条病院');
ok($zip->set_number('9558543')->is_valid_number, '大竹産業 株式会社');
ok($zip->set_number('9558550')->is_valid_number, '大竹オール 株式会社');
ok($zip->set_number('9558555')->is_valid_number, '株式会社 高敏');
ok($zip->set_number('9558558')->is_valid_number, 'トラスコ中山 株式会社 新潟支店');
ok($zip->set_number('9558567')->is_valid_number, '株式会社 柄長');
ok($zip->set_number('9558567')->is_valid_number, '株式会社 ハーモニック');
ok($zip->set_number('9558575')->is_valid_number, '三条社会保険事務所');
ok($zip->set_number('9558577')->is_valid_number, 'シンワ測定 株式会社');
ok($zip->set_number('9558585')->is_valid_number, 'パピー製販 株式会社');
ok($zip->set_number('9558588')->is_valid_number, 'パール金属 株式会社');
ok($zip->set_number('9558589')->is_valid_number, '丸喜重量運輸 株式会社');
ok($zip->set_number('9558601')->is_valid_number, '川口工器 株式会社');
ok($zip->set_number('9558602')->is_valid_number, '三条税務署');
ok($zip->set_number('9558603')->is_valid_number, '三条商工会議所');
ok($zip->set_number('9558612')->is_valid_number, '株式会社 関マーク製作所');
ok($zip->set_number('9558655')->is_valid_number, '株式会社 高儀');
ok($zip->set_number('9558666')->is_valid_number, '三条信用金庫');
ok($zip->set_number('9558677')->is_valid_number, '高森コーキ 株式会社');
ok($zip->set_number('9558686')->is_valid_number, '三条市役所');
ok($zip->set_number('9558688')->is_valid_number, '三恵 株式会社');
ok($zip->set_number('9560192')->is_valid_number, '新潟市秋葉区役所 小須戸出張所');
ok($zip->set_number('9568601')->is_valid_number, '新潟市秋葉区役所');
ok($zip->set_number('9568602')->is_valid_number, '新津税務署');
ok($zip->set_number('9568603')->is_valid_number, '新潟薬科大学');
ok($zip->set_number('9568625')->is_valid_number, '新潟地域振興局');
ok($zip->set_number('9568635')->is_valid_number, '新潟地域振興局 農林振興部');
ok($zip->set_number('9570192')->is_valid_number, '聖籠町役場');
ok($zip->set_number('9570193')->is_valid_number, '新潟県 警察本部運転免許センター');
ok($zip->set_number('9570195')->is_valid_number, '日本海エル・エヌ・ジー 株式会社');
ok($zip->set_number('9570196')->is_valid_number, '株式会社 堀川');
ok($zip->set_number('9570197')->is_valid_number, 'グローバルウェーハズ・ジャパン 株式会社');
ok($zip->set_number('9570293')->is_valid_number, '片山食品 株式会社');
ok($zip->set_number('9578502')->is_valid_number, '新潟県立新発田農業高等学校');
ok($zip->set_number('9578503')->is_valid_number, '新潟地方法務局 新発田支局');
ok($zip->set_number('9578506')->is_valid_number, '新発田公共職業安定所');
ok($zip->set_number('9578506')->is_valid_number, '新発田労働基準監督署');
ok($zip->set_number('9578511')->is_valid_number, '新潟県 新発田地域振興局 企画振興部');
ok($zip->set_number('9578511')->is_valid_number, '新潟県 新発田地域振興局 健康福祉環境部');
ok($zip->set_number('9578511')->is_valid_number, '新潟県 新発田地域振興局 県税部');
ok($zip->set_number('9578511')->is_valid_number, '新潟県 新発田地域振興局 地域整備部');
ok($zip->set_number('9578511')->is_valid_number, '新潟県 新発田地域振興局 農業振興部');
ok($zip->set_number('9578511')->is_valid_number, '新潟県 新発田地域振興局 農村整備部');
ok($zip->set_number('9578522')->is_valid_number, '新潟県立西新発田高等学校');
ok($zip->set_number('9578530')->is_valid_number, '陸上自衛隊 新発田駐屯地');
ok($zip->set_number('9578540')->is_valid_number, '新発田社会保険事務所');
ok($zip->set_number('9578550')->is_valid_number, '新発田商工会議所');
ok($zip->set_number('9578555')->is_valid_number, '新潟県立新発田高等学校');
ok($zip->set_number('9578558')->is_valid_number, '新潟県立 新発田商業高等学校');
ok($zip->set_number('9578567')->is_valid_number, '新潟県立新発田南高等学校');
ok($zip->set_number('9578585')->is_valid_number, '敬和学園大学');
ok($zip->set_number('9578588')->is_valid_number, '新潟県立新発田病院');
ok($zip->set_number('9578601')->is_valid_number, '新発田建設 株式会社');
ok($zip->set_number('9578666')->is_valid_number, '新発田税務署');
ok($zip->set_number('9578686')->is_valid_number, '新発田市役所');
ok($zip->set_number('9578701')->is_valid_number, '京セラ 株式会社 新潟新発田工場');
ok($zip->set_number('9580292')->is_valid_number, '村上市 朝日支所');
ok($zip->set_number('9588501')->is_valid_number, '村上市役所');
ok($zip->set_number('9588533')->is_valid_number, '新潟県厚生農業協同組合連合会 村上総合病院');
ok($zip->set_number('9588555')->is_valid_number, '新潟県厚生連瀬波病院');
ok($zip->set_number('9588558')->is_valid_number, '村上プラザ');
ok($zip->set_number('9588585')->is_valid_number, '村上地域振興局');
ok($zip->set_number('9588601')->is_valid_number, '村上信用金庫');
ok($zip->set_number('9588686')->is_valid_number, '村上税務署');
ok($zip->set_number('9590192')->is_valid_number, 'パナソニック 株式会社 新潟工場');
ok($zip->set_number('9590193')->is_valid_number, '北越工業 株式会社 新潟営業所');
ok($zip->set_number('9590194')->is_valid_number, '新潟大栄信用組合');
ok($zip->set_number('9590292')->is_valid_number, 'ツインバード工業 株式会社');
ok($zip->set_number('9590293')->is_valid_number, '北越工業 株式会社');
ok($zip->set_number('9590294')->is_valid_number, '富士通フロンテック 株式会社 新潟工場');
ok($zip->set_number('9590295')->is_valid_number, '燕市役所');
ok($zip->set_number('9590296')->is_valid_number, '株式会社 本宏製作所');
ok($zip->set_number('9590392')->is_valid_number, '弥彦村役場');
ok($zip->set_number('9590393')->is_valid_number, '彌彦神社');
ok($zip->set_number('9590492')->is_valid_number, '新潟市西蒲区役所 西川出張所');
ok($zip->set_number('9590592')->is_valid_number, '新潟市西蒲区役所 潟東出張所');
ok($zip->set_number('9590593')->is_valid_number, 'スギコ産業 株式会社');
ok($zip->set_number('9590595')->is_valid_number, '株式会社 高儀');
ok($zip->set_number('9590596')->is_valid_number, 'ピーアイエス 株式会社');
ok($zip->set_number('9590597')->is_valid_number, '株式会社 UniBio');
ok($zip->set_number('9591292')->is_valid_number, '和平フレイズMS 株式会社');
ok($zip->set_number('9591293')->is_valid_number, 'アステージ 株式会社');
ok($zip->set_number('9591294')->is_valid_number, '北日本物産 株式会社');
ok($zip->set_number('9591296')->is_valid_number, '協栄信用組合');
ok($zip->set_number('9591298')->is_valid_number, '遠藤商事 株式会社');
ok($zip->set_number('9591392')->is_valid_number, '加茂市役所');
ok($zip->set_number('9591393')->is_valid_number, '東芝ホームテクノ 株式会社');
ok($zip->set_number('9591395')->is_valid_number, '株式会社 山忠');
ok($zip->set_number('9591397')->is_valid_number, '新潟県立 加茂病院');
ok($zip->set_number('9591692')->is_valid_number, '五泉市役所');
ok($zip->set_number('9591693')->is_valid_number, 'イーグルブルグマンジャパン 株式会社');
ok($zip->set_number('9591695')->is_valid_number, 'デンカ生研 株式会社 新潟工場');
ok($zip->set_number('9591794')->is_valid_number, 'たいまつ食品 株式会社');
ok($zip->set_number('9591795')->is_valid_number, '株式会社 安中製作所');
ok($zip->set_number('9591797')->is_valid_number, '蒲原鉄道 株式会社');
ok($zip->set_number('9592092')->is_valid_number, '阿賀野市役所');
ok($zip->set_number('9592093')->is_valid_number, '総合病院国民健康保険 水原郷病院');
ok($zip->set_number('9592292')->is_valid_number, '阿賀野市役所 安田支所');
ok($zip->set_number('9592393')->is_valid_number, 'フォレストゴルフクラブ');
ok($zip->set_number('9592395')->is_valid_number, 'ホテル 泉慶');
ok($zip->set_number('9592397')->is_valid_number, 'ホテル 清風苑');
ok($zip->set_number('9592688')->is_valid_number, '株式会社 日立産機システム 中条事業所');
ok($zip->set_number('9592693')->is_valid_number, '胎内市役所');
ok($zip->set_number('9592711')->is_valid_number, 'JX日鉱日石開発 株式会社 中条油業所');
ok($zip->set_number('9593192')->is_valid_number, '村上市 荒川支所');
ok($zip->set_number('9593193')->is_valid_number, '新潟県立 坂町病院');
ok($zip->set_number('9593194')->is_valid_number, '新潟県立 荒川高等学校');
ok($zip->set_number('9593196')->is_valid_number, '北陸地方整備局 羽越河川国道事務所');
ok($zip->set_number('9593292')->is_valid_number, '関川村役場');
ok($zip->set_number('9593492')->is_valid_number, '村上市 神林支所');
ok($zip->set_number('9593493')->is_valid_number, 'JA かみはやし');
ok($zip->set_number('9593993')->is_valid_number, '村上市 山北支所');
ok($zip->set_number('9594392')->is_valid_number, '阿賀町役場 鹿瀬支所');
ok($zip->set_number('9594495')->is_valid_number, '阿賀町役場');
ok($zip->set_number('9594497')->is_valid_number, '新潟県立 津川病院');
ok($zip->set_number('9600180')->is_valid_number, '株式会社 タカムラ');
ok($zip->set_number('9600181')->is_valid_number, '福島学院大学');
ok($zip->set_number('9600184')->is_valid_number, '株式会社 ひらい');
ok($zip->set_number('9600185')->is_valid_number, '新ふくしま農業協同組合');
ok($zip->set_number('9600192')->is_valid_number, '財団法人 福島県退職教職員互助会');
ok($zip->set_number('9600194')->is_valid_number, '株式会社 マイカル 福島サティ');
ok($zip->set_number('9600195')->is_valid_number, '財団法人 大原綜合病院附属大原医療センター');
ok($zip->set_number('9600280')->is_valid_number, 'トーアエイヨー 株式会社');
ok($zip->set_number('9600282')->is_valid_number, 'かむろみの郷 穴原温泉吉川屋');
ok($zip->set_number('9600283')->is_valid_number, '福島乳業 株式会社');
ok($zip->set_number('9600289')->is_valid_number, '東北通信 株式会社');
ok($zip->set_number('9600294')->is_valid_number, '福島県農業協同組合中央会');
ok($zip->set_number('9600296')->is_valid_number, '全国農業協同組合連合会 福島県本部');
ok($zip->set_number('9600297')->is_valid_number, '全国共済農業協同組合連合会 福島県本部');
ok($zip->set_number('9600298')->is_valid_number, '福島県厚生農業協同組合連合会');
ok($zip->set_number('9600596')->is_valid_number, '公益財団法人 仁泉会');
ok($zip->set_number('9600692')->is_valid_number, '伊達市役所');
ok($zip->set_number('9600695')->is_valid_number, '富士通アイソテック 株式会社');
ok($zip->set_number('9600893')->is_valid_number, '伊達市役所 霊山総合支所');
ok($zip->set_number('9600992')->is_valid_number, '伊達市役所 月舘総合支所');
ok($zip->set_number('9601192')->is_valid_number, '福島県立 福島明成高等学校');
ok($zip->set_number('9601193')->is_valid_number, 'NOK 株式会社 福島事業場');
ok($zip->set_number('9601195')->is_valid_number, '社団法人 福島県エルピーガス協会');
ok($zip->set_number('9601196')->is_valid_number, '福島県酒類卸 株式会社');
ok($zip->set_number('9601197')->is_valid_number, '日本赤十字社 福島県支部');
ok($zip->set_number('9601198')->is_valid_number, '福島県 赤十字血液センター');
ok($zip->set_number('9601292')->is_valid_number, '北芝電機 株式会社');
ok($zip->set_number('9601293')->is_valid_number, '福島大学附属図書館');
ok($zip->set_number('9601295')->is_valid_number, '福島県立 医科大学');
ok($zip->set_number('9601296')->is_valid_number, '福島大学');
ok($zip->set_number('9601297')->is_valid_number, '福島県立 医科大学附属図書館');
ok($zip->set_number('9601392')->is_valid_number, '福島市役所 飯野支所');
ok($zip->set_number('9601393')->is_valid_number, '日特エンジニアリング 株式会社 福島工場');
ok($zip->set_number('9601492')->is_valid_number, '川俣町役場');
ok($zip->set_number('9601892')->is_valid_number, '飯舘村役場');
ok($zip->set_number('9602193')->is_valid_number, 'キヤノン 株式会社 福島工場');
ok($zip->set_number('9602194')->is_valid_number, '日進堂印刷所');
ok($zip->set_number('9602195')->is_valid_number, '阿部紙工');
ok($zip->set_number('9602196')->is_valid_number, '株式会社 OKIデータMES');
ok($zip->set_number('9602292')->is_valid_number, '福島県警察 福島運転免許センター');
ok($zip->set_number('9608501')->is_valid_number, '株式会社 中合');
ok($zip->set_number('9608502')->is_valid_number, '福島県 土地改良事業団体連合会');
ok($zip->set_number('9608503')->is_valid_number, '東日本電信電話 株式会社 福島支店');
ok($zip->set_number('9608505')->is_valid_number, '福島学院大学');
ok($zip->set_number('9608506')->is_valid_number, 'ムネカタ 株式会社');
ok($zip->set_number('9608507')->is_valid_number, '日本年金機構 福島事務センター');
ok($zip->set_number('9608508')->is_valid_number, '福島テレビ');
ok($zip->set_number('9608509')->is_valid_number, '仙台国税局業務センター福島分室');
ok($zip->set_number('9608511')->is_valid_number, 'NECネットワークプロダクツ 株式会社');
ok($zip->set_number('9608512')->is_valid_number, '福島地方・家庭・簡易裁判所');
ok($zip->set_number('9608513')->is_valid_number, '福島労働局');
ok($zip->set_number('9608515')->is_valid_number, '福島県市町村職員 共済組合');
ok($zip->set_number('9608516')->is_valid_number, '福島県立医科大学 福島駅前キャンパス');
ok($zip->set_number('9608518')->is_valid_number, '株式会社 帝国データバンク 福島支店');
ok($zip->set_number('9608520')->is_valid_number, '株式会社 ヤクルト本社 福島工場');
ok($zip->set_number('9608521')->is_valid_number, '財団法人 電気通信共済会 福島営業所');
ok($zip->set_number('9608522')->is_valid_number, '東北電力ネットワーク 株式会社 福島電力センター');
ok($zip->set_number('9608523')->is_valid_number, '損害保険ジャパン日本興亜 株式会社');
ok($zip->set_number('9608524')->is_valid_number, '東北電力 (株) 福島支店');
ok($zip->set_number('9608530')->is_valid_number, '福島赤十字病院');
ok($zip->set_number('9608531')->is_valid_number, 'テレビユー福島');
ok($zip->set_number('9608534')->is_valid_number, '(財) 福島県教育会館');
ok($zip->set_number('9608536')->is_valid_number, '福島刑務支所');
ok($zip->set_number('9608540')->is_valid_number, '全労災 福島県本部');
ok($zip->set_number('9608546')->is_valid_number, '全国健康保険協会 福島支部');
ok($zip->set_number('9608550')->is_valid_number, '財団法人 福島県 保健衛生協会');
ok($zip->set_number('9608555')->is_valid_number, '福島県 社会保険診療報酬支払基金');
ok($zip->set_number('9608558')->is_valid_number, '松下電器産業 株式会社 オーディオ事業部 福島工場');
ok($zip->set_number('9608560')->is_valid_number, '福島県 衛生公害研究所');
ok($zip->set_number('9608566')->is_valid_number, '生活協同組合 コープふくしま');
ok($zip->set_number('9608567')->is_valid_number, '日本年金機構 東北福島年金事務所');
ok($zip->set_number('9608575')->is_valid_number, '社団法人 福島県医師会');
ok($zip->set_number('9608580')->is_valid_number, '株式会社 ユアテック 福島支社');
ok($zip->set_number('9608581')->is_valid_number, '日東紡績 株式会社 福島工場');
ok($zip->set_number('9608584')->is_valid_number, '国土交通省 東北地方整備局 福島河川国道事務所');
ok($zip->set_number('9608585')->is_valid_number, '桜の聖母短期大学');
ok($zip->set_number('9608588')->is_valid_number, '日本放送協会 福島放送局');
ok($zip->set_number('9608589')->is_valid_number, '福島公共職業安定所');
ok($zip->set_number('9608601')->is_valid_number, '福島市役所');
ok($zip->set_number('9608602')->is_valid_number, '株式会社 福島民報社');
ok($zip->set_number('9608603')->is_valid_number, '株式会社 みずほ銀行 福島支店');
ok($zip->set_number('9608605')->is_valid_number, '株式会社 岩瀬書店');
ok($zip->set_number('9608607')->is_valid_number, '東北労働金庫 福島県本部');
ok($zip->set_number('9608610')->is_valid_number, '佐藤工業 株式会社');
ok($zip->set_number('9608611')->is_valid_number, '一般財団法人 大原記念財団 大原綜合病院');
ok($zip->set_number('9608614')->is_valid_number, '日本銀行 福島支店');
ok($zip->set_number('9608620')->is_valid_number, '福島 税務署');
ok($zip->set_number('9608625')->is_valid_number, '株式会社 福島銀行');
ok($zip->set_number('9608626')->is_valid_number, '(株) 東邦銀行事務センター');
ok($zip->set_number('9608633')->is_valid_number, '株式会社 東邦銀行 本店');
ok($zip->set_number('9608639')->is_valid_number, '福島交通 株式会社');
ok($zip->set_number('9608648')->is_valid_number, '福島民友新聞 株式会社');
ok($zip->set_number('9608651')->is_valid_number, '大和証券 株式会社 福島支店');
ok($zip->set_number('9608655')->is_valid_number, '株式会社 ラジオ福島');
ok($zip->set_number('9608660')->is_valid_number, '福島信用金庫');
ok($zip->set_number('9608666')->is_valid_number, '福島県 自動車県税事務所');
ok($zip->set_number('9608668')->is_valid_number, '福島県 県北建設事務所');
ok($zip->set_number('9608670')->is_valid_number, '福島県庁');
ok($zip->set_number('9608677')->is_valid_number, '福島県 県北地方振興局 県税部');
ok($zip->set_number('9608686')->is_valid_number, '福島県警察本部');
ok($zip->set_number('9608688')->is_valid_number, '福島県教育庁');
ok($zip->set_number('9610192')->is_valid_number, '中島村役場');
ok($zip->set_number('9610392')->is_valid_number, '福島県 白河市東庁舎');
ok($zip->set_number('9610492')->is_valid_number, '白河市役所 表郷庁舎');
ok($zip->set_number('9618501')->is_valid_number, '西郷村役場');
ok($zip->set_number('9618508')->is_valid_number, '丸水白河魚市場 株式会社');
ok($zip->set_number('9618511')->is_valid_number, '家畜改良センター');
ok($zip->set_number('9618516')->is_valid_number, '福島県南生活協同組合');
ok($zip->set_number('9618522')->is_valid_number, '白河警察署');
ok($zip->set_number('9618585')->is_valid_number, '夢みなみ農業協同組合 営農経済本店');
ok($zip->set_number('9618588')->is_valid_number, '西白河酪農業協同組合');
ok($zip->set_number('9618601')->is_valid_number, '白河信用金庫');
ok($zip->set_number('9618602')->is_valid_number, '白河市役所');
ok($zip->set_number('9618611')->is_valid_number, '白河税務署');
ok($zip->set_number('9618686')->is_valid_number, '日本工機 株式会社 白河製造所');
ok($zip->set_number('9620292')->is_valid_number, '須賀川市役所 長沼支所');
ok($zip->set_number('9620392')->is_valid_number, '須賀川市役所 岩瀬支所');
ok($zip->set_number('9620592')->is_valid_number, '天栄村役場');
ok($zip->set_number('9620692')->is_valid_number, '羽島湖高原レジーナの森 株式会社');
ok($zip->set_number('9628501')->is_valid_number, 'ジョンソンエンドジョンソン 株式会社 須賀川工場');
ok($zip->set_number('9628502')->is_valid_number, '笠原工業 株式会社');
ok($zip->set_number('9628503')->is_valid_number, '公立岩瀬病院組合');
ok($zip->set_number('9628507')->is_valid_number, '独立行政法人 国立病院機構 福島病院');
ok($zip->set_number('9628508')->is_valid_number, '日本工営パワー・システムズ 株式会社');
ok($zip->set_number('9628509')->is_valid_number, '須賀川市総合福祉センター');
ok($zip->set_number('9628601')->is_valid_number, '須賀川市役所');
ok($zip->set_number('9630192')->is_valid_number, '根本石油 株式会社');
ok($zip->set_number('9630195')->is_valid_number, '福島日野自動車 株式会社');
ok($zip->set_number('9630196')->is_valid_number, '日本全薬工業 株式会社');
ok($zip->set_number('9630197')->is_valid_number, '財団法人 慈山会医学研究所付属坪井病院');
ok($zip->set_number('9630198')->is_valid_number, '医療法人 安積保養園');
ok($zip->set_number('9630296')->is_valid_number, '株式会社 日本デジタル研究所');
ok($zip->set_number('9630297')->is_valid_number, '福島県ハイテクプラザ');
ok($zip->set_number('9631380')->is_valid_number, 'かんぽの宿郡山');
ok($zip->set_number('9631383')->is_valid_number, '一般財団法人 太田総合病院附属 太田熱海病院');
ok($zip->set_number('9631386')->is_valid_number, '中山商事 株式会社 郡山営業所');
ok($zip->set_number('9631387')->is_valid_number, 'ホテル華の湯');
ok($zip->set_number('9631388')->is_valid_number, '東北花材 株式会社');
ok($zip->set_number('9633492')->is_valid_number, '小野町役場');
ok($zip->set_number('9633692')->is_valid_number, '田村市 滝根行政局');
ok($zip->set_number('9634192')->is_valid_number, '田村市大越行政局');
ok($zip->set_number('9634393')->is_valid_number, '田村市役所');
ok($zip->set_number('9634396')->is_valid_number, 'たむら農業協同組合');
ok($zip->set_number('9634398')->is_valid_number, '福島県立 船引高等学校');
ok($zip->set_number('9634692')->is_valid_number, '田村市役所 常葉行政局');
ok($zip->set_number('9635192')->is_valid_number, '矢祭町役場');
ok($zip->set_number('9635492')->is_valid_number, '塙町役場');
ok($zip->set_number('9635493')->is_valid_number, 'JA福島厚生連 塙厚生病院');
ok($zip->set_number('9635692')->is_valid_number, '京セラ 株式会社 福島棚倉工場');
ok($zip->set_number('9636192')->is_valid_number, '棚倉町役場');
ok($zip->set_number('9636292')->is_valid_number, '浅川町役場');
ok($zip->set_number('9636392')->is_valid_number, '玉川村役場');
ok($zip->set_number('9637796')->is_valid_number, '三春町役場');
ok($zip->set_number('9637893')->is_valid_number, '石川町役場');
ok($zip->set_number('9638292')->is_valid_number, '平田村役場');
ok($zip->set_number('9638501')->is_valid_number, '公益財団法人 星総合病院');
ok($zip->set_number('9638502')->is_valid_number, '福島さくら農業協同組合');
ok($zip->set_number('9638503')->is_valid_number, '学校法人 郡山開成学園 郡山女子大学 郡山女子大学短期大学部 郡山女子大学附属高等学校 郡山女子大学附属幼稚園');
ok($zip->set_number('9638506')->is_valid_number, '東印郡山青果 株式会社');
ok($zip->set_number('9638507')->is_valid_number, '(株) 西友 ザ・モール郡山店');
ok($zip->set_number('9638508')->is_valid_number, '日本たばこ産業 株式会社 郡山工場');
ok($zip->set_number('9638510')->is_valid_number, '株式会社 日立製作所 通信ネットワーク事業部');
ok($zip->set_number('9638511')->is_valid_number, '福島トヨペット 株式会社');
ok($zip->set_number('9638513')->is_valid_number, '住友生命保険 相互会社 福島支社');
ok($zip->set_number('9638515')->is_valid_number, '有限会社 墨雅書道会');
ok($zip->set_number('9638519')->is_valid_number, '株式会社 NTT東日本-福島 郡山支店');
ok($zip->set_number('9638520')->is_valid_number, '株式会社 エフコム');
ok($zip->set_number('9638530')->is_valid_number, '株式会社 協立医療');
ok($zip->set_number('9638531')->is_valid_number, '福島民報 郡山本社');
ok($zip->set_number('9638533')->is_valid_number, '株式会社 福島中央テレビ');
ok($zip->set_number('9638535')->is_valid_number, '株式会社 福島放送');
ok($zip->set_number('9638539')->is_valid_number, '福島地方法務局 郡山支局');
ok($zip->set_number('9638540')->is_valid_number, '福島県教育庁県中教育事務所');
ok($zip->set_number('9638540')->is_valid_number, '福島県県中地方振興局');
ok($zip->set_number('9638543')->is_valid_number, '株式会社 ヨークベニマル');
ok($zip->set_number('9638550')->is_valid_number, '福島ミドリ安全 株式会社');
ok($zip->set_number('9638551')->is_valid_number, '日本放送協会 福島放送局 郡山支局');
ok($zip->set_number('9638555')->is_valid_number, '株式会社 アイワ・コーポ');
ok($zip->set_number('9638556')->is_valid_number, 'パナソニック インダストリー 株式会社 郡山事業所');
ok($zip->set_number('9638558')->is_valid_number, '一般財団法人 太田綜合病院附属 太田西ノ内病院');
ok($zip->set_number('9638560')->is_valid_number, 'セキスイハイム東北 株式会社 福島支社');
ok($zip->set_number('9638563')->is_valid_number, '一般財団法人 脳神経疾患研究所附属 総合南東北病院');
ok($zip->set_number('9638564')->is_valid_number, '一般財団法人 脳神経疾患研究所附属 南東北医療クリニック');
ok($zip->set_number('9638566')->is_valid_number, '福島地方裁判所 郡山支部');
ok($zip->set_number('9638567')->is_valid_number, '株式会社 宮川紙店');
ok($zip->set_number('9638568')->is_valid_number, '株式会社 ジオット');
ok($zip->set_number('9638570')->is_valid_number, '東京海上日動火災保険 株式会社 福島支店');
ok($zip->set_number('9638575')->is_valid_number, '東北電力 株式会社 郡山営業所');
ok($zip->set_number('9638577')->is_valid_number, '株式会社 ニノテック');
ok($zip->set_number('9638578')->is_valid_number, 'ホテル ハマツ');
ok($zip->set_number('9638580')->is_valid_number, '日本生命保険 相互会社 郡山支社');
ok($zip->set_number('9638583')->is_valid_number, '東北工業 株式会社');
ok($zip->set_number('9638585')->is_valid_number, '公益財団法人 湯浅報恩会 寿泉堂綜合病院');
ok($zip->set_number('9638586')->is_valid_number, '三菱電機 株式会社 コミュニケーシヨン・ネットワーク製作所 郡山工場');
ok($zip->set_number('9638588')->is_valid_number, '株式会社 三万石');
ok($zip->set_number('9638601')->is_valid_number, '郡山市役所');
ok($zip->set_number('9638602')->is_valid_number, '株式会社 東邦銀行 郡山支店');
ok($zip->set_number('9638609')->is_valid_number, '郡山公共職業安定所');
ok($zip->set_number('9638610')->is_valid_number, '郡山警察署');
ok($zip->set_number('9638611')->is_valid_number, '学校法人 晴川学舎 奥羽大学');
ok($zip->set_number('9638622')->is_valid_number, '株式会社 大東銀行');
ok($zip->set_number('9638630')->is_valid_number, '郡山信用金庫');
ok($zip->set_number('9638637')->is_valid_number, 'ニデックプレシジョン 株式会社 郡山事業所');
ok($zip->set_number('9638642')->is_valid_number, '日本大学 工学部');
ok($zip->set_number('9638655')->is_valid_number, '郡山 税務署');
ok($zip->set_number('9638660')->is_valid_number, '株式会社 福島銀行 郡山支店');
ok($zip->set_number('9638661')->is_valid_number, '大和証券 株式会社 郡山支店');
ok($zip->set_number('9638664')->is_valid_number, '福島信用販売 株式会社');
ok($zip->set_number('9638665')->is_valid_number, '明治安田生命保険 相互会社 郡山支社');
ok($zip->set_number('9638666')->is_valid_number, '佐藤 株式会社');
ok($zip->set_number('9638668')->is_valid_number, '福島県商工信用組合');
ok($zip->set_number('9638670')->is_valid_number, '宝化成機器 株式会社');
ok($zip->set_number('9638675')->is_valid_number, '株式会社 岡部');
ok($zip->set_number('9638676')->is_valid_number, '東北アルフレッサ 株式会社');
ok($zip->set_number('9638677')->is_valid_number, '株式会社 東流社 郡山営業所');
ok($zip->set_number('9638685')->is_valid_number, '郡山運送 株式会社');
ok($zip->set_number('9638686')->is_valid_number, 'ブリヂストンタイヤ福島販売 株式会社');
ok($zip->set_number('9638794')->is_valid_number, '郡山店 法人サービス部');
ok($zip->set_number('9640292')->is_valid_number, '二本松市東和支所');
ok($zip->set_number('9640392')->is_valid_number, '二本松市岩代支所');
ok($zip->set_number('9648501')->is_valid_number, '社会保険福島二本松病院');
ok($zip->set_number('9648558')->is_valid_number, '独立行政法人 国際協力機構 二本松青年海外協力隊訓練所');
ok($zip->set_number('9648567')->is_valid_number, '医療法人 辰星会 枡病院');
ok($zip->set_number('9648577')->is_valid_number, '二本松商工会議所');
ok($zip->set_number('9648601')->is_valid_number, '二本松市役所');
ok($zip->set_number('9658501')->is_valid_number, '福島県 会津地方振興局');
ok($zip->set_number('9658502')->is_valid_number, '会津富士通セミコンダクター 株式会社');
ok($zip->set_number('9658503')->is_valid_number, '会津若松警察署');
ok($zip->set_number('9658504')->is_valid_number, '会津富士通セミコンダクターウェハーソリューション 株式会社');
ok($zip->set_number('9658505')->is_valid_number, '東北電力 株式会社 会津若松支社');
ok($zip->set_number('9658506')->is_valid_number, '会津富士通セミコンダクターマニュファクチャリング 株式会社');
ok($zip->set_number('9658510')->is_valid_number, 'NTT東日本-福島 (株) 会津支店');
ok($zip->set_number('9658511')->is_valid_number, '会津天宝醸造 株式会社');
ok($zip->set_number('9658516')->is_valid_number, '日本年金機構 会津若松年金事務所');
ok($zip->set_number('9658520')->is_valid_number, 'オリンパス光電子 (株) 会津事業場');
ok($zip->set_number('9658522')->is_valid_number, '三菱伸銅 株式会社 若松製作所');
ok($zip->set_number('9658530')->is_valid_number, 'アピタ会津若松店');
ok($zip->set_number('9658540')->is_valid_number, '福島地方裁判所 会津若松支部');
ok($zip->set_number('9658550')->is_valid_number, '若松営林署');
ok($zip->set_number('9658558')->is_valid_number, 'リズム工機 株式会社');
ok($zip->set_number('9658567')->is_valid_number, '国土交通省 北陸地方整備局 阿賀川河川事務所');
ok($zip->set_number('9658570')->is_valid_number, '会津大学短期大学部');
ok($zip->set_number('9658580')->is_valid_number, '会津大学');
ok($zip->set_number('9658585')->is_valid_number, '財団法人 竹田綜合病院');
ok($zip->set_number('9658588')->is_valid_number, '(有) 東鳳');
ok($zip->set_number('9658601')->is_valid_number, '会津若松市役所');
ok($zip->set_number('9658611')->is_valid_number, '総合会津中央病院');
ok($zip->set_number('9658678')->is_valid_number, '東邦銀行 会津支店');
ok($zip->set_number('9660192')->is_valid_number, '喜多方市 熱塩加納総合支所');
ok($zip->set_number('9660193')->is_valid_number, '会津いいで農業協同組合 熱塩加納支所');
ok($zip->set_number('9660194')->is_valid_number, '有限会社 ホテルふじや');
ok($zip->set_number('9660485')->is_valid_number, '北塩原村役場');
ok($zip->set_number('9668601')->is_valid_number, '喜多方市役所');
ok($zip->set_number('9670692')->is_valid_number, '会津森林管理署南会津支署');
ok($zip->set_number('9678501')->is_valid_number, '南会津町役場');
ok($zip->set_number('9680498')->is_valid_number, '只見町役場');
ok($zip->set_number('9690196')->is_valid_number, '泉崎村役場');
ok($zip->set_number('9690197')->is_valid_number, 'イオナ インターナショナル 株式会社 福島工園');
ok($zip->set_number('9690292')->is_valid_number, '福島県立 農業短期大学校');
ok($zip->set_number('9690296')->is_valid_number, '矢吹町役場');
ok($zip->set_number('9690392')->is_valid_number, '福島県 白河市大信庁舎');
ok($zip->set_number('9690492')->is_valid_number, '鏡石町役場');
ok($zip->set_number('9691180')->is_valid_number, '株式会社 東北村田製作所 本宮工場');
ok($zip->set_number('9691181')->is_valid_number, 'アサヒビール 株式会社 福島工場');
ok($zip->set_number('9691186')->is_valid_number, '株式会社 IHI機械システム');
ok($zip->set_number('9691188')->is_valid_number, '株式会社 イワキ');
ok($zip->set_number('9691192')->is_valid_number, '本宮市役所');
ok($zip->set_number('9691193')->is_valid_number, '株式会社 東邦銀行 本宮支店');
ok($zip->set_number('9691195')->is_valid_number, '医療法人 慈久会 谷病院');
ok($zip->set_number('9691292')->is_valid_number, '本宮市役所 白沢総合支所');
ok($zip->set_number('9691392')->is_valid_number, '大玉村役場');
ok($zip->set_number('9691492')->is_valid_number, '二本松市安達支所');
ok($zip->set_number('9691692')->is_valid_number, '桑折町役場');
ok($zip->set_number('9691792')->is_valid_number, '国見町役場');
ok($zip->set_number('9691793')->is_valid_number, '藤田総合病院');
ok($zip->set_number('9692696')->is_valid_number, 'ホテルリステル猪苗代');
ok($zip->set_number('9693192')->is_valid_number, '猪苗代町役場');
ok($zip->set_number('9693392')->is_valid_number, '磐梯町役場');
ok($zip->set_number('9693393')->is_valid_number, '日曹金属化学 株式会社 会津工場');
ok($zip->set_number('9693395')->is_valid_number, '株式会社 シグマ会津工場');
ok($zip->set_number('9693396')->is_valid_number, '磐梯リゾート開発 株式会社');
ok($zip->set_number('9693492')->is_valid_number, '福島県立医科大学 会津医療センター');
ok($zip->set_number('9693593')->is_valid_number, '湯川村役場');
ok($zip->set_number('9694495')->is_valid_number, '西会津町役場');
ok($zip->set_number('9696192')->is_valid_number, '医療法人 明精会 会津西病院');
ok($zip->set_number('9696195')->is_valid_number, '会津美里町役場 本郷庁舎');
ok($zip->set_number('9696292')->is_valid_number, '会津美里町役場');
ok($zip->set_number('9696495')->is_valid_number, '会津美里町役場 新鶴庁舎');
ok($zip->set_number('9696592')->is_valid_number, '会津坂下町役場');
ok($zip->set_number('9696593')->is_valid_number, '坂下厚生総合病院');
ok($zip->set_number('9701192')->is_valid_number, 'アルプスアルパイン 株式会社 いわき開発センター');
ok($zip->set_number('9701193')->is_valid_number, 'アルプス電気 株式会社 ペリフェラル事業部 平工場');
ok($zip->set_number('9701194')->is_valid_number, '有限会社 長久保食品');
ok($zip->set_number('9708410')->is_valid_number, 'ホテルB4T エスパルいわき');
ok($zip->set_number('9708501')->is_valid_number, '日本年金機構 平年金事務所');
ok($zip->set_number('9708511')->is_valid_number, '株式会社 NTT東日本-福島 いわき支店');
ok($zip->set_number('9708516')->is_valid_number, '財団法人 磐城済世会 松村総合病院');
ok($zip->set_number('9708551')->is_valid_number, 'いわき明星大学');
ok($zip->set_number('9708611')->is_valid_number, 'いわき税務署');
ok($zip->set_number('9708625')->is_valid_number, '岡田電気産業 株式会社');
ok($zip->set_number('9708635')->is_valid_number, '佐藤 株式会社 いわき支店');
ok($zip->set_number('9708646')->is_valid_number, '株式会社 加地和組');
ok($zip->set_number('9708686')->is_valid_number, 'いわき市役所');
ok($zip->set_number('9708703')->is_valid_number, 'いわき労働基準監督署');
ok($zip->set_number('9718555')->is_valid_number, 'イオンモールいわき小名浜 イオンモール事務所');
ok($zip->set_number('9728501')->is_valid_number, '古河電池 株式会社 いわき事業所');
ok($zip->set_number('9728555')->is_valid_number, '常磐興産 株式会社 スパ・リゾート・ハワイアンズ');
ok($zip->set_number('9738501')->is_valid_number, '独立行政法人 労働者健康福祉機構 福島労災病院');
ok($zip->set_number('9738555')->is_valid_number, 'いわき市立 総合磐城共立病院');
ok($zip->set_number('9738601')->is_valid_number, 'いわき中央警察署');
ok($zip->set_number('9748686')->is_valid_number, '株式会社 クレハ 生産本部 いわき事業所');
ok($zip->set_number('9758585')->is_valid_number, '南相馬ジャスモール');
ok($zip->set_number('9758686')->is_valid_number, '南相馬市役所');
ok($zip->set_number('9768501')->is_valid_number, 'アルプス電気 株式会社 通信デバイス事業部 相馬工場');
ok($zip->set_number('9768510')->is_valid_number, '日本年金機構 相馬年金事務所');
ok($zip->set_number('9790192')->is_valid_number, '日本製紙 株式会社 勿来工場');
ok($zip->set_number('9790195')->is_valid_number, '株式会社 マルト');
ok($zip->set_number('9790196')->is_valid_number, '株式会社 マルト SC窪田店');
ok($zip->set_number('9790197')->is_valid_number, '株式会社 くすりのマルト マルト健康の森 窪田店');
ok($zip->set_number('9790198')->is_valid_number, '株式会社 ファミリー ファミリー窪田店');
ok($zip->set_number('9790695')->is_valid_number, '東京電力 株式会社 福島第二原子力発電所');
ok($zip->set_number('9790696')->is_valid_number, '楢葉町役場');
ok($zip->set_number('9791192')->is_valid_number, '富岡町役場');
ok($zip->set_number('9791392')->is_valid_number, '東京電力 (株) 福島第一原子力発電所');
ok($zip->set_number('9791495')->is_valid_number, '双葉町役場');
ok($zip->set_number('9791592')->is_valid_number, '浪江町役場');
ok($zip->set_number('9792195')->is_valid_number, '南相馬市 小高区役所');
ok($zip->set_number('9792392')->is_valid_number, '南相馬市 鹿島区役所');
ok($zip->set_number('9792393')->is_valid_number, '株式会社 菅野漬物食品');
ok($zip->set_number('9792394')->is_valid_number, '鹿島総業 株式会社 鹿島カントリー倶楽部');
ok($zip->set_number('9792792')->is_valid_number, '新地町役場');
ok($zip->set_number('9806055')->is_valid_number, '株式会社 ウィルコム 東北支社');
ok($zip->set_number('9806088')->is_valid_number, '住友生命保険 相互会社 仙台総支社');
ok($zip->set_number('9806161')->is_valid_number, '東北ミサワホーム 株式会社');
ok($zip->set_number('9806180')->is_valid_number, '伊藤忠商事 株式会社 東北支社');
ok($zip->set_number('9808401')->is_valid_number, '株式会社 東芝 東北支社');
ok($zip->set_number('9808402')->is_valid_number, '仙台北 税務署');
ok($zip->set_number('9808403')->is_valid_number, '経済産業省 東北経済産業局');
ok($zip->set_number('9808406')->is_valid_number, '仙台国税局業務センター');
ok($zip->set_number('9808407')->is_valid_number, '株式会社 ジャパンヘルスサミット');
ok($zip->set_number('9808408')->is_valid_number, '東北管区警察局');
ok($zip->set_number('9808410')->is_valid_number, '宮城県 警察本部');
ok($zip->set_number('9808411')->is_valid_number, '株式会社 第一エージェンシー');
ok($zip->set_number('9808414')->is_valid_number, '仙台商工会議所');
ok($zip->set_number('9808415')->is_valid_number, '株式会社 東日本放送 営業センター');
ok($zip->set_number('9808420')->is_valid_number, '株式会社 エフエム仙台');
ok($zip->set_number('9808421')->is_valid_number, '日本年金機構 仙台北年金事務所');
ok($zip->set_number('9808422')->is_valid_number, '宮城県市町村職員 共済組合');
ok($zip->set_number('9808423')->is_valid_number, '宮城県教育庁');
ok($zip->set_number('9808426')->is_valid_number, '東北厚生局');
ok($zip->set_number('9808429')->is_valid_number, '全国土木建築国民健康保険組合 仙台健康支援室');
ok($zip->set_number('9808430')->is_valid_number, '仙台国税局');
ok($zip->set_number('9808431')->is_valid_number, '積水ハウス不動産東北 株式会社');
ok($zip->set_number('9808433')->is_valid_number, '株式会社 仙台放送');
ok($zip->set_number('9808435')->is_valid_number, '日本放送協会 仙台放送局');
ok($zip->set_number('9808436')->is_valid_number, '財務省 東北財務局');
ok($zip->set_number('9808439')->is_valid_number, '積水ハウス 株式会社 東北シャーメゾン支店');
ok($zip->set_number('9808441')->is_valid_number, '富士通 株式会社 東北支社');
ok($zip->set_number('9808442')->is_valid_number, 'イオン 株式会社');
ok($zip->set_number('9808443')->is_valid_number, '出光興産 株式会社 東北支店');
ok($zip->set_number('9808445')->is_valid_number, '東北電力ネットワーク 株式会社 仙台電力センター');
ok($zip->set_number('9808446')->is_valid_number, '株式会社 武富士 仙台支社');
ok($zip->set_number('9808447')->is_valid_number, 'キリンビールマーケティング 株式会社 東北統括本部');
ok($zip->set_number('9808448')->is_valid_number, '明治安田生命保険 相互会社 仙台支社');
ok($zip->set_number('9808450')->is_valid_number, '仙台パルコ2');
ok($zip->set_number('9808452')->is_valid_number, '株式会社 日本政策金融公庫 仙台支店 国民生活事業');
ok($zip->set_number('9808453')->is_valid_number, '株式会社 日本政策金融公庫 仙台支店 中小企業事業');
ok($zip->set_number('9808454')->is_valid_number, '株式会社 日本政策金融公庫 仙台支店 農林水産事業');
ok($zip->set_number('9808456')->is_valid_number, '株式会社 エヌシーカード仙台');
ok($zip->set_number('9808458')->is_valid_number, '丸紅 株式会社 東北支社');
ok($zip->set_number('9808460')->is_valid_number, '東京海上日動火災保険 株式会社');
ok($zip->set_number('9808461')->is_valid_number, '日本年金機構 仙台広域事務センター');
ok($zip->set_number('9808466')->is_valid_number, '株式会社 さくら野百貨店');
ok($zip->set_number('9808477')->is_valid_number, 'ホテルメトロポリタン仙台');
ok($zip->set_number('9808478')->is_valid_number, '三菱マテリアル 株式会社 東北支店');
ok($zip->set_number('9808480')->is_valid_number, '森永乳業 株式会社 東北支店');
ok($zip->set_number('9808481')->is_valid_number, '岩谷産業 株式会社 エネルギー東北支社');
ok($zip->set_number('9808484')->is_valid_number, '仙台パルコ');
ok($zip->set_number('9808485')->is_valid_number, '仙台マークワン');
ok($zip->set_number('9808486')->is_valid_number, '株式会社 ニチレイフーズ 東北支社');
ok($zip->set_number('9808487')->is_valid_number, 'エスパル仙台 東館');
ok($zip->set_number('9808488')->is_valid_number, '株式会社 日本航空インターナショナル');
ok($zip->set_number('9808501')->is_valid_number, '株式会社 タケザワ');
ok($zip->set_number('9808505')->is_valid_number, 'りんかい日産建設 株式会社 東北支店');
ok($zip->set_number('9808508')->is_valid_number, 'JR仙台病院');
ok($zip->set_number('9808510')->is_valid_number, 'アイリスオーヤマ 株式会社');
ok($zip->set_number('9808511')->is_valid_number, '東北学院大学');
ok($zip->set_number('9808515')->is_valid_number, '株式会社 エヌ・ティ・ティ・ドコモ東北');
ok($zip->set_number('9808520')->is_valid_number, '株式会社 JTB東北');
ok($zip->set_number('9808521')->is_valid_number, '栄光時計 株式会社 仙台営業所');
ok($zip->set_number('9808525')->is_valid_number, '株式会社 東北しんきんカード');
ok($zip->set_number('9808526')->is_valid_number, 'サッポロビール 株式会社 東日本本部');
ok($zip->set_number('9808526')->is_valid_number, 'ポッカサッポロフード&ビバレッジ 株式会社 東北支社');
ok($zip->set_number('9808529')->is_valid_number, '株式会社 河北仙販');
ok($zip->set_number('9808531')->is_valid_number, '株式会社 日立製作所 東北支社');
ok($zip->set_number('9808533')->is_valid_number, 'サントリービア&スピリッツ 株式会社 東北支社');
ok($zip->set_number('9808534')->is_valid_number, '東日本興業 株式会社');
ok($zip->set_number('9808543')->is_valid_number, '株式会社 三越 仙台店');
ok($zip->set_number('9808544')->is_valid_number, '社団法人 日本金属学会');
ok($zip->set_number('9808546')->is_valid_number, 'イオン 株式会社 仙台フォーラス');
ok($zip->set_number('9808550')->is_valid_number, '東北電力 株式会社');
ok($zip->set_number('9808551')->is_valid_number, '東北電力ネットワーク 株式会社');
ok($zip->set_number('9808555')->is_valid_number, '株式会社 一・四・一');
ok($zip->set_number('9808560')->is_valid_number, 'キャノンマーケティングジャパン 株式会社 仙台支店');
ok($zip->set_number('9808561')->is_valid_number, '全国健康保険協会 宮城支部');
ok($zip->set_number('9808565')->is_valid_number, '東急建設 株式会社 東北支店');
ok($zip->set_number('9808566')->is_valid_number, '丸善雄松堂 株式会社 仙台支店');
ok($zip->set_number('9808570')->is_valid_number, '宮城県庁');
ok($zip->set_number('9808571')->is_valid_number, '三菱商事 株式会社 東北支社');
ok($zip->set_number('9808572')->is_valid_number, '東北大学 農学部・環境科学研究科・災害科学国際研究所・国際集積エレクトロニクス研究開発センター');
ok($zip->set_number('9808573')->is_valid_number, '国立大学法人 東北大学 東北メディカル・メガバンク機構');
ok($zip->set_number('9808574')->is_valid_number, '東北大学医学部附属病院');
ok($zip->set_number('9808575')->is_valid_number, '東北大学 (医学部等)');
ok($zip->set_number('9808576')->is_valid_number, '東北大学 文学部・文学研究科');
ok($zip->set_number('9808577')->is_valid_number, '東北大学 (本部事務機構等)');
ok($zip->set_number('9808578')->is_valid_number, '東北大学 (理学部・薬学部等)');
ok($zip->set_number('9808579')->is_valid_number, '東北大学(工学研究科・工学部等)');
ok($zip->set_number('9808580')->is_valid_number, '東日本旅客鉄道 株式会社 仙台支社');
ok($zip->set_number('9808581')->is_valid_number, '株式会社 バイタルネット');
ok($zip->set_number('9808583')->is_valid_number, 'カメイ 株式会社');
ok($zip->set_number('9808585')->is_valid_number, '株式会社 仙台リビング新聞社');
ok($zip->set_number('9808587')->is_valid_number, '松下電器産業 株式会社 東北支店');
ok($zip->set_number('9808588')->is_valid_number, '杜の都信用金庫');
ok($zip->set_number('9808601')->is_valid_number, '仙台法務局');
ok($zip->set_number('9808602')->is_valid_number, '国土交通省 東北地方整備局');
ok($zip->set_number('9808605')->is_valid_number, '五洋建設 株式会社 東北支店');
ok($zip->set_number('9808608')->is_valid_number, '三井住友建設 株式会社 東北支店');
ok($zip->set_number('9808621')->is_valid_number, '鹿島建設 株式会社 東北支店');
ok($zip->set_number('9808622')->is_valid_number, '株式会社 ジー・アイ・ピー');
ok($zip->set_number('9808631')->is_valid_number, '宮城県 仙台第二高等学校');
ok($zip->set_number('9808632')->is_valid_number, '(株) オフィストライ');
ok($zip->set_number('9808633')->is_valid_number, '宮城県医師会');
ok($zip->set_number('9808636')->is_valid_number, '仙台簡易裁判所');
ok($zip->set_number('9808637')->is_valid_number, '仙台家庭裁判所');
ok($zip->set_number('9808638')->is_valid_number, '仙台高等裁判所');
ok($zip->set_number('9808639')->is_valid_number, '仙台地方裁判所');
ok($zip->set_number('9808640')->is_valid_number, '株式会社 安藤・間 東北支店');
ok($zip->set_number('9808650')->is_valid_number, '一般財団法人 郵政福祉東北地方本部');
ok($zip->set_number('9808651')->is_valid_number, '株式会社 みずほ銀行 仙台支店');
ok($zip->set_number('9808652')->is_valid_number, '株式会社 藤崎');
ok($zip->set_number('9808656')->is_valid_number, '株式会社 仙台銀行');
ok($zip->set_number('9808660')->is_valid_number, '株式会社 河北新報社');
ok($zip->set_number('9808661')->is_valid_number, '東北労働金庫');
ok($zip->set_number('9808668')->is_valid_number, '東北放送 株式会社');
ok($zip->set_number('9808670')->is_valid_number, '大正製薬 株式会社 北日本支店');
ok($zip->set_number('9808671')->is_valid_number, '仙台市役所');
ok($zip->set_number('9808677')->is_valid_number, '株式会社 宮城テレビ放送 事業局');
ok($zip->set_number('9808686')->is_valid_number, '株式会社 ベネッセコーポレーション');
ok($zip->set_number('9808701')->is_valid_number, '仙台市青葉区役所');
ok($zip->set_number('9808703')->is_valid_number, '日本生命保険 相互会社 仙台支社');
ok($zip->set_number('9808707')->is_valid_number, '日本銀行 仙台支店');
ok($zip->set_number('9808711')->is_valid_number, '仙台中郵便局');
ok($zip->set_number('9808733')->is_valid_number, '日本年金機構 仙台北年金事務所');
ok($zip->set_number('9808777')->is_valid_number, '株式会社 七十七銀行 本店');
ok($zip->set_number('9808792')->is_valid_number, '(株) かんぽ生命保険 仙台サービスセンター');
ok($zip->set_number('9808793')->is_valid_number, '日本郵便 株式会社 東北支社 郵便事業本部(三種)');
ok($zip->set_number('9808794')->is_valid_number, '仙台貯金事務センター');
ok($zip->set_number('9808795')->is_valid_number, '東北総合通信局');
ok($zip->set_number('9808797')->is_valid_number, '株式会社 ゆうちょ銀行 仙台支店');
ok($zip->set_number('9808797')->is_valid_number, '株式会社 かんぽ生命 仙台支店');
ok($zip->set_number('9808797')->is_valid_number, '日本郵便 株式会社 東北支社');
ok($zip->set_number('9808798')->is_valid_number, '仙台逓信病院');
ok($zip->set_number('9810394')->is_valid_number, '鮫ヶ浦水曜日郵便局');
ok($zip->set_number('9811292')->is_valid_number, '名取市役所');
ok($zip->set_number('9811293')->is_valid_number, '宮城県立 がんセンター');
ok($zip->set_number('9811294')->is_valid_number, 'イオンモール名取エアリ');
ok($zip->set_number('9811295')->is_valid_number, '尚絅学院大学');
ok($zip->set_number('9811298')->is_valid_number, '株式会社 バイタルネット名取物流センター');
ok($zip->set_number('9811581')->is_valid_number, '株式会社 ケーヒン角田第一事業所');
ok($zip->set_number('9811582')->is_valid_number, '株式会社 ケーヒン角田第二事業所');
ok($zip->set_number('9811583')->is_valid_number, '株式会社 ケーヒン電子事業所');
ok($zip->set_number('9811592')->is_valid_number, '角田市役所');
ok($zip->set_number('9811593')->is_valid_number, 'JAみやぎ仙南農業協同組合 角田支店');
ok($zip->set_number('9811595')->is_valid_number, 'アルプス電気 (株) 通信デバイス事業部 角田工場');
ok($zip->set_number('9811596')->is_valid_number, 'アイリスオーヤマ 株式会社');
ok($zip->set_number('9812192')->is_valid_number, '丸森町役場');
ok($zip->set_number('9813180')->is_valid_number, '東北電力 株式会社 仙台北営業所');
ok($zip->set_number('9813185')->is_valid_number, '東北電力ネットワーク 株式会社 仙台北電力センター');
ok($zip->set_number('9813188')->is_valid_number, '株式会社 バイタルネット');
ok($zip->set_number('9813189')->is_valid_number, '泉区役所');
ok($zip->set_number('9813192')->is_valid_number, '宮城県 運転免許センター');
ok($zip->set_number('9813193')->is_valid_number, '東北学院 大学泉キャンパス');
ok($zip->set_number('9813194')->is_valid_number, 'みやぎ生活協同組合');
ok($zip->set_number('9813195')->is_valid_number, '新日本法規出版 株式会社');
ok($zip->set_number('9813280')->is_valid_number, 'アルプス電気 株式会社 中央研究所');
ok($zip->set_number('9813281')->is_valid_number, '独立行政法人 地域医療機能推進機構 仙台病院');
ok($zip->set_number('9813287')->is_valid_number, '泉パークタウン タピオ');
ok($zip->set_number('9813288')->is_valid_number, 'プルデンシャル生命保険 株式会社');
ok($zip->set_number('9813292')->is_valid_number, '株式会社 日本セラテック');
ok($zip->set_number('9813293')->is_valid_number, '東北セミコンダクタ 株式会社');
ok($zip->set_number('9813295')->is_valid_number, '東北国分 株式会社');
ok($zip->set_number('9813296')->is_valid_number, '凸版印刷 株式会社 東北事業部');
ok($zip->set_number('9813297')->is_valid_number, '仙台泉プレミアム・アウトレット');
ok($zip->set_number('9813298')->is_valid_number, '宮城大学');
ok($zip->set_number('9813392')->is_valid_number, '富谷市役所');
ok($zip->set_number('9813494')->is_valid_number, '株式会社 ジェーシーアイ 本部 工場');
ok($zip->set_number('9813495')->is_valid_number, '日本トーカンパッケージ 株式会社 仙台工場');
ok($zip->set_number('9813496')->is_valid_number, '富士写真フィルム 株式会社 電子映像事業部');
ok($zip->set_number('9813497')->is_valid_number, '富士フイルムオプティクス 株式会社 大和工場');
ok($zip->set_number('9813592')->is_valid_number, '大郷町役場');
ok($zip->set_number('9813680')->is_valid_number, '大和町役場');
ok($zip->set_number('9813681')->is_valid_number, 'セレスティカ・ジャパン 株式会社');
ok($zip->set_number('9813682')->is_valid_number, '公立黒川病院');
ok($zip->set_number('9813684')->is_valid_number, '陸上自衛隊 大和駐屯地');
ok($zip->set_number('9813685')->is_valid_number, '宮城県 黒川高等学校');
ok($zip->set_number('9813686')->is_valid_number, '株式会社 Aコープ東日本 宮城営業所');
ok($zip->set_number('9813688')->is_valid_number, '東北理工専門学校');
ok($zip->set_number('9813692')->is_valid_number, '大衡村役場');
ok($zip->set_number('9813697')->is_valid_number, '株式会社 本山製作所');
ok($zip->set_number('9813698')->is_valid_number, '株式会社 バイタルネット 宮城物流センター');
ok($zip->set_number('9814292')->is_valid_number, '加美町役場');
ok($zip->set_number('9814293')->is_valid_number, '株式会社 秋山食品');
ok($zip->set_number('9814294')->is_valid_number, '宮城県 中新田高等学校');
ok($zip->set_number('9814392')->is_valid_number, '加美町役場 小野田支所');
ok($zip->set_number('9818502')->is_valid_number, '仙台高等学校');
ok($zip->set_number('9818505')->is_valid_number, '宮城県 仙台地方振興事務所');
ok($zip->set_number('9818510')->is_valid_number, '宮城県 仙台北県税事務所');
ok($zip->set_number('9818522')->is_valid_number, '東北福祉大学');
ok($zip->set_number('9818523')->is_valid_number, '東北福祉大学 ステーションキャンパス');
ok($zip->set_number('9818533')->is_valid_number, '株式会社 錢高組 東北支店');
ok($zip->set_number('9818540')->is_valid_number, '飛島建設 株式会社 東北支店');
ok($zip->set_number('9818543')->is_valid_number, '学校法人 南光学園 東北高等学校 小松島キャンパス');
ok($zip->set_number('9818545')->is_valid_number, '宮城県 教職員組合');
ok($zip->set_number('9818550')->is_valid_number, '学校法人 東北文化学園大学');
ok($zip->set_number('9818551')->is_valid_number, '東北文化学園大学 東北科学技術短期大学');
ok($zip->set_number('9818552')->is_valid_number, '東北文化学園専門学校');
ok($zip->set_number('9818556')->is_valid_number, '野崎印刷紙業 株式会社 仙台支店');
ok($zip->set_number('9818557')->is_valid_number, '学校法人 宮城学院');
ok($zip->set_number('9818558')->is_valid_number, '学校法人 東北薬科大学');
ok($zip->set_number('9818560')->is_valid_number, '宮城県 高等学校教職員組合');
ok($zip->set_number('9818563')->is_valid_number, '独立行政法人 労働者健康福祉機構 東北労災病院');
ok($zip->set_number('9818570')->is_valid_number, '朴沢学園明成高等学校');
ok($zip->set_number('9818577')->is_valid_number, '一般財団法人 消防試験研究センター 宮城県支部');
ok($zip->set_number('9818585')->is_valid_number, '学校法人 三島学園');
ok($zip->set_number('9828501')->is_valid_number, '仙台赤十字病院');
ok($zip->set_number('9828502')->is_valid_number, '仙台市立病院');
ok($zip->set_number('9828505')->is_valid_number, '株式会社 東日本放送');
ok($zip->set_number('9828510')->is_valid_number, '株式会社 トーキン');
ok($zip->set_number('9828511')->is_valid_number, '北日本電線 株式会社');
ok($zip->set_number('9828521')->is_valid_number, '株式会社 ユニパル');
ok($zip->set_number('9828523')->is_valid_number, '財団法人 広南会 広南病院');
ok($zip->set_number('9828531')->is_valid_number, '仙台南年金事務所');
ok($zip->set_number('9828544')->is_valid_number, '社会福祉法人 ありのまま舎');
ok($zip->set_number('9828551')->is_valid_number, '仙台南税務署');
ok($zip->set_number('9828555')->is_valid_number, '国立療養所 西多賀病院');
ok($zip->set_number('9828566')->is_valid_number, '国土交通省 東北地方整備局 仙台河川国道事務所');
ok($zip->set_number('9828577')->is_valid_number, '東北工業大学 香澄町校舎');
ok($zip->set_number('9828585')->is_valid_number, '仙台市水道局');
ok($zip->set_number('9828588')->is_valid_number, '東北工業大学 二ツ沢校舎');
ok($zip->set_number('9828601')->is_valid_number, '仙台市太白区役所');
ok($zip->set_number('9828798')->is_valid_number, '東北郵政研修センター');
ok($zip->set_number('9838477')->is_valid_number, 'JR仙台イーストゲートビル');
ok($zip->set_number('9838501')->is_valid_number, '株式会社 日産サティオ宮城');
ok($zip->set_number('9838502')->is_valid_number, '東洋製罐 株式会社 仙台工場');
ok($zip->set_number('9838504')->is_valid_number, '宮城県 社会保険診療報酬支払基金');
ok($zip->set_number('9838507')->is_valid_number, '仙台労働基準監督署');
ok($zip->set_number('9838511')->is_valid_number, '東北福祉大学 仙台駅東口キャンパス');
ok($zip->set_number('9838512')->is_valid_number, '東北薬科大学病院');
ok($zip->set_number('9838513')->is_valid_number, '仙台市ガス局');
ok($zip->set_number('9838517')->is_valid_number, 'テクノ・マインド 株式会社');
ok($zip->set_number('9838520')->is_valid_number, '仙台医療センター');
ok($zip->set_number('9838522')->is_valid_number, '三井食品 株式會社 東北支社');
ok($zip->set_number('9838523')->is_valid_number, 'NTTファイナンス 株式会社');
ok($zip->set_number('9838533')->is_valid_number, '株式会社 菱食 仙台支社');
ok($zip->set_number('9838536')->is_valid_number, '東北医科薬科大学 医学部');
ok($zip->set_number('9838537')->is_valid_number, '東北運輸局');
ok($zip->set_number('9838543')->is_valid_number, '仙台工業高等学校');
ok($zip->set_number('9838545')->is_valid_number, 'ユアサ商事 株式会社 東北支社');
ok($zip->set_number('9838551')->is_valid_number, '独立行政法人 産業技術総合研究所 東北センター');
ok($zip->set_number('9838552')->is_valid_number, 'トラスコ中山 株式会社 プラネット東北');
ok($zip->set_number('9838555')->is_valid_number, '株式会社 高速');
ok($zip->set_number('9838556')->is_valid_number, '株式会社 サトー商会');
ok($zip->set_number('9838560')->is_valid_number, '新宮城日野自動車 株式会社');
ok($zip->set_number('9838562')->is_valid_number, '仙台市郵送事務センター');
ok($zip->set_number('9838565')->is_valid_number, '東北学院中学・高等学校');
ok($zip->set_number('9838567')->is_valid_number, 'コカ・コーラ ボトラーズジャパン 株式会社');
ok($zip->set_number('9838570')->is_valid_number, '宮城トヨタ自動車 株式会社');
ok($zip->set_number('9838585')->is_valid_number, '宮城労働局');
ok($zip->set_number('9838601')->is_valid_number, '仙台市宮城野区役所');
ok($zip->set_number('9838622')->is_valid_number, '株式会社 ユアテック');
ok($zip->set_number('9838639')->is_valid_number, 'トヨタカローラ宮城 株式会社');
ok($zip->set_number('9848501')->is_valid_number, '仙台市立病院');
ok($zip->set_number('9848503')->is_valid_number, '東北電力 株式会社 仙台南営業所');
ok($zip->set_number('9848505')->is_valid_number, 'アイビー 株式会社');
ok($zip->set_number('9848510')->is_valid_number, '矢崎総業 株式会社 仙台支社');
ok($zip->set_number('9848511')->is_valid_number, '杉本商事 株式会社 東北営業所');
ok($zip->set_number('9848512')->is_valid_number, '(株) エスエスケイ 仙台支店');
ok($zip->set_number('9848516')->is_valid_number, '株式会社 プレスアート');
ok($zip->set_number('9848518')->is_valid_number, '株式会社 広済堂HRソリューションズ 仙台営業所');
ok($zip->set_number('9848519')->is_valid_number, '東日本電信電話 株式会社 宮城支店');
ok($zip->set_number('9848522')->is_valid_number, '仙都魚類 株式会社');
ok($zip->set_number('9848525')->is_valid_number, '株式会社 五十嵐商会');
ok($zip->set_number('9848530')->is_valid_number, 'ダイト薬品 株式会社');
ok($zip->set_number('9848533')->is_valid_number, '渡辺パイプ 株式会社');
ok($zip->set_number('9848538')->is_valid_number, '社団法人 日本自動車連盟 東北本部');
ok($zip->set_number('9848539')->is_valid_number, '社団法人 日本自動車連盟 宮城支部');
ok($zip->set_number('9848540')->is_valid_number, 'タツミ産業 (株) 東北事業部');
ok($zip->set_number('9848543')->is_valid_number, '(株) カネタ田畑');
ok($zip->set_number('9848545')->is_valid_number, '(株) ユーメディア');
ok($zip->set_number('9848550')->is_valid_number, '株式会社 東機工');
ok($zip->set_number('9848551')->is_valid_number, '宮城鋼具 株式会社 仙台営業所');
ok($zip->set_number('9848552')->is_valid_number, 'カメイ (株) 宮城支店');
ok($zip->set_number('9848553')->is_valid_number, '(株) 橋本総業');
ok($zip->set_number('9848555')->is_valid_number, '株式会社 仙台水産');
ok($zip->set_number('9848557')->is_valid_number, 'ヤンマーグリーンシステム 株式会社 東北支店');
ok($zip->set_number('9848558')->is_valid_number, '株式会社 TTK');
ok($zip->set_number('9848560')->is_valid_number, '東北医科薬科大学 若林病院');
ok($zip->set_number('9848561')->is_valid_number, '宮城県 仙台第一高等学校');
ok($zip->set_number('9848567')->is_valid_number, '(株) 協和エクシオ 東北支店');
ok($zip->set_number('9848568')->is_valid_number, '株式会社 TTK 中倉ビル');
ok($zip->set_number('9848570')->is_valid_number, 'イシグロ 株式会社 仙台支店');
ok($zip->set_number('9848575')->is_valid_number, '(株) 中北電機');
ok($zip->set_number('9848577')->is_valid_number, '株式会社 サンケー');
ok($zip->set_number('9848580')->is_valid_number, '陸上自衛隊 霞目駐屯地');
ok($zip->set_number('9848584')->is_valid_number, '株式会社 東流社');
ok($zip->set_number('9848585')->is_valid_number, '日本たばこ産業 株式会社 仙台支店');
ok($zip->set_number('9848588')->is_valid_number, '東北学院大学 五橋キャンパス');
ok($zip->set_number('9848601')->is_valid_number, '若林区役所');
ok($zip->set_number('9848603')->is_valid_number, '株式会社 ホクエツ');
ok($zip->set_number('9848642')->is_valid_number, '青葉化成 株式会社');
ok($zip->set_number('9848654')->is_valid_number, '東北ナショナル設備建材 株式会社');
ok($zip->set_number('9848666')->is_valid_number, '株式会社 瀬戸屋');
ok($zip->set_number('9848668')->is_valid_number, '株式会社 菊重');
ok($zip->set_number('9848669')->is_valid_number, 'かねへい食品 株式会社 仙台支店');
ok($zip->set_number('9848670')->is_valid_number, 'マルホン 株式会社');
ok($zip->set_number('9848675')->is_valid_number, '馬淵 株式会社');
ok($zip->set_number('9848676')->is_valid_number, 'ワタヒョウ 株式会社');
ok($zip->set_number('9848680')->is_valid_number, '株式会社 植松商会');
ok($zip->set_number('9848686')->is_valid_number, '株式会社 山善 東北支社');
ok($zip->set_number('9848688')->is_valid_number, '株式会社 渡辺海苔店');
ok($zip->set_number('9858501')->is_valid_number, '塩竈市役所');
ok($zip->set_number('9858502')->is_valid_number, 'ヤマトモ水産食品 株式会社');
ok($zip->set_number('9858504')->is_valid_number, '塩釜商工会議所');
ok($zip->set_number('9858506')->is_valid_number, '宮城厚生協会 坂総合病院');
ok($zip->set_number('9858507')->is_valid_number, '第二管区海上保安本部');
ok($zip->set_number('9858510')->is_valid_number, '志波彦神社・鹽竈神社');
ok($zip->set_number('9858511')->is_valid_number, 'マルブン食品 株式会社');
ok($zip->set_number('9858521')->is_valid_number, '塩釜ガス 株式会社');
ok($zip->set_number('9858522')->is_valid_number, '塩竈港運送 株式会社');
ok($zip->set_number('9858531')->is_valid_number, '多賀城市役所');
ok($zip->set_number('9858533')->is_valid_number, '東洋刃物 株式会社 多賀城工場');
ok($zip->set_number('9858535')->is_valid_number, '東北電機製造 株式会社');
ok($zip->set_number('9858537')->is_valid_number, '東北学院大学 多賀城キャンパス');
ok($zip->set_number('9858538')->is_valid_number, '王子コンテナー 株式会社');
ok($zip->set_number('9858550')->is_valid_number, '宮城職業能力開発促進センター');
ok($zip->set_number('9858551')->is_valid_number, '日立建機 株式会社 東北支社');
ok($zip->set_number('9858555')->is_valid_number, 'ソニー (株) 仙台テクノロジーセンター');
ok($zip->set_number('9858577')->is_valid_number, '七ヶ浜町役場');
ok($zip->set_number('9858601')->is_valid_number, '塩釜税務署');
ok($zip->set_number('9858607')->is_valid_number, '東北ドック鉄工 株式会社');
ok($zip->set_number('9858655')->is_valid_number, '陸上自衛隊 多賀城駐屯地 業務隊');
ok($zip->set_number('9860195')->is_valid_number, '宮城県 石巻市 河北総合支所');
ok($zip->set_number('9860792')->is_valid_number, '南三陸町役場');
ok($zip->set_number('9862292')->is_valid_number, '女川町役場');
ok($zip->set_number('9862293')->is_valid_number, '東北電力 株式会社 女川原子力発電所');
ok($zip->set_number('9868501')->is_valid_number, '石巻市役所');
ok($zip->set_number('9868507')->is_valid_number, '株式会社 七星社');
ok($zip->set_number('9868522')->is_valid_number, '石巻赤十字病院');
ok($zip->set_number('9868525')->is_valid_number, '日本製紙石巻テクノ 株式会社');
ok($zip->set_number('9868540')->is_valid_number, '大興水産 株式会社');
ok($zip->set_number('9868555')->is_valid_number, '日本製紙 株式会社 石巻工場');
ok($zip->set_number('9868580')->is_valid_number, '石巻専修大学');
ok($zip->set_number('9868585')->is_valid_number, '株式会社 遠藤商会');
ok($zip->set_number('9870192')->is_valid_number, '涌谷町役場');
ok($zip->set_number('9870195')->is_valid_number, 'アルプス電気 株式会社 涌谷工場');
ok($zip->set_number('9870592')->is_valid_number, '一般社団法人 登米市観光物産協会');
ok($zip->set_number('9870593')->is_valid_number, 'みやぎ登米農業協同組合');
ok($zip->set_number('9870595')->is_valid_number, '登米市役所');
ok($zip->set_number('9870792')->is_valid_number, '登米市 登米総合支所');
ok($zip->set_number('9871393')->is_valid_number, '株式会社 一ノ蔵');
ok($zip->set_number('9871395')->is_valid_number, '大崎市 松山総合支所');
ok($zip->set_number('9872195')->is_valid_number, '伊藤ハムディリー 株式会社');
ok($zip->set_number('9872292')->is_valid_number, '築館税務署');
ok($zip->set_number('9872293')->is_valid_number, '栗原市役所');
ok($zip->set_number('9872392')->is_valid_number, '栗原市 一迫総合支所');
ok($zip->set_number('9872592')->is_valid_number, '栗原市役所 花山総合支所');
ok($zip->set_number('9872593')->is_valid_number, '国立 花山青少年自然の家');
ok($zip->set_number('9878602')->is_valid_number, '美里町役場');
ok($zip->set_number('9878603')->is_valid_number, '株式会社 瀬川勝雄商店');
ok($zip->set_number('9878605')->is_valid_number, '株式会社 丸協');
ok($zip->set_number('9878607')->is_valid_number, '株式会社 渡辺採種場');
ok($zip->set_number('9878608')->is_valid_number, '株式会社 瀬川本店');
ok($zip->set_number('9880392')->is_valid_number, '小宮山印刷工業 株式会社 宮城工場');
ok($zip->set_number('9880393')->is_valid_number, '気仙沼市 本吉総合支所');
ok($zip->set_number('9888501')->is_valid_number, '気仙沼市役所');
ok($zip->set_number('9888502')->is_valid_number, '気仙沼市教育委員会');
ok($zip->set_number('9888555')->is_valid_number, '気仙沼市観光キャラクター「海の子ホヤぼーや」');
ok($zip->set_number('9890292')->is_valid_number, '白石市役所');
ok($zip->set_number('9890293')->is_valid_number, '仙南信用金庫');
ok($zip->set_number('9890294')->is_valid_number, 'NECインフロンティア東北 株式会社');
ok($zip->set_number('9890295')->is_valid_number, 'セコム工業 株式会社 宮城第二物流センター');
ok($zip->set_number('9890296')->is_valid_number, 'セコム工業 株式会社 宮城第一物流センター');
ok($zip->set_number('9890592')->is_valid_number, '七ヶ宿町役場');
ok($zip->set_number('9890892')->is_valid_number, '蔵王町役場');
ok($zip->set_number('9890998')->is_valid_number, '宮城蔵王観光 株式会社');
ok($zip->set_number('9891292')->is_valid_number, '大河原税務署');
ok($zip->set_number('9891293')->is_valid_number, '株式会社 菓匠三全');
ok($zip->set_number('9891295')->is_valid_number, '大河原町役場');
ok($zip->set_number('9891392')->is_valid_number, '村田町役場');
ok($zip->set_number('9891393')->is_valid_number, '東北特殊鋼 (株)');
ok($zip->set_number('9891394')->is_valid_number, 'スポーツランドSUGO');
ok($zip->set_number('9891592')->is_valid_number, '川崎町役場');
ok($zip->set_number('9891692')->is_valid_number, '柴田町役場');
ok($zip->set_number('9891693')->is_valid_number, '仙台大学');
ok($zip->set_number('9891694')->is_valid_number, '陸上自衛隊 船岡駐屯地');
ok($zip->set_number('9891695')->is_valid_number, '東北リコー 株式会社');
ok($zip->set_number('9891795')->is_valid_number, '山崎製パン 株式会社 仙台工場');
ok($zip->set_number('9892292')->is_valid_number, '山元町役場');
ok($zip->set_number('9892393')->is_valid_number, '亘理町役場');
ok($zip->set_number('9892480')->is_valid_number, '岩沼市役所');
ok($zip->set_number('9892481')->is_valid_number, 'スズキ病院');
ok($zip->set_number('9892483')->is_valid_number, '医療法人 南東北病院');
ok($zip->set_number('9892484')->is_valid_number, '東洋ゴム工業 株式会社 仙台工場');
ok($zip->set_number('9892492')->is_valid_number, '日本製紙 株式会社 岩沼工場');
ok($zip->set_number('9892493')->is_valid_number, '株式会社 キタセキ');
ok($zip->set_number('9892496')->is_valid_number, '株式会社 ヰセキ東北');
ok($zip->set_number('9893292')->is_valid_number, '(株) 大江設計');
ok($zip->set_number('9894192')->is_valid_number, '大崎市役所 鹿島台総合支所');
ok($zip->set_number('9894592')->is_valid_number, '栗原市 瀬峰総合支所');
ok($zip->set_number('9894692')->is_valid_number, '国立療養所 東北新生園');
ok($zip->set_number('9894792')->is_valid_number, '登米市 石越総合支所');
ok($zip->set_number('9895392')->is_valid_number, '栗原市 栗駒総合支所');
ok($zip->set_number('9895492')->is_valid_number, '栗原市役所 鶯沢総合支所');
ok($zip->set_number('9895592')->is_valid_number, '栗原市 若柳総合支所');
ok($zip->set_number('9895692')->is_valid_number, '栗原市 志波姫総合支所');
ok($zip->set_number('9895693')->is_valid_number, '栗っこ農業協同組合');
ok($zip->set_number('9896181')->is_valid_number, 'アルプス電気 (株) 古川工場');
ok($zip->set_number('9896182')->is_valid_number, '東北電力ネットワーク 株式会社 古川電力センター');
ok($zip->set_number('9896183')->is_valid_number, '大崎市民病院');
ok($zip->set_number('9896185')->is_valid_number, '古川税務署');
ok($zip->set_number('9896188')->is_valid_number, '大崎市役所');
ok($zip->set_number('9896192')->is_valid_number, '東北電力 株式会社 宮城県北営業所');
ok($zip->set_number('9896193')->is_valid_number, '(株) 柳川商店');
ok($zip->set_number('9896195')->is_valid_number, '日本年金機構 古川年金事務所');
ok($zip->set_number('9896392')->is_valid_number, 'YKK AP 株式会社 東北事業所');
ok($zip->set_number('9896492')->is_valid_number, '大崎市 岩出山総合支所');
ok($zip->set_number('9896493')->is_valid_number, '日東電工 株式会社 東北事業所');
ok($zip->set_number('9896892')->is_valid_number, '大崎市 鳴子総合支所');
ok($zip->set_number('9900392')->is_valid_number, '山辺町役場');
ok($zip->set_number('9900492')->is_valid_number, '中山町役場');
ok($zip->set_number('9900493')->is_valid_number, '三和缶詰 株式会社');
ok($zip->set_number('9900792')->is_valid_number, '西川町役場');
ok($zip->set_number('9902196')->is_valid_number, '(株) トプコン山形');
ok($zip->set_number('9902292')->is_valid_number, '山形県立 中央病院');
ok($zip->set_number('9908501')->is_valid_number, '山形商工会議所');
ok($zip->set_number('9908502')->is_valid_number, '株式会社 タルイシ');
ok($zip->set_number('9908506')->is_valid_number, '(株) でん六');
ok($zip->set_number('9908510')->is_valid_number, '公立学校 共済組合 東北中央病院');
ok($zip->set_number('9908511')->is_valid_number, '株式会社 山形テレビ');
ok($zip->set_number('9908512')->is_valid_number, '株式会社 吉田');
ok($zip->set_number('9908519')->is_valid_number, '東日本電信電話 株式会社 山形支店');
ok($zip->set_number('9908521')->is_valid_number, '山形ニコス 株式会社');
ok($zip->set_number('9908522')->is_valid_number, '東京海上日動火災保険 株式会社 山形支店');
ok($zip->set_number('9908525')->is_valid_number, '山形県立 山形東高等学校');
ok($zip->set_number('9908531')->is_valid_number, '山形地方裁判所');
ok($zip->set_number('9908533')->is_valid_number, '山形市立病院済生館');
ok($zip->set_number('9908535')->is_valid_number, '山形農業協同組合');
ok($zip->set_number('9908539')->is_valid_number, '株式会社 さくらんぼテレビジヨン');
ok($zip->set_number('9908540')->is_valid_number, '山形市役所');
ok($zip->set_number('9908545')->is_valid_number, '社会福祉法人 恩賜財団 済生会 山形済生病院');
ok($zip->set_number('9908550')->is_valid_number, '株式会社 山形新聞社');
ok($zip->set_number('9908551')->is_valid_number, '株式会社 中合十字屋 山形店');
ok($zip->set_number('9908555')->is_valid_number, '山形放送 株式会社');
ok($zip->set_number('9908558')->is_valid_number, '遠藤商事 株式会社');
ok($zip->set_number('9908560')->is_valid_number, '山形大学(事務局)(人文学部)(地域教育文化学部)(理学部)(附属図書館)');
ok($zip->set_number('9908566')->is_valid_number, 'ルネサスマイクロシステム 株式会社');
ok($zip->set_number('9908567')->is_valid_number, '山形労働局');
ok($zip->set_number('9908570')->is_valid_number, '山形県庁');
ok($zip->set_number('9908571')->is_valid_number, '株式会社 大沼');
ok($zip->set_number('9908575')->is_valid_number, '日本放送協会 山形放送局');
ok($zip->set_number('9908577')->is_valid_number, '山形県 警察本部');
ok($zip->set_number('9908578')->is_valid_number, '株式会社 きらやかホールディングス');
ok($zip->set_number('9908580')->is_valid_number, '霞城セントラル');
ok($zip->set_number('9908585')->is_valid_number, '(株) ヤマザワ');
ok($zip->set_number('9908587')->is_valid_number, '全国健康保険協会 山形支部');
ok($zip->set_number('9908601')->is_valid_number, '仙台国税局業務センター 山形分室');
ok($zip->set_number('9908606')->is_valid_number, '山形税務署');
ok($zip->set_number('9908611')->is_valid_number, '株式会社 きらやか銀行');
ok($zip->set_number('9908622')->is_valid_number, '全国農業協同組合連合会 山形県本部');
ok($zip->set_number('9908642')->is_valid_number, '株式会社 山形銀行');
ok($zip->set_number('9908668')->is_valid_number, 'オビサン (株)');
ok($zip->set_number('9908670')->is_valid_number, 'ネムール (株)');
ok($zip->set_number('9908677')->is_valid_number, '株式会社 シブヤ');
ok($zip->set_number('9908678')->is_valid_number, '株式会社 ヤマケン');
ok($zip->set_number('9908794')->is_valid_number, '山形店 法人サービス部');
ok($zip->set_number('9909506')->is_valid_number, '山形県立 山形中央高等学校');
ok($zip->set_number('9909530')->is_valid_number, '学校法人 東北芸術工科大学');
ok($zip->set_number('9909536')->is_valid_number, '株式会社 テレビユー山形');
ok($zip->set_number('9909559')->is_valid_number, '山形県 社会保険診療報酬支払基金');
ok($zip->set_number('9909567')->is_valid_number, '山交観光 株式会社');
ok($zip->set_number('9909578')->is_valid_number, 'やまがたシティエフエム 株式会社');
ok($zip->set_number('9909580')->is_valid_number, '国土交通省 山形河川国道事務所');
ok($zip->set_number('9909581')->is_valid_number, '財団法人 山形県結核成人病予防協会');
ok($zip->set_number('9909582')->is_valid_number, '株式会社 ヤガイ');
ok($zip->set_number('9909585')->is_valid_number, '山形大学 医学部');
ok($zip->set_number('9909588')->is_valid_number, '山形トヨペット 株式会社');
ok($zip->set_number('9918501')->is_valid_number, '村山総合支庁 西庁舎');
ok($zip->set_number('9918505')->is_valid_number, '寒河江公共職業安定所');
ok($zip->set_number('9918508')->is_valid_number, '寒河江市立病院');
ok($zip->set_number('9918511')->is_valid_number, '山形県立 寒河江高等学校');
ok($zip->set_number('9918512')->is_valid_number, '山形県立 寒河江工業高等学校');
ok($zip->set_number('9918513')->is_valid_number, '丸菱食品 株式会社');
ok($zip->set_number('9918521')->is_valid_number, '西村山福祉事務所');
ok($zip->set_number('9918555')->is_valid_number, '寒河江市商工会');
ok($zip->set_number('9918585')->is_valid_number, 'さがえ西村山農業協同組合');
ok($zip->set_number('9918601')->is_valid_number, '寒河江市役所');
ok($zip->set_number('9918610')->is_valid_number, '日東ベスト 株式会社');
ok($zip->set_number('9918613')->is_valid_number, '株式会社 高松木材');
ok($zip->set_number('9920392')->is_valid_number, '高畠町役場');
ok($zip->set_number('9920393')->is_valid_number, '山形第一信用組合');
ok($zip->set_number('9920492')->is_valid_number, '石黒製麺 株式会社');
ok($zip->set_number('9920892')->is_valid_number, '白鷹町役場');
ok($zip->set_number('9928501')->is_valid_number, '米沢市役所');
ok($zip->set_number('9928502')->is_valid_number, '米沢市立病院');
ok($zip->set_number('9928510')->is_valid_number, '山形大学 工学部');
ok($zip->set_number('9928520')->is_valid_number, 'NECパーソナルプロダクツ (株) 米沢事業場');
ok($zip->set_number('9928540')->is_valid_number, 'サクサ 株式会社 米沢事業場');
ok($zip->set_number('9928550')->is_valid_number, '株式会社 大沼 米沢店');
ok($zip->set_number('9928601')->is_valid_number, '米沢信用金庫');
ok($zip->set_number('9928610')->is_valid_number, '米沢 税務署');
ok($zip->set_number('9938501')->is_valid_number, '置賜総合支庁 西庁舎');
ok($zip->set_number('9938511')->is_valid_number, 'ケミコン山形 株式会社');
ok($zip->set_number('9938601')->is_valid_number, '長井市役所');
ok($zip->set_number('9938602')->is_valid_number, '公立置賜長井病院');
ok($zip->set_number('9938611')->is_valid_number, '協同薬品工業 株式会社');
ok($zip->set_number('9938642')->is_valid_number, '山形中央信用組合');
ok($zip->set_number('9948501')->is_valid_number, 'エムテックスマツムラ 株式会社');
ok($zip->set_number('9948510')->is_valid_number, '天童市役所');
ok($zip->set_number('9948511')->is_valid_number, '山形中央農業共済組合');
ok($zip->set_number('9948585')->is_valid_number, '東北パイオニア 株式会社');
ok($zip->set_number('9948601')->is_valid_number, '株式会社 天童木工');
ok($zip->set_number('9948611')->is_valid_number, '株式会社 山本製作所');
ok($zip->set_number('9958666')->is_valid_number, '村山市役所');
ok($zip->set_number('9968501')->is_valid_number, '新庄市役所');
ok($zip->set_number('9968585')->is_valid_number, '山形県立 新庄病院');
ok($zip->set_number('9968602')->is_valid_number, '最北精密 株式会社');
ok($zip->set_number('9970192')->is_valid_number, '鶴岡市 羽黒庁舎');
ok($zip->set_number('9970292')->is_valid_number, '出羽三山神社');
ok($zip->set_number('9970296')->is_valid_number, '学校法人 羽黒学園 羽黒高等学校');
ok($zip->set_number('9970492')->is_valid_number, '鶴岡市 朝日庁舎');
ok($zip->set_number('9971392')->is_valid_number, '山形県 庄内総合支庁');
ok($zip->set_number('9978501')->is_valid_number, '鶴岡社会保険事務所');
ok($zip->set_number('9978510')->is_valid_number, '山形県立こころの医療センター');
ok($zip->set_number('9978511')->is_valid_number, '鶴岡工業高等専門学校');
ok($zip->set_number('9978515')->is_valid_number, '鶴岡市立 荘内病院');
ok($zip->set_number('9978522')->is_valid_number, 'ソニーセミコンダクタ 株式会社 山形テクノロジーセンター');
ok($zip->set_number('9978523')->is_valid_number, 'ルネサスセミコンダクタマニュファクチュアリング 株式会社 鶴岡工場');
ok($zip->set_number('9978555')->is_valid_number, '山形大学 農学部');
ok($zip->set_number('9978558')->is_valid_number, '鶴岡市農業協同組合');
ok($zip->set_number('9978567')->is_valid_number, '庄内医療生活協同組合');
ok($zip->set_number('9978585')->is_valid_number, '鶴岡商工会議所');
ok($zip->set_number('9978588')->is_valid_number, '生活協同組合共立社');
ok($zip->set_number('9978601')->is_valid_number, '鶴岡市役所');
ok($zip->set_number('9978611')->is_valid_number, '株式会社 荘内銀行');
ok($zip->set_number('9978655')->is_valid_number, '鶴岡信用金庫');
ok($zip->set_number('9980192')->is_valid_number, '東北日本ハム 株式会社');
ok($zip->set_number('9980194')->is_valid_number, '東北エプソン 株式会社');
ok($zip->set_number('9988501')->is_valid_number, '独立行政法人 山形県・酒田市病院機構 日本海総合病院');
ok($zip->set_number('9988502')->is_valid_number, '酒田商工会議所');
ok($zip->set_number('9988510')->is_valid_number, '庄内みどり農業協同組合');
ok($zip->set_number('9988540')->is_valid_number, '酒田市役所');
ok($zip->set_number('9988550')->is_valid_number, '株式会社 本間ゴルフ 酒田工場');
ok($zip->set_number('9988555')->is_valid_number, '酒田公共職業安定所');
ok($zip->set_number('9988580')->is_valid_number, '東北公益文科大学');
ok($zip->set_number('9988585')->is_valid_number, '日本海総合病院 酒田医療センター');
ok($zip->set_number('9988588')->is_valid_number, 'かんぽの宿 酒田');
ok($zip->set_number('9988611')->is_valid_number, '前田製管 株式会社');
ok($zip->set_number('9988633')->is_valid_number, '酒田税務署');
ok($zip->set_number('9990193')->is_valid_number, '川西町役場');
ok($zip->set_number('9990696')->is_valid_number, '飯豊町役場');
ok($zip->set_number('9991292')->is_valid_number, '学校法人 基督教独立学園');
ok($zip->set_number('9992292')->is_valid_number, '南陽市役所');
ok($zip->set_number('9992293')->is_valid_number, '株式会社 かわでん');
ok($zip->set_number('9993192')->is_valid_number, '上山市役所');
ok($zip->set_number('9993193')->is_valid_number, '山形県立 上山明新館高等学校');
ok($zip->set_number('9993292')->is_valid_number, '株式会社 旅館古窯');
ok($zip->set_number('9993792')->is_valid_number, '北村山公立病院');
ok($zip->set_number('9993795')->is_valid_number, '東根市役所');
ok($zip->set_number('9993796')->is_valid_number, '東根さくらんぼタントクルセンター');
ok($zip->set_number('9993797')->is_valid_number, '陸上自衛隊 神町駐屯地');
ok($zip->set_number('9994292')->is_valid_number, '尾花沢市役所');
ok($zip->set_number('9995292')->is_valid_number, '鮭川村役場');
ok($zip->set_number('9997292')->is_valid_number, '鶴岡市 温海庁舎');
ok($zip->set_number('9997695')->is_valid_number, '株式会社 スタンレー 鶴岡製作所');
ok($zip->set_number('9997696')->is_valid_number, '鶴岡市 藤島庁舎');
ok($zip->set_number('9998292')->is_valid_number, '酒田市役所 八幡総合支所');
ok(!$zip->set_number('0018613')->is_valid_number, 'checking for 0018613');
ok(!$zip->set_number('0028505')->is_valid_number, 'checking for 0028505');
ok(!$zip->set_number('0038703')->is_valid_number, 'checking for 0038703');
ok(!$zip->set_number('0048687')->is_valid_number, 'checking for 0048687');
ok(!$zip->set_number('0058799')->is_valid_number, 'checking for 0058799');
ok(!$zip->set_number('0068613')->is_valid_number, 'checking for 0068613');
ok(!$zip->set_number('0078734')->is_valid_number, 'checking for 0078734');
ok(!$zip->set_number('0108795')->is_valid_number, 'checking for 0108795');
ok(!$zip->set_number('0118687')->is_valid_number, 'checking for 0118687');
ok(!$zip->set_number('0128652')->is_valid_number, 'checking for 0128652');
ok(!$zip->set_number('0138610')->is_valid_number, 'checking for 0138610');
ok(!$zip->set_number('0148612')->is_valid_number, 'checking for 0148612');
ok(!$zip->set_number('0158689')->is_valid_number, 'checking for 0158689');
ok(!$zip->set_number('0168603')->is_valid_number, 'checking for 0168603');
ok(!$zip->set_number('0178687')->is_valid_number, 'checking for 0178687');
ok(!$zip->set_number('0185794')->is_valid_number, 'checking for 0185794');
ok(!$zip->set_number('0192693')->is_valid_number, 'checking for 0192693');
ok(!$zip->set_number('0208795')->is_valid_number, 'checking for 0208795');
ok(!$zip->set_number('0218688')->is_valid_number, 'checking for 0218688');
ok(!$zip->set_number('0228603')->is_valid_number, 'checking for 0228603');
ok(!$zip->set_number('0238502')->is_valid_number, 'checking for 0238502');
ok(!$zip->set_number('0248556')->is_valid_number, 'checking for 0248556');
ok(!$zip->set_number('0258603')->is_valid_number, 'checking for 0258603');
ok(!$zip->set_number('0268687')->is_valid_number, 'checking for 0268687');
ok(!$zip->set_number('0278504')->is_valid_number, 'checking for 0278504');
ok(!$zip->set_number('0288697')->is_valid_number, 'checking for 0288697');
ok(!$zip->set_number('0295693')->is_valid_number, 'checking for 0295693');
ok(!$zip->set_number('0308687')->is_valid_number, 'checking for 0308687');
ok(!$zip->set_number('0318687')->is_valid_number, 'checking for 0318687');
ok(!$zip->set_number('0338689')->is_valid_number, 'checking for 0338689');
ok(!$zip->set_number('0348629')->is_valid_number, 'checking for 0348629');
ok(!$zip->set_number('0358687')->is_valid_number, 'checking for 0358687');
ok(!$zip->set_number('0368789')->is_valid_number, 'checking for 0368789');
ok(!$zip->set_number('0378687')->is_valid_number, 'checking for 0378687');
ok(!$zip->set_number('0388586')->is_valid_number, 'checking for 0388586');
ok(!$zip->set_number('0394693')->is_valid_number, 'checking for 0394693');
ok(!$zip->set_number('0408728')->is_valid_number, 'checking for 0408728');
ok(!$zip->set_number('0418712')->is_valid_number, 'checking for 0418712');
ok(!$zip->set_number('0428679')->is_valid_number, 'checking for 0428679');
ok(!$zip->set_number('0438652')->is_valid_number, 'checking for 0438652');
ok(!$zip->set_number('0448589')->is_valid_number, 'checking for 0448589');
ok(!$zip->set_number('0458610')->is_valid_number, 'checking for 0458610');
ok(!$zip->set_number('0468687')->is_valid_number, 'checking for 0468687');
ok(!$zip->set_number('0478795')->is_valid_number, 'checking for 0478795');
ok(!$zip->set_number('0482494')->is_valid_number, 'checking for 0482494');
ok(!$zip->set_number('0495893')->is_valid_number, 'checking for 0495893');
ok(!$zip->set_number('0508726')->is_valid_number, 'checking for 0508726');
ok(!$zip->set_number('0518589')->is_valid_number, 'checking for 0518589');
ok(!$zip->set_number('0528687')->is_valid_number, 'checking for 0528687');
ok(!$zip->set_number('0538723')->is_valid_number, 'checking for 0538723');
ok(!$zip->set_number('0548661')->is_valid_number, 'checking for 0548661');
ok(!$zip->set_number('0550196')->is_valid_number, 'checking for 0550196');
ok(!$zip->set_number('0568651')->is_valid_number, 'checking for 0568651');
ok(!$zip->set_number('0578559')->is_valid_number, 'checking for 0578559');
ok(!$zip->set_number('0588502')->is_valid_number, 'checking for 0588502');
ok(!$zip->set_number('0598702')->is_valid_number, 'checking for 0598702');
ok(!$zip->set_number('0608798')->is_valid_number, 'checking for 0608798');
ok(!$zip->set_number('0618502')->is_valid_number, 'checking for 0618502');
ok(!$zip->set_number('0628687')->is_valid_number, 'checking for 0628687');
ok(!$zip->set_number('0638646')->is_valid_number, 'checking for 0638646');
ok(!$zip->set_number('0648799')->is_valid_number, 'checking for 0648799');
ok(!$zip->set_number('0658640')->is_valid_number, 'checking for 0658640');
ok(!$zip->set_number('0668788')->is_valid_number, 'checking for 0668788');
ok(!$zip->set_number('0678675')->is_valid_number, 'checking for 0678675');
ok(!$zip->set_number('0688689')->is_valid_number, 'checking for 0688689');
ok(!$zip->set_number('0698586')->is_valid_number, 'checking for 0698586');
ok(!$zip->set_number('0708771')->is_valid_number, 'checking for 0708771');
ok(!$zip->set_number('0711597')->is_valid_number, 'checking for 0711597');
ok(!$zip->set_number('0728661')->is_valid_number, 'checking for 0728661');
ok(!$zip->set_number('0738689')->is_valid_number, 'checking for 0738689');
ok(!$zip->set_number('0748687')->is_valid_number, 'checking for 0748687');
ok(!$zip->set_number('0758712')->is_valid_number, 'checking for 0758712');
ok(!$zip->set_number('0768766')->is_valid_number, 'checking for 0768766');
ok(!$zip->set_number('0778687')->is_valid_number, 'checking for 0778687');
ok(!$zip->set_number('0788556')->is_valid_number, 'checking for 0788556');
ok(!$zip->set_number('0798657')->is_valid_number, 'checking for 0798657');
ok(!$zip->set_number('0808719')->is_valid_number, 'checking for 0808719');
ok(!$zip->set_number('0818502')->is_valid_number, 'checking for 0818502');
ok(!$zip->set_number('0828652')->is_valid_number, 'checking for 0828652');
ok(!$zip->set_number('0838651')->is_valid_number, 'checking for 0838651');
ok(!$zip->set_number('0848687')->is_valid_number, 'checking for 0848687');
ok(!$zip->set_number('0858678')->is_valid_number, 'checking for 0858678');
ok(!$zip->set_number('0861894')->is_valid_number, 'checking for 0861894');
ok(!$zip->set_number('0878712')->is_valid_number, 'checking for 0878712');
ok(!$zip->set_number('0883396')->is_valid_number, 'checking for 0883396');
ok(!$zip->set_number('0895696')->is_valid_number, 'checking for 0895696');
ok(!$zip->set_number('0908730')->is_valid_number, 'checking for 0908730');
ok(!$zip->set_number('0918667')->is_valid_number, 'checking for 0918667');
ok(!$zip->set_number('0928652')->is_valid_number, 'checking for 0928652');
ok(!$zip->set_number('0938729')->is_valid_number, 'checking for 0938729');
ok(!$zip->set_number('0948718')->is_valid_number, 'checking for 0948718');
ok(!$zip->set_number('0958687')->is_valid_number, 'checking for 0958687');
ok(!$zip->set_number('0968687')->is_valid_number, 'checking for 0968687');
ok(!$zip->set_number('0978687')->is_valid_number, 'checking for 0978687');
ok(!$zip->set_number('0986293')->is_valid_number, 'checking for 0986293');
ok(!$zip->set_number('0996593')->is_valid_number, 'checking for 0996593');
ok(!$zip->set_number('1008997')->is_valid_number, 'checking for 1008997');
ok(!$zip->set_number('1018987')->is_valid_number, 'checking for 1018987');
ok(!$zip->set_number('1028799')->is_valid_number, 'checking for 1028799');
ok(!$zip->set_number('1038690')->is_valid_number, 'checking for 1038690');
ok(!$zip->set_number('1048686')->is_valid_number, 'checking for 1048686');
ok(!$zip->set_number('1058789')->is_valid_number, 'checking for 1058789');
ok(!$zip->set_number('1068798')->is_valid_number, 'checking for 1068798');
ok(!$zip->set_number('1078798')->is_valid_number, 'checking for 1078798');
ok(!$zip->set_number('1088714')->is_valid_number, 'checking for 1088714');
ok(!$zip->set_number('1098793')->is_valid_number, 'checking for 1098793');
ok(!$zip->set_number('1108808')->is_valid_number, 'checking for 1108808');
ok(!$zip->set_number('1118799')->is_valid_number, 'checking for 1118799');
ok(!$zip->set_number('1128779')->is_valid_number, 'checking for 1128779');
ok(!$zip->set_number('1138720')->is_valid_number, 'checking for 1138720');
ok(!$zip->set_number('1148687')->is_valid_number, 'checking for 1148687');
ok(!$zip->set_number('1158712')->is_valid_number, 'checking for 1158712');
ok(!$zip->set_number('1168622')->is_valid_number, 'checking for 1168622');
ok(!$zip->set_number('1208603')->is_valid_number, 'checking for 1208603');
ok(!$zip->set_number('1218730')->is_valid_number, 'checking for 1218730');
ok(!$zip->set_number('1238589')->is_valid_number, 'checking for 1238589');
ok(!$zip->set_number('1248589')->is_valid_number, 'checking for 1248589');
ok(!$zip->set_number('1258602')->is_valid_number, 'checking for 1258602');
ok(!$zip->set_number('1308721')->is_valid_number, 'checking for 1308721');
ok(!$zip->set_number('1318712')->is_valid_number, 'checking for 1318712');
ok(!$zip->set_number('1328740')->is_valid_number, 'checking for 1328740');
ok(!$zip->set_number('1338707')->is_valid_number, 'checking for 1338707');
ok(!$zip->set_number('1348703')->is_valid_number, 'checking for 1348703');
ok(!$zip->set_number('1358798')->is_valid_number, 'checking for 1358798');
ok(!$zip->set_number('1368909')->is_valid_number, 'checking for 1368909');
ok(!$zip->set_number('1378687')->is_valid_number, 'checking for 1378687');
ok(!$zip->set_number('1408811')->is_valid_number, 'checking for 1408811');
ok(!$zip->set_number('1418925')->is_valid_number, 'checking for 1418925');
ok(!$zip->set_number('1428778')->is_valid_number, 'checking for 1428778');
ok(!$zip->set_number('1438586')->is_valid_number, 'checking for 1438586');
ok(!$zip->set_number('1448679')->is_valid_number, 'checking for 1448679');
ok(!$zip->set_number('1458567')->is_valid_number, 'checking for 1458567');
ok(!$zip->set_number('1468678')->is_valid_number, 'checking for 1468678');
ok(!$zip->set_number('1508968')->is_valid_number, 'checking for 1508968');
ok(!$zip->set_number('1518678')->is_valid_number, 'checking for 1518678');
ok(!$zip->set_number('1528914')->is_valid_number, 'checking for 1528914');
ok(!$zip->set_number('1538940')->is_valid_number, 'checking for 1538940');
ok(!$zip->set_number('1548733')->is_valid_number, 'checking for 1548733');
ok(!$zip->set_number('1558669')->is_valid_number, 'checking for 1558669');
ok(!$zip->set_number('1568667')->is_valid_number, 'checking for 1568667');
ok(!$zip->set_number('1578578')->is_valid_number, 'checking for 1578578');
ok(!$zip->set_number('1588772')->is_valid_number, 'checking for 1588772');
ok(!$zip->set_number('1608911')->is_valid_number, 'checking for 1608911');
ok(!$zip->set_number('1618711')->is_valid_number, 'checking for 1618711');
ok(!$zip->set_number('1628954')->is_valid_number, 'checking for 1628954');
ok(!$zip->set_number('1638681')->is_valid_number, 'checking for 1638681');
ok(!$zip->set_number('1648726')->is_valid_number, 'checking for 1648726');
ok(!$zip->set_number('1658781')->is_valid_number, 'checking for 1658781');
ok(!$zip->set_number('1668589')->is_valid_number, 'checking for 1668589');
ok(!$zip->set_number('1678629')->is_valid_number, 'checking for 1678629');
ok(!$zip->set_number('1688687')->is_valid_number, 'checking for 1688687');
ok(!$zip->set_number('1698916')->is_valid_number, 'checking for 1698916');
ok(!$zip->set_number('1708687')->is_valid_number, 'checking for 1708687');
ok(!$zip->set_number('1718589')->is_valid_number, 'checking for 1718589');
ok(!$zip->set_number('1738711')->is_valid_number, 'checking for 1738711');
ok(!$zip->set_number('1748904')->is_valid_number, 'checking for 1748904');
ok(!$zip->set_number('1758589')->is_valid_number, 'checking for 1758589');
ok(!$zip->set_number('1768586')->is_valid_number, 'checking for 1768586');
ok(!$zip->set_number('1778522')->is_valid_number, 'checking for 1778522');
ok(!$zip->set_number('1788687')->is_valid_number, 'checking for 1788687');
ok(!$zip->set_number('1798915')->is_valid_number, 'checking for 1798915');
ok(!$zip->set_number('1808778')->is_valid_number, 'checking for 1808778');
ok(!$zip->set_number('1818649')->is_valid_number, 'checking for 1818649');
ok(!$zip->set_number('1828687')->is_valid_number, 'checking for 1828687');
ok(!$zip->set_number('1838708')->is_valid_number, 'checking for 1838708');
ok(!$zip->set_number('1848796')->is_valid_number, 'checking for 1848796');
ok(!$zip->set_number('1858796')->is_valid_number, 'checking for 1858796');
ok(!$zip->set_number('1868799')->is_valid_number, 'checking for 1868799');
ok(!$zip->set_number('1878702')->is_valid_number, 'checking for 1878702');
ok(!$zip->set_number('1888702')->is_valid_number, 'checking for 1888702');
ok(!$zip->set_number('1898586')->is_valid_number, 'checking for 1898586');
ok(!$zip->set_number('1908689')->is_valid_number, 'checking for 1908689');
ok(!$zip->set_number('1918687')->is_valid_number, 'checking for 1918687');
ok(!$zip->set_number('1928703')->is_valid_number, 'checking for 1928703');
ok(!$zip->set_number('1938687')->is_valid_number, 'checking for 1938687');
ok(!$zip->set_number('1948667')->is_valid_number, 'checking for 1948667');
ok(!$zip->set_number('1958586')->is_valid_number, 'checking for 1958586');
ok(!$zip->set_number('1968687')->is_valid_number, 'checking for 1968687');
ok(!$zip->set_number('1978624')->is_valid_number, 'checking for 1978624');
ok(!$zip->set_number('1988761')->is_valid_number, 'checking for 1988761');
ok(!$zip->set_number('2018687')->is_valid_number, 'checking for 2018687');
ok(!$zip->set_number('2028586')->is_valid_number, 'checking for 2028586');
ok(!$zip->set_number('2038740')->is_valid_number, 'checking for 2038740');
ok(!$zip->set_number('2048590')->is_valid_number, 'checking for 2048590');
ok(!$zip->set_number('2058661')->is_valid_number, 'checking for 2058661');
ok(!$zip->set_number('2068687')->is_valid_number, 'checking for 2068687');
ok(!$zip->set_number('2078586')->is_valid_number, 'checking for 2078586');
ok(!$zip->set_number('2088586')->is_valid_number, 'checking for 2088586');
ok(!$zip->set_number('2109651')->is_valid_number, 'checking for 2109651');
ok(!$zip->set_number('2118676')->is_valid_number, 'checking for 2118676');
ok(!$zip->set_number('2128605')->is_valid_number, 'checking for 2128605');
ok(!$zip->set_number('2138590')->is_valid_number, 'checking for 2138590');
ok(!$zip->set_number('2148589')->is_valid_number, 'checking for 2148589');
ok(!$zip->set_number('2158589')->is_valid_number, 'checking for 2158589');
ok(!$zip->set_number('2168632')->is_valid_number, 'checking for 2168632');
ok(!$zip->set_number('2208766')->is_valid_number, 'checking for 2208766');
ok(!$zip->set_number('2218766')->is_valid_number, 'checking for 2218766');
ok(!$zip->set_number('2228653')->is_valid_number, 'checking for 2228653');
ok(!$zip->set_number('2238589')->is_valid_number, 'checking for 2238589');
ok(!$zip->set_number('2248689')->is_valid_number, 'checking for 2248689');
ok(!$zip->set_number('2258586')->is_valid_number, 'checking for 2258586');
ok(!$zip->set_number('2268571')->is_valid_number, 'checking for 2268571');
ok(!$zip->set_number('2278541')->is_valid_number, 'checking for 2278541');
ok(!$zip->set_number('2308766')->is_valid_number, 'checking for 2308766');
ok(!$zip->set_number('2318967')->is_valid_number, 'checking for 2318967');
ok(!$zip->set_number('2328689')->is_valid_number, 'checking for 2328689');
ok(!$zip->set_number('2338557')->is_valid_number, 'checking for 2338557');
ok(!$zip->set_number('2358559')->is_valid_number, 'checking for 2358559');
ok(!$zip->set_number('2368654')->is_valid_number, 'checking for 2368654');
ok(!$zip->set_number('2378556')->is_valid_number, 'checking for 2378556');
ok(!$zip->set_number('2388687')->is_valid_number, 'checking for 2388687');
ok(!$zip->set_number('2398689')->is_valid_number, 'checking for 2398689');
ok(!$zip->set_number('2408613')->is_valid_number, 'checking for 2408613');
ok(!$zip->set_number('2418607')->is_valid_number, 'checking for 2418607');
ok(!$zip->set_number('2428611')->is_valid_number, 'checking for 2428611');
ok(!$zip->set_number('2438690')->is_valid_number, 'checking for 2438690');
ok(!$zip->set_number('2448603')->is_valid_number, 'checking for 2448603');
ok(!$zip->set_number('2458652')->is_valid_number, 'checking for 2458652');
ok(!$zip->set_number('2468557')->is_valid_number, 'checking for 2468557');
ok(!$zip->set_number('2478731')->is_valid_number, 'checking for 2478731');
ok(!$zip->set_number('2488687')->is_valid_number, 'checking for 2488687');
ok(!$zip->set_number('2498687')->is_valid_number, 'checking for 2498687');
ok(!$zip->set_number('2508589')->is_valid_number, 'checking for 2508589');
ok(!$zip->set_number('2518602')->is_valid_number, 'checking for 2518602');
ok(!$zip->set_number('2528586')->is_valid_number, 'checking for 2528586');
ok(!$zip->set_number('2538687')->is_valid_number, 'checking for 2538687');
ok(!$zip->set_number('2548687')->is_valid_number, 'checking for 2548687');
ok(!$zip->set_number('2558556')->is_valid_number, 'checking for 2558556');
ok(!$zip->set_number('2568511')->is_valid_number, 'checking for 2568511');
ok(!$zip->set_number('2578589')->is_valid_number, 'checking for 2578589');
ok(!$zip->set_number('2588586')->is_valid_number, 'checking for 2588586');
ok(!$zip->set_number('2591393')->is_valid_number, 'checking for 2591393');
ok(!$zip->set_number('2608735')->is_valid_number, 'checking for 2608735');
ok(!$zip->set_number('2618734')->is_valid_number, 'checking for 2618734');
ok(!$zip->set_number('2628734')->is_valid_number, 'checking for 2628734');
ok(!$zip->set_number('2638734')->is_valid_number, 'checking for 2638734');
ok(!$zip->set_number('2648734')->is_valid_number, 'checking for 2648734');
ok(!$zip->set_number('2658502')->is_valid_number, 'checking for 2658502');
ok(!$zip->set_number('2668734')->is_valid_number, 'checking for 2668734');
ok(!$zip->set_number('2708556')->is_valid_number, 'checking for 2708556');
ok(!$zip->set_number('2718673')->is_valid_number, 'checking for 2718673');
ok(!$zip->set_number('2728589')->is_valid_number, 'checking for 2728589');
ok(!$zip->set_number('2738734')->is_valid_number, 'checking for 2738734');
ok(!$zip->set_number('2748602')->is_valid_number, 'checking for 2748602');
ok(!$zip->set_number('2758667')->is_valid_number, 'checking for 2758667');
ok(!$zip->set_number('2768581')->is_valid_number, 'checking for 2768581');
ok(!$zip->set_number('2778687')->is_valid_number, 'checking for 2778687');
ok(!$zip->set_number('2788687')->is_valid_number, 'checking for 2788687');
ok(!$zip->set_number('2798687')->is_valid_number, 'checking for 2798687');
ok(!$zip->set_number('2828611')->is_valid_number, 'checking for 2828611');
ok(!$zip->set_number('2838702')->is_valid_number, 'checking for 2838702');
ok(!$zip->set_number('2848556')->is_valid_number, 'checking for 2848556');
ok(!$zip->set_number('2858766')->is_valid_number, 'checking for 2858766');
ok(!$zip->set_number('2868687')->is_valid_number, 'checking for 2868687');
ok(!$zip->set_number('2878602')->is_valid_number, 'checking for 2878602');
ok(!$zip->set_number('2888602')->is_valid_number, 'checking for 2888602');
ok(!$zip->set_number('2892596')->is_valid_number, 'checking for 2892596');
ok(!$zip->set_number('2908611')->is_valid_number, 'checking for 2908611');
ok(!$zip->set_number('2928687')->is_valid_number, 'checking for 2928687');
ok(!$zip->set_number('2938512')->is_valid_number, 'checking for 2938512');
ok(!$zip->set_number('2948702')->is_valid_number, 'checking for 2948702');
ok(!$zip->set_number('2958602')->is_valid_number, 'checking for 2958602');
ok(!$zip->set_number('2968603')->is_valid_number, 'checking for 2968603');
ok(!$zip->set_number('2978667')->is_valid_number, 'checking for 2978667');
ok(!$zip->set_number('2988502')->is_valid_number, 'checking for 2988502');
ok(!$zip->set_number('2995296')->is_valid_number, 'checking for 2995296');
ok(!$zip->set_number('3008687')->is_valid_number, 'checking for 3008687');
ok(!$zip->set_number('3018612')->is_valid_number, 'checking for 3018612');
ok(!$zip->set_number('3028587')->is_valid_number, 'checking for 3028587');
ok(!$zip->set_number('3038504')->is_valid_number, 'checking for 3038504');
ok(!$zip->set_number('3048602')->is_valid_number, 'checking for 3048602');
ok(!$zip->set_number('3058703')->is_valid_number, 'checking for 3058703');
ok(!$zip->set_number('3068687')->is_valid_number, 'checking for 3068687');
ok(!$zip->set_number('3078602')->is_valid_number, 'checking for 3078602');
ok(!$zip->set_number('3088639')->is_valid_number, 'checking for 3088639');
ok(!$zip->set_number('3091798')->is_valid_number, 'checking for 3091798');
ok(!$zip->set_number('3108687')->is_valid_number, 'checking for 3108687');
ok(!$zip->set_number('3114596')->is_valid_number, 'checking for 3114596');
ok(!$zip->set_number('3128512')->is_valid_number, 'checking for 3128512');
ok(!$zip->set_number('3138687')->is_valid_number, 'checking for 3138687');
ok(!$zip->set_number('3148656')->is_valid_number, 'checking for 3148656');
ok(!$zip->set_number('3158641')->is_valid_number, 'checking for 3158641');
ok(!$zip->set_number('3168534')->is_valid_number, 'checking for 3168534');
ok(!$zip->set_number('3178603')->is_valid_number, 'checking for 3178603');
ok(!$zip->set_number('3188512')->is_valid_number, 'checking for 3188512');
ok(!$zip->set_number('3193596')->is_valid_number, 'checking for 3193596');
ok(!$zip->set_number('3208689')->is_valid_number, 'checking for 3208689');
ok(!$zip->set_number('3218586')->is_valid_number, 'checking for 3218586');
ok(!$zip->set_number('3228689')->is_valid_number, 'checking for 3228689');
ok(!$zip->set_number('3238757')->is_valid_number, 'checking for 3238757');
ok(!$zip->set_number('3248766')->is_valid_number, 'checking for 3248766');
ok(!$zip->set_number('3250399')->is_valid_number, 'checking for 3250399');
ok(!$zip->set_number('3268687')->is_valid_number, 'checking for 3268687');
ok(!$zip->set_number('3278679')->is_valid_number, 'checking for 3278679');
ok(!$zip->set_number('3288687')->is_valid_number, 'checking for 3288687');
ok(!$zip->set_number('3294499')->is_valid_number, 'checking for 3294499');
ok(!$zip->set_number('3309851')->is_valid_number, 'checking for 3309851');
ok(!$zip->set_number('3319578')->is_valid_number, 'checking for 3319578');
ok(!$zip->set_number('3328687')->is_valid_number, 'checking for 3328687');
ok(!$zip->set_number('3338612')->is_valid_number, 'checking for 3338612');
ok(!$zip->set_number('3348502')->is_valid_number, 'checking for 3348502');
ok(!$zip->set_number('3358667')->is_valid_number, 'checking for 3358667');
ok(!$zip->set_number('3368761')->is_valid_number, 'checking for 3368761');
ok(!$zip->set_number('3378587')->is_valid_number, 'checking for 3378587');
ok(!$zip->set_number('3388687')->is_valid_number, 'checking for 3388687');
ok(!$zip->set_number('3398687')->is_valid_number, 'checking for 3398687');
ok(!$zip->set_number('3408687')->is_valid_number, 'checking for 3408687');
ok(!$zip->set_number('3418559')->is_valid_number, 'checking for 3418559');
ok(!$zip->set_number('3428602')->is_valid_number, 'checking for 3428602');
ok(!$zip->set_number('3438602')->is_valid_number, 'checking for 3438602');
ok(!$zip->set_number('3448687')->is_valid_number, 'checking for 3448687');
ok(!$zip->set_number('3458509')->is_valid_number, 'checking for 3458509');
ok(!$zip->set_number('3468687')->is_valid_number, 'checking for 3468687');
ok(!$zip->set_number('3478586')->is_valid_number, 'checking for 3478586');
ok(!$zip->set_number('3488602')->is_valid_number, 'checking for 3488602');
ok(!$zip->set_number('3491293')->is_valid_number, 'checking for 3491293');
ok(!$zip->set_number('3508667')->is_valid_number, 'checking for 3508667');
ok(!$zip->set_number('3518602')->is_valid_number, 'checking for 3518602');
ok(!$zip->set_number('3528667')->is_valid_number, 'checking for 3528667');
ok(!$zip->set_number('3538556')->is_valid_number, 'checking for 3538556');
ok(!$zip->set_number('3548586')->is_valid_number, 'checking for 3548586');
ok(!$zip->set_number('3558609')->is_valid_number, 'checking for 3558609');
ok(!$zip->set_number('3568586')->is_valid_number, 'checking for 3568586');
ok(!$zip->set_number('3578589')->is_valid_number, 'checking for 3578589');
ok(!$zip->set_number('3588589')->is_valid_number, 'checking for 3588589');
ok(!$zip->set_number('3598687')->is_valid_number, 'checking for 3598687');
ok(!$zip->set_number('3608621')->is_valid_number, 'checking for 3608621');
ok(!$zip->set_number('3618605')->is_valid_number, 'checking for 3618605');
ok(!$zip->set_number('3628689')->is_valid_number, 'checking for 3628689');
ok(!$zip->set_number('3638602')->is_valid_number, 'checking for 3638602');
ok(!$zip->set_number('3648634')->is_valid_number, 'checking for 3648634');
ok(!$zip->set_number('3658604')->is_valid_number, 'checking for 3658604');
ok(!$zip->set_number('3668582')->is_valid_number, 'checking for 3668582');
ok(!$zip->set_number('3678687')->is_valid_number, 'checking for 3678687');
ok(!$zip->set_number('3688687')->is_valid_number, 'checking for 3688687');
ok(!$zip->set_number('3691999')->is_valid_number, 'checking for 3691999');
ok(!$zip->set_number('3708687')->is_valid_number, 'checking for 3708687');
ok(!$zip->set_number('3718689')->is_valid_number, 'checking for 3718689');
ok(!$zip->set_number('3728687')->is_valid_number, 'checking for 3728687');
ok(!$zip->set_number('3738719')->is_valid_number, 'checking for 3738719');
ok(!$zip->set_number('3748687')->is_valid_number, 'checking for 3748687');
ok(!$zip->set_number('3758605')->is_valid_number, 'checking for 3758605');
ok(!$zip->set_number('3768687')->is_valid_number, 'checking for 3768687');
ok(!$zip->set_number('3778617')->is_valid_number, 'checking for 3778617');
ok(!$zip->set_number('3788502')->is_valid_number, 'checking for 3788502');
ok(!$zip->set_number('3792399')->is_valid_number, 'checking for 3792399');
ok(!$zip->set_number('3808799')->is_valid_number, 'checking for 3808799');
ok(!$zip->set_number('3818794')->is_valid_number, 'checking for 3818794');
ok(!$zip->set_number('3828634')->is_valid_number, 'checking for 3828634');
ok(!$zip->set_number('3838687')->is_valid_number, 'checking for 3838687');
ok(!$zip->set_number('3848606')->is_valid_number, 'checking for 3848606');
ok(!$zip->set_number('3858687')->is_valid_number, 'checking for 3858687');
ok(!$zip->set_number('3868721')->is_valid_number, 'checking for 3868721');
ok(!$zip->set_number('3878604')->is_valid_number, 'checking for 3878604');
ok(!$zip->set_number('3888556')->is_valid_number, 'checking for 3888556');
ok(!$zip->set_number('3892793')->is_valid_number, 'checking for 3892793');
ok(!$zip->set_number('3908766')->is_valid_number, 'checking for 3908766');
ok(!$zip->set_number('3918589')->is_valid_number, 'checking for 3918589');
ok(!$zip->set_number('3928687')->is_valid_number, 'checking for 3928687');
ok(!$zip->set_number('3938602')->is_valid_number, 'checking for 3938602');
ok(!$zip->set_number('3948687')->is_valid_number, 'checking for 3948687');
ok(!$zip->set_number('3958689')->is_valid_number, 'checking for 3958689');
ok(!$zip->set_number('3968683')->is_valid_number, 'checking for 3968683');
ok(!$zip->set_number('3978610')->is_valid_number, 'checking for 3978610');
ok(!$zip->set_number('3988687')->is_valid_number, 'checking for 3988687');
ok(!$zip->set_number('3999495')->is_valid_number, 'checking for 3999495');
ok(!$zip->set_number('4008795')->is_valid_number, 'checking for 4008795');
ok(!$zip->set_number('4018602')->is_valid_number, 'checking for 4018602');
ok(!$zip->set_number('4028581')->is_valid_number, 'checking for 4028581');
ok(!$zip->set_number('4038602')->is_valid_number, 'checking for 4038602');
ok(!$zip->set_number('4048602')->is_valid_number, 'checking for 4048602');
ok(!$zip->set_number('4058586')->is_valid_number, 'checking for 4058586');
ok(!$zip->set_number('4068602')->is_valid_number, 'checking for 4068602');
ok(!$zip->set_number('4078556')->is_valid_number, 'checking for 4078556');
ok(!$zip->set_number('4088586')->is_valid_number, 'checking for 4088586');
ok(!$zip->set_number('4093899')->is_valid_number, 'checking for 4093899');
ok(!$zip->set_number('4108740')->is_valid_number, 'checking for 4108740');
ok(!$zip->set_number('4118788')->is_valid_number, 'checking for 4118788');
ok(!$zip->set_number('4128702')->is_valid_number, 'checking for 4128702');
ok(!$zip->set_number('4138679')->is_valid_number, 'checking for 4138679');
ok(!$zip->set_number('4148556')->is_valid_number, 'checking for 4148556');
ok(!$zip->set_number('4158612')->is_valid_number, 'checking for 4158612');
ok(!$zip->set_number('4168687')->is_valid_number, 'checking for 4168687');
ok(!$zip->set_number('4178687')->is_valid_number, 'checking for 4178687');
ok(!$zip->set_number('4188687')->is_valid_number, 'checking for 4188687');
ok(!$zip->set_number('4190393')->is_valid_number, 'checking for 4190393');
ok(!$zip->set_number('4208762')->is_valid_number, 'checking for 4208762');
ok(!$zip->set_number('4213393')->is_valid_number, 'checking for 4213393');
ok(!$zip->set_number('4228788')->is_valid_number, 'checking for 4228788');
ok(!$zip->set_number('4248783')->is_valid_number, 'checking for 4248783');
ok(!$zip->set_number('4258712')->is_valid_number, 'checking for 4258712');
ok(!$zip->set_number('4268723')->is_valid_number, 'checking for 4268723');
ok(!$zip->set_number('4278687')->is_valid_number, 'checking for 4278687');
ok(!$zip->set_number('4288687')->is_valid_number, 'checking for 4288687');
ok(!$zip->set_number('4308690')->is_valid_number, 'checking for 4308690');
ok(!$zip->set_number('4314196')->is_valid_number, 'checking for 4314196');
ok(!$zip->set_number('4328778')->is_valid_number, 'checking for 4328778');
ok(!$zip->set_number('4338602')->is_valid_number, 'checking for 4338602');
ok(!$zip->set_number('4348602')->is_valid_number, 'checking for 4348602');
ok(!$zip->set_number('4358687')->is_valid_number, 'checking for 4358687');
ok(!$zip->set_number('4368702')->is_valid_number, 'checking for 4368702');
ok(!$zip->set_number('4378687')->is_valid_number, 'checking for 4378687');
ok(!$zip->set_number('4388719')->is_valid_number, 'checking for 4388719');
ok(!$zip->set_number('4398652')->is_valid_number, 'checking for 4398652');
ok(!$zip->set_number('4408605')->is_valid_number, 'checking for 4408605');
ok(!$zip->set_number('4418687')->is_valid_number, 'checking for 4418687');
ok(!$zip->set_number('4428604')->is_valid_number, 'checking for 4428604');
ok(!$zip->set_number('4438612')->is_valid_number, 'checking for 4438612');
ok(!$zip->set_number('4448788')->is_valid_number, 'checking for 4448788');
ok(!$zip->set_number('4458603')->is_valid_number, 'checking for 4458603');
ok(!$zip->set_number('4468687')->is_valid_number, 'checking for 4468687');
ok(!$zip->set_number('4478681')->is_valid_number, 'checking for 4478681');
ok(!$zip->set_number('4488732')->is_valid_number, 'checking for 4488732');
ok(!$zip->set_number('4490294')->is_valid_number, 'checking for 4490294');
ok(!$zip->set_number('4508998')->is_valid_number, 'checking for 4508998');
ok(!$zip->set_number('4518702')->is_valid_number, 'checking for 4518702');
ok(!$zip->set_number('4528603')->is_valid_number, 'checking for 4528603');
ok(!$zip->set_number('4538778')->is_valid_number, 'checking for 4538778');
ok(!$zip->set_number('4548652')->is_valid_number, 'checking for 4548652');
ok(!$zip->set_number('4558778')->is_valid_number, 'checking for 4558778');
ok(!$zip->set_number('4568764')->is_valid_number, 'checking for 4568764');
ok(!$zip->set_number('4578713')->is_valid_number, 'checking for 4578713');
ok(!$zip->set_number('4588586')->is_valid_number, 'checking for 4588586');
ok(!$zip->set_number('4598541')->is_valid_number, 'checking for 4598541');
ok(!$zip->set_number('4608721')->is_valid_number, 'checking for 4608721');
ok(!$zip->set_number('4618799')->is_valid_number, 'checking for 4618799');
ok(!$zip->set_number('4628740')->is_valid_number, 'checking for 4628740');
ok(!$zip->set_number('4638586')->is_valid_number, 'checking for 4638586');
ok(!$zip->set_number('4648711')->is_valid_number, 'checking for 4648711');
ok(!$zip->set_number('4658671')->is_valid_number, 'checking for 4658671');
ok(!$zip->set_number('4668712')->is_valid_number, 'checking for 4668712');
ok(!$zip->set_number('4678687')->is_valid_number, 'checking for 4678687');
ok(!$zip->set_number('4688627')->is_valid_number, 'checking for 4688627');
ok(!$zip->set_number('4698798')->is_valid_number, 'checking for 4698798');
ok(!$zip->set_number('4703496')->is_valid_number, 'checking for 4703496');
ok(!$zip->set_number('4718610')->is_valid_number, 'checking for 4718610');
ok(!$zip->set_number('4728687')->is_valid_number, 'checking for 4728687');
ok(!$zip->set_number('4738512')->is_valid_number, 'checking for 4738512');
ok(!$zip->set_number('4748778')->is_valid_number, 'checking for 4748778');
ok(!$zip->set_number('4758687')->is_valid_number, 'checking for 4758687');
ok(!$zip->set_number('4768687')->is_valid_number, 'checking for 4768687');
ok(!$zip->set_number('4778523')->is_valid_number, 'checking for 4778523');
ok(!$zip->set_number('4788642')->is_valid_number, 'checking for 4788642');
ok(!$zip->set_number('4798788')->is_valid_number, 'checking for 4798788');
ok(!$zip->set_number('4801299')->is_valid_number, 'checking for 4801299');
ok(!$zip->set_number('4818682')->is_valid_number, 'checking for 4818682');
ok(!$zip->set_number('4828687')->is_valid_number, 'checking for 4828687');
ok(!$zip->set_number('4838715')->is_valid_number, 'checking for 4838715');
ok(!$zip->set_number('4848610')->is_valid_number, 'checking for 4848610');
ok(!$zip->set_number('4858751')->is_valid_number, 'checking for 4858751');
ok(!$zip->set_number('4868687')->is_valid_number, 'checking for 4868687');
ok(!$zip->set_number('4878651')->is_valid_number, 'checking for 4878651');
ok(!$zip->set_number('4888689')->is_valid_number, 'checking for 4888689');
ok(!$zip->set_number('4898778')->is_valid_number, 'checking for 4898778');
ok(!$zip->set_number('4901393')->is_valid_number, 'checking for 4901393');
ok(!$zip->set_number('4918689')->is_valid_number, 'checking for 4918689');
ok(!$zip->set_number('4928687')->is_valid_number, 'checking for 4928687');
ok(!$zip->set_number('4948687')->is_valid_number, 'checking for 4948687');
ok(!$zip->set_number('4958602')->is_valid_number, 'checking for 4958602');
ok(!$zip->set_number('4968721')->is_valid_number, 'checking for 4968721');
ok(!$zip->set_number('4978603')->is_valid_number, 'checking for 4978603');
ok(!$zip->set_number('4988506')->is_valid_number, 'checking for 4988506');
ok(!$zip->set_number('5008766')->is_valid_number, 'checking for 5008766');
ok(!$zip->set_number('5016296')->is_valid_number, 'checking for 5016296');
ok(!$zip->set_number('5028793')->is_valid_number, 'checking for 5028793');
ok(!$zip->set_number('5038605')->is_valid_number, 'checking for 5038605');
ok(!$zip->set_number('5048711')->is_valid_number, 'checking for 5048711');
ok(!$zip->set_number('5058607')->is_valid_number, 'checking for 5058607');
ok(!$zip->set_number('5068691')->is_valid_number, 'checking for 5068691');
ok(!$zip->set_number('5078788')->is_valid_number, 'checking for 5078788');
ok(!$zip->set_number('5088687')->is_valid_number, 'checking for 5088687');
ok(!$zip->set_number('5099299')->is_valid_number, 'checking for 5099299');
ok(!$zip->set_number('5108671')->is_valid_number, 'checking for 5108671');
ok(!$zip->set_number('5118799')->is_valid_number, 'checking for 5118799');
ok(!$zip->set_number('5128551')->is_valid_number, 'checking for 5128551');
ok(!$zip->set_number('5138702')->is_valid_number, 'checking for 5138702');
ok(!$zip->set_number('5148687')->is_valid_number, 'checking for 5148687');
ok(!$zip->set_number('5158689')->is_valid_number, 'checking for 5158689');
ok(!$zip->set_number('5168687')->is_valid_number, 'checking for 5168687');
ok(!$zip->set_number('5178518')->is_valid_number, 'checking for 5178518');
ok(!$zip->set_number('5188534')->is_valid_number, 'checking for 5188534');
ok(!$zip->set_number('5195294')->is_valid_number, 'checking for 5195294');
ok(!$zip->set_number('5208667')->is_valid_number, 'checking for 5208667');
ok(!$zip->set_number('5218602')->is_valid_number, 'checking for 5218602');
ok(!$zip->set_number('5228667')->is_valid_number, 'checking for 5228667');
ok(!$zip->set_number('5238652')->is_valid_number, 'checking for 5238652');
ok(!$zip->set_number('5248586')->is_valid_number, 'checking for 5248586');
ok(!$zip->set_number('5258589')->is_valid_number, 'checking for 5258589');
ok(!$zip->set_number('5268687')->is_valid_number, 'checking for 5268687');
ok(!$zip->set_number('5278688')->is_valid_number, 'checking for 5278688');
ok(!$zip->set_number('5288667')->is_valid_number, 'checking for 5288667');
ok(!$zip->set_number('5291893')->is_valid_number, 'checking for 5291893');
ok(!$zip->set_number('5308799')->is_valid_number, 'checking for 5308799');
ok(!$zip->set_number('5318788')->is_valid_number, 'checking for 5318788');
ok(!$zip->set_number('5328681')->is_valid_number, 'checking for 5328681');
ok(!$zip->set_number('5338652')->is_valid_number, 'checking for 5338652');
ok(!$zip->set_number('5348586')->is_valid_number, 'checking for 5348586');
ok(!$zip->set_number('5358586')->is_valid_number, 'checking for 5358586');
ok(!$zip->set_number('5368687')->is_valid_number, 'checking for 5368687');
ok(!$zip->set_number('5378912')->is_valid_number, 'checking for 5378912');
ok(!$zip->set_number('5388687')->is_valid_number, 'checking for 5388687');
ok(!$zip->set_number('5398795')->is_valid_number, 'checking for 5398795');
ok(!$zip->set_number('5408796')->is_valid_number, 'checking for 5408796');
ok(!$zip->set_number('5418766')->is_valid_number, 'checking for 5418766');
ok(!$zip->set_number('5428746')->is_valid_number, 'checking for 5428746');
ok(!$zip->set_number('5438689')->is_valid_number, 'checking for 5438689');
ok(!$zip->set_number('5448687')->is_valid_number, 'checking for 5448687');
ok(!$zip->set_number('5458587')->is_valid_number, 'checking for 5458587');
ok(!$zip->set_number('5468502')->is_valid_number, 'checking for 5468502');
ok(!$zip->set_number('5478581')->is_valid_number, 'checking for 5478581');
ok(!$zip->set_number('5498586')->is_valid_number, 'checking for 5498586');
ok(!$zip->set_number('5508661')->is_valid_number, 'checking for 5508661');
ok(!$zip->set_number('5518552')->is_valid_number, 'checking for 5518552');
ok(!$zip->set_number('5528511')->is_valid_number, 'checking for 5528511');
ok(!$zip->set_number('5538740')->is_valid_number, 'checking for 5538740');
ok(!$zip->set_number('5548589')->is_valid_number, 'checking for 5548589');
ok(!$zip->set_number('5558556')->is_valid_number, 'checking for 5558556');
ok(!$zip->set_number('5568671')->is_valid_number, 'checking for 5568671');
ok(!$zip->set_number('5578502')->is_valid_number, 'checking for 5578502');
ok(!$zip->set_number('5588586')->is_valid_number, 'checking for 5588586');
ok(!$zip->set_number('5598730')->is_valid_number, 'checking for 5598730');
ok(!$zip->set_number('5608581')->is_valid_number, 'checking for 5608581');
ok(!$zip->set_number('5618578')->is_valid_number, 'checking for 5618578');
ok(!$zip->set_number('5628687')->is_valid_number, 'checking for 5628687');
ok(!$zip->set_number('5638589')->is_valid_number, 'checking for 5638589');
ok(!$zip->set_number('5648681')->is_valid_number, 'checking for 5648681');
ok(!$zip->set_number('5658566')->is_valid_number, 'checking for 5658566');
ok(!$zip->set_number('5668687')->is_valid_number, 'checking for 5668687');
ok(!$zip->set_number('5678681')->is_valid_number, 'checking for 5678681');
ok(!$zip->set_number('5698687')->is_valid_number, 'checking for 5698687');
ok(!$zip->set_number('5708788')->is_valid_number, 'checking for 5708788');
ok(!$zip->set_number('5718687')->is_valid_number, 'checking for 5718687');
ok(!$zip->set_number('5728590')->is_valid_number, 'checking for 5728590');
ok(!$zip->set_number('5738667')->is_valid_number, 'checking for 5738667');
ok(!$zip->set_number('5748586')->is_valid_number, 'checking for 5748586');
ok(!$zip->set_number('5758589')->is_valid_number, 'checking for 5758589');
ok(!$zip->set_number('5768502')->is_valid_number, 'checking for 5768502');
ok(!$zip->set_number('5778589')->is_valid_number, 'checking for 5778589');
ok(!$zip->set_number('5788589')->is_valid_number, 'checking for 5788589');
ok(!$zip->set_number('5798503')->is_valid_number, 'checking for 5798503');
ok(!$zip->set_number('5808602')->is_valid_number, 'checking for 5808602');
ok(!$zip->set_number('5818687')->is_valid_number, 'checking for 5818687');
ok(!$zip->set_number('5828586')->is_valid_number, 'checking for 5828586');
ok(!$zip->set_number('5838589')->is_valid_number, 'checking for 5838589');
ok(!$zip->set_number('5848652')->is_valid_number, 'checking for 5848652');
ok(!$zip->set_number('5858586')->is_valid_number, 'checking for 5858586');
ok(!$zip->set_number('5868586')->is_valid_number, 'checking for 5868586');
ok(!$zip->set_number('5878587')->is_valid_number, 'checking for 5878587');
ok(!$zip->set_number('5898586')->is_valid_number, 'checking for 5898586');
ok(!$zip->set_number('5908687')->is_valid_number, 'checking for 5908687');
ok(!$zip->set_number('5918702')->is_valid_number, 'checking for 5918702');
ok(!$zip->set_number('5928586')->is_valid_number, 'checking for 5928586');
ok(!$zip->set_number('5938505')->is_valid_number, 'checking for 5938505');
ok(!$zip->set_number('5948687')->is_valid_number, 'checking for 5948687');
ok(!$zip->set_number('5958687')->is_valid_number, 'checking for 5958687');
ok(!$zip->set_number('5968687')->is_valid_number, 'checking for 5968687');
ok(!$zip->set_number('5978687')->is_valid_number, 'checking for 5978687');
ok(!$zip->set_number('5988567')->is_valid_number, 'checking for 5988567');
ok(!$zip->set_number('5998532')->is_valid_number, 'checking for 5998532');
ok(!$zip->set_number('6008793')->is_valid_number, 'checking for 6008793');
ok(!$zip->set_number('6018602')->is_valid_number, 'checking for 6018602');
ok(!$zip->set_number('6028612')->is_valid_number, 'checking for 6028612');
ok(!$zip->set_number('6038589')->is_valid_number, 'checking for 6038589');
ok(!$zip->set_number('6048667')->is_valid_number, 'checking for 6048667');
ok(!$zip->set_number('6058687')->is_valid_number, 'checking for 6058687');
ok(!$zip->set_number('6068589')->is_valid_number, 'checking for 6068589');
ok(!$zip->set_number('6078572')->is_valid_number, 'checking for 6078572');
ok(!$zip->set_number('6101199')->is_valid_number, 'checking for 6101199');
ok(!$zip->set_number('6118661')->is_valid_number, 'checking for 6118661');
ok(!$zip->set_number('6128687')->is_valid_number, 'checking for 6128687');
ok(!$zip->set_number('6138586')->is_valid_number, 'checking for 6138586');
ok(!$zip->set_number('6148589')->is_valid_number, 'checking for 6148589');
ok(!$zip->set_number('6158687')->is_valid_number, 'checking for 6158687');
ok(!$zip->set_number('6168667')->is_valid_number, 'checking for 6168667');
ok(!$zip->set_number('6178773')->is_valid_number, 'checking for 6178773');
ok(!$zip->set_number('6188586')->is_valid_number, 'checking for 6188586');
ok(!$zip->set_number('6191394')->is_valid_number, 'checking for 6191394');
ok(!$zip->set_number('6208509')->is_valid_number, 'checking for 6208509');
ok(!$zip->set_number('6218687')->is_valid_number, 'checking for 6218687');
ok(!$zip->set_number('6228652')->is_valid_number, 'checking for 6228652');
ok(!$zip->set_number('6238589')->is_valid_number, 'checking for 6238589');
ok(!$zip->set_number('6248687')->is_valid_number, 'checking for 6248687');
ok(!$zip->set_number('6258667')->is_valid_number, 'checking for 6258667');
ok(!$zip->set_number('6268572')->is_valid_number, 'checking for 6268572');
ok(!$zip->set_number('6278689')->is_valid_number, 'checking for 6278689');
ok(!$zip->set_number('6292499')->is_valid_number, 'checking for 6292499');
ok(!$zip->set_number('6308689')->is_valid_number, 'checking for 6308689');
ok(!$zip->set_number('6318586')->is_valid_number, 'checking for 6318586');
ok(!$zip->set_number('6328689')->is_valid_number, 'checking for 6328689');
ok(!$zip->set_number('6338687')->is_valid_number, 'checking for 6338687');
ok(!$zip->set_number('6348587')->is_valid_number, 'checking for 6348587');
ok(!$zip->set_number('6358788')->is_valid_number, 'checking for 6358788');
ok(!$zip->set_number('6368799')->is_valid_number, 'checking for 6368799');
ok(!$zip->set_number('6378512')->is_valid_number, 'checking for 6378512');
ok(!$zip->set_number('6388562')->is_valid_number, 'checking for 6388562');
ok(!$zip->set_number('6393595')->is_valid_number, 'checking for 6393595');
ok(!$zip->set_number('6408788')->is_valid_number, 'checking for 6408788');
ok(!$zip->set_number('6418771')->is_valid_number, 'checking for 6418771');
ok(!$zip->set_number('6428502')->is_valid_number, 'checking for 6428502');
ok(!$zip->set_number('6438502')->is_valid_number, 'checking for 6438502');
ok(!$zip->set_number('6448687')->is_valid_number, 'checking for 6448687');
ok(!$zip->set_number('6458512')->is_valid_number, 'checking for 6458512');
ok(!$zip->set_number('6468661')->is_valid_number, 'checking for 6468661');
ok(!$zip->set_number('6478556')->is_valid_number, 'checking for 6478556');
ok(!$zip->set_number('6488586')->is_valid_number, 'checking for 6488586');
ok(!$zip->set_number('6497196')->is_valid_number, 'checking for 6497196');
ok(!$zip->set_number('6508795')->is_valid_number, 'checking for 6508795');
ok(!$zip->set_number('6518799')->is_valid_number, 'checking for 6518799');
ok(!$zip->set_number('6528586')->is_valid_number, 'checking for 6528586');
ok(!$zip->set_number('6538586')->is_valid_number, 'checking for 6538586');
ok(!$zip->set_number('6548586')->is_valid_number, 'checking for 6548586');
ok(!$zip->set_number('6558571')->is_valid_number, 'checking for 6558571');
ok(!$zip->set_number('6568687')->is_valid_number, 'checking for 6568687');
ok(!$zip->set_number('6578571')->is_valid_number, 'checking for 6578571');
ok(!$zip->set_number('6588571')->is_valid_number, 'checking for 6588571');
ok(!$zip->set_number('6598512')->is_valid_number, 'checking for 6598512');
ok(!$zip->set_number('6608589')->is_valid_number, 'checking for 6608589');
ok(!$zip->set_number('6618662')->is_valid_number, 'checking for 6618662');
ok(!$zip->set_number('6628587')->is_valid_number, 'checking for 6628587');
ok(!$zip->set_number('6638602')->is_valid_number, 'checking for 6638602');
ok(!$zip->set_number('6648651')->is_valid_number, 'checking for 6648651');
ok(!$zip->set_number('6658666')->is_valid_number, 'checking for 6658666');
ok(!$zip->set_number('6668502')->is_valid_number, 'checking for 6668502');
ok(!$zip->set_number('6678652')->is_valid_number, 'checking for 6678652');
ok(!$zip->set_number('6688667')->is_valid_number, 'checking for 6688667');
ok(!$zip->set_number('6696893')->is_valid_number, 'checking for 6696893');
ok(!$zip->set_number('6708690')->is_valid_number, 'checking for 6708690');
ok(!$zip->set_number('6714194')->is_valid_number, 'checking for 6714194');
ok(!$zip->set_number('6728678')->is_valid_number, 'checking for 6728678');
ok(!$zip->set_number('6738689')->is_valid_number, 'checking for 6738689');
ok(!$zip->set_number('6748687')->is_valid_number, 'checking for 6748687');
ok(!$zip->set_number('6758689')->is_valid_number, 'checking for 6758689');
ok(!$zip->set_number('6768689')->is_valid_number, 'checking for 6768689');
ok(!$zip->set_number('6778512')->is_valid_number, 'checking for 6778512');
ok(!$zip->set_number('6788586')->is_valid_number, 'checking for 6788586');
ok(!$zip->set_number('6795596')->is_valid_number, 'checking for 6795596');
ok(!$zip->set_number('6808702')->is_valid_number, 'checking for 6808702');
ok(!$zip->set_number('6818502')->is_valid_number, 'checking for 6818502');
ok(!$zip->set_number('6828634')->is_valid_number, 'checking for 6828634');
ok(!$zip->set_number('6838687')->is_valid_number, 'checking for 6838687');
ok(!$zip->set_number('6848687')->is_valid_number, 'checking for 6848687');
ok(!$zip->set_number('6858667')->is_valid_number, 'checking for 6858667');
ok(!$zip->set_number('6895293')->is_valid_number, 'checking for 6895293');
ok(!$zip->set_number('6908795')->is_valid_number, 'checking for 6908795');
ok(!$zip->set_number('6918603')->is_valid_number, 'checking for 6918603');
ok(!$zip->set_number('6928687')->is_valid_number, 'checking for 6928687');
ok(!$zip->set_number('6938690')->is_valid_number, 'checking for 6938690');
ok(!$zip->set_number('6948503')->is_valid_number, 'checking for 6948503');
ok(!$zip->set_number('6958586')->is_valid_number, 'checking for 6958586');
ok(!$zip->set_number('6968511')->is_valid_number, 'checking for 6968511');
ok(!$zip->set_number('6978790')->is_valid_number, 'checking for 6978790');
ok(!$zip->set_number('6988652')->is_valid_number, 'checking for 6988652');
ok(!$zip->set_number('6995696')->is_valid_number, 'checking for 6995696');
ok(!$zip->set_number('7008795')->is_valid_number, 'checking for 7008795');
ok(!$zip->set_number('7014594')->is_valid_number, 'checking for 7014594');
ok(!$zip->set_number('7028610')->is_valid_number, 'checking for 7028610');
ok(!$zip->set_number('7038751')->is_valid_number, 'checking for 7038751');
ok(!$zip->set_number('7048589')->is_valid_number, 'checking for 7048589');
ok(!$zip->set_number('7058616')->is_valid_number, 'checking for 7058616');
ok(!$zip->set_number('7068656')->is_valid_number, 'checking for 7068656');
ok(!$zip->set_number('7078586')->is_valid_number, 'checking for 7078586');
ok(!$zip->set_number('7088658')->is_valid_number, 'checking for 7088658');
ok(!$zip->set_number('7094393')->is_valid_number, 'checking for 7094393');
ok(!$zip->set_number('7108687')->is_valid_number, 'checking for 7108687');
ok(!$zip->set_number('7118689')->is_valid_number, 'checking for 7118689');
ok(!$zip->set_number('7128687')->is_valid_number, 'checking for 7128687');
ok(!$zip->set_number('7138714')->is_valid_number, 'checking for 7138714');
ok(!$zip->set_number('7148602')->is_valid_number, 'checking for 7148602');
ok(!$zip->set_number('7158604')->is_valid_number, 'checking for 7158604');
ok(!$zip->set_number('7168602')->is_valid_number, 'checking for 7168602');
ok(!$zip->set_number('7178502')->is_valid_number, 'checking for 7178502');
ok(!$zip->set_number('7188586')->is_valid_number, 'checking for 7188586');
ok(!$zip->set_number('7193293')->is_valid_number, 'checking for 7193293');
ok(!$zip->set_number('7208651')->is_valid_number, 'checking for 7208651');
ok(!$zip->set_number('7218689')->is_valid_number, 'checking for 7218689');
ok(!$zip->set_number('7228606')->is_valid_number, 'checking for 7228606');
ok(!$zip->set_number('7238687')->is_valid_number, 'checking for 7238687');
ok(!$zip->set_number('7258687')->is_valid_number, 'checking for 7258687');
ok(!$zip->set_number('7268633')->is_valid_number, 'checking for 7268633');
ok(!$zip->set_number('7278502')->is_valid_number, 'checking for 7278502');
ok(!$zip->set_number('7288512')->is_valid_number, 'checking for 7288512');
ok(!$zip->set_number('7295793')->is_valid_number, 'checking for 7295793');
ok(!$zip->set_number('7308798')->is_valid_number, 'checking for 7308798');
ok(!$zip->set_number('7315199')->is_valid_number, 'checking for 7315199');
ok(!$zip->set_number('7328766')->is_valid_number, 'checking for 7328766');
ok(!$zip->set_number('7338702')->is_valid_number, 'checking for 7338702');
ok(!$zip->set_number('7348799')->is_valid_number, 'checking for 7348799');
ok(!$zip->set_number('7358687')->is_valid_number, 'checking for 7358687');
ok(!$zip->set_number('7368603')->is_valid_number, 'checking for 7368603');
ok(!$zip->set_number('7378687')->is_valid_number, 'checking for 7378687');
ok(!$zip->set_number('7388604')->is_valid_number, 'checking for 7388604');
ok(!$zip->set_number('7398617')->is_valid_number, 'checking for 7398617');
ok(!$zip->set_number('7408687')->is_valid_number, 'checking for 7408687');
ok(!$zip->set_number('7418586')->is_valid_number, 'checking for 7418586');
ok(!$zip->set_number('7428788')->is_valid_number, 'checking for 7428788');
ok(!$zip->set_number('7438578')->is_valid_number, 'checking for 7438578');
ok(!$zip->set_number('7448612')->is_valid_number, 'checking for 7448612');
ok(!$zip->set_number('7458687')->is_valid_number, 'checking for 7458687');
ok(!$zip->set_number('7468667')->is_valid_number, 'checking for 7468667');
ok(!$zip->set_number('7478687')->is_valid_number, 'checking for 7478687');
ok(!$zip->set_number('7490196')->is_valid_number, 'checking for 7490196');
ok(!$zip->set_number('7508611')->is_valid_number, 'checking for 7508611');
ok(!$zip->set_number('7518631')->is_valid_number, 'checking for 7518631');
ok(!$zip->set_number('7528610')->is_valid_number, 'checking for 7528610');
ok(!$zip->set_number('7538655')->is_valid_number, 'checking for 7538655');
ok(!$zip->set_number('7548612')->is_valid_number, 'checking for 7548612');
ok(!$zip->set_number('7558643')->is_valid_number, 'checking for 7558643');
ok(!$zip->set_number('7568603')->is_valid_number, 'checking for 7568603');
ok(!$zip->set_number('7578687')->is_valid_number, 'checking for 7578687');
ok(!$zip->set_number('7588687')->is_valid_number, 'checking for 7588687');
ok(!$zip->set_number('7596596')->is_valid_number, 'checking for 7596596');
ok(!$zip->set_number('7608689')->is_valid_number, 'checking for 7608689');
ok(!$zip->set_number('7618778')->is_valid_number, 'checking for 7618778');
ok(!$zip->set_number('7628603')->is_valid_number, 'checking for 7628603');
ok(!$zip->set_number('7638609')->is_valid_number, 'checking for 7638609');
ok(!$zip->set_number('7648521')->is_valid_number, 'checking for 7648521');
ok(!$zip->set_number('7658509')->is_valid_number, 'checking for 7658509');
ok(!$zip->set_number('7668503')->is_valid_number, 'checking for 7668503');
ok(!$zip->set_number('7678586')->is_valid_number, 'checking for 7678586');
ok(!$zip->set_number('7688603')->is_valid_number, 'checking for 7688603');
ok(!$zip->set_number('7692993')->is_valid_number, 'checking for 7692993');
ok(!$zip->set_number('7708799')->is_valid_number, 'checking for 7708799');
ok(!$zip->set_number('7716496')->is_valid_number, 'checking for 7716496');
ok(!$zip->set_number('7728602')->is_valid_number, 'checking for 7728602');
ok(!$zip->set_number('7738602')->is_valid_number, 'checking for 7738602');
ok(!$zip->set_number('7748602')->is_valid_number, 'checking for 7748602');
ok(!$zip->set_number('7758571')->is_valid_number, 'checking for 7758571');
ok(!$zip->set_number('7768687')->is_valid_number, 'checking for 7768687');
ok(!$zip->set_number('7778578')->is_valid_number, 'checking for 7778578');
ok(!$zip->set_number('7788508')->is_valid_number, 'checking for 7788508');
ok(!$zip->set_number('7795396')->is_valid_number, 'checking for 7795396');
ok(!$zip->set_number('7808788')->is_valid_number, 'checking for 7808788');
ok(!$zip->set_number('7819690')->is_valid_number, 'checking for 7819690');
ok(!$zip->set_number('7828503')->is_valid_number, 'checking for 7828503');
ok(!$zip->set_number('7838586')->is_valid_number, 'checking for 7838586');
ok(!$zip->set_number('7848506')->is_valid_number, 'checking for 7848506');
ok(!$zip->set_number('7858602')->is_valid_number, 'checking for 7858602');
ok(!$zip->set_number('7868502')->is_valid_number, 'checking for 7868502');
ok(!$zip->set_number('7878502')->is_valid_number, 'checking for 7878502');
ok(!$zip->set_number('7888687')->is_valid_number, 'checking for 7888687');
ok(!$zip->set_number('7891993')->is_valid_number, 'checking for 7891993');
ok(!$zip->set_number('7908798')->is_valid_number, 'checking for 7908798');
ok(!$zip->set_number('7918678')->is_valid_number, 'checking for 7918678');
ok(!$zip->set_number('7928687')->is_valid_number, 'checking for 7928687');
ok(!$zip->set_number('7938602')->is_valid_number, 'checking for 7938602');
ok(!$zip->set_number('7948615')->is_valid_number, 'checking for 7948615');
ok(!$zip->set_number('7958604')->is_valid_number, 'checking for 7958604');
ok(!$zip->set_number('7968503')->is_valid_number, 'checking for 7968503');
ok(!$zip->set_number('7978512')->is_valid_number, 'checking for 7978512');
ok(!$zip->set_number('7988615')->is_valid_number, 'checking for 7988615');
ok(!$zip->set_number('7993794')->is_valid_number, 'checking for 7993794');
ok(!$zip->set_number('8008687')->is_valid_number, 'checking for 8008687');
ok(!$zip->set_number('8018602')->is_valid_number, 'checking for 8018602');
ok(!$zip->set_number('8028702')->is_valid_number, 'checking for 8028702');
ok(!$zip->set_number('8038788')->is_valid_number, 'checking for 8038788');
ok(!$zip->set_number('8048602')->is_valid_number, 'checking for 8048602');
ok(!$zip->set_number('8058626')->is_valid_number, 'checking for 8058626');
ok(!$zip->set_number('8068687')->is_valid_number, 'checking for 8068687');
ok(!$zip->set_number('8078589')->is_valid_number, 'checking for 8078589');
ok(!$zip->set_number('8088607')->is_valid_number, 'checking for 8088607');
ok(!$zip->set_number('8098502')->is_valid_number, 'checking for 8098502');
ok(!$zip->set_number('8108799')->is_valid_number, 'checking for 8108799');
ok(!$zip->set_number('8115193')->is_valid_number, 'checking for 8115193');
ok(!$zip->set_number('8129590')->is_valid_number, 'checking for 8129590');
ok(!$zip->set_number('8138682')->is_valid_number, 'checking for 8138682');
ok(!$zip->set_number('8148799')->is_valid_number, 'checking for 8148799');
ok(!$zip->set_number('8158687')->is_valid_number, 'checking for 8158687');
ok(!$zip->set_number('8168667')->is_valid_number, 'checking for 8168667');
ok(!$zip->set_number('8178521')->is_valid_number, 'checking for 8178521');
ok(!$zip->set_number('8188687')->is_valid_number, 'checking for 8188687');
ok(!$zip->set_number('8198612')->is_valid_number, 'checking for 8198612');
ok(!$zip->set_number('8208608')->is_valid_number, 'checking for 8208608');
ok(!$zip->set_number('8218502')->is_valid_number, 'checking for 8218502');
ok(!$zip->set_number('8228667')->is_valid_number, 'checking for 8228667');
ok(!$zip->set_number('8238556')->is_valid_number, 'checking for 8238556');
ok(!$zip->set_number('8248612')->is_valid_number, 'checking for 8248612');
ok(!$zip->set_number('8258602')->is_valid_number, 'checking for 8258602');
ok(!$zip->set_number('8268610')->is_valid_number, 'checking for 8268610');
ok(!$zip->set_number('8278502')->is_valid_number, 'checking for 8278502');
ok(!$zip->set_number('8288502')->is_valid_number, 'checking for 8288502');
ok(!$zip->set_number('8290394')->is_valid_number, 'checking for 8290394');
ok(!$zip->set_number('8308689')->is_valid_number, 'checking for 8308689');
ok(!$zip->set_number('8318687')->is_valid_number, 'checking for 8318687');
ok(!$zip->set_number('8328602')->is_valid_number, 'checking for 8328602');
ok(!$zip->set_number('8338602')->is_valid_number, 'checking for 8338602');
ok(!$zip->set_number('8348586')->is_valid_number, 'checking for 8348586');
ok(!$zip->set_number('8358602')->is_valid_number, 'checking for 8358602');
ok(!$zip->set_number('8368687')->is_valid_number, 'checking for 8368687');
ok(!$zip->set_number('8378502')->is_valid_number, 'checking for 8378502');
ok(!$zip->set_number('8388687')->is_valid_number, 'checking for 8388687');
ok(!$zip->set_number('8398541')->is_valid_number, 'checking for 8398541');
ok(!$zip->set_number('8408690')->is_valid_number, 'checking for 8408690');
ok(!$zip->set_number('8418687')->is_valid_number, 'checking for 8418687');
ok(!$zip->set_number('8428602')->is_valid_number, 'checking for 8428602');
ok(!$zip->set_number('8438687')->is_valid_number, 'checking for 8438687');
ok(!$zip->set_number('8448626')->is_valid_number, 'checking for 8448626');
ok(!$zip->set_number('8458512')->is_valid_number, 'checking for 8458512');
ok(!$zip->set_number('8468502')->is_valid_number, 'checking for 8468502');
ok(!$zip->set_number('8478602')->is_valid_number, 'checking for 8478602');
ok(!$zip->set_number('8488502')->is_valid_number, 'checking for 8488502');
ok(!$zip->set_number('8498589')->is_valid_number, 'checking for 8498589');
ok(!$zip->set_number('8508689')->is_valid_number, 'checking for 8508689');
ok(!$zip->set_number('8513593')->is_valid_number, 'checking for 8513593');
ok(!$zip->set_number('8528795')->is_valid_number, 'checking for 8528795');
ok(!$zip->set_number('8538602')->is_valid_number, 'checking for 8538602');
ok(!$zip->set_number('8548667')->is_valid_number, 'checking for 8548667');
ok(!$zip->set_number('8558687')->is_valid_number, 'checking for 8558687');
ok(!$zip->set_number('8568687')->is_valid_number, 'checking for 8568687');
ok(!$zip->set_number('8578687')->is_valid_number, 'checking for 8578687');
ok(!$zip->set_number('8588590')->is_valid_number, 'checking for 8588590');
ok(!$zip->set_number('8596493')->is_valid_number, 'checking for 8596493');
ok(!$zip->set_number('8608798')->is_valid_number, 'checking for 8608798');
ok(!$zip->set_number('8618539')->is_valid_number, 'checking for 8618539');
ok(!$zip->set_number('8628795')->is_valid_number, 'checking for 8628795');
ok(!$zip->set_number('8638687')->is_valid_number, 'checking for 8638687');
ok(!$zip->set_number('8648687')->is_valid_number, 'checking for 8648687');
ok(!$zip->set_number('8658578')->is_valid_number, 'checking for 8658578');
ok(!$zip->set_number('8668687')->is_valid_number, 'checking for 8668687');
ok(!$zip->set_number('8678586')->is_valid_number, 'checking for 8678586');
ok(!$zip->set_number('8688602')->is_valid_number, 'checking for 8688602');
ok(!$zip->set_number('8695693')->is_valid_number, 'checking for 8695693');
ok(!$zip->set_number('8708689')->is_valid_number, 'checking for 8708689');
ok(!$zip->set_number('8718689')->is_valid_number, 'checking for 8718689');
ok(!$zip->set_number('8720593')->is_valid_number, 'checking for 8720593');
ok(!$zip->set_number('8738502')->is_valid_number, 'checking for 8738502');
ok(!$zip->set_number('8748689')->is_valid_number, 'checking for 8748689');
ok(!$zip->set_number('8758687')->is_valid_number, 'checking for 8758687');
ok(!$zip->set_number('8768667')->is_valid_number, 'checking for 8768667');
ok(!$zip->set_number('8778687')->is_valid_number, 'checking for 8778687');
ok(!$zip->set_number('8788556')->is_valid_number, 'checking for 8788556');
ok(!$zip->set_number('8797199')->is_valid_number, 'checking for 8797199');
ok(!$zip->set_number('8808726')->is_valid_number, 'checking for 8808726');
ok(!$zip->set_number('8818568')->is_valid_number, 'checking for 8818568');
ok(!$zip->set_number('8828689')->is_valid_number, 'checking for 8828689');
ok(!$zip->set_number('8838589')->is_valid_number, 'checking for 8838589');
ok(!$zip->set_number('8848667')->is_valid_number, 'checking for 8848667');
ok(!$zip->set_number('8858637')->is_valid_number, 'checking for 8858637');
ok(!$zip->set_number('8868612')->is_valid_number, 'checking for 8868612');
ok(!$zip->set_number('8878687')->is_valid_number, 'checking for 8878687');
ok(!$zip->set_number('8888556')->is_valid_number, 'checking for 8888556');
ok(!$zip->set_number('8894593')->is_valid_number, 'checking for 8894593');
ok(!$zip->set_number('8908799')->is_valid_number, 'checking for 8908799');
ok(!$zip->set_number('8919297')->is_valid_number, 'checking for 8919297');
ok(!$zip->set_number('8928689')->is_valid_number, 'checking for 8928689');
ok(!$zip->set_number('8938612')->is_valid_number, 'checking for 8938612');
ok(!$zip->set_number('8948689')->is_valid_number, 'checking for 8948689');
ok(!$zip->set_number('8958687')->is_valid_number, 'checking for 8958687');
ok(!$zip->set_number('8968687')->is_valid_number, 'checking for 8968687');
ok(!$zip->set_number('8978502')->is_valid_number, 'checking for 8978502');
ok(!$zip->set_number('8988502')->is_valid_number, 'checking for 8988502');
ok(!$zip->set_number('8998693')->is_valid_number, 'checking for 8998693');
ok(!$zip->set_number('9008798')->is_valid_number, 'checking for 9008798');
ok(!$zip->set_number('9013993')->is_valid_number, 'checking for 9013993');
ok(!$zip->set_number('9028589')->is_valid_number, 'checking for 9028589');
ok(!$zip->set_number('9038604')->is_valid_number, 'checking for 9038604');
ok(!$zip->set_number('9048687')->is_valid_number, 'checking for 9048687');
ok(!$zip->set_number('9058669')->is_valid_number, 'checking for 9058669');
ok(!$zip->set_number('9068602')->is_valid_number, 'checking for 9068602');
ok(!$zip->set_number('9078504')->is_valid_number, 'checking for 9078504');
ok(!$zip->set_number('9108731')->is_valid_number, 'checking for 9108731');
ok(!$zip->set_number('9118602')->is_valid_number, 'checking for 9118602');
ok(!$zip->set_number('9128687')->is_valid_number, 'checking for 9128687');
ok(!$zip->set_number('9138612')->is_valid_number, 'checking for 9138612');
ok(!$zip->set_number('9148689')->is_valid_number, 'checking for 9148689');
ok(!$zip->set_number('9158667')->is_valid_number, 'checking for 9158667');
ok(!$zip->set_number('9168687')->is_valid_number, 'checking for 9168687');
ok(!$zip->set_number('9178687')->is_valid_number, 'checking for 9178687');
ok(!$zip->set_number('9188689')->is_valid_number, 'checking for 9188689');
ok(!$zip->set_number('9192393')->is_valid_number, 'checking for 9192393');
ok(!$zip->set_number('9208798')->is_valid_number, 'checking for 9208798');
ok(!$zip->set_number('9218799')->is_valid_number, 'checking for 9218799');
ok(!$zip->set_number('9228687')->is_valid_number, 'checking for 9228687');
ok(!$zip->set_number('9238689')->is_valid_number, 'checking for 9238689');
ok(!$zip->set_number('9248778')->is_valid_number, 'checking for 9248778');
ok(!$zip->set_number('9258689')->is_valid_number, 'checking for 9258689');
ok(!$zip->set_number('9268687')->is_valid_number, 'checking for 9268687');
ok(!$zip->set_number('9278602')->is_valid_number, 'checking for 9278602');
ok(!$zip->set_number('9288610')->is_valid_number, 'checking for 9288610');
ok(!$zip->set_number('9292393')->is_valid_number, 'checking for 9292393');
ok(!$zip->set_number('9308688')->is_valid_number, 'checking for 9308688');
ok(!$zip->set_number('9318689')->is_valid_number, 'checking for 9318689');
ok(!$zip->set_number('9328612')->is_valid_number, 'checking for 9328612');
ok(!$zip->set_number('9338789')->is_valid_number, 'checking for 9338789');
ok(!$zip->set_number('9348689')->is_valid_number, 'checking for 9348689');
ok(!$zip->set_number('9358687')->is_valid_number, 'checking for 9358687');
ok(!$zip->set_number('9368687')->is_valid_number, 'checking for 9368687');
ok(!$zip->set_number('9378679')->is_valid_number, 'checking for 9378679');
ok(!$zip->set_number('9388614')->is_valid_number, 'checking for 9388614');
ok(!$zip->set_number('9398651')->is_valid_number, 'checking for 9398651');
ok(!$zip->set_number('9408708')->is_valid_number, 'checking for 9408708');
ok(!$zip->set_number('9418687')->is_valid_number, 'checking for 9418687');
ok(!$zip->set_number('9428667')->is_valid_number, 'checking for 9428667');
ok(!$zip->set_number('9438617')->is_valid_number, 'checking for 9438617');
ok(!$zip->set_number('9448687')->is_valid_number, 'checking for 9448687');
ok(!$zip->set_number('9458689')->is_valid_number, 'checking for 9458689');
ok(!$zip->set_number('9468602')->is_valid_number, 'checking for 9468602');
ok(!$zip->set_number('9478766')->is_valid_number, 'checking for 9478766');
ok(!$zip->set_number('9488603')->is_valid_number, 'checking for 9488603');
ok(!$zip->set_number('9498493')->is_valid_number, 'checking for 9498493');
ok(!$zip->set_number('9508802')->is_valid_number, 'checking for 9508802');
ok(!$zip->set_number('9518687')->is_valid_number, 'checking for 9518687');
ok(!$zip->set_number('9528503')->is_valid_number, 'checking for 9528503');
ok(!$zip->set_number('9538667')->is_valid_number, 'checking for 9538667');
ok(!$zip->set_number('9548687')->is_valid_number, 'checking for 9548687');
ok(!$zip->set_number('9558689')->is_valid_number, 'checking for 9558689');
ok(!$zip->set_number('9568636')->is_valid_number, 'checking for 9568636');
ok(!$zip->set_number('9578702')->is_valid_number, 'checking for 9578702');
ok(!$zip->set_number('9588687')->is_valid_number, 'checking for 9588687');
ok(!$zip->set_number('9594498')->is_valid_number, 'checking for 9594498');
ok(!$zip->set_number('9608689')->is_valid_number, 'checking for 9608689');
ok(!$zip->set_number('9618687')->is_valid_number, 'checking for 9618687');
ok(!$zip->set_number('9628602')->is_valid_number, 'checking for 9628602');
ok(!$zip->set_number('9638795')->is_valid_number, 'checking for 9638795');
ok(!$zip->set_number('9648602')->is_valid_number, 'checking for 9648602');
ok(!$zip->set_number('9658679')->is_valid_number, 'checking for 9658679');
ok(!$zip->set_number('9668602')->is_valid_number, 'checking for 9668602');
ok(!$zip->set_number('9678502')->is_valid_number, 'checking for 9678502');
ok(!$zip->set_number('9680499')->is_valid_number, 'checking for 9680499');
ok(!$zip->set_number('9696594')->is_valid_number, 'checking for 9696594');
ok(!$zip->set_number('9708704')->is_valid_number, 'checking for 9708704');
ok(!$zip->set_number('9718556')->is_valid_number, 'checking for 9718556');
ok(!$zip->set_number('9728556')->is_valid_number, 'checking for 9728556');
ok(!$zip->set_number('9738602')->is_valid_number, 'checking for 9738602');
ok(!$zip->set_number('9748687')->is_valid_number, 'checking for 9748687');
ok(!$zip->set_number('9758687')->is_valid_number, 'checking for 9758687');
ok(!$zip->set_number('9768511')->is_valid_number, 'checking for 9768511');
ok(!$zip->set_number('9792793')->is_valid_number, 'checking for 9792793');
ok(!$zip->set_number('9808799')->is_valid_number, 'checking for 9808799');
ok(!$zip->set_number('9818586')->is_valid_number, 'checking for 9818586');
ok(!$zip->set_number('9828799')->is_valid_number, 'checking for 9828799');
ok(!$zip->set_number('9838640')->is_valid_number, 'checking for 9838640');
ok(!$zip->set_number('9848689')->is_valid_number, 'checking for 9848689');
ok(!$zip->set_number('9858656')->is_valid_number, 'checking for 9858656');
ok(!$zip->set_number('9868586')->is_valid_number, 'checking for 9868586');
ok(!$zip->set_number('9878609')->is_valid_number, 'checking for 9878609');
ok(!$zip->set_number('9888556')->is_valid_number, 'checking for 9888556');
ok(!$zip->set_number('9896893')->is_valid_number, 'checking for 9896893');
ok(!$zip->set_number('9909589')->is_valid_number, 'checking for 9909589');
ok(!$zip->set_number('9918614')->is_valid_number, 'checking for 9918614');
ok(!$zip->set_number('9928611')->is_valid_number, 'checking for 9928611');
ok(!$zip->set_number('9938643')->is_valid_number, 'checking for 9938643');
ok(!$zip->set_number('9948612')->is_valid_number, 'checking for 9948612');
ok(!$zip->set_number('9958667')->is_valid_number, 'checking for 9958667');
ok(!$zip->set_number('9968603')->is_valid_number, 'checking for 9968603');
ok(!$zip->set_number('9978656')->is_valid_number, 'checking for 9978656');
ok(!$zip->set_number('9988634')->is_valid_number, 'checking for 9988634');
