use strict;
use Test::More tests => 125577;

use_ok('Number::ZipCode::JP', 'area');

my $zip = Number::ZipCode::JP->new;
ok($zip->set_number('0010000')->is_valid_number, '北海道札幌市北区以下に掲載がない場合');
ok($zip->set_number('0010010')->is_valid_number, '北海道札幌市北区北十条西(1~4丁目)');
ok($zip->set_number('0010011')->is_valid_number, '北海道札幌市北区北十一条西(1~4丁目)');
ok($zip->set_number('0010012')->is_valid_number, '北海道札幌市北区北十二条西(1~4丁目)');
ok($zip->set_number('0010013')->is_valid_number, '北海道札幌市北区北十三条西(1~4丁目)');
ok($zip->set_number('0010014')->is_valid_number, '北海道札幌市北区北十四条西(1~4丁目)');
ok($zip->set_number('0010015')->is_valid_number, '北海道札幌市北区北十五条西(1~5丁目)');
ok($zip->set_number('0010016')->is_valid_number, '北海道札幌市北区北十六条西(1~6丁目)');
ok($zip->set_number('0010017')->is_valid_number, '北海道札幌市北区北十七条西(1~6丁目)');
ok($zip->set_number('0010018')->is_valid_number, '北海道札幌市北区北十八条西(1~7丁目)');
ok($zip->set_number('0010019')->is_valid_number, '北海道札幌市北区北十九条西(2~7丁目)');
ok($zip->set_number('0010020')->is_valid_number, '北海道札幌市北区北二十条西(2~10丁目)');
ok($zip->set_number('0010021')->is_valid_number, '北海道札幌市北区北二十一条西');
ok($zip->set_number('0010022')->is_valid_number, '北海道札幌市北区北二十二条西');
ok($zip->set_number('0010023')->is_valid_number, '北海道札幌市北区北二十三条西');
ok($zip->set_number('0010024')->is_valid_number, '北海道札幌市北区北二十四条西');
ok($zip->set_number('0010025')->is_valid_number, '北海道札幌市北区北二十五条西');
ok($zip->set_number('0010026')->is_valid_number, '北海道札幌市北区北二十六条西');
ok($zip->set_number('0010027')->is_valid_number, '北海道札幌市北区北二十七条西');
ok($zip->set_number('0010028')->is_valid_number, '北海道札幌市北区北二十八条西');
ok($zip->set_number('0010029')->is_valid_number, '北海道札幌市北区北二十九条西');
ok($zip->set_number('0010030')->is_valid_number, '北海道札幌市北区北三十条西');
ok($zip->set_number('0010031')->is_valid_number, '北海道札幌市北区北三十一条西');
ok($zip->set_number('0010032')->is_valid_number, '北海道札幌市北区北三十二条西');
ok($zip->set_number('0010033')->is_valid_number, '北海道札幌市北区北三十三条西');
ok($zip->set_number('0010034')->is_valid_number, '北海道札幌市北区北三十四条西');
ok($zip->set_number('0010035')->is_valid_number, '北海道札幌市北区北三十五条西');
ok($zip->set_number('0010036')->is_valid_number, '北海道札幌市北区北三十六条西');
ok($zip->set_number('0010037')->is_valid_number, '北海道札幌市北区北三十七条西');
ok($zip->set_number('0010038')->is_valid_number, '北海道札幌市北区北三十八条西');
ok($zip->set_number('0010039')->is_valid_number, '北海道札幌市北区北三十九条西');
ok($zip->set_number('0010040')->is_valid_number, '北海道札幌市北区北四十条西');
ok($zip->set_number('0010045')->is_valid_number, '北海道札幌市北区麻生町');
ok($zip->set_number('0010901')->is_valid_number, '北海道札幌市北区新琴似一条');
ok($zip->set_number('0010902')->is_valid_number, '北海道札幌市北区新琴似二条');
ok($zip->set_number('0010903')->is_valid_number, '北海道札幌市北区新琴似三条');
ok($zip->set_number('0010904')->is_valid_number, '北海道札幌市北区新琴似四条');
ok($zip->set_number('0010905')->is_valid_number, '北海道札幌市北区新琴似五条');
ok($zip->set_number('0010906')->is_valid_number, '北海道札幌市北区新琴似六条');
ok($zip->set_number('0010907')->is_valid_number, '北海道札幌市北区新琴似七条');
ok($zip->set_number('0010908')->is_valid_number, '北海道札幌市北区新琴似八条');
ok($zip->set_number('0010909')->is_valid_number, '北海道札幌市北区新琴似九条');
ok($zip->set_number('0010910')->is_valid_number, '北海道札幌市北区新琴似十条');
ok($zip->set_number('0010911')->is_valid_number, '北海道札幌市北区新琴似十一条');
ok($zip->set_number('0010912')->is_valid_number, '北海道札幌市北区新琴似十二条');
ok($zip->set_number('0010915')->is_valid_number, '北海道札幌市北区新琴似町');
ok($zip->set_number('0010921')->is_valid_number, '北海道札幌市北区新川一条');
ok($zip->set_number('0010922')->is_valid_number, '北海道札幌市北区新川二条');
ok($zip->set_number('0010923')->is_valid_number, '北海道札幌市北区新川三条');
ok($zip->set_number('0010924')->is_valid_number, '北海道札幌市北区新川四条');
ok($zip->set_number('0010925')->is_valid_number, '北海道札幌市北区新川五条');
ok($zip->set_number('0010926')->is_valid_number, '北海道札幌市北区新川六条');
ok($zip->set_number('0010927')->is_valid_number, '北海道札幌市北区新川七条');
ok($zip->set_number('0010928')->is_valid_number, '北海道札幌市北区新川八条');
ok($zip->set_number('0010930')->is_valid_number, '北海道札幌市北区新川');
ok($zip->set_number('0010931')->is_valid_number, '北海道札幌市北区新川西一条');
ok($zip->set_number('0010932')->is_valid_number, '北海道札幌市北区新川西二条');
ok($zip->set_number('0010933')->is_valid_number, '北海道札幌市北区新川西三条');
ok($zip->set_number('0010934')->is_valid_number, '北海道札幌市北区新川西四条');
ok($zip->set_number('0010935')->is_valid_number, '北海道札幌市北区新川西五条');
ok($zip->set_number('0020851')->is_valid_number, '北海道札幌市北区屯田一条');
ok($zip->set_number('0020852')->is_valid_number, '北海道札幌市北区屯田二条');
ok($zip->set_number('0020853')->is_valid_number, '北海道札幌市北区屯田三条');
ok($zip->set_number('0020854')->is_valid_number, '北海道札幌市北区屯田四条');
ok($zip->set_number('0020855')->is_valid_number, '北海道札幌市北区屯田五条');
ok($zip->set_number('0020856')->is_valid_number, '北海道札幌市北区屯田六条');
ok($zip->set_number('0020857')->is_valid_number, '北海道札幌市北区屯田七条');
ok($zip->set_number('0020858')->is_valid_number, '北海道札幌市北区屯田八条');
ok($zip->set_number('0020859')->is_valid_number, '北海道札幌市北区屯田九条');
ok($zip->set_number('0020860')->is_valid_number, '北海道札幌市北区屯田十条');
ok($zip->set_number('0020861')->is_valid_number, '北海道札幌市北区屯田十一条');
ok($zip->set_number('0020865')->is_valid_number, '北海道札幌市北区屯田町');
ok($zip->set_number('0028001')->is_valid_number, '北海道札幌市北区太平一条');
ok($zip->set_number('0028002')->is_valid_number, '北海道札幌市北区太平二条');
ok($zip->set_number('0028003')->is_valid_number, '北海道札幌市北区太平三条');
ok($zip->set_number('0028004')->is_valid_number, '北海道札幌市北区太平四条');
ok($zip->set_number('0028005')->is_valid_number, '北海道札幌市北区太平五条');
ok($zip->set_number('0028006')->is_valid_number, '北海道札幌市北区太平六条');
ok($zip->set_number('0028007')->is_valid_number, '北海道札幌市北区太平七条');
ok($zip->set_number('0028008')->is_valid_number, '北海道札幌市北区太平八条');
ok($zip->set_number('0028009')->is_valid_number, '北海道札幌市北区太平九条');
ok($zip->set_number('0028010')->is_valid_number, '北海道札幌市北区太平十条');
ok($zip->set_number('0028011')->is_valid_number, '北海道札幌市北区太平十一条');
ok($zip->set_number('0028012')->is_valid_number, '北海道札幌市北区太平十二条');
ok($zip->set_number('0028021')->is_valid_number, '北海道札幌市北区篠路一条');
ok($zip->set_number('0028022')->is_valid_number, '北海道札幌市北区篠路二条');
ok($zip->set_number('0028023')->is_valid_number, '北海道札幌市北区篠路三条');
ok($zip->set_number('0028024')->is_valid_number, '北海道札幌市北区篠路四条');
ok($zip->set_number('0028025')->is_valid_number, '北海道札幌市北区篠路五条');
ok($zip->set_number('0028026')->is_valid_number, '北海道札幌市北区篠路六条');
ok($zip->set_number('0028027')->is_valid_number, '北海道札幌市北区篠路七条');
ok($zip->set_number('0028028')->is_valid_number, '北海道札幌市北区篠路八条');
ok($zip->set_number('0028029')->is_valid_number, '北海道札幌市北区篠路九条');
ok($zip->set_number('0028030')->is_valid_number, '北海道札幌市北区篠路十条');
ok($zip->set_number('0028031')->is_valid_number, '北海道札幌市北区西茨戸一条');
ok($zip->set_number('0028032')->is_valid_number, '北海道札幌市北区西茨戸二条');
ok($zip->set_number('0028033')->is_valid_number, '北海道札幌市北区西茨戸三条');
ok($zip->set_number('0028034')->is_valid_number, '北海道札幌市北区西茨戸四条');
ok($zip->set_number('0028035')->is_valid_number, '北海道札幌市北区西茨戸五条');
ok($zip->set_number('0028036')->is_valid_number, '北海道札幌市北区西茨戸六条');
ok($zip->set_number('0028037')->is_valid_number, '北海道札幌市北区西茨戸七条');
ok($zip->set_number('0028038')->is_valid_number, '北海道札幌市北区西茨戸');
ok($zip->set_number('0028041')->is_valid_number, '北海道札幌市北区東茨戸一条');
ok($zip->set_number('0028042')->is_valid_number, '北海道札幌市北区東茨戸二条');
ok($zip->set_number('0028043')->is_valid_number, '北海道札幌市北区東茨戸');
ok($zip->set_number('0028044')->is_valid_number, '北海道札幌市北区東茨戸三条');
ok($zip->set_number('0028045')->is_valid_number, '北海道札幌市北区東茨戸四条');
ok($zip->set_number('0028051')->is_valid_number, '北海道札幌市北区篠路町太平');
ok($zip->set_number('0028052')->is_valid_number, '北海道札幌市北区篠路町上篠路');
ok($zip->set_number('0028053')->is_valid_number, '北海道札幌市北区篠路町篠路');
ok($zip->set_number('0028054')->is_valid_number, '北海道札幌市北区篠路町拓北');
ok($zip->set_number('0028055')->is_valid_number, '北海道札幌市北区篠路町福移');
ok($zip->set_number('0028061')->is_valid_number, '北海道札幌市北区拓北一条');
ok($zip->set_number('0028062')->is_valid_number, '北海道札幌市北区拓北二条');
ok($zip->set_number('0028063')->is_valid_number, '北海道札幌市北区拓北三条');
ok($zip->set_number('0028064')->is_valid_number, '北海道札幌市北区拓北四条');
ok($zip->set_number('0028065')->is_valid_number, '北海道札幌市北区拓北五条');
ok($zip->set_number('0028066')->is_valid_number, '北海道札幌市北区拓北六条');
ok($zip->set_number('0028067')->is_valid_number, '北海道札幌市北区拓北七条');
ok($zip->set_number('0028068')->is_valid_number, '北海道札幌市北区拓北八条');
ok($zip->set_number('0028071')->is_valid_number, '北海道札幌市北区あいの里一条');
ok($zip->set_number('0028072')->is_valid_number, '北海道札幌市北区あいの里二条');
ok($zip->set_number('0028073')->is_valid_number, '北海道札幌市北区あいの里三条');
ok($zip->set_number('0028074')->is_valid_number, '北海道札幌市北区あいの里四条');
ok($zip->set_number('0028075')->is_valid_number, '北海道札幌市北区あいの里五条');
ok($zip->set_number('0028081')->is_valid_number, '北海道札幌市北区百合が原');
ok($zip->set_number('0028082')->is_valid_number, '北海道札幌市北区百合が原公園');
ok($zip->set_number('0028089')->is_valid_number, '北海道石狩郡当別町ビトエ(中島)');
ok($zip->set_number('0028091')->is_valid_number, '北海道札幌市北区南あいの里');
ok($zip->set_number('0030000')->is_valid_number, '北海道札幌市白石区以下に掲載がない場合');
ok($zip->set_number('0030001')->is_valid_number, '北海道札幌市白石区東札幌一条');
ok($zip->set_number('0030002')->is_valid_number, '北海道札幌市白石区東札幌二条');
ok($zip->set_number('0030003')->is_valid_number, '北海道札幌市白石区東札幌三条');
ok($zip->set_number('0030004')->is_valid_number, '北海道札幌市白石区東札幌四条');
ok($zip->set_number('0030005')->is_valid_number, '北海道札幌市白石区東札幌五条');
ok($zip->set_number('0030006')->is_valid_number, '北海道札幌市白石区東札幌六条');
ok($zip->set_number('0030011')->is_valid_number, '北海道札幌市白石区中央一条');
ok($zip->set_number('0030012')->is_valid_number, '北海道札幌市白石区中央二条');
ok($zip->set_number('0030013')->is_valid_number, '北海道札幌市白石区中央三条');
ok($zip->set_number('0030021')->is_valid_number, '北海道札幌市白石区栄通');
ok($zip->set_number('0030022')->is_valid_number, '北海道札幌市白石区南郷通(南)');
ok($zip->set_number('0030023')->is_valid_number, '北海道札幌市白石区南郷通(北)');
ok($zip->set_number('0030024')->is_valid_number, '北海道札幌市白石区本郷通(南)');
ok($zip->set_number('0030025')->is_valid_number, '北海道札幌市白石区本郷通(北)');
ok($zip->set_number('0030026')->is_valid_number, '北海道札幌市白石区本通(南)');
ok($zip->set_number('0030027')->is_valid_number, '北海道札幌市白石区本通(北)');
ok($zip->set_number('0030028')->is_valid_number, '北海道札幌市白石区平和通(南)');
ok($zip->set_number('0030029')->is_valid_number, '北海道札幌市白石区平和通(北)');
ok($zip->set_number('0030030')->is_valid_number, '北海道札幌市白石区流通センター');
ok($zip->set_number('0030801')->is_valid_number, '北海道札幌市白石区菊水一条');
ok($zip->set_number('0030802')->is_valid_number, '北海道札幌市白石区菊水二条');
ok($zip->set_number('0030803')->is_valid_number, '北海道札幌市白石区菊水三条');
ok($zip->set_number('0030804')->is_valid_number, '北海道札幌市白石区菊水四条');
ok($zip->set_number('0030805')->is_valid_number, '北海道札幌市白石区菊水五条');
ok($zip->set_number('0030806')->is_valid_number, '北海道札幌市白石区菊水六条');
ok($zip->set_number('0030807')->is_valid_number, '北海道札幌市白石区菊水七条');
ok($zip->set_number('0030808')->is_valid_number, '北海道札幌市白石区菊水八条');
ok($zip->set_number('0030809')->is_valid_number, '北海道札幌市白石区菊水九条');
ok($zip->set_number('0030811')->is_valid_number, '北海道札幌市白石区菊水上町一条');
ok($zip->set_number('0030812')->is_valid_number, '北海道札幌市白石区菊水上町二条');
ok($zip->set_number('0030813')->is_valid_number, '北海道札幌市白石区菊水上町三条');
ok($zip->set_number('0030814')->is_valid_number, '北海道札幌市白石区菊水上町四条');
ok($zip->set_number('0030821')->is_valid_number, '北海道札幌市白石区菊水元町一条');
ok($zip->set_number('0030822')->is_valid_number, '北海道札幌市白石区菊水元町二条');
ok($zip->set_number('0030823')->is_valid_number, '北海道札幌市白石区菊水元町三条');
ok($zip->set_number('0030824')->is_valid_number, '北海道札幌市白石区菊水元町四条');
ok($zip->set_number('0030825')->is_valid_number, '北海道札幌市白石区菊水元町五条');
ok($zip->set_number('0030826')->is_valid_number, '北海道札幌市白石区菊水元町六条');
ok($zip->set_number('0030827')->is_valid_number, '北海道札幌市白石区菊水元町七条');
ok($zip->set_number('0030828')->is_valid_number, '北海道札幌市白石区菊水元町八条');
ok($zip->set_number('0030829')->is_valid_number, '北海道札幌市白石区菊水元町九条');
ok($zip->set_number('0030830')->is_valid_number, '北海道札幌市白石区菊水元町十条');
ok($zip->set_number('0030831')->is_valid_number, '北海道札幌市白石区北郷一条');
ok($zip->set_number('0030832')->is_valid_number, '北海道札幌市白石区北郷二条');
ok($zip->set_number('0030833')->is_valid_number, '北海道札幌市白石区北郷三条');
ok($zip->set_number('0030834')->is_valid_number, '北海道札幌市白石区北郷四条');
ok($zip->set_number('0030835')->is_valid_number, '北海道札幌市白石区北郷五条');
ok($zip->set_number('0030836')->is_valid_number, '北海道札幌市白石区北郷六条');
ok($zip->set_number('0030837')->is_valid_number, '北海道札幌市白石区北郷七条');
ok($zip->set_number('0030838')->is_valid_number, '北海道札幌市白石区北郷八条');
ok($zip->set_number('0030839')->is_valid_number, '北海道札幌市白石区北郷九条');
ok($zip->set_number('0030840')->is_valid_number, '北海道札幌市白石区北郷十条');
ok($zip->set_number('0030849')->is_valid_number, '北海道札幌市白石区北郷');
ok($zip->set_number('0030851')->is_valid_number, '北海道札幌市白石区川北一条');
ok($zip->set_number('0030852')->is_valid_number, '北海道札幌市白石区川北二条');
ok($zip->set_number('0030853')->is_valid_number, '北海道札幌市白石区川北三条');
ok($zip->set_number('0030854')->is_valid_number, '北海道札幌市白石区川北四条');
ok($zip->set_number('0030855')->is_valid_number, '北海道札幌市白石区川北五条');
ok($zip->set_number('0030859')->is_valid_number, '北海道札幌市白石区川北');
ok($zip->set_number('0030861')->is_valid_number, '北海道札幌市白石区川下一条');
ok($zip->set_number('0030862')->is_valid_number, '北海道札幌市白石区川下二条');
ok($zip->set_number('0030863')->is_valid_number, '北海道札幌市白石区川下三条');
ok($zip->set_number('0030864')->is_valid_number, '北海道札幌市白石区川下四条');
ok($zip->set_number('0030865')->is_valid_number, '北海道札幌市白石区川下五条');
ok($zip->set_number('0030869')->is_valid_number, '北海道札幌市白石区川下');
ok($zip->set_number('0030871')->is_valid_number, '北海道札幌市白石区米里一条');
ok($zip->set_number('0030872')->is_valid_number, '北海道札幌市白石区米里二条');
ok($zip->set_number('0030873')->is_valid_number, '北海道札幌市白石区米里三条');
ok($zip->set_number('0030874')->is_valid_number, '北海道札幌市白石区米里四条');
ok($zip->set_number('0030875')->is_valid_number, '北海道札幌市白石区米里五条');
ok($zip->set_number('0030876')->is_valid_number, '北海道札幌市白石区東米里');
ok($zip->set_number('0040000')->is_valid_number, '北海道札幌市厚別区以下に掲載がない場合');
ok($zip->set_number('0040000')->is_valid_number, '北海道札幌市清田区以下に掲載がない場合');
ok($zip->set_number('0040001')->is_valid_number, '北海道札幌市厚別区厚別東一条');
ok($zip->set_number('0040002')->is_valid_number, '北海道札幌市厚別区厚別東二条');
ok($zip->set_number('0040003')->is_valid_number, '北海道札幌市厚別区厚別東三条');
ok($zip->set_number('0040004')->is_valid_number, '北海道札幌市厚別区厚別東四条');
ok($zip->set_number('0040005')->is_valid_number, '北海道札幌市厚別区厚別東五条');
ok($zip->set_number('0040006')->is_valid_number, '北海道札幌市厚別区厚別町小野幌');
ok($zip->set_number('0040007')->is_valid_number, '北海道札幌市厚別区厚別町下野幌');
ok($zip->set_number('0040011')->is_valid_number, '北海道札幌市厚別区もみじ台東');
ok($zip->set_number('0040012')->is_valid_number, '北海道札幌市厚別区もみじ台南');
ok($zip->set_number('0040013')->is_valid_number, '北海道札幌市厚別区もみじ台西');
ok($zip->set_number('0040014')->is_valid_number, '北海道札幌市厚別区もみじ台北');
ok($zip->set_number('0040015')->is_valid_number, '北海道札幌市厚別区下野幌テクノパーク');
ok($zip->set_number('0040021')->is_valid_number, '北海道札幌市厚別区青葉町');
ok($zip->set_number('0040022')->is_valid_number, '北海道札幌市厚別区厚別南');
ok($zip->set_number('0040031')->is_valid_number, '北海道札幌市厚別区上野幌一条');
ok($zip->set_number('0040032')->is_valid_number, '北海道札幌市厚別区上野幌二条');
ok($zip->set_number('0040033')->is_valid_number, '北海道札幌市厚別区上野幌三条');
ok($zip->set_number('0040039')->is_valid_number, '北海道札幌市厚別区厚別町上野幌');
ok($zip->set_number('0040041')->is_valid_number, '北海道札幌市厚別区大谷地東');
ok($zip->set_number('0040042')->is_valid_number, '北海道札幌市厚別区大谷地西');
ok($zip->set_number('0040051')->is_valid_number, '北海道札幌市厚別区厚別中央一条');
ok($zip->set_number('0040052')->is_valid_number, '北海道札幌市厚別区厚別中央二条');
ok($zip->set_number('0040053')->is_valid_number, '北海道札幌市厚別区厚別中央三条');
ok($zip->set_number('0040054')->is_valid_number, '北海道札幌市厚別区厚別中央四条');
ok($zip->set_number('0040055')->is_valid_number, '北海道札幌市厚別区厚別中央五条');
ok($zip->set_number('0040061')->is_valid_number, '北海道札幌市厚別区厚別西一条');
ok($zip->set_number('0040062')->is_valid_number, '北海道札幌市厚別区厚別西二条');
ok($zip->set_number('0040063')->is_valid_number, '北海道札幌市厚別区厚別西三条');
ok($zip->set_number('0040064')->is_valid_number, '北海道札幌市厚別区厚別西四条');
ok($zip->set_number('0040065')->is_valid_number, '北海道札幌市厚別区厚別西五条');
ok($zip->set_number('0040068')->is_valid_number, '北海道札幌市厚別区厚別西');
ok($zip->set_number('0040069')->is_valid_number, '北海道札幌市厚別区厚別町山本');
ok($zip->set_number('0040071')->is_valid_number, '北海道札幌市厚別区厚別北一条');
ok($zip->set_number('0040072')->is_valid_number, '北海道札幌市厚別区厚別北二条');
ok($zip->set_number('0040073')->is_valid_number, '北海道札幌市厚別区厚別北三条');
ok($zip->set_number('0040074')->is_valid_number, '北海道札幌市厚別区厚別北四条');
ok($zip->set_number('0040075')->is_valid_number, '北海道札幌市厚別区厚別北五条');
ok($zip->set_number('0040076')->is_valid_number, '北海道札幌市厚別区厚別北六条');
ok($zip->set_number('0040801')->is_valid_number, '北海道札幌市清田区里塚一条');
ok($zip->set_number('0040802')->is_valid_number, '北海道札幌市清田区里塚二条');
ok($zip->set_number('0040803')->is_valid_number, '北海道札幌市清田区里塚三条');
ok($zip->set_number('0040804')->is_valid_number, '北海道札幌市清田区里塚四条');
ok($zip->set_number('0040805')->is_valid_number, '北海道札幌市清田区里塚緑ケ丘');
ok($zip->set_number('0040809')->is_valid_number, '北海道札幌市清田区里塚');
ok($zip->set_number('0040811')->is_valid_number, '北海道札幌市清田区美しが丘一条');
ok($zip->set_number('0040812')->is_valid_number, '北海道札幌市清田区美しが丘二条');
ok($zip->set_number('0040813')->is_valid_number, '北海道札幌市清田区美しが丘三条');
ok($zip->set_number('0040814')->is_valid_number, '北海道札幌市清田区美しが丘四条');
ok($zip->set_number('0040815')->is_valid_number, '北海道札幌市清田区美しが丘五条');
ok($zip->set_number('0040821')->is_valid_number, '北海道札幌市清田区有明');
ok($zip->set_number('0040831')->is_valid_number, '北海道札幌市清田区真栄一条');
ok($zip->set_number('0040832')->is_valid_number, '北海道札幌市清田区真栄二条');
ok($zip->set_number('0040833')->is_valid_number, '北海道札幌市清田区真栄三条');
ok($zip->set_number('0040834')->is_valid_number, '北海道札幌市清田区真栄四条');
ok($zip->set_number('0040835')->is_valid_number, '北海道札幌市清田区真栄五条');
ok($zip->set_number('0040836')->is_valid_number, '北海道札幌市清田区真栄六条');
ok($zip->set_number('0040839')->is_valid_number, '北海道札幌市清田区真栄');
ok($zip->set_number('0040840')->is_valid_number, '北海道札幌市清田区清田十条');
ok($zip->set_number('0040841')->is_valid_number, '北海道札幌市清田区清田一条');
ok($zip->set_number('0040842')->is_valid_number, '北海道札幌市清田区清田二条');
ok($zip->set_number('0040843')->is_valid_number, '北海道札幌市清田区清田三条');
ok($zip->set_number('0040844')->is_valid_number, '北海道札幌市清田区清田四条');
ok($zip->set_number('0040845')->is_valid_number, '北海道札幌市清田区清田五条');
ok($zip->set_number('0040846')->is_valid_number, '北海道札幌市清田区清田六条');
ok($zip->set_number('0040847')->is_valid_number, '北海道札幌市清田区清田七条');
ok($zip->set_number('0040848')->is_valid_number, '北海道札幌市清田区清田八条');
ok($zip->set_number('0040849')->is_valid_number, '北海道札幌市清田区清田九条');
ok($zip->set_number('0040859')->is_valid_number, '北海道札幌市清田区清田');
ok($zip->set_number('0040861')->is_valid_number, '北海道札幌市清田区北野一条');
ok($zip->set_number('0040862')->is_valid_number, '北海道札幌市清田区北野二条');
ok($zip->set_number('0040863')->is_valid_number, '北海道札幌市清田区北野三条');
ok($zip->set_number('0040864')->is_valid_number, '北海道札幌市清田区北野四条');
ok($zip->set_number('0040865')->is_valid_number, '北海道札幌市清田区北野五条');
ok($zip->set_number('0040866')->is_valid_number, '北海道札幌市清田区北野六条');
ok($zip->set_number('0040867')->is_valid_number, '北海道札幌市清田区北野七条');
ok($zip->set_number('0040871')->is_valid_number, '北海道札幌市清田区平岡一条');
ok($zip->set_number('0040872')->is_valid_number, '北海道札幌市清田区平岡二条');
ok($zip->set_number('0040873')->is_valid_number, '北海道札幌市清田区平岡三条');
ok($zip->set_number('0040874')->is_valid_number, '北海道札幌市清田区平岡四条');
ok($zip->set_number('0040875')->is_valid_number, '北海道札幌市清田区平岡五条');
ok($zip->set_number('0040876')->is_valid_number, '北海道札幌市清田区平岡六条');
ok($zip->set_number('0040877')->is_valid_number, '北海道札幌市清田区平岡七条');
ok($zip->set_number('0040878')->is_valid_number, '北海道札幌市清田区平岡八条');
ok($zip->set_number('0040879')->is_valid_number, '北海道札幌市清田区平岡九条');
ok($zip->set_number('0040880')->is_valid_number, '北海道札幌市清田区平岡十条');
ok($zip->set_number('0040881')->is_valid_number, '北海道札幌市清田区平岡公園');
ok($zip->set_number('0040882')->is_valid_number, '北海道札幌市清田区平岡公園東');
ok($zip->set_number('0040889')->is_valid_number, '北海道札幌市清田区平岡');
ok($zip->set_number('0050000')->is_valid_number, '北海道札幌市南区以下に掲載がない場合');
ok($zip->set_number('0050001')->is_valid_number, '北海道札幌市南区澄川一条');
ok($zip->set_number('0050002')->is_valid_number, '北海道札幌市南区澄川二条');
ok($zip->set_number('0050003')->is_valid_number, '北海道札幌市南区澄川三条');
ok($zip->set_number('0050004')->is_valid_number, '北海道札幌市南区澄川四条');
ok($zip->set_number('0050005')->is_valid_number, '北海道札幌市南区澄川五条');
ok($zip->set_number('0050006')->is_valid_number, '北海道札幌市南区澄川六条');
ok($zip->set_number('0050007')->is_valid_number, '北海道札幌市南区澄川');
ok($zip->set_number('0050008')->is_valid_number, '北海道札幌市南区真駒内(17番地)');
ok($zip->set_number('0050011')->is_valid_number, '北海道札幌市南区真駒内東町');
ok($zip->set_number('0050012')->is_valid_number, '北海道札幌市南区真駒内上町');
ok($zip->set_number('0050013')->is_valid_number, '北海道札幌市南区真駒内緑町');
ok($zip->set_number('0050014')->is_valid_number, '北海道札幌市南区真駒内幸町');
ok($zip->set_number('0050015')->is_valid_number, '北海道札幌市南区真駒内泉町');
ok($zip->set_number('0050016')->is_valid_number, '北海道札幌市南区真駒内南町');
ok($zip->set_number('0050017')->is_valid_number, '北海道札幌市南区真駒内公園');
ok($zip->set_number('0050018')->is_valid_number, '北海道札幌市南区真駒内曙町');
ok($zip->set_number('0050021')->is_valid_number, '北海道札幌市南区真駒内本町');
ok($zip->set_number('0050022')->is_valid_number, '北海道札幌市南区真駒内柏丘');
ok($zip->set_number('0050030')->is_valid_number, '北海道札幌市南区南三十条西(8丁目)');
ok($zip->set_number('0050031')->is_valid_number, '北海道札幌市南区南三十一条西');
ok($zip->set_number('0050032')->is_valid_number, '北海道札幌市南区南三十二条西');
ok($zip->set_number('0050033')->is_valid_number, '北海道札幌市南区南三十三条西');
ok($zip->set_number('0050034')->is_valid_number, '北海道札幌市南区南三十四条西');
ok($zip->set_number('0050035')->is_valid_number, '北海道札幌市南区南三十五条西');
ok($zip->set_number('0050036')->is_valid_number, '北海道札幌市南区南三十六条西');
ok($zip->set_number('0050037')->is_valid_number, '北海道札幌市南区南三十七条西');
ok($zip->set_number('0050038')->is_valid_number, '北海道札幌市南区南三十八条西');
ok($zip->set_number('0050039')->is_valid_number, '北海道札幌市南区南三十九条西');
ok($zip->set_number('0050040')->is_valid_number, '北海道札幌市南区藻岩下');
ok($zip->set_number('0050041')->is_valid_number, '北海道札幌市南区藻岩山');
ok($zip->set_number('0050801')->is_valid_number, '北海道札幌市南区川沿一条');
ok($zip->set_number('0050802')->is_valid_number, '北海道札幌市南区川沿二条');
ok($zip->set_number('0050803')->is_valid_number, '北海道札幌市南区川沿三条');
ok($zip->set_number('0050804')->is_valid_number, '北海道札幌市南区川沿四条');
ok($zip->set_number('0050805')->is_valid_number, '北海道札幌市南区川沿五条');
ok($zip->set_number('0050806')->is_valid_number, '北海道札幌市南区川沿六条');
ok($zip->set_number('0050807')->is_valid_number, '北海道札幌市南区川沿七条');
ok($zip->set_number('0050808')->is_valid_number, '北海道札幌市南区川沿八条');
ok($zip->set_number('0050809')->is_valid_number, '北海道札幌市南区川沿九条');
ok($zip->set_number('0050810')->is_valid_number, '北海道札幌市南区川沿十条');
ok($zip->set_number('0050811')->is_valid_number, '北海道札幌市南区川沿十一条');
ok($zip->set_number('0050812')->is_valid_number, '北海道札幌市南区川沿十二条');
ok($zip->set_number('0050813')->is_valid_number, '北海道札幌市南区川沿十三条');
ok($zip->set_number('0050814')->is_valid_number, '北海道札幌市南区川沿十四条');
ok($zip->set_number('0050815')->is_valid_number, '北海道札幌市南区川沿十五条');
ok($zip->set_number('0050816')->is_valid_number, '北海道札幌市南区川沿十六条');
ok($zip->set_number('0050817')->is_valid_number, '北海道札幌市南区川沿十七条');
ok($zip->set_number('0050818')->is_valid_number, '北海道札幌市南区川沿十八条');
ok($zip->set_number('0050821')->is_valid_number, '北海道札幌市南区南沢一条');
ok($zip->set_number('0050822')->is_valid_number, '北海道札幌市南区南沢二条');
ok($zip->set_number('0050823')->is_valid_number, '北海道札幌市南区南沢三条');
ok($zip->set_number('0050824')->is_valid_number, '北海道札幌市南区南沢四条');
ok($zip->set_number('0050825')->is_valid_number, '北海道札幌市南区南沢五条');
ok($zip->set_number('0050826')->is_valid_number, '北海道札幌市南区南沢六条');
ok($zip->set_number('0050827')->is_valid_number, '北海道札幌市南区南沢');
ok($zip->set_number('0050830')->is_valid_number, '北海道札幌市南区砥石山');
ok($zip->set_number('0050831')->is_valid_number, '北海道札幌市南区中ノ沢');
ok($zip->set_number('0050832')->is_valid_number, '北海道札幌市南区北ノ沢');
ok($zip->set_number('0050840')->is_valid_number, '北海道札幌市南区藤野(400、400-2番地)');
ok($zip->set_number('0050841')->is_valid_number, '北海道札幌市南区石山一条');
ok($zip->set_number('0050842')->is_valid_number, '北海道札幌市南区石山二条');
ok($zip->set_number('0050843')->is_valid_number, '北海道札幌市南区石山三条');
ok($zip->set_number('0050844')->is_valid_number, '北海道札幌市南区石山四条');
ok($zip->set_number('0050849')->is_valid_number, '北海道札幌市南区石山');
ok($zip->set_number('0050850')->is_valid_number, '北海道札幌市南区石山東');
ok($zip->set_number('0050851')->is_valid_number, '北海道札幌市南区常盤一条');
ok($zip->set_number('0050852')->is_valid_number, '北海道札幌市南区常盤二条');
ok($zip->set_number('0050853')->is_valid_number, '北海道札幌市南区常盤三条');
ok($zip->set_number('0050854')->is_valid_number, '北海道札幌市南区常盤四条');
ok($zip->set_number('0050855')->is_valid_number, '北海道札幌市南区常盤五条');
ok($zip->set_number('0050856')->is_valid_number, '北海道札幌市南区常盤六条');
ok($zip->set_number('0050861')->is_valid_number, '北海道札幌市南区真駒内(その他)');
ok($zip->set_number('0050862')->is_valid_number, '北海道札幌市南区滝野');
ok($zip->set_number('0050863')->is_valid_number, '北海道札幌市南区常盤(その他)');
ok($zip->set_number('0050864')->is_valid_number, '北海道札幌市南区芸術の森');
ok($zip->set_number('0050865')->is_valid_number, '北海道札幌市南区常盤(1~131番地)');
ok($zip->set_number('0060000')->is_valid_number, '北海道札幌市手稲区以下に掲載がない場合');
ok($zip->set_number('0060001')->is_valid_number, '北海道札幌市手稲区西宮の沢一条');
ok($zip->set_number('0060002')->is_valid_number, '北海道札幌市手稲区西宮の沢二条');
ok($zip->set_number('0060003')->is_valid_number, '北海道札幌市手稲区西宮の沢三条');
ok($zip->set_number('0060004')->is_valid_number, '北海道札幌市手稲区西宮の沢四条');
ok($zip->set_number('0060005')->is_valid_number, '北海道札幌市手稲区西宮の沢五条');
ok($zip->set_number('0060006')->is_valid_number, '北海道札幌市手稲区西宮の沢六条');
ok($zip->set_number('0060009')->is_valid_number, '北海道札幌市手稲区西宮の沢');
ok($zip->set_number('0060011')->is_valid_number, '北海道札幌市手稲区富丘一条');
ok($zip->set_number('0060012')->is_valid_number, '北海道札幌市手稲区富丘二条');
ok($zip->set_number('0060013')->is_valid_number, '北海道札幌市手稲区富丘三条');
ok($zip->set_number('0060014')->is_valid_number, '北海道札幌市手稲区富丘四条');
ok($zip->set_number('0060015')->is_valid_number, '北海道札幌市手稲区富丘五条');
ok($zip->set_number('0060016')->is_valid_number, '北海道札幌市手稲区富丘六条');
ok($zip->set_number('0060019')->is_valid_number, '北海道札幌市手稲区手稲富丘');
ok($zip->set_number('0060021')->is_valid_number, '北海道札幌市手稲区手稲本町一条');
ok($zip->set_number('0060022')->is_valid_number, '北海道札幌市手稲区手稲本町二条');
ok($zip->set_number('0060023')->is_valid_number, '北海道札幌市手稲区手稲本町三条');
ok($zip->set_number('0060024')->is_valid_number, '北海道札幌市手稲区手稲本町四条');
ok($zip->set_number('0060025')->is_valid_number, '北海道札幌市手稲区手稲本町五条');
ok($zip->set_number('0060026')->is_valid_number, '北海道札幌市手稲区手稲本町六条');
ok($zip->set_number('0060029')->is_valid_number, '北海道札幌市手稲区手稲本町');
ok($zip->set_number('0060031')->is_valid_number, '北海道札幌市手稲区稲穂一条');
ok($zip->set_number('0060032')->is_valid_number, '北海道札幌市手稲区稲穂二条');
ok($zip->set_number('0060033')->is_valid_number, '北海道札幌市手稲区稲穂三条');
ok($zip->set_number('0060034')->is_valid_number, '北海道札幌市手稲区稲穂四条');
ok($zip->set_number('0060035')->is_valid_number, '北海道札幌市手稲区稲穂五条');
ok($zip->set_number('0060039')->is_valid_number, '北海道札幌市手稲区手稲稲穂');
ok($zip->set_number('0060041')->is_valid_number, '北海道札幌市手稲区金山一条');
ok($zip->set_number('0060042')->is_valid_number, '北海道札幌市手稲区金山二条');
ok($zip->set_number('0060043')->is_valid_number, '北海道札幌市手稲区金山三条');
ok($zip->set_number('0060049')->is_valid_number, '北海道札幌市手稲区手稲金山');
ok($zip->set_number('0060050')->is_valid_number, '北海道札幌市手稲区星置南');
ok($zip->set_number('0060801')->is_valid_number, '北海道札幌市手稲区新発寒一条');
ok($zip->set_number('0060802')->is_valid_number, '北海道札幌市手稲区新発寒二条');
ok($zip->set_number('0060803')->is_valid_number, '北海道札幌市手稲区新発寒三条');
ok($zip->set_number('0060804')->is_valid_number, '北海道札幌市手稲区新発寒四条');
ok($zip->set_number('0060805')->is_valid_number, '北海道札幌市手稲区新発寒五条');
ok($zip->set_number('0060806')->is_valid_number, '北海道札幌市手稲区新発寒六条');
ok($zip->set_number('0060807')->is_valid_number, '北海道札幌市手稲区新発寒七条');
ok($zip->set_number('0060811')->is_valid_number, '北海道札幌市手稲区前田一条');
ok($zip->set_number('0060812')->is_valid_number, '北海道札幌市手稲区前田二条');
ok($zip->set_number('0060813')->is_valid_number, '北海道札幌市手稲区前田三条');
ok($zip->set_number('0060814')->is_valid_number, '北海道札幌市手稲区前田四条');
ok($zip->set_number('0060815')->is_valid_number, '北海道札幌市手稲区前田五条');
ok($zip->set_number('0060816')->is_valid_number, '北海道札幌市手稲区前田六条');
ok($zip->set_number('0060817')->is_valid_number, '北海道札幌市手稲区前田七条');
ok($zip->set_number('0060818')->is_valid_number, '北海道札幌市手稲区前田八条');
ok($zip->set_number('0060819')->is_valid_number, '北海道札幌市手稲区前田九条');
ok($zip->set_number('0060820')->is_valid_number, '北海道札幌市手稲区前田十条');
ok($zip->set_number('0060821')->is_valid_number, '北海道札幌市手稲区前田十一条');
ok($zip->set_number('0060822')->is_valid_number, '北海道札幌市手稲区前田十二条');
ok($zip->set_number('0060823')->is_valid_number, '北海道札幌市手稲区前田十三条');
ok($zip->set_number('0060829')->is_valid_number, '北海道札幌市手稲区手稲前田');
ok($zip->set_number('0060831')->is_valid_number, '北海道札幌市手稲区曙一条');
ok($zip->set_number('0060832')->is_valid_number, '北海道札幌市手稲区曙二条');
ok($zip->set_number('0060833')->is_valid_number, '北海道札幌市手稲区曙三条');
ok($zip->set_number('0060834')->is_valid_number, '北海道札幌市手稲区曙四条');
ok($zip->set_number('0060835')->is_valid_number, '北海道札幌市手稲区曙五条');
ok($zip->set_number('0060836')->is_valid_number, '北海道札幌市手稲区曙六条');
ok($zip->set_number('0060837')->is_valid_number, '北海道札幌市手稲区曙七条');
ok($zip->set_number('0060838')->is_valid_number, '北海道札幌市手稲区曙八条');
ok($zip->set_number('0060839')->is_valid_number, '北海道札幌市手稲区曙九条');
ok($zip->set_number('0060840')->is_valid_number, '北海道札幌市手稲区曙十条');
ok($zip->set_number('0060841')->is_valid_number, '北海道札幌市手稲区曙十一条');
ok($zip->set_number('0060842')->is_valid_number, '北海道札幌市手稲区曙十二条');
ok($zip->set_number('0060851')->is_valid_number, '北海道札幌市手稲区星置一条');
ok($zip->set_number('0060852')->is_valid_number, '北海道札幌市手稲区星置二条');
ok($zip->set_number('0060853')->is_valid_number, '北海道札幌市手稲区星置三条');
ok($zip->set_number('0060859')->is_valid_number, '北海道札幌市手稲区手稲星置');
ok($zip->set_number('0060860')->is_valid_number, '北海道札幌市手稲区手稲山口');
ok($zip->set_number('0060861')->is_valid_number, '北海道札幌市手稲区明日風');
ok($zip->set_number('0070001')->is_valid_number, '北海道札幌市東区中沼一条');
ok($zip->set_number('0070002')->is_valid_number, '北海道札幌市東区中沼二条');
ok($zip->set_number('0070003')->is_valid_number, '北海道札幌市東区中沼三条');
ok($zip->set_number('0070004')->is_valid_number, '北海道札幌市東区中沼四条');
ok($zip->set_number('0070005')->is_valid_number, '北海道札幌市東区中沼五条');
ok($zip->set_number('0070006')->is_valid_number, '北海道札幌市東区中沼六条');
ok($zip->set_number('0070011')->is_valid_number, '北海道札幌市東区モエレ沼公園');
ok($zip->set_number('0070030')->is_valid_number, '北海道札幌市東区東雁来十条');
ok($zip->set_number('0070031')->is_valid_number, '北海道札幌市東区東雁来十一条');
ok($zip->set_number('0070032')->is_valid_number, '北海道札幌市東区東雁来十二条');
ok($zip->set_number('0070033')->is_valid_number, '北海道札幌市東区東雁来十三条');
ok($zip->set_number('0070034')->is_valid_number, '北海道札幌市東区東雁来十四条');
ok($zip->set_number('0070801')->is_valid_number, '北海道札幌市東区東苗穂一条');
ok($zip->set_number('0070802')->is_valid_number, '北海道札幌市東区東苗穂二条');
ok($zip->set_number('0070803')->is_valid_number, '北海道札幌市東区東苗穂三条');
ok($zip->set_number('0070804')->is_valid_number, '北海道札幌市東区東苗穂四条');
ok($zip->set_number('0070805')->is_valid_number, '北海道札幌市東区東苗穂五条');
ok($zip->set_number('0070806')->is_valid_number, '北海道札幌市東区東苗穂六条');
ok($zip->set_number('0070807')->is_valid_number, '北海道札幌市東区東苗穂七条');
ok($zip->set_number('0070808')->is_valid_number, '北海道札幌市東区東苗穂八条');
ok($zip->set_number('0070809')->is_valid_number, '北海道札幌市東区東苗穂九条');
ok($zip->set_number('0070810')->is_valid_number, '北海道札幌市東区東苗穂十条');
ok($zip->set_number('0070811')->is_valid_number, '北海道札幌市東区東苗穂十一条');
ok($zip->set_number('0070812')->is_valid_number, '北海道札幌市東区東苗穂十二条');
ok($zip->set_number('0070813')->is_valid_number, '北海道札幌市東区東苗穂十三条');
ok($zip->set_number('0070814')->is_valid_number, '北海道札幌市東区東苗穂十四条');
ok($zip->set_number('0070815')->is_valid_number, '北海道札幌市東区東苗穂十五条');
ok($zip->set_number('0070819')->is_valid_number, '北海道札幌市東区東苗穂町');
ok($zip->set_number('0070820')->is_valid_number, '北海道札幌市東区東雁来町');
ok($zip->set_number('0070821')->is_valid_number, '北海道札幌市東区東雁来一条');
ok($zip->set_number('0070822')->is_valid_number, '北海道札幌市東区東雁来二条');
ok($zip->set_number('0070823')->is_valid_number, '北海道札幌市東区東雁来三条');
ok($zip->set_number('0070824')->is_valid_number, '北海道札幌市東区東雁来四条');
ok($zip->set_number('0070825')->is_valid_number, '北海道札幌市東区東雁来五条');
ok($zip->set_number('0070826')->is_valid_number, '北海道札幌市東区東雁来六条');
ok($zip->set_number('0070827')->is_valid_number, '北海道札幌市東区東雁来七条');
ok($zip->set_number('0070828')->is_valid_number, '北海道札幌市東区東雁来八条');
ok($zip->set_number('0070829')->is_valid_number, '北海道札幌市東区東雁来九条');
ok($zip->set_number('0070834')->is_valid_number, '北海道札幌市東区北三十四条東');
ok($zip->set_number('0070835')->is_valid_number, '北海道札幌市東区北三十五条東');
ok($zip->set_number('0070836')->is_valid_number, '北海道札幌市東区北三十六条東');
ok($zip->set_number('0070837')->is_valid_number, '北海道札幌市東区北三十七条東');
ok($zip->set_number('0070838')->is_valid_number, '北海道札幌市東区北三十八条東');
ok($zip->set_number('0070839')->is_valid_number, '北海道札幌市東区北三十九条東');
ok($zip->set_number('0070840')->is_valid_number, '北海道札幌市東区北四十条東');
ok($zip->set_number('0070841')->is_valid_number, '北海道札幌市東区北四十一条東');
ok($zip->set_number('0070842')->is_valid_number, '北海道札幌市東区北四十二条東');
ok($zip->set_number('0070843')->is_valid_number, '北海道札幌市東区北四十三条東');
ok($zip->set_number('0070844')->is_valid_number, '北海道札幌市東区北四十四条東');
ok($zip->set_number('0070845')->is_valid_number, '北海道札幌市東区北四十五条東');
ok($zip->set_number('0070846')->is_valid_number, '北海道札幌市東区北四十六条東');
ok($zip->set_number('0070847')->is_valid_number, '北海道札幌市東区北四十七条東');
ok($zip->set_number('0070848')->is_valid_number, '北海道札幌市東区北四十八条東');
ok($zip->set_number('0070849')->is_valid_number, '北海道札幌市東区北四十九条東');
ok($zip->set_number('0070850')->is_valid_number, '北海道札幌市東区北五十条東');
ok($zip->set_number('0070851')->is_valid_number, '北海道札幌市東区北五十一条東');
ok($zip->set_number('0070852')->is_valid_number, '北海道札幌市東区栄町');
ok($zip->set_number('0070861')->is_valid_number, '北海道札幌市東区伏古一条');
ok($zip->set_number('0070862')->is_valid_number, '北海道札幌市東区伏古二条');
ok($zip->set_number('0070863')->is_valid_number, '北海道札幌市東区伏古三条');
ok($zip->set_number('0070864')->is_valid_number, '北海道札幌市東区伏古四条');
ok($zip->set_number('0070865')->is_valid_number, '北海道札幌市東区伏古五条');
ok($zip->set_number('0070866')->is_valid_number, '北海道札幌市東区伏古六条');
ok($zip->set_number('0070867')->is_valid_number, '北海道札幌市東区伏古七条');
ok($zip->set_number('0070868')->is_valid_number, '北海道札幌市東区伏古八条');
ok($zip->set_number('0070869')->is_valid_number, '北海道札幌市東区伏古九条');
ok($zip->set_number('0070870')->is_valid_number, '北海道札幌市東区伏古十条');
ok($zip->set_number('0070871')->is_valid_number, '北海道札幌市東区伏古十一条');
ok($zip->set_number('0070872')->is_valid_number, '北海道札幌市東区伏古十二条');
ok($zip->set_number('0070873')->is_valid_number, '北海道札幌市東区伏古十三条');
ok($zip->set_number('0070874')->is_valid_number, '北海道札幌市東区伏古十四条');
ok($zip->set_number('0070880')->is_valid_number, '北海道札幌市東区丘珠町');
ok($zip->set_number('0070881')->is_valid_number, '北海道札幌市東区北丘珠一条');
ok($zip->set_number('0070882')->is_valid_number, '北海道札幌市東区北丘珠二条');
ok($zip->set_number('0070883')->is_valid_number, '北海道札幌市東区北丘珠三条');
ok($zip->set_number('0070884')->is_valid_number, '北海道札幌市東区北丘珠四条');
ok($zip->set_number('0070885')->is_valid_number, '北海道札幌市東区北丘珠五条');
ok($zip->set_number('0070886')->is_valid_number, '北海道札幌市東区北丘珠六条');
ok($zip->set_number('0070890')->is_valid_number, '北海道札幌市東区中沼町');
ok($zip->set_number('0070891')->is_valid_number, '北海道札幌市東区中沼西一条');
ok($zip->set_number('0070892')->is_valid_number, '北海道札幌市東区中沼西二条');
ok($zip->set_number('0070893')->is_valid_number, '北海道札幌市東区中沼西三条');
ok($zip->set_number('0070894')->is_valid_number, '北海道札幌市東区中沼西四条');
ok($zip->set_number('0070895')->is_valid_number, '北海道札幌市東区中沼西五条');
ok($zip->set_number('0100000')->is_valid_number, '秋田県秋田市以下に掲載がない場合');
ok($zip->set_number('0100001')->is_valid_number, '秋田県秋田市中通');
ok($zip->set_number('0100002')->is_valid_number, '秋田県秋田市東通仲町');
ok($zip->set_number('0100003')->is_valid_number, '秋田県秋田市東通');
ok($zip->set_number('0100004')->is_valid_number, '秋田県秋田市東通観音前');
ok($zip->set_number('0100005')->is_valid_number, '秋田県秋田市東通明田');
ok($zip->set_number('0100006')->is_valid_number, '秋田県秋田市東通館ノ越');
ok($zip->set_number('0100011')->is_valid_number, '秋田県秋田市南通亀の町');
ok($zip->set_number('0100012')->is_valid_number, '秋田県秋田市南通みその町');
ok($zip->set_number('0100013')->is_valid_number, '秋田県秋田市南通築地');
ok($zip->set_number('0100014')->is_valid_number, '秋田県秋田市南通宮田');
ok($zip->set_number('0100021')->is_valid_number, '秋田県秋田市楢山登町');
ok($zip->set_number('0100022')->is_valid_number, '秋田県秋田市楢山南中町');
ok($zip->set_number('0100023')->is_valid_number, '秋田県秋田市楢山本町');
ok($zip->set_number('0100024')->is_valid_number, '秋田県秋田市楢山南新町上丁');
ok($zip->set_number('0100025')->is_valid_number, '秋田県秋田市楢山佐竹町');
ok($zip->set_number('0100026')->is_valid_number, '秋田県秋田市楢山古川新町');
ok($zip->set_number('0100027')->is_valid_number, '秋田県秋田市楢山南新町下丁');
ok($zip->set_number('0100028')->is_valid_number, '秋田県秋田市楢山共和町');
ok($zip->set_number('0100029')->is_valid_number, '秋田県秋田市楢山川口境');
ok($zip->set_number('0100031')->is_valid_number, '秋田県秋田市楢山大元町');
ok($zip->set_number('0100032')->is_valid_number, '秋田県秋田市楢山太田町');
ok($zip->set_number('0100033')->is_valid_number, '秋田県秋田市楢山石塚町');
ok($zip->set_number('0100034')->is_valid_number, '秋田県秋田市楢山');
ok($zip->set_number('0100035')->is_valid_number, '秋田県秋田市楢山城南町');
ok($zip->set_number('0100036')->is_valid_number, '秋田県秋田市楢山金照町');
ok($zip->set_number('0100037')->is_valid_number, '秋田県秋田市楢山愛宕下');
ok($zip->set_number('0100038')->is_valid_number, '秋田県秋田市楢山城南新町');
ok($zip->set_number('0100041')->is_valid_number, '秋田県秋田市広面');
ok($zip->set_number('0100042')->is_valid_number, '秋田県秋田市桜');
ok($zip->set_number('0100043')->is_valid_number, '秋田県秋田市桜ガ丘');
ok($zip->set_number('0100044')->is_valid_number, '秋田県秋田市横森');
ok($zip->set_number('0100051')->is_valid_number, '秋田県秋田市下北手松崎');
ok($zip->set_number('0100052')->is_valid_number, '秋田県秋田市下北手柳館');
ok($zip->set_number('0100053')->is_valid_number, '秋田県秋田市下北手寒川');
ok($zip->set_number('0100054')->is_valid_number, '秋田県秋田市下北手宝川');
ok($zip->set_number('0100055')->is_valid_number, '秋田県秋田市下北手通沢');
ok($zip->set_number('0100056')->is_valid_number, '秋田県秋田市下北手黒川');
ok($zip->set_number('0100057')->is_valid_number, '秋田県秋田市下北手梨平');
ok($zip->set_number('0100058')->is_valid_number, '秋田県秋田市下北手桜');
ok($zip->set_number('0100059')->is_valid_number, '秋田県秋田市桜台');
ok($zip->set_number('0100061')->is_valid_number, '秋田県秋田市卸町');
ok($zip->set_number('0100062')->is_valid_number, '秋田県秋田市牛島東');
ok($zip->set_number('0100063')->is_valid_number, '秋田県秋田市牛島西');
ok($zip->set_number('0100064')->is_valid_number, '秋田県秋田市牛島');
ok($zip->set_number('0100065')->is_valid_number, '秋田県秋田市茨島');
ok($zip->set_number('0100066')->is_valid_number, '秋田県秋田市牛島南');
ok($zip->set_number('0100101')->is_valid_number, '秋田県潟上市天王(追分、追分西、上北野、長沼)');
ok($zip->set_number('0100111')->is_valid_number, '秋田県秋田市金足岩瀬');
ok($zip->set_number('0100112')->is_valid_number, '秋田県秋田市金足堀内');
ok($zip->set_number('0100113')->is_valid_number, '秋田県秋田市金足浦山');
ok($zip->set_number('0100114')->is_valid_number, '秋田県秋田市金足下刈');
ok($zip->set_number('0100115')->is_valid_number, '秋田県秋田市金足大清水');
ok($zip->set_number('0100116')->is_valid_number, '秋田県秋田市金足小泉');
ok($zip->set_number('0100121')->is_valid_number, '秋田県秋田市金足黒川');
ok($zip->set_number('0100122')->is_valid_number, '秋田県秋田市金足吉田');
ok($zip->set_number('0100123')->is_valid_number, '秋田県秋田市金足片田');
ok($zip->set_number('0100124')->is_valid_number, '秋田県秋田市金足鳰崎');
ok($zip->set_number('0100125')->is_valid_number, '秋田県秋田市金足高岡');
ok($zip->set_number('0100126')->is_valid_number, '秋田県秋田市金足追分');
ok($zip->set_number('0100131')->is_valid_number, '秋田県秋田市上新城白山');
ok($zip->set_number('0100132')->is_valid_number, '秋田県秋田市上新城小又');
ok($zip->set_number('0100133')->is_valid_number, '秋田県秋田市上新城湯ノ里');
ok($zip->set_number('0100134')->is_valid_number, '秋田県秋田市上新城道川');
ok($zip->set_number('0100135')->is_valid_number, '秋田県秋田市上新城五十丁');
ok($zip->set_number('0100136')->is_valid_number, '秋田県秋田市上新城中');
ok($zip->set_number('0100137')->is_valid_number, '秋田県秋田市上新城石名坂');
ok($zip->set_number('0100138')->is_valid_number, '秋田県秋田市上新城保多野');
ok($zip->set_number('0100141')->is_valid_number, '秋田県秋田市下新城長岡');
ok($zip->set_number('0100142')->is_valid_number, '秋田県秋田市下新城青崎');
ok($zip->set_number('0100143')->is_valid_number, '秋田県秋田市下新城小友');
ok($zip->set_number('0100144')->is_valid_number, '秋田県秋田市下新城岩城');
ok($zip->set_number('0100145')->is_valid_number, '秋田県秋田市下新城笠岡');
ok($zip->set_number('0100146')->is_valid_number, '秋田県秋田市下新城中野');
ok($zip->set_number('0100201')->is_valid_number, '秋田県潟上市天王(その他)');
ok($zip->set_number('0100202')->is_valid_number, '秋田県潟上市天王大崎');
ok($zip->set_number('0100341')->is_valid_number, '秋田県男鹿市船越');
ok($zip->set_number('0100342')->is_valid_number, '秋田県男鹿市脇本脇本');
ok($zip->set_number('0100343')->is_valid_number, '秋田県男鹿市脇本田谷沢');
ok($zip->set_number('0100344')->is_valid_number, '秋田県男鹿市脇本富永');
ok($zip->set_number('0100345')->is_valid_number, '秋田県男鹿市脇本浦田');
ok($zip->set_number('0100346')->is_valid_number, '秋田県男鹿市脇本樽沢');
ok($zip->set_number('0100347')->is_valid_number, '秋田県男鹿市脇本百川');
ok($zip->set_number('0100351')->is_valid_number, '秋田県男鹿市五里合箱井');
ok($zip->set_number('0100352')->is_valid_number, '秋田県男鹿市五里合琴川');
ok($zip->set_number('0100353')->is_valid_number, '秋田県男鹿市五里合神谷');
ok($zip->set_number('0100354')->is_valid_number, '秋田県男鹿市五里合中石');
ok($zip->set_number('0100355')->is_valid_number, '秋田県男鹿市五里合鮪川');
ok($zip->set_number('0100400')->is_valid_number, '秋田県南秋田郡大潟村以下に掲載がない場合');
ok($zip->set_number('0100401')->is_valid_number, '秋田県男鹿市野石');
ok($zip->set_number('0100411')->is_valid_number, '秋田県男鹿市福米沢');
ok($zip->set_number('0100412')->is_valid_number, '秋田県男鹿市本内');
ok($zip->set_number('0100413')->is_valid_number, '秋田県男鹿市松木沢');
ok($zip->set_number('0100421')->is_valid_number, '秋田県男鹿市鵜木');
ok($zip->set_number('0100422')->is_valid_number, '秋田県男鹿市角間崎');
ok($zip->set_number('0100423')->is_valid_number, '秋田県男鹿市福川');
ok($zip->set_number('0100431')->is_valid_number, '秋田県男鹿市払戸');
ok($zip->set_number('0100441')->is_valid_number, '秋田県南秋田郡大潟村北');
ok($zip->set_number('0100442')->is_valid_number, '秋田県南秋田郡大潟村東');
ok($zip->set_number('0100443')->is_valid_number, '秋田県南秋田郡大潟村中央');
ok($zip->set_number('0100444')->is_valid_number, '秋田県南秋田郡大潟村南');
ok($zip->set_number('0100445')->is_valid_number, '秋田県南秋田郡大潟村西');
ok($zip->set_number('0100451')->is_valid_number, '秋田県南秋田郡大潟村大潟');
ok($zip->set_number('0100452')->is_valid_number, '秋田県南秋田郡大潟村方上');
ok($zip->set_number('0100453')->is_valid_number, '秋田県南秋田郡大潟村方口');
ok($zip->set_number('0100454')->is_valid_number, '秋田県南秋田郡大潟村中野');
ok($zip->set_number('0100455')->is_valid_number, '秋田県南秋田郡大潟村西野');
ok($zip->set_number('0100456')->is_valid_number, '秋田県南秋田郡大潟村東野');
ok($zip->set_number('0100500')->is_valid_number, '秋田県男鹿市以下に掲載がない場合');
ok($zip->set_number('0100501')->is_valid_number, '秋田県男鹿市船川港仁井山');
ok($zip->set_number('0100502')->is_valid_number, '秋田県男鹿市船川港比詰');
ok($zip->set_number('0100503')->is_valid_number, '秋田県男鹿市船川港金川');
ok($zip->set_number('0100511')->is_valid_number, '秋田県男鹿市船川港船川');
ok($zip->set_number('0100521')->is_valid_number, '秋田県男鹿市船川港南平沢');
ok($zip->set_number('0100522')->is_valid_number, '秋田県男鹿市船川港増川');
ok($zip->set_number('0100523')->is_valid_number, '秋田県男鹿市船川港女川');
ok($zip->set_number('0100531')->is_valid_number, '秋田県男鹿市船川港台島');
ok($zip->set_number('0100532')->is_valid_number, '秋田県男鹿市船川港椿');
ok($zip->set_number('0100533')->is_valid_number, '秋田県男鹿市船川港双六');
ok($zip->set_number('0100534')->is_valid_number, '秋田県男鹿市船川港小浜');
ok($zip->set_number('0100535')->is_valid_number, '秋田県男鹿市船川港本山門前');
ok($zip->set_number('0100661')->is_valid_number, '秋田県男鹿市男鹿中浜間口');
ok($zip->set_number('0100662')->is_valid_number, '秋田県男鹿市男鹿中中間口');
ok($zip->set_number('0100663')->is_valid_number, '秋田県男鹿市男鹿中滝川');
ok($zip->set_number('0100664')->is_valid_number, '秋田県男鹿市男鹿中国有地内');
ok($zip->set_number('0100665')->is_valid_number, '秋田県男鹿市男鹿中山町');
ok($zip->set_number('0100671')->is_valid_number, '秋田県男鹿市戸賀加茂青砂');
ok($zip->set_number('0100672')->is_valid_number, '秋田県男鹿市戸賀浜塩谷');
ok($zip->set_number('0100673')->is_valid_number, '秋田県男鹿市戸賀塩浜');
ok($zip->set_number('0100674')->is_valid_number, '秋田県男鹿市戸賀戸賀');
ok($zip->set_number('0100675')->is_valid_number, '秋田県男鹿市北浦入道崎');
ok($zip->set_number('0100676')->is_valid_number, '秋田県男鹿市北浦西黒沢');
ok($zip->set_number('0100681')->is_valid_number, '秋田県男鹿市北浦相川');
ok($zip->set_number('0100682')->is_valid_number, '秋田県男鹿市北浦表町');
ok($zip->set_number('0100683')->is_valid_number, '秋田県男鹿市北浦北浦');
ok($zip->set_number('0100684')->is_valid_number, '秋田県男鹿市北浦安全寺');
ok($zip->set_number('0100685')->is_valid_number, '秋田県男鹿市北浦真山');
ok($zip->set_number('0100686')->is_valid_number, '秋田県男鹿市北浦西水口');
ok($zip->set_number('0100687')->is_valid_number, '秋田県男鹿市北浦湯本');
ok($zip->set_number('0100688')->is_valid_number, '秋田県男鹿市北浦野村');
ok($zip->set_number('0100802')->is_valid_number, '秋田県秋田市外旭川');
ok($zip->set_number('0100803')->is_valid_number, '秋田県秋田市外旭川八柳');
ok($zip->set_number('0100804')->is_valid_number, '秋田県秋田市外旭川八幡田(丁目)');
ok($zip->set_number('0100811')->is_valid_number, '秋田県秋田市泉釜ノ町');
ok($zip->set_number('0100812')->is_valid_number, '秋田県秋田市泉三嶽根');
ok($zip->set_number('0100813')->is_valid_number, '秋田県秋田市泉一ノ坪');
ok($zip->set_number('0100814')->is_valid_number, '秋田県秋田市泉東町');
ok($zip->set_number('0100815')->is_valid_number, '秋田県秋田市泉馬場');
ok($zip->set_number('0100816')->is_valid_number, '秋田県秋田市泉');
ok($zip->set_number('0100817')->is_valid_number, '秋田県秋田市泉菅野(丁目)');
ok($zip->set_number('0100821')->is_valid_number, '秋田県秋田市濁川');
ok($zip->set_number('0100822')->is_valid_number, '秋田県秋田市添川');
ok($zip->set_number('0100823')->is_valid_number, '秋田県秋田市山内');
ok($zip->set_number('0100824')->is_valid_number, '秋田県秋田市仁別');
ok($zip->set_number('0100825')->is_valid_number, '秋田県秋田市柳田');
ok($zip->set_number('0100826')->is_valid_number, '秋田県秋田市新藤田');
ok($zip->set_number('0100831')->is_valid_number, '秋田県秋田市旭川清澄町');
ok($zip->set_number('0100832')->is_valid_number, '秋田県秋田市旭川新藤田西町');
ok($zip->set_number('0100833')->is_valid_number, '秋田県秋田市旭川新藤田東町');
ok($zip->set_number('0100834')->is_valid_number, '秋田県秋田市旭川南町');
ok($zip->set_number('0100841')->is_valid_number, '秋田県秋田市手形山西町');
ok($zip->set_number('0100842')->is_valid_number, '秋田県秋田市手形山北町');
ok($zip->set_number('0100843')->is_valid_number, '秋田県秋田市手形山東町');
ok($zip->set_number('0100844')->is_valid_number, '秋田県秋田市手形山中町');
ok($zip->set_number('0100845')->is_valid_number, '秋田県秋田市手形山南町');
ok($zip->set_number('0100851')->is_valid_number, '秋田県秋田市手形');
ok($zip->set_number('0100852')->is_valid_number, '秋田県秋田市手形学園町');
ok($zip->set_number('0100853')->is_valid_number, '秋田県秋田市蛇野');
ok($zip->set_number('0100854')->is_valid_number, '秋田県秋田市手形山崎町');
ok($zip->set_number('0100861')->is_valid_number, '秋田県秋田市手形からみでん');
ok($zip->set_number('0100862')->is_valid_number, '秋田県秋田市手形田中');
ok($zip->set_number('0100863')->is_valid_number, '秋田県秋田市手形休下町');
ok($zip->set_number('0100864')->is_valid_number, '秋田県秋田市手形住吉町');
ok($zip->set_number('0100865')->is_valid_number, '秋田県秋田市手形新栄町');
ok($zip->set_number('0100871')->is_valid_number, '秋田県秋田市千秋中島町');
ok($zip->set_number('0100872')->is_valid_number, '秋田県秋田市千秋北の丸');
ok($zip->set_number('0100873')->is_valid_number, '秋田県秋田市千秋城下町');
ok($zip->set_number('0100874')->is_valid_number, '秋田県秋田市千秋久保田町');
ok($zip->set_number('0100875')->is_valid_number, '秋田県秋田市千秋明徳町');
ok($zip->set_number('0100876')->is_valid_number, '秋田県秋田市千秋公園');
ok($zip->set_number('0100877')->is_valid_number, '秋田県秋田市千秋矢留町');
ok($zip->set_number('0100901')->is_valid_number, '秋田県秋田市保戸野桜町');
ok($zip->set_number('0100902')->is_valid_number, '秋田県秋田市保戸野金砂町');
ok($zip->set_number('0100903')->is_valid_number, '秋田県秋田市保戸野八丁');
ok($zip->set_number('0100904')->is_valid_number, '秋田県秋田市保戸野原の町');
ok($zip->set_number('0100905')->is_valid_number, '秋田県秋田市保戸野中町');
ok($zip->set_number('0100911')->is_valid_number, '秋田県秋田市保戸野すわ町');
ok($zip->set_number('0100912')->is_valid_number, '秋田県秋田市保戸野通町');
ok($zip->set_number('0100913')->is_valid_number, '秋田県秋田市保戸野鉄砲町');
ok($zip->set_number('0100914')->is_valid_number, '秋田県秋田市保戸野千代田町');
ok($zip->set_number('0100915')->is_valid_number, '秋田県秋田市保戸野');
ok($zip->set_number('0100916')->is_valid_number, '秋田県秋田市泉北');
ok($zip->set_number('0100917')->is_valid_number, '秋田県秋田市泉中央');
ok($zip->set_number('0100918')->is_valid_number, '秋田県秋田市泉南');
ok($zip->set_number('0100921')->is_valid_number, '秋田県秋田市大町');
ok($zip->set_number('0100922')->is_valid_number, '秋田県秋田市旭北栄町');
ok($zip->set_number('0100923')->is_valid_number, '秋田県秋田市旭北錦町');
ok($zip->set_number('0100924')->is_valid_number, '秋田県秋田市旭北寺町');
ok($zip->set_number('0100925')->is_valid_number, '秋田県秋田市旭南');
ok($zip->set_number('0100931')->is_valid_number, '秋田県秋田市川元山下町');
ok($zip->set_number('0100932')->is_valid_number, '秋田県秋田市川元開和町');
ok($zip->set_number('0100933')->is_valid_number, '秋田県秋田市川元松丘町');
ok($zip->set_number('0100934')->is_valid_number, '秋田県秋田市川元むつみ町');
ok($zip->set_number('0100935')->is_valid_number, '秋田県秋田市川元小川町');
ok($zip->set_number('0100941')->is_valid_number, '秋田県秋田市川尻町');
ok($zip->set_number('0100942')->is_valid_number, '秋田県秋田市川尻大川町');
ok($zip->set_number('0100943')->is_valid_number, '秋田県秋田市川尻御休町');
ok($zip->set_number('0100944')->is_valid_number, '秋田県秋田市川尻若葉町');
ok($zip->set_number('0100945')->is_valid_number, '秋田県秋田市川尻みよし町');
ok($zip->set_number('0100946')->is_valid_number, '秋田県秋田市川尻総社町');
ok($zip->set_number('0100947')->is_valid_number, '秋田県秋田市川尻上野町');
ok($zip->set_number('0100948')->is_valid_number, '秋田県秋田市川尻新川町');
ok($zip->set_number('0100951')->is_valid_number, '秋田県秋田市山王');
ok($zip->set_number('0100952')->is_valid_number, '秋田県秋田市山王新町');
ok($zip->set_number('0100953')->is_valid_number, '秋田県秋田市山王中園町');
ok($zip->set_number('0100954')->is_valid_number, '秋田県秋田市山王沼田町');
ok($zip->set_number('0100955')->is_valid_number, '秋田県秋田市山王中島町');
ok($zip->set_number('0100956')->is_valid_number, '秋田県秋田市山王臨海町');
ok($zip->set_number('0100961')->is_valid_number, '秋田県秋田市八橋イサノ');
ok($zip->set_number('0100962')->is_valid_number, '秋田県秋田市八橋大畑');
ok($zip->set_number('0100963')->is_valid_number, '秋田県秋田市八橋大沼町');
ok($zip->set_number('0100964')->is_valid_number, '秋田県秋田市八橋鯲沼町');
ok($zip->set_number('0100965')->is_valid_number, '秋田県秋田市八橋新川向');
ok($zip->set_number('0100966')->is_valid_number, '秋田県秋田市高陽青柳町');
ok($zip->set_number('0100967')->is_valid_number, '秋田県秋田市高陽幸町');
ok($zip->set_number('0100971')->is_valid_number, '秋田県秋田市八橋三和町');
ok($zip->set_number('0100972')->is_valid_number, '秋田県秋田市八橋田五郎');
ok($zip->set_number('0100973')->is_valid_number, '秋田県秋田市八橋本町');
ok($zip->set_number('0100974')->is_valid_number, '秋田県秋田市八橋運動公園');
ok($zip->set_number('0100975')->is_valid_number, '秋田県秋田市八橋');
ok($zip->set_number('0100976')->is_valid_number, '秋田県秋田市八橋南');
ok($zip->set_number('0100977')->is_valid_number, '秋田県秋田市八橋大道東');
ok($zip->set_number('0101101')->is_valid_number, '秋田県秋田市太平八田');
ok($zip->set_number('0101102')->is_valid_number, '秋田県秋田市太平目長崎');
ok($zip->set_number('0101103')->is_valid_number, '秋田県秋田市太平中関');
ok($zip->set_number('0101104')->is_valid_number, '秋田県秋田市太平寺庭');
ok($zip->set_number('0101105')->is_valid_number, '秋田県秋田市太平黒沢');
ok($zip->set_number('0101106')->is_valid_number, '秋田県秋田市太平山谷');
ok($zip->set_number('0101201')->is_valid_number, '秋田県秋田市雄和田草川');
ok($zip->set_number('0101202')->is_valid_number, '秋田県秋田市雄和芝野新田');
ok($zip->set_number('0101203')->is_valid_number, '秋田県秋田市雄和下黒瀬');
ok($zip->set_number('0101211')->is_valid_number, '秋田県秋田市雄和椿川');
ok($zip->set_number('0101212')->is_valid_number, '秋田県秋田市雄和平尾鳥');
ok($zip->set_number('0101221')->is_valid_number, '秋田県秋田市雄和平沢');
ok($zip->set_number('0101222')->is_valid_number, '秋田県秋田市雄和石田');
ok($zip->set_number('0101223')->is_valid_number, '秋田県秋田市雄和妙法');
ok($zip->set_number('0101224')->is_valid_number, '秋田県秋田市雄和種沢');
ok($zip->set_number('0101225')->is_valid_number, '秋田県秋田市雄和左手子');
ok($zip->set_number('0101231')->is_valid_number, '秋田県秋田市雄和相川');
ok($zip->set_number('0101232')->is_valid_number, '秋田県秋田市雄和戸賀沢');
ok($zip->set_number('0101233')->is_valid_number, '秋田県秋田市雄和女米木');
ok($zip->set_number('0101341')->is_valid_number, '秋田県秋田市雄和新波');
ok($zip->set_number('0101342')->is_valid_number, '秋田県秋田市雄和神ケ村');
ok($zip->set_number('0101343')->is_valid_number, '秋田県秋田市雄和繋');
ok($zip->set_number('0101344')->is_valid_number, '秋田県秋田市雄和向野');
ok($zip->set_number('0101351')->is_valid_number, '秋田県秋田市雄和碇田');
ok($zip->set_number('0101352')->is_valid_number, '秋田県秋田市雄和萱ケ沢');
ok($zip->set_number('0101401')->is_valid_number, '秋田県秋田市上北手大杉沢');
ok($zip->set_number('0101402')->is_valid_number, '秋田県秋田市上北手小山田');
ok($zip->set_number('0101403')->is_valid_number, '秋田県秋田市上北手荒巻');
ok($zip->set_number('0101404')->is_valid_number, '秋田県秋田市上北手古野');
ok($zip->set_number('0101405')->is_valid_number, '秋田県秋田市上北手大山田');
ok($zip->set_number('0101406')->is_valid_number, '秋田県秋田市上北手猿田');
ok($zip->set_number('0101407')->is_valid_number, '秋田県秋田市上北手百崎');
ok($zip->set_number('0101408')->is_valid_number, '秋田県秋田市上北手大戸');
ok($zip->set_number('0101409')->is_valid_number, '秋田県秋田市南ケ丘');
ok($zip->set_number('0101411')->is_valid_number, '秋田県秋田市上北手御所野');
ok($zip->set_number('0101412')->is_valid_number, '秋田県秋田市御所野下堤');
ok($zip->set_number('0101413')->is_valid_number, '秋田県秋田市御所野地蔵田');
ok($zip->set_number('0101414')->is_valid_number, '秋田県秋田市御所野元町');
ok($zip->set_number('0101415')->is_valid_number, '秋田県秋田市御所野湯本');
ok($zip->set_number('0101416')->is_valid_number, '秋田県秋田市四ツ小屋末戸松本');
ok($zip->set_number('0101417')->is_valid_number, '秋田県秋田市四ツ小屋');
ok($zip->set_number('0101418')->is_valid_number, '秋田県秋田市四ツ小屋小阿地');
ok($zip->set_number('0101419')->is_valid_number, '秋田県秋田市御所野堤台');
ok($zip->set_number('0101420')->is_valid_number, '秋田県秋田市大住南');
ok($zip->set_number('0101421')->is_valid_number, '秋田県秋田市仁井田本町');
ok($zip->set_number('0101422')->is_valid_number, '秋田県秋田市仁井田目長田');
ok($zip->set_number('0101423')->is_valid_number, '秋田県秋田市仁井田');
ok($zip->set_number('0101424')->is_valid_number, '秋田県秋田市御野場');
ok($zip->set_number('0101425')->is_valid_number, '秋田県秋田市御野場新町');
ok($zip->set_number('0101426')->is_valid_number, '秋田県秋田市仁井田小中島');
ok($zip->set_number('0101427')->is_valid_number, '秋田県秋田市仁井田新田');
ok($zip->set_number('0101428')->is_valid_number, '秋田県秋田市大平台');
ok($zip->set_number('0101429')->is_valid_number, '秋田県秋田市山手台');
ok($zip->set_number('0101431')->is_valid_number, '秋田県秋田市仁井田二ツ屋');
ok($zip->set_number('0101432')->is_valid_number, '秋田県秋田市仁井田福島');
ok($zip->set_number('0101433')->is_valid_number, '秋田県秋田市仁井田栄町');
ok($zip->set_number('0101434')->is_valid_number, '秋田県秋田市仁井田蕗見町');
ok($zip->set_number('0101435')->is_valid_number, '秋田県秋田市仁井田潟中町');
ok($zip->set_number('0101436')->is_valid_number, '秋田県秋田市大住');
ok($zip->set_number('0101437')->is_valid_number, '秋田県秋田市仁井田緑町');
ok($zip->set_number('0101501')->is_valid_number, '秋田県秋田市下浜桂根');
ok($zip->set_number('0101502')->is_valid_number, '秋田県秋田市下浜長浜');
ok($zip->set_number('0101503')->is_valid_number, '秋田県秋田市下浜羽川');
ok($zip->set_number('0101504')->is_valid_number, '秋田県秋田市下浜名ケ沢');
ok($zip->set_number('0101505')->is_valid_number, '秋田県秋田市下浜八田');
ok($zip->set_number('0101506')->is_valid_number, '秋田県秋田市下浜楢田');
ok($zip->set_number('0101601')->is_valid_number, '秋田県秋田市向浜');
ok($zip->set_number('0101602')->is_valid_number, '秋田県秋田市新屋下川原町');
ok($zip->set_number('0101603')->is_valid_number, '秋田県秋田市新屋勝平台');
ok($zip->set_number('0101604')->is_valid_number, '秋田県秋田市新屋松美町');
ok($zip->set_number('0101605')->is_valid_number, '秋田県秋田市新屋勝平町');
ok($zip->set_number('0101606')->is_valid_number, '秋田県秋田市新屋寿町');
ok($zip->set_number('0101607')->is_valid_number, '秋田県秋田市新屋南浜町');
ok($zip->set_number('0101608')->is_valid_number, '秋田県秋田市新屋北浜町');
ok($zip->set_number('0101611')->is_valid_number, '秋田県秋田市新屋天秤野');
ok($zip->set_number('0101612')->is_valid_number, '秋田県秋田市新屋豊町');
ok($zip->set_number('0101613')->is_valid_number, '秋田県秋田市新屋朝日町');
ok($zip->set_number('0101614')->is_valid_number, '秋田県秋田市新屋割山町');
ok($zip->set_number('0101615')->is_valid_number, '秋田県秋田市新屋船場町');
ok($zip->set_number('0101616')->is_valid_number, '秋田県秋田市新屋松美ガ丘南町');
ok($zip->set_number('0101617')->is_valid_number, '秋田県秋田市新屋松美ガ丘東町');
ok($zip->set_number('0101618')->is_valid_number, '秋田県秋田市新屋松美ガ丘北町');
ok($zip->set_number('0101621')->is_valid_number, '秋田県秋田市新屋栗田町');
ok($zip->set_number('0101622')->is_valid_number, '秋田県秋田市新屋日吉町');
ok($zip->set_number('0101623')->is_valid_number, '秋田県秋田市新屋町');
ok($zip->set_number('0101631')->is_valid_number, '秋田県秋田市新屋元町');
ok($zip->set_number('0101632')->is_valid_number, '秋田県秋田市新屋大川町');
ok($zip->set_number('0101633')->is_valid_number, '秋田県秋田市新屋鳥木町');
ok($zip->set_number('0101634')->is_valid_number, '秋田県秋田市新屋沖田町');
ok($zip->set_number('0101635')->is_valid_number, '秋田県秋田市新屋前野町');
ok($zip->set_number('0101636')->is_valid_number, '秋田県秋田市新屋比内町');
ok($zip->set_number('0101637')->is_valid_number, '秋田県秋田市新屋扇町');
ok($zip->set_number('0101638')->is_valid_number, '秋田県秋田市新屋表町');
ok($zip->set_number('0101641')->is_valid_number, '秋田県秋田市新屋高美町');
ok($zip->set_number('0101642')->is_valid_number, '秋田県秋田市新屋渋谷町');
ok($zip->set_number('0101643')->is_valid_number, '秋田県秋田市新屋田尻沢東町');
ok($zip->set_number('0101644')->is_valid_number, '秋田県秋田市新屋田尻沢中町');
ok($zip->set_number('0101645')->is_valid_number, '秋田県秋田市新屋田尻沢西町');
ok($zip->set_number('0101651')->is_valid_number, '秋田県秋田市豊岩石田坂');
ok($zip->set_number('0101652')->is_valid_number, '秋田県秋田市豊岩豊巻');
ok($zip->set_number('0101653')->is_valid_number, '秋田県秋田市豊岩小山');
ok($zip->set_number('0101654')->is_valid_number, '秋田県秋田市浜田');
ok($zip->set_number('0110901')->is_valid_number, '秋田県秋田市寺内');
ok($zip->set_number('0110902')->is_valid_number, '秋田県秋田市寺内堂ノ沢');
ok($zip->set_number('0110903')->is_valid_number, '秋田県秋田市寺内油田');
ok($zip->set_number('0110904')->is_valid_number, '秋田県秋田市寺内蛭根');
ok($zip->set_number('0110905')->is_valid_number, '秋田県秋田市寺内神屋敷');
ok($zip->set_number('0110906')->is_valid_number, '秋田県秋田市寺内後城');
ok($zip->set_number('0110907')->is_valid_number, '秋田県秋田市寺内焼山');
ok($zip->set_number('0110908')->is_valid_number, '秋田県秋田市寺内大小路');
ok($zip->set_number('0110909')->is_valid_number, '秋田県秋田市寺内児桜');
ok($zip->set_number('0110911')->is_valid_number, '秋田県秋田市飯島');
ok($zip->set_number('0110912')->is_valid_number, '秋田県秋田市飯島川端');
ok($zip->set_number('0110913')->is_valid_number, '秋田県秋田市飯島鼠田');
ok($zip->set_number('0110914')->is_valid_number, '秋田県秋田市飯島美砂町');
ok($zip->set_number('0110915')->is_valid_number, '秋田県秋田市飯島緑丘町');
ok($zip->set_number('0110916')->is_valid_number, '秋田県秋田市飯島穀丁');
ok($zip->set_number('0110917')->is_valid_number, '秋田県秋田市飯島道東');
ok($zip->set_number('0110921')->is_valid_number, '秋田県秋田市飯島松根西町');
ok($zip->set_number('0110922')->is_valid_number, '秋田県秋田市飯島松根東町');
ok($zip->set_number('0110923')->is_valid_number, '秋田県秋田市飯島文京町');
ok($zip->set_number('0110924')->is_valid_number, '秋田県秋田市飯島長野本町');
ok($zip->set_number('0110925')->is_valid_number, '秋田県秋田市飯島長野中町');
ok($zip->set_number('0110926')->is_valid_number, '秋田県秋田市港北松野町');
ok($zip->set_number('0110927')->is_valid_number, '秋田県秋田市港北新町');
ok($zip->set_number('0110928')->is_valid_number, '秋田県秋田市飯島長野上町');
ok($zip->set_number('0110931')->is_valid_number, '秋田県秋田市将軍野東');
ok($zip->set_number('0110932')->is_valid_number, '秋田県秋田市将軍野青山町');
ok($zip->set_number('0110933')->is_valid_number, '秋田県秋田市将軍野堰越');
ok($zip->set_number('0110934')->is_valid_number, '秋田県秋田市将軍野桂町');
ok($zip->set_number('0110935')->is_valid_number, '秋田県秋田市将軍野向山');
ok($zip->set_number('0110936')->is_valid_number, '秋田県秋田市将軍野南');
ok($zip->set_number('0110937')->is_valid_number, '秋田県秋田市寺内高野');
ok($zip->set_number('0110938')->is_valid_number, '秋田県秋田市寺内鵜ノ木');
ok($zip->set_number('0110939')->is_valid_number, '秋田県秋田市寺内大畑');
ok($zip->set_number('0110941')->is_valid_number, '秋田県秋田市土崎港北');
ok($zip->set_number('0110942')->is_valid_number, '秋田県秋田市土崎港東');
ok($zip->set_number('0110943')->is_valid_number, '秋田県秋田市土崎港南');
ok($zip->set_number('0110944')->is_valid_number, '秋田県秋田市土崎港穀保町');
ok($zip->set_number('0110945')->is_valid_number, '秋田県秋田市土崎港西');
ok($zip->set_number('0110946')->is_valid_number, '秋田県秋田市土崎港中央');
ok($zip->set_number('0110947')->is_valid_number, '秋田県秋田市飯島新町');
ok($zip->set_number('0110948')->is_valid_number, '秋田県秋田市飯島西袋');
ok($zip->set_number('0110949')->is_valid_number, '秋田県秋田市飯島飯田');
ok($zip->set_number('0110951')->is_valid_number, '秋田県秋田市土崎港相染町');
ok($zip->set_number('0110951')->is_valid_number, '秋田県秋田市土崎港古川町');
ok($zip->set_number('0120000')->is_valid_number, '秋田県湯沢市以下に掲載がない場合');
ok($zip->set_number('0120001')->is_valid_number, '秋田県湯沢市角間');
ok($zip->set_number('0120002')->is_valid_number, '秋田県湯沢市下二井田');
ok($zip->set_number('0120003')->is_valid_number, '秋田県湯沢市上二井田');
ok($zip->set_number('0120004')->is_valid_number, '秋田県湯沢市二井田');
ok($zip->set_number('0120005')->is_valid_number, '秋田県湯沢市金谷');
ok($zip->set_number('0120006')->is_valid_number, '秋田県湯沢市柳田');
ok($zip->set_number('0120007')->is_valid_number, '秋田県湯沢市八幡');
ok($zip->set_number('0120008')->is_valid_number, '秋田県湯沢市高前');
ok($zip->set_number('0120011')->is_valid_number, '秋田県湯沢市森');
ok($zip->set_number('0120012')->is_valid_number, '秋田県湯沢市大森');
ok($zip->set_number('0120013')->is_valid_number, '秋田県湯沢市栄田');
ok($zip->set_number('0120014')->is_valid_number, '秋田県湯沢市大倉谷地');
ok($zip->set_number('0120015')->is_valid_number, '秋田県湯沢市倉内');
ok($zip->set_number('0120016')->is_valid_number, '秋田県湯沢市千刈');
ok($zip->set_number('0120017')->is_valid_number, '秋田県湯沢市富士見');
ok($zip->set_number('0120021')->is_valid_number, '秋田県湯沢市黄金原');
ok($zip->set_number('0120022')->is_valid_number, '秋田県湯沢市祝田');
ok($zip->set_number('0120023')->is_valid_number, '秋田県湯沢市沖田');
ok($zip->set_number('0120024')->is_valid_number, '秋田県湯沢市赤土');
ok($zip->set_number('0120025')->is_valid_number, '秋田県湯沢市前島');
ok($zip->set_number('0120026')->is_valid_number, '秋田県湯沢市大島');
ok($zip->set_number('0120031')->is_valid_number, '秋田県湯沢市鶴館');
ok($zip->set_number('0120032')->is_valid_number, '秋田県湯沢市元清水');
ok($zip->set_number('0120033')->is_valid_number, '秋田県湯沢市清水町');
ok($zip->set_number('0120034')->is_valid_number, '秋田県湯沢市西新町');
ok($zip->set_number('0120035')->is_valid_number, '秋田県湯沢市幸町');
ok($zip->set_number('0120036')->is_valid_number, '秋田県湯沢市両神');
ok($zip->set_number('0120037')->is_valid_number, '秋田県湯沢市沖鶴');
ok($zip->set_number('0120041')->is_valid_number, '秋田県湯沢市中野');
ok($zip->set_number('0120042')->is_valid_number, '秋田県湯沢市小豆田');
ok($zip->set_number('0120043')->is_valid_number, '秋田県湯沢市万石');
ok($zip->set_number('0120044')->is_valid_number, '秋田県湯沢市中野々目');
ok($zip->set_number('0120045')->is_valid_number, '秋田県湯沢市岡田町');
ok($zip->set_number('0120051')->is_valid_number, '秋田県湯沢市深堀');
ok($zip->set_number('0120052')->is_valid_number, '秋田県湯沢市下中川原');
ok($zip->set_number('0120053')->is_valid_number, '秋田県湯沢市中川原');
ok($zip->set_number('0120054')->is_valid_number, '秋田県湯沢市西中川原');
ok($zip->set_number('0120055')->is_valid_number, '秋田県湯沢市山田');
ok($zip->set_number('0120056')->is_valid_number, '秋田県湯沢市藤花');
ok($zip->set_number('0120057')->is_valid_number, '秋田県湯沢市雄勝田');
ok($zip->set_number('0120061')->is_valid_number, '秋田県湯沢市松岡');
ok($zip->set_number('0120062')->is_valid_number, '秋田県湯沢市石塚');
ok($zip->set_number('0120104')->is_valid_number, '秋田県湯沢市駒形町');
ok($zip->set_number('0120105')->is_valid_number, '秋田県湯沢市川連町');
ok($zip->set_number('0120106')->is_valid_number, '秋田県湯沢市三梨町');
ok($zip->set_number('0120107')->is_valid_number, '秋田県湯沢市稲庭町');
ok($zip->set_number('0120183')->is_valid_number, '秋田県湯沢市皆瀬(その他)');
ok($zip->set_number('0120801')->is_valid_number, '秋田県湯沢市岩崎');
ok($zip->set_number('0120802')->is_valid_number, '秋田県湯沢市成沢');
ok($zip->set_number('0120803')->is_valid_number, '秋田県湯沢市杉沢新所');
ok($zip->set_number('0120804')->is_valid_number, '秋田県湯沢市杉沢');
ok($zip->set_number('0120811')->is_valid_number, '秋田県湯沢市桜通り');
ok($zip->set_number('0120812')->is_valid_number, '秋田県湯沢市東赤土山');
ok($zip->set_number('0120813')->is_valid_number, '秋田県湯沢市前森');
ok($zip->set_number('0120814')->is_valid_number, '秋田県湯沢市大工町');
ok($zip->set_number('0120815')->is_valid_number, '秋田県湯沢市古館町');
ok($zip->set_number('0120821')->is_valid_number, '秋田県湯沢市山谷');
ok($zip->set_number('0120822')->is_valid_number, '秋田県湯沢市下山谷');
ok($zip->set_number('0120823')->is_valid_number, '秋田県湯沢市湯ノ上山');
ok($zip->set_number('0120823')->is_valid_number, '秋田県湯沢市湯ノ原');
ok($zip->set_number('0120824')->is_valid_number, '秋田県湯沢市裏門');
ok($zip->set_number('0120824')->is_valid_number, '秋田県湯沢市佐竹町');
ok($zip->set_number('0120825')->is_valid_number, '秋田県湯沢市北荒町');
ok($zip->set_number('0120826')->is_valid_number, '秋田県湯沢市柳町');
ok($zip->set_number('0120827')->is_valid_number, '秋田県湯沢市表町');
ok($zip->set_number('0120831')->is_valid_number, '秋田県湯沢市角間沢');
ok($zip->set_number('0120832')->is_valid_number, '秋田県湯沢市広沢山');
ok($zip->set_number('0120833')->is_valid_number, '秋田県湯沢市カツクイ沢山');
ok($zip->set_number('0120834')->is_valid_number, '秋田県湯沢市岩ノ沢山');
ok($zip->set_number('0120835')->is_valid_number, '秋田県湯沢市鉦打沢');
ok($zip->set_number('0120836')->is_valid_number, '秋田県湯沢市金堀沢山');
ok($zip->set_number('0120837')->is_valid_number, '秋田県湯沢市西金堀沢山');
ok($zip->set_number('0120838')->is_valid_number, '秋田県湯沢市蛇野');
ok($zip->set_number('0120841')->is_valid_number, '秋田県湯沢市大町');
ok($zip->set_number('0120842')->is_valid_number, '秋田県湯沢市内舘町');
ok($zip->set_number('0120843')->is_valid_number, '秋田県湯沢市内町');
ok($zip->set_number('0120844')->is_valid_number, '秋田県湯沢市田町');
ok($zip->set_number('0120845')->is_valid_number, '秋田県湯沢市材木町');
ok($zip->set_number('0120851')->is_valid_number, '秋田県湯沢市吹張');
ok($zip->set_number('0120852')->is_valid_number, '秋田県湯沢市荒町');
ok($zip->set_number('0120853')->is_valid_number, '秋田県湯沢市新町');
ok($zip->set_number('0120854')->is_valid_number, '秋田県湯沢市鳶ケ沢山');
ok($zip->set_number('0120855')->is_valid_number, '秋田県湯沢市愛宕町');
ok($zip->set_number('0120856')->is_valid_number, '秋田県湯沢市御囲地町');
ok($zip->set_number('0120857')->is_valid_number, '秋田県湯沢市千石町');
ok($zip->set_number('0120861')->is_valid_number, '秋田県湯沢市東松沢');
ok($zip->set_number('0120862')->is_valid_number, '秋田県湯沢市関口');
ok($zip->set_number('0120863')->is_valid_number, '秋田県湯沢市下関');
ok($zip->set_number('0120864')->is_valid_number, '秋田県湯沢市上関');
ok($zip->set_number('0120865')->is_valid_number, '秋田県湯沢市沼樋');
ok($zip->set_number('0120866')->is_valid_number, '秋田県湯沢市西松沢');
ok($zip->set_number('0120867')->is_valid_number, '秋田県湯沢市南台');
ok($zip->set_number('0120868')->is_valid_number, '秋田県湯沢市西愛宕町');
ok($zip->set_number('0120869')->is_valid_number, '秋田県湯沢市若葉町');
ok($zip->set_number('0121100')->is_valid_number, '秋田県雄勝郡羽後町以下に掲載がない場合');
ok($zip->set_number('0121101')->is_valid_number, '秋田県雄勝郡羽後町大沢');
ok($zip->set_number('0121102')->is_valid_number, '秋田県雄勝郡羽後町新町');
ok($zip->set_number('0121103')->is_valid_number, '秋田県雄勝郡羽後町林崎');
ok($zip->set_number('0121104')->is_valid_number, '秋田県雄勝郡羽後町堀内');
ok($zip->set_number('0121105')->is_valid_number, '秋田県雄勝郡羽後町水沢');
ok($zip->set_number('0121106')->is_valid_number, '秋田県雄勝郡羽後町払体');
ok($zip->set_number('0121111')->is_valid_number, '秋田県雄勝郡羽後町嶋田新田');
ok($zip->set_number('0121112')->is_valid_number, '秋田県雄勝郡羽後町睦合');
ok($zip->set_number('0121113')->is_valid_number, '秋田県雄勝郡羽後町郡山');
ok($zip->set_number('0121114')->is_valid_number, '秋田県雄勝郡羽後町糠塚');
ok($zip->set_number('0121115')->is_valid_number, '秋田県雄勝郡羽後町足田');
ok($zip->set_number('0121116')->is_valid_number, '秋田県雄勝郡羽後町高尾田');
ok($zip->set_number('0121121')->is_valid_number, '秋田県雄勝郡羽後町大久保');
ok($zip->set_number('0121122')->is_valid_number, '秋田県雄勝郡羽後町柏原');
ok($zip->set_number('0121123')->is_valid_number, '秋田県雄勝郡羽後町貝沢');
ok($zip->set_number('0121124')->is_valid_number, '秋田県雄勝郡羽後町赤袴');
ok($zip->set_number('0121125')->is_valid_number, '秋田県雄勝郡羽後町野中');
ok($zip->set_number('0121126')->is_valid_number, '秋田県雄勝郡羽後町杉宮');
ok($zip->set_number('0121131')->is_valid_number, '秋田県雄勝郡羽後町西馬音内');
ok($zip->set_number('0121132')->is_valid_number, '秋田県雄勝郡羽後町大戸');
ok($zip->set_number('0121133')->is_valid_number, '秋田県雄勝郡羽後町床舞');
ok($zip->set_number('0121134')->is_valid_number, '秋田県雄勝郡羽後町田沢');
ok($zip->set_number('0121135')->is_valid_number, '秋田県雄勝郡羽後町鹿内');
ok($zip->set_number('0121136')->is_valid_number, '秋田県雄勝郡羽後町飯沢');
ok($zip->set_number('0121137')->is_valid_number, '秋田県雄勝郡羽後町西馬音内堀回');
ok($zip->set_number('0121241')->is_valid_number, '秋田県雄勝郡羽後町田代');
ok($zip->set_number('0121242')->is_valid_number, '秋田県雄勝郡羽後町上到米');
ok($zip->set_number('0121243')->is_valid_number, '秋田県雄勝郡羽後町軽井沢');
ok($zip->set_number('0121351')->is_valid_number, '秋田県雄勝郡羽後町下仙道');
ok($zip->set_number('0121352')->is_valid_number, '秋田県雄勝郡羽後町中仙道');
ok($zip->set_number('0121353')->is_valid_number, '秋田県雄勝郡羽後町上仙道');
ok($zip->set_number('0130000')->is_valid_number, '秋田県横手市以下に掲載がない場合');
ok($zip->set_number('0130001')->is_valid_number, '秋田県横手市杉沢');
ok($zip->set_number('0130002')->is_valid_number, '秋田県横手市追廻');
ok($zip->set_number('0130003')->is_valid_number, '秋田県横手市台所町');
ok($zip->set_number('0130004')->is_valid_number, '秋田県横手市明永町');
ok($zip->set_number('0130005')->is_valid_number, '秋田県横手市幸町');
ok($zip->set_number('0130006')->is_valid_number, '秋田県横手市新坂町');
ok($zip->set_number('0130007')->is_valid_number, '秋田県横手市大鳥町');
ok($zip->set_number('0130008')->is_valid_number, '秋田県横手市睦成');
ok($zip->set_number('0130011')->is_valid_number, '秋田県横手市城西町');
ok($zip->set_number('0130012')->is_valid_number, '秋田県横手市城山町');
ok($zip->set_number('0130013')->is_valid_number, '秋田県横手市城南町');
ok($zip->set_number('0130014')->is_valid_number, '秋田県横手市上内町');
ok($zip->set_number('0130015')->is_valid_number, '秋田県横手市羽黒町');
ok($zip->set_number('0130016')->is_valid_number, '秋田県横手市根岸町');
ok($zip->set_number('0130017')->is_valid_number, '秋田県横手市蛇の崎町');
ok($zip->set_number('0130018')->is_valid_number, '秋田県横手市本町');
ok($zip->set_number('0130019')->is_valid_number, '秋田県横手市二葉町');
ok($zip->set_number('0130021')->is_valid_number, '秋田県横手市大町');
ok($zip->set_number('0130022')->is_valid_number, '秋田県横手市四日町');
ok($zip->set_number('0130023')->is_valid_number, '秋田県横手市中央町');
ok($zip->set_number('0130024')->is_valid_number, '秋田県横手市田中町');
ok($zip->set_number('0130025')->is_valid_number, '秋田県横手市寿町');
ok($zip->set_number('0130026')->is_valid_number, '秋田県横手市大水戸町');
ok($zip->set_number('0130027')->is_valid_number, '秋田県横手市平城町');
ok($zip->set_number('0130028')->is_valid_number, '秋田県横手市朝倉町');
ok($zip->set_number('0130031')->is_valid_number, '秋田県横手市鍛冶町');
ok($zip->set_number('0130032')->is_valid_number, '秋田県横手市清川町');
ok($zip->set_number('0130033')->is_valid_number, '秋田県横手市旭川');
ok($zip->set_number('0130034')->is_valid_number, '秋田県横手市本郷町');
ok($zip->set_number('0130035')->is_valid_number, '秋田県横手市平和町');
ok($zip->set_number('0130036')->is_valid_number, '秋田県横手市駅前町');
ok($zip->set_number('0130037')->is_valid_number, '秋田県横手市前郷二番町');
ok($zip->set_number('0130038')->is_valid_number, '秋田県横手市前郷一番町');
ok($zip->set_number('0130041')->is_valid_number, '秋田県横手市大沢');
ok($zip->set_number('0130042')->is_valid_number, '秋田県横手市前郷');
ok($zip->set_number('0130043')->is_valid_number, '秋田県横手市安田');
ok($zip->set_number('0130044')->is_valid_number, '秋田県横手市横山町');
ok($zip->set_number('0130045')->is_valid_number, '秋田県横手市南町');
ok($zip->set_number('0130046')->is_valid_number, '秋田県横手市神明町');
ok($zip->set_number('0130047')->is_valid_number, '秋田県横手市松原町');
ok($zip->set_number('0130048')->is_valid_number, '秋田県横手市安田原町');
ok($zip->set_number('0130049')->is_valid_number, '秋田県横手市駅西');
ok($zip->set_number('0130051')->is_valid_number, '秋田県横手市大屋新町');
ok($zip->set_number('0130052')->is_valid_number, '秋田県横手市大屋寺内');
ok($zip->set_number('0130053')->is_valid_number, '秋田県横手市外目');
ok($zip->set_number('0130054')->is_valid_number, '秋田県横手市柳田');
ok($zip->set_number('0130055')->is_valid_number, '秋田県横手市朝日が丘');
ok($zip->set_number('0130056')->is_valid_number, '秋田県横手市清水町新田');
ok($zip->set_number('0130060')->is_valid_number, '秋田県横手市条里');
ok($zip->set_number('0130061')->is_valid_number, '秋田県横手市横手町');
ok($zip->set_number('0130062')->is_valid_number, '秋田県横手市駅南');
ok($zip->set_number('0130063')->is_valid_number, '秋田県横手市婦気大堤');
ok($zip->set_number('0130064')->is_valid_number, '秋田県横手市赤坂');
ok($zip->set_number('0130065')->is_valid_number, '秋田県横手市猪岡');
ok($zip->set_number('0130066')->is_valid_number, '秋田県横手市塚堀');
ok($zip->set_number('0130068')->is_valid_number, '秋田県横手市梅の木町');
ok($zip->set_number('0130069')->is_valid_number, '秋田県横手市三枚橋');
ok($zip->set_number('0130071')->is_valid_number, '秋田県横手市八幡');
ok($zip->set_number('0130072')->is_valid_number, '秋田県横手市卸町');
ok($zip->set_number('0130073')->is_valid_number, '秋田県横手市赤川');
ok($zip->set_number('0130074')->is_valid_number, '秋田県横手市三本柳');
ok($zip->set_number('0130075')->is_valid_number, '秋田県横手市静町');
ok($zip->set_number('0130076')->is_valid_number, '秋田県横手市杉目');
ok($zip->set_number('0130101')->is_valid_number, '秋田県横手市平鹿町上吉田');
ok($zip->set_number('0130102')->is_valid_number, '秋田県横手市平鹿町醍醐');
ok($zip->set_number('0130103')->is_valid_number, '秋田県横手市平鹿町下鍋倉');
ok($zip->set_number('0130104')->is_valid_number, '秋田県横手市平鹿町樽見内');
ok($zip->set_number('0130105')->is_valid_number, '秋田県横手市平鹿町浅舞');
ok($zip->set_number('0130106')->is_valid_number, '秋田県横手市平鹿町中吉田');
ok($zip->set_number('0130107')->is_valid_number, '秋田県横手市平鹿町下吉田');
ok($zip->set_number('0130201')->is_valid_number, '秋田県横手市雄物川町会塚');
ok($zip->set_number('0130202')->is_valid_number, '秋田県横手市雄物川町砂子田');
ok($zip->set_number('0130203')->is_valid_number, '秋田県横手市雄物川町東里');
ok($zip->set_number('0130204')->is_valid_number, '秋田県横手市雄物川町谷地新田');
ok($zip->set_number('0130205')->is_valid_number, '秋田県横手市雄物川町今宿');
ok($zip->set_number('0130206')->is_valid_number, '秋田県横手市雄物川町二井山');
ok($zip->set_number('0130207')->is_valid_number, '秋田県横手市雄物川町矢神');
ok($zip->set_number('0130208')->is_valid_number, '秋田県横手市雄物川町沼館');
ok($zip->set_number('0130211')->is_valid_number, '秋田県横手市雄物川町深井');
ok($zip->set_number('0130212')->is_valid_number, '秋田県横手市雄物川町造山');
ok($zip->set_number('0130213')->is_valid_number, '秋田県横手市雄物川町南形');
ok($zip->set_number('0130214')->is_valid_number, '秋田県横手市雄物川町柏木');
ok($zip->set_number('0130215')->is_valid_number, '秋田県横手市雄物川町常野');
ok($zip->set_number('0130216')->is_valid_number, '秋田県横手市雄物川町西野');
ok($zip->set_number('0130217')->is_valid_number, '秋田県横手市雄物川町道地');
ok($zip->set_number('0130218')->is_valid_number, '秋田県横手市雄物川町大沢');
ok($zip->set_number('0130301')->is_valid_number, '秋田県横手市大雄福島');
ok($zip->set_number('0130302')->is_valid_number, '秋田県横手市大雄新町北');
ok($zip->set_number('0130303')->is_valid_number, '秋田県横手市大雄福島南');
ok($zip->set_number('0130304')->is_valid_number, '秋田県横手市大雄新町南');
ok($zip->set_number('0130305')->is_valid_number, '秋田県横手市大雄柏木南');
ok($zip->set_number('0130306')->is_valid_number, '秋田県横手市大雄田村');
ok($zip->set_number('0130307')->is_valid_number, '秋田県横手市大雄新町東');
ok($zip->set_number('0130308')->is_valid_number, '秋田県横手市大雄佐加里');
ok($zip->set_number('0130309')->is_valid_number, '秋田県横手市大雄佐加里南');
ok($zip->set_number('0130311')->is_valid_number, '秋田県横手市大雄中野東');
ok($zip->set_number('0130312')->is_valid_number, '秋田県横手市大雄中野');
ok($zip->set_number('0130313')->is_valid_number, '秋田県横手市大雄大森道北');
ok($zip->set_number('0130314')->is_valid_number, '秋田県横手市大雄傾城塚');
ok($zip->set_number('0130315')->is_valid_number, '秋田県横手市大雄下根田谷地');
ok($zip->set_number('0130316')->is_valid_number, '秋田県横手市大雄潤井谷地');
ok($zip->set_number('0130317')->is_valid_number, '秋田県横手市大雄大戸川端');
ok($zip->set_number('0130318')->is_valid_number, '秋田県横手市大雄根田谷地南');
ok($zip->set_number('0130319')->is_valid_number, '秋田県横手市大雄四ツ屋東');
ok($zip->set_number('0130321')->is_valid_number, '秋田県横手市大雄根田谷地西');
ok($zip->set_number('0130322')->is_valid_number, '秋田県横手市大雄伝蔵村');
ok($zip->set_number('0130323')->is_valid_number, '秋田県横手市大雄根田谷地東');
ok($zip->set_number('0130324')->is_valid_number, '秋田県横手市大雄根田谷地');
ok($zip->set_number('0130325')->is_valid_number, '秋田県横手市大雄田根森東');
ok($zip->set_number('0130326')->is_valid_number, '秋田県横手市大雄上田村東');
ok($zip->set_number('0130327')->is_valid_number, '秋田県横手市大雄焼野');
ok($zip->set_number('0130331')->is_valid_number, '秋田県横手市大雄東高津野');
ok($zip->set_number('0130332')->is_valid_number, '秋田県横手市大雄新町西野添');
ok($zip->set_number('0130333')->is_valid_number, '秋田県横手市大雄新町西');
ok($zip->set_number('0130334')->is_valid_number, '秋田県横手市大雄新町');
ok($zip->set_number('0130335')->is_valid_number, '秋田県横手市大雄折橋');
ok($zip->set_number('0130336')->is_valid_number, '秋田県横手市大雄傾城塚南');
ok($zip->set_number('0130337')->is_valid_number, '秋田県横手市大雄折橋南');
ok($zip->set_number('0130338')->is_valid_number, '秋田県横手市大雄耳取西');
ok($zip->set_number('0130339')->is_valid_number, '秋田県横手市大雄耳取');
ok($zip->set_number('0130341')->is_valid_number, '秋田県横手市大雄四ッ屋');
ok($zip->set_number('0130342')->is_valid_number, '秋田県横手市大雄精兵村');
ok($zip->set_number('0130343')->is_valid_number, '秋田県横手市大雄田根森西');
ok($zip->set_number('0130344')->is_valid_number, '秋田県横手市大雄精兵西');
ok($zip->set_number('0130345')->is_valid_number, '秋田県横手市大雄本庄道北堰間');
ok($zip->set_number('0130346')->is_valid_number, '秋田県横手市大雄四ツ屋西');
ok($zip->set_number('0130347')->is_valid_number, '秋田県横手市大雄本庄道南');
ok($zip->set_number('0130348')->is_valid_number, '秋田県横手市大雄田根森');
ok($zip->set_number('0130349')->is_valid_number, '秋田県横手市大雄上田村西');
ok($zip->set_number('0130351')->is_valid_number, '秋田県横手市大雄上田村');
ok($zip->set_number('0130352')->is_valid_number, '秋田県横手市大雄一ノ関東');
ok($zip->set_number('0130353')->is_valid_number, '秋田県横手市大雄一ノ関');
ok($zip->set_number('0130354')->is_valid_number, '秋田県横手市大雄狐塚');
ok($zip->set_number('0130355')->is_valid_number, '秋田県横手市大雄上桜森');
ok($zip->set_number('0130356')->is_valid_number, '秋田県横手市大雄一ノ関南');
ok($zip->set_number('0130357')->is_valid_number, '秋田県横手市大雄向東');
ok($zip->set_number('0130358')->is_valid_number, '秋田県横手市大雄向');
ok($zip->set_number('0130359')->is_valid_number, '秋田県横手市大雄柏木');
ok($zip->set_number('0130361')->is_valid_number, '秋田県横手市大雄柏木西');
ok($zip->set_number('0130362')->is_valid_number, '秋田県横手市大雄柏木下');
ok($zip->set_number('0130363')->is_valid_number, '秋田県横手市大雄桜森西');
ok($zip->set_number('0130364')->is_valid_number, '秋田県横手市大雄袋谷地');
ok($zip->set_number('0130365')->is_valid_number, '秋田県横手市大雄鍛治村');
ok($zip->set_number('0130371')->is_valid_number, '秋田県横手市大雄文蔵開');
ok($zip->set_number('0130372')->is_valid_number, '秋田県横手市大雄上田村南');
ok($zip->set_number('0130373')->is_valid_number, '秋田県横手市大雄八柏谷地');
ok($zip->set_number('0130374')->is_valid_number, '秋田県横手市大雄八柏中村東');
ok($zip->set_number('0130375')->is_valid_number, '秋田県横手市大雄八柏釜蓋');
ok($zip->set_number('0130376')->is_valid_number, '秋田県横手市大雄八柏馬道添');
ok($zip->set_number('0130377')->is_valid_number, '秋田県横手市大雄八柏中村');
ok($zip->set_number('0130378')->is_valid_number, '秋田県横手市大雄八柏街道添');
ok($zip->set_number('0130379')->is_valid_number, '秋田県横手市大雄八柏家間');
ok($zip->set_number('0130381')->is_valid_number, '秋田県横手市大雄八柏下村');
ok($zip->set_number('0130382')->is_valid_number, '秋田県横手市大雄上堰東');
ok($zip->set_number('0130383')->is_valid_number, '秋田県横手市大雄八柏村西');
ok($zip->set_number('0130384')->is_valid_number, '秋田県横手市大雄八柏村表');
ok($zip->set_number('0130385')->is_valid_number, '秋田県横手市大雄万貝');
ok($zip->set_number('0130402')->is_valid_number, '秋田県横手市大雄八柏');
ok($zip->set_number('0130404')->is_valid_number, '秋田県横手市大雄上柏木');
ok($zip->set_number('0130405')->is_valid_number, '秋田県横手市大雄南四津屋');
ok($zip->set_number('0130406')->is_valid_number, '秋田県横手市大雄西四津屋');
ok($zip->set_number('0130407')->is_valid_number, '秋田県横手市大雄四津屋下');
ok($zip->set_number('0130408')->is_valid_number, '秋田県横手市大雄北四津屋');
ok($zip->set_number('0130409')->is_valid_number, '秋田県横手市大雄東四津屋');
ok($zip->set_number('0130411')->is_valid_number, '秋田県横手市大雄剰水東');
ok($zip->set_number('0130412')->is_valid_number, '秋田県横手市大雄剰水');
ok($zip->set_number('0130413')->is_valid_number, '秋田県横手市大雄宮田');
ok($zip->set_number('0130414')->is_valid_number, '秋田県横手市大雄藤巻');
ok($zip->set_number('0130415')->is_valid_number, '秋田県横手市大雄藤巻西');
ok($zip->set_number('0130416')->is_valid_number, '秋田県横手市大雄藤巻中島');
ok($zip->set_number('0130417')->is_valid_number, '秋田県横手市大雄六町下');
ok($zip->set_number('0130418')->is_valid_number, '秋田県横手市大雄六町東');
ok($zip->set_number('0130419')->is_valid_number, '秋田県横手市大雄六町');
ok($zip->set_number('0130421')->is_valid_number, '秋田県横手市大雄江原');
ok($zip->set_number('0130422')->is_valid_number, '秋田県横手市大雄南阿気');
ok($zip->set_number('0130423')->is_valid_number, '秋田県横手市大雄土井尻');
ok($zip->set_number('0130424')->is_valid_number, '秋田県横手市大雄中館合');
ok($zip->set_number('0130425')->is_valid_number, '秋田県横手市大雄西館合');
ok($zip->set_number('0130426')->is_valid_number, '秋田県横手市大雄木戸口');
ok($zip->set_number('0130427')->is_valid_number, '秋田県横手市大雄阿気');
ok($zip->set_number('0130428')->is_valid_number, '秋田県横手市大雄鶴巻田');
ok($zip->set_number('0130429')->is_valid_number, '秋田県横手市大雄宮小路');
ok($zip->set_number('0130431')->is_valid_number, '秋田県横手市大雄牛中島');
ok($zip->set_number('0130432')->is_valid_number, '秋田県横手市大雄東中島');
ok($zip->set_number('0130433')->is_valid_number, '秋田県横手市大雄西中島');
ok($zip->set_number('0130434')->is_valid_number, '秋田県横手市大雄山王');
ok($zip->set_number('0130435')->is_valid_number, '秋田県横手市大雄木戸口西');
ok($zip->set_number('0130436')->is_valid_number, '秋田県横手市大雄小林西');
ok($zip->set_number('0130437')->is_valid_number, '秋田県横手市大雄小林');
ok($zip->set_number('0130438')->is_valid_number, '秋田県横手市大雄木戸口下');
ok($zip->set_number('0130439')->is_valid_number, '秋田県横手市大雄山王西');
ok($zip->set_number('0130441')->is_valid_number, '秋田県横手市大雄野中');
ok($zip->set_number('0130442')->is_valid_number, '秋田県横手市大雄高津野下');
ok($zip->set_number('0130443')->is_valid_number, '秋田県横手市大雄高津野');
ok($zip->set_number('0130444')->is_valid_number, '秋田県横手市大雄向田東');
ok($zip->set_number('0130445')->is_valid_number, '秋田県横手市大雄向田');
ok($zip->set_number('0130446')->is_valid_number, '秋田県横手市大雄乗阿気');
ok($zip->set_number('0130447')->is_valid_number, '秋田県横手市大雄阿久戸');
ok($zip->set_number('0130448')->is_valid_number, '秋田県横手市大雄乗阿気下');
ok($zip->set_number('0130451')->is_valid_number, '秋田県横手市大雄折橋西');
ok($zip->set_number('0130452')->is_valid_number, '秋田県横手市大雄大関');
ok($zip->set_number('0130453')->is_valid_number, '秋田県横手市大雄三村北');
ok($zip->set_number('0130454')->is_valid_number, '秋田県横手市大雄大谷地');
ok($zip->set_number('0130455')->is_valid_number, '秋田県横手市大雄大谷地西');
ok($zip->set_number('0130456')->is_valid_number, '秋田県横手市大雄大慈寺前');
ok($zip->set_number('0130457')->is_valid_number, '秋田県横手市大雄大慈寺東');
ok($zip->set_number('0130458')->is_valid_number, '秋田県横手市大雄大慈寺谷地');
ok($zip->set_number('0130459')->is_valid_number, '秋田県横手市大雄赤沼');
ok($zip->set_number('0130461')->is_valid_number, '秋田県横手市大雄三村東');
ok($zip->set_number('0130462')->is_valid_number, '秋田県横手市大雄樋脇');
ok($zip->set_number('0130463')->is_valid_number, '秋田県横手市大雄石持前');
ok($zip->set_number('0130464')->is_valid_number, '秋田県横手市大雄石持');
ok($zip->set_number('0130465')->is_valid_number, '秋田県横手市大雄石持下');
ok($zip->set_number('0130466')->is_valid_number, '秋田県横手市大雄三村');
ok($zip->set_number('0130467')->is_valid_number, '秋田県横手市大雄三村西');
ok($zip->set_number('0130468')->is_valid_number, '秋田県横手市大雄中谷地');
ok($zip->set_number('0130471')->is_valid_number, '秋田県横手市大雄板橋堰添');
ok($zip->set_number('0130472')->is_valid_number, '秋田県横手市大雄東阿気');
ok($zip->set_number('0130473')->is_valid_number, '秋田県横手市大雄東桜森');
ok($zip->set_number('0130474')->is_valid_number, '秋田県横手市大雄桜森');
ok($zip->set_number('0130475')->is_valid_number, '秋田県横手市大雄桜森前');
ok($zip->set_number('0130476')->is_valid_number, '秋田県横手市大雄西桜森');
ok($zip->set_number('0130477')->is_valid_number, '秋田県横手市大雄桜森東');
ok($zip->set_number('0130481')->is_valid_number, '秋田県横手市雄物川町薄井');
ok($zip->set_number('0130482')->is_valid_number, '秋田県横手市大雄平柳');
ok($zip->set_number('0130483')->is_valid_number, '秋田県横手市大雄島田');
ok($zip->set_number('0130484')->is_valid_number, '秋田県横手市大雄新処');
ok($zip->set_number('0130485')->is_valid_number, '秋田県横手市大雄下新処');
ok($zip->set_number('0130486')->is_valid_number, '秋田県横手市大雄田町');
ok($zip->set_number('0130487')->is_valid_number, '秋田県横手市大雄下田町');
ok($zip->set_number('0130488')->is_valid_number, '秋田県横手市大雄東館合');
ok($zip->set_number('0130501')->is_valid_number, '秋田県横手市大森町板井田');
ok($zip->set_number('0130502')->is_valid_number, '秋田県横手市大森町袴形');
ok($zip->set_number('0130503')->is_valid_number, '秋田県横手市大森町十日町');
ok($zip->set_number('0130511')->is_valid_number, '秋田県横手市大森町牛中島');
ok($zip->set_number('0130512')->is_valid_number, '秋田県横手市大森町湯ノ沢');
ok($zip->set_number('0130513')->is_valid_number, '秋田県横手市大森町湯ノ島');
ok($zip->set_number('0130514')->is_valid_number, '秋田県横手市大森町大中島');
ok($zip->set_number('0130515')->is_valid_number, '秋田県横手市大森町西中島');
ok($zip->set_number('0130516')->is_valid_number, '秋田県横手市大森町東中島');
ok($zip->set_number('0130517')->is_valid_number, '秋田県横手市大森町高口下水戸堤');
ok($zip->set_number('0130518')->is_valid_number, '秋田県横手市大森町文天鏡田');
ok($zip->set_number('0130519')->is_valid_number, '秋田県横手市大森町持向');
ok($zip->set_number('0130521')->is_valid_number, '秋田県横手市大森町大森');
ok($zip->set_number('0130522')->is_valid_number, '秋田県横手市大森町町回');
ok($zip->set_number('0130523')->is_valid_number, '秋田県横手市大森町堂林');
ok($zip->set_number('0130524')->is_valid_number, '秋田県横手市大森町清水上');
ok($zip->set_number('0130525')->is_valid_number, '秋田県横手市大森町菅生田');
ok($zip->set_number('0130526')->is_valid_number, '秋田県横手市大森町西野');
ok($zip->set_number('0130531')->is_valid_number, '秋田県横手市大森町佐渡');
ok($zip->set_number('0130532')->is_valid_number, '秋田県横手市大森町久保');
ok($zip->set_number('0130533')->is_valid_number, '秋田県横手市大森町中田');
ok($zip->set_number('0130534')->is_valid_number, '秋田県横手市大森町峠町頭');
ok($zip->set_number('0130535')->is_valid_number, '秋田県横手市大森町町田');
ok($zip->set_number('0130536')->is_valid_number, '秋田県横手市大森町真山');
ok($zip->set_number('0130541')->is_valid_number, '秋田県横手市大森町中嶋');
ok($zip->set_number('0130542')->is_valid_number, '秋田県横手市大森町高野中島');
ok($zip->set_number('0130543')->is_valid_number, '秋田県横手市大森町本郷');
ok($zip->set_number('0130544')->is_valid_number, '秋田県横手市大森町長助巻');
ok($zip->set_number('0130545')->is_valid_number, '秋田県横手市大森町鯲沼');
ok($zip->set_number('0130546')->is_valid_number, '秋田県横手市大森町牛ケ沢');
ok($zip->set_number('0130551')->is_valid_number, '秋田県横手市大森町猿田');
ok($zip->set_number('0130552')->is_valid_number, '秋田県横手市大森町上溝');
ok($zip->set_number('0130561')->is_valid_number, '秋田県横手市大森町八沢木');
ok($zip->set_number('0130562')->is_valid_number, '秋田県横手市大森町坂部');
ok($zip->set_number('0130811')->is_valid_number, '秋田県横手市安本');
ok($zip->set_number('0130812')->is_valid_number, '秋田県横手市金沢本町');
ok($zip->set_number('0130813')->is_valid_number, '秋田県横手市金沢');
ok($zip->set_number('0130814')->is_valid_number, '秋田県横手市金沢中野');
ok($zip->set_number('0130821')->is_valid_number, '秋田県横手市上境');
ok($zip->set_number('0130822')->is_valid_number, '秋田県横手市上八丁');
ok($zip->set_number('0130823')->is_valid_number, '秋田県横手市下八丁');
ok($zip->set_number('0130824')->is_valid_number, '秋田県横手市下境');
ok($zip->set_number('0130825')->is_valid_number, '秋田県横手市百万刈');
ok($zip->set_number('0130826')->is_valid_number, '秋田県横手市黒川');
ok($zip->set_number('0140000')->is_valid_number, '秋田県大仙市以下に掲載がない場合');
ok($zip->set_number('0140001')->is_valid_number, '秋田県大仙市花館');
ok($zip->set_number('0140002')->is_valid_number, '秋田県大仙市花館上町');
ok($zip->set_number('0140003')->is_valid_number, '秋田県大仙市美原町');
ok($zip->set_number('0140004')->is_valid_number, '秋田県大仙市泉町');
ok($zip->set_number('0140005')->is_valid_number, '秋田県大仙市花館柳町');
ok($zip->set_number('0140006')->is_valid_number, '秋田県大仙市花館中町');
ok($zip->set_number('0140011')->is_valid_number, '秋田県大仙市富士見町');
ok($zip->set_number('0140012')->is_valid_number, '秋田県大仙市幸町');
ok($zip->set_number('0140013')->is_valid_number, '秋田県大仙市朝日町');
ok($zip->set_number('0140014')->is_valid_number, '秋田県大仙市大曲福住町');
ok($zip->set_number('0140015')->is_valid_number, '秋田県大仙市大曲白金町');
ok($zip->set_number('0140016')->is_valid_number, '秋田県大仙市若竹町');
ok($zip->set_number('0140017')->is_valid_number, '秋田県大仙市佐野町');
ok($zip->set_number('0140021')->is_valid_number, '秋田県大仙市福田町');
ok($zip->set_number('0140022')->is_valid_number, '秋田県大仙市大花町');
ok($zip->set_number('0140023')->is_valid_number, '秋田県大仙市大曲黒瀬町');
ok($zip->set_number('0140024')->is_valid_number, '秋田県大仙市大曲中通町');
ok($zip->set_number('0140025')->is_valid_number, '秋田県大仙市大曲大町');
ok($zip->set_number('0140026')->is_valid_number, '秋田県大仙市大曲丸の内町');
ok($zip->set_number('0140027')->is_valid_number, '秋田県大仙市大曲通町');
ok($zip->set_number('0140031')->is_valid_number, '秋田県大仙市大曲');
ok($zip->set_number('0140032')->is_valid_number, '秋田県大仙市東川');
ok($zip->set_number('0140033')->is_valid_number, '秋田県大仙市和合');
ok($zip->set_number('0140034')->is_valid_number, '秋田県大仙市大曲住吉町');
ok($zip->set_number('0140041')->is_valid_number, '秋田県大仙市大曲丸子町');
ok($zip->set_number('0140042')->is_valid_number, '秋田県大仙市大曲福見町');
ok($zip->set_number('0140043')->is_valid_number, '秋田県大仙市大曲戸巻町');
ok($zip->set_number('0140044')->is_valid_number, '秋田県大仙市戸蒔');
ok($zip->set_number('0140045')->is_valid_number, '秋田県大仙市大曲若葉町');
ok($zip->set_number('0140046')->is_valid_number, '秋田県大仙市大曲田町');
ok($zip->set_number('0140047')->is_valid_number, '秋田県大仙市大曲須和町');
ok($zip->set_number('0140048')->is_valid_number, '秋田県大仙市大曲上大町');
ok($zip->set_number('0140051')->is_valid_number, '秋田県大仙市大曲浜町');
ok($zip->set_number('0140052')->is_valid_number, '秋田県大仙市大曲川原町');
ok($zip->set_number('0140053')->is_valid_number, '秋田県大仙市大曲花園町');
ok($zip->set_number('0140054')->is_valid_number, '秋田県大仙市大曲金谷町');
ok($zip->set_number('0140055')->is_valid_number, '秋田県大仙市大曲あけぼの町');
ok($zip->set_number('0140056')->is_valid_number, '秋田県大仙市大曲緑町');
ok($zip->set_number('0140057')->is_valid_number, '秋田県大仙市大曲船場町');
ok($zip->set_number('0140061')->is_valid_number, '秋田県大仙市大曲栄町');
ok($zip->set_number('0140062')->is_valid_number, '秋田県大仙市大曲上栄町');
ok($zip->set_number('0140063')->is_valid_number, '秋田県大仙市大曲日の出町');
ok($zip->set_number('0140064')->is_valid_number, '秋田県大仙市小貫高畑');
ok($zip->set_number('0140065')->is_valid_number, '秋田県大仙市下深井');
ok($zip->set_number('0140066')->is_valid_number, '秋田県大仙市川目');
ok($zip->set_number('0140067')->is_valid_number, '秋田県大仙市飯田');
ok($zip->set_number('0140068')->is_valid_number, '秋田県大仙市大曲飯田町');
ok($zip->set_number('0140071')->is_valid_number, '秋田県大仙市蛭川');
ok($zip->set_number('0140072')->is_valid_number, '秋田県大仙市大曲西根');
ok($zip->set_number('0140073')->is_valid_number, '秋田県大仙市内小友');
ok($zip->set_number('0140101')->is_valid_number, '秋田県大仙市松倉');
ok($zip->set_number('0140102')->is_valid_number, '秋田県大仙市四ツ屋');
ok($zip->set_number('0140103')->is_valid_number, '秋田県大仙市高関上郷');
ok($zip->set_number('0140104')->is_valid_number, '秋田県大仙市新谷地');
ok($zip->set_number('0140111')->is_valid_number, '秋田県大仙市横堀');
ok($zip->set_number('0140112')->is_valid_number, '秋田県大仙市板見内');
ok($zip->set_number('0140113')->is_valid_number, '秋田県大仙市堀見内');
ok($zip->set_number('0140114')->is_valid_number, '秋田県大仙市福田');
ok($zip->set_number('0140201')->is_valid_number, '秋田県大仙市下鶯野');
ok($zip->set_number('0140202')->is_valid_number, '秋田県大仙市上鶯野');
ok($zip->set_number('0140203')->is_valid_number, '秋田県大仙市北長野');
ok($zip->set_number('0140204')->is_valid_number, '秋田県大仙市清水');
ok($zip->set_number('0140205')->is_valid_number, '秋田県大仙市鑓見内');
ok($zip->set_number('0140206')->is_valid_number, '秋田県大仙市長戸呂');
ok($zip->set_number('0140207')->is_valid_number, '秋田県大仙市長野');
ok($zip->set_number('0140300')->is_valid_number, '秋田県仙北市以下に掲載がない場合');
ok($zip->set_number('0140301')->is_valid_number, '秋田県仙北市角館町広久内');
ok($zip->set_number('0140302')->is_valid_number, '秋田県仙北市角館町白岩');
ok($zip->set_number('0140303')->is_valid_number, '秋田県仙北市角館町薗田');
ok($zip->set_number('0140311')->is_valid_number, '秋田県仙北市角館町田町上丁');
ok($zip->set_number('0140312')->is_valid_number, '秋田県仙北市角館町田町下丁');
ok($zip->set_number('0140313')->is_valid_number, '秋田県仙北市角館町下岩瀬町');
ok($zip->set_number('0140315')->is_valid_number, '秋田県仙北市角館町下新町');
ok($zip->set_number('0140316')->is_valid_number, '秋田県仙北市角館町岩瀬町');
ok($zip->set_number('0140317')->is_valid_number, '秋田県仙北市角館町下中町');
ok($zip->set_number('0140318')->is_valid_number, '秋田県仙北市角館町中町');
ok($zip->set_number('0140321')->is_valid_number, '秋田県仙北市角館町西勝楽町');
ok($zip->set_number('0140322')->is_valid_number, '秋田県仙北市角館町七日町');
ok($zip->set_number('0140323')->is_valid_number, '秋田県仙北市角館町横町');
ok($zip->set_number('0140324')->is_valid_number, '秋田県仙北市角館町小人町');
ok($zip->set_number('0140325')->is_valid_number, '秋田県仙北市角館町東勝楽丁');
ok($zip->set_number('0140326')->is_valid_number, '秋田県仙北市角館町山根町');
ok($zip->set_number('0140327')->is_valid_number, '秋田県仙北市角館町上新町');
ok($zip->set_number('0140328')->is_valid_number, '秋田県仙北市角館町竹原町');
ok($zip->set_number('0140331')->is_valid_number, '秋田県仙北市角館町表町下丁');
ok($zip->set_number('0140332')->is_valid_number, '秋田県仙北市角館町歩行町');
ok($zip->set_number('0140333')->is_valid_number, '秋田県仙北市角館町川原町');
ok($zip->set_number('0140334')->is_valid_number, '秋田県仙北市角館町表町上丁');
ok($zip->set_number('0140335')->is_valid_number, '秋田県仙北市角館町細越町');
ok($zip->set_number('0140336')->is_valid_number, '秋田県仙北市角館町裏町');
ok($zip->set_number('0140337')->is_valid_number, '秋田県仙北市角館町古城');
ok($zip->set_number('0140341')->is_valid_number, '秋田県仙北市角館町雲然');
ok($zip->set_number('0140342')->is_valid_number, '秋田県仙北市角館町八割');
ok($zip->set_number('0140343')->is_valid_number, '秋田県仙北市角館町下延');
ok($zip->set_number('0140344')->is_valid_number, '秋田県仙北市角館町西長野');
ok($zip->set_number('0140345')->is_valid_number, '秋田県仙北市角館町山谷川崎');
ok($zip->set_number('0140346')->is_valid_number, '秋田県仙北市角館町川原');
ok($zip->set_number('0140347')->is_valid_number, '秋田県仙北市角館町小勝田');
ok($zip->set_number('0140351')->is_valid_number, '秋田県仙北市角館町古城山');
ok($zip->set_number('0140352')->is_valid_number, '秋田県仙北市角館町外ノ山');
ok($zip->set_number('0140353')->is_valid_number, '秋田県仙北市角館町西菅沢');
ok($zip->set_number('0140354')->is_valid_number, '秋田県仙北市角館町水ノ目沢');
ok($zip->set_number('0140355')->is_valid_number, '秋田県仙北市角館町外ノ山官有地');
ok($zip->set_number('0140356')->is_valid_number, '秋田県仙北市角館町花場');
ok($zip->set_number('0140357')->is_valid_number, '秋田県仙北市角館町花場下');
ok($zip->set_number('0140358')->is_valid_number, '秋田県仙北市角館町川原町後');
ok($zip->set_number('0140359')->is_valid_number, '秋田県仙北市角館町北野');
ok($zip->set_number('0140361')->is_valid_number, '秋田県仙北市角館町鳥木沢');
ok($zip->set_number('0140362')->is_valid_number, '秋田県仙北市角館町金山下');
ok($zip->set_number('0140363')->is_valid_number, '秋田県仙北市角館町下川原');
ok($zip->set_number('0140364')->is_valid_number, '秋田県仙北市角館町大中嶋');
ok($zip->set_number('0140365')->is_valid_number, '秋田県仙北市角館町菅沢');
ok($zip->set_number('0140366')->is_valid_number, '秋田県仙北市角館町下菅沢');
ok($zip->set_number('0140367')->is_valid_number, '秋田県仙北市角館町勝楽');
ok($zip->set_number('0140368')->is_valid_number, '秋田県仙北市角館町中菅沢');
ok($zip->set_number('0140369')->is_valid_number, '秋田県仙北市角館町上菅沢');
ok($zip->set_number('0140371')->is_valid_number, '秋田県仙北市角館町大風呂');
ok($zip->set_number('0140372')->is_valid_number, '秋田県仙北市角館町小館');
ok($zip->set_number('0140373')->is_valid_number, '秋田県仙北市角館町岩瀬');
ok($zip->set_number('0140374')->is_valid_number, '秋田県仙北市角館町上野');
ok($zip->set_number('0140375')->is_valid_number, '秋田県仙北市角館町岩瀬下タ野');
ok($zip->set_number('0140376')->is_valid_number, '秋田県仙北市角館町西下タ野');
ok($zip->set_number('0140377')->is_valid_number, '秋田県仙北市角館町西田');
ok($zip->set_number('0140378')->is_valid_number, '秋田県仙北市角館町西野川原');
ok($zip->set_number('0140379')->is_valid_number, '秋田県仙北市角館町西北野');
ok($zip->set_number('0140511')->is_valid_number, '秋田県仙北市西木町西明寺');
ok($zip->set_number('0140512')->is_valid_number, '秋田県仙北市西木町上荒井');
ok($zip->set_number('0140513')->is_valid_number, '秋田県仙北市西木町小渕野');
ok($zip->set_number('0140514')->is_valid_number, '秋田県仙北市西木町西荒井');
ok($zip->set_number('0140515')->is_valid_number, '秋田県仙北市西木町門屋');
ok($zip->set_number('0140516')->is_valid_number, '秋田県仙北市西木町小山田');
ok($zip->set_number('0140601')->is_valid_number, '秋田県仙北市西木町上桧木内');
ok($zip->set_number('0140602')->is_valid_number, '秋田県仙北市西木町桧木内');
ok($zip->set_number('0140711')->is_valid_number, '秋田県大仙市豊川');
ok($zip->set_number('0140712')->is_valid_number, '秋田県大仙市豊岡');
ok($zip->set_number('0140713')->is_valid_number, '秋田県大仙市栗沢');
ok($zip->set_number('0140714')->is_valid_number, '秋田県大仙市大神成');
ok($zip->set_number('0140801')->is_valid_number, '秋田県大仙市戸地谷');
ok($zip->set_number('0140802')->is_valid_number, '秋田県大仙市払田');
ok($zip->set_number('0140803')->is_valid_number, '秋田県大仙市上野田');
ok($zip->set_number('0140804')->is_valid_number, '秋田県大仙市橋本');
ok($zip->set_number('0140805')->is_valid_number, '秋田県大仙市高梨');
ok($zip->set_number('0141111')->is_valid_number, '秋田県仙北市田沢湖岡崎');
ok($zip->set_number('0141112')->is_valid_number, '秋田県仙北市田沢湖梅沢');
ok($zip->set_number('0141113')->is_valid_number, '秋田県仙北市田沢湖卒田');
ok($zip->set_number('0141114')->is_valid_number, '秋田県仙北市田沢湖神代');
ok($zip->set_number('0141115')->is_valid_number, '秋田県仙北市田沢湖小松');
ok($zip->set_number('0141116')->is_valid_number, '秋田県仙北市田沢湖角館東前郷');
ok($zip->set_number('0141201')->is_valid_number, '秋田県仙北市田沢湖生保内');
ok($zip->set_number('0141202')->is_valid_number, '秋田県仙北市田沢湖刺巻');
ok($zip->set_number('0141203')->is_valid_number, '秋田県仙北市田沢湖潟');
ok($zip->set_number('0141204')->is_valid_number, '秋田県仙北市田沢湖田沢');
ok($zip->set_number('0141205')->is_valid_number, '秋田県仙北市田沢湖玉川');
ok($zip->set_number('0141411')->is_valid_number, '秋田県大仙市六郷西根');
ok($zip->set_number('0141412')->is_valid_number, '秋田県大仙市藤木');
ok($zip->set_number('0141413')->is_valid_number, '秋田県大仙市角間川町');
ok($zip->set_number('0150000')->is_valid_number, '秋田県由利本荘市以下に掲載がない場合');
ok($zip->set_number('0150011')->is_valid_number, '秋田県由利本荘市石脇(その他)');
ok($zip->set_number('0150012')->is_valid_number, '秋田県由利本荘市石脇(田尻)');
ok($zip->set_number('0150013')->is_valid_number, '秋田県由利本荘市石脇(田尻野)');
ok($zip->set_number('0150014')->is_valid_number, '秋田県由利本荘市石脇(山ノ神)');
ok($zip->set_number('0150021')->is_valid_number, '秋田県由利本荘市大浦');
ok($zip->set_number('0150022')->is_valid_number, '秋田県由利本荘市内黒瀬');
ok($zip->set_number('0150023')->is_valid_number, '秋田県由利本荘市赤田');
ok($zip->set_number('0150024')->is_valid_number, '秋田県由利本荘市内越');
ok($zip->set_number('0150025')->is_valid_number, '秋田県由利本荘市山田');
ok($zip->set_number('0150031')->is_valid_number, '秋田県由利本荘市浜三川');
ok($zip->set_number('0150032')->is_valid_number, '秋田県由利本荘市松ケ崎');
ok($zip->set_number('0150033')->is_valid_number, '秋田県由利本荘市神沢');
ok($zip->set_number('0150034')->is_valid_number, '秋田県由利本荘市芦川');
ok($zip->set_number('0150035')->is_valid_number, '秋田県由利本荘市親川');
ok($zip->set_number('0150041')->is_valid_number, '秋田県由利本荘市薬師堂');
ok($zip->set_number('0150042')->is_valid_number, '秋田県由利本荘市埋田');
ok($zip->set_number('0150043')->is_valid_number, '秋田県由利本荘市宮内');
ok($zip->set_number('0150044')->is_valid_number, '秋田県由利本荘市玉ノ池');
ok($zip->set_number('0150045')->is_valid_number, '秋田県由利本荘市葛法');
ok($zip->set_number('0150046')->is_valid_number, '秋田県由利本荘市船岡');
ok($zip->set_number('0150047')->is_valid_number, '秋田県由利本荘市藤崎');
ok($zip->set_number('0150051')->is_valid_number, '秋田県由利本荘市川口');
ok($zip->set_number('0150052')->is_valid_number, '秋田県由利本荘市畑谷');
ok($zip->set_number('0150053')->is_valid_number, '秋田県由利本荘市福山');
ok($zip->set_number('0150054')->is_valid_number, '秋田県由利本荘市土谷(谷地)');
ok($zip->set_number('0150055')->is_valid_number, '秋田県由利本荘市土谷(その他)');
ok($zip->set_number('0150061')->is_valid_number, '秋田県由利本荘市二十六木');
ok($zip->set_number('0150062')->is_valid_number, '秋田県由利本荘市大中ノ沢');
ok($zip->set_number('0150063')->is_valid_number, '秋田県由利本荘市舘前');
ok($zip->set_number('0150064')->is_valid_number, '秋田県由利本荘市万願寺');
ok($zip->set_number('0150065')->is_valid_number, '秋田県由利本荘市荒町');
ok($zip->set_number('0150066')->is_valid_number, '秋田県由利本荘市金山');
ok($zip->set_number('0150067')->is_valid_number, '秋田県由利本荘市三条');
ok($zip->set_number('0150068')->is_valid_number, '秋田県由利本荘市南ノ股');
ok($zip->set_number('0150069')->is_valid_number, '秋田県由利本荘市北ノ股');
ok($zip->set_number('0150071')->is_valid_number, '秋田県由利本荘市赤沼町');
ok($zip->set_number('0150072')->is_valid_number, '秋田県由利本荘市裏尾崎町');
ok($zip->set_number('0150073')->is_valid_number, '秋田県由利本荘市笹道');
ok($zip->set_number('0150074')->is_valid_number, '秋田県由利本荘市桜小路');
ok($zip->set_number('0150075')->is_valid_number, '秋田県由利本荘市花畑町');
ok($zip->set_number('0150076')->is_valid_number, '秋田県由利本荘市東町');
ok($zip->set_number('0150077')->is_valid_number, '秋田県由利本荘市本田仲町');
ok($zip->set_number('0150078')->is_valid_number, '秋田県由利本荘市谷地町');
ok($zip->set_number('0150079')->is_valid_number, '秋田県由利本荘市赤沼下道');
ok($zip->set_number('0150081')->is_valid_number, '秋田県由利本荘市雪車町');
ok($zip->set_number('0150082')->is_valid_number, '秋田県由利本荘市宮沢');
ok($zip->set_number('0150083')->is_valid_number, '秋田県由利本荘市滝ノ沢');
ok($zip->set_number('0150084')->is_valid_number, '秋田県由利本荘市鮎瀬');
ok($zip->set_number('0150085')->is_valid_number, '秋田県由利本荘市烏川');
ok($zip->set_number('0150086')->is_valid_number, '秋田県由利本荘市舘');
ok($zip->set_number('0150087')->is_valid_number, '秋田県由利本荘市湯沢');
ok($zip->set_number('0150088')->is_valid_number, '秋田県由利本荘市柳生');
ok($zip->set_number('0150089')->is_valid_number, '秋田県由利本荘市鳥田目');
ok($zip->set_number('0150091')->is_valid_number, '秋田県由利本荘市大簗');
ok($zip->set_number('0150092')->is_valid_number, '秋田県由利本荘市山内(その他)');
ok($zip->set_number('0150093')->is_valid_number, '秋田県由利本荘市大沢');
ok($zip->set_number('0150094')->is_valid_number, '秋田県由利本荘市上野');
ok($zip->set_number('0150201')->is_valid_number, '秋田県由利本荘市東由利法内');
ok($zip->set_number('0150202')->is_valid_number, '秋田県由利本荘市東由利蔵');
ok($zip->set_number('0150211')->is_valid_number, '秋田県由利本荘市東由利老方');
ok($zip->set_number('0150221')->is_valid_number, '秋田県由利本荘市東由利舘合');
ok($zip->set_number('0150231')->is_valid_number, '秋田県由利本荘市東由利黒渕');
ok($zip->set_number('0150232')->is_valid_number, '秋田県由利本荘市東由利田代');
ok($zip->set_number('0150241')->is_valid_number, '秋田県由利本荘市東由利宿');
ok($zip->set_number('0150242')->is_valid_number, '秋田県由利本荘市東由利杉森');
ok($zip->set_number('0150243')->is_valid_number, '秋田県由利本荘市山内(三ツ方森)');
ok($zip->set_number('0150301')->is_valid_number, '秋田県由利本荘市飯沢');
ok($zip->set_number('0150302')->is_valid_number, '秋田県由利本荘市久保田');
ok($zip->set_number('0150303')->is_valid_number, '秋田県由利本荘市陳ケ森');
ok($zip->set_number('0150304')->is_valid_number, '秋田県由利本荘市曲沢');
ok($zip->set_number('0150311')->is_valid_number, '秋田県由利本荘市五十土');
ok($zip->set_number('0150312')->is_valid_number, '秋田県由利本荘市大水口');
ok($zip->set_number('0150313')->is_valid_number, '秋田県由利本荘市小菅野');
ok($zip->set_number('0150314')->is_valid_number, '秋田県由利本荘市東中沢');
ok($zip->set_number('0150321')->is_valid_number, '秋田県由利本荘市蟹沢');
ok($zip->set_number('0150322')->is_valid_number, '秋田県由利本荘市新上条');
ok($zip->set_number('0150323')->is_valid_number, '秋田県由利本荘市土倉');
ok($zip->set_number('0150324')->is_valid_number, '秋田県由利本荘市吉沢');
ok($zip->set_number('0150331')->is_valid_number, '秋田県由利本荘市川西');
ok($zip->set_number('0150332')->is_valid_number, '秋田県由利本荘市森子');
ok($zip->set_number('0150333')->is_valid_number, '秋田県由利本荘市山本');
ok($zip->set_number('0150341')->is_valid_number, '秋田県由利本荘市前郷');
ok($zip->set_number('0150351')->is_valid_number, '秋田県由利本荘市堰口');
ok($zip->set_number('0150352')->is_valid_number, '秋田県由利本荘市西沢');
ok($zip->set_number('0150353')->is_valid_number, '秋田県由利本荘市平石');
ok($zip->set_number('0150361')->is_valid_number, '秋田県由利本荘市黒沢');
ok($zip->set_number('0150362')->is_valid_number, '秋田県由利本荘市東鮎川');
ok($zip->set_number('0150363')->is_valid_number, '秋田県由利本荘市町村');
ok($zip->set_number('0150364')->is_valid_number, '秋田県由利本荘市南福田');
ok($zip->set_number('0150401')->is_valid_number, '秋田県由利本荘市矢島町田中町');
ok($zip->set_number('0150402')->is_valid_number, '秋田県由利本荘市矢島町矢島町');
ok($zip->set_number('0150403')->is_valid_number, '秋田県由利本荘市矢島町舘町');
ok($zip->set_number('0150404')->is_valid_number, '秋田県由利本荘市矢島町七日町');
ok($zip->set_number('0150411')->is_valid_number, '秋田県由利本荘市矢島町城内');
ok($zip->set_number('0150412')->is_valid_number, '秋田県由利本荘市矢島町川辺');
ok($zip->set_number('0150413')->is_valid_number, '秋田県由利本荘市矢島町木在');
ok($zip->set_number('0150414')->is_valid_number, '秋田県由利本荘市矢島町立石');
ok($zip->set_number('0150415')->is_valid_number, '秋田県由利本荘市矢島町新荘');
ok($zip->set_number('0150416')->is_valid_number, '秋田県由利本荘市矢島町坂之下');
ok($zip->set_number('0150417')->is_valid_number, '秋田県由利本荘市矢島町元町');
ok($zip->set_number('0150418')->is_valid_number, '秋田県由利本荘市矢島町荒沢');
ok($zip->set_number('0150501')->is_valid_number, '秋田県由利本荘市鳥海町伏見');
ok($zip->set_number('0150502')->is_valid_number, '秋田県由利本荘市鳥海町下川内');
ok($zip->set_number('0150503')->is_valid_number, '秋田県由利本荘市鳥海町栗沢');
ok($zip->set_number('0150504')->is_valid_number, '秋田県由利本荘市鳥海町上川内');
ok($zip->set_number('0150505')->is_valid_number, '秋田県由利本荘市鳥海町小川');
ok($zip->set_number('0150511')->is_valid_number, '秋田県由利本荘市鳥海町戈之神');
ok($zip->set_number('0150512')->is_valid_number, '秋田県由利本荘市鳥海町猿倉');
ok($zip->set_number('0150513')->is_valid_number, '秋田県由利本荘市鳥海町下直根');
ok($zip->set_number('0150514')->is_valid_number, '秋田県由利本荘市鳥海町中直根');
ok($zip->set_number('0150515')->is_valid_number, '秋田県由利本荘市鳥海町上直根');
ok($zip->set_number('0150516')->is_valid_number, '秋田県由利本荘市鳥海町百宅');
ok($zip->set_number('0150721')->is_valid_number, '秋田県由利本荘市鳥海町上笹子');
ok($zip->set_number('0150722')->is_valid_number, '秋田県由利本荘市鳥海町下笹子');
ok($zip->set_number('0150801')->is_valid_number, '秋田県由利本荘市美倉町');
ok($zip->set_number('0150802')->is_valid_number, '秋田県由利本荘市表尾崎町');
ok($zip->set_number('0150803')->is_valid_number, '秋田県由利本荘市中竪町');
ok($zip->set_number('0150804')->is_valid_number, '秋田県由利本荘市谷山小路');
ok($zip->set_number('0150807')->is_valid_number, '秋田県由利本荘市中横町');
ok($zip->set_number('0150808')->is_valid_number, '秋田県由利本荘市大門');
ok($zip->set_number('0150809')->is_valid_number, '秋田県由利本荘市本荘');
ok($zip->set_number('0150811')->is_valid_number, '秋田県由利本荘市桶屋町');
ok($zip->set_number('0150812')->is_valid_number, '秋田県由利本荘市鍛治町');
ok($zip->set_number('0150813')->is_valid_number, '秋田県由利本荘市日役町');
ok($zip->set_number('0150814')->is_valid_number, '秋田県由利本荘市後町');
ok($zip->set_number('0150815')->is_valid_number, '秋田県由利本荘市猟師町');
ok($zip->set_number('0150816')->is_valid_number, '秋田県由利本荘市大町');
ok($zip->set_number('0150817')->is_valid_number, '秋田県由利本荘市中町');
ok($zip->set_number('0150821')->is_valid_number, '秋田県由利本荘市肴町');
ok($zip->set_number('0150822')->is_valid_number, '秋田県由利本荘市田町');
ok($zip->set_number('0150823')->is_valid_number, '秋田県由利本荘市和泉町');
ok($zip->set_number('0150824')->is_valid_number, '秋田県由利本荘市古雪町');
ok($zip->set_number('0150825')->is_valid_number, '秋田県由利本荘市観音町');
ok($zip->set_number('0150826')->is_valid_number, '秋田県由利本荘市片町');
ok($zip->set_number('0150827')->is_valid_number, '秋田県由利本荘市浜ノ町');
ok($zip->set_number('0150831')->is_valid_number, '秋田県由利本荘市北裏地');
ok($zip->set_number('0150832')->is_valid_number, '秋田県由利本荘市下川原中島');
ok($zip->set_number('0150833')->is_valid_number, '秋田県由利本荘市巣組');
ok($zip->set_number('0150834')->is_valid_number, '秋田県由利本荘市岩渕下');
ok($zip->set_number('0150835')->is_valid_number, '秋田県由利本荘市八幡下');
ok($zip->set_number('0150836')->is_valid_number, '秋田県由利本荘市赤沼下');
ok($zip->set_number('0150837')->is_valid_number, '秋田県由利本荘市出戸町(赤沼下道)');
ok($zip->set_number('0150838')->is_valid_number, '秋田県由利本荘市梵天谷地');
ok($zip->set_number('0150839')->is_valid_number, '秋田県由利本荘市古川端');
ok($zip->set_number('0150840')->is_valid_number, '秋田県由利本荘市瀬越場');
ok($zip->set_number('0150841')->is_valid_number, '秋田県由利本荘市下大野');
ok($zip->set_number('0150842')->is_valid_number, '秋田県由利本荘市出戸上野');
ok($zip->set_number('0150843')->is_valid_number, '秋田県由利本荘市東梵天');
ok($zip->set_number('0150851')->is_valid_number, '秋田県由利本荘市中梵天');
ok($zip->set_number('0150852')->is_valid_number, '秋田県由利本荘市一番堰');
ok($zip->set_number('0150853')->is_valid_number, '秋田県由利本荘市松街道');
ok($zip->set_number('0150854')->is_valid_number, '秋田県由利本荘市上大野');
ok($zip->set_number('0150855')->is_valid_number, '秋田県由利本荘市二番堰');
ok($zip->set_number('0150856')->is_valid_number, '秋田県由利本荘市円正脇');
ok($zip->set_number('0150857')->is_valid_number, '秋田県由利本荘市寺後');
ok($zip->set_number('0150858')->is_valid_number, '秋田県由利本荘市西梵天');
ok($zip->set_number('0150861')->is_valid_number, '秋田県由利本荘市御門');
ok($zip->set_number('0150862')->is_valid_number, '秋田県由利本荘市小人町');
ok($zip->set_number('0150863')->is_valid_number, '秋田県由利本荘市不戻沢');
ok($zip->set_number('0150864')->is_valid_number, '秋田県由利本荘市大鍬町');
ok($zip->set_number('0150865')->is_valid_number, '秋田県由利本荘市西大鍬町');
ok($zip->set_number('0150866')->is_valid_number, '秋田県由利本荘市堤脇');
ok($zip->set_number('0150867')->is_valid_number, '秋田県由利本荘市千刈');
ok($zip->set_number('0150868')->is_valid_number, '秋田県由利本荘市大堤下');
ok($zip->set_number('0150869')->is_valid_number, '秋田県由利本荘市陳場岱');
ok($zip->set_number('0150871')->is_valid_number, '秋田県由利本荘市尾崎');
ok($zip->set_number('0150872')->is_valid_number, '秋田県由利本荘市瓦谷地');
ok($zip->set_number('0150873')->is_valid_number, '秋田県由利本荘市鶴沼');
ok($zip->set_number('0150874')->is_valid_number, '秋田県由利本荘市給人町');
ok($zip->set_number('0150875')->is_valid_number, '秋田県由利本荘市砂子下');
ok($zip->set_number('0150876')->is_valid_number, '秋田県由利本荘市井戸尻');
ok($zip->set_number('0150877')->is_valid_number, '秋田県由利本荘市濡浜北');
ok($zip->set_number('0150878')->is_valid_number, '秋田県由利本荘市観音森');
ok($zip->set_number('0150881')->is_valid_number, '秋田県由利本荘市切通');
ok($zip->set_number('0150882')->is_valid_number, '秋田県由利本荘市西小人町');
ok($zip->set_number('0150883')->is_valid_number, '秋田県由利本荘市下地ケ沢');
ok($zip->set_number('0150884')->is_valid_number, '秋田県由利本荘市狐森');
ok($zip->set_number('0150885')->is_valid_number, '秋田県由利本荘市水林');
ok($zip->set_number('0150886')->is_valid_number, '秋田県由利本荘市調練場');
ok($zip->set_number('0150887')->is_valid_number, '秋田県由利本荘市今野谷地');
ok($zip->set_number('0150888')->is_valid_number, '秋田県由利本荘市新組町');
ok($zip->set_number('0150889')->is_valid_number, '秋田県由利本荘市砂糖畑');
ok($zip->set_number('0150890')->is_valid_number, '秋田県由利本荘市船ケ台');
ok($zip->set_number('0150891')->is_valid_number, '秋田県由利本荘市小防ケ沢');
ok($zip->set_number('0150892')->is_valid_number, '秋田県由利本荘市蟻山');
ok($zip->set_number('0160000')->is_valid_number, '秋田県能代市以下に掲載がない場合');
ok($zip->set_number('0160001')->is_valid_number, '秋田県能代市外荒巻');
ok($zip->set_number('0160002')->is_valid_number, '秋田県能代市朴瀬');
ok($zip->set_number('0160003')->is_valid_number, '秋田県能代市荷八田');
ok($zip->set_number('0160004')->is_valid_number, '秋田県能代市吹越');
ok($zip->set_number('0160005')->is_valid_number, '秋田県能代市真壁地');
ok($zip->set_number('0160011')->is_valid_number, '秋田県能代市坂形');
ok($zip->set_number('0160012')->is_valid_number, '秋田県能代市比八田');
ok($zip->set_number('0160013')->is_valid_number, '秋田県能代市向能代');
ok($zip->set_number('0160014')->is_valid_number, '秋田県能代市落合');
ok($zip->set_number('0160015')->is_valid_number, '秋田県能代市須田');
ok($zip->set_number('0160016')->is_valid_number, '秋田県能代市竹生');
ok($zip->set_number('0160017')->is_valid_number, '秋田県能代市磐');
ok($zip->set_number('0160101')->is_valid_number, '秋田県能代市中関');
ok($zip->set_number('0160102')->is_valid_number, '秋田県能代市一本木');
ok($zip->set_number('0160103')->is_valid_number, '秋田県能代市宮ノ前');
ok($zip->set_number('0160104')->is_valid_number, '秋田県能代市下関');
ok($zip->set_number('0160111')->is_valid_number, '秋田県能代市仁井田白山');
ok($zip->set_number('0160112')->is_valid_number, '秋田県能代市中嶋(その他)');
ok($zip->set_number('0160113')->is_valid_number, '秋田県能代市下悪戸');
ok($zip->set_number('0160114')->is_valid_number, '秋田県能代市中悪戸');
ok($zip->set_number('0160115')->is_valid_number, '秋田県能代市悪戸');
ok($zip->set_number('0160116')->is_valid_number, '秋田県能代市機織轌ノ目');
ok($zip->set_number('0160121')->is_valid_number, '秋田県能代市鰄渕');
ok($zip->set_number('0160122')->is_valid_number, '秋田県能代市扇田');
ok($zip->set_number('0160123')->is_valid_number, '秋田県能代市田床内');
ok($zip->set_number('0160131')->is_valid_number, '秋田県能代市鶴形');
ok($zip->set_number('0160132')->is_valid_number, '秋田県能代市町後');
ok($zip->set_number('0160133')->is_valid_number, '秋田県能代市向田表');
ok($zip->set_number('0160134')->is_valid_number, '秋田県能代市戸草沢');
ok($zip->set_number('0160135')->is_valid_number, '秋田県能代市姥懐');
ok($zip->set_number('0160136')->is_valid_number, '秋田県能代市鵜鳥');
ok($zip->set_number('0160137')->is_valid_number, '秋田県能代市鵜鳥悪戸');
ok($zip->set_number('0160138')->is_valid_number, '秋田県能代市鵜鳥川原');
ok($zip->set_number('0160139')->is_valid_number, '秋田県能代市谷地上');
ok($zip->set_number('0160141')->is_valid_number, '秋田県能代市鵜ノ沢');
ok($zip->set_number('0160142')->is_valid_number, '秋田県能代市半戸沢');
ok($zip->set_number('0160143')->is_valid_number, '秋田県能代市上ノ山');
ok($zip->set_number('0160144')->is_valid_number, '秋田県能代市上ノ山台');
ok($zip->set_number('0160145')->is_valid_number, '秋田県能代市若田');
ok($zip->set_number('0160146')->is_valid_number, '秋田県能代市外堤');
ok($zip->set_number('0160147')->is_valid_number, '秋田県能代市鳥矢場');
ok($zip->set_number('0160148')->is_valid_number, '秋田県能代市冷清水');
ok($zip->set_number('0160149')->is_valid_number, '秋田県能代市田中谷地');
ok($zip->set_number('0160151')->is_valid_number, '秋田県能代市檜山');
ok($zip->set_number('0160152')->is_valid_number, '秋田県能代市母体');
ok($zip->set_number('0160153')->is_valid_number, '秋田県能代市上関');
ok($zip->set_number('0160154')->is_valid_number, '秋田県能代市上谷地');
ok($zip->set_number('0160155')->is_valid_number, '秋田県能代市大森');
ok($zip->set_number('0160156')->is_valid_number, '秋田県能代市中沢');
ok($zip->set_number('0160157')->is_valid_number, '秋田県能代市腹鞁ノ沢');
ok($zip->set_number('0160161')->is_valid_number, '秋田県能代市松長布');
ok($zip->set_number('0160162')->is_valid_number, '秋田県能代市大内田');
ok($zip->set_number('0160163')->is_valid_number, '秋田県能代市袖又');
ok($zip->set_number('0160164')->is_valid_number, '秋田県能代市大塚');
ok($zip->set_number('0160165')->is_valid_number, '秋田県能代市田屋');
ok($zip->set_number('0160166')->is_valid_number, '秋田県能代市柏子所');
ok($zip->set_number('0160167')->is_valid_number, '秋田県能代市塩干田');
ok($zip->set_number('0160167')->is_valid_number, '秋田県能代市塩干田前');
ok($zip->set_number('0160168')->is_valid_number, '秋田県能代市十洲崎');
ok($zip->set_number('0160169')->is_valid_number, '秋田県能代市坊ケ崎');
ok($zip->set_number('0160171')->is_valid_number, '秋田県能代市河戸川');
ok($zip->set_number('0160172')->is_valid_number, '秋田県能代市上古川布');
ok($zip->set_number('0160173')->is_valid_number, '秋田県能代市下古川布');
ok($zip->set_number('0160174')->is_valid_number, '秋田県能代市新山前');
ok($zip->set_number('0160175')->is_valid_number, '秋田県能代市古屋布');
ok($zip->set_number('0160176')->is_valid_number, '秋田県能代市戸川向');
ok($zip->set_number('0160177')->is_valid_number, '秋田県能代市権現台');
ok($zip->set_number('0160178')->is_valid_number, '秋田県能代市九郎左衛門笹台');
ok($zip->set_number('0160179')->is_valid_number, '秋田県能代市浅内');
ok($zip->set_number('0160181')->is_valid_number, '秋田県能代市大瀬儘下');
ok($zip->set_number('0160182')->is_valid_number, '秋田県能代市上柳');
ok($zip->set_number('0160183')->is_valid_number, '秋田県能代市中柳');
ok($zip->set_number('0160184')->is_valid_number, '秋田県能代市高塙');
ok($zip->set_number('0160185')->is_valid_number, '秋田県能代市下瀬');
ok($zip->set_number('0160186')->is_valid_number, '秋田県能代市下野');
ok($zip->set_number('0160187')->is_valid_number, '秋田県能代市下柳');
ok($zip->set_number('0160188')->is_valid_number, '秋田県能代市寺向');
ok($zip->set_number('0160801')->is_valid_number, '秋田県能代市浜通町');
ok($zip->set_number('0160802')->is_valid_number, '秋田県能代市川反町');
ok($zip->set_number('0160803')->is_valid_number, '秋田県能代市大町');
ok($zip->set_number('0160804')->is_valid_number, '秋田県能代市万町');
ok($zip->set_number('0160805')->is_valid_number, '秋田県能代市大手町');
ok($zip->set_number('0160806')->is_valid_number, '秋田県能代市清助町');
ok($zip->set_number('0160807')->is_valid_number, '秋田県能代市大森山');
ok($zip->set_number('0160808')->is_valid_number, '秋田県能代市日和山下');
ok($zip->set_number('0160811')->is_valid_number, '秋田県能代市日吉町');
ok($zip->set_number('0160812')->is_valid_number, '秋田県能代市中嶋(1-97~116)');
ok($zip->set_number('0160813')->is_valid_number, '秋田県能代市能代町');
ok($zip->set_number('0160814')->is_valid_number, '秋田県能代市中川原');
ok($zip->set_number('0160815')->is_valid_number, '秋田県能代市御指南町');
ok($zip->set_number('0160816')->is_valid_number, '秋田県能代市富町');
ok($zip->set_number('0160817')->is_valid_number, '秋田県能代市上町');
ok($zip->set_number('0160821')->is_valid_number, '秋田県能代市畠町');
ok($zip->set_number('0160822')->is_valid_number, '秋田県能代市東町');
ok($zip->set_number('0160823')->is_valid_number, '秋田県能代市若松町');
ok($zip->set_number('0160824')->is_valid_number, '秋田県能代市住吉町');
ok($zip->set_number('0160825')->is_valid_number, '秋田県能代市柳町');
ok($zip->set_number('0160831')->is_valid_number, '秋田県能代市元町');
ok($zip->set_number('0160832')->is_valid_number, '秋田県能代市南元町');
ok($zip->set_number('0160833')->is_valid_number, '秋田県能代市明治町');
ok($zip->set_number('0160834')->is_valid_number, '秋田県能代市下内崎');
ok($zip->set_number('0160835')->is_valid_number, '秋田県能代市赤沼');
ok($zip->set_number('0160836')->is_valid_number, '秋田県能代市東赤沼');
ok($zip->set_number('0160837')->is_valid_number, '秋田県能代市西赤沼');
ok($zip->set_number('0160838')->is_valid_number, '秋田県能代市養蚕脇');
ok($zip->set_number('0160839')->is_valid_number, '秋田県能代市東大瀬');
ok($zip->set_number('0160841')->is_valid_number, '秋田県能代市養蚕');
ok($zip->set_number('0160842')->is_valid_number, '秋田県能代市追分町');
ok($zip->set_number('0160843')->is_valid_number, '秋田県能代市中和');
ok($zip->set_number('0160844')->is_valid_number, '秋田県能代市花園町');
ok($zip->set_number('0160845')->is_valid_number, '秋田県能代市通町');
ok($zip->set_number('0160846')->is_valid_number, '秋田県能代市栄町');
ok($zip->set_number('0160851')->is_valid_number, '秋田県能代市緑町');
ok($zip->set_number('0160852')->is_valid_number, '秋田県能代市出戸本町');
ok($zip->set_number('0160853')->is_valid_number, '秋田県能代市出戸後');
ok($zip->set_number('0160854')->is_valid_number, '秋田県能代市豊祥岱');
ok($zip->set_number('0160855')->is_valid_number, '秋田県能代市西大瀬');
ok($zip->set_number('0160856')->is_valid_number, '秋田県能代市藤山');
ok($zip->set_number('0160857')->is_valid_number, '秋田県能代市田子向');
ok($zip->set_number('0160861')->is_valid_number, '秋田県能代市彩霞長根');
ok($zip->set_number('0160862')->is_valid_number, '秋田県能代市寿域長根');
ok($zip->set_number('0160863')->is_valid_number, '秋田県能代市後谷地');
ok($zip->set_number('0160864')->is_valid_number, '秋田県能代市鳥小屋');
ok($zip->set_number('0160865')->is_valid_number, '秋田県能代市青葉町');
ok($zip->set_number('0160871')->is_valid_number, '秋田県能代市昇平岱');
ok($zip->set_number('0160872')->is_valid_number, '秋田県能代市芝童森');
ok($zip->set_number('0160873')->is_valid_number, '秋田県能代市長崎');
ok($zip->set_number('0160874')->is_valid_number, '秋田県能代市沼ノ上');
ok($zip->set_number('0160875')->is_valid_number, '秋田県能代市南陽崎');
ok($zip->set_number('0160876')->is_valid_number, '秋田県能代市海詠坂');
ok($zip->set_number('0160877')->is_valid_number, '秋田県能代市仙遊長根');
ok($zip->set_number('0160878')->is_valid_number, '秋田県能代市臥竜山');
ok($zip->set_number('0160879')->is_valid_number, '秋田県能代市不老岱');
ok($zip->set_number('0160881')->is_valid_number, '秋田県能代市砂留山');
ok($zip->set_number('0160882')->is_valid_number, '秋田県能代市鳳凰岱');
ok($zip->set_number('0160883')->is_valid_number, '秋田県能代市五雲岱');
ok($zip->set_number('0160884')->is_valid_number, '秋田県能代市卸町');
ok($zip->set_number('0160891')->is_valid_number, '秋田県能代市西通町');
ok($zip->set_number('0160892')->is_valid_number, '秋田県能代市景林町');
ok($zip->set_number('0160893')->is_valid_number, '秋田県能代市松美町');
ok($zip->set_number('0160894')->is_valid_number, '秋田県能代市萩の台');
ok($zip->set_number('0160895')->is_valid_number, '秋田県能代市末広町');
ok($zip->set_number('0160896')->is_valid_number, '秋田県能代市盤若町');
ok($zip->set_number('0160897')->is_valid_number, '秋田県能代市昭南町');
ok($zip->set_number('0170000')->is_valid_number, '秋田県大館市以下に掲載がない場合');
ok($zip->set_number('0170001')->is_valid_number, '秋田県大館市長走');
ok($zip->set_number('0170002')->is_valid_number, '秋田県大館市白沢');
ok($zip->set_number('0170003')->is_valid_number, '秋田県大館市橋桁');
ok($zip->set_number('0170004')->is_valid_number, '秋田県大館市粕田');
ok($zip->set_number('0170005')->is_valid_number, '秋田県大館市花岡町');
ok($zip->set_number('0170011')->is_valid_number, '秋田県大館市商人留');
ok($zip->set_number('0170012')->is_valid_number, '秋田県大館市釈迦内');
ok($zip->set_number('0170014')->is_valid_number, '秋田県大館市小釈迦内道上');
ok($zip->set_number('0170015')->is_valid_number, '秋田県大館市小釈迦内道下');
ok($zip->set_number('0170021')->is_valid_number, '秋田県大館市雪沢');
ok($zip->set_number('0170022')->is_valid_number, '秋田県大館市茂内');
ok($zip->set_number('0170023')->is_valid_number, '秋田県大館市東');
ok($zip->set_number('0170024')->is_valid_number, '秋田県大館市大茂内');
ok($zip->set_number('0170025')->is_valid_number, '秋田県大館市芦田子');
ok($zip->set_number('0170026')->is_valid_number, '秋田県大館市二ツ屋境');
ok($zip->set_number('0170031')->is_valid_number, '秋田県大館市上代野');
ok($zip->set_number('0170032')->is_valid_number, '秋田県大館市新綱');
ok($zip->set_number('0170033')->is_valid_number, '秋田県大館市下綱');
ok($zip->set_number('0170034')->is_valid_number, '秋田県大館市下代野');
ok($zip->set_number('0170035')->is_valid_number, '秋田県大館市代野');
ok($zip->set_number('0170036')->is_valid_number, '秋田県大館市二本杉後');
ok($zip->set_number('0170037')->is_valid_number, '秋田県大館市清水堰合');
ok($zip->set_number('0170041')->is_valid_number, '秋田県大館市大田面');
ok($zip->set_number('0170042')->is_valid_number, '秋田県大館市観音堂');
ok($zip->set_number('0170043')->is_valid_number, '秋田県大館市有浦');
ok($zip->set_number('0170044')->is_valid_number, '秋田県大館市御成町');
ok($zip->set_number('0170045')->is_valid_number, '秋田県大館市中道');
ok($zip->set_number('0170046')->is_valid_number, '秋田県大館市清水');
ok($zip->set_number('0170051')->is_valid_number, '秋田県大館市松峰');
ok($zip->set_number('0170052')->is_valid_number, '秋田県大館市松木');
ok($zip->set_number('0170053')->is_valid_number, '秋田県大館市板子石境');
ok($zip->set_number('0170054')->is_valid_number, '秋田県大館市松館');
ok($zip->set_number('0170055')->is_valid_number, '秋田県大館市沼館道上');
ok($zip->set_number('0170056')->is_valid_number, '秋田県大館市沼館道南');
ok($zip->set_number('0170057')->is_valid_number, '秋田県大館市沼館');
ok($zip->set_number('0170200')->is_valid_number, '秋田県鹿角郡小坂町以下に掲載がない場合');
ok($zip->set_number('0170201')->is_valid_number, '秋田県鹿角郡小坂町小坂');
ok($zip->set_number('0170202')->is_valid_number, '秋田県鹿角郡小坂町小坂鉱山');
ok($zip->set_number('0170203')->is_valid_number, '秋田県鹿角郡小坂町上向');
ok($zip->set_number('0170204')->is_valid_number, '秋田県鹿角郡小坂町荒谷');
ok($zip->set_number('0170205')->is_valid_number, '秋田県鹿角郡小坂町大地');
ok($zip->set_number('0170801')->is_valid_number, '秋田県大館市一本杉');
ok($zip->set_number('0170802')->is_valid_number, '秋田県大館市長根山下');
ok($zip->set_number('0170803')->is_valid_number, '秋田県大館市東台');
ok($zip->set_number('0170804')->is_valid_number, '秋田県大館市柄沢');
ok($zip->set_number('0170805')->is_valid_number, '秋田県大館市扇田道下');
ok($zip->set_number('0170806')->is_valid_number, '秋田県大館市相染沢中岱');
ok($zip->set_number('0170811')->is_valid_number, '秋田県大館市八幡');
ok($zip->set_number('0170812')->is_valid_number, '秋田県大館市金坂');
ok($zip->set_number('0170813')->is_valid_number, '秋田県大館市金坂後');
ok($zip->set_number('0170814')->is_valid_number, '秋田県大館市赤館町');
ok($zip->set_number('0170815')->is_valid_number, '秋田県大館市部垂町');
ok($zip->set_number('0170816')->is_valid_number, '秋田県大館市赤館');
ok($zip->set_number('0170817')->is_valid_number, '秋田県大館市上町');
ok($zip->set_number('0170821')->is_valid_number, '秋田県大館市桜町');
ok($zip->set_number('0170822')->is_valid_number, '秋田県大館市桜町南');
ok($zip->set_number('0170823')->is_valid_number, '秋田県大館市八幡沢岱');
ok($zip->set_number('0170824')->is_valid_number, '秋田県大館市七曲岱');
ok($zip->set_number('0170825')->is_valid_number, '秋田県大館市一心院南');
ok($zip->set_number('0170826')->is_valid_number, '秋田県大館市谷地町後');
ok($zip->set_number('0170827')->is_valid_number, '秋田県大館市谷地町');
ok($zip->set_number('0170828')->is_valid_number, '秋田県大館市向町');
ok($zip->set_number('0170831')->is_valid_number, '秋田県大館市青葉町');
ok($zip->set_number('0170832')->is_valid_number, '秋田県大館市池内道下');
ok($zip->set_number('0170833')->is_valid_number, '秋田県大館市象ケ鼻');
ok($zip->set_number('0170834')->is_valid_number, '秋田県大館市池内道上');
ok($zip->set_number('0170835')->is_valid_number, '秋田県大館市小館花');
ok($zip->set_number('0170836')->is_valid_number, '秋田県大館市池内');
ok($zip->set_number('0170837')->is_valid_number, '秋田県大館市餌釣');
ok($zip->set_number('0170838')->is_valid_number, '秋田県大館市山館');
ok($zip->set_number('0170839')->is_valid_number, '秋田県大館市中山');
ok($zip->set_number('0170841')->is_valid_number, '秋田県大館市大町');
ok($zip->set_number('0170842')->is_valid_number, '秋田県大館市馬喰町');
ok($zip->set_number('0170843')->is_valid_number, '秋田県大館市中町');
ok($zip->set_number('0170844')->is_valid_number, '秋田県大館市新町');
ok($zip->set_number('0170845')->is_valid_number, '秋田県大館市泉町');
ok($zip->set_number('0170846')->is_valid_number, '秋田県大館市常盤木町');
ok($zip->set_number('0170847')->is_valid_number, '秋田県大館市幸町');
ok($zip->set_number('0170851')->is_valid_number, '秋田県大館市大披');
ok($zip->set_number('0170852')->is_valid_number, '秋田県大館市小袴');
ok($zip->set_number('0170853')->is_valid_number, '秋田県大館市板沢');
ok($zip->set_number('0170854')->is_valid_number, '秋田県大館市赤石');
ok($zip->set_number('0170855')->is_valid_number, '秋田県大館市櫃崎');
ok($zip->set_number('0170857')->is_valid_number, '秋田県大館市出川');
ok($zip->set_number('0170861')->is_valid_number, '秋田県大館市小館町');
ok($zip->set_number('0170862')->is_valid_number, '秋田県大館市根下戸');
ok($zip->set_number('0170863')->is_valid_number, '秋田県大館市根下戸町');
ok($zip->set_number('0170864')->is_valid_number, '秋田県大館市根下戸新町');
ok($zip->set_number('0170865')->is_valid_number, '秋田県大館市城西町');
ok($zip->set_number('0170866')->is_valid_number, '秋田県大館市北神明町');
ok($zip->set_number('0170867')->is_valid_number, '秋田県大館市中神明町');
ok($zip->set_number('0170868')->is_valid_number, '秋田県大館市南神明町');
ok($zip->set_number('0170871')->is_valid_number, '秋田県大館市片山');
ok($zip->set_number('0170872')->is_valid_number, '秋田県大館市片山町');
ok($zip->set_number('0170873')->is_valid_number, '秋田県大館市御坂');
ok($zip->set_number('0170874')->is_valid_number, '秋田県大館市美園町');
ok($zip->set_number('0170875')->is_valid_number, '秋田県大館市住吉町');
ok($zip->set_number('0170876')->is_valid_number, '秋田県大館市餅田');
ok($zip->set_number('0170877')->is_valid_number, '秋田県大館市立花');
ok($zip->set_number('0170878')->is_valid_number, '秋田県大館市川口');
ok($zip->set_number('0170881')->is_valid_number, '秋田県大館市長木川南');
ok($zip->set_number('0170882')->is_valid_number, '秋田県大館市鉄砲場');
ok($zip->set_number('0170883')->is_valid_number, '秋田県大館市古川町');
ok($zip->set_number('0170884')->is_valid_number, '秋田県大館市土飛山下');
ok($zip->set_number('0170885')->is_valid_number, '秋田県大館市豊町');
ok($zip->set_number('0170886')->is_valid_number, '秋田県大館市館下');
ok($zip->set_number('0170887')->is_valid_number, '秋田県大館市水門町');
ok($zip->set_number('0170888')->is_valid_number, '秋田県大館市水門前');
ok($zip->set_number('0170891')->is_valid_number, '秋田県大館市中城');
ok($zip->set_number('0170892')->is_valid_number, '秋田県大館市片町');
ok($zip->set_number('0170893')->is_valid_number, '秋田県大館市桂城');
ok($zip->set_number('0170894')->is_valid_number, '秋田県大館市裏町');
ok($zip->set_number('0170895')->is_valid_number, '秋田県大館市長倉');
ok($zip->set_number('0170896')->is_valid_number, '秋田県大館市大館');
ok($zip->set_number('0170897')->is_valid_number, '秋田県大館市三ノ丸');
ok($zip->set_number('0180101')->is_valid_number, '秋田県にかほ市象潟町浜山');
ok($zip->set_number('0180102')->is_valid_number, '秋田県にかほ市象潟町木戸口');
ok($zip->set_number('0180103')->is_valid_number, '秋田県にかほ市象潟町上狐森');
ok($zip->set_number('0180104')->is_valid_number, '秋田県にかほ市象潟町狐森');
ok($zip->set_number('0180105')->is_valid_number, '秋田県にかほ市象潟町荒屋妻');
ok($zip->set_number('0180106')->is_valid_number, '秋田県にかほ市象潟町5丁目塩越');
ok($zip->set_number('0180107')->is_valid_number, '秋田県にかほ市象潟町荒屋下');
ok($zip->set_number('0180108')->is_valid_number, '秋田県にかほ市象潟町入湖の澗');
ok($zip->set_number('0180109')->is_valid_number, '秋田県にかほ市象潟町冠石下');
ok($zip->set_number('0180111')->is_valid_number, '秋田県にかほ市象潟町武道島');
ok($zip->set_number('0180112')->is_valid_number, '秋田県にかほ市象潟町家の後');
ok($zip->set_number('0180113')->is_valid_number, '秋田県にかほ市象潟町浜の田');
ok($zip->set_number('0180114')->is_valid_number, '秋田県にかほ市象潟町沖の田');
ok($zip->set_number('0180115')->is_valid_number, '秋田県にかほ市象潟町後田');
ok($zip->set_number('0180116')->is_valid_number, '秋田県にかほ市象潟町4丁目塩越');
ok($zip->set_number('0180117')->is_valid_number, '秋田県にかほ市象潟町浜畑');
ok($zip->set_number('0180118')->is_valid_number, '秋田県にかほ市象潟町2丁目塩越');
ok($zip->set_number('0180119')->is_valid_number, '秋田県にかほ市象潟町3丁目塩越');
ok($zip->set_number('0180121')->is_valid_number, '秋田県にかほ市象潟町大塩越');
ok($zip->set_number('0180122')->is_valid_number, '秋田県にかほ市象潟町象潟島');
ok($zip->set_number('0180123')->is_valid_number, '秋田県にかほ市象潟町妙見下');
ok($zip->set_number('0180124')->is_valid_number, '秋田県にかほ市象潟町入道島');
ok($zip->set_number('0180125')->is_valid_number, '秋田県にかほ市象潟町二の丸');
ok($zip->set_number('0180126')->is_valid_number, '秋田県にかほ市象潟町1丁目塩越');
ok($zip->set_number('0180127')->is_valid_number, '秋田県にかほ市象潟町中橋町');
ok($zip->set_number('0180128')->is_valid_number, '秋田県にかほ市象潟町太郎島');
ok($zip->set_number('0180129')->is_valid_number, '秋田県にかほ市象潟町才の神');
ok($zip->set_number('0180131')->is_valid_number, '秋田県にかほ市象潟町大谷地');
ok($zip->set_number('0180132')->is_valid_number, '秋田県にかほ市象潟町鳥の海');
ok($zip->set_number('0180133')->is_valid_number, '秋田県にかほ市象潟町関');
ok($zip->set_number('0180134')->is_valid_number, '秋田県にかほ市象潟町西中野沢');
ok($zip->set_number('0180135')->is_valid_number, '秋田県にかほ市象潟町洗釜');
ok($zip->set_number('0180136')->is_valid_number, '秋田県にかほ市象潟町大砂川');
ok($zip->set_number('0180141')->is_valid_number, '秋田県にかほ市象潟町川袋');
ok($zip->set_number('0180142')->is_valid_number, '秋田県にかほ市象潟町大須郷');
ok($zip->set_number('0180143')->is_valid_number, '秋田県にかほ市象潟町小砂川');
ok($zip->set_number('0180144')->is_valid_number, '秋田県にかほ市象潟町中谷地');
ok($zip->set_number('0180145')->is_valid_number, '秋田県にかほ市象潟町源蔵潟');
ok($zip->set_number('0180146')->is_valid_number, '秋田県にかほ市象潟町蒲谷地');
ok($zip->set_number('0180147')->is_valid_number, '秋田県にかほ市象潟町立石');
ok($zip->set_number('0180148')->is_valid_number, '秋田県にかほ市象潟町下浜山');
ok($zip->set_number('0180151')->is_valid_number, '秋田県にかほ市象潟町横岡');
ok($zip->set_number('0180152')->is_valid_number, '秋田県にかほ市象潟町本郷');
ok($zip->set_number('0180153')->is_valid_number, '秋田県にかほ市象潟町小滝');
ok($zip->set_number('0180154')->is_valid_number, '秋田県にかほ市象潟町二階谷地');
ok($zip->set_number('0180155')->is_valid_number, '秋田県にかほ市象潟町弁天島');
ok($zip->set_number('0180156')->is_valid_number, '秋田県にかほ市象潟町大門先');
ok($zip->set_number('0180157')->is_valid_number, '秋田県にかほ市象潟町鷹放');
ok($zip->set_number('0180158')->is_valid_number, '秋田県にかほ市象潟町琴和喜');
ok($zip->set_number('0180161')->is_valid_number, '秋田県にかほ市象潟町大飯郷');
ok($zip->set_number('0180162')->is_valid_number, '秋田県にかほ市象潟町大森');
ok($zip->set_number('0180163')->is_valid_number, '秋田県にかほ市象潟町長岡');
ok($zip->set_number('0180164')->is_valid_number, '秋田県にかほ市象潟町丸山');
ok($zip->set_number('0180165')->is_valid_number, '秋田県にかほ市象潟町狸森');
ok($zip->set_number('0180166')->is_valid_number, '秋田県にかほ市象潟町高田');
ok($zip->set_number('0180167')->is_valid_number, '秋田県にかほ市象潟町田の神');
ok($zip->set_number('0180171')->is_valid_number, '秋田県にかほ市象潟町続島');
ok($zip->set_number('0180172')->is_valid_number, '秋田県にかほ市象潟町小才の神');
ok($zip->set_number('0180173')->is_valid_number, '秋田県にかほ市象潟町四隅池');
ok($zip->set_number('0180174')->is_valid_number, '秋田県にかほ市象潟町林の下');
ok($zip->set_number('0180175')->is_valid_number, '秋田県にかほ市象潟町坂の下');
ok($zip->set_number('0180176')->is_valid_number, '秋田県にかほ市象潟町横山');
ok($zip->set_number('0180181')->is_valid_number, '秋田県にかほ市象潟町白山堂');
ok($zip->set_number('0180182')->is_valid_number, '秋田県にかほ市象潟町不動沢');
ok($zip->set_number('0180183')->is_valid_number, '秋田県にかほ市象潟町小坂');
ok($zip->set_number('0180184')->is_valid_number, '秋田県にかほ市象潟町上小坂');
ok($zip->set_number('0180185')->is_valid_number, '秋田県にかほ市象潟町屋敷田');
ok($zip->set_number('0180186')->is_valid_number, '秋田県にかほ市象潟町能因島');
ok($zip->set_number('0180187')->is_valid_number, '秋田県にかほ市象潟町小烏島');
ok($zip->set_number('0180188')->is_valid_number, '秋田県にかほ市象潟町烏島');
ok($zip->set_number('0180301')->is_valid_number, '秋田県にかほ市飛');
ok($zip->set_number('0180302')->is_valid_number, '秋田県にかほ市黒川');
ok($zip->set_number('0180311')->is_valid_number, '秋田県にかほ市金浦');
ok($zip->set_number('0180321')->is_valid_number, '秋田県にかほ市前川');
ok($zip->set_number('0180322')->is_valid_number, '秋田県にかほ市大竹');
ok($zip->set_number('0180400')->is_valid_number, '秋田県にかほ市以下に掲載がない場合');
ok($zip->set_number('0180401')->is_valid_number, '秋田県にかほ市両前寺');
ok($zip->set_number('0180402')->is_valid_number, '秋田県にかほ市平沢');
ok($zip->set_number('0180403')->is_valid_number, '秋田県にかほ市三森');
ok($zip->set_number('0180404')->is_valid_number, '秋田県にかほ市芹田');
ok($zip->set_number('0180411')->is_valid_number, '秋田県にかほ市院内');
ok($zip->set_number('0180412')->is_valid_number, '秋田県にかほ市小国');
ok($zip->set_number('0180413')->is_valid_number, '秋田県にかほ市馬場');
ok($zip->set_number('0180414')->is_valid_number, '秋田県にかほ市田抓');
ok($zip->set_number('0180421')->is_valid_number, '秋田県にかほ市釜ケ台');
ok($zip->set_number('0180422')->is_valid_number, '秋田県にかほ市冬師');
ok($zip->set_number('0180431')->is_valid_number, '秋田県にかほ市伊勢居地');
ok($zip->set_number('0180432')->is_valid_number, '秋田県にかほ市水沢');
ok($zip->set_number('0180433')->is_valid_number, '秋田県にかほ市畑');
ok($zip->set_number('0180434')->is_valid_number, '秋田県にかほ市寺田');
ok($zip->set_number('0180435')->is_valid_number, '秋田県にかほ市中三地');
ok($zip->set_number('0180436')->is_valid_number, '秋田県にかほ市樋目野');
ok($zip->set_number('0180601')->is_valid_number, '秋田県由利本荘市西目町海士剥');
ok($zip->set_number('0180602')->is_valid_number, '秋田県由利本荘市西目町出戸');
ok($zip->set_number('0180603')->is_valid_number, '秋田県由利本荘市西目町西目');
ok($zip->set_number('0180604')->is_valid_number, '秋田県由利本荘市西目町沼田');
ok($zip->set_number('0180711')->is_valid_number, '秋田県由利本荘市岩谷町');
ok($zip->set_number('0180721')->is_valid_number, '秋田県由利本荘市大谷');
ok($zip->set_number('0180722')->is_valid_number, '秋田県由利本荘市中館');
ok($zip->set_number('0180723')->is_valid_number, '秋田県由利本荘市牛寺');
ok($zip->set_number('0180724')->is_valid_number, '秋田県由利本荘市深沢');
ok($zip->set_number('0180725')->is_valid_number, '秋田県由利本荘市米坂');
ok($zip->set_number('0180726')->is_valid_number, '秋田県由利本荘市岩谷麓');
ok($zip->set_number('0180731')->is_valid_number, '秋田県由利本荘市大内三川');
ok($zip->set_number('0180732')->is_valid_number, '秋田県由利本荘市徳沢');
ok($zip->set_number('0180733')->is_valid_number, '秋田県由利本荘市大倉沢');
ok($zip->set_number('0180734')->is_valid_number, '秋田県由利本荘市北福田');
ok($zip->set_number('0180841')->is_valid_number, '秋田県由利本荘市加賀沢');
ok($zip->set_number('0180842')->is_valid_number, '秋田県由利本荘市新沢');
ok($zip->set_number('0180843')->is_valid_number, '秋田県由利本荘市中帳');
ok($zip->set_number('0180844')->is_valid_number, '秋田県由利本荘市高尾');
ok($zip->set_number('0180845')->is_valid_number, '秋田県由利本荘市中俣');
ok($zip->set_number('0180851')->is_valid_number, '秋田県由利本荘市平岫');
ok($zip->set_number('0180852')->is_valid_number, '秋田県由利本荘市葛岡');
ok($zip->set_number('0180853')->is_valid_number, '秋田県由利本荘市長坂');
ok($zip->set_number('0180854')->is_valid_number, '秋田県由利本荘市及位');
ok($zip->set_number('0180855')->is_valid_number, '秋田県由利本荘市松本');
ok($zip->set_number('0180901')->is_valid_number, '秋田県由利本荘市中田代');
ok($zip->set_number('0180902')->is_valid_number, '秋田県由利本荘市新田');
ok($zip->set_number('0180903')->is_valid_number, '秋田県由利本荘市小栗山');
ok($zip->set_number('0180904')->is_valid_number, '秋田県由利本荘市岩野目沢');
ok($zip->set_number('0180905')->is_valid_number, '秋田県由利本荘市滝');
ok($zip->set_number('0180906')->is_valid_number, '秋田県由利本荘市羽広');
ok($zip->set_number('0180907')->is_valid_number, '秋田県由利本荘市坂部');
ok($zip->set_number('0181211')->is_valid_number, '秋田県由利本荘市岩城滝俣');
ok($zip->set_number('0181212')->is_valid_number, '秋田県由利本荘市岩城福俣');
ok($zip->set_number('0181213')->is_valid_number, '秋田県由利本荘市岩城泉田');
ok($zip->set_number('0181214')->is_valid_number, '秋田県由利本荘市岩城富田');
ok($zip->set_number('0181215')->is_valid_number, '秋田県由利本荘市岩城赤平');
ok($zip->set_number('0181216')->is_valid_number, '秋田県由利本荘市岩城亀田愛宕町');
ok($zip->set_number('0181217')->is_valid_number, '秋田県由利本荘市岩城亀田亀田町');
ok($zip->set_number('0181218')->is_valid_number, '秋田県由利本荘市岩城亀田大町');
ok($zip->set_number('0181221')->is_valid_number, '秋田県由利本荘市岩城亀田最上町');
ok($zip->set_number('0181222')->is_valid_number, '秋田県由利本荘市岩城上蛇田');
ok($zip->set_number('0181223')->is_valid_number, '秋田県由利本荘市岩城下蛇田');
ok($zip->set_number('0181224')->is_valid_number, '秋田県由利本荘市岩城六呂田');
ok($zip->set_number('0181225')->is_valid_number, '秋田県由利本荘市岩城上黒川');
ok($zip->set_number('0181226')->is_valid_number, '秋田県由利本荘市岩城下黒川');
ok($zip->set_number('0181301')->is_valid_number, '秋田県由利本荘市岩城内道川');
ok($zip->set_number('0181302')->is_valid_number, '秋田県由利本荘市岩城勝手');
ok($zip->set_number('0181303')->is_valid_number, '秋田県由利本荘市岩城君ケ野');
ok($zip->set_number('0181304')->is_valid_number, '秋田県由利本荘市岩城道川');
ok($zip->set_number('0181305')->is_valid_number, '秋田県由利本荘市岩城二古');
ok($zip->set_number('0181400')->is_valid_number, '秋田県潟上市以下に掲載がない場合');
ok($zip->set_number('0181401')->is_valid_number, '秋田県潟上市昭和大久保');
ok($zip->set_number('0181402')->is_valid_number, '秋田県潟上市昭和乱橋');
ok($zip->set_number('0181403')->is_valid_number, '秋田県潟上市昭和八丁目');
ok($zip->set_number('0181411')->is_valid_number, '秋田県潟上市昭和豊川上虻川');
ok($zip->set_number('0181412')->is_valid_number, '秋田県潟上市昭和豊川岡井戸');
ok($zip->set_number('0181413')->is_valid_number, '秋田県潟上市昭和豊川船橋');
ok($zip->set_number('0181414')->is_valid_number, '秋田県潟上市昭和豊川槻木');
ok($zip->set_number('0181415')->is_valid_number, '秋田県潟上市昭和豊川竜毛');
ok($zip->set_number('0181416')->is_valid_number, '秋田県潟上市昭和豊川山田');
ok($zip->set_number('0181500')->is_valid_number, '秋田県南秋田郡井川町以下に掲載がない場合');
ok($zip->set_number('0181501')->is_valid_number, '秋田県潟上市飯田川金山');
ok($zip->set_number('0181502')->is_valid_number, '秋田県潟上市飯田川下虻川');
ok($zip->set_number('0181503')->is_valid_number, '秋田県潟上市飯田川和田妹川');
ok($zip->set_number('0181504')->is_valid_number, '秋田県潟上市飯田川飯塚');
ok($zip->set_number('0181511')->is_valid_number, '秋田県南秋田郡井川町今戸');
ok($zip->set_number('0181512')->is_valid_number, '秋田県南秋田郡井川町北川尻');
ok($zip->set_number('0181513')->is_valid_number, '秋田県南秋田郡井川町黒坪');
ok($zip->set_number('0181514')->is_valid_number, '秋田県南秋田郡井川町宇治木');
ok($zip->set_number('0181515')->is_valid_number, '秋田県南秋田郡井川町小竹花');
ok($zip->set_number('0181516')->is_valid_number, '秋田県南秋田郡井川町浜井川');
ok($zip->set_number('0181521')->is_valid_number, '秋田県南秋田郡井川町八田大倉');
ok($zip->set_number('0181522')->is_valid_number, '秋田県南秋田郡井川町保野子');
ok($zip->set_number('0181523')->is_valid_number, '秋田県南秋田郡井川町坂本');
ok($zip->set_number('0181524')->is_valid_number, '秋田県南秋田郡井川町大麦');
ok($zip->set_number('0181525')->is_valid_number, '秋田県南秋田郡井川町赤沢');
ok($zip->set_number('0181526')->is_valid_number, '秋田県南秋田郡井川町寺沢');
ok($zip->set_number('0181527')->is_valid_number, '秋田県南秋田郡井川町井内');
ok($zip->set_number('0181528')->is_valid_number, '秋田県南秋田郡井川町葹田');
ok($zip->set_number('0181600')->is_valid_number, '秋田県南秋田郡八郎潟町以下に掲載がない場合');
ok($zip->set_number('0181601')->is_valid_number, '秋田県南秋田郡八郎潟町真坂');
ok($zip->set_number('0181602')->is_valid_number, '秋田県南秋田郡八郎潟町浦大町');
ok($zip->set_number('0181603')->is_valid_number, '秋田県南秋田郡八郎潟町小池');
ok($zip->set_number('0181604')->is_valid_number, '秋田県南秋田郡八郎潟町野田');
ok($zip->set_number('0181605')->is_valid_number, '秋田県南秋田郡八郎潟町川崎');
ok($zip->set_number('0181606')->is_valid_number, '秋田県南秋田郡八郎潟町夜叉袋');
ok($zip->set_number('0181611')->is_valid_number, '秋田県南秋田郡八郎潟町上沖谷地');
ok($zip->set_number('0181612')->is_valid_number, '秋田県南秋田郡八郎潟町昼根下');
ok($zip->set_number('0181613')->is_valid_number, '秋田県南秋田郡八郎潟町上昼根');
ok($zip->set_number('0181614')->is_valid_number, '秋田県南秋田郡八郎潟町中田');
ok($zip->set_number('0181615')->is_valid_number, '秋田県南秋田郡八郎潟町蒲沼');
ok($zip->set_number('0181616')->is_valid_number, '秋田県南秋田郡八郎潟町大道');
ok($zip->set_number('0181617')->is_valid_number, '秋田県南秋田郡八郎潟町イカリ');
ok($zip->set_number('0181618')->is_valid_number, '秋田県南秋田郡八郎潟町川口');
ok($zip->set_number('0181621')->is_valid_number, '秋田県南秋田郡八郎潟町家の後');
ok($zip->set_number('0181622')->is_valid_number, '秋田県南秋田郡八郎潟町一日市');
ok($zip->set_number('0181623')->is_valid_number, '秋田県南秋田郡八郎潟町下川原');
ok($zip->set_number('0181624')->is_valid_number, '秋田県南秋田郡八郎潟町中久保');
ok($zip->set_number('0181625')->is_valid_number, '秋田県南秋田郡八郎潟町久保見');
ok($zip->set_number('0181626')->is_valid_number, '秋田県南秋田郡八郎潟町細川');
ok($zip->set_number('0181627')->is_valid_number, '秋田県南秋田郡八郎潟町押切');
ok($zip->set_number('0181628')->is_valid_number, '秋田県南秋田郡八郎潟町島ノ内');
ok($zip->set_number('0181629')->is_valid_number, '秋田県南秋田郡八郎潟町中嶋');
ok($zip->set_number('0181631')->is_valid_number, '秋田県南秋田郡八郎潟町八幡沼');
ok($zip->set_number('0181632')->is_valid_number, '秋田県南秋田郡八郎潟町長沼');
ok($zip->set_number('0181633')->is_valid_number, '秋田県南秋田郡八郎潟町中谷地');
ok($zip->set_number('0181634')->is_valid_number, '秋田県南秋田郡八郎潟町軒嶋');
ok($zip->set_number('0181635')->is_valid_number, '秋田県南秋田郡八郎潟町洲先');
ok($zip->set_number('0181700')->is_valid_number, '秋田県南秋田郡五城目町以下に掲載がない場合');
ok($zip->set_number('0181701')->is_valid_number, '秋田県南秋田郡五城目町兎品沢');
ok($zip->set_number('0181702')->is_valid_number, '秋田県南秋田郡五城目町杉ケ崎');
ok($zip->set_number('0181703')->is_valid_number, '秋田県南秋田郡五城目町羽黒前');
ok($zip->set_number('0181704')->is_valid_number, '秋田県南秋田郡五城目町石田六ケ村堰添');
ok($zip->set_number('0181705')->is_valid_number, '秋田県南秋田郡五城目町上町');
ok($zip->set_number('0181706')->is_valid_number, '秋田県南秋田郡五城目町下タ町');
ok($zip->set_number('0181711')->is_valid_number, '秋田県南秋田郡五城目町高崎');
ok($zip->set_number('0181712')->is_valid_number, '秋田県南秋田郡五城目町久保');
ok($zip->set_number('0181713')->is_valid_number, '秋田県南秋田郡五城目町馬場目');
ok($zip->set_number('0181714')->is_valid_number, '秋田県南秋田郡五城目町舘越');
ok($zip->set_number('0181721')->is_valid_number, '秋田県南秋田郡五城目町七倉');
ok($zip->set_number('0181722')->is_valid_number, '秋田県南秋田郡五城目町鵜ノ木');
ok($zip->set_number('0181723')->is_valid_number, '秋田県南秋田郡五城目町上樋口');
ok($zip->set_number('0181724')->is_valid_number, '秋田県南秋田郡五城目町東磯ノ目');
ok($zip->set_number('0181725')->is_valid_number, '秋田県南秋田郡五城目町西磯ノ目');
ok($zip->set_number('0181731')->is_valid_number, '秋田県南秋田郡五城目町大川石崎');
ok($zip->set_number('0181732')->is_valid_number, '秋田県南秋田郡五城目町大川西野');
ok($zip->set_number('0181733')->is_valid_number, '秋田県南秋田郡五城目町大川谷地中');
ok($zip->set_number('0181734')->is_valid_number, '秋田県南秋田郡五城目町大川大川');
ok($zip->set_number('0181735')->is_valid_number, '秋田県南秋田郡五城目町大川下樋口');
ok($zip->set_number('0181741')->is_valid_number, '秋田県南秋田郡五城目町浦大町');
ok($zip->set_number('0181742')->is_valid_number, '秋田県南秋田郡五城目町浦横町');
ok($zip->set_number('0181743')->is_valid_number, '秋田県南秋田郡五城目町稲荷前');
ok($zip->set_number('0181744')->is_valid_number, '秋田県南秋田郡五城目町神明前');
ok($zip->set_number('0181745')->is_valid_number, '秋田県南秋田郡五城目町川崎');
ok($zip->set_number('0181746')->is_valid_number, '秋田県南秋田郡五城目町小池');
ok($zip->set_number('0181747')->is_valid_number, '秋田県南秋田郡五城目町野田');
ok($zip->set_number('0181851')->is_valid_number, '秋田県南秋田郡五城目町内川浅見内');
ok($zip->set_number('0181852')->is_valid_number, '秋田県南秋田郡五城目町内川湯ノ又');
ok($zip->set_number('0181853')->is_valid_number, '秋田県南秋田郡五城目町富津内中津又');
ok($zip->set_number('0181854')->is_valid_number, '秋田県南秋田郡五城目町内川黒土');
ok($zip->set_number('0181855')->is_valid_number, '秋田県南秋田郡五城目町富津内富田');
ok($zip->set_number('0181856')->is_valid_number, '秋田県南秋田郡五城目町富津内下山内');
ok($zip->set_number('0181857')->is_valid_number, '秋田県南秋田郡五城目町内川小倉');
ok($zip->set_number('0182101')->is_valid_number, '秋田県山本郡三種町上岩川');
ok($zip->set_number('0182102')->is_valid_number, '秋田県山本郡三種町天瀬川');
ok($zip->set_number('0182103')->is_valid_number, '秋田県山本郡三種町鯉川');
ok($zip->set_number('0182104')->is_valid_number, '秋田県山本郡三種町鹿渡');
ok($zip->set_number('0182301')->is_valid_number, '秋田県山本郡三種町志戸橋');
ok($zip->set_number('0182302')->is_valid_number, '秋田県山本郡三種町下岩川');
ok($zip->set_number('0182303')->is_valid_number, '秋田県山本郡三種町森岳');
ok($zip->set_number('0182304')->is_valid_number, '秋田県山本郡三種町豊岡金田');
ok($zip->set_number('0182305')->is_valid_number, '秋田県山本郡三種町外岡');
ok($zip->set_number('0182400')->is_valid_number, '秋田県山本郡三種町以下に掲載がない場合');
ok($zip->set_number('0182401')->is_valid_number, '秋田県山本郡三種町鵜川');
ok($zip->set_number('0182402')->is_valid_number, '秋田県山本郡三種町川尻');
ok($zip->set_number('0182403')->is_valid_number, '秋田県山本郡三種町久米岡新田');
ok($zip->set_number('0182404')->is_valid_number, '秋田県山本郡三種町富岡新田');
ok($zip->set_number('0182405')->is_valid_number, '秋田県山本郡三種町芦崎');
ok($zip->set_number('0182406')->is_valid_number, '秋田県山本郡三種町大口');
ok($zip->set_number('0182407')->is_valid_number, '秋田県山本郡三種町浜田');
ok($zip->set_number('0182500')->is_valid_number, '秋田県山本郡八峰町以下に掲載がない場合');
ok($zip->set_number('0182501')->is_valid_number, '秋田県山本郡八峰町峰浜水沢');
ok($zip->set_number('0182502')->is_valid_number, '秋田県山本郡八峰町峰浜目名潟');
ok($zip->set_number('0182503')->is_valid_number, '秋田県山本郡八峰町峰浜塙');
ok($zip->set_number('0182504')->is_valid_number, '秋田県山本郡八峰町峰浜石川');
ok($zip->set_number('0182505')->is_valid_number, '秋田県山本郡八峰町峰浜内荒巻');
ok($zip->set_number('0182506')->is_valid_number, '秋田県山本郡八峰町峰浜小手萩');
ok($zip->set_number('0182507')->is_valid_number, '秋田県山本郡八峰町峰浜田中');
ok($zip->set_number('0182508')->is_valid_number, '秋田県山本郡八峰町峰浜坂形');
ok($zip->set_number('0182509')->is_valid_number, '秋田県山本郡八峰町峰浜沼田');
ok($zip->set_number('0182511')->is_valid_number, '秋田県山本郡八峰町峰浜高野々');
ok($zip->set_number('0182512')->is_valid_number, '秋田県山本郡八峰町峰浜畑谷');
ok($zip->set_number('0182601')->is_valid_number, '秋田県山本郡八峰町八森乙の水');
ok($zip->set_number('0182602')->is_valid_number, '秋田県山本郡八峰町八森チゴキ');
ok($zip->set_number('0182603')->is_valid_number, '秋田県山本郡八峰町八森物見');
ok($zip->set_number('0182604')->is_valid_number, '秋田県山本郡八峰町八森和田表');
ok($zip->set_number('0182605')->is_valid_number, '秋田県山本郡八峰町八森岩館塚の台');
ok($zip->set_number('0182606')->is_valid_number, '秋田県山本郡八峰町八森釜の上');
ok($zip->set_number('0182607')->is_valid_number, '秋田県山本郡八峰町八森林の沢');
ok($zip->set_number('0182608')->is_valid_number, '秋田県山本郡八峰町八森岩館向台');
ok($zip->set_number('0182609')->is_valid_number, '秋田県山本郡八峰町八森門の沢');
ok($zip->set_number('0182611')->is_valid_number, '秋田県山本郡八峰町八森岩館');
ok($zip->set_number('0182612')->is_valid_number, '秋田県山本郡八峰町八森ノケソリ');
ok($zip->set_number('0182613')->is_valid_number, '秋田県山本郡八峰町八森鉱山');
ok($zip->set_number('0182614')->is_valid_number, '秋田県山本郡八峰町八森小入川家の上');
ok($zip->set_number('0182615')->is_valid_number, '秋田県山本郡八峰町八森伊勢鉢台');
ok($zip->set_number('0182616')->is_valid_number, '秋田県山本郡八峰町八森三沢');
ok($zip->set_number('0182617')->is_valid_number, '秋田県山本郡八峰町八森御所の台');
ok($zip->set_number('0182618')->is_valid_number, '秋田県山本郡八峰町八森木戸の沢');
ok($zip->set_number('0182619')->is_valid_number, '秋田県山本郡八峰町八森長坂');
ok($zip->set_number('0182621')->is_valid_number, '秋田県山本郡八峰町八森茶の沢');
ok($zip->set_number('0182622')->is_valid_number, '秋田県山本郡八峰町八森家の向');
ok($zip->set_number('0182623')->is_valid_number, '秋田県山本郡八峰町八森滝ノ間');
ok($zip->set_number('0182624')->is_valid_number, '秋田県山本郡八峰町八森横間台');
ok($zip->set_number('0182625')->is_valid_number, '秋田県山本郡八峰町八森山内台');
ok($zip->set_number('0182626')->is_valid_number, '秋田県山本郡八峰町八森横間');
ok($zip->set_number('0182627')->is_valid_number, '秋田県山本郡八峰町八森山内');
ok($zip->set_number('0182628')->is_valid_number, '秋田県山本郡八峰町八森立石');
ok($zip->set_number('0182631')->is_valid_number, '秋田県山本郡八峰町八森五輪台下段');
ok($zip->set_number('0182632')->is_valid_number, '秋田県山本郡八峰町八森三十釜');
ok($zip->set_number('0182633')->is_valid_number, '秋田県山本郡八峰町八森五輪台上段');
ok($zip->set_number('0182634')->is_valid_number, '秋田県山本郡八峰町八森滝の上');
ok($zip->set_number('0182635')->is_valid_number, '秋田県山本郡八峰町八森下嘉治助台');
ok($zip->set_number('0182636')->is_valid_number, '秋田県山本郡八峰町八森上嘉治助台');
ok($zip->set_number('0182637')->is_valid_number, '秋田県山本郡八峰町八森家の後');
ok($zip->set_number('0182638')->is_valid_number, '秋田県山本郡八峰町八森茂浦');
ok($zip->set_number('0182641')->is_valid_number, '秋田県山本郡八峰町八森中浜');
ok($zip->set_number('0182642')->is_valid_number, '秋田県山本郡八峰町八森椿');
ok($zip->set_number('0182643')->is_valid_number, '秋田県山本郡八峰町八森家の上');
ok($zip->set_number('0182644')->is_valid_number, '秋田県山本郡八峰町八森椿台');
ok($zip->set_number('0182645')->is_valid_number, '秋田県山本郡八峰町八森中嶋');
ok($zip->set_number('0182646')->is_valid_number, '秋田県山本郡八峰町八森塚の台');
ok($zip->set_number('0182647')->is_valid_number, '秋田県山本郡八峰町八森鹿の浦');
ok($zip->set_number('0182648')->is_valid_number, '秋田県山本郡八峰町八森泊台');
ok($zip->set_number('0182651')->is_valid_number, '秋田県山本郡八峰町八森下館下');
ok($zip->set_number('0182652')->is_valid_number, '秋田県山本郡八峰町八森本館中台');
ok($zip->set_number('0182653')->is_valid_number, '秋田県山本郡八峰町八森倉の沢');
ok($zip->set_number('0182654')->is_valid_number, '秋田県山本郡八峰町八森諸沢口');
ok($zip->set_number('0182655')->is_valid_number, '秋田県山本郡八峰町八森本館');
ok($zip->set_number('0182656')->is_valid_number, '秋田県山本郡八峰町八森諸沢下脇');
ok($zip->set_number('0182661')->is_valid_number, '秋田県山本郡八峰町八森浜田');
ok($zip->set_number('0182662')->is_valid_number, '秋田県山本郡八峰町八森新浜田');
ok($zip->set_number('0182663')->is_valid_number, '秋田県山本郡八峰町八森樋長');
ok($zip->set_number('0182664')->is_valid_number, '秋田県山本郡八峰町八森古屋敷');
ok($zip->set_number('0182665')->is_valid_number, '秋田県山本郡八峰町八森寺の後川向');
ok($zip->set_number('0182666')->is_valid_number, '秋田県山本郡八峰町八森寺の後');
ok($zip->set_number('0182667')->is_valid_number, '秋田県山本郡八峰町八森八森家後');
ok($zip->set_number('0182671')->is_valid_number, '秋田県山本郡八峰町八森湯の尻');
ok($zip->set_number('0182672')->is_valid_number, '秋田県山本郡八峰町八森下家後');
ok($zip->set_number('0182673')->is_valid_number, '秋田県山本郡八峰町八森中家後');
ok($zip->set_number('0182674')->is_valid_number, '秋田県山本郡八峰町八森上家後');
ok($zip->set_number('0182675')->is_valid_number, '秋田県山本郡八峰町八森篭田');
ok($zip->set_number('0182676')->is_valid_number, '秋田県山本郡八峰町八森磯村');
ok($zip->set_number('0182677')->is_valid_number, '秋田県山本郡八峰町八森八森後');
ok($zip->set_number('0182678')->is_valid_number, '秋田県山本郡八峰町八森八森');
ok($zip->set_number('0182801')->is_valid_number, '秋田県能代市常盤');
ok($zip->set_number('0182802')->is_valid_number, '秋田県能代市天内');
ok($zip->set_number('0182803')->is_valid_number, '秋田県能代市外割田');
ok($zip->set_number('0182804')->is_valid_number, '秋田県能代市槐');
ok($zip->set_number('0182805')->is_valid_number, '秋田県能代市轟');
ok($zip->set_number('0182806')->is_valid_number, '秋田県能代市久喜沢');
ok($zip->set_number('0182811')->is_valid_number, '秋田県能代市産物');
ok($zip->set_number('0182812')->is_valid_number, '秋田県能代市大曲');
ok($zip->set_number('0182813')->is_valid_number, '秋田県能代市上悪土');
ok($zip->set_number('0182814')->is_valid_number, '秋田県能代市狐森');
ok($zip->set_number('0182815')->is_valid_number, '秋田県能代市東面');
ok($zip->set_number('0183101')->is_valid_number, '秋田県能代市二ツ井町麻生');
ok($zip->set_number('0183102')->is_valid_number, '秋田県能代市二ツ井町小繋');
ok($zip->set_number('0183103')->is_valid_number, '秋田県能代市二ツ井町荷上場');
ok($zip->set_number('0183104')->is_valid_number, '秋田県能代市二ツ井町沢口');
ok($zip->set_number('0183105')->is_valid_number, '秋田県能代市二ツ井町上山崎');
ok($zip->set_number('0183106')->is_valid_number, '秋田県能代市二ツ井町濁川');
ok($zip->set_number('0183107')->is_valid_number, '秋田県能代市二ツ井町苅又石');
ok($zip->set_number('0183111')->is_valid_number, '秋田県能代市二ツ井町田代');
ok($zip->set_number('0183112')->is_valid_number, '秋田県能代市二ツ井町小掛');
ok($zip->set_number('0183113')->is_valid_number, '秋田県能代市二ツ井町仁鮒');
ok($zip->set_number('0183114')->is_valid_number, '秋田県能代市二ツ井町桜台');
ok($zip->set_number('0183115')->is_valid_number, '秋田県能代市二ツ井町海道上');
ok($zip->set_number('0183116')->is_valid_number, '秋田県能代市二ツ井町家後');
ok($zip->set_number('0183117')->is_valid_number, '秋田県能代市二ツ井町塚台');
ok($zip->set_number('0183118')->is_valid_number, '秋田県能代市二ツ井町上台');
ok($zip->set_number('0183119')->is_valid_number, '秋田県能代市二ツ井町薄井');
ok($zip->set_number('0183121')->is_valid_number, '秋田県能代市二ツ井町飛根(富根)');
ok($zip->set_number('0183122')->is_valid_number, '秋田県能代市二ツ井町飛根(その他)');
ok($zip->set_number('0183123')->is_valid_number, '秋田県能代市二ツ井町駒形');
ok($zip->set_number('0183124')->is_valid_number, '秋田県能代市二ツ井町切石');
ok($zip->set_number('0183125')->is_valid_number, '秋田県能代市二ツ井町茶屋下');
ok($zip->set_number('0183126')->is_valid_number, '秋田県能代市二ツ井町狐台');
ok($zip->set_number('0183127')->is_valid_number, '秋田県能代市二ツ井町稗川原');
ok($zip->set_number('0183128')->is_valid_number, '秋田県能代市二ツ井町下稗柄');
ok($zip->set_number('0183129')->is_valid_number, '秋田県能代市二ツ井町稗柄');
ok($zip->set_number('0183131')->is_valid_number, '秋田県能代市二ツ井町梅内');
ok($zip->set_number('0183132')->is_valid_number, '秋田県能代市二ツ井町種(その他)');
ok($zip->set_number('0183133')->is_valid_number, '秋田県能代市二ツ井町種(竹原)');
ok($zip->set_number('0183134')->is_valid_number, '秋田県能代市二ツ井町高関');
ok($zip->set_number('0183135')->is_valid_number, '秋田県能代市二ツ井町山根');
ok($zip->set_number('0183141')->is_valid_number, '秋田県能代市二ツ井町五千苅');
ok($zip->set_number('0183142')->is_valid_number, '秋田県能代市二ツ井町上野');
ok($zip->set_number('0183143')->is_valid_number, '秋田県能代市二ツ井町太田面');
ok($zip->set_number('0183144')->is_valid_number, '秋田県能代市二ツ井町中坪');
ok($zip->set_number('0183145')->is_valid_number, '秋田県能代市二ツ井町道上中坪');
ok($zip->set_number('0183146')->is_valid_number, '秋田県能代市二ツ井町中坪道下');
ok($zip->set_number('0183147')->is_valid_number, '秋田県能代市二ツ井町小槻木');
ok($zip->set_number('0183148')->is_valid_number, '秋田県能代市二ツ井町槻ノ木');
ok($zip->set_number('0183151')->is_valid_number, '秋田県能代市二ツ井町三千苅');
ok($zip->set_number('0183152')->is_valid_number, '秋田県能代市二ツ井町下野家後');
ok($zip->set_number('0183153')->is_valid_number, '秋田県能代市二ツ井町滑良子川端');
ok($zip->set_number('0183154')->is_valid_number, '秋田県能代市二ツ井町町尻');
ok($zip->set_number('0183155')->is_valid_number, '秋田県能代市二ツ井町比井野');
ok($zip->set_number('0183156')->is_valid_number, '秋田県能代市二ツ井町下野川端');
ok($zip->set_number('0183157')->is_valid_number, '秋田県能代市二ツ井町下野');
ok($zip->set_number('0183200')->is_valid_number, '秋田県山本郡藤里町以下に掲載がない場合');
ok($zip->set_number('0183201')->is_valid_number, '秋田県山本郡藤里町藤琴');
ok($zip->set_number('0183202')->is_valid_number, '秋田県山本郡藤里町太良');
ok($zip->set_number('0183203')->is_valid_number, '秋田県山本郡藤里町大沢');
ok($zip->set_number('0183204')->is_valid_number, '秋田県山本郡藤里町矢坂');
ok($zip->set_number('0183205')->is_valid_number, '秋田県山本郡藤里町粕毛');
ok($zip->set_number('0183300')->is_valid_number, '秋田県北秋田市以下に掲載がない場合');
ok($zip->set_number('0183301')->is_valid_number, '秋田県北秋田市綴子');
ok($zip->set_number('0183302')->is_valid_number, '秋田県北秋田市栄');
ok($zip->set_number('0183311')->is_valid_number, '秋田県北秋田市材木町');
ok($zip->set_number('0183312')->is_valid_number, '秋田県北秋田市花園町');
ok($zip->set_number('0183313')->is_valid_number, '秋田県北秋田市旭町');
ok($zip->set_number('0183314')->is_valid_number, '秋田県北秋田市伊勢町');
ok($zip->set_number('0183315')->is_valid_number, '秋田県北秋田市宮前町');
ok($zip->set_number('0183316')->is_valid_number, '秋田県北秋田市東横町');
ok($zip->set_number('0183321')->is_valid_number, '秋田県北秋田市松葉町');
ok($zip->set_number('0183322')->is_valid_number, '秋田県北秋田市住吉町');
ok($zip->set_number('0183323')->is_valid_number, '秋田県北秋田市米代町');
ok($zip->set_number('0183324')->is_valid_number, '秋田県北秋田市大町');
ok($zip->set_number('0183325')->is_valid_number, '秋田県北秋田市元町');
ok($zip->set_number('0183331')->is_valid_number, '秋田県北秋田市鷹巣(その他)');
ok($zip->set_number('0183332')->is_valid_number, '秋田県北秋田市鷹巣(平崎上岱)');
ok($zip->set_number('0183333')->is_valid_number, '秋田県北秋田市坊沢');
ok($zip->set_number('0183341')->is_valid_number, '秋田県北秋田市黒沢');
ok($zip->set_number('0183342')->is_valid_number, '秋田県北秋田市前山');
ok($zip->set_number('0183343')->is_valid_number, '秋田県北秋田市今泉');
ok($zip->set_number('0183451')->is_valid_number, '秋田県北秋田市小森');
ok($zip->set_number('0183452')->is_valid_number, '秋田県北秋田市七日市');
ok($zip->set_number('0183453')->is_valid_number, '秋田県北秋田市中屋敷');
ok($zip->set_number('0183454')->is_valid_number, '秋田県北秋田市脇神');
ok($zip->set_number('0183501')->is_valid_number, '秋田県大館市岩瀬');
ok($zip->set_number('0183502')->is_valid_number, '秋田県大館市山田');
ok($zip->set_number('0183503')->is_valid_number, '秋田県大館市外川原');
ok($zip->set_number('0183504')->is_valid_number, '秋田県大館市長坂');
ok($zip->set_number('0183505')->is_valid_number, '秋田県大館市早口');
ok($zip->set_number('0183506')->is_valid_number, '秋田県大館市山瀬');
ok($zip->set_number('0184201')->is_valid_number, '秋田県北秋田市増沢');
ok($zip->set_number('0184202')->is_valid_number, '秋田県北秋田市八幡岱新田');
ok($zip->set_number('0184203')->is_valid_number, '秋田県北秋田市木戸石');
ok($zip->set_number('0184211')->is_valid_number, '秋田県北秋田市川井');
ok($zip->set_number('0184221')->is_valid_number, '秋田県北秋田市下杉');
ok($zip->set_number('0184231')->is_valid_number, '秋田県北秋田市上杉');
ok($zip->set_number('0184241')->is_valid_number, '秋田県北秋田市道城');
ok($zip->set_number('0184251')->is_valid_number, '秋田県北秋田市鎌沢');
ok($zip->set_number('0184261')->is_valid_number, '秋田県北秋田市芹沢');
ok($zip->set_number('0184262')->is_valid_number, '秋田県北秋田市三里');
ok($zip->set_number('0184263')->is_valid_number, '秋田県北秋田市三木田');
ok($zip->set_number('0184271')->is_valid_number, '秋田県北秋田市福田');
ok($zip->set_number('0184272')->is_valid_number, '秋田県北秋田市新田目');
ok($zip->set_number('0184273')->is_valid_number, '秋田県北秋田市根田');
ok($zip->set_number('0184281')->is_valid_number, '秋田県北秋田市羽根山');
ok($zip->set_number('0184282')->is_valid_number, '秋田県北秋田市李岱');
ok($zip->set_number('0184301')->is_valid_number, '秋田県北秋田市米内沢');
ok($zip->set_number('0184302')->is_valid_number, '秋田県北秋田市浦田');
ok($zip->set_number('0184303')->is_valid_number, '秋田県北秋田市本城');
ok($zip->set_number('0184400')->is_valid_number, '秋田県北秋田郡上小阿仁村以下に掲載がない場合');
ok($zip->set_number('0184401')->is_valid_number, '秋田県北秋田郡上小阿仁村沖田面');
ok($zip->set_number('0184411')->is_valid_number, '秋田県北秋田郡上小阿仁村福舘');
ok($zip->set_number('0184412')->is_valid_number, '秋田県北秋田郡上小阿仁村五反沢');
ok($zip->set_number('0184413')->is_valid_number, '秋田県北秋田郡上小阿仁村杉花');
ok($zip->set_number('0184421')->is_valid_number, '秋田県北秋田郡上小阿仁村小沢田');
ok($zip->set_number('0184422')->is_valid_number, '秋田県北秋田郡上小阿仁村堂川');
ok($zip->set_number('0184423')->is_valid_number, '秋田県北秋田郡上小阿仁村仏社');
ok($zip->set_number('0184431')->is_valid_number, '秋田県北秋田郡上小阿仁村大林');
ok($zip->set_number('0184432')->is_valid_number, '秋田県北秋田郡上小阿仁村南沢');
ok($zip->set_number('0184511')->is_valid_number, '秋田県北秋田市森吉');
ok($zip->set_number('0184512')->is_valid_number, '秋田県北秋田市根森田');
ok($zip->set_number('0184513')->is_valid_number, '秋田県北秋田市小又');
ok($zip->set_number('0184514')->is_valid_number, '秋田県北秋田市五味堀');
ok($zip->set_number('0184515')->is_valid_number, '秋田県北秋田市阿仁前田');
ok($zip->set_number('0184516')->is_valid_number, '秋田県北秋田市桂瀬');
ok($zip->set_number('0184601')->is_valid_number, '秋田県北秋田市阿仁吉田');
ok($zip->set_number('0184602')->is_valid_number, '秋田県北秋田市阿仁小渕');
ok($zip->set_number('0184603')->is_valid_number, '秋田県北秋田市阿仁小様');
ok($zip->set_number('0184604')->is_valid_number, '秋田県北秋田市阿仁三枚鉱山');
ok($zip->set_number('0184611')->is_valid_number, '秋田県北秋田市阿仁水無');
ok($zip->set_number('0184612')->is_valid_number, '秋田県北秋田市阿仁真木沢鉱山');
ok($zip->set_number('0184613')->is_valid_number, '秋田県北秋田市阿仁銀山');
ok($zip->set_number('0184621')->is_valid_number, '秋田県北秋田市阿仁荒瀬');
ok($zip->set_number('0184622')->is_valid_number, '秋田県北秋田市阿仁小沢鉱山');
ok($zip->set_number('0184623')->is_valid_number, '秋田県北秋田市阿仁荒瀬川櫃畑');
ok($zip->set_number('0184624')->is_valid_number, '秋田県北秋田市阿仁鍵ノ滝');
ok($zip->set_number('0184731')->is_valid_number, '秋田県北秋田市阿仁打当');
ok($zip->set_number('0184732')->is_valid_number, '秋田県北秋田市阿仁中村');
ok($zip->set_number('0184733')->is_valid_number, '秋田県北秋田市阿仁戸鳥内');
ok($zip->set_number('0184734')->is_valid_number, '秋田県北秋田市阿仁長畑');
ok($zip->set_number('0184735')->is_valid_number, '秋田県北秋田市阿仁比立内');
ok($zip->set_number('0184741')->is_valid_number, '秋田県北秋田市阿仁幸屋');
ok($zip->set_number('0184742')->is_valid_number, '秋田県北秋田市阿仁幸屋渡');
ok($zip->set_number('0184743')->is_valid_number, '秋田県北秋田市阿仁笑内');
ok($zip->set_number('0184744')->is_valid_number, '秋田県北秋田市阿仁根子');
ok($zip->set_number('0184745')->is_valid_number, '秋田県北秋田市阿仁萱草');
ok($zip->set_number('0184746')->is_valid_number, '秋田県北秋田市阿仁伏影');
ok($zip->set_number('0185141')->is_valid_number, '秋田県鹿角市八幡平');
ok($zip->set_number('0185200')->is_valid_number, '秋田県鹿角市以下に掲載がない場合');
ok($zip->set_number('0185201')->is_valid_number, '秋田県鹿角市花輪');
ok($zip->set_number('0185202')->is_valid_number, '秋田県鹿角市尾去沢');
ok($zip->set_number('0185331')->is_valid_number, '秋田県鹿角市十和田山根');
ok($zip->set_number('0185332')->is_valid_number, '秋田県鹿角市十和田上向');
ok($zip->set_number('0185333')->is_valid_number, '秋田県鹿角市十和田岡田');
ok($zip->set_number('0185334')->is_valid_number, '秋田県鹿角市十和田毛馬内');
ok($zip->set_number('0185335')->is_valid_number, '秋田県鹿角市十和田瀬田石');
ok($zip->set_number('0185336')->is_valid_number, '秋田県鹿角市十和田錦木');
ok($zip->set_number('0185337')->is_valid_number, '秋田県鹿角市十和田末広');
ok($zip->set_number('0185421')->is_valid_number, '秋田県鹿角市十和田大湯');
ok($zip->set_number('0185422')->is_valid_number, '秋田県鹿角市十和田草木');
ok($zip->set_number('0185501')->is_valid_number, '青森県十和田市奥瀬(青撫、小畳石、十和田、十和田湖畔宇樽部、十和田湖畔子ノ口、');
ok($zip->set_number('0185501')->is_valid_number, '青森県十和田市十和田湖畔休屋)');
ok($zip->set_number('0185511')->is_valid_number, '秋田県鹿角郡小坂町十和田湖');
ok($zip->set_number('0185601')->is_valid_number, '秋田県大館市十二所');
ok($zip->set_number('0185602')->is_valid_number, '秋田県大館市道目木');
ok($zip->set_number('0185603')->is_valid_number, '秋田県大館市曲田');
ok($zip->set_number('0185604')->is_valid_number, '秋田県大館市軽井沢');
ok($zip->set_number('0185605')->is_valid_number, '秋田県大館市猿間');
ok($zip->set_number('0185606')->is_valid_number, '秋田県大館市葛原');
ok($zip->set_number('0185701')->is_valid_number, '秋田県大館市比内町扇田');
ok($zip->set_number('0185711')->is_valid_number, '秋田県大館市比内町味噌内');
ok($zip->set_number('0185712')->is_valid_number, '秋田県大館市比内町新館');
ok($zip->set_number('0185721')->is_valid_number, '秋田県大館市比内町独鈷');
ok($zip->set_number('0185722')->is_valid_number, '秋田県大館市比内町中野');
ok($zip->set_number('0185731')->is_valid_number, '秋田県大館市比内町笹館');
ok($zip->set_number('0185732')->is_valid_number, '秋田県大館市比内町谷地中');
ok($zip->set_number('0185741')->is_valid_number, '秋田県大館市比内町達子');
ok($zip->set_number('0185742')->is_valid_number, '秋田県大館市比内町白沢水沢');
ok($zip->set_number('0185743')->is_valid_number, '秋田県大館市比内町小坪沢');
ok($zip->set_number('0185744')->is_valid_number, '秋田県大館市比内町八木橋');
ok($zip->set_number('0185745')->is_valid_number, '秋田県大館市比内町片貝');
ok($zip->set_number('0185751')->is_valid_number, '秋田県大館市二井田');
ok($zip->set_number('0185752')->is_valid_number, '秋田県大館市本宮');
ok($zip->set_number('0185753')->is_valid_number, '秋田県大館市比内前田');
ok($zip->set_number('0185754')->is_valid_number, '秋田県大館市大子内');
ok($zip->set_number('0185755')->is_valid_number, '秋田県大館市杉沢');
ok($zip->set_number('0185756')->is_valid_number, '秋田県大館市下川原');
ok($zip->set_number('0185851')->is_valid_number, '秋田県大館市比内町大葛');
ok($zip->set_number('0190111')->is_valid_number, '秋田県湯沢市上院内');
ok($zip->set_number('0190112')->is_valid_number, '秋田県湯沢市下院内');
ok($zip->set_number('0190113')->is_valid_number, '秋田県湯沢市院内銀山町');
ok($zip->set_number('0190201')->is_valid_number, '秋田県湯沢市泉沢');
ok($zip->set_number('0190202')->is_valid_number, '秋田県湯沢市桑崎');
ok($zip->set_number('0190203')->is_valid_number, '秋田県湯沢市寺沢');
ok($zip->set_number('0190204')->is_valid_number, '秋田県湯沢市横堀');
ok($zip->set_number('0190205')->is_valid_number, '秋田県湯沢市小野');
ok($zip->set_number('0190321')->is_valid_number, '秋田県湯沢市秋ノ宮');
ok($zip->set_number('0190401')->is_valid_number, '秋田県湯沢市酒蒔');
ok($zip->set_number('0190402')->is_valid_number, '秋田県湯沢市相川');
ok($zip->set_number('0190403')->is_valid_number, '秋田県湯沢市宇留院内');
ok($zip->set_number('0190404')->is_valid_number, '秋田県湯沢市高松');
ok($zip->set_number('0190481')->is_valid_number, '秋田県湯沢市皆瀬(水上沢)');
ok($zip->set_number('0190501')->is_valid_number, '秋田県横手市十文字町腕越');
ok($zip->set_number('0190502')->is_valid_number, '秋田県横手市十文字町西原2番町');
ok($zip->set_number('0190503')->is_valid_number, '秋田県横手市十文字町西原1番町');
ok($zip->set_number('0190505')->is_valid_number, '秋田県横手市十文字町仁井田');
ok($zip->set_number('0190506')->is_valid_number, '秋田県横手市十文字町佐賀会');
ok($zip->set_number('0190507')->is_valid_number, '秋田県横手市十文字町上鍋倉');
ok($zip->set_number('0190508')->is_valid_number, '秋田県横手市十文字町十五野新田');
ok($zip->set_number('0190509')->is_valid_number, '秋田県横手市十文字町梨木');
ok($zip->set_number('0190511')->is_valid_number, '秋田県横手市十文字町鼎');
ok($zip->set_number('0190512')->is_valid_number, '秋田県横手市十文字町越前');
ok($zip->set_number('0190513')->is_valid_number, '秋田県横手市十文字町植田');
ok($zip->set_number('0190514')->is_valid_number, '秋田県横手市十文字町睦合');
ok($zip->set_number('0190515')->is_valid_number, '秋田県横手市十文字町谷地新田');
ok($zip->set_number('0190516')->is_valid_number, '秋田県横手市十文字町源太左馬');
ok($zip->set_number('0190517')->is_valid_number, '秋田県横手市十文字町木下');
ok($zip->set_number('0190518')->is_valid_number, '秋田県横手市十文字町宝竜');
ok($zip->set_number('0190521')->is_valid_number, '秋田県横手市十文字町西下');
ok($zip->set_number('0190522')->is_valid_number, '秋田県横手市十文字町西上');
ok($zip->set_number('0190523')->is_valid_number, '秋田県横手市十文字町十文字');
ok($zip->set_number('0190524')->is_valid_number, '秋田県横手市十文字町本町');
ok($zip->set_number('0190525')->is_valid_number, '秋田県横手市十文字町曙町');
ok($zip->set_number('0190526')->is_valid_number, '秋田県横手市十文字町通町');
ok($zip->set_number('0190527')->is_valid_number, '秋田県横手市十文字町大道東');
ok($zip->set_number('0190528')->is_valid_number, '秋田県横手市十文字町栄町');
ok($zip->set_number('0190529')->is_valid_number, '秋田県横手市十文字町海道下');
ok($zip->set_number('0190531')->is_valid_number, '秋田県横手市十文字町上佐吉開');
ok($zip->set_number('0190532')->is_valid_number, '秋田県横手市十文字町麻当');
ok($zip->set_number('0190533')->is_valid_number, '秋田県横手市十文字町下佐吉開');
ok($zip->set_number('0190701')->is_valid_number, '秋田県横手市増田町増田');
ok($zip->set_number('0190702')->is_valid_number, '秋田県横手市増田町亀田');
ok($zip->set_number('0190703')->is_valid_number, '秋田県横手市増田町吉野');
ok($zip->set_number('0190704')->is_valid_number, '秋田県横手市増田町湯野沢');
ok($zip->set_number('0190705')->is_valid_number, '秋田県横手市増田町狙半内');
ok($zip->set_number('0190711')->is_valid_number, '秋田県横手市増田町荻袋');
ok($zip->set_number('0190712')->is_valid_number, '秋田県横手市増田町熊渕');
ok($zip->set_number('0190713')->is_valid_number, '秋田県横手市増田町三又');
ok($zip->set_number('0190714')->is_valid_number, '秋田県横手市増田町戸波');
ok($zip->set_number('0190715')->is_valid_number, '秋田県横手市増田町八木');
ok($zip->set_number('0190800')->is_valid_number, '秋田県雄勝郡東成瀬村以下に掲載がない場合');
ok($zip->set_number('0190801')->is_valid_number, '秋田県雄勝郡東成瀬村田子内');
ok($zip->set_number('0190802')->is_valid_number, '秋田県雄勝郡東成瀬村岩井川');
ok($zip->set_number('0190803')->is_valid_number, '秋田県雄勝郡東成瀬村椿川');
ok($zip->set_number('0191101')->is_valid_number, '秋田県横手市山内大松川');
ok($zip->set_number('0191102')->is_valid_number, '秋田県横手市山内小松川');
ok($zip->set_number('0191103')->is_valid_number, '秋田県横手市山内黒沢');
ok($zip->set_number('0191104')->is_valid_number, '秋田県横手市山内三又');
ok($zip->set_number('0191105')->is_valid_number, '秋田県横手市山内南郷');
ok($zip->set_number('0191106')->is_valid_number, '秋田県横手市山内平野沢');
ok($zip->set_number('0191107')->is_valid_number, '秋田県横手市山内筏');
ok($zip->set_number('0191108')->is_valid_number, '秋田県横手市山内土渕');
ok($zip->set_number('0191109')->is_valid_number, '秋田県横手市山内大沢');
ok($zip->set_number('0191231')->is_valid_number, '秋田県仙北郡美郷町南町');
ok($zip->set_number('0191232')->is_valid_number, '秋田県仙北郡美郷町天神堂');
ok($zip->set_number('0191233')->is_valid_number, '秋田県仙北郡美郷町境田');
ok($zip->set_number('0191234')->is_valid_number, '秋田県仙北郡美郷町飯詰');
ok($zip->set_number('0191235')->is_valid_number, '秋田県仙北郡美郷町金沢西根');
ok($zip->set_number('0191236')->is_valid_number, '秋田県仙北郡美郷町上深井');
ok($zip->set_number('0191237')->is_valid_number, '秋田県仙北郡美郷町佐野');
ok($zip->set_number('0191301')->is_valid_number, '秋田県仙北郡美郷町野荒町');
ok($zip->set_number('0191302')->is_valid_number, '秋田県仙北郡美郷町金沢');
ok($zip->set_number('0191400')->is_valid_number, '秋田県仙北郡美郷町以下に掲載がない場合');
ok($zip->set_number('0191401')->is_valid_number, '秋田県仙北郡美郷町鑓田');
ok($zip->set_number('0191402')->is_valid_number, '秋田県仙北郡美郷町野中');
ok($zip->set_number('0191403')->is_valid_number, '秋田県仙北郡美郷町六郷東根');
ok($zip->set_number('0191404')->is_valid_number, '秋田県仙北郡美郷町六郷');
ok($zip->set_number('0191501')->is_valid_number, '秋田県仙北郡美郷町浪花');
ok($zip->set_number('0191502')->is_valid_number, '秋田県仙北郡美郷町千屋');
ok($zip->set_number('0191511')->is_valid_number, '秋田県仙北郡美郷町黒沢');
ok($zip->set_number('0191512')->is_valid_number, '秋田県仙北郡美郷町本堂城回');
ok($zip->set_number('0191521')->is_valid_number, '秋田県仙北郡美郷町中野');
ok($zip->set_number('0191522')->is_valid_number, '秋田県仙北郡美郷町金沢東根');
ok($zip->set_number('0191531')->is_valid_number, '秋田県仙北郡美郷町畑屋');
ok($zip->set_number('0191532')->is_valid_number, '秋田県仙北郡美郷町羽貫谷地');
ok($zip->set_number('0191533')->is_valid_number, '秋田県仙北郡美郷町安城寺');
ok($zip->set_number('0191541')->is_valid_number, '秋田県仙北郡美郷町土崎');
ok($zip->set_number('0191542')->is_valid_number, '秋田県仙北郡美郷町小荒川');
ok($zip->set_number('0191601')->is_valid_number, '秋田県大仙市太田町横沢');
ok($zip->set_number('0191602')->is_valid_number, '秋田県大仙市太田町三本扇');
ok($zip->set_number('0191603')->is_valid_number, '秋田県大仙市太田町中里');
ok($zip->set_number('0191604')->is_valid_number, '秋田県大仙市太田町駒場');
ok($zip->set_number('0191605')->is_valid_number, '秋田県大仙市太田町国見');
ok($zip->set_number('0191611')->is_valid_number, '秋田県大仙市太田町斉内');
ok($zip->set_number('0191612')->is_valid_number, '秋田県大仙市太田町小神成');
ok($zip->set_number('0191613')->is_valid_number, '秋田県大仙市太田町太田');
ok($zip->set_number('0191614')->is_valid_number, '秋田県大仙市太田町東今泉');
ok($zip->set_number('0191615')->is_valid_number, '秋田県大仙市太田町川口');
ok($zip->set_number('0191616')->is_valid_number, '秋田県大仙市太田町永代');
ok($zip->set_number('0191701')->is_valid_number, '秋田県大仙市神宮寺');
ok($zip->set_number('0191702')->is_valid_number, '秋田県大仙市北楢岡');
ok($zip->set_number('0191801')->is_valid_number, '秋田県大仙市南外物渡台');
ok($zip->set_number('0191802')->is_valid_number, '秋田県大仙市南外小春木沢');
ok($zip->set_number('0191803')->is_valid_number, '秋田県大仙市南外坊田石兀ノ下');
ok($zip->set_number('0191804')->is_valid_number, '秋田県大仙市南外西野');
ok($zip->set_number('0191805')->is_valid_number, '秋田県大仙市南外西板戸');
ok($zip->set_number('0191806')->is_valid_number, '秋田県大仙市南外十二袋');
ok($zip->set_number('0191807')->is_valid_number, '秋田県大仙市南外川口本町');
ok($zip->set_number('0191808')->is_valid_number, '秋田県大仙市南外川口');
ok($zip->set_number('0191811')->is_valid_number, '秋田県大仙市南外本宿');
ok($zip->set_number('0191812')->is_valid_number, '秋田県大仙市南外沖田');
ok($zip->set_number('0191813')->is_valid_number, '秋田県大仙市南外猿ケ瀬出野');
ok($zip->set_number('0191814')->is_valid_number, '秋田県大仙市南外下木直');
ok($zip->set_number('0191815')->is_valid_number, '秋田県大仙市南外平形');
ok($zip->set_number('0191816')->is_valid_number, '秋田県大仙市南外上木直');
ok($zip->set_number('0191817')->is_valid_number, '秋田県大仙市南外木直沢');
ok($zip->set_number('0191822')->is_valid_number, '秋田県大仙市南外田屋村');
ok($zip->set_number('0191824')->is_valid_number, '秋田県大仙市南外宮田');
ok($zip->set_number('0191825')->is_valid_number, '秋田県大仙市南外坊田');
ok($zip->set_number('0191826')->is_valid_number, '秋田県大仙市南外田中田');
ok($zip->set_number('0191827')->is_valid_number, '秋田県大仙市南外田中田山根');
ok($zip->set_number('0191831')->is_valid_number, '秋田県大仙市南外壇ノ平山');
ok($zip->set_number('0191832')->is_valid_number, '秋田県大仙市南外北田山田ケ沢');
ok($zip->set_number('0191834')->is_valid_number, '秋田県大仙市南外揚土山');
ok($zip->set_number('0191834')->is_valid_number, '秋田県大仙市南外北田黒瀬');
ok($zip->set_number('0191835')->is_valid_number, '秋田県大仙市南外揚土');
ok($zip->set_number('0191841')->is_valid_number, '秋田県大仙市南外大杉山岸');
ok($zip->set_number('0191842')->is_valid_number, '秋田県大仙市南外大杉');
ok($zip->set_number('0191843')->is_valid_number, '秋田県大仙市南外大杉二タ又杉');
ok($zip->set_number('0191846')->is_valid_number, '秋田県大仙市南外梨木田');
ok($zip->set_number('0191847')->is_valid_number, '秋田県大仙市南外小出');
ok($zip->set_number('0191848')->is_valid_number, '秋田県大仙市南外鞦田');
ok($zip->set_number('0191851')->is_valid_number, '秋田県大仙市南外山王台');
ok($zip->set_number('0191852')->is_valid_number, '秋田県大仙市南外太田');
ok($zip->set_number('0191853')->is_valid_number, '秋田県大仙市南外坊田黒沢');
ok($zip->set_number('0191855')->is_valid_number, '秋田県大仙市南外大畑');
ok($zip->set_number('0191856')->is_valid_number, '秋田県大仙市南外大畑深山');
ok($zip->set_number('0191857')->is_valid_number, '秋田県大仙市南外大畑潜沢');
ok($zip->set_number('0191858')->is_valid_number, '秋田県大仙市南外赤平六郎沢');
ok($zip->set_number('0191861')->is_valid_number, '秋田県大仙市南外寺沢');
ok($zip->set_number('0191862')->is_valid_number, '秋田県大仙市南外和合');
ok($zip->set_number('0191863')->is_valid_number, '秋田県大仙市南外赤平貝沼');
ok($zip->set_number('0191864')->is_valid_number, '秋田県大仙市南外赤平大道東');
ok($zip->set_number('0191865')->is_valid_number, '秋田県大仙市南外赤平後野');
ok($zip->set_number('0191866')->is_valid_number, '秋田県大仙市南外赤平台野');
ok($zip->set_number('0191868')->is_valid_number, '秋田県大仙市南外赤平平家');
ok($zip->set_number('0191871')->is_valid_number, '秋田県大仙市南外谷地田');
ok($zip->set_number('0191872')->is_valid_number, '秋田県大仙市南外上中宿');
ok($zip->set_number('0191873')->is_valid_number, '秋田県大仙市南外田中');
ok($zip->set_number('0191874')->is_valid_number, '秋田県大仙市南外中宿');
ok($zip->set_number('0191875')->is_valid_number, '秋田県大仙市南外落合');
ok($zip->set_number('0191876')->is_valid_number, '秋田県大仙市南外新屋布');
ok($zip->set_number('0191877')->is_valid_number, '秋田県大仙市南外水沢');
ok($zip->set_number('0191878')->is_valid_number, '秋田県大仙市南外及位');
ok($zip->set_number('0191881')->is_valid_number, '秋田県大仙市南外葎沢');
ok($zip->set_number('0191882')->is_valid_number, '秋田県大仙市南外大和野');
ok($zip->set_number('0191883')->is_valid_number, '秋田県大仙市南外平沢');
ok($zip->set_number('0191884')->is_valid_number, '秋田県大仙市南外林ノ沢');
ok($zip->set_number('0191885')->is_valid_number, '秋田県大仙市南外無尻橋');
ok($zip->set_number('0191886')->is_valid_number, '秋田県大仙市南外西ノ又');
ok($zip->set_number('0191887')->is_valid_number, '秋田県大仙市南外中渡');
ok($zip->set_number('0191888')->is_valid_number, '秋田県大仙市南外土場');
ok($zip->set_number('0191901')->is_valid_number, '秋田県大仙市南外悪戸野');
ok($zip->set_number('0191902')->is_valid_number, '秋田県大仙市南外下袋');
ok($zip->set_number('0191903')->is_valid_number, '秋田県大仙市南外下鎌田');
ok($zip->set_number('0191904')->is_valid_number, '秋田県大仙市南外中袋');
ok($zip->set_number('0191905')->is_valid_number, '秋田県大仙市南外大向');
ok($zip->set_number('0191906')->is_valid_number, '秋田県大仙市南外金屋');
ok($zip->set_number('0191907')->is_valid_number, '秋田県大仙市南外上鎌田');
ok($zip->set_number('0191908')->is_valid_number, '秋田県大仙市南外上野');
ok($zip->set_number('0191909')->is_valid_number, '秋田県大仙市南外杉橋');
ok($zip->set_number('0191911')->is_valid_number, '秋田県大仙市南外坊村');
ok($zip->set_number('0191912')->is_valid_number, '秋田県大仙市南外丸木橋');
ok($zip->set_number('0191913')->is_valid_number, '秋田県大仙市南外湯神台');
ok($zip->set_number('0191914')->is_valid_number, '秋田県大仙市南外湯ノ又');
ok($zip->set_number('0191915')->is_valid_number, '秋田県大仙市南外下湯ノ又');
ok($zip->set_number('0191916')->is_valid_number, '秋田県大仙市南外石仏');
ok($zip->set_number('0191917')->is_valid_number, '秋田県大仙市南外薬師堂');
ok($zip->set_number('0191918')->is_valid_number, '秋田県大仙市南外広表');
ok($zip->set_number('0191921')->is_valid_number, '秋田県大仙市南外中野');
ok($zip->set_number('0191922')->is_valid_number, '秋田県大仙市南外上中野');
ok($zip->set_number('0191923')->is_valid_number, '秋田県大仙市南外巣ノ沢');
ok($zip->set_number('0191924')->is_valid_number, '秋田県大仙市南外巣ノ沢石切場');
ok($zip->set_number('0191925')->is_valid_number, '秋田県大仙市南外上巣ノ沢');
ok($zip->set_number('0191926')->is_valid_number, '秋田県大仙市南外上桑台');
ok($zip->set_number('0191927')->is_valid_number, '秋田県大仙市南外中桑台');
ok($zip->set_number('0191928')->is_valid_number, '秋田県大仙市南外滝中田表');
ok($zip->set_number('0191929')->is_valid_number, '秋田県大仙市南外中野山');
ok($zip->set_number('0191931')->is_valid_number, '秋田県大仙市南外下滝');
ok($zip->set_number('0191932')->is_valid_number, '秋田県大仙市南外大黒森');
ok($zip->set_number('0191933')->is_valid_number, '秋田県大仙市南外滝ノ沢');
ok($zip->set_number('0191934')->is_valid_number, '秋田県大仙市南外田尻');
ok($zip->set_number('0191935')->is_valid_number, '秋田県大仙市南外大平');
ok($zip->set_number('0191936')->is_valid_number, '秋田県大仙市南外中荒沢');
ok($zip->set_number('0191937')->is_valid_number, '秋田県大仙市南外小荒沢');
ok($zip->set_number('0191938')->is_valid_number, '秋田県大仙市南外下荒沢');
ok($zip->set_number('0191939')->is_valid_number, '秋田県大仙市南外水上沢');
ok($zip->set_number('0191941')->is_valid_number, '秋田県大仙市南外松木田');
ok($zip->set_number('0191942')->is_valid_number, '秋田県大仙市南外岩倉');
ok($zip->set_number('0191943')->is_valid_number, '秋田県大仙市南外一ト刎');
ok($zip->set_number('0191944')->is_valid_number, '秋田県大仙市南外湯元');
ok($zip->set_number('0191945')->is_valid_number, '秋田県大仙市南外岩瀬');
ok($zip->set_number('0191946')->is_valid_number, '秋田県大仙市南外十二ノ前');
ok($zip->set_number('0191947')->is_valid_number, '秋田県大仙市南外下釜坂');
ok($zip->set_number('0191948')->is_valid_number, '秋田県大仙市南外上釜坂');
ok($zip->set_number('0191949')->is_valid_number, '秋田県大仙市南外赤畑');
ok($zip->set_number('0191951')->is_valid_number, '秋田県大仙市南外黒滝');
ok($zip->set_number('0191952')->is_valid_number, '秋田県大仙市南外下荒又');
ok($zip->set_number('0191953')->is_valid_number, '秋田県大仙市南外外小友');
ok($zip->set_number('0191954')->is_valid_number, '秋田県大仙市南外中荒又');
ok($zip->set_number('0191955')->is_valid_number, '秋田県大仙市南外外山');
ok($zip->set_number('0191956')->is_valid_number, '秋田県大仙市南外上荒又');
ok($zip->set_number('0191957')->is_valid_number, '秋田県大仙市南外小浪滝');
ok($zip->set_number('0191958')->is_valid_number, '秋田県大仙市南外向ノ沢');
ok($zip->set_number('0191961')->is_valid_number, '秋田県大仙市南外大柳');
ok($zip->set_number('0191962')->is_valid_number, '秋田県大仙市南外若林');
ok($zip->set_number('0191963')->is_valid_number, '秋田県大仙市南外西ノ又滝ノ沢');
ok($zip->set_number('0192103')->is_valid_number, '秋田県大仙市大沢郷寺');
ok($zip->set_number('0192111')->is_valid_number, '秋田県大仙市土川');
ok($zip->set_number('0192112')->is_valid_number, '秋田県大仙市刈和野');
ok($zip->set_number('0192121')->is_valid_number, '秋田県大仙市北野目');
ok($zip->set_number('0192122')->is_valid_number, '秋田県大仙市高城');
ok($zip->set_number('0192123')->is_valid_number, '秋田県大仙市寺館');
ok($zip->set_number('0192201')->is_valid_number, '秋田県大仙市円行寺');
ok($zip->set_number('0192202')->is_valid_number, '秋田県大仙市大沢郷宿');
ok($zip->set_number('0192204')->is_valid_number, '秋田県大仙市正手沢');
ok($zip->set_number('0192205')->is_valid_number, '秋田県大仙市杉山田');
ok($zip->set_number('0192331')->is_valid_number, '秋田県大仙市大巻');
ok($zip->set_number('0192332')->is_valid_number, '秋田県大仙市九升田');
ok($zip->set_number('0192333')->is_valid_number, '秋田県大仙市金山沢');
ok($zip->set_number('0192334')->is_valid_number, '秋田県大仙市木原田');
ok($zip->set_number('0192335')->is_valid_number, '秋田県大仙市強首');
ok($zip->set_number('0192401')->is_valid_number, '秋田県大仙市協和船岡');
ok($zip->set_number('0192402')->is_valid_number, '秋田県大仙市協和船沢');
ok($zip->set_number('0192411')->is_valid_number, '秋田県大仙市協和境');
ok($zip->set_number('0192412')->is_valid_number, '秋田県大仙市協和荒川');
ok($zip->set_number('0192413')->is_valid_number, '秋田県大仙市協和上淀川');
ok($zip->set_number('0192431')->is_valid_number, '秋田県大仙市協和峰吉川');
ok($zip->set_number('0192441')->is_valid_number, '秋田県大仙市協和小種');
ok($zip->set_number('0192442')->is_valid_number, '秋田県大仙市協和下淀川');
ok($zip->set_number('0192443')->is_valid_number, '秋田県大仙市協和中淀川');
ok($zip->set_number('0192521')->is_valid_number, '秋田県大仙市協和稲沢');
ok($zip->set_number('0192601')->is_valid_number, '秋田県秋田市河辺和田');
ok($zip->set_number('0192611')->is_valid_number, '秋田県秋田市河辺戸島');
ok($zip->set_number('0192612')->is_valid_number, '秋田県秋田市河辺畑谷');
ok($zip->set_number('0192613')->is_valid_number, '秋田県秋田市河辺松渕');
ok($zip->set_number('0192614')->is_valid_number, '秋田県秋田市河辺豊成');
ok($zip->set_number('0192621')->is_valid_number, '秋田県秋田市河辺諸井');
ok($zip->set_number('0192622')->is_valid_number, '秋田県秋田市河辺高岡');
ok($zip->set_number('0192623')->is_valid_number, '秋田県秋田市河辺赤平');
ok($zip->set_number('0192624')->is_valid_number, '秋田県秋田市河辺大沢');
ok($zip->set_number('0192625')->is_valid_number, '秋田県秋田市河辺北野田高屋');
ok($zip->set_number('0192631')->is_valid_number, '秋田県秋田市河辺神内');
ok($zip->set_number('0192632')->is_valid_number, '秋田県秋田市河辺大張野');
ok($zip->set_number('0192741')->is_valid_number, '秋田県秋田市河辺岩見');
ok($zip->set_number('0192742')->is_valid_number, '秋田県秋田市河辺三内');
ok($zip->set_number('0200000')->is_valid_number, '岩手県盛岡市以下に掲載がない場合');
ok($zip->set_number('0200001')->is_valid_number, '岩手県盛岡市上米内');
ok($zip->set_number('0200002')->is_valid_number, '岩手県盛岡市桜台');
ok($zip->set_number('0200003')->is_valid_number, '岩手県盛岡市下米内');
ok($zip->set_number('0200004')->is_valid_number, '岩手県盛岡市山岸');
ok($zip->set_number('0200005')->is_valid_number, '岩手県盛岡市紅葉が丘');
ok($zip->set_number('0200011')->is_valid_number, '岩手県盛岡市三ツ割');
ok($zip->set_number('0200012')->is_valid_number, '岩手県盛岡市岩清水');
ok($zip->set_number('0200013')->is_valid_number, '岩手県盛岡市愛宕町');
ok($zip->set_number('0200014')->is_valid_number, '岩手県盛岡市愛宕下');
ok($zip->set_number('0200015')->is_valid_number, '岩手県盛岡市本町通');
ok($zip->set_number('0200016')->is_valid_number, '岩手県盛岡市名須川町');
ok($zip->set_number('0200021')->is_valid_number, '岩手県盛岡市中央通');
ok($zip->set_number('0200022')->is_valid_number, '岩手県盛岡市大通');
ok($zip->set_number('0200023')->is_valid_number, '岩手県盛岡市内丸');
ok($zip->set_number('0200024')->is_valid_number, '岩手県盛岡市菜園');
ok($zip->set_number('0200025')->is_valid_number, '岩手県盛岡市大沢川原');
ok($zip->set_number('0200026')->is_valid_number, '岩手県盛岡市開運橋通');
ok($zip->set_number('0200031')->is_valid_number, '岩手県盛岡市北夕顔瀬町');
ok($zip->set_number('0200032')->is_valid_number, '岩手県盛岡市夕顔瀬町');
ok($zip->set_number('0200033')->is_valid_number, '岩手県盛岡市盛岡駅前北通');
ok($zip->set_number('0200034')->is_valid_number, '岩手県盛岡市盛岡駅前通');
ok($zip->set_number('0200041')->is_valid_number, '岩手県盛岡市境田町');
ok($zip->set_number('0200042')->is_valid_number, '岩手県盛岡市新田町');
ok($zip->set_number('0200043')->is_valid_number, '岩手県盛岡市中川町');
ok($zip->set_number('0200044')->is_valid_number, '岩手県盛岡市城西町');
ok($zip->set_number('0200045')->is_valid_number, '岩手県盛岡市盛岡駅西通');
ok($zip->set_number('0200051')->is_valid_number, '岩手県盛岡市下太田');
ok($zip->set_number('0200052')->is_valid_number, '岩手県盛岡市中太田');
ok($zip->set_number('0200053')->is_valid_number, '岩手県盛岡市上太田');
ok($zip->set_number('0200054')->is_valid_number, '岩手県盛岡市猪去');
ok($zip->set_number('0200055')->is_valid_number, '岩手県盛岡市繋');
ok($zip->set_number('0200061')->is_valid_number, '岩手県盛岡市北山');
ok($zip->set_number('0200062')->is_valid_number, '岩手県盛岡市長田町');
ok($zip->set_number('0200063')->is_valid_number, '岩手県盛岡市材木町');
ok($zip->set_number('0200064')->is_valid_number, '岩手県盛岡市梨木町');
ok($zip->set_number('0200065')->is_valid_number, '岩手県盛岡市西下台町');
ok($zip->set_number('0200066')->is_valid_number, '岩手県盛岡市上田(1~4丁目、北山)');
ok($zip->set_number('0200101')->is_valid_number, '岩手県盛岡市岩脇町');
ok($zip->set_number('0200102')->is_valid_number, '岩手県盛岡市上田(その他)');
ok($zip->set_number('0200103')->is_valid_number, '岩手県盛岡市西松園');
ok($zip->set_number('0200104')->is_valid_number, '岩手県盛岡市小鳥沢');
ok($zip->set_number('0200105')->is_valid_number, '岩手県盛岡市北松園');
ok($zip->set_number('0200106')->is_valid_number, '岩手県盛岡市東松園');
ok($zip->set_number('0200107')->is_valid_number, '岩手県盛岡市松園');
ok($zip->set_number('0200108')->is_valid_number, '岩手県盛岡市東黒石野');
ok($zip->set_number('0200111')->is_valid_number, '岩手県盛岡市黒石野');
ok($zip->set_number('0200112')->is_valid_number, '岩手県盛岡市東緑が丘');
ok($zip->set_number('0200113')->is_valid_number, '岩手県盛岡市上田堤');
ok($zip->set_number('0200114')->is_valid_number, '岩手県盛岡市高松');
ok($zip->set_number('0200115')->is_valid_number, '岩手県盛岡市館向町');
ok($zip->set_number('0200116')->is_valid_number, '岩手県盛岡市箱清水');
ok($zip->set_number('0200117')->is_valid_number, '岩手県盛岡市緑が丘');
ok($zip->set_number('0200121')->is_valid_number, '岩手県盛岡市月が丘');
ok($zip->set_number('0200122')->is_valid_number, '岩手県盛岡市みたけ');
ok($zip->set_number('0200123')->is_valid_number, '岩手県盛岡市下厨川');
ok($zip->set_number('0200124')->is_valid_number, '岩手県盛岡市厨川');
ok($zip->set_number('0200125')->is_valid_number, '岩手県盛岡市上堂');
ok($zip->set_number('0200126')->is_valid_number, '岩手県盛岡市安倍館町');
ok($zip->set_number('0200127')->is_valid_number, '岩手県盛岡市前九年');
ok($zip->set_number('0200131')->is_valid_number, '岩手県盛岡市中堤町');
ok($zip->set_number('0200132')->is_valid_number, '岩手県盛岡市西青山');
ok($zip->set_number('0200133')->is_valid_number, '岩手県盛岡市青山');
ok($zip->set_number('0200134')->is_valid_number, '岩手県盛岡市南青山町');
ok($zip->set_number('0200135')->is_valid_number, '岩手県盛岡市大新町');
ok($zip->set_number('0200136')->is_valid_number, '岩手県盛岡市北天昌寺町');
ok($zip->set_number('0200137')->is_valid_number, '岩手県盛岡市天昌寺町');
ok($zip->set_number('0200141')->is_valid_number, '岩手県盛岡市中屋敷町');
ok($zip->set_number('0200142')->is_valid_number, '岩手県盛岡市稲荷町');
ok($zip->set_number('0200143')->is_valid_number, '岩手県盛岡市上厨川');
ok($zip->set_number('0200144')->is_valid_number, '岩手県盛岡市土淵');
ok($zip->set_number('0200145')->is_valid_number, '岩手県盛岡市平賀新田');
ok($zip->set_number('0200146')->is_valid_number, '岩手県盛岡市長橋町');
ok($zip->set_number('0200147')->is_valid_number, '岩手県盛岡市大館町');
ok($zip->set_number('0200148')->is_valid_number, '岩手県盛岡市前潟');
ok($zip->set_number('0200201')->is_valid_number, '岩手県盛岡市日戸');
ok($zip->set_number('0200202')->is_valid_number, '岩手県盛岡市玉山');
ok($zip->set_number('0200203')->is_valid_number, '岩手県盛岡市川又');
ok($zip->set_number('0200204')->is_valid_number, '岩手県盛岡市上田(糠森、小野松)');
ok($zip->set_number('0200311')->is_valid_number, '岩手県盛岡市簗川');
ok($zip->set_number('0200312')->is_valid_number, '岩手県盛岡市砂子沢');
ok($zip->set_number('0200313')->is_valid_number, '岩手県盛岡市根田茂');
ok($zip->set_number('0200401')->is_valid_number, '岩手県盛岡市手代森');
ok($zip->set_number('0200402')->is_valid_number, '岩手県盛岡市黒川');
ok($zip->set_number('0200403')->is_valid_number, '岩手県盛岡市乙部');
ok($zip->set_number('0200404')->is_valid_number, '岩手県盛岡市大ケ生');
ok($zip->set_number('0200500')->is_valid_number, '岩手県岩手郡雫石町以下に掲載がない場合');
ok($zip->set_number('0200501')->is_valid_number, '岩手県岩手郡雫石町仁佐瀬');
ok($zip->set_number('0200502')->is_valid_number, '岩手県岩手郡雫石町板橋');
ok($zip->set_number('0200503')->is_valid_number, '岩手県岩手郡雫石町七ツ森');
ok($zip->set_number('0200504')->is_valid_number, '岩手県岩手郡雫石町中沼');
ok($zip->set_number('0200505')->is_valid_number, '岩手県岩手郡雫石町中黒沢川');
ok($zip->set_number('0200506')->is_valid_number, '岩手県岩手郡雫石町沼返');
ok($zip->set_number('0200507')->is_valid_number, '岩手県岩手郡雫石町丸谷地');
ok($zip->set_number('0200511')->is_valid_number, '岩手県岩手郡雫石町長畑');
ok($zip->set_number('0200512')->is_valid_number, '岩手県岩手郡雫石町塩ケ森');
ok($zip->set_number('0200513')->is_valid_number, '岩手県岩手郡雫石町下兎野');
ok($zip->set_number('0200514')->is_valid_number, '岩手県岩手郡雫石町野中');
ok($zip->set_number('0200515')->is_valid_number, '岩手県岩手郡雫石町下長根');
ok($zip->set_number('0200517')->is_valid_number, '岩手県岩手郡雫石町黒沢川');
ok($zip->set_number('0200520')->is_valid_number, '岩手県岩手郡雫石町下町東');
ok($zip->set_number('0200521')->is_valid_number, '岩手県岩手郡雫石町麁津田');
ok($zip->set_number('0200522')->is_valid_number, '岩手県岩手郡雫石町下久保');
ok($zip->set_number('0200523')->is_valid_number, '岩手県岩手郡雫石町根堀');
ok($zip->set_number('0200524')->is_valid_number, '岩手県岩手郡雫石町寺の下');
ok($zip->set_number('0200525')->is_valid_number, '岩手県岩手郡雫石町源大堂');
ok($zip->set_number('0200527')->is_valid_number, '岩手県岩手郡雫石町中町');
ok($zip->set_number('0200528')->is_valid_number, '岩手県岩手郡雫石町下町');
ok($zip->set_number('0200529')->is_valid_number, '岩手県岩手郡雫石町下町西');
ok($zip->set_number('0200530')->is_valid_number, '岩手県岩手郡雫石町上町南');
ok($zip->set_number('0200531')->is_valid_number, '岩手県岩手郡雫石町麻見田');
ok($zip->set_number('0200532')->is_valid_number, '岩手県岩手郡雫石町払川');
ok($zip->set_number('0200533')->is_valid_number, '岩手県岩手郡雫石町林');
ok($zip->set_number('0200534')->is_valid_number, '岩手県岩手郡雫石町川原');
ok($zip->set_number('0200535')->is_valid_number, '岩手県岩手郡雫石町小日谷地');
ok($zip->set_number('0200536')->is_valid_number, '岩手県岩手郡雫石町八卦');
ok($zip->set_number('0200537')->is_valid_number, '岩手県岩手郡雫石町上町西');
ok($zip->set_number('0200538')->is_valid_number, '岩手県岩手郡雫石町上町北');
ok($zip->set_number('0200539')->is_valid_number, '岩手県岩手郡雫石町上町東');
ok($zip->set_number('0200541')->is_valid_number, '岩手県岩手郡雫石町千刈田');
ok($zip->set_number('0200542')->is_valid_number, '岩手県岩手郡雫石町万田渡');
ok($zip->set_number('0200543')->is_valid_number, '岩手県岩手郡雫石町高前田');
ok($zip->set_number('0200544')->is_valid_number, '岩手県岩手郡雫石町柿木');
ok($zip->set_number('0200545')->is_valid_number, '岩手県岩手郡雫石町谷地');
ok($zip->set_number('0200546')->is_valid_number, '岩手県岩手郡雫石町稲荷下');
ok($zip->set_number('0200547')->is_valid_number, '岩手県岩手郡雫石町晴山');
ok($zip->set_number('0200551')->is_valid_number, '岩手県岩手郡雫石町笹森');
ok($zip->set_number('0200552')->is_valid_number, '岩手県岩手郡雫石町下平');
ok($zip->set_number('0200553')->is_valid_number, '岩手県岩手郡雫石町下曽根田');
ok($zip->set_number('0200554')->is_valid_number, '岩手県岩手郡雫石町町裏');
ok($zip->set_number('0200555')->is_valid_number, '岩手県岩手郡雫石町上曽根田');
ok($zip->set_number('0200556')->is_valid_number, '岩手県岩手郡雫石町名子');
ok($zip->set_number('0200557')->is_valid_number, '岩手県岩手郡雫石町上平');
ok($zip->set_number('0200558')->is_valid_number, '岩手県岩手郡雫石町下笹森');
ok($zip->set_number('0200559')->is_valid_number, '岩手県岩手郡雫石町上笹森');
ok($zip->set_number('0200571')->is_valid_number, '岩手県岩手郡雫石町繋');
ok($zip->set_number('0200572')->is_valid_number, '岩手県岩手郡雫石町西安庭');
ok($zip->set_number('0200573')->is_valid_number, '岩手県岩手郡雫石町南畑');
ok($zip->set_number('0200574')->is_valid_number, '岩手県岩手郡雫石町鴬宿');
ok($zip->set_number('0200581')->is_valid_number, '岩手県岩手郡雫石町御明神');
ok($zip->set_number('0200582')->is_valid_number, '岩手県岩手郡雫石町橋場');
ok($zip->set_number('0200583')->is_valid_number, '岩手県岩手郡雫石町上野');
ok($zip->set_number('0200584')->is_valid_number, '岩手県岩手郡雫石町西根');
ok($zip->set_number('0200585')->is_valid_number, '岩手県岩手郡雫石町長山');
ok($zip->set_number('0200600')->is_valid_number, '岩手県滝沢市以下に掲載がない場合');
ok($zip->set_number('0200601')->is_valid_number, '岩手県滝沢市後');
ok($zip->set_number('0200602')->is_valid_number, '岩手県滝沢市大森平');
ok($zip->set_number('0200603')->is_valid_number, '岩手県滝沢市留が森');
ok($zip->set_number('0200604')->is_valid_number, '岩手県滝沢市一本木');
ok($zip->set_number('0200605')->is_valid_number, '岩手県滝沢市砂込');
ok($zip->set_number('0200606')->is_valid_number, '岩手県滝沢市加賀内');
ok($zip->set_number('0200607')->is_valid_number, '岩手県滝沢市弥兵エ林');
ok($zip->set_number('0200608')->is_valid_number, '岩手県滝沢市長太郎林');
ok($zip->set_number('0200609')->is_valid_number, '岩手県滝沢市柳原');
ok($zip->set_number('0200611')->is_valid_number, '岩手県滝沢市巣子');
ok($zip->set_number('0200612')->is_valid_number, '岩手県滝沢市柳沢');
ok($zip->set_number('0200613')->is_valid_number, '岩手県滝沢市大石渡');
ok($zip->set_number('0200614')->is_valid_number, '岩手県滝沢市上中村');
ok($zip->set_number('0200615')->is_valid_number, '岩手県滝沢市卯遠坂');
ok($zip->set_number('0200616')->is_valid_number, '岩手県滝沢市木賊川');
ok($zip->set_number('0200617')->is_valid_number, '岩手県滝沢市湯舟沢');
ok($zip->set_number('0200618')->is_valid_number, '岩手県滝沢市岩手山');
ok($zip->set_number('0200619')->is_valid_number, '岩手県滝沢市上岩手山');
ok($zip->set_number('0200621')->is_valid_number, '岩手県滝沢市大崎');
ok($zip->set_number('0200622')->is_valid_number, '岩手県滝沢市野沢');
ok($zip->set_number('0200623')->is_valid_number, '岩手県滝沢市楢の木沢');
ok($zip->set_number('0200624')->is_valid_number, '岩手県滝沢市妻の神');
ok($zip->set_number('0200625')->is_valid_number, '岩手県滝沢市葉の木沢山');
ok($zip->set_number('0200626')->is_valid_number, '岩手県滝沢市明神平');
ok($zip->set_number('0200627')->is_valid_number, '岩手県滝沢市狼久保');
ok($zip->set_number('0200631')->is_valid_number, '岩手県滝沢市根堀坂');
ok($zip->set_number('0200632')->is_valid_number, '岩手県滝沢市牧野林');
ok($zip->set_number('0200633')->is_valid_number, '岩手県滝沢市穴口');
ok($zip->set_number('0200634')->is_valid_number, '岩手県滝沢市室小路');
ok($zip->set_number('0200635')->is_valid_number, '岩手県滝沢市耳取山');
ok($zip->set_number('0200636')->is_valid_number, '岩手県滝沢市大久保');
ok($zip->set_number('0200637')->is_valid_number, '岩手県滝沢市高屋敷平');
ok($zip->set_number('0200638')->is_valid_number, '岩手県滝沢市土沢');
ok($zip->set_number('0200641')->is_valid_number, '岩手県滝沢市祢宜屋敷');
ok($zip->set_number('0200642')->is_valid_number, '岩手県滝沢市中村');
ok($zip->set_number('0200643')->is_valid_number, '岩手県滝沢市外山');
ok($zip->set_number('0200644')->is_valid_number, '岩手県滝沢市平蔵沢');
ok($zip->set_number('0200645')->is_valid_number, '岩手県滝沢市高屋敷');
ok($zip->set_number('0200646')->is_valid_number, '岩手県滝沢市黒沢');
ok($zip->set_number('0200651')->is_valid_number, '岩手県滝沢市鵜飼細谷地');
ok($zip->set_number('0200652')->is_valid_number, '岩手県滝沢市鵜飼洞畑');
ok($zip->set_number('0200653')->is_valid_number, '岩手県滝沢市鵜飼迫');
ok($zip->set_number('0200654')->is_valid_number, '岩手県滝沢市中鵜飼');
ok($zip->set_number('0200655')->is_valid_number, '岩手県滝沢市鵜飼御庭田');
ok($zip->set_number('0200656')->is_valid_number, '岩手県滝沢市鵜飼上山');
ok($zip->set_number('0200657')->is_valid_number, '岩手県滝沢市鵜飼鰍森');
ok($zip->set_number('0200658')->is_valid_number, '岩手県滝沢市鵜飼清水沢');
ok($zip->set_number('0200659')->is_valid_number, '岩手県滝沢市鵜飼外久保');
ok($zip->set_number('0200661')->is_valid_number, '岩手県滝沢市鵜飼白石');
ok($zip->set_number('0200662')->is_valid_number, '岩手県滝沢市鵜飼大緩');
ok($zip->set_number('0200663')->is_valid_number, '岩手県滝沢市鵜飼諸葛川');
ok($zip->set_number('0200664')->is_valid_number, '岩手県滝沢市鵜飼笹森');
ok($zip->set_number('0200665')->is_valid_number, '岩手県滝沢市下鵜飼');
ok($zip->set_number('0200666')->is_valid_number, '岩手県滝沢市鵜飼先古川');
ok($zip->set_number('0200667')->is_valid_number, '岩手県滝沢市鵜飼向新田');
ok($zip->set_number('0200668')->is_valid_number, '岩手県滝沢市鵜飼狐洞');
ok($zip->set_number('0200671')->is_valid_number, '岩手県滝沢市鵜飼上高柳');
ok($zip->set_number('0200672')->is_valid_number, '岩手県滝沢市鵜飼下高柳');
ok($zip->set_number('0200673')->is_valid_number, '岩手県滝沢市鵜飼石留');
ok($zip->set_number('0200674')->is_valid_number, '岩手県滝沢市鵜飼高柳');
ok($zip->set_number('0200675')->is_valid_number, '岩手県滝沢市鵜飼滝向');
ok($zip->set_number('0200676')->is_valid_number, '岩手県滝沢市鵜飼八人打');
ok($zip->set_number('0200677')->is_valid_number, '岩手県滝沢市鵜飼樋の口');
ok($zip->set_number('0200678')->is_valid_number, '岩手県滝沢市鵜飼年毛');
ok($zip->set_number('0200681')->is_valid_number, '岩手県滝沢市鵜飼姥屋敷');
ok($zip->set_number('0200682')->is_valid_number, '岩手県滝沢市鵜飼臨安');
ok($zip->set_number('0200683')->is_valid_number, '岩手県滝沢市鵜飼花平');
ok($zip->set_number('0200684')->is_valid_number, '岩手県滝沢市鵜飼沼森');
ok($zip->set_number('0200685')->is_valid_number, '岩手県滝沢市鵜飼安達');
ok($zip->set_number('0200686')->is_valid_number, '岩手県滝沢市鵜飼鬼越');
ok($zip->set_number('0200687')->is_valid_number, '岩手県滝沢市上鵜飼');
ok($zip->set_number('0200688')->is_valid_number, '岩手県滝沢市鵜飼上前田');
ok($zip->set_number('0200701')->is_valid_number, '岩手県滝沢市大沢籠屋敷');
ok($zip->set_number('0200702')->is_valid_number, '岩手県滝沢市大沢上鶴子');
ok($zip->set_number('0200703')->is_valid_number, '岩手県滝沢市大沢堰合');
ok($zip->set_number('0200704')->is_valid_number, '岩手県滝沢市大沢谷地中');
ok($zip->set_number('0200705')->is_valid_number, '岩手県滝沢市大沢二タ又');
ok($zip->set_number('0200706')->is_valid_number, '岩手県滝沢市大沢割田');
ok($zip->set_number('0200707')->is_valid_number, '岩手県滝沢市大沢館');
ok($zip->set_number('0200708')->is_valid_number, '岩手県滝沢市大沢箸木平');
ok($zip->set_number('0200709')->is_valid_number, '岩手県滝沢市大沢外山野');
ok($zip->set_number('0200710')->is_valid_number, '岩手県滝沢市大沢弥作畑');
ok($zip->set_number('0200711')->is_valid_number, '岩手県滝沢市大沢谷地上');
ok($zip->set_number('0200712')->is_valid_number, '岩手県滝沢市大沢長坪');
ok($zip->set_number('0200713')->is_valid_number, '岩手県滝沢市大沢新道');
ok($zip->set_number('0200714')->is_valid_number, '岩手県滝沢市大沢舛村');
ok($zip->set_number('0200715')->is_valid_number, '岩手県滝沢市大沢下屋敷');
ok($zip->set_number('0200716')->is_valid_number, '岩手県滝沢市大沢米倉');
ok($zip->set_number('0200717')->is_valid_number, '岩手県滝沢市大沢四つ家');
ok($zip->set_number('0200718')->is_valid_number, '岩手県滝沢市大沢小谷地');
ok($zip->set_number('0200719')->is_valid_number, '岩手県滝沢市大沢鶴子');
ok($zip->set_number('0200721')->is_valid_number, '岩手県滝沢市篠木中村');
ok($zip->set_number('0200722')->is_valid_number, '岩手県滝沢市篠木上綾織');
ok($zip->set_number('0200723')->is_valid_number, '岩手県滝沢市篠木綾織');
ok($zip->set_number('0200724')->is_valid_number, '岩手県滝沢市篠木小谷地');
ok($zip->set_number('0200725')->is_valid_number, '岩手県滝沢市篠木中屋敷');
ok($zip->set_number('0200726')->is_valid_number, '岩手県滝沢市篠木荒屋');
ok($zip->set_number('0200727')->is_valid_number, '岩手県滝沢市篠木鳥谷平');
ok($zip->set_number('0200728')->is_valid_number, '岩手県滝沢市篠木上篠木');
ok($zip->set_number('0200731')->is_valid_number, '岩手県滝沢市篠木明法');
ok($zip->set_number('0200732')->is_valid_number, '岩手県滝沢市篠木樋の口');
ok($zip->set_number('0200733')->is_valid_number, '岩手県滝沢市篠木待場');
ok($zip->set_number('0200734')->is_valid_number, '岩手県滝沢市篠木上黒畑');
ok($zip->set_number('0200735')->is_valid_number, '岩手県滝沢市篠木黒畑');
ok($zip->set_number('0200736')->is_valid_number, '岩手県滝沢市篠木参郷');
ok($zip->set_number('0200737')->is_valid_number, '岩手県滝沢市篠木堤');
ok($zip->set_number('0200738')->is_valid_number, '岩手県滝沢市篠木参郷の森');
ok($zip->set_number('0200741')->is_valid_number, '岩手県滝沢市篠木矢取森');
ok($zip->set_number('0200742')->is_valid_number, '岩手県滝沢市篠木苧桶沢');
ok($zip->set_number('0200743')->is_valid_number, '岩手県滝沢市篠木外山');
ok($zip->set_number('0200744')->is_valid_number, '岩手県滝沢市篠木館が沢');
ok($zip->set_number('0200745')->is_valid_number, '岩手県滝沢市篠木大寺沢');
ok($zip->set_number('0200746')->is_valid_number, '岩手県滝沢市篠木仁沢瀬');
ok($zip->set_number('0200751')->is_valid_number, '岩手県滝沢市大釜千が窪');
ok($zip->set_number('0200752')->is_valid_number, '岩手県滝沢市大釜白山');
ok($zip->set_number('0200753')->is_valid_number, '岩手県滝沢市大釜細屋');
ok($zip->set_number('0200754')->is_valid_number, '岩手県滝沢市大釜上釜');
ok($zip->set_number('0200755')->is_valid_number, '岩手県滝沢市大釜釜口');
ok($zip->set_number('0200756')->is_valid_number, '岩手県滝沢市大釜高森');
ok($zip->set_number('0200757')->is_valid_number, '岩手県滝沢市大釜風林');
ok($zip->set_number('0200758')->is_valid_number, '岩手県滝沢市大釜大清水');
ok($zip->set_number('0200761')->is_valid_number, '岩手県滝沢市大釜田の尻');
ok($zip->set_number('0200762')->is_valid_number, '岩手県滝沢市大釜外館');
ok($zip->set_number('0200763')->is_valid_number, '岩手県滝沢市大釜大畑');
ok($zip->set_number('0200764')->is_valid_number, '岩手県滝沢市大釜土井尻');
ok($zip->set_number('0200765')->is_valid_number, '岩手県滝沢市大釜小屋敷');
ok($zip->set_number('0200766')->is_valid_number, '岩手県滝沢市大釜八幡前');
ok($zip->set_number('0200767')->is_valid_number, '岩手県滝沢市大釜中道');
ok($zip->set_number('0200768')->is_valid_number, '岩手県滝沢市大釜和田');
ok($zip->set_number('0200769')->is_valid_number, '岩手県滝沢市大釜荒屋敷');
ok($zip->set_number('0200771')->is_valid_number, '岩手県滝沢市大釜竹鼻');
ok($zip->set_number('0200772')->is_valid_number, '岩手県滝沢市大釜中瀬');
ok($zip->set_number('0200773')->is_valid_number, '岩手県滝沢市大釜上竹鼻');
ok($zip->set_number('0200774')->is_valid_number, '岩手県滝沢市大釜塩の森');
ok($zip->set_number('0200775')->is_valid_number, '岩手県滝沢市大釜沼袋');
ok($zip->set_number('0200776')->is_valid_number, '岩手県滝沢市大釜鬼が滝');
ok($zip->set_number('0200777')->is_valid_number, '岩手県滝沢市大釜仁沢瀬');
ok($zip->set_number('0200778')->is_valid_number, '岩手県滝沢市大釜吉水');
ok($zip->set_number('0200779')->is_valid_number, '岩手県滝沢市大釜吉清水');
ok($zip->set_number('0200801')->is_valid_number, '岩手県盛岡市浅岸');
ok($zip->set_number('0200802')->is_valid_number, '岩手県盛岡市つつじが丘');
ok($zip->set_number('0200803')->is_valid_number, '岩手県盛岡市新庄');
ok($zip->set_number('0200804')->is_valid_number, '岩手県盛岡市東桜山');
ok($zip->set_number('0200805')->is_valid_number, '岩手県盛岡市東新庄');
ok($zip->set_number('0200806')->is_valid_number, '岩手県盛岡市新庄町');
ok($zip->set_number('0200807')->is_valid_number, '岩手県盛岡市加賀野');
ok($zip->set_number('0200811')->is_valid_number, '岩手県盛岡市川目町');
ok($zip->set_number('0200812')->is_valid_number, '岩手県盛岡市川目');
ok($zip->set_number('0200813')->is_valid_number, '岩手県盛岡市東山');
ok($zip->set_number('0200814')->is_valid_number, '岩手県盛岡市東中野町');
ok($zip->set_number('0200815')->is_valid_number, '岩手県盛岡市小杉山');
ok($zip->set_number('0200816')->is_valid_number, '岩手県盛岡市中野');
ok($zip->set_number('0200817')->is_valid_number, '岩手県盛岡市東中野');
ok($zip->set_number('0200821')->is_valid_number, '岩手県盛岡市山王町');
ok($zip->set_number('0200822')->is_valid_number, '岩手県盛岡市茶畑');
ok($zip->set_number('0200823')->is_valid_number, '岩手県盛岡市門');
ok($zip->set_number('0200824')->is_valid_number, '岩手県盛岡市東安庭');
ok($zip->set_number('0200825')->is_valid_number, '岩手県盛岡市高崩');
ok($zip->set_number('0200826')->is_valid_number, '岩手県盛岡市神子田町');
ok($zip->set_number('0200827')->is_valid_number, '岩手県盛岡市鉈屋町');
ok($zip->set_number('0200828')->is_valid_number, '岩手県盛岡市大慈寺町');
ok($zip->set_number('0200831')->is_valid_number, '岩手県盛岡市三本柳');
ok($zip->set_number('0200832')->is_valid_number, '岩手県盛岡市東見前');
ok($zip->set_number('0200833')->is_valid_number, '岩手県盛岡市西見前');
ok($zip->set_number('0200834')->is_valid_number, '岩手県盛岡市永井');
ok($zip->set_number('0200835')->is_valid_number, '岩手県盛岡市津志田');
ok($zip->set_number('0200836')->is_valid_number, '岩手県盛岡市津志田西');
ok($zip->set_number('0200837')->is_valid_number, '岩手県盛岡市津志田町');
ok($zip->set_number('0200838')->is_valid_number, '岩手県盛岡市津志田中央');
ok($zip->set_number('0200839')->is_valid_number, '岩手県盛岡市津志田南');
ok($zip->set_number('0200841')->is_valid_number, '岩手県盛岡市羽場');
ok($zip->set_number('0200842')->is_valid_number, '岩手県盛岡市湯沢');
ok($zip->set_number('0200843')->is_valid_number, '岩手県盛岡市湯沢西');
ok($zip->set_number('0200844')->is_valid_number, '岩手県盛岡市湯沢東');
ok($zip->set_number('0200845')->is_valid_number, '岩手県盛岡市湯沢南');
ok($zip->set_number('0200846')->is_valid_number, '岩手県盛岡市流通センター北');
ok($zip->set_number('0200851')->is_valid_number, '岩手県盛岡市向中野');
ok($zip->set_number('0200852')->is_valid_number, '岩手県盛岡市飯岡新田');
ok($zip->set_number('0200853')->is_valid_number, '岩手県盛岡市下飯岡');
ok($zip->set_number('0200854')->is_valid_number, '岩手県盛岡市上飯岡');
ok($zip->set_number('0200855')->is_valid_number, '岩手県盛岡市上鹿妻');
ok($zip->set_number('0200856')->is_valid_number, '岩手県盛岡市下鹿妻');
ok($zip->set_number('0200857')->is_valid_number, '岩手県盛岡市北飯岡');
ok($zip->set_number('0200861')->is_valid_number, '岩手県盛岡市仙北');
ok($zip->set_number('0200862')->is_valid_number, '岩手県盛岡市東仙北');
ok($zip->set_number('0200863')->is_valid_number, '岩手県盛岡市南仙北');
ok($zip->set_number('0200864')->is_valid_number, '岩手県盛岡市西仙北');
ok($zip->set_number('0200865')->is_valid_number, '岩手県盛岡市仙北町');
ok($zip->set_number('0200866')->is_valid_number, '岩手県盛岡市本宮');
ok($zip->set_number('0200871')->is_valid_number, '岩手県盛岡市中ノ橋通');
ok($zip->set_number('0200872')->is_valid_number, '岩手県盛岡市八幡町');
ok($zip->set_number('0200873')->is_valid_number, '岩手県盛岡市松尾町');
ok($zip->set_number('0200874')->is_valid_number, '岩手県盛岡市南大通');
ok($zip->set_number('0200875')->is_valid_number, '岩手県盛岡市清水町');
ok($zip->set_number('0200876')->is_valid_number, '岩手県盛岡市馬場町');
ok($zip->set_number('0200877')->is_valid_number, '岩手県盛岡市下ノ橋町');
ok($zip->set_number('0200878')->is_valid_number, '岩手県盛岡市肴町');
ok($zip->set_number('0200881')->is_valid_number, '岩手県盛岡市天神町');
ok($zip->set_number('0200882')->is_valid_number, '岩手県盛岡市住吉町');
ok($zip->set_number('0200883')->is_valid_number, '岩手県盛岡市志家町');
ok($zip->set_number('0200884')->is_valid_number, '岩手県盛岡市神明町');
ok($zip->set_number('0200885')->is_valid_number, '岩手県盛岡市紺屋町');
ok($zip->set_number('0200886')->is_valid_number, '岩手県盛岡市若園町');
ok($zip->set_number('0200887')->is_valid_number, '岩手県盛岡市上ノ橋町');
ok($zip->set_number('0200891')->is_valid_number, '岩手県紫波郡矢巾町流通センター南');
ok($zip->set_number('0210000')->is_valid_number, '岩手県一関市以下に掲載がない場合');
ok($zip->set_number('0210001')->is_valid_number, '岩手県一関市新町');
ok($zip->set_number('0210002')->is_valid_number, '岩手県一関市中里(その他)');
ok($zip->set_number('0210003')->is_valid_number, '岩手県一関市東五代');
ok($zip->set_number('0210004')->is_valid_number, '岩手県一関市町浦');
ok($zip->set_number('0210005')->is_valid_number, '岩手県一関市中里(沢田)');
ok($zip->set_number('0210006')->is_valid_number, '岩手県一関市上坊');
ok($zip->set_number('0210007')->is_valid_number, '岩手県一関市上日照');
ok($zip->set_number('0210008')->is_valid_number, '岩手県一関市石畑');
ok($zip->set_number('0210011')->is_valid_number, '岩手県一関市山目町');
ok($zip->set_number('0210012')->is_valid_number, '岩手県一関市宮前町');
ok($zip->set_number('0210013')->is_valid_number, '岩手県一関市宮下町');
ok($zip->set_number('0210014')->is_valid_number, '岩手県一関市蘭梅町');
ok($zip->set_number('0210021')->is_valid_number, '岩手県一関市中央町');
ok($zip->set_number('0210022')->is_valid_number, '岩手県一関市五代町');
ok($zip->set_number('0210023')->is_valid_number, '岩手県一関市銅谷町');
ok($zip->set_number('0210024')->is_valid_number, '岩手県一関市幸町');
ok($zip->set_number('0210025')->is_valid_number, '岩手県一関市山目(向野)');
ok($zip->set_number('0210026')->is_valid_number, '岩手県一関市山目(前田)');
ok($zip->set_number('0210027')->is_valid_number, '岩手県一関市竹山町');
ok($zip->set_number('0210031')->is_valid_number, '岩手県一関市青葉');
ok($zip->set_number('0210032')->is_valid_number, '岩手県一関市末広');
ok($zip->set_number('0210033')->is_valid_number, '岩手県一関市山目(里前)');
ok($zip->set_number('0210034')->is_valid_number, '岩手県一関市山目(立沢)');
ok($zip->set_number('0210035')->is_valid_number, '岩手県一関市山目(才天)');
ok($zip->set_number('0210036')->is_valid_number, '岩手県一関市山目(十二神)');
ok($zip->set_number('0210041')->is_valid_number, '岩手県一関市赤荻');
ok($zip->set_number('0210051')->is_valid_number, '岩手県一関市山目(三反田)');
ok($zip->set_number('0210052')->is_valid_number, '岩手県一関市寿町');
ok($zip->set_number('0210053')->is_valid_number, '岩手県一関市山目(中野)');
ok($zip->set_number('0210054')->is_valid_number, '岩手県一関市山目(境)');
ok($zip->set_number('0210055')->is_valid_number, '岩手県一関市山目(泥田)');
ok($zip->set_number('0210056')->is_valid_number, '岩手県一関市山目(泥田山下)');
ok($zip->set_number('0210061')->is_valid_number, '岩手県一関市山目(館)');
ok($zip->set_number('0210062')->is_valid_number, '岩手県一関市山目(寺前)');
ok($zip->set_number('0210063')->is_valid_number, '岩手県一関市山目(大槻)');
ok($zip->set_number('0210064')->is_valid_number, '岩手県一関市山目(沢内)');
ok($zip->set_number('0210101')->is_valid_number, '岩手県一関市厳美町');
ok($zip->set_number('0210102')->is_valid_number, '岩手県一関市萩荘(赤猪子、芦ノ口、甘蕨、老流、大沢、上宇津野、上本郷、上要害、化粧');
ok($zip->set_number('0210102')->is_valid_number, '岩手県一関市坂、三月田、下宇津野、下本郷、外山、堂の沢、栃倉、栃倉南、長倉、中沢、');
ok($zip->set_number('0210102')->is_valid_number, '岩手県一関市八森、馬場、広面、平場、古釜場、曲淵、松原、南沢、谷起、焼切、八瀬、');
ok($zip->set_number('0210102')->is_valid_number, '岩手県一関市八幡、山ノ沢)');
ok($zip->set_number('0210221')->is_valid_number, '岩手県一関市舞川');
ok($zip->set_number('0210801')->is_valid_number, '岩手県一関市桜街');
ok($zip->set_number('0210802')->is_valid_number, '岩手県一関市北十軒街');
ok($zip->set_number('0210803')->is_valid_number, '岩手県一関市南十軒街');
ok($zip->set_number('0210804')->is_valid_number, '岩手県一関市五十人町');
ok($zip->set_number('0210805')->is_valid_number, '岩手県一関市豊町');
ok($zip->set_number('0210806')->is_valid_number, '岩手県一関市下大槻街');
ok($zip->set_number('0210807')->is_valid_number, '岩手県一関市東花王町');
ok($zip->set_number('0210811')->is_valid_number, '岩手県一関市久保');
ok($zip->set_number('0210812')->is_valid_number, '岩手県一関市樋渡');
ok($zip->set_number('0210813')->is_valid_number, '岩手県一関市南ほうりょう');
ok($zip->set_number('0210814')->is_valid_number, '岩手県一関市北ほうりょう');
ok($zip->set_number('0210815')->is_valid_number, '岩手県一関市要害');
ok($zip->set_number('0210821')->is_valid_number, '岩手県一関市三関');
ok($zip->set_number('0210822')->is_valid_number, '岩手県一関市東台');
ok($zip->set_number('0210831')->is_valid_number, '岩手県一関市沼田');
ok($zip->set_number('0210832')->is_valid_number, '岩手県一関市散田');
ok($zip->set_number('0210833')->is_valid_number, '岩手県一関市柄貝');
ok($zip->set_number('0210834')->is_valid_number, '岩手県一関市宇南');
ok($zip->set_number('0210835')->is_valid_number, '岩手県一関市二本木');
ok($zip->set_number('0210836')->is_valid_number, '岩手県一関市鳴神');
ok($zip->set_number('0210841')->is_valid_number, '岩手県一関市吸川街');
ok($zip->set_number('0210842')->is_valid_number, '岩手県一関市柳町');
ok($zip->set_number('0210843')->is_valid_number, '岩手県一関市深町');
ok($zip->set_number('0210844')->is_valid_number, '岩手県一関市反町');
ok($zip->set_number('0210851')->is_valid_number, '岩手県一関市関が丘');
ok($zip->set_number('0210852')->is_valid_number, '岩手県一関市沢');
ok($zip->set_number('0210853')->is_valid_number, '岩手県一関市相去');
ok($zip->set_number('0210854')->is_valid_number, '岩手県一関市西沢');
ok($zip->set_number('0210861')->is_valid_number, '岩手県一関市機織山');
ok($zip->set_number('0210862')->is_valid_number, '岩手県一関市千代田町');
ok($zip->set_number('0210863')->is_valid_number, '岩手県一関市南町');
ok($zip->set_number('0210864')->is_valid_number, '岩手県一関市旭町');
ok($zip->set_number('0210865')->is_valid_number, '岩手県一関市新山');
ok($zip->set_number('0210866')->is_valid_number, '岩手県一関市南新町');
ok($zip->set_number('0210867')->is_valid_number, '岩手県一関市駅前');
ok($zip->set_number('0210871')->is_valid_number, '岩手県一関市八幡町');
ok($zip->set_number('0210872')->is_valid_number, '岩手県一関市宮坂町');
ok($zip->set_number('0210873')->is_valid_number, '岩手県一関市台町');
ok($zip->set_number('0210874')->is_valid_number, '岩手県一関市釣山');
ok($zip->set_number('0210875')->is_valid_number, '岩手県一関市高崎町');
ok($zip->set_number('0210876')->is_valid_number, '岩手県一関市広街');
ok($zip->set_number('0210877')->is_valid_number, '岩手県一関市城内');
ok($zip->set_number('0210881')->is_valid_number, '岩手県一関市大町');
ok($zip->set_number('0210882')->is_valid_number, '岩手県一関市上大槻街');
ok($zip->set_number('0210883')->is_valid_number, '岩手県一関市新大町');
ok($zip->set_number('0210884')->is_valid_number, '岩手県一関市大手町');
ok($zip->set_number('0210885')->is_valid_number, '岩手県一関市田村町');
ok($zip->set_number('0210891')->is_valid_number, '岩手県一関市桜木町');
ok($zip->set_number('0210892')->is_valid_number, '岩手県一関市東地主町');
ok($zip->set_number('0210893')->is_valid_number, '岩手県一関市地主町');
ok($zip->set_number('0210894')->is_valid_number, '岩手県一関市磐井町');
ok($zip->set_number('0210901')->is_valid_number, '岩手県一関市真柴');
ok($zip->set_number('0210902')->is_valid_number, '岩手県一関市萩荘(その他)');
ok($zip->set_number('0220000')->is_valid_number, '岩手県大船渡市以下に掲載がない場合');
ok($zip->set_number('0220001')->is_valid_number, '岩手県大船渡市末崎町');
ok($zip->set_number('0220002')->is_valid_number, '岩手県大船渡市大船渡町');
ok($zip->set_number('0220003')->is_valid_number, '岩手県大船渡市盛町');
ok($zip->set_number('0220004')->is_valid_number, '岩手県大船渡市猪川町');
ok($zip->set_number('0220005')->is_valid_number, '岩手県大船渡市日頃市町');
ok($zip->set_number('0220006')->is_valid_number, '岩手県大船渡市立根町');
ok($zip->set_number('0220007')->is_valid_number, '岩手県大船渡市赤崎町');
ok($zip->set_number('0220101')->is_valid_number, '岩手県大船渡市三陸町越喜来');
ok($zip->set_number('0220102')->is_valid_number, '岩手県大船渡市三陸町吉浜');
ok($zip->set_number('0220211')->is_valid_number, '岩手県大船渡市三陸町綾里');
ok($zip->set_number('0230000')->is_valid_number, '岩手県奥州市以下に掲載がない場合');
ok($zip->set_number('0230001')->is_valid_number, '岩手県奥州市水沢卸町');
ok($zip->set_number('0230002')->is_valid_number, '岩手県奥州市水沢工業団地');
ok($zip->set_number('0230003')->is_valid_number, '岩手県奥州市水沢佐倉河');
ok($zip->set_number('0230011')->is_valid_number, '岩手県奥州市水沢稲荷田');
ok($zip->set_number('0230012')->is_valid_number, '岩手県奥州市水沢斉勝田');
ok($zip->set_number('0230013')->is_valid_number, '岩手県奥州市水沢一本柳');
ok($zip->set_number('0230014')->is_valid_number, '岩手県奥州市水沢地蔵田');
ok($zip->set_number('0230015')->is_valid_number, '岩手県奥州市水沢五千刈');
ok($zip->set_number('0230016')->is_valid_number, '岩手県奥州市水沢平沢');
ok($zip->set_number('0230017')->is_valid_number, '岩手県奥州市水沢渋田');
ok($zip->set_number('0230018')->is_valid_number, '岩手県奥州市水沢小中');
ok($zip->set_number('0230019')->is_valid_number, '岩手県奥州市水沢築舘');
ok($zip->set_number('0230021')->is_valid_number, '岩手県奥州市水沢欠ノ下');
ok($zip->set_number('0230022')->is_valid_number, '岩手県奥州市水沢中城');
ok($zip->set_number('0230023')->is_valid_number, '岩手県奥州市水沢八反町');
ok($zip->set_number('0230024')->is_valid_number, '岩手県奥州市水沢名残');
ok($zip->set_number('0230025')->is_valid_number, '岩手県奥州市水沢高網');
ok($zip->set_number('0230026')->is_valid_number, '岩手県奥州市水沢里鎗');
ok($zip->set_number('0230027')->is_valid_number, '岩手県奥州市水沢幅下');
ok($zip->set_number('0230031')->is_valid_number, '岩手県奥州市水沢北丑沢');
ok($zip->set_number('0230032')->is_valid_number, '岩手県奥州市水沢多賀');
ok($zip->set_number('0230033')->is_valid_number, '岩手県奥州市水沢不断町');
ok($zip->set_number('0230034')->is_valid_number, '岩手県奥州市水沢川口町');
ok($zip->set_number('0230035')->is_valid_number, '岩手県奥州市水沢赤土田');
ok($zip->set_number('0230036')->is_valid_number, '岩手県奥州市水沢北栗林');
ok($zip->set_number('0230037')->is_valid_number, '岩手県奥州市水沢南丑沢');
ok($zip->set_number('0230041')->is_valid_number, '岩手県奥州市水沢秋葉町');
ok($zip->set_number('0230042')->is_valid_number, '岩手県奥州市水沢柳町');
ok($zip->set_number('0230043')->is_valid_number, '岩手県奥州市水沢道合');
ok($zip->set_number('0230044')->is_valid_number, '岩手県奥州市水沢三本木');
ok($zip->set_number('0230045')->is_valid_number, '岩手県奥州市水沢大町');
ok($zip->set_number('0230046')->is_valid_number, '岩手県奥州市水沢川原小路');
ok($zip->set_number('0230047')->is_valid_number, '岩手県奥州市水沢立町');
ok($zip->set_number('0230051')->is_valid_number, '岩手県奥州市水沢勝手町');
ok($zip->set_number('0230052')->is_valid_number, '岩手県奥州市水沢搦手丁');
ok($zip->set_number('0230053')->is_valid_number, '岩手県奥州市水沢大手町');
ok($zip->set_number('0230054')->is_valid_number, '岩手県奥州市水沢吉小路');
ok($zip->set_number('0230055')->is_valid_number, '岩手県奥州市水沢虚空蔵小路');
ok($zip->set_number('0230056')->is_valid_number, '岩手県奥州市水沢久田');
ok($zip->set_number('0230057')->is_valid_number, '岩手県奥州市水沢上町');
ok($zip->set_number('0230058')->is_valid_number, '岩手県奥州市水沢堀ノ内');
ok($zip->set_number('0230061')->is_valid_number, '岩手県奥州市水沢長町');
ok($zip->set_number('0230062')->is_valid_number, '岩手県奥州市水沢小石田');
ok($zip->set_number('0230063')->is_valid_number, '岩手県奥州市水沢聖天');
ok($zip->set_number('0230064')->is_valid_number, '岩手県奥州市水沢土器田');
ok($zip->set_number('0230065')->is_valid_number, '岩手県奥州市水沢水山');
ok($zip->set_number('0230066')->is_valid_number, '岩手県奥州市水沢前田袋');
ok($zip->set_number('0230067')->is_valid_number, '岩手県奥州市水沢二反田');
ok($zip->set_number('0230071')->is_valid_number, '岩手県奥州市水沢黒子');
ok($zip->set_number('0230072')->is_valid_number, '岩手県奥州市水沢樋渡');
ok($zip->set_number('0230073')->is_valid_number, '岩手県奥州市水沢寺領');
ok($zip->set_number('0230074')->is_valid_number, '岩手県奥州市水沢極楽');
ok($zip->set_number('0230075')->is_valid_number, '岩手県奥州市水沢水ノ口');
ok($zip->set_number('0230076')->is_valid_number, '岩手県奥州市水沢造道');
ok($zip->set_number('0230077')->is_valid_number, '岩手県奥州市水沢桑畑');
ok($zip->set_number('0230081')->is_valid_number, '岩手県奥州市水沢橇町');
ok($zip->set_number('0230082')->is_valid_number, '岩手県奥州市水沢東半郷');
ok($zip->set_number('0230083')->is_valid_number, '岩手県奥州市水沢前郷');
ok($zip->set_number('0230084')->is_valid_number, '岩手県奥州市水沢大上');
ok($zip->set_number('0230085')->is_valid_number, '岩手県奥州市水沢踊子');
ok($zip->set_number('0230086')->is_valid_number, '岩手県奥州市水沢谷地中');
ok($zip->set_number('0230087')->is_valid_number, '岩手県奥州市水沢高谷宿');
ok($zip->set_number('0230091')->is_valid_number, '岩手県奥州市水沢高山');
ok($zip->set_number('0230092')->is_valid_number, '岩手県奥州市水沢北半郷');
ok($zip->set_number('0230093')->is_valid_number, '岩手県奥州市水沢水神');
ok($zip->set_number('0230094')->is_valid_number, '岩手県奥州市水沢五輪');
ok($zip->set_number('0230095')->is_valid_number, '岩手県奥州市水沢雀田');
ok($zip->set_number('0230096')->is_valid_number, '岩手県奥州市水沢向田');
ok($zip->set_number('0230101')->is_valid_number, '岩手県奥州市水沢黒石町');
ok($zip->set_number('0230102')->is_valid_number, '岩手県奥州市水沢羽田町駅東');
ok($zip->set_number('0230103')->is_valid_number, '岩手県奥州市水沢羽田町駅南');
ok($zip->set_number('0230104')->is_valid_number, '岩手県奥州市水沢羽田町駅前');
ok($zip->set_number('0230105')->is_valid_number, '岩手県奥州市水沢羽田町宝生');
ok($zip->set_number('0230106')->is_valid_number, '岩手県奥州市水沢羽田町久保');
ok($zip->set_number('0230107')->is_valid_number, '岩手県奥州市水沢羽田町宝柳木');
ok($zip->set_number('0230108')->is_valid_number, '岩手県奥州市水沢羽田町向畑');
ok($zip->set_number('0230132')->is_valid_number, '岩手県奥州市水沢羽田町(その他)');
ok($zip->set_number('0230171')->is_valid_number, '岩手県奥州市江刺田原');
ok($zip->set_number('0230401')->is_valid_number, '岩手県奥州市胆沢南都田');
ok($zip->set_number('0230402')->is_valid_number, '岩手県奥州市胆沢小山');
ok($zip->set_number('0230403')->is_valid_number, '岩手県奥州市胆沢若柳');
ok($zip->set_number('0230801')->is_valid_number, '岩手県奥州市水沢横町');
ok($zip->set_number('0230802')->is_valid_number, '岩手県奥州市水沢大畑小路');
ok($zip->set_number('0230803')->is_valid_number, '岩手県奥州市水沢田小路');
ok($zip->set_number('0230804')->is_valid_number, '岩手県奥州市水沢谷地明円');
ok($zip->set_number('0230805')->is_valid_number, '岩手県奥州市水沢斉の神');
ok($zip->set_number('0230806')->is_valid_number, '岩手県奥州市水沢日高西');
ok($zip->set_number('0230807')->is_valid_number, '岩手県奥州市水沢新小路');
ok($zip->set_number('0230808')->is_valid_number, '岩手県奥州市水沢日高小路');
ok($zip->set_number('0230811')->is_valid_number, '岩手県奥州市水沢寺小路');
ok($zip->set_number('0230812')->is_valid_number, '岩手県奥州市水沢寺脇');
ok($zip->set_number('0230813')->is_valid_number, '岩手県奥州市水沢中町');
ok($zip->set_number('0230814')->is_valid_number, '岩手県奥州市水沢袋町');
ok($zip->set_number('0230815')->is_valid_number, '岩手県奥州市水沢天文台通り');
ok($zip->set_number('0230816')->is_valid_number, '岩手県奥州市水沢西町');
ok($zip->set_number('0230817')->is_valid_number, '岩手県奥州市水沢宮下町');
ok($zip->set_number('0230818')->is_valid_number, '岩手県奥州市水沢東町');
ok($zip->set_number('0230821')->is_valid_number, '岩手県奥州市水沢神明町');
ok($zip->set_number('0230822')->is_valid_number, '岩手県奥州市水沢東中通り');
ok($zip->set_number('0230823')->is_valid_number, '岩手県奥州市水沢朝日町');
ok($zip->set_number('0230824')->is_valid_number, '岩手県奥州市水沢泉町');
ok($zip->set_number('0230825')->is_valid_number, '岩手県奥州市水沢台町');
ok($zip->set_number('0230826')->is_valid_number, '岩手県奥州市水沢中田町');
ok($zip->set_number('0230827')->is_valid_number, '岩手県奥州市水沢太日通り');
ok($zip->set_number('0230828')->is_valid_number, '岩手県奥州市水沢東大通り');
ok($zip->set_number('0230829')->is_valid_number, '岩手県奥州市水沢花園町');
ok($zip->set_number('0230831')->is_valid_number, '岩手県奥州市水沢姉体町');
ok($zip->set_number('0230832')->is_valid_number, '岩手県奥州市水沢羽田町(草井沼、下沼、谷木、元谷木)');
ok($zip->set_number('0230833')->is_valid_number, '岩手県奥州市水沢上姉体');
ok($zip->set_number('0230841')->is_valid_number, '岩手県奥州市水沢真城');
ok($zip->set_number('0230842')->is_valid_number, '岩手県奥州市水沢真城が丘');
ok($zip->set_number('0230851')->is_valid_number, '岩手県奥州市水沢南町');
ok($zip->set_number('0230852')->is_valid_number, '岩手県奥州市水沢山崎町');
ok($zip->set_number('0230853')->is_valid_number, '岩手県奥州市水沢東上野町');
ok($zip->set_number('0230854')->is_valid_number, '岩手県奥州市水沢大鐘町');
ok($zip->set_number('0230855')->is_valid_number, '岩手県奥州市水沢南大鐘');
ok($zip->set_number('0230856')->is_valid_number, '岩手県奥州市水沢西上野町');
ok($zip->set_number('0230857')->is_valid_number, '岩手県奥州市水沢中上野町');
ok($zip->set_number('0230861')->is_valid_number, '岩手県奥州市水沢星ガ丘町');
ok($zip->set_number('0230862')->is_valid_number, '岩手県奥州市水沢福吉町');
ok($zip->set_number('0230863')->is_valid_number, '岩手県奥州市水沢川端');
ok($zip->set_number('0230864')->is_valid_number, '岩手県奥州市水沢龍ヶ馬場');
ok($zip->set_number('0230865')->is_valid_number, '岩手県奥州市水沢桜屋敷');
ok($zip->set_number('0230866')->is_valid_number, '岩手県奥州市水沢堰合');
ok($zip->set_number('0230867')->is_valid_number, '岩手県奥州市水沢大橋');
ok($zip->set_number('0230871')->is_valid_number, '岩手県奥州市水沢外谷地');
ok($zip->set_number('0230872')->is_valid_number, '岩手県奥州市水沢桜屋敷西');
ok($zip->set_number('0230873')->is_valid_number, '岩手県奥州市水沢笹森谷地');
ok($zip->set_number('0230874')->is_valid_number, '岩手県奥州市水沢見分森');
ok($zip->set_number('0230875')->is_valid_number, '岩手県奥州市水沢森下');
ok($zip->set_number('0230876')->is_valid_number, '岩手県奥州市水沢鶴淵');
ok($zip->set_number('0230877')->is_valid_number, '岩手県奥州市水沢袖谷地');
ok($zip->set_number('0230881')->is_valid_number, '岩手県奥州市水沢北田');
ok($zip->set_number('0230882')->is_valid_number, '岩手県奥州市水沢福原');
ok($zip->set_number('0230883')->is_valid_number, '岩手県奥州市水沢町裏');
ok($zip->set_number('0230884')->is_valid_number, '岩手県奥州市水沢前谷地');
ok($zip->set_number('0230885')->is_valid_number, '岩手県奥州市水沢西田');
ok($zip->set_number('0230886')->is_valid_number, '岩手県奥州市水沢南矢中');
ok($zip->set_number('0230887')->is_valid_number, '岩手県奥州市水沢矢中');
ok($zip->set_number('0230888')->is_valid_number, '岩手県奥州市水沢八反田');
ok($zip->set_number('0230889')->is_valid_number, '岩手県奥州市水沢高屋敷');
ok($zip->set_number('0230891')->is_valid_number, '岩手県奥州市水沢内匠田');
ok($zip->set_number('0230892')->is_valid_number, '岩手県奥州市水沢釜田');
ok($zip->set_number('0230893')->is_valid_number, '岩手県奥州市水沢蓬田');
ok($zip->set_number('0230894')->is_valid_number, '岩手県奥州市水沢大明神');
ok($zip->set_number('0230895')->is_valid_number, '岩手県奥州市水沢足袋針');
ok($zip->set_number('0230896')->is_valid_number, '岩手県奥州市水沢西光田');
ok($zip->set_number('0230897')->is_valid_number, '岩手県奥州市水沢桜川');
ok($zip->set_number('0230898')->is_valid_number, '岩手県奥州市水沢後田');
ok($zip->set_number('0231101')->is_valid_number, '岩手県奥州市江刺岩谷堂');
ok($zip->set_number('0231102')->is_valid_number, '岩手県奥州市江刺八日町');
ok($zip->set_number('0231103')->is_valid_number, '岩手県奥州市江刺西大通り');
ok($zip->set_number('0231104')->is_valid_number, '岩手県奥州市江刺豊田町');
ok($zip->set_number('0231105')->is_valid_number, '岩手県奥州市江刺杉ノ町');
ok($zip->set_number('0231111')->is_valid_number, '岩手県奥州市江刺大通り');
ok($zip->set_number('0231112')->is_valid_number, '岩手県奥州市江刺南大通り');
ok($zip->set_number('0231113')->is_valid_number, '岩手県奥州市江刺中町');
ok($zip->set_number('0231114')->is_valid_number, '岩手県奥州市江刺川原町');
ok($zip->set_number('0231115')->is_valid_number, '岩手県奥州市江刺本町');
ok($zip->set_number('0231116')->is_valid_number, '岩手県奥州市江刺重染寺');
ok($zip->set_number('0231117')->is_valid_number, '岩手県奥州市江刺南町');
ok($zip->set_number('0231118')->is_valid_number, '岩手県奥州市江刺栄町');
ok($zip->set_number('0231121')->is_valid_number, '岩手県奥州市江刺男石');
ok($zip->set_number('0231122')->is_valid_number, '岩手県奥州市江刺館山');
ok($zip->set_number('0231123')->is_valid_number, '岩手県奥州市江刺前田町');
ok($zip->set_number('0231124')->is_valid_number, '岩手県奥州市江刺六日町');
ok($zip->set_number('0231125')->is_valid_number, '岩手県奥州市江刺銭町');
ok($zip->set_number('0231131')->is_valid_number, '岩手県奥州市江刺愛宕');
ok($zip->set_number('0231132')->is_valid_number, '岩手県奥州市江刺稲瀬');
ok($zip->set_number('0231133')->is_valid_number, '岩手県奥州市江刺広瀬');
ok($zip->set_number('0231134')->is_valid_number, '岩手県奥州市江刺玉里');
ok($zip->set_number('0231341')->is_valid_number, '岩手県奥州市江刺梁川');
ok($zip->set_number('0231551')->is_valid_number, '岩手県奥州市江刺米里');
ok($zip->set_number('0231761')->is_valid_number, '岩手県奥州市江刺伊手');
ok($zip->set_number('0231762')->is_valid_number, '岩手県奥州市江刺藤里');
ok($zip->set_number('0240000')->is_valid_number, '岩手県北上市以下に掲載がない場合');
ok($zip->set_number('0240001')->is_valid_number, '岩手県北上市飯豊');
ok($zip->set_number('0240002')->is_valid_number, '岩手県北上市北工業団地(その他)');
ok($zip->set_number('0240003')->is_valid_number, '岩手県北上市成田');
ok($zip->set_number('0240004')->is_valid_number, '岩手県北上市村崎野');
ok($zip->set_number('0240011')->is_valid_number, '岩手県北上市堤ケ丘');
ok($zip->set_number('0240012')->is_valid_number, '岩手県北上市常盤台');
ok($zip->set_number('0240013')->is_valid_number, '岩手県北上市藤沢');
ok($zip->set_number('0240014')->is_valid_number, '岩手県北上市流通センター');
ok($zip->set_number('0240021')->is_valid_number, '岩手県北上市上野町');
ok($zip->set_number('0240022')->is_valid_number, '岩手県北上市黒沢尻');
ok($zip->set_number('0240023')->is_valid_number, '岩手県北上市里分');
ok($zip->set_number('0240024')->is_valid_number, '岩手県北上市中野町');
ok($zip->set_number('0240025')->is_valid_number, '岩手県北上市孫屋敷');
ok($zip->set_number('0240031')->is_valid_number, '岩手県北上市青柳町');
ok($zip->set_number('0240032')->is_valid_number, '岩手県北上市川岸');
ok($zip->set_number('0240033')->is_valid_number, '岩手県北上市幸町');
ok($zip->set_number('0240034')->is_valid_number, '岩手県北上市諏訪町');
ok($zip->set_number('0240035')->is_valid_number, '岩手県北上市花園町');
ok($zip->set_number('0240041')->is_valid_number, '岩手県北上市稲瀬町');
ok($zip->set_number('0240042')->is_valid_number, '岩手県北上市黒岩');
ok($zip->set_number('0240043')->is_valid_number, '岩手県北上市立花');
ok($zip->set_number('0240044')->is_valid_number, '岩手県北上市平沢');
ok($zip->set_number('0240045')->is_valid_number, '岩手県北上市湯沢');
ok($zip->set_number('0240051')->is_valid_number, '岩手県北上市相去町');
ok($zip->set_number('0240052')->is_valid_number, '岩手県北上市大堤北');
ok($zip->set_number('0240053')->is_valid_number, '岩手県北上市大堤西');
ok($zip->set_number('0240054')->is_valid_number, '岩手県北上市大堤東');
ok($zip->set_number('0240055')->is_valid_number, '岩手県北上市大堤南');
ok($zip->set_number('0240056')->is_valid_number, '岩手県北上市鬼柳町');
ok($zip->set_number('0240057')->is_valid_number, '岩手県北上市上鬼柳');
ok($zip->set_number('0240058')->is_valid_number, '岩手県北上市下鬼柳');
ok($zip->set_number('0240061')->is_valid_number, '岩手県北上市大通り');
ok($zip->set_number('0240062')->is_valid_number, '岩手県北上市鍛冶町');
ok($zip->set_number('0240063')->is_valid_number, '岩手県北上市九年橋');
ok($zip->set_number('0240064')->is_valid_number, '岩手県北上市若宮町');
ok($zip->set_number('0240071')->is_valid_number, '岩手県北上市上江釣子');
ok($zip->set_number('0240072')->is_valid_number, '岩手県北上市北鬼柳');
ok($zip->set_number('0240073')->is_valid_number, '岩手県北上市下江釣子');
ok($zip->set_number('0240074')->is_valid_number, '岩手県北上市滑田');
ok($zip->set_number('0240075')->is_valid_number, '岩手県北上市新平');
ok($zip->set_number('0240076')->is_valid_number, '岩手県北上市鳩岡崎');
ok($zip->set_number('0240081')->is_valid_number, '岩手県北上市有田町');
ok($zip->set_number('0240082')->is_valid_number, '岩手県北上市町分');
ok($zip->set_number('0240083')->is_valid_number, '岩手県北上市柳原町');
ok($zip->set_number('0240084')->is_valid_number, '岩手県北上市さくら通り');
ok($zip->set_number('0240085')->is_valid_number, '岩手県北上市しらゆり');
ok($zip->set_number('0240091')->is_valid_number, '岩手県北上市大曲町');
ok($zip->set_number('0240092')->is_valid_number, '岩手県北上市新穀町');
ok($zip->set_number('0240093')->is_valid_number, '岩手県北上市本石町');
ok($zip->set_number('0240094')->is_valid_number, '岩手県北上市本通り');
ok($zip->set_number('0240095')->is_valid_number, '岩手県北上市芳町');
ok($zip->set_number('0240101')->is_valid_number, '岩手県北上市臥牛');
ok($zip->set_number('0240102')->is_valid_number, '岩手県北上市北工業団地(3、5番地)');
ok($zip->set_number('0240103')->is_valid_number, '岩手県北上市更木');
ok($zip->set_number('0240104')->is_valid_number, '岩手県北上市二子町');
ok($zip->set_number('0240105')->is_valid_number, '岩手県北上市小鳥崎');
ok($zip->set_number('0240211')->is_valid_number, '岩手県北上市口内町');
ok($zip->set_number('0240321')->is_valid_number, '岩手県北上市和賀町岩崎');
ok($zip->set_number('0240322')->is_valid_number, '岩手県北上市和賀町岩崎新田');
ok($zip->set_number('0240323')->is_valid_number, '岩手県北上市和賀町煤孫');
ok($zip->set_number('0240324')->is_valid_number, '岩手県北上市和賀町山口');
ok($zip->set_number('0240325')->is_valid_number, '岩手県北上市和賀町岩沢');
ok($zip->set_number('0240326')->is_valid_number, '岩手県北上市和賀町仙人');
ok($zip->set_number('0240331')->is_valid_number, '岩手県北上市和賀町横川目');
ok($zip->set_number('0240332')->is_valid_number, '岩手県北上市和賀町竪川目');
ok($zip->set_number('0240333')->is_valid_number, '岩手県北上市和賀町長沼');
ok($zip->set_number('0240334')->is_valid_number, '岩手県北上市和賀町藤根');
ok($zip->set_number('0240335')->is_valid_number, '岩手県北上市和賀町後藤');
ok($zip->set_number('0240341')->is_valid_number, '岩手県和賀郡西和賀町杉名畑44地割(湯田ダム管理事務所、後口山、当楽)');
ok($zip->set_number('0250000')->is_valid_number, '岩手県花巻市以下に掲載がない場合');
ok($zip->set_number('0250001')->is_valid_number, '岩手県花巻市天下田');
ok($zip->set_number('0250002')->is_valid_number, '岩手県花巻市西宮野目');
ok($zip->set_number('0250003')->is_valid_number, '岩手県花巻市東宮野目');
ok($zip->set_number('0250004')->is_valid_number, '岩手県花巻市葛');
ok($zip->set_number('0250005')->is_valid_number, '岩手県花巻市田力');
ok($zip->set_number('0250006')->is_valid_number, '岩手県花巻市下似内');
ok($zip->set_number('0250007')->is_valid_number, '岩手県花巻市上似内');
ok($zip->set_number('0250008')->is_valid_number, '岩手県花巻市空港南');
ok($zip->set_number('0250011')->is_valid_number, '岩手県花巻市矢沢');
ok($zip->set_number('0250012')->is_valid_number, '岩手県花巻市胡四王');
ok($zip->set_number('0250013')->is_valid_number, '岩手県花巻市幸田');
ok($zip->set_number('0250014')->is_valid_number, '岩手県花巻市高松');
ok($zip->set_number('0250015')->is_valid_number, '岩手県花巻市東十二丁目');
ok($zip->set_number('0250016')->is_valid_number, '岩手県花巻市高木');
ok($zip->set_number('0250021')->is_valid_number, '岩手県花巻市南城');
ok($zip->set_number('0250022')->is_valid_number, '岩手県花巻市十二丁目');
ok($zip->set_number('0250023')->is_valid_number, '岩手県花巻市成田');
ok($zip->set_number('0250024')->is_valid_number, '岩手県花巻市山の神');
ok($zip->set_number('0250025')->is_valid_number, '岩手県花巻市下根子');
ok($zip->set_number('0250026')->is_valid_number, '岩手県花巻市大谷地');
ok($zip->set_number('0250031')->is_valid_number, '岩手県花巻市不動');
ok($zip->set_number('0250032')->is_valid_number, '岩手県花巻市上諏訪');
ok($zip->set_number('0250033')->is_valid_number, '岩手県花巻市諏訪');
ok($zip->set_number('0250034')->is_valid_number, '岩手県花巻市南諏訪町');
ok($zip->set_number('0250035')->is_valid_number, '岩手県花巻市実相寺');
ok($zip->set_number('0250036')->is_valid_number, '岩手県花巻市中根子');
ok($zip->set_number('0250037')->is_valid_number, '岩手県花巻市太田');
ok($zip->set_number('0250038')->is_valid_number, '岩手県花巻市不動町');
ok($zip->set_number('0250039')->is_valid_number, '岩手県花巻市諏訪町');
ok($zip->set_number('0250041')->is_valid_number, '岩手県花巻市膝立');
ok($zip->set_number('0250042')->is_valid_number, '岩手県花巻市円万寺');
ok($zip->set_number('0250043')->is_valid_number, '岩手県花巻市上根子');
ok($zip->set_number('0250044')->is_valid_number, '岩手県花巻市湯口(石川原、田屋、二ツ堰、的場)');
ok($zip->set_number('0250045')->is_valid_number, '岩手県花巻市西晴山');
ok($zip->set_number('0250046')->is_valid_number, '岩手県花巻市鍋倉');
ok($zip->set_number('0250051')->is_valid_number, '岩手県花巻市南新田');
ok($zip->set_number('0250052')->is_valid_number, '岩手県花巻市野田');
ok($zip->set_number('0250053')->is_valid_number, '岩手県花巻市中北万丁目');
ok($zip->set_number('0250054')->is_valid_number, '岩手県花巻市下北万丁目');
ok($zip->set_number('0250055')->is_valid_number, '岩手県花巻市南万丁目');
ok($zip->set_number('0250056')->is_valid_number, '岩手県花巻市上北万丁目');
ok($zip->set_number('0250057')->is_valid_number, '岩手県花巻市新田');
ok($zip->set_number('0250058')->is_valid_number, '岩手県花巻市一本杉');
ok($zip->set_number('0250061')->is_valid_number, '岩手県花巻市本館');
ok($zip->set_number('0250062')->is_valid_number, '岩手県花巻市上小舟渡');
ok($zip->set_number('0250063')->is_valid_number, '岩手県花巻市下小舟渡');
ok($zip->set_number('0250064')->is_valid_number, '岩手県花巻市桜台');
ok($zip->set_number('0250065')->is_valid_number, '岩手県花巻市星が丘');
ok($zip->set_number('0250066')->is_valid_number, '岩手県花巻市松園町');
ok($zip->set_number('0250067')->is_valid_number, '岩手県花巻市浅沢');
ok($zip->set_number('0250068')->is_valid_number, '岩手県花巻市下幅');
ok($zip->set_number('0250071')->is_valid_number, '岩手県花巻市愛宕町');
ok($zip->set_number('0250072')->is_valid_number, '岩手県花巻市四日町');
ok($zip->set_number('0250073')->is_valid_number, '岩手県花巻市一日市');
ok($zip->set_number('0250074')->is_valid_number, '岩手県花巻市坂本町');
ok($zip->set_number('0250075')->is_valid_number, '岩手県花巻市花城町');
ok($zip->set_number('0250076')->is_valid_number, '岩手県花巻市城内');
ok($zip->set_number('0250077')->is_valid_number, '岩手県花巻市仲町');
ok($zip->set_number('0250078')->is_valid_number, '岩手県花巻市吹張町');
ok($zip->set_number('0250079')->is_valid_number, '岩手県花巻市末広町');
ok($zip->set_number('0250081')->is_valid_number, '岩手県花巻市里川口町');
ok($zip->set_number('0250082')->is_valid_number, '岩手県花巻市御田屋町');
ok($zip->set_number('0250083')->is_valid_number, '岩手県花巻市高田');
ok($zip->set_number('0250084')->is_valid_number, '岩手県花巻市桜町');
ok($zip->set_number('0250085')->is_valid_number, '岩手県花巻市双葉町');
ok($zip->set_number('0250086')->is_valid_number, '岩手県花巻市鍛治町');
ok($zip->set_number('0250087')->is_valid_number, '岩手県花巻市上町');
ok($zip->set_number('0250088')->is_valid_number, '岩手県花巻市東町');
ok($zip->set_number('0250089')->is_valid_number, '岩手県花巻市豊沢町');
ok($zip->set_number('0250091')->is_valid_number, '岩手県花巻市西大通り');
ok($zip->set_number('0250092')->is_valid_number, '岩手県花巻市大通り');
ok($zip->set_number('0250093')->is_valid_number, '岩手県花巻市南川原町');
ok($zip->set_number('0250094')->is_valid_number, '岩手県花巻市桜木町');
ok($zip->set_number('0250095')->is_valid_number, '岩手県花巻市石神町');
ok($zip->set_number('0250096')->is_valid_number, '岩手県花巻市藤沢町');
ok($zip->set_number('0250097')->is_valid_number, '岩手県花巻市若葉町');
ok($zip->set_number('0250098')->is_valid_number, '岩手県花巻市材木町');
ok($zip->set_number('0250131')->is_valid_number, '岩手県花巻市轟木');
ok($zip->set_number('0250132')->is_valid_number, '岩手県花巻市北笹間');
ok($zip->set_number('0250133')->is_valid_number, '岩手県花巻市中笹間');
ok($zip->set_number('0250134')->is_valid_number, '岩手県花巻市南笹間');
ok($zip->set_number('0250135')->is_valid_number, '岩手県花巻市栃内');
ok($zip->set_number('0250136')->is_valid_number, '岩手県花巻市横志田');
ok($zip->set_number('0250137')->is_valid_number, '岩手県花巻市尻平川');
ok($zip->set_number('0250244')->is_valid_number, '岩手県花巻市湯口(その他)');
ok($zip->set_number('0250251')->is_valid_number, '岩手県花巻市豊沢');
ok($zip->set_number('0250252')->is_valid_number, '岩手県花巻市鉛');
ok($zip->set_number('0250253')->is_valid_number, '岩手県花巻市下シ沢');
ok($zip->set_number('0250301')->is_valid_number, '岩手県花巻市北湯口');
ok($zip->set_number('0250302')->is_valid_number, '岩手県花巻市糠塚');
ok($zip->set_number('0250303')->is_valid_number, '岩手県花巻市大畑');
ok($zip->set_number('0250304')->is_valid_number, '岩手県花巻市湯本');
ok($zip->set_number('0250305')->is_valid_number, '岩手県花巻市台');
ok($zip->set_number('0250311')->is_valid_number, '岩手県花巻市卸町');
ok($zip->set_number('0250312')->is_valid_number, '岩手県花巻市二枚橋');
ok($zip->set_number('0250313')->is_valid_number, '岩手県花巻市二枚橋町北');
ok($zip->set_number('0250314')->is_valid_number, '岩手県花巻市二枚橋町大通り');
ok($zip->set_number('0250315')->is_valid_number, '岩手県花巻市二枚橋町南');
ok($zip->set_number('0250321')->is_valid_number, '岩手県花巻市金矢');
ok($zip->set_number('0250322')->is_valid_number, '岩手県花巻市狼沢');
ok($zip->set_number('0250323')->is_valid_number, '岩手県花巻市椚ノ目');
ok($zip->set_number('0250324')->is_valid_number, '岩手県花巻市小瀬川');
ok($zip->set_number('0260000')->is_valid_number, '岩手県釜石市以下に掲載がない場合');
ok($zip->set_number('0260001')->is_valid_number, '岩手県釜石市平田');
ok($zip->set_number('0260002')->is_valid_number, '岩手県釜石市大平町');
ok($zip->set_number('0260003')->is_valid_number, '岩手県釜石市嬉石町');
ok($zip->set_number('0260004')->is_valid_number, '岩手県釜石市松原町');
ok($zip->set_number('0260005')->is_valid_number, '岩手県釜石市平田町');
ok($zip->set_number('0260011')->is_valid_number, '岩手県釜石市港町');
ok($zip->set_number('0260012')->is_valid_number, '岩手県釜石市魚河岸');
ok($zip->set_number('0260013')->is_valid_number, '岩手県釜石市浜町');
ok($zip->set_number('0260014')->is_valid_number, '岩手県釜石市東前町');
ok($zip->set_number('0260015')->is_valid_number, '岩手県釜石市新浜町');
ok($zip->set_number('0260021')->is_valid_number, '岩手県釜石市只越町');
ok($zip->set_number('0260022')->is_valid_number, '岩手県釜石市大只越町');
ok($zip->set_number('0260023')->is_valid_number, '岩手県釜石市天神町');
ok($zip->set_number('0260024')->is_valid_number, '岩手県釜石市大町');
ok($zip->set_number('0260025')->is_valid_number, '岩手県釜石市大渡町');
ok($zip->set_number('0260026')->is_valid_number, '岩手県釜石市釜石');
ok($zip->set_number('0260031')->is_valid_number, '岩手県釜石市鈴子町');
ok($zip->set_number('0260032')->is_valid_number, '岩手県釜石市千鳥町');
ok($zip->set_number('0260033')->is_valid_number, '岩手県釜石市駒木町');
ok($zip->set_number('0260034')->is_valid_number, '岩手県釜石市中妻町');
ok($zip->set_number('0260035')->is_valid_number, '岩手県釜石市八雲町');
ok($zip->set_number('0260041')->is_valid_number, '岩手県釜石市上中島町');
ok($zip->set_number('0260042')->is_valid_number, '岩手県釜石市源太沢町');
ok($zip->set_number('0260043')->is_valid_number, '岩手県釜石市新町');
ok($zip->set_number('0260044')->is_valid_number, '岩手県釜石市住吉町');
ok($zip->set_number('0260045')->is_valid_number, '岩手県釜石市小川町');
ok($zip->set_number('0260046')->is_valid_number, '岩手県釜石市桜木町');
ok($zip->set_number('0260051')->is_valid_number, '岩手県釜石市礼ケ口町');
ok($zip->set_number('0260052')->is_valid_number, '岩手県釜石市小佐野町');
ok($zip->set_number('0260053')->is_valid_number, '岩手県釜石市定内町');
ok($zip->set_number('0260054')->is_valid_number, '岩手県釜石市野田町');
ok($zip->set_number('0260055')->is_valid_number, '岩手県釜石市甲子町');
ok($zip->set_number('0260061')->is_valid_number, '岩手県釜石市唐丹町(鍋倉)');
ok($zip->set_number('0260121')->is_valid_number, '岩手県釜石市唐丹町(その他)');
ok($zip->set_number('0260301')->is_valid_number, '岩手県釜石市鵜住居町');
ok($zip->set_number('0260302')->is_valid_number, '岩手県釜石市片岸町');
ok($zip->set_number('0260303')->is_valid_number, '岩手県釜石市箱崎町');
ok($zip->set_number('0260304')->is_valid_number, '岩手県釜石市両石町');
ok($zip->set_number('0260411')->is_valid_number, '岩手県釜石市橋野町');
ok($zip->set_number('0260412')->is_valid_number, '岩手県釜石市栗林町');
ok($zip->set_number('0270000')->is_valid_number, '岩手県宮古市以下に掲載がない場合');
ok($zip->set_number('0270001')->is_valid_number, '岩手県宮古市日立浜町');
ok($zip->set_number('0270002')->is_valid_number, '岩手県宮古市山根町');
ok($zip->set_number('0270003')->is_valid_number, '岩手県宮古市港町');
ok($zip->set_number('0270004')->is_valid_number, '岩手県宮古市臨港通');
ok($zip->set_number('0270005')->is_valid_number, '岩手県宮古市光岸地');
ok($zip->set_number('0270006')->is_valid_number, '岩手県宮古市鍬ケ崎');
ok($zip->set_number('0270007')->is_valid_number, '岩手県宮古市日影町');
ok($zip->set_number('0270008')->is_valid_number, '岩手県宮古市熊野町');
ok($zip->set_number('0270009')->is_valid_number, '岩手県宮古市蛸の浜町');
ok($zip->set_number('0270021')->is_valid_number, '岩手県宮古市藤原');
ok($zip->set_number('0270021')->is_valid_number, '岩手県宮古市藤原上町');
ok($zip->set_number('0270022')->is_valid_number, '岩手県宮古市磯鶏石崎');
ok($zip->set_number('0270023')->is_valid_number, '岩手県宮古市磯鶏沖');
ok($zip->set_number('0270024')->is_valid_number, '岩手県宮古市磯鶏');
ok($zip->set_number('0270025')->is_valid_number, '岩手県宮古市実田');
ok($zip->set_number('0270026')->is_valid_number, '岩手県宮古市上村');
ok($zip->set_number('0270027')->is_valid_number, '岩手県宮古市磯鶏西');
ok($zip->set_number('0270028')->is_valid_number, '岩手県宮古市神林');
ok($zip->set_number('0270029')->is_valid_number, '岩手県宮古市藤の川');
ok($zip->set_number('0270031')->is_valid_number, '岩手県宮古市八木沢');
ok($zip->set_number('0270032')->is_valid_number, '岩手県宮古市高浜');
ok($zip->set_number('0270033')->is_valid_number, '岩手県宮古市金浜');
ok($zip->set_number('0270034')->is_valid_number, '岩手県宮古市長沢');
ok($zip->set_number('0270035')->is_valid_number, '岩手県宮古市花輪');
ok($zip->set_number('0270036')->is_valid_number, '岩手県宮古市田鎖');
ok($zip->set_number('0270037')->is_valid_number, '岩手県宮古市松山');
ok($zip->set_number('0270038')->is_valid_number, '岩手県宮古市小山田');
ok($zip->set_number('0270039')->is_valid_number, '岩手県宮古市河南');
ok($zip->set_number('0270041')->is_valid_number, '岩手県宮古市西ケ丘');
ok($zip->set_number('0270042')->is_valid_number, '岩手県宮古市神田沢町');
ok($zip->set_number('0270043')->is_valid_number, '岩手県宮古市千徳町');
ok($zip->set_number('0270044')->is_valid_number, '岩手県宮古市上鼻');
ok($zip->set_number('0270045')->is_valid_number, '岩手県宮古市老木');
ok($zip->set_number('0270046')->is_valid_number, '岩手県宮古市花原市');
ok($zip->set_number('0270047')->is_valid_number, '岩手県宮古市根市');
ok($zip->set_number('0270048')->is_valid_number, '岩手県宮古市板屋');
ok($zip->set_number('0270051')->is_valid_number, '岩手県宮古市南町');
ok($zip->set_number('0270052')->is_valid_number, '岩手県宮古市宮町');
ok($zip->set_number('0270053')->is_valid_number, '岩手県宮古市長町');
ok($zip->set_number('0270054')->is_valid_number, '岩手県宮古市太田');
ok($zip->set_number('0270055')->is_valid_number, '岩手県宮古市長根');
ok($zip->set_number('0270056')->is_valid_number, '岩手県宮古市近内');
ok($zip->set_number('0270058')->is_valid_number, '岩手県宮古市千徳');
ok($zip->set_number('0270061')->is_valid_number, '岩手県宮古市西町');
ok($zip->set_number('0270062')->is_valid_number, '岩手県宮古市泉町');
ok($zip->set_number('0270063')->is_valid_number, '岩手県宮古市山口');
ok($zip->set_number('0270064')->is_valid_number, '岩手県宮古市宮園');
ok($zip->set_number('0270065')->is_valid_number, '岩手県宮古市黒森町');
ok($zip->set_number('0270066')->is_valid_number, '岩手県宮古市田の神');
ok($zip->set_number('0270067')->is_valid_number, '岩手県宮古市田代');
ok($zip->set_number('0270071')->is_valid_number, '岩手県宮古市小沢');
ok($zip->set_number('0270072')->is_valid_number, '岩手県宮古市五月町');
ok($zip->set_number('0270073')->is_valid_number, '岩手県宮古市緑ケ丘');
ok($zip->set_number('0270074')->is_valid_number, '岩手県宮古市保久田');
ok($zip->set_number('0270075')->is_valid_number, '岩手県宮古市和見町');
ok($zip->set_number('0270076')->is_valid_number, '岩手県宮古市栄町');
ok($zip->set_number('0270077')->is_valid_number, '岩手県宮古市舘合町');
ok($zip->set_number('0270078')->is_valid_number, '岩手県宮古市鴨崎町');
ok($zip->set_number('0270081')->is_valid_number, '岩手県宮古市新川町');
ok($zip->set_number('0270082')->is_valid_number, '岩手県宮古市向町');
ok($zip->set_number('0270083')->is_valid_number, '岩手県宮古市大通');
ok($zip->set_number('0270084')->is_valid_number, '岩手県宮古市末広町');
ok($zip->set_number('0270085')->is_valid_number, '岩手県宮古市黒田町');
ok($zip->set_number('0270086')->is_valid_number, '岩手県宮古市新町');
ok($zip->set_number('0270087')->is_valid_number, '岩手県宮古市横町');
ok($zip->set_number('0270088')->is_valid_number, '岩手県宮古市沢田');
ok($zip->set_number('0270089')->is_valid_number, '岩手県宮古市本町');
ok($zip->set_number('0270091')->is_valid_number, '岩手県宮古市築地');
ok($zip->set_number('0270092')->is_valid_number, '岩手県宮古市愛宕');
ok($zip->set_number('0270093')->is_valid_number, '岩手県宮古市中里団地');
ok($zip->set_number('0270094')->is_valid_number, '岩手県宮古市日の出町');
ok($zip->set_number('0270095')->is_valid_number, '岩手県宮古市佐原');
ok($zip->set_number('0270096')->is_valid_number, '岩手県宮古市崎鍬ケ崎');
ok($zip->set_number('0270097')->is_valid_number, '岩手県宮古市崎山');
ok($zip->set_number('0270111')->is_valid_number, '岩手県宮古市重茂');
ok($zip->set_number('0270112')->is_valid_number, '岩手県宮古市音部');
ok($zip->set_number('0270201')->is_valid_number, '岩手県宮古市白浜');
ok($zip->set_number('0270202')->is_valid_number, '岩手県宮古市赤前');
ok($zip->set_number('0270203')->is_valid_number, '岩手県宮古市津軽石');
ok($zip->set_number('0270301')->is_valid_number, '岩手県宮古市田老館が森');
ok($zip->set_number('0270302')->is_valid_number, '岩手県宮古市田老田中');
ok($zip->set_number('0270303')->is_valid_number, '岩手県宮古市田老田の沢');
ok($zip->set_number('0270304')->is_valid_number, '岩手県宮古市田老ケラス');
ok($zip->set_number('0270305')->is_valid_number, '岩手県宮古市田老荒谷');
ok($zip->set_number('0270306')->is_valid_number, '岩手県宮古市田老川向');
ok($zip->set_number('0270307')->is_valid_number, '岩手県宮古市田老');
ok($zip->set_number('0270311')->is_valid_number, '岩手県宮古市田老和野');
ok($zip->set_number('0270312')->is_valid_number, '岩手県宮古市田老越田');
ok($zip->set_number('0270313')->is_valid_number, '岩手県宮古市田老駿達');
ok($zip->set_number('0270321')->is_valid_number, '岩手県宮古市田老乙部');
ok($zip->set_number('0270322')->is_valid_number, '岩手県宮古市田老青砂里');
ok($zip->set_number('0270323')->is_valid_number, '岩手県宮古市田老野原');
ok($zip->set_number('0270324')->is_valid_number, '岩手県宮古市田老向山');
ok($zip->set_number('0270325')->is_valid_number, '岩手県宮古市田老三王');
ok($zip->set_number('0270331')->is_valid_number, '岩手県宮古市田老西向山');
ok($zip->set_number('0270332')->is_valid_number, '岩手県宮古市田老樫内');
ok($zip->set_number('0270333')->is_valid_number, '岩手県宮古市田老古田');
ok($zip->set_number('0270341')->is_valid_number, '岩手県宮古市田老養呂地');
ok($zip->set_number('0270342')->is_valid_number, '岩手県宮古市田老小田代');
ok($zip->set_number('0270343')->is_valid_number, '岩手県宮古市田老上小田代');
ok($zip->set_number('0270344')->is_valid_number, '岩手県宮古市田老辰の口');
ok($zip->set_number('0270345')->is_valid_number, '岩手県宮古市田老篠倉');
ok($zip->set_number('0270346')->is_valid_number, '岩手県宮古市田老七滝');
ok($zip->set_number('0270347')->is_valid_number, '岩手県宮古市田老笹見平');
ok($zip->set_number('0270351')->is_valid_number, '岩手県宮古市田老小林');
ok($zip->set_number('0270352')->is_valid_number, '岩手県宮古市田老八幡水神');
ok($zip->set_number('0270353')->is_valid_number, '岩手県宮古市田老和蒔');
ok($zip->set_number('0270354')->is_valid_number, '岩手県宮古市田老森崎');
ok($zip->set_number('0270355')->is_valid_number, '岩手県宮古市田老末前');
ok($zip->set_number('0270356')->is_valid_number, '岩手県宮古市田老和山');
ok($zip->set_number('0270357')->is_valid_number, '岩手県宮古市田老向桑畑');
ok($zip->set_number('0270358')->is_valid_number, '岩手県宮古市田老立腰');
ok($zip->set_number('0270359')->is_valid_number, '岩手県宮古市田老青倉');
ok($zip->set_number('0270361')->is_valid_number, '岩手県宮古市田老小堀内');
ok($zip->set_number('0270362')->is_valid_number, '岩手県宮古市田老小堀内南');
ok($zip->set_number('0270363')->is_valid_number, '岩手県宮古市田老長畑');
ok($zip->set_number('0270364')->is_valid_number, '岩手県宮古市田老新田');
ok($zip->set_number('0270365')->is_valid_number, '岩手県宮古市田老滝の沢');
ok($zip->set_number('0270366')->is_valid_number, '岩手県宮古市田老新田平');
ok($zip->set_number('0270367')->is_valid_number, '岩手県宮古市田老鈴子沢');
ok($zip->set_number('0270371')->is_valid_number, '岩手県宮古市田老水沢');
ok($zip->set_number('0270372')->is_valid_number, '岩手県宮古市田老水沢南');
ok($zip->set_number('0270373')->is_valid_number, '岩手県宮古市田老向新田');
ok($zip->set_number('0270374')->is_valid_number, '岩手県宮古市田老青野滝北');
ok($zip->set_number('0270375')->is_valid_number, '岩手県宮古市田老青野滝');
ok($zip->set_number('0270376')->is_valid_number, '岩手県宮古市田老青野滝南');
ok($zip->set_number('0270377')->is_valid_number, '岩手県宮古市田老重津部北');
ok($zip->set_number('0270378')->is_valid_number, '岩手県宮古市田老重津部');
ok($zip->set_number('0270379')->is_valid_number, '岩手県宮古市田老乙部野');
ok($zip->set_number('0270381')->is_valid_number, '岩手県宮古市田老星山');
ok($zip->set_number('0270382')->is_valid_number, '岩手県宮古市田老片巻');
ok($zip->set_number('0270383')->is_valid_number, '岩手県宮古市田老上摂待');
ok($zip->set_number('0270384')->is_valid_number, '岩手県宮古市田老摂待');
ok($zip->set_number('0270385')->is_valid_number, '岩手県宮古市田老下摂待');
ok($zip->set_number('0270386')->is_valid_number, '岩手県宮古市田老胡桃畑');
ok($zip->set_number('0270387')->is_valid_number, '岩手県宮古市田老畑');
ok($zip->set_number('0270388')->is_valid_number, '岩手県宮古市田老上沖');
ok($zip->set_number('0270421')->is_valid_number, '岩手県下閉伊郡岩泉町小本');
ok($zip->set_number('0270422')->is_valid_number, '岩手県下閉伊郡岩泉町中島');
ok($zip->set_number('0270423')->is_valid_number, '岩手県下閉伊郡岩泉町中里');
ok($zip->set_number('0270424')->is_valid_number, '岩手県下閉伊郡岩泉町袰野');
ok($zip->set_number('0270500')->is_valid_number, '岩手県下閉伊郡岩泉町以下に掲載がない場合');
ok($zip->set_number('0270501')->is_valid_number, '岩手県下閉伊郡岩泉町岩泉');
ok($zip->set_number('0270502')->is_valid_number, '岩手県下閉伊郡岩泉町乙茂');
ok($zip->set_number('0270503')->is_valid_number, '岩手県下閉伊郡岩泉町猿沢');
ok($zip->set_number('0270504')->is_valid_number, '岩手県下閉伊郡岩泉町下有芸');
ok($zip->set_number('0270505')->is_valid_number, '岩手県下閉伊郡岩泉町上有芸');
ok($zip->set_number('0270506')->is_valid_number, '岩手県下閉伊郡岩泉町鼠入');
ok($zip->set_number('0270507')->is_valid_number, '岩手県下閉伊郡岩泉町二升石');
ok($zip->set_number('0270508')->is_valid_number, '岩手県下閉伊郡岩泉町尼額');
ok($zip->set_number('0270611')->is_valid_number, '岩手県下閉伊郡岩泉町安家');
ok($zip->set_number('0280000')->is_valid_number, '岩手県久慈市以下に掲載がない場合');
ok($zip->set_number('0280001')->is_valid_number, '岩手県久慈市夏井町');
ok($zip->set_number('0280011')->is_valid_number, '岩手県久慈市湊町');
ok($zip->set_number('0280012')->is_valid_number, '岩手県久慈市新井田');
ok($zip->set_number('0280013')->is_valid_number, '岩手県久慈市京の森');
ok($zip->set_number('0280014')->is_valid_number, '岩手県久慈市旭町');
ok($zip->set_number('0280015')->is_valid_number, '岩手県久慈市源道');
ok($zip->set_number('0280021')->is_valid_number, '岩手県久慈市門前');
ok($zip->set_number('0280022')->is_valid_number, '岩手県久慈市田屋町');
ok($zip->set_number('0280023')->is_valid_number, '岩手県久慈市新中の橋');
ok($zip->set_number('0280024')->is_valid_number, '岩手県久慈市栄町');
ok($zip->set_number('0280031')->is_valid_number, '岩手県久慈市天神堂');
ok($zip->set_number('0280032')->is_valid_number, '岩手県久慈市寺里');
ok($zip->set_number('0280033')->is_valid_number, '岩手県久慈市畑田');
ok($zip->set_number('0280034')->is_valid_number, '岩手県久慈市枝成沢');
ok($zip->set_number('0280035')->is_valid_number, '岩手県久慈市沢里');
ok($zip->set_number('0280041')->is_valid_number, '岩手県久慈市長内町');
ok($zip->set_number('0280051')->is_valid_number, '岩手県久慈市川崎町');
ok($zip->set_number('0280052')->is_valid_number, '岩手県久慈市本町');
ok($zip->set_number('0280053')->is_valid_number, '岩手県久慈市田高');
ok($zip->set_number('0280054')->is_valid_number, '岩手県久慈市柏崎');
ok($zip->set_number('0280055')->is_valid_number, '岩手県久慈市巽町');
ok($zip->set_number('0280056')->is_valid_number, '岩手県久慈市中町');
ok($zip->set_number('0280061')->is_valid_number, '岩手県久慈市中央');
ok($zip->set_number('0280062')->is_valid_number, '岩手県久慈市二十八日町');
ok($zip->set_number('0280063')->is_valid_number, '岩手県久慈市荒町');
ok($zip->set_number('0280064')->is_valid_number, '岩手県久慈市八日町');
ok($zip->set_number('0280065')->is_valid_number, '岩手県久慈市十八日町');
ok($zip->set_number('0280066')->is_valid_number, '岩手県久慈市中の橋');
ok($zip->set_number('0280071')->is_valid_number, '岩手県久慈市小久慈町');
ok($zip->set_number('0280081')->is_valid_number, '岩手県久慈市西の沢');
ok($zip->set_number('0280082')->is_valid_number, '岩手県久慈市川貫');
ok($zip->set_number('0280083')->is_valid_number, '岩手県久慈市大沢');
ok($zip->set_number('0280091')->is_valid_number, '岩手県久慈市大川目町');
ok($zip->set_number('0280101')->is_valid_number, '岩手県花巻市東和町北前田');
ok($zip->set_number('0280102')->is_valid_number, '岩手県花巻市東和町北川目');
ok($zip->set_number('0280103')->is_valid_number, '岩手県花巻市東和町石鳩岡');
ok($zip->set_number('0280104')->is_valid_number, '岩手県花巻市東和町南川目');
ok($zip->set_number('0280105')->is_valid_number, '岩手県花巻市東和町前田');
ok($zip->set_number('0280106')->is_valid_number, '岩手県花巻市東和町外谷地');
ok($zip->set_number('0280107')->is_valid_number, '岩手県花巻市東和町北小山田');
ok($zip->set_number('0280111')->is_valid_number, '岩手県花巻市東和町百ノ沢');
ok($zip->set_number('0280112')->is_valid_number, '岩手県花巻市東和町新地');
ok($zip->set_number('0280113')->is_valid_number, '岩手県花巻市東和町東晴山');
ok($zip->set_number('0280114')->is_valid_number, '岩手県花巻市東和町土沢');
ok($zip->set_number('0280115')->is_valid_number, '岩手県花巻市東和町安俵');
ok($zip->set_number('0280116')->is_valid_number, '岩手県花巻市東和町北成島');
ok($zip->set_number('0280121')->is_valid_number, '岩手県花巻市東和町小友');
ok($zip->set_number('0280122')->is_valid_number, '岩手県花巻市東和町谷内');
ok($zip->set_number('0280123')->is_valid_number, '岩手県花巻市東和町田瀬');
ok($zip->set_number('0280131')->is_valid_number, '岩手県花巻市東和町町井');
ok($zip->set_number('0280132')->is_valid_number, '岩手県花巻市東和町舘迫');
ok($zip->set_number('0280133')->is_valid_number, '岩手県花巻市東和町鷹巣堂');
ok($zip->set_number('0280134')->is_valid_number, '岩手県花巻市東和町砂子');
ok($zip->set_number('0280135')->is_valid_number, '岩手県花巻市東和町倉沢');
ok($zip->set_number('0280136')->is_valid_number, '岩手県花巻市東和町小原');
ok($zip->set_number('0280141')->is_valid_number, '岩手県花巻市東和町下浮田');
ok($zip->set_number('0280142')->is_valid_number, '岩手県花巻市東和町駒籠');
ok($zip->set_number('0280143')->is_valid_number, '岩手県花巻市東和町上浮田');
ok($zip->set_number('0280144')->is_valid_number, '岩手県花巻市東和町宮田');
ok($zip->set_number('0280151')->is_valid_number, '岩手県花巻市東和町落合');
ok($zip->set_number('0280152')->is_valid_number, '岩手県花巻市東和町毒沢');
ok($zip->set_number('0280153')->is_valid_number, '岩手県花巻市東和町中内');
ok($zip->set_number('0280154')->is_valid_number, '岩手県花巻市東和町石持');
ok($zip->set_number('0280155')->is_valid_number, '岩手県花巻市東和町南成島');
ok($zip->set_number('0280156')->is_valid_number, '岩手県花巻市東和町小通');
ok($zip->set_number('0280301')->is_valid_number, '岩手県遠野市宮守町上宮守');
ok($zip->set_number('0280302')->is_valid_number, '岩手県遠野市宮守町上鱒沢');
ok($zip->set_number('0280303')->is_valid_number, '岩手県遠野市宮守町下鱒沢');
ok($zip->set_number('0280304')->is_valid_number, '岩手県遠野市宮守町下宮守');
ok($zip->set_number('0280305')->is_valid_number, '岩手県遠野市宮守町達曽部');
ok($zip->set_number('0280481')->is_valid_number, '岩手県遠野市小友町');
ok($zip->set_number('0280500')->is_valid_number, '岩手県遠野市以下に掲載がない場合');
ok($zip->set_number('0280501')->is_valid_number, '岩手県遠野市青笹町糠前');
ok($zip->set_number('0280502')->is_valid_number, '岩手県遠野市青笹町中沢');
ok($zip->set_number('0280503')->is_valid_number, '岩手県遠野市青笹町青笹');
ok($zip->set_number('0280511')->is_valid_number, '岩手県遠野市鶯崎町');
ok($zip->set_number('0280512')->is_valid_number, '岩手県遠野市東上組町');
ok($zip->set_number('0280513')->is_valid_number, '岩手県遠野市東穀町');
ok($zip->set_number('0280514')->is_valid_number, '岩手県遠野市遠野町');
ok($zip->set_number('0280515')->is_valid_number, '岩手県遠野市東舘町');
ok($zip->set_number('0280516')->is_valid_number, '岩手県遠野市穀町');
ok($zip->set_number('0280517')->is_valid_number, '岩手県遠野市上組町');
ok($zip->set_number('0280521')->is_valid_number, '岩手県遠野市材木町');
ok($zip->set_number('0280522')->is_valid_number, '岩手県遠野市新穀町');
ok($zip->set_number('0280523')->is_valid_number, '岩手県遠野市中央通り');
ok($zip->set_number('0280524')->is_valid_number, '岩手県遠野市新町');
ok($zip->set_number('0280525')->is_valid_number, '岩手県遠野市六日町');
ok($zip->set_number('0280526')->is_valid_number, '岩手県遠野市下組町');
ok($zip->set_number('0280527')->is_valid_number, '岩手県遠野市大工町');
ok($zip->set_number('0280531')->is_valid_number, '岩手県遠野市綾織町新里');
ok($zip->set_number('0280532')->is_valid_number, '岩手県遠野市綾織町下綾織');
ok($zip->set_number('0280533')->is_valid_number, '岩手県遠野市綾織町上綾織');
ok($zip->set_number('0280534')->is_valid_number, '岩手県遠野市綾織町みさ崎');
ok($zip->set_number('0280541')->is_valid_number, '岩手県遠野市松崎町白岩');
ok($zip->set_number('0280542')->is_valid_number, '岩手県遠野市早瀬町');
ok($zip->set_number('0280543')->is_valid_number, '岩手県遠野市松崎町光興寺');
ok($zip->set_number('0280544')->is_valid_number, '岩手県遠野市松崎町松崎');
ok($zip->set_number('0280545')->is_valid_number, '岩手県遠野市松崎町駒木');
ok($zip->set_number('0280551')->is_valid_number, '岩手県遠野市土淵町栃内');
ok($zip->set_number('0280552')->is_valid_number, '岩手県遠野市土淵町山口');
ok($zip->set_number('0280553')->is_valid_number, '岩手県遠野市土淵町柏崎');
ok($zip->set_number('0280554')->is_valid_number, '岩手県遠野市土淵町飯豊');
ok($zip->set_number('0280555')->is_valid_number, '岩手県遠野市土淵町土淵');
ok($zip->set_number('0280661')->is_valid_number, '岩手県遠野市附馬牛町上附馬牛');
ok($zip->set_number('0280662')->is_valid_number, '岩手県遠野市附馬牛町安居台');
ok($zip->set_number('0280663')->is_valid_number, '岩手県遠野市附馬牛町下附馬牛');
ok($zip->set_number('0280664')->is_valid_number, '岩手県遠野市附馬牛町東禅寺');
ok($zip->set_number('0280771')->is_valid_number, '岩手県遠野市上郷町佐比内');
ok($zip->set_number('0280772')->is_valid_number, '岩手県遠野市上郷町細越');
ok($zip->set_number('0280773')->is_valid_number, '岩手県遠野市上郷町平野原');
ok($zip->set_number('0280774')->is_valid_number, '岩手県遠野市上郷町来内');
ok($zip->set_number('0280775')->is_valid_number, '岩手県遠野市上郷町平倉');
ok($zip->set_number('0280776')->is_valid_number, '岩手県遠野市上郷町板沢');
ok($zip->set_number('0281100')->is_valid_number, '岩手県上閉伊郡大槌町以下に掲載がない場合');
ok($zip->set_number('0281101')->is_valid_number, '岩手県上閉伊郡大槌町吉里吉里');
ok($zip->set_number('0281102')->is_valid_number, '岩手県上閉伊郡大槌町赤浜');
ok($zip->set_number('0281103')->is_valid_number, '岩手県上閉伊郡大槌町港町');
ok($zip->set_number('0281104')->is_valid_number, '岩手県上閉伊郡大槌町新港町');
ok($zip->set_number('0281105')->is_valid_number, '岩手県上閉伊郡大槌町安渡');
ok($zip->set_number('0281111')->is_valid_number, '岩手県上閉伊郡大槌町新町');
ok($zip->set_number('0281112')->is_valid_number, '岩手県上閉伊郡大槌町大町');
ok($zip->set_number('0281113')->is_valid_number, '岩手県上閉伊郡大槌町須賀町');
ok($zip->set_number('0281114')->is_valid_number, '岩手県上閉伊郡大槌町栄町');
ok($zip->set_number('0281115')->is_valid_number, '岩手県上閉伊郡大槌町上町');
ok($zip->set_number('0281116')->is_valid_number, '岩手県上閉伊郡大槌町本町');
ok($zip->set_number('0281117')->is_valid_number, '岩手県上閉伊郡大槌町末広町');
ok($zip->set_number('0281121')->is_valid_number, '岩手県上閉伊郡大槌町小鎚');
ok($zip->set_number('0281122')->is_valid_number, '岩手県上閉伊郡大槌町桜木町');
ok($zip->set_number('0281131')->is_valid_number, '岩手県上閉伊郡大槌町大槌');
ok($zip->set_number('0281132')->is_valid_number, '岩手県上閉伊郡大槌町大ケ口');
ok($zip->set_number('0281133')->is_valid_number, '岩手県上閉伊郡大槌町金沢');
ok($zip->set_number('0281300')->is_valid_number, '岩手県下閉伊郡山田町以下に掲載がない場合');
ok($zip->set_number('0281301')->is_valid_number, '岩手県下閉伊郡山田町石峠');
ok($zip->set_number('0281302')->is_valid_number, '岩手県下閉伊郡山田町豊間根');
ok($zip->set_number('0281303')->is_valid_number, '岩手県下閉伊郡山田町荒川');
ok($zip->set_number('0281311')->is_valid_number, '岩手県下閉伊郡山田町大沢');
ok($zip->set_number('0281321')->is_valid_number, '岩手県下閉伊郡山田町山田');
ok($zip->set_number('0281331')->is_valid_number, '岩手県下閉伊郡山田町北浜町');
ok($zip->set_number('0281332')->is_valid_number, '岩手県下閉伊郡山田町中央町');
ok($zip->set_number('0281333')->is_valid_number, '岩手県下閉伊郡山田町後楽町');
ok($zip->set_number('0281341')->is_valid_number, '岩手県下閉伊郡山田町八幡町');
ok($zip->set_number('0281342')->is_valid_number, '岩手県下閉伊郡山田町川向町');
ok($zip->set_number('0281343')->is_valid_number, '岩手県下閉伊郡山田町境田町');
ok($zip->set_number('0281351')->is_valid_number, '岩手県下閉伊郡山田町長崎');
ok($zip->set_number('0281352')->is_valid_number, '岩手県下閉伊郡山田町飯岡');
ok($zip->set_number('0281361')->is_valid_number, '岩手県下閉伊郡山田町織笠');
ok($zip->set_number('0281371')->is_valid_number, '岩手県下閉伊郡山田町船越');
ok($zip->set_number('0282101')->is_valid_number, '岩手県宮古市茂市');
ok($zip->set_number('0282102')->is_valid_number, '岩手県宮古市蟇目');
ok($zip->set_number('0282103')->is_valid_number, '岩手県宮古市腹帯');
ok($zip->set_number('0282104')->is_valid_number, '岩手県宮古市刈屋');
ok($zip->set_number('0282105')->is_valid_number, '岩手県宮古市和井内');
ok($zip->set_number('0282231')->is_valid_number, '岩手県下閉伊郡岩泉町浅内');
ok($zip->set_number('0282232')->is_valid_number, '岩手県下閉伊郡岩泉町大川');
ok($zip->set_number('0282233')->is_valid_number, '岩手県下閉伊郡岩泉町釜津田(その他)');
ok($zip->set_number('0282301')->is_valid_number, '岩手県宮古市古田');
ok($zip->set_number('0282302')->is_valid_number, '岩手県宮古市川井(その他)');
ok($zip->set_number('0282303')->is_valid_number, '岩手県宮古市片巣');
ok($zip->set_number('0282304')->is_valid_number, '岩手県宮古市箱石(その他)');
ok($zip->set_number('0282402')->is_valid_number, '岩手県宮古市川井(第9地割~第11地割)');
ok($zip->set_number('0282421')->is_valid_number, '岩手県宮古市江繋');
ok($zip->set_number('0282422')->is_valid_number, '岩手県宮古市小国');
ok($zip->set_number('0282504')->is_valid_number, '岩手県宮古市箱石(第2地割「70~136」~第4地割「3~11」)');
ok($zip->set_number('0282511')->is_valid_number, '岩手県宮古市夏屋');
ok($zip->set_number('0282512')->is_valid_number, '岩手県宮古市鈴久名');
ok($zip->set_number('0282513')->is_valid_number, '岩手県宮古市川内');
ok($zip->set_number('0282631')->is_valid_number, '岩手県宮古市区界');
ok($zip->set_number('0282632')->is_valid_number, '岩手県宮古市門馬');
ok($zip->set_number('0282633')->is_valid_number, '岩手県宮古市平津戸');
ok($zip->set_number('0282711')->is_valid_number, '岩手県盛岡市薮川');
ok($zip->set_number('0283101')->is_valid_number, '岩手県花巻市石鳥谷町好地');
ok($zip->set_number('0283102')->is_valid_number, '岩手県花巻市石鳥谷町上口');
ok($zip->set_number('0283111')->is_valid_number, '岩手県花巻市石鳥谷町新堀');
ok($zip->set_number('0283121')->is_valid_number, '岩手県花巻市石鳥谷町戸塚');
ok($zip->set_number('0283122')->is_valid_number, '岩手県花巻市石鳥谷町滝田');
ok($zip->set_number('0283131')->is_valid_number, '岩手県花巻市石鳥谷町猪鼻');
ok($zip->set_number('0283132')->is_valid_number, '岩手県花巻市石鳥谷町東中島');
ok($zip->set_number('0283133')->is_valid_number, '岩手県花巻市石鳥谷町関口');
ok($zip->set_number('0283141')->is_valid_number, '岩手県花巻市石鳥谷町五大堂');
ok($zip->set_number('0283142')->is_valid_number, '岩手県花巻市石鳥谷町八重畑');
ok($zip->set_number('0283151')->is_valid_number, '岩手県花巻市石鳥谷町江曽');
ok($zip->set_number('0283152')->is_valid_number, '岩手県花巻市石鳥谷町南寺林');
ok($zip->set_number('0283153')->is_valid_number, '岩手県花巻市石鳥谷町小森林');
ok($zip->set_number('0283161')->is_valid_number, '岩手県花巻市石鳥谷町黒沼');
ok($zip->set_number('0283162')->is_valid_number, '岩手県花巻市石鳥谷町西中島');
ok($zip->set_number('0283163')->is_valid_number, '岩手県花巻市石鳥谷町八幡');
ok($zip->set_number('0283171')->is_valid_number, '岩手県花巻市石鳥谷町中寺林');
ok($zip->set_number('0283172')->is_valid_number, '岩手県花巻市石鳥谷町北寺林');
ok($zip->set_number('0283181')->is_valid_number, '岩手県花巻市石鳥谷町大興寺');
ok($zip->set_number('0283182')->is_valid_number, '岩手県花巻市石鳥谷町松林寺');
ok($zip->set_number('0283183')->is_valid_number, '岩手県花巻市石鳥谷町長谷堂');
ok($zip->set_number('0283184')->is_valid_number, '岩手県花巻市石鳥谷町富沢');
ok($zip->set_number('0283185')->is_valid_number, '岩手県花巻市石鳥谷町大瀬川');
ok($zip->set_number('0283201')->is_valid_number, '岩手県花巻市大迫町内川目');
ok($zip->set_number('0283202')->is_valid_number, '岩手県花巻市大迫町外川目');
ok($zip->set_number('0283203')->is_valid_number, '岩手県花巻市大迫町大迫');
ok($zip->set_number('0283204')->is_valid_number, '岩手県花巻市大迫町亀ケ森');
ok($zip->set_number('0283300')->is_valid_number, '岩手県紫波郡紫波町以下に掲載がない場合');
ok($zip->set_number('0283301')->is_valid_number, '岩手県紫波郡紫波町中島');
ok($zip->set_number('0283302')->is_valid_number, '岩手県紫波郡紫波町陣ケ岡');
ok($zip->set_number('0283303')->is_valid_number, '岩手県紫波郡紫波町高水寺');
ok($zip->set_number('0283304')->is_valid_number, '岩手県紫波郡紫波町二日町');
ok($zip->set_number('0283305')->is_valid_number, '岩手県紫波郡紫波町日詰');
ok($zip->set_number('0283306')->is_valid_number, '岩手県紫波郡紫波町日詰西');
ok($zip->set_number('0283307')->is_valid_number, '岩手県紫波郡紫波町桜町');
ok($zip->set_number('0283308')->is_valid_number, '岩手県紫波郡紫波町平沢');
ok($zip->set_number('0283309')->is_valid_number, '岩手県紫波郡紫波町北日詰');
ok($zip->set_number('0283310')->is_valid_number, '岩手県紫波郡紫波町日詰駅前');
ok($zip->set_number('0283311')->is_valid_number, '岩手県紫波郡紫波町犬渕');
ok($zip->set_number('0283312')->is_valid_number, '岩手県紫波郡紫波町犬吠森');
ok($zip->set_number('0283313')->is_valid_number, '岩手県紫波郡紫波町星山');
ok($zip->set_number('0283314')->is_valid_number, '岩手県紫波郡紫波町大巻');
ok($zip->set_number('0283315')->is_valid_number, '岩手県紫波郡紫波町彦部');
ok($zip->set_number('0283316')->is_valid_number, '岩手県紫波郡紫波町佐比内');
ok($zip->set_number('0283317')->is_valid_number, '岩手県紫波郡紫波町南日詰');
ok($zip->set_number('0283318')->is_valid_number, '岩手県紫波郡紫波町紫波中央駅前');
ok($zip->set_number('0283321')->is_valid_number, '岩手県紫波郡紫波町江柄');
ok($zip->set_number('0283322')->is_valid_number, '岩手県紫波郡紫波町栃内');
ok($zip->set_number('0283323')->is_valid_number, '岩手県紫波郡紫波町北沢');
ok($zip->set_number('0283324')->is_valid_number, '岩手県紫波郡紫波町東長岡');
ok($zip->set_number('0283325')->is_valid_number, '岩手県紫波郡紫波町草刈');
ok($zip->set_number('0283326')->is_valid_number, '岩手県紫波郡紫波町西長岡');
ok($zip->set_number('0283441')->is_valid_number, '岩手県紫波郡紫波町上平沢');
ok($zip->set_number('0283442')->is_valid_number, '岩手県紫波郡紫波町升沢');
ok($zip->set_number('0283443')->is_valid_number, '岩手県紫波郡紫波町上松本');
ok($zip->set_number('0283444')->is_valid_number, '岩手県紫波郡紫波町小屋敷');
ok($zip->set_number('0283445')->is_valid_number, '岩手県紫波郡紫波町南伝法寺');
ok($zip->set_number('0283446')->is_valid_number, '岩手県紫波郡紫波町下松本');
ok($zip->set_number('0283447')->is_valid_number, '岩手県紫波郡紫波町宮手');
ok($zip->set_number('0283448')->is_valid_number, '岩手県紫波郡紫波町吉水');
ok($zip->set_number('0283451')->is_valid_number, '岩手県紫波郡紫波町稲藤');
ok($zip->set_number('0283452')->is_valid_number, '岩手県紫波郡紫波町片寄');
ok($zip->set_number('0283453')->is_valid_number, '岩手県紫波郡紫波町土舘');
ok($zip->set_number('0283531')->is_valid_number, '岩手県紫波郡紫波町山屋');
ok($zip->set_number('0283532')->is_valid_number, '岩手県紫波郡紫波町船久保');
ok($zip->set_number('0283533')->is_valid_number, '岩手県紫波郡紫波町赤沢');
ok($zip->set_number('0283534')->is_valid_number, '岩手県紫波郡紫波町紫野');
ok($zip->set_number('0283535')->is_valid_number, '岩手県紫波郡紫波町遠山');
ok($zip->set_number('0283536')->is_valid_number, '岩手県紫波郡紫波町北田');
ok($zip->set_number('0283600')->is_valid_number, '岩手県紫波郡矢巾町以下に掲載がない場合');
ok($zip->set_number('0283601')->is_valid_number, '岩手県紫波郡矢巾町高田');
ok($zip->set_number('0283602')->is_valid_number, '岩手県紫波郡矢巾町藤沢');
ok($zip->set_number('0283603')->is_valid_number, '岩手県紫波郡矢巾町西徳田');
ok($zip->set_number('0283604')->is_valid_number, '岩手県紫波郡矢巾町東徳田');
ok($zip->set_number('0283605')->is_valid_number, '岩手県紫波郡矢巾町間野々');
ok($zip->set_number('0283606')->is_valid_number, '岩手県紫波郡矢巾町土橋');
ok($zip->set_number('0283607')->is_valid_number, '岩手県紫波郡矢巾町高水寺');
ok($zip->set_number('0283608')->is_valid_number, '岩手県紫波郡矢巾町北郡山');
ok($zip->set_number('0283609')->is_valid_number, '岩手県紫波郡矢巾町医大通');
ok($zip->set_number('0283611')->is_valid_number, '岩手県紫波郡矢巾町赤林');
ok($zip->set_number('0283612')->is_valid_number, '岩手県紫波郡矢巾町下矢次');
ok($zip->set_number('0283613')->is_valid_number, '岩手県紫波郡矢巾町北矢幅');
ok($zip->set_number('0283614')->is_valid_number, '岩手県紫波郡矢巾町又兵エ新田');
ok($zip->set_number('0283615')->is_valid_number, '岩手県紫波郡矢巾町南矢幅');
ok($zip->set_number('0283616')->is_valid_number, '岩手県紫波郡矢巾町白沢');
ok($zip->set_number('0283617')->is_valid_number, '岩手県紫波郡矢巾町太田');
ok($zip->set_number('0283618')->is_valid_number, '岩手県紫波郡矢巾町駅東');
ok($zip->set_number('0283621')->is_valid_number, '岩手県紫波郡矢巾町広宮沢');
ok($zip->set_number('0283622')->is_valid_number, '岩手県紫波郡矢巾町上矢次');
ok($zip->set_number('0283623')->is_valid_number, '岩手県紫波郡矢巾町煙山');
ok($zip->set_number('0283624')->is_valid_number, '岩手県紫波郡矢巾町北伝法寺');
ok($zip->set_number('0283625')->is_valid_number, '岩手県紫波郡矢巾町室岡');
ok($zip->set_number('0283626')->is_valid_number, '岩手県紫波郡矢巾町岩清水');
ok($zip->set_number('0283627')->is_valid_number, '岩手県紫波郡矢巾町和味');
ok($zip->set_number('0284121')->is_valid_number, '岩手県盛岡市玉山永井');
ok($zip->set_number('0284122')->is_valid_number, '岩手県盛岡市寺林');
ok($zip->set_number('0284123')->is_valid_number, '岩手県盛岡市巻堀');
ok($zip->set_number('0284124')->is_valid_number, '岩手県盛岡市玉山馬場');
ok($zip->set_number('0284125')->is_valid_number, '岩手県盛岡市好摩');
ok($zip->set_number('0284131')->is_valid_number, '岩手県盛岡市芋田');
ok($zip->set_number('0284132')->is_valid_number, '岩手県盛岡市渋民');
ok($zip->set_number('0284133')->is_valid_number, '岩手県盛岡市門前寺');
ok($zip->set_number('0284134')->is_valid_number, '岩手県盛岡市下田');
ok($zip->set_number('0284135')->is_valid_number, '岩手県盛岡市川崎');
ok($zip->set_number('0284136')->is_valid_number, '岩手県盛岡市松内');
ok($zip->set_number('0284211')->is_valid_number, '岩手県岩手郡岩手町川口');
ok($zip->set_number('0284300')->is_valid_number, '岩手県岩手郡岩手町以下に掲載がない場合');
ok($zip->set_number('0284301')->is_valid_number, '岩手県岩手郡岩手町沼宮内');
ok($zip->set_number('0284302')->is_valid_number, '岩手県岩手郡岩手町大坊');
ok($zip->set_number('0284303')->is_valid_number, '岩手県岩手郡岩手町江刈内');
ok($zip->set_number('0284304')->is_valid_number, '岩手県岩手郡岩手町子抱');
ok($zip->set_number('0284305')->is_valid_number, '岩手県岩手郡岩手町久保');
ok($zip->set_number('0284306')->is_valid_number, '岩手県岩手郡岩手町御堂');
ok($zip->set_number('0284307')->is_valid_number, '岩手県岩手郡岩手町五日市');
ok($zip->set_number('0284421')->is_valid_number, '岩手県岩手郡岩手町一方井');
ok($zip->set_number('0284422')->is_valid_number, '岩手県岩手郡岩手町坊');
ok($zip->set_number('0284423')->is_valid_number, '岩手県岩手郡岩手町土川');
ok($zip->set_number('0284424')->is_valid_number, '岩手県岩手郡岩手町黒石');
ok($zip->set_number('0284425')->is_valid_number, '岩手県岩手郡岩手町葉木田');
ok($zip->set_number('0284426')->is_valid_number, '岩手県岩手郡岩手町黒内');
ok($zip->set_number('0285102')->is_valid_number, '岩手県岩手郡葛巻町葛巻(第40地割「57番地125、176を除く」~第45地割)');
ok($zip->set_number('0285131')->is_valid_number, '岩手県二戸郡一戸町宇別');
ok($zip->set_number('0285132')->is_valid_number, '岩手県二戸郡一戸町小繋');
ok($zip->set_number('0285133')->is_valid_number, '岩手県二戸郡一戸町中山(その他)');
ok($zip->set_number('0285134')->is_valid_number, '岩手県二戸郡一戸町奥中山');
ok($zip->set_number('0285221')->is_valid_number, '岩手県二戸郡一戸町小鳥谷');
ok($zip->set_number('0285222')->is_valid_number, '岩手県二戸郡一戸町姉帯');
ok($zip->set_number('0285223')->is_valid_number, '岩手県二戸郡一戸町面岸');
ok($zip->set_number('0285224')->is_valid_number, '岩手県二戸郡一戸町平糠');
ok($zip->set_number('0285233')->is_valid_number, '岩手県二戸郡一戸町中山(新田17-2、37番地、東火行1番地)');
ok($zip->set_number('0285300')->is_valid_number, '岩手県二戸郡一戸町以下に掲載がない場合');
ok($zip->set_number('0285301')->is_valid_number, '岩手県二戸郡一戸町西法寺');
ok($zip->set_number('0285302')->is_valid_number, '岩手県二戸郡一戸町女鹿');
ok($zip->set_number('0285303')->is_valid_number, '岩手県二戸郡一戸町小友');
ok($zip->set_number('0285304')->is_valid_number, '岩手県二戸郡一戸町出ル町');
ok($zip->set_number('0285305')->is_valid_number, '岩手県二戸郡一戸町月舘');
ok($zip->set_number('0285306')->is_valid_number, '岩手県二戸郡一戸町中里');
ok($zip->set_number('0285311')->is_valid_number, '岩手県二戸郡一戸町高善寺');
ok($zip->set_number('0285312')->is_valid_number, '岩手県二戸郡一戸町一戸');
ok($zip->set_number('0285313')->is_valid_number, '岩手県二戸郡一戸町鳥越');
ok($zip->set_number('0285314')->is_valid_number, '岩手県二戸郡一戸町楢山');
ok($zip->set_number('0285315')->is_valid_number, '岩手県二戸郡一戸町根反');
ok($zip->set_number('0285316')->is_valid_number, '岩手県二戸郡一戸町岩舘');
ok($zip->set_number('0285400')->is_valid_number, '岩手県岩手郡葛巻町以下に掲載がない場合');
ok($zip->set_number('0285401')->is_valid_number, '岩手県岩手郡葛巻町田部');
ok($zip->set_number('0285402')->is_valid_number, '岩手県岩手郡葛巻町葛巻(その他)');
ok($zip->set_number('0285403')->is_valid_number, '岩手県岩手郡葛巻町江刈');
ok($zip->set_number('0285633')->is_valid_number, '岩手県下閉伊郡岩泉町釜津田(上栗宿、栗宿、権現)');
ok($zip->set_number('0285641')->is_valid_number, '岩手県下閉伊郡岩泉町門');
ok($zip->set_number('0285642')->is_valid_number, '岩手県下閉伊郡岩泉町穴沢');
ok($zip->set_number('0285643')->is_valid_number, '岩手県下閉伊郡岩泉町袰綿');
ok($zip->set_number('0285702')->is_valid_number, '岩手県二戸市下斗米(外芹沢、月折、土橋)');
ok($zip->set_number('0285711')->is_valid_number, '岩手県二戸市金田一');
ok($zip->set_number('0285712')->is_valid_number, '岩手県二戸市野々上');
ok($zip->set_number('0285713')->is_valid_number, '岩手県二戸市釜沢');
ok($zip->set_number('0286100')->is_valid_number, '岩手県二戸市以下に掲載がない場合');
ok($zip->set_number('0286101')->is_valid_number, '岩手県二戸市福岡');
ok($zip->set_number('0286102')->is_valid_number, '岩手県二戸市下斗米(その他)');
ok($zip->set_number('0286103')->is_valid_number, '岩手県二戸市石切所');
ok($zip->set_number('0286104')->is_valid_number, '岩手県二戸市米沢');
ok($zip->set_number('0286105')->is_valid_number, '岩手県二戸市堀野');
ok($zip->set_number('0286106')->is_valid_number, '岩手県二戸市仁左平');
ok($zip->set_number('0286107')->is_valid_number, '岩手県二戸市白鳥');
ok($zip->set_number('0286108')->is_valid_number, '岩手県二戸市上斗米');
ok($zip->set_number('0286221')->is_valid_number, '岩手県九戸郡軽米町晴山');
ok($zip->set_number('0286222')->is_valid_number, '岩手県九戸郡軽米町山内');
ok($zip->set_number('0286223')->is_valid_number, '岩手県九戸郡軽米町狄塚');
ok($zip->set_number('0286300')->is_valid_number, '岩手県九戸郡軽米町以下に掲載がない場合');
ok($zip->set_number('0286301')->is_valid_number, '岩手県九戸郡軽米町上舘');
ok($zip->set_number('0286302')->is_valid_number, '岩手県九戸郡軽米町軽米');
ok($zip->set_number('0286303')->is_valid_number, '岩手県九戸郡軽米町高家');
ok($zip->set_number('0286304')->is_valid_number, '岩手県九戸郡軽米町長倉');
ok($zip->set_number('0286411')->is_valid_number, '岩手県九戸郡軽米町小軽米');
ok($zip->set_number('0286412')->is_valid_number, '岩手県九戸郡軽米町蛇口');
ok($zip->set_number('0286413')->is_valid_number, '岩手県九戸郡軽米町円子');
ok($zip->set_number('0286500')->is_valid_number, '岩手県九戸郡九戸村以下に掲載がない場合');
ok($zip->set_number('0286501')->is_valid_number, '岩手県九戸郡九戸村荒谷');
ok($zip->set_number('0286502')->is_valid_number, '岩手県九戸郡九戸村伊保内');
ok($zip->set_number('0286503')->is_valid_number, '岩手県九戸郡九戸村小倉');
ok($zip->set_number('0286504')->is_valid_number, '岩手県九戸郡九戸村長興寺');
ok($zip->set_number('0286505')->is_valid_number, '岩手県九戸郡九戸村江刺家');
ok($zip->set_number('0286506')->is_valid_number, '岩手県九戸郡九戸村山屋');
ok($zip->set_number('0286507')->is_valid_number, '岩手県九戸郡九戸村雪屋');
ok($zip->set_number('0286611')->is_valid_number, '岩手県九戸郡九戸村山根');
ok($zip->set_number('0286612')->is_valid_number, '岩手県九戸郡九戸村戸田');
ok($zip->set_number('0286721')->is_valid_number, '岩手県二戸市似鳥');
ok($zip->set_number('0286722')->is_valid_number, '岩手県二戸市福田');
ok($zip->set_number('0286723')->is_valid_number, '岩手県二戸市安比');
ok($zip->set_number('0286724')->is_valid_number, '岩手県二戸市足沢');
ok($zip->set_number('0286811')->is_valid_number, '岩手県二戸市浄法寺町手倉森');
ok($zip->set_number('0286812')->is_valid_number, '岩手県二戸市浄法寺町下沢');
ok($zip->set_number('0286813')->is_valid_number, '岩手県二戸市浄法寺町大平');
ok($zip->set_number('0286814')->is_valid_number, '岩手県二戸市浄法寺町北村');
ok($zip->set_number('0286815')->is_valid_number, '岩手県二戸市浄法寺町八方口');
ok($zip->set_number('0286816')->is_valid_number, '岩手県二戸市浄法寺町上谷地');
ok($zip->set_number('0286817')->is_valid_number, '岩手県二戸市浄法寺町漆沢大久保');
ok($zip->set_number('0286818')->is_valid_number, '岩手県二戸市浄法寺町鏡田');
ok($zip->set_number('0286819')->is_valid_number, '岩手県二戸市浄法寺町馬洗場');
ok($zip->set_number('0286821')->is_valid_number, '岩手県二戸市浄法寺町小平');
ok($zip->set_number('0286822')->is_valid_number, '岩手県二戸市浄法寺町漆沢舘');
ok($zip->set_number('0286823')->is_valid_number, '岩手県二戸市浄法寺町宮沢');
ok($zip->set_number('0286824')->is_valid_number, '岩手県二戸市浄法寺町西ノ沢');
ok($zip->set_number('0286825')->is_valid_number, '岩手県二戸市浄法寺町長坂');
ok($zip->set_number('0286826')->is_valid_number, '岩手県二戸市浄法寺町川又');
ok($zip->set_number('0286831')->is_valid_number, '岩手県二戸市浄法寺町漆沢下平');
ok($zip->set_number('0286832')->is_valid_number, '岩手県二戸市浄法寺町漆沢上平');
ok($zip->set_number('0286833')->is_valid_number, '岩手県二戸市浄法寺町漆沢');
ok($zip->set_number('0286834')->is_valid_number, '岩手県二戸市浄法寺町細田');
ok($zip->set_number('0286835')->is_valid_number, '岩手県二戸市浄法寺町漆沢下モ前田');
ok($zip->set_number('0286836')->is_valid_number, '岩手県二戸市浄法寺町関田');
ok($zip->set_number('0286837')->is_valid_number, '岩手県二戸市浄法寺町荒屋敷');
ok($zip->set_number('0286838')->is_valid_number, '岩手県二戸市浄法寺町向田');
ok($zip->set_number('0286841')->is_valid_number, '岩手県二戸市浄法寺町松岡');
ok($zip->set_number('0286842')->is_valid_number, '岩手県二戸市浄法寺町漆沢中前田');
ok($zip->set_number('0286843')->is_valid_number, '岩手県二戸市浄法寺町堤口');
ok($zip->set_number('0286844')->is_valid_number, '岩手県二戸市浄法寺町岡本前田');
ok($zip->set_number('0286845')->is_valid_number, '岩手県二戸市浄法寺町漆沢上前田');
ok($zip->set_number('0286846')->is_valid_number, '岩手県二戸市浄法寺町下タ前田');
ok($zip->set_number('0286847')->is_valid_number, '岩手県二戸市浄法寺町岩渕');
ok($zip->set_number('0286848')->is_valid_number, '岩手県二戸市浄法寺町ウト坂');
ok($zip->set_number('0286849')->is_valid_number, '岩手県二戸市浄法寺町岡本');
ok($zip->set_number('0286851')->is_valid_number, '岩手県二戸市浄法寺町小池');
ok($zip->set_number('0286852')->is_valid_number, '岩手県二戸市浄法寺町樋田');
ok($zip->set_number('0286853')->is_valid_number, '岩手県二戸市浄法寺町サイカツ田');
ok($zip->set_number('0286854')->is_valid_number, '岩手県二戸市浄法寺町下前田');
ok($zip->set_number('0286855')->is_valid_number, '岩手県二戸市浄法寺町浄法寺');
ok($zip->set_number('0286856')->is_valid_number, '岩手県二戸市浄法寺町上外野');
ok($zip->set_number('0286857')->is_valid_number, '岩手県二戸市浄法寺町合名沢');
ok($zip->set_number('0286861')->is_valid_number, '岩手県二戸市浄法寺町上野');
ok($zip->set_number('0286862')->is_valid_number, '岩手県二戸市浄法寺町寺ノ上');
ok($zip->set_number('0286863')->is_valid_number, '岩手県二戸市浄法寺町八幡舘');
ok($zip->set_number('0286864')->is_valid_number, '岩手県二戸市浄法寺町門前向');
ok($zip->set_number('0286865')->is_valid_number, '岩手県二戸市浄法寺町野田');
ok($zip->set_number('0286866')->is_valid_number, '岩手県二戸市浄法寺町飯近');
ok($zip->set_number('0286867')->is_valid_number, '岩手県二戸市浄法寺町焼場');
ok($zip->set_number('0286868')->is_valid_number, '岩手県二戸市浄法寺町長者花');
ok($zip->set_number('0286871')->is_valid_number, '岩手県二戸市浄法寺町安戸');
ok($zip->set_number('0286872')->is_valid_number, '岩手県二戸市浄法寺町里川目');
ok($zip->set_number('0286873')->is_valid_number, '岩手県二戸市浄法寺町大志田');
ok($zip->set_number('0286874')->is_valid_number, '岩手県二戸市浄法寺町一反田');
ok($zip->set_number('0286875')->is_valid_number, '岩手県二戸市浄法寺町舘');
ok($zip->set_number('0286876')->is_valid_number, '岩手県二戸市浄法寺町田子内沢');
ok($zip->set_number('0286877')->is_valid_number, '岩手県二戸市浄法寺町伊崎沢');
ok($zip->set_number('0286878')->is_valid_number, '岩手県二戸市浄法寺町漆原');
ok($zip->set_number('0286879')->is_valid_number, '岩手県二戸市浄法寺町梅ノ木');
ok($zip->set_number('0286881')->is_valid_number, '岩手県二戸市浄法寺町渡ノ羽');
ok($zip->set_number('0286882')->is_valid_number, '岩手県二戸市浄法寺町羽余内');
ok($zip->set_number('0286883')->is_valid_number, '岩手県二戸市浄法寺町荒谷');
ok($zip->set_number('0286884')->is_valid_number, '岩手県二戸市浄法寺町新山');
ok($zip->set_number('0286885')->is_valid_number, '岩手県二戸市浄法寺町森越');
ok($zip->set_number('0286901')->is_valid_number, '岩手県二戸市浄法寺町深堀');
ok($zip->set_number('0286902')->is_valid_number, '岩手県二戸市浄法寺町明神沢');
ok($zip->set_number('0286903')->is_valid_number, '岩手県二戸市浄法寺町坂本');
ok($zip->set_number('0286904')->is_valid_number, '岩手県二戸市浄法寺町里代');
ok($zip->set_number('0286905')->is_valid_number, '岩手県二戸市浄法寺町空久保');
ok($zip->set_number('0286906')->is_valid_number, '岩手県二戸市浄法寺町上杉沢');
ok($zip->set_number('0286907')->is_valid_number, '岩手県二戸市浄法寺町季ケ平');
ok($zip->set_number('0286908')->is_valid_number, '岩手県二戸市浄法寺町野黒沢');
ok($zip->set_number('0286911')->is_valid_number, '岩手県二戸市浄法寺町上前田');
ok($zip->set_number('0286912')->is_valid_number, '岩手県二戸市浄法寺町中前田');
ok($zip->set_number('0286913')->is_valid_number, '岩手県二戸市浄法寺町下ノ沢');
ok($zip->set_number('0286914')->is_valid_number, '岩手県二戸市浄法寺町和泉田');
ok($zip->set_number('0286915')->is_valid_number, '岩手県二戸市浄法寺町霜屋敷');
ok($zip->set_number('0286916')->is_valid_number, '岩手県二戸市浄法寺町大清水下モ平');
ok($zip->set_number('0286917')->is_valid_number, '岩手県二戸市浄法寺町大清水前田');
ok($zip->set_number('0286918')->is_valid_number, '岩手県二戸市浄法寺町サイカツ平');
ok($zip->set_number('0286919')->is_valid_number, '岩手県二戸市浄法寺町大清水荒屋');
ok($zip->set_number('0286921')->is_valid_number, '岩手県二戸市浄法寺町小泉');
ok($zip->set_number('0286922')->is_valid_number, '岩手県二戸市浄法寺町下谷地');
ok($zip->set_number('0286923')->is_valid_number, '岩手県二戸市浄法寺町下村');
ok($zip->set_number('0286924')->is_valid_number, '岩手県二戸市浄法寺町家ノ上');
ok($zip->set_number('0286925')->is_valid_number, '岩手県二戸市浄法寺町梅田');
ok($zip->set_number('0286926')->is_valid_number, '岩手県二戸市浄法寺町門崎');
ok($zip->set_number('0286927')->is_valid_number, '岩手県二戸市浄法寺町湯沢');
ok($zip->set_number('0286928')->is_valid_number, '岩手県二戸市浄法寺町山内');
ok($zip->set_number('0286929')->is_valid_number, '岩手県二戸市浄法寺町大清水空久保');
ok($zip->set_number('0286931')->is_valid_number, '岩手県二戸市浄法寺町尻平');
ok($zip->set_number('0286932')->is_valid_number, '岩手県二戸市浄法寺町松畑');
ok($zip->set_number('0286933')->is_valid_number, '岩手県二戸市浄法寺町御山上野');
ok($zip->set_number('0286934')->is_valid_number, '岩手県二戸市浄法寺町沢田');
ok($zip->set_number('0286935')->is_valid_number, '岩手県二戸市浄法寺町御山下前田');
ok($zip->set_number('0286936')->is_valid_number, '岩手県二戸市浄法寺町長渡路');
ok($zip->set_number('0286937')->is_valid_number, '岩手県二戸市浄法寺町大畑');
ok($zip->set_number('0286938')->is_valid_number, '岩手県二戸市浄法寺町御山上平');
ok($zip->set_number('0286939')->is_valid_number, '岩手県二戸市浄法寺町長流部');
ok($zip->set_number('0286941')->is_valid_number, '岩手県二戸市浄法寺町御山中前田');
ok($zip->set_number('0286942')->is_valid_number, '岩手県二戸市浄法寺町御山久保');
ok($zip->set_number('0286943')->is_valid_number, '岩手県二戸市浄法寺町後久保');
ok($zip->set_number('0286944')->is_valid_number, '岩手県二戸市浄法寺町飛鳥');
ok($zip->set_number('0286945')->is_valid_number, '岩手県二戸市浄法寺町飛鳥谷地');
ok($zip->set_number('0286946')->is_valid_number, '岩手県二戸市浄法寺町安比内');
ok($zip->set_number('0286947')->is_valid_number, '岩手県二戸市浄法寺町安比内沢');
ok($zip->set_number('0286948')->is_valid_number, '岩手県二戸市浄法寺町御山舘');
ok($zip->set_number('0286949')->is_valid_number, '岩手県二戸市浄法寺町御山前田');
ok($zip->set_number('0286951')->is_valid_number, '岩手県二戸市浄法寺町清水尻');
ok($zip->set_number('0286952')->is_valid_number, '岩手県二戸市浄法寺町御山大久保');
ok($zip->set_number('0286953')->is_valid_number, '岩手県二戸市浄法寺町木沢畑向');
ok($zip->set_number('0286954')->is_valid_number, '岩手県二戸市浄法寺町早坂');
ok($zip->set_number('0286955')->is_valid_number, '岩手県二戸市浄法寺町桂平');
ok($zip->set_number('0286956')->is_valid_number, '岩手県二戸市浄法寺町大坊');
ok($zip->set_number('0286957')->is_valid_number, '岩手県二戸市浄法寺町海上田');
ok($zip->set_number('0286958')->is_valid_number, '岩手県二戸市浄法寺町大手');
ok($zip->set_number('0286961')->is_valid_number, '岩手県二戸市浄法寺町滝見橋');
ok($zip->set_number('0286962')->is_valid_number, '岩手県二戸市浄法寺町馬場向');
ok($zip->set_number('0286963')->is_valid_number, '岩手県二戸市浄法寺町小又');
ok($zip->set_number('0286964')->is_valid_number, '岩手県二戸市浄法寺町沼久保');
ok($zip->set_number('0286965')->is_valid_number, '岩手県二戸市浄法寺町谷地屋敷');
ok($zip->set_number('0286966')->is_valid_number, '岩手県二戸市浄法寺町海上');
ok($zip->set_number('0286967')->is_valid_number, '岩手県二戸市浄法寺町惣川原田');
ok($zip->set_number('0286968')->is_valid_number, '岩手県二戸市浄法寺町海上前田');
ok($zip->set_number('0286969')->is_valid_number, '岩手県二戸市浄法寺町端保口');
ok($zip->set_number('0286971')->is_valid_number, '岩手県二戸市浄法寺町向川原');
ok($zip->set_number('0286972')->is_valid_number, '岩手県二戸市浄法寺町桜田');
ok($zip->set_number('0286973')->is_valid_number, '岩手県二戸市浄法寺町駒ケ嶺舘');
ok($zip->set_number('0286974')->is_valid_number, '岩手県二戸市浄法寺町中畑');
ok($zip->set_number('0286975')->is_valid_number, '岩手県二戸市浄法寺町田余内');
ok($zip->set_number('0286976')->is_valid_number, '岩手県二戸市浄法寺町樋口');
ok($zip->set_number('0286977')->is_valid_number, '岩手県二戸市浄法寺町駒ケ嶺');
ok($zip->set_number('0286978')->is_valid_number, '岩手県二戸市浄法寺町駒ケ嶺前田');
ok($zip->set_number('0286979')->is_valid_number, '岩手県二戸市浄法寺町駒ケ嶺野田');
ok($zip->set_number('0286981')->is_valid_number, '岩手県二戸市浄法寺町五庵');
ok($zip->set_number('0286982')->is_valid_number, '岩手県二戸市浄法寺町焼切');
ok($zip->set_number('0286983')->is_valid_number, '岩手県二戸市浄法寺町下藤');
ok($zip->set_number('0286984')->is_valid_number, '岩手県二戸市浄法寺町柿ノ木平');
ok($zip->set_number('0286985')->is_valid_number, '岩手県二戸市浄法寺町漆畑');
ok($zip->set_number('0287100')->is_valid_number, '岩手県八幡平市以下に掲載がない場合');
ok($zip->set_number('0287111')->is_valid_number, '岩手県八幡平市大更');
ok($zip->set_number('0287112')->is_valid_number, '岩手県八幡平市田頭');
ok($zip->set_number('0287113')->is_valid_number, '岩手県八幡平市平笠');
ok($zip->set_number('0287301')->is_valid_number, '岩手県八幡平市野駄');
ok($zip->set_number('0287302')->is_valid_number, '岩手県八幡平市八幡平温泉郷');
ok($zip->set_number('0287302')->is_valid_number, '岩手県八幡平市松尾寄木');
ok($zip->set_number('0287302')->is_valid_number, '岩手県八幡平市松川温泉');
ok($zip->set_number('0287303')->is_valid_number, '岩手県八幡平市柏台');
ok($zip->set_number('0287303')->is_valid_number, '岩手県八幡平市藤七温泉');
ok($zip->set_number('0287304')->is_valid_number, '岩手県八幡平市緑ガ丘');
ok($zip->set_number('0287305')->is_valid_number, '岩手県八幡平市松尾');
ok($zip->set_number('0287306')->is_valid_number, '岩手県八幡平市安比高原');
ok($zip->set_number('0287401')->is_valid_number, '岩手県八幡平市西根寺田');
ok($zip->set_number('0287402')->is_valid_number, '岩手県八幡平市帷子');
ok($zip->set_number('0287403')->is_valid_number, '岩手県八幡平市上関');
ok($zip->set_number('0287404')->is_valid_number, '岩手県八幡平市堀切');
ok($zip->set_number('0287405')->is_valid_number, '岩手県八幡平市平舘');
ok($zip->set_number('0287406')->is_valid_number, '岩手県八幡平市荒木田');
ok($zip->set_number('0287501')->is_valid_number, '岩手県八幡平市岩木向');
ok($zip->set_number('0287502')->is_valid_number, '岩手県八幡平市上岩木');
ok($zip->set_number('0287503')->is_valid_number, '岩手県八幡平市中田');
ok($zip->set_number('0287504')->is_valid_number, '岩手県八幡平市前田');
ok($zip->set_number('0287505')->is_valid_number, '岩手県八幡平市岩屋');
ok($zip->set_number('0287506')->is_valid_number, '岩手県八幡平市安代寺田');
ok($zip->set_number('0287511')->is_valid_number, '岩手県八幡平市下の田');
ok($zip->set_number('0287512')->is_valid_number, '岩手県八幡平市山岸');
ok($zip->set_number('0287513')->is_valid_number, '岩手県八幡平市土沢');
ok($zip->set_number('0287514')->is_valid_number, '岩手県八幡平市中佐井');
ok($zip->set_number('0287515')->is_valid_number, '岩手県八幡平市古屋敷');
ok($zip->set_number('0287516')->is_valid_number, '岩手県八幡平市関沢口');
ok($zip->set_number('0287521')->is_valid_number, '岩手県八幡平市石神');
ok($zip->set_number('0287522')->is_valid_number, '岩手県八幡平市山口');
ok($zip->set_number('0287523')->is_valid_number, '岩手県八幡平市繋沢');
ok($zip->set_number('0287524')->is_valid_number, '岩手県八幡平市湯の沢');
ok($zip->set_number('0287525')->is_valid_number, '岩手県八幡平市日影');
ok($zip->set_number('0287526')->is_valid_number, '岩手県八幡平市赤子平');
ok($zip->set_number('0287527')->is_valid_number, '岩手県八幡平市川原');
ok($zip->set_number('0287531')->is_valid_number, '岩手県八幡平市上の山');
ok($zip->set_number('0287532')->is_valid_number, '岩手県八幡平市小柳田');
ok($zip->set_number('0287533')->is_valid_number, '岩手県八幡平市叺田');
ok($zip->set_number('0287534')->is_valid_number, '岩手県八幡平市荒屋新町');
ok($zip->set_number('0287535')->is_valid_number, '岩手県八幡平市清水');
ok($zip->set_number('0287536')->is_valid_number, '岩手県八幡平市打田内');
ok($zip->set_number('0287537')->is_valid_number, '岩手県八幡平市曲田');
ok($zip->set_number('0287541')->is_valid_number, '岩手県八幡平市寺志田');
ok($zip->set_number('0287542')->is_valid_number, '岩手県八幡平市高畑');
ok($zip->set_number('0287543')->is_valid_number, '岩手県八幡平市小屋畑');
ok($zip->set_number('0287544')->is_valid_number, '岩手県八幡平市保戸坂');
ok($zip->set_number('0287545')->is_valid_number, '岩手県八幡平市松木田');
ok($zip->set_number('0287551')->is_valid_number, '岩手県八幡平市新田');
ok($zip->set_number('0287552')->is_valid_number, '岩手県八幡平市安代寄木');
ok($zip->set_number('0287553')->is_valid_number, '岩手県八幡平市扇畑');
ok($zip->set_number('0287554')->is_valid_number, '岩手県八幡平市赤坂田');
ok($zip->set_number('0287555')->is_valid_number, '岩手県八幡平市黒沢');
ok($zip->set_number('0287556')->is_valid_number, '岩手県八幡平市星沢');
ok($zip->set_number('0287557')->is_valid_number, '岩手県八幡平市細野');
ok($zip->set_number('0287561')->is_valid_number, '岩手県八幡平市下町');
ok($zip->set_number('0287562')->is_valid_number, '岩手県八幡平市五日市');
ok($zip->set_number('0287563')->is_valid_number, '岩手県八幡平市田の沢');
ok($zip->set_number('0287564')->is_valid_number, '岩手県八幡平市谷地田');
ok($zip->set_number('0287565')->is_valid_number, '岩手県八幡平市目名市');
ok($zip->set_number('0287566')->is_valid_number, '岩手県八幡平市滝沢');
ok($zip->set_number('0287567')->is_valid_number, '岩手県八幡平市戸沢');
ok($zip->set_number('0287601')->is_valid_number, '岩手県八幡平市田沢');
ok($zip->set_number('0287602')->is_valid_number, '岩手県八幡平市丑山');
ok($zip->set_number('0287603')->is_valid_number, '岩手県八幡平市矢神');
ok($zip->set_number('0287604')->is_valid_number, '岩手県八幡平市丑山口');
ok($zip->set_number('0287605')->is_valid_number, '岩手県八幡平市鵜谷地');
ok($zip->set_number('0287606')->is_valid_number, '岩手県八幡平市姥子石');
ok($zip->set_number('0287607')->is_valid_number, '岩手県八幡平市大面平');
ok($zip->set_number('0287608')->is_valid_number, '岩手県八幡平市谷地中');
ok($zip->set_number('0287611')->is_valid_number, '岩手県八幡平市沖田表');
ok($zip->set_number('0287612')->is_valid_number, '岩手県八幡平市欠田');
ok($zip->set_number('0287613')->is_valid_number, '岩手県八幡平市亦戸川原');
ok($zip->set_number('0287614')->is_valid_number, '岩手県八幡平市石名坂下タ');
ok($zip->set_number('0287615')->is_valid_number, '岩手県八幡平市石名坂');
ok($zip->set_number('0287616')->is_valid_number, '岩手県八幡平市二タ子');
ok($zip->set_number('0287617')->is_valid_number, '岩手県八幡平市折壁');
ok($zip->set_number('0287618')->is_valid_number, '岩手県八幡平市蛇石');
ok($zip->set_number('0287619')->is_valid_number, '岩手県八幡平市相沢');
ok($zip->set_number('0287621')->is_valid_number, '岩手県八幡平市兄川');
ok($zip->set_number('0287621')->is_valid_number, '岩手県八幡平市作平');
ok($zip->set_number('0287622')->is_valid_number, '岩手県八幡平市兄畑中川原');
ok($zip->set_number('0287623')->is_valid_number, '岩手県八幡平市舘市');
ok($zip->set_number('0287624')->is_valid_number, '岩手県八幡平市大又沢口');
ok($zip->set_number('0287625')->is_valid_number, '岩手県八幡平市沖ノ平');
ok($zip->set_number('0287626')->is_valid_number, '岩手県八幡平市戸鎖');
ok($zip->set_number('0287627')->is_valid_number, '岩手県八幡平市佐比内');
ok($zip->set_number('0287628')->is_valid_number, '岩手県八幡平市小岩井');
ok($zip->set_number('0287629')->is_valid_number, '岩手県八幡平市白沢口');
ok($zip->set_number('0287631')->is_valid_number, '岩手県八幡平市瀬ノ沢');
ok($zip->set_number('0287632')->is_valid_number, '岩手県八幡平市小原道ノ上');
ok($zip->set_number('0287633')->is_valid_number, '岩手県八幡平市日泥道ノ上');
ok($zip->set_number('0287634')->is_valid_number, '岩手県八幡平市和屋敷道ノ上');
ok($zip->set_number('0287635')->is_valid_number, '岩手県八幡平市愛の山');
ok($zip->set_number('0287636')->is_valid_number, '岩手県八幡平市和屋敷道ノ下');
ok($zip->set_number('0287637')->is_valid_number, '岩手県八幡平市日泥道ノ下');
ok($zip->set_number('0287638')->is_valid_number, '岩手県八幡平市小原道ノ下');
ok($zip->set_number('0287641')->is_valid_number, '岩手県八幡平市比路平');
ok($zip->set_number('0287642')->is_valid_number, '岩手県八幡平市勝善川原');
ok($zip->set_number('0287643')->is_valid_number, '岩手県八幡平市切通');
ok($zip->set_number('0287644')->is_valid_number, '岩手県八幡平市雀長根');
ok($zip->set_number('0287645')->is_valid_number, '岩手県八幡平市下タ川原');
ok($zip->set_number('0287651')->is_valid_number, '岩手県八幡平市長者前');
ok($zip->set_number('0287652')->is_valid_number, '岩手県八幡平市根石');
ok($zip->set_number('0287653')->is_valid_number, '岩手県八幡平市平又');
ok($zip->set_number('0287654')->is_valid_number, '岩手県八幡平市小峠');
ok($zip->set_number('0287655')->is_valid_number, '岩手県八幡平市馬揚沢');
ok($zip->set_number('0287656')->is_valid_number, '岩手県八幡平市左妻');
ok($zip->set_number('0287657')->is_valid_number, '岩手県八幡平市栗木田');
ok($zip->set_number('0287661')->is_valid_number, '岩手県八幡平市大沢');
ok($zip->set_number('0287662')->is_valid_number, '岩手県八幡平市杉沢');
ok($zip->set_number('0287663')->is_valid_number, '岩手県八幡平市石森');
ok($zip->set_number('0287664')->is_valid_number, '岩手県八幡平市大沢田');
ok($zip->set_number('0287671')->is_valid_number, '岩手県八幡平市馬場下');
ok($zip->set_number('0287672')->is_valid_number, '岩手県八幡平市田中下タ');
ok($zip->set_number('0287673')->is_valid_number, '岩手県八幡平市殿坂下タ');
ok($zip->set_number('0287674')->is_valid_number, '岩手県八幡平市家ノ裏');
ok($zip->set_number('0287675')->is_valid_number, '岩手県八幡平市下モ川原');
ok($zip->set_number('0287676')->is_valid_number, '岩手県八幡平市沢口');
ok($zip->set_number('0287677')->is_valid_number, '岩手県八幡平市田山');
ok($zip->set_number('0287678')->is_valid_number, '岩手県八幡平市小森');
ok($zip->set_number('0287679')->is_valid_number, '岩手県八幡平市足深');
ok($zip->set_number('0287801')->is_valid_number, '岩手県久慈市侍浜町');
ok($zip->set_number('0287900')->is_valid_number, '岩手県九戸郡洋野町以下に掲載がない場合');
ok($zip->set_number('0287901')->is_valid_number, '岩手県九戸郡洋野町種市第8地割~第14地割(玉川、戸類家)');
ok($zip->set_number('0287902')->is_valid_number, '岩手県九戸郡洋野町種市第4地割~第7地割(宿戸)');
ok($zip->set_number('0287903')->is_valid_number, '岩手県九戸郡洋野町種市第1地割~第3地割(八木南町、八木北町)');
ok($zip->set_number('0287904')->is_valid_number, '岩手県九戸郡洋野町小子内');
ok($zip->set_number('0287905')->is_valid_number, '岩手県九戸郡洋野町有家');
ok($zip->set_number('0287906')->is_valid_number, '岩手県九戸郡洋野町中野');
ok($zip->set_number('0287911')->is_valid_number, '岩手県九戸郡洋野町種市第39地割~第45地割(角浜、伝吉)');
ok($zip->set_number('0287912')->is_valid_number, '岩手県九戸郡洋野町種市第26地割~第38地割(川尻、平内)');
ok($zip->set_number('0287913')->is_valid_number, '岩手県九戸郡洋野町種市第24地割~第25地割(緑ケ丘町、横手)');
ok($zip->set_number('0287914')->is_valid_number, '岩手県九戸郡洋野町種市第22地割~第23地割(一区、二区、三区、四区、大町、小橋、住吉町)');
ok($zip->set_number('0287915')->is_valid_number, '岩手県九戸郡洋野町種市第15地割~第21地割(鹿糠、小路合、緑町、大久保、高取)');
ok($zip->set_number('0287916')->is_valid_number, '岩手県九戸郡洋野町種市第71地割~第74地割(大谷、和座)');
ok($zip->set_number('0287917')->is_valid_number, '岩手県九戸郡洋野町種市第50地割~第70地割(大沢、城内、滝沢)');
ok($zip->set_number('0287918')->is_valid_number, '岩手県九戸郡洋野町種市第46地割~第49地割(麦沢)');
ok($zip->set_number('0288111')->is_valid_number, '岩手県久慈市宇部町');
ok($zip->set_number('0288200')->is_valid_number, '岩手県九戸郡野田村以下に掲載がない場合');
ok($zip->set_number('0288201')->is_valid_number, '岩手県九戸郡野田村野田');
ok($zip->set_number('0288202')->is_valid_number, '岩手県九戸郡野田村玉川');
ok($zip->set_number('0288300')->is_valid_number, '岩手県下閉伊郡普代村以下に掲載がない場合');
ok($zip->set_number('0288301')->is_valid_number, '岩手県下閉伊郡普代村馬場野');
ok($zip->set_number('0288302')->is_valid_number, '岩手県下閉伊郡普代村堀内');
ok($zip->set_number('0288303')->is_valid_number, '岩手県下閉伊郡普代村沢向');
ok($zip->set_number('0288311')->is_valid_number, '岩手県下閉伊郡普代村白井');
ok($zip->set_number('0288312')->is_valid_number, '岩手県下閉伊郡普代村小谷地');
ok($zip->set_number('0288313')->is_valid_number, '岩手県下閉伊郡普代村土取場');
ok($zip->set_number('0288321')->is_valid_number, '岩手県下閉伊郡普代村野胡桃');
ok($zip->set_number('0288322')->is_valid_number, '岩手県下閉伊郡普代村天拝坂');
ok($zip->set_number('0288323')->is_valid_number, '岩手県下閉伊郡普代村鳥居');
ok($zip->set_number('0288331')->is_valid_number, '岩手県下閉伊郡普代村宇留部');
ok($zip->set_number('0288332')->is_valid_number, '岩手県下閉伊郡普代村銅屋');
ok($zip->set_number('0288333')->is_valid_number, '岩手県下閉伊郡普代村羅賀');
ok($zip->set_number('0288334')->is_valid_number, '岩手県下閉伊郡普代村中村');
ok($zip->set_number('0288335')->is_valid_number, '岩手県下閉伊郡普代村普代');
ok($zip->set_number('0288336')->is_valid_number, '岩手県下閉伊郡普代村堤');
ok($zip->set_number('0288341')->is_valid_number, '岩手県下閉伊郡普代村明神');
ok($zip->set_number('0288342')->is_valid_number, '岩手県下閉伊郡普代村和野山');
ok($zip->set_number('0288343')->is_valid_number, '岩手県下閉伊郡普代村上の山');
ok($zip->set_number('0288344')->is_valid_number, '岩手県下閉伊郡普代村中山');
ok($zip->set_number('0288345')->is_valid_number, '岩手県下閉伊郡普代村太田名部');
ok($zip->set_number('0288351')->is_valid_number, '岩手県下閉伊郡普代村下村');
ok($zip->set_number('0288352')->is_valid_number, '岩手県下閉伊郡普代村上村');
ok($zip->set_number('0288353')->is_valid_number, '岩手県下閉伊郡普代村黒崎');
ok($zip->set_number('0288361')->is_valid_number, '岩手県下閉伊郡普代村北ノ股');
ok($zip->set_number('0288362')->is_valid_number, '岩手県下閉伊郡普代村卯子酉');
ok($zip->set_number('0288363')->is_valid_number, '岩手県下閉伊郡普代村茂市');
ok($zip->set_number('0288364')->is_valid_number, '岩手県下閉伊郡普代村南股');
ok($zip->set_number('0288365')->is_valid_number, '岩手県下閉伊郡普代村芦渡');
ok($zip->set_number('0288366')->is_valid_number, '岩手県下閉伊郡普代村芦生');
ok($zip->set_number('0288367')->is_valid_number, '岩手県下閉伊郡普代村萩牛');
ok($zip->set_number('0288368')->is_valid_number, '岩手県下閉伊郡普代村柏木平');
ok($zip->set_number('0288400')->is_valid_number, '岩手県下閉伊郡田野畑村以下に掲載がない場合');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村一の渡');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村蝦夷森');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村大森');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村尾肝要');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村奥地');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村奥地向');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村茅刈沢');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村巣合');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村千丈');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村千足');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村滝ノ沢');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村田代');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村長根');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村沼袋');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村子木地');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村子木屋敷');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村萩牛');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村日蔭');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村姫松');
ok($zip->set_number('0288401')->is_valid_number, '岩手県下閉伊郡田野畑村三沢');
ok($zip->set_number('0288402')->is_valid_number, '岩手県下閉伊郡田野畑村明戸');
ok($zip->set_number('0288402')->is_valid_number, '岩手県下閉伊郡田野畑村北山');
ok($zip->set_number('0288402')->is_valid_number, '岩手県下閉伊郡田野畑村机');
ok($zip->set_number('0288403')->is_valid_number, '岩手県下閉伊郡田野畑村羅賀');
ok($zip->set_number('0288404')->is_valid_number, '岩手県下閉伊郡田野畑村島越');
ok($zip->set_number('0288404')->is_valid_number, '岩手県下閉伊郡田野畑村松前沢');
ok($zip->set_number('0288405')->is_valid_number, '岩手県下閉伊郡田野畑村大芦');
ok($zip->set_number('0288405')->is_valid_number, '岩手県下閉伊郡田野畑村切牛');
ok($zip->set_number('0288405')->is_valid_number, '岩手県下閉伊郡田野畑村浜岩泉');
ok($zip->set_number('0288405')->is_valid_number, '岩手県下閉伊郡田野畑村真木沢');
ok($zip->set_number('0288405')->is_valid_number, '岩手県下閉伊郡田野畑村南大芦');
ok($zip->set_number('0288406')->is_valid_number, '岩手県下閉伊郡田野畑村猿山');
ok($zip->set_number('0288406')->is_valid_number, '岩手県下閉伊郡田野畑村年呂部');
ok($zip->set_number('0288406')->is_valid_number, '岩手県下閉伊郡田野畑村七滝');
ok($zip->set_number('0288406')->is_valid_number, '岩手県下閉伊郡田野畑村室場');
ok($zip->set_number('0288406')->is_valid_number, '岩手県下閉伊郡田野畑村目名');
ok($zip->set_number('0288407')->is_valid_number, '岩手県下閉伊郡田野畑村川平');
ok($zip->set_number('0288407')->is_valid_number, '岩手県下閉伊郡田野畑村菅窪');
ok($zip->set_number('0288407')->is_valid_number, '岩手県下閉伊郡田野畑村田野畑');
ok($zip->set_number('0288407')->is_valid_number, '岩手県下閉伊郡田野畑村和野');
ok($zip->set_number('0288521')->is_valid_number, '岩手県久慈市山根町');
ok($zip->set_number('0288601')->is_valid_number, '岩手県久慈市山形町戸呂町');
ok($zip->set_number('0288602')->is_valid_number, '岩手県久慈市山形町川井');
ok($zip->set_number('0288603')->is_valid_number, '岩手県久慈市山形町荷軽部');
ok($zip->set_number('0288604')->is_valid_number, '岩手県久慈市山形町日野沢');
ok($zip->set_number('0288605')->is_valid_number, '岩手県久慈市山形町来内');
ok($zip->set_number('0288711')->is_valid_number, '岩手県久慈市山形町繋');
ok($zip->set_number('0288712')->is_valid_number, '岩手県久慈市山形町小国');
ok($zip->set_number('0288713')->is_valid_number, '岩手県久慈市山形町霜畑');
ok($zip->set_number('0288801')->is_valid_number, '岩手県九戸郡洋野町上館');
ok($zip->set_number('0288802')->is_valid_number, '岩手県九戸郡洋野町大野');
ok($zip->set_number('0288803')->is_valid_number, '岩手県九戸郡洋野町阿子木');
ok($zip->set_number('0288804')->is_valid_number, '岩手県九戸郡洋野町帯島');
ok($zip->set_number('0288805')->is_valid_number, '岩手県九戸郡洋野町水沢');
ok($zip->set_number('0290131')->is_valid_number, '岩手県一関市狐禅寺');
ok($zip->set_number('0290132')->is_valid_number, '岩手県一関市滝沢');
ok($zip->set_number('0290201')->is_valid_number, '岩手県一関市川崎町門崎');
ok($zip->set_number('0290202')->is_valid_number, '岩手県一関市川崎町薄衣');
ok($zip->set_number('0290211')->is_valid_number, '岩手県一関市弥栄');
ok($zip->set_number('0290301')->is_valid_number, '岩手県一関市東山町田河津');
ok($zip->set_number('0290302')->is_valid_number, '岩手県一関市東山町長坂');
ok($zip->set_number('0290303')->is_valid_number, '岩手県一関市東山町松川');
ok($zip->set_number('0290431')->is_valid_number, '岩手県一関市大東町猿沢');
ok($zip->set_number('0290521')->is_valid_number, '岩手県一関市大東町渋民');
ok($zip->set_number('0290522')->is_valid_number, '岩手県一関市大東町曽慶');
ok($zip->set_number('0290523')->is_valid_number, '岩手県一関市大東町摺沢');
ok($zip->set_number('0290601')->is_valid_number, '岩手県一関市大東町中川');
ok($zip->set_number('0290602')->is_valid_number, '岩手県一関市大東町鳥海');
ok($zip->set_number('0290603')->is_valid_number, '岩手県一関市大東町沖田');
ok($zip->set_number('0290711')->is_valid_number, '岩手県一関市大東町大原');
ok($zip->set_number('0290801')->is_valid_number, '岩手県一関市千厩町清田');
ok($zip->set_number('0290802')->is_valid_number, '岩手県一関市千厩町小梨');
ok($zip->set_number('0290803')->is_valid_number, '岩手県一関市千厩町千厩');
ok($zip->set_number('0290804')->is_valid_number, '岩手県一関市千厩町磐清水');
ok($zip->set_number('0291111')->is_valid_number, '岩手県一関市千厩町奥玉');
ok($zip->set_number('0291201')->is_valid_number, '岩手県一関市室根町折壁');
ok($zip->set_number('0291202')->is_valid_number, '岩手県一関市室根町矢越');
ok($zip->set_number('0291211')->is_valid_number, '岩手県一関市室根町津谷川');
ok($zip->set_number('0292200')->is_valid_number, '岩手県陸前高田市以下に掲載がない場合');
ok($zip->set_number('0292201')->is_valid_number, '岩手県陸前高田市矢作町');
ok($zip->set_number('0292202')->is_valid_number, '岩手県陸前高田市横田町');
ok($zip->set_number('0292203')->is_valid_number, '岩手県陸前高田市竹駒町');
ok($zip->set_number('0292204')->is_valid_number, '岩手県陸前高田市気仙町');
ok($zip->set_number('0292205')->is_valid_number, '岩手県陸前高田市高田町');
ok($zip->set_number('0292206')->is_valid_number, '岩手県陸前高田市米崎町');
ok($zip->set_number('0292207')->is_valid_number, '岩手県陸前高田市小友町');
ok($zip->set_number('0292208')->is_valid_number, '岩手県陸前高田市広田町');
ok($zip->set_number('0292300')->is_valid_number, '岩手県気仙郡住田町以下に掲載がない場合');
ok($zip->set_number('0292311')->is_valid_number, '岩手県気仙郡住田町世田米');
ok($zip->set_number('0292501')->is_valid_number, '岩手県気仙郡住田町上有住');
ok($zip->set_number('0292502')->is_valid_number, '岩手県気仙郡住田町下有住');
ok($zip->set_number('0293101')->is_valid_number, '岩手県一関市花泉町花泉');
ok($zip->set_number('0293102')->is_valid_number, '岩手県一関市花泉町金沢');
ok($zip->set_number('0293103')->is_valid_number, '岩手県一関市花泉町老松');
ok($zip->set_number('0293104')->is_valid_number, '岩手県一関市花泉町日形');
ok($zip->set_number('0293105')->is_valid_number, '岩手県一関市花泉町涌津(一ノ町、二ノ町、上原、境、古川、道下)');
ok($zip->set_number('0293205')->is_valid_number, '岩手県一関市花泉町涌津(その他)');
ok($zip->set_number('0293206')->is_valid_number, '岩手県一関市花泉町永井');
ok($zip->set_number('0293207')->is_valid_number, '岩手県一関市花泉町油島');
ok($zip->set_number('0293311')->is_valid_number, '岩手県一関市藤沢町黄海');
ok($zip->set_number('0293401')->is_valid_number, '岩手県一関市藤沢町増沢');
ok($zip->set_number('0293402')->is_valid_number, '岩手県一関市藤沢町新沼');
ok($zip->set_number('0293403')->is_valid_number, '岩手県一関市藤沢町砂子田');
ok($zip->set_number('0293404')->is_valid_number, '岩手県一関市藤沢町徳田');
ok($zip->set_number('0293405')->is_valid_number, '岩手県一関市藤沢町藤沢');
ok($zip->set_number('0293406')->is_valid_number, '岩手県一関市藤沢町西口');
ok($zip->set_number('0293521')->is_valid_number, '岩手県一関市藤沢町保呂羽');
ok($zip->set_number('0293522')->is_valid_number, '岩手県一関市藤沢町大籠');
ok($zip->set_number('0294100')->is_valid_number, '岩手県西磐井郡平泉町以下に掲載がない場合');
ok($zip->set_number('0294101')->is_valid_number, '岩手県西磐井郡平泉町長島');
ok($zip->set_number('0294102')->is_valid_number, '岩手県西磐井郡平泉町平泉');
ok($zip->set_number('0294201')->is_valid_number, '岩手県奥州市前沢阿部舘');
ok($zip->set_number('0294201')->is_valid_number, '岩手県奥州市前沢久田');
ok($zip->set_number('0294201')->is_valid_number, '岩手県奥州市前沢源氏ケ崎');
ok($zip->set_number('0294201')->is_valid_number, '岩手県奥州市前沢古城');
ok($zip->set_number('0294202')->is_valid_number, '岩手県奥州市前沢白山');
ok($zip->set_number('0294203')->is_valid_number, '岩手県奥州市前沢北久保');
ok($zip->set_number('0294203')->is_valid_number, '岩手県奥州市前沢狐堂');
ok($zip->set_number('0294203')->is_valid_number, '岩手県奥州市前沢生母');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢下谷起');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢島');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢宿');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢高畑');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢田中');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢道場');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢鳥待小屋');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢中久保');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢長檀');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢中村');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢古川');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢南前沢');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢向田');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢本杉');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢谷地');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢八幡');
ok($zip->set_number('0294204')->is_valid_number, '岩手県奥州市前沢八幡前');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢合ノ沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢安寺沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢石田');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢一ノ沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢鵜ノ木');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢鵜ノ木田');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢うるし野');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢大袋');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢沖田');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢小沢口');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢川内');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢衣関');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢里');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢清水');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢蛇ノ鼻');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢白鳥舘');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢新城');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢堤田');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢照井舘');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢徳沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢永沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢長根');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢中屋敷');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢浪洗');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢二ノ沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢沼尻');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢沼ノ沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢日向');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢福養');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢干場');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢前野');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢南陣場');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢南塔ケ崎');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢南中島');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢箕輪');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢両手沢');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢谷記');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢谷起');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢谷記田');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢谷起田');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢櫓前');
ok($zip->set_number('0294205')->is_valid_number, '岩手県奥州市前沢六本松');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢赤坂');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢裏新田');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢狐石');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢駒水');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢陣場');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢太郎ケ沢');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢日除松');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢簾森');
ok($zip->set_number('0294206')->is_valid_number, '岩手県奥州市前沢養ケ森');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢赤面');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢一本杉');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢大桜');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢五十人町');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢下小路');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢平小路');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢平前');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢塔ケ崎');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢泊ケ崎');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢三日町');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢三日町浦');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢三日町新裏');
ok($zip->set_number('0294207')->is_valid_number, '岩手県奥州市前沢屋敷');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢粟ケ島');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢河ノ畑');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢株樹');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢五合田');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢新町');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢新町裏');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢大林寺下');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢竹沢');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢立石');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢田畠');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢中田');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢七日町');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢七日町裏');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢二十人町');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢二十人町裏');
ok($zip->set_number('0294208')->is_valid_number, '岩手県奥州市前沢山下');
ok($zip->set_number('0294209')->is_valid_number, '岩手県奥州市前沢あすか通');
ok($zip->set_number('0294211')->is_valid_number, '岩手県奥州市前沢駅東');
ok($zip->set_number('0294303')->is_valid_number, '岩手県奥州市衣川衣原');
ok($zip->set_number('0294304')->is_valid_number, '岩手県奥州市衣川外の沢');
ok($zip->set_number('0294305')->is_valid_number, '岩手県奥州市衣川長袋');
ok($zip->set_number('0294306')->is_valid_number, '岩手県奥州市衣川小田');
ok($zip->set_number('0294307')->is_valid_number, '岩手県奥州市衣川有浦');
ok($zip->set_number('0294308')->is_valid_number, '岩手県奥州市衣川大平');
ok($zip->set_number('0294311')->is_valid_number, '岩手県奥州市衣川古館');
ok($zip->set_number('0294312')->is_valid_number, '岩手県奥州市衣川西窪');
ok($zip->set_number('0294313')->is_valid_number, '岩手県奥州市衣川石生');
ok($zip->set_number('0294314')->is_valid_number, '岩手県奥州市衣川中屋敷');
ok($zip->set_number('0294315')->is_valid_number, '岩手県奥州市衣川天田');
ok($zip->set_number('0294316')->is_valid_number, '岩手県奥州市衣川苗代沢');
ok($zip->set_number('0294317')->is_valid_number, '岩手県奥州市衣川桑畑');
ok($zip->set_number('0294321')->is_valid_number, '岩手県奥州市衣川雲南田');
ok($zip->set_number('0294322')->is_valid_number, '岩手県奥州市衣川板倉');
ok($zip->set_number('0294323')->is_valid_number, '岩手県奥州市衣川小安代');
ok($zip->set_number('0294324')->is_valid_number, '岩手県奥州市衣川正板');
ok($zip->set_number('0294325')->is_valid_number, '岩手県奥州市衣川小正板');
ok($zip->set_number('0294326')->is_valid_number, '岩手県奥州市衣川懸田');
ok($zip->set_number('0294327')->is_valid_number, '岩手県奥州市衣川馬懸');
ok($zip->set_number('0294328')->is_valid_number, '岩手県奥州市衣川下寺田');
ok($zip->set_number('0294329')->is_valid_number, '岩手県奥州市衣川上寺田');
ok($zip->set_number('0294331')->is_valid_number, '岩手県奥州市衣川深沢');
ok($zip->set_number('0294332')->is_valid_number, '岩手県奥州市衣川古戸');
ok($zip->set_number('0294333')->is_valid_number, '岩手県奥州市衣川駒場');
ok($zip->set_number('0294334')->is_valid_number, '岩手県奥州市衣川百ヶ袋');
ok($zip->set_number('0294341')->is_valid_number, '岩手県奥州市衣川六道');
ok($zip->set_number('0294342')->is_valid_number, '岩手県奥州市衣川高保呂');
ok($zip->set_number('0294343')->is_valid_number, '岩手県奥州市衣川能登屋敷');
ok($zip->set_number('0294344')->is_valid_number, '岩手県奥州市衣川沢田');
ok($zip->set_number('0294345')->is_valid_number, '岩手県奥州市衣川館城');
ok($zip->set_number('0294346')->is_valid_number, '岩手県奥州市衣川豊巻');
ok($zip->set_number('0294347')->is_valid_number, '岩手県奥州市衣川大西');
ok($zip->set_number('0294348')->is_valid_number, '岩手県奥州市衣川杉野');
ok($zip->set_number('0294351')->is_valid_number, '岩手県奥州市衣川夏秋');
ok($zip->set_number('0294352')->is_valid_number, '岩手県奥州市衣川岩の上');
ok($zip->set_number('0294353')->is_valid_number, '岩手県奥州市衣川旧殿');
ok($zip->set_number('0294354')->is_valid_number, '岩手県奥州市衣川除');
ok($zip->set_number('0294355')->is_valid_number, '岩手県奥州市衣川山岸');
ok($zip->set_number('0294361')->is_valid_number, '岩手県奥州市衣川長嚢');
ok($zip->set_number('0294362')->is_valid_number, '岩手県奥州市衣川小林山');
ok($zip->set_number('0294363')->is_valid_number, '岩手県奥州市衣川夏梨');
ok($zip->set_number('0294364')->is_valid_number, '岩手県奥州市衣川西風山');
ok($zip->set_number('0294365')->is_valid_number, '岩手県奥州市衣川天土');
ok($zip->set_number('0294371')->is_valid_number, '岩手県奥州市衣川桧山沢');
ok($zip->set_number('0294372')->is_valid_number, '岩手県奥州市衣川松林');
ok($zip->set_number('0294373')->is_valid_number, '岩手県奥州市衣川山田');
ok($zip->set_number('0294374')->is_valid_number, '岩手県奥州市衣川桧山沢山');
ok($zip->set_number('0294375')->is_valid_number, '岩手県奥州市衣川鞍掛');
ok($zip->set_number('0294376')->is_valid_number, '岩手県奥州市衣川本巻');
ok($zip->set_number('0294377')->is_valid_number, '岩手県奥州市衣川後山');
ok($zip->set_number('0294378')->is_valid_number, '岩手県奥州市衣川菖蒲平');
ok($zip->set_number('0294381')->is_valid_number, '岩手県奥州市衣川石ヶ沢');
ok($zip->set_number('0294382')->is_valid_number, '岩手県奥州市衣川関袋');
ok($zip->set_number('0294383')->is_valid_number, '岩手県奥州市衣川沖の野');
ok($zip->set_number('0294384')->is_valid_number, '岩手県奥州市衣川石神');
ok($zip->set_number('0294385')->is_valid_number, '岩手県奥州市衣川富沢');
ok($zip->set_number('0294386')->is_valid_number, '岩手県奥州市衣川女石');
ok($zip->set_number('0294387')->is_valid_number, '岩手県奥州市衣川下大森');
ok($zip->set_number('0294388')->is_valid_number, '岩手県奥州市衣川上大森');
ok($zip->set_number('0294389')->is_valid_number, '岩手県奥州市衣川長板沢');
ok($zip->set_number('0294401')->is_valid_number, '岩手県奥州市衣川張山');
ok($zip->set_number('0294402')->is_valid_number, '岩手県奥州市衣川星屋');
ok($zip->set_number('0294403')->is_valid_number, '岩手県奥州市衣川本田原');
ok($zip->set_number('0294404')->is_valid_number, '岩手県奥州市衣川寺袋');
ok($zip->set_number('0294405')->is_valid_number, '岩手県奥州市衣川桑木谷地');
ok($zip->set_number('0294406')->is_valid_number, '岩手県奥州市衣川大坂');
ok($zip->set_number('0294407')->is_valid_number, '岩手県奥州市衣川金成');
ok($zip->set_number('0294408')->is_valid_number, '岩手県奥州市衣川土屋');
ok($zip->set_number('0294411')->is_valid_number, '岩手県奥州市衣川上小路');
ok($zip->set_number('0294412')->is_valid_number, '岩手県奥州市衣川富田');
ok($zip->set_number('0294413')->is_valid_number, '岩手県奥州市衣川堰下');
ok($zip->set_number('0294414')->is_valid_number, '岩手県奥州市衣川野田');
ok($zip->set_number('0294415')->is_valid_number, '岩手県奥州市衣川向館谷起');
ok($zip->set_number('0294416')->is_valid_number, '岩手県奥州市衣川向館');
ok($zip->set_number('0294417')->is_valid_number, '岩手県奥州市衣川富田前');
ok($zip->set_number('0294418')->is_valid_number, '岩手県奥州市衣川杉林');
ok($zip->set_number('0294419')->is_valid_number, '岩手県奥州市衣川大面');
ok($zip->set_number('0294421')->is_valid_number, '岩手県奥州市衣川日向');
ok($zip->set_number('0294422')->is_valid_number, '岩手県奥州市衣川瀬原');
ok($zip->set_number('0294423')->is_valid_number, '岩手県奥州市衣川瀬原西浦');
ok($zip->set_number('0294424')->is_valid_number, '岩手県奥州市衣川九輪堂');
ok($zip->set_number('0294425')->is_valid_number, '岩手県奥州市衣川采女沢');
ok($zip->set_number('0294426')->is_valid_number, '岩手県奥州市衣川愛宕下');
ok($zip->set_number('0294427')->is_valid_number, '岩手県奥州市衣川陣場下');
ok($zip->set_number('0294431')->is_valid_number, '岩手県奥州市衣川田中');
ok($zip->set_number('0294432')->is_valid_number, '岩手県奥州市衣川小林');
ok($zip->set_number('0294433')->is_valid_number, '岩手県奥州市衣川池田西');
ok($zip->set_number('0294434')->is_valid_number, '岩手県奥州市衣川池田');
ok($zip->set_number('0294435')->is_valid_number, '岩手県奥州市衣川押切');
ok($zip->set_number('0294436')->is_valid_number, '岩手県奥州市衣川大石ヶ沢');
ok($zip->set_number('0294437')->is_valid_number, '岩手県奥州市衣川唐金');
ok($zip->set_number('0294438')->is_valid_number, '岩手県奥州市衣川室の木');
ok($zip->set_number('0294439')->is_valid_number, '岩手県奥州市衣川田中西');
ok($zip->set_number('0294441')->is_valid_number, '岩手県奥州市衣川並木前');
ok($zip->set_number('0294442')->is_valid_number, '岩手県奥州市衣川上野');
ok($zip->set_number('0294443')->is_valid_number, '岩手県奥州市衣川六日市場');
ok($zip->set_number('0294444')->is_valid_number, '岩手県奥州市衣川清水の上');
ok($zip->set_number('0294445')->is_valid_number, '岩手県奥州市衣川七日市場');
ok($zip->set_number('0294446')->is_valid_number, '岩手県奥州市衣川川端');
ok($zip->set_number('0294451')->is_valid_number, '岩手県奥州市衣川東裏');
ok($zip->set_number('0294452')->is_valid_number, '岩手県奥州市衣川月山');
ok($zip->set_number('0294453')->is_valid_number, '岩手県奥州市衣川山口');
ok($zip->set_number('0294454')->is_valid_number, '岩手県奥州市衣川表');
ok($zip->set_number('0294455')->is_valid_number, '岩手県奥州市衣川横道下');
ok($zip->set_number('0294456')->is_valid_number, '岩手県奥州市衣川西裏');
ok($zip->set_number('0294461')->is_valid_number, '岩手県奥州市衣川平');
ok($zip->set_number('0294462')->is_valid_number, '岩手県奥州市衣川八千');
ok($zip->set_number('0294463')->is_valid_number, '岩手県奥州市衣川葭ヶ沢');
ok($zip->set_number('0294464')->is_valid_number, '岩手県奥州市衣川前滝の沢');
ok($zip->set_number('0294465')->is_valid_number, '岩手県奥州市衣川後滝の沢');
ok($zip->set_number('0294471')->is_valid_number, '岩手県奥州市衣川下河内');
ok($zip->set_number('0294472')->is_valid_number, '岩手県奥州市衣川中河内');
ok($zip->set_number('0294473')->is_valid_number, '岩手県奥州市衣川向');
ok($zip->set_number('0294474')->is_valid_number, '岩手県奥州市衣川上河内');
ok($zip->set_number('0294475')->is_valid_number, '岩手県奥州市衣川中山');
ok($zip->set_number('0294481')->is_valid_number, '岩手県奥州市衣川畦畑山');
ok($zip->set_number('0294482')->is_valid_number, '岩手県奥州市衣川畦畑');
ok($zip->set_number('0294483')->is_valid_number, '岩手県奥州市衣川沼野');
ok($zip->set_number('0294484')->is_valid_number, '岩手県奥州市衣川噌味');
ok($zip->set_number('0294485')->is_valid_number, '岩手県奥州市衣川宝塔谷地');
ok($zip->set_number('0294486')->is_valid_number, '岩手県奥州市衣川鷹の巣');
ok($zip->set_number('0294487')->is_valid_number, '岩手県奥州市衣川大原山');
ok($zip->set_number('0294488')->is_valid_number, '岩手県奥州市衣川大原');
ok($zip->set_number('0294491')->is_valid_number, '岩手県奥州市衣川上立沢');
ok($zip->set_number('0294492')->is_valid_number, '岩手県奥州市衣川下立沢');
ok($zip->set_number('0294493')->is_valid_number, '岩手県奥州市衣川野崎');
ok($zip->set_number('0294494')->is_valid_number, '岩手県奥州市衣川楢原山');
ok($zip->set_number('0294495')->is_valid_number, '岩手県奥州市衣川楢原');
ok($zip->set_number('0294496')->is_valid_number, '岩手県奥州市衣川真打');
ok($zip->set_number('0294497')->is_valid_number, '岩手県奥州市衣川餅転');
ok($zip->set_number('0294500')->is_valid_number, '岩手県胆沢郡金ケ崎町以下に掲載がない場合');
ok($zip->set_number('0294501')->is_valid_number, '岩手県胆沢郡金ケ崎町六原');
ok($zip->set_number('0294502')->is_valid_number, '岩手県胆沢郡金ケ崎町三ケ尻');
ok($zip->set_number('0294503')->is_valid_number, '岩手県胆沢郡金ケ崎町西根');
ok($zip->set_number('0294504')->is_valid_number, '岩手県胆沢郡金ケ崎町永沢');
ok($zip->set_number('0294505')->is_valid_number, '岩手県胆沢郡金ケ崎町永栄');
ok($zip->set_number('0295500')->is_valid_number, '岩手県和賀郡西和賀町以下に掲載がない場合');
ok($zip->set_number('0295501')->is_valid_number, '岩手県和賀郡西和賀町左草1地割~左草6地割');
ok($zip->set_number('0295501')->is_valid_number, '岩手県和賀郡西和賀町下左草77地割~下左草80地割');
ok($zip->set_number('0295502')->is_valid_number, '岩手県和賀郡西和賀町樺沢16地割、樺沢17地割');
ok($zip->set_number('0295502')->is_valid_number, '岩手県和賀郡西和賀町下前7地割~下前14地割');
ok($zip->set_number('0295502')->is_valid_number, '岩手県和賀郡西和賀町寅沢15地割');
ok($zip->set_number('0295503')->is_valid_number, '岩手県和賀郡西和賀町穴明22地割、穴明23地割');
ok($zip->set_number('0295503')->is_valid_number, '岩手県和賀郡西和賀町清水ケ野18地割');
ok($zip->set_number('0295503')->is_valid_number, '岩手県和賀郡西和賀町間木野24地割');
ok($zip->set_number('0295503')->is_valid_number, '岩手県和賀郡西和賀町湯田19地割~湯田21地割');
ok($zip->set_number('0295504')->is_valid_number, '岩手県和賀郡西和賀町槻沢25地割~槻沢28地割');
ok($zip->set_number('0295505')->is_valid_number, '岩手県和賀郡西和賀町湯本29地割、湯本30地割');
ok($zip->set_number('0295506')->is_valid_number, '岩手県和賀郡西和賀町湯之沢31地割~湯之沢35地割');
ok($zip->set_number('0295507')->is_valid_number, '岩手県和賀郡西和賀町大沓36地割');
ok($zip->set_number('0295511')->is_valid_number, '岩手県和賀郡西和賀町上野々39地割');
ok($zip->set_number('0295512')->is_valid_number, '岩手県和賀郡西和賀町川尻40地割、川尻41地割');
ok($zip->set_number('0295513')->is_valid_number, '岩手県和賀郡西和賀町甲子51地割');
ok($zip->set_number('0295513')->is_valid_number, '岩手県和賀郡西和賀町草井沢47地割');
ok($zip->set_number('0295513')->is_valid_number, '岩手県和賀郡西和賀町杉名畑44地割(その他)');
ok($zip->set_number('0295513')->is_valid_number, '岩手県和賀郡西和賀町本内46地割');
ok($zip->set_number('0295513')->is_valid_number, '岩手県和賀郡西和賀町耳取49地割');
ok($zip->set_number('0295513')->is_valid_number, '岩手県和賀郡西和賀町本屋敷48地割');
ok($zip->set_number('0295513')->is_valid_number, '岩手県和賀郡西和賀町鷲之巣50地割');
ok($zip->set_number('0295514')->is_valid_number, '岩手県和賀郡西和賀町湯川52地割、湯川53地割');
ok($zip->set_number('0295521')->is_valid_number, '岩手県和賀郡西和賀町大渡57地割');
ok($zip->set_number('0295521')->is_valid_number, '岩手県和賀郡西和賀町小繋沢54地割~小繋沢56地割');
ok($zip->set_number('0295522')->is_valid_number, '岩手県和賀郡西和賀町巣郷63地割');
ok($zip->set_number('0295522')->is_valid_number, '岩手県和賀郡西和賀町中村58地割、中村59地割');
ok($zip->set_number('0295522')->is_valid_number, '岩手県和賀郡西和賀町野々宿60地割~野々宿62地割');
ok($zip->set_number('0295523')->is_valid_number, '岩手県和賀郡西和賀町越中畑64地割~越中畑66地割');
ok($zip->set_number('0295523')->is_valid_number, '岩手県和賀郡西和賀町桂子沢75地割、桂子沢76地割');
ok($zip->set_number('0295523')->is_valid_number, '岩手県和賀郡西和賀町沢中73地割、沢中74地割');
ok($zip->set_number('0295523')->is_valid_number, '岩手県和賀郡西和賀町白木野67地割');
ok($zip->set_number('0295523')->is_valid_number, '岩手県和賀郡西和賀町細内68地割、細内69地割');
ok($zip->set_number('0295523')->is_valid_number, '岩手県和賀郡西和賀町柳沢70地割、柳沢71地割');
ok($zip->set_number('0295523')->is_valid_number, '岩手県和賀郡西和賀町芦ケ沢72地割');
ok($zip->set_number('0295611')->is_valid_number, '岩手県和賀郡西和賀町沢内新町');
ok($zip->set_number('0295612')->is_valid_number, '岩手県和賀郡西和賀町沢内大野');
ok($zip->set_number('0295613')->is_valid_number, '岩手県和賀郡西和賀町沢内前郷');
ok($zip->set_number('0295614')->is_valid_number, '岩手県和賀郡西和賀町沢内太田');
ok($zip->set_number('0295615')->is_valid_number, '岩手県和賀郡西和賀町沢内猿橋');
ok($zip->set_number('0295616')->is_valid_number, '岩手県和賀郡西和賀町沢内泉沢');
ok($zip->set_number('0295617')->is_valid_number, '岩手県和賀郡西和賀町沢内長瀬野');
ok($zip->set_number('0295618')->is_valid_number, '岩手県和賀郡西和賀町沢内両沢');
ok($zip->set_number('0295619')->is_valid_number, '岩手県和賀郡西和賀町沢内弁天');
ok($zip->set_number('0295621')->is_valid_number, '岩手県和賀郡西和賀町沢内鍵飯');
ok($zip->set_number('0295701')->is_valid_number, '岩手県和賀郡西和賀町沢内川舟');
ok($zip->set_number('0295702')->is_valid_number, '岩手県和賀郡西和賀町沢内若畑');
ok($zip->set_number('0295703')->is_valid_number, '岩手県和賀郡西和賀町沢内貝沢');
ok($zip->set_number('0300111')->is_valid_number, '青森県青森市荒川');
ok($zip->set_number('0300112')->is_valid_number, '青森県青森市八ツ役');
ok($zip->set_number('0300113')->is_valid_number, '青森県青森市第二問屋町');
ok($zip->set_number('0300121')->is_valid_number, '青森県青森市妙見');
ok($zip->set_number('0300122')->is_valid_number, '青森県青森市野尻');
ok($zip->set_number('0300123')->is_valid_number, '青森県青森市大矢沢');
ok($zip->set_number('0300124')->is_valid_number, '青森県青森市田茂木野');
ok($zip->set_number('0300125')->is_valid_number, '青森県青森市四ツ石');
ok($zip->set_number('0300131')->is_valid_number, '青森県青森市問屋町');
ok($zip->set_number('0300132')->is_valid_number, '青森県青森市横内');
ok($zip->set_number('0300133')->is_valid_number, '青森県青森市雲谷');
ok($zip->set_number('0300134')->is_valid_number, '青森県青森市合子沢');
ok($zip->set_number('0300135')->is_valid_number, '青森県青森市新町野');
ok($zip->set_number('0300136')->is_valid_number, '青森県青森市牛館');
ok($zip->set_number('0300137')->is_valid_number, '青森県青森市卸町');
ok($zip->set_number('0300141')->is_valid_number, '青森県青森市上野');
ok($zip->set_number('0300142')->is_valid_number, '青森県青森市野木');
ok($zip->set_number('0300143')->is_valid_number, '青森県青森市小畑沢');
ok($zip->set_number('0300144')->is_valid_number, '青森県青森市大別内');
ok($zip->set_number('0300145')->is_valid_number, '青森県青森市金浜');
ok($zip->set_number('0300151')->is_valid_number, '青森県青森市高田');
ok($zip->set_number('0300152')->is_valid_number, '青森県青森市野沢');
ok($zip->set_number('0300153')->is_valid_number, '青森県青森市小館');
ok($zip->set_number('0300154')->is_valid_number, '青森県青森市入内');
ok($zip->set_number('0300155')->is_valid_number, '青森県青森市大谷');
ok($zip->set_number('0300801')->is_valid_number, '青森県青森市新町');
ok($zip->set_number('0300802')->is_valid_number, '青森県青森市本町');
ok($zip->set_number('0300803')->is_valid_number, '青森県青森市安方');
ok($zip->set_number('0300811')->is_valid_number, '青森県青森市青柳');
ok($zip->set_number('0300812')->is_valid_number, '青森県青森市堤町');
ok($zip->set_number('0300813')->is_valid_number, '青森県青森市松原');
ok($zip->set_number('0300821')->is_valid_number, '青森県青森市勝田');
ok($zip->set_number('0300822')->is_valid_number, '青森県青森市中央');
ok($zip->set_number('0300823')->is_valid_number, '青森県青森市橋本');
ok($zip->set_number('0300841')->is_valid_number, '青森県青森市奥野');
ok($zip->set_number('0300842')->is_valid_number, '青森県青森市浦町');
ok($zip->set_number('0300843')->is_valid_number, '青森県青森市浜田');
ok($zip->set_number('0300844')->is_valid_number, '青森県青森市桂木');
ok($zip->set_number('0300845')->is_valid_number, '青森県青森市緑');
ok($zip->set_number('0300846')->is_valid_number, '青森県青森市青葉');
ok($zip->set_number('0300847')->is_valid_number, '青森県青森市東大野');
ok($zip->set_number('0300851')->is_valid_number, '青森県青森市旭町');
ok($zip->set_number('0300852')->is_valid_number, '青森県青森市大野');
ok($zip->set_number('0300853')->is_valid_number, '青森県青森市金沢');
ok($zip->set_number('0300854')->is_valid_number, '青森県青森市千富町');
ok($zip->set_number('0300855')->is_valid_number, '青森県青森市北金沢');
ok($zip->set_number('0300856')->is_valid_number, '青森県青森市西大野');
ok($zip->set_number('0300861')->is_valid_number, '青森県青森市長島');
ok($zip->set_number('0300862')->is_valid_number, '青森県青森市古川');
ok($zip->set_number('0300901')->is_valid_number, '青森県青森市港町');
ok($zip->set_number('0300902')->is_valid_number, '青森県青森市合浦');
ok($zip->set_number('0300903')->is_valid_number, '青森県青森市栄町');
ok($zip->set_number('0300904')->is_valid_number, '青森県青森市茶屋町');
ok($zip->set_number('0300911')->is_valid_number, '青森県青森市造道');
ok($zip->set_number('0300912')->is_valid_number, '青森県青森市八重田');
ok($zip->set_number('0300913')->is_valid_number, '青森県青森市東造道');
ok($zip->set_number('0300914')->is_valid_number, '青森県青森市岡造道');
ok($zip->set_number('0300915')->is_valid_number, '青森県青森市小柳');
ok($zip->set_number('0300916')->is_valid_number, '青森県青森市田屋敷');
ok($zip->set_number('0300917')->is_valid_number, '青森県青森市矢作');
ok($zip->set_number('0300918')->is_valid_number, '青森県青森市けやき');
ok($zip->set_number('0300919')->is_valid_number, '青森県青森市はまなす');
ok($zip->set_number('0300921')->is_valid_number, '青森県青森市原別');
ok($zip->set_number('0300922')->is_valid_number, '青森県青森市泉野');
ok($zip->set_number('0300923')->is_valid_number, '青森県青森市八幡林');
ok($zip->set_number('0300924')->is_valid_number, '青森県青森市滝沢(下川原190-1)');
ok($zip->set_number('0300925')->is_valid_number, '青森県青森市築木館');
ok($zip->set_number('0300931')->is_valid_number, '青森県青森市平新田');
ok($zip->set_number('0300932')->is_valid_number, '青森県青森市後萢');
ok($zip->set_number('0300933')->is_valid_number, '青森県青森市諏訪沢');
ok($zip->set_number('0300934')->is_valid_number, '青森県青森市戸崎');
ok($zip->set_number('0300935')->is_valid_number, '青森県青森市桑原');
ok($zip->set_number('0300936')->is_valid_number, '青森県青森市矢田前');
ok($zip->set_number('0300937')->is_valid_number, '青森県青森市本泉');
ok($zip->set_number('0300941')->is_valid_number, '青森県青森市自由ケ丘');
ok($zip->set_number('0300942')->is_valid_number, '青森県青森市沢山');
ok($zip->set_number('0300943')->is_valid_number, '青森県青森市幸畑');
ok($zip->set_number('0300944')->is_valid_number, '青森県青森市筒井');
ok($zip->set_number('0300945')->is_valid_number, '青森県青森市桜川');
ok($zip->set_number('0300946')->is_valid_number, '青森県青森市古館');
ok($zip->set_number('0300947')->is_valid_number, '青森県青森市浜館');
ok($zip->set_number('0300948')->is_valid_number, '青森県青森市虹ケ丘');
ok($zip->set_number('0300951')->is_valid_number, '青森県青森市戸山(その他)');
ok($zip->set_number('0300952')->is_valid_number, '青森県青森市戸山(赤坂)');
ok($zip->set_number('0300953')->is_valid_number, '青森県青森市駒込(蛍沢)');
ok($zip->set_number('0300954')->is_valid_number, '青森県青森市駒込(月見野)');
ok($zip->set_number('0300955')->is_valid_number, '青森県青森市駒込(その他)');
ok($zip->set_number('0300956')->is_valid_number, '青森県青森市赤坂');
ok($zip->set_number('0300957')->is_valid_number, '青森県青森市蛍沢');
ok($zip->set_number('0300958')->is_valid_number, '青森県青森市月見野');
ok($zip->set_number('0300961')->is_valid_number, '青森県青森市浪打');
ok($zip->set_number('0300962')->is_valid_number, '青森県青森市佃');
ok($zip->set_number('0300963')->is_valid_number, '青森県青森市中佃');
ok($zip->set_number('0300964')->is_valid_number, '青森県青森市南佃');
ok($zip->set_number('0300965')->is_valid_number, '青森県青森市松森');
ok($zip->set_number('0300966')->is_valid_number, '青森県青森市花園');
ok($zip->set_number('0301200')->is_valid_number, '青森県東津軽郡蓬田村以下に掲載がない場合');
ok($zip->set_number('0301201')->is_valid_number, '青森県東津軽郡蓬田村広瀬');
ok($zip->set_number('0301202')->is_valid_number, '青森県東津軽郡蓬田村瀬辺地');
ok($zip->set_number('0301203')->is_valid_number, '青森県東津軽郡蓬田村郷沢');
ok($zip->set_number('0301211')->is_valid_number, '青森県東津軽郡蓬田村蓬田');
ok($zip->set_number('0301212')->is_valid_number, '青森県東津軽郡蓬田村阿弥陀川');
ok($zip->set_number('0301213')->is_valid_number, '青森県東津軽郡蓬田村長科');
ok($zip->set_number('0301214')->is_valid_number, '青森県東津軽郡蓬田村中沢');
ok($zip->set_number('0301261')->is_valid_number, '青森県青森市四戸橋');
ok($zip->set_number('0301262')->is_valid_number, '青森県青森市後潟');
ok($zip->set_number('0301271')->is_valid_number, '青森県青森市六枚橋');
ok($zip->set_number('0301272')->is_valid_number, '青森県青森市小橋');
ok($zip->set_number('0301273')->is_valid_number, '青森県青森市左堰');
ok($zip->set_number('0301301')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田石浜');
ok($zip->set_number('0301302')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田中師');
ok($zip->set_number('0301303')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田');
ok($zip->set_number('0301304')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田南沢');
ok($zip->set_number('0301305')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田小国');
ok($zip->set_number('0301306')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田山本');
ok($zip->set_number('0301307')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田大平');
ok($zip->set_number('0301308')->is_valid_number, '青森県東津軽郡外ヶ浜町下蟹田');
ok($zip->set_number('0301309')->is_valid_number, '青森県東津軽郡外ヶ浜町上蟹田');
ok($zip->set_number('0301311')->is_valid_number, '青森県東津軽郡外ヶ浜町蟹田塩越');
ok($zip->set_number('0301400')->is_valid_number, '青森県東津軽郡外ヶ浜町以下に掲載がない場合');
ok($zip->set_number('0301402')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘');
ok($zip->set_number('0301403')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘元宇田');
ok($zip->set_number('0301404')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘弥蔵釜');
ok($zip->set_number('0301405')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘石崎沢');
ok($zip->set_number('0301411')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘根岸');
ok($zip->set_number('0301412')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘野田');
ok($zip->set_number('0301413')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘今津');
ok($zip->set_number('0301415')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘舟岡');
ok($zip->set_number('0301416')->is_valid_number, '青森県東津軽郡外ヶ浜町平舘磯山');
ok($zip->set_number('0301500')->is_valid_number, '青森県東津軽郡今別町以下に掲載がない場合');
ok($zip->set_number('0301501')->is_valid_number, '青森県東津軽郡今別町浜名');
ok($zip->set_number('0301502')->is_valid_number, '青森県東津軽郡今別町今別');
ok($zip->set_number('0301503')->is_valid_number, '青森県東津軽郡今別町村元');
ok($zip->set_number('0301504')->is_valid_number, '青森県東津軽郡今別町鍋田');
ok($zip->set_number('0301505')->is_valid_number, '青森県東津軽郡今別町大川平');
ok($zip->set_number('0301511')->is_valid_number, '青森県東津軽郡今別町山崎');
ok($zip->set_number('0301512')->is_valid_number, '青森県東津軽郡今別町大泊');
ok($zip->set_number('0301513')->is_valid_number, '青森県東津軽郡今別町袰月');
ok($zip->set_number('0301514')->is_valid_number, '青森県東津軽郡今別町砂ケ森');
ok($zip->set_number('0301515')->is_valid_number, '青森県東津軽郡今別町奥平部');
ok($zip->set_number('0301701')->is_valid_number, '青森県北津軽郡中泊町小泊袰内');
ok($zip->set_number('0301711')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩源兵衛間');
ok($zip->set_number('0301711')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩龍浜');
ok($zip->set_number('0301712')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩木落');
ok($zip->set_number('0301713')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩鎧嶋');
ok($zip->set_number('0301714')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩梹榔');
ok($zip->set_number('0301715')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩鳴神');
ok($zip->set_number('0301716')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩尻神');
ok($zip->set_number('0301717')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩川柱');
ok($zip->set_number('0301718')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩梨ノ木間');
ok($zip->set_number('0301719')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩宇鉄山');
ok($zip->set_number('0301720')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩四枚橋');
ok($zip->set_number('0301721')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩鐇泊');
ok($zip->set_number('0301722')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩上宇鉄');
ok($zip->set_number('0301723')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩元宇鉄');
ok($zip->set_number('0301724')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩釜野澤');
ok($zip->set_number('0301725')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩藤嶋');
ok($zip->set_number('0301726')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩六條間');
ok($zip->set_number('0301727')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩算用師');
ok($zip->set_number('0301728')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩中浜');
ok($zip->set_number('0301729')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩下平');
ok($zip->set_number('0301731')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩本町');
ok($zip->set_number('0301732')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩家ノ上');
ok($zip->set_number('0301733')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩新町');
ok($zip->set_number('0301734')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩増川');
ok($zip->set_number('0301735')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩緑ケ丘');
ok($zip->set_number('0301736')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩桃ケ丘');
ok($zip->set_number('0301737')->is_valid_number, '青森県東津軽郡外ヶ浜町三厩東町');
ok($zip->set_number('0310000')->is_valid_number, '青森県八戸市以下に掲載がない場合');
ok($zip->set_number('0310001')->is_valid_number, '青森県八戸市類家');
ok($zip->set_number('0310002')->is_valid_number, '青森県八戸市中居林');
ok($zip->set_number('0310003')->is_valid_number, '青森県八戸市吹上');
ok($zip->set_number('0310004')->is_valid_number, '青森県八戸市南類家');
ok($zip->set_number('0310007')->is_valid_number, '青森県八戸市櫛引(土橋)');
ok($zip->set_number('0310011')->is_valid_number, '青森県八戸市田向');
ok($zip->set_number('0310012')->is_valid_number, '青森県八戸市十日市');
ok($zip->set_number('0310013')->is_valid_number, '青森県八戸市石手洗');
ok($zip->set_number('0310021')->is_valid_number, '青森県八戸市長者');
ok($zip->set_number('0310022')->is_valid_number, '青森県八戸市糠塚');
ok($zip->set_number('0310023')->is_valid_number, '青森県八戸市是川');
ok($zip->set_number('0310031')->is_valid_number, '青森県八戸市番町');
ok($zip->set_number('0310032')->is_valid_number, '青森県八戸市三日町');
ok($zip->set_number('0310033')->is_valid_number, '青森県八戸市六日町');
ok($zip->set_number('0310034')->is_valid_number, '青森県八戸市鷹匠小路');
ok($zip->set_number('0310035')->is_valid_number, '青森県八戸市寺横町');
ok($zip->set_number('0310036')->is_valid_number, '青森県八戸市大工町');
ok($zip->set_number('0310037')->is_valid_number, '青森県八戸市鍛冶町');
ok($zip->set_number('0310038')->is_valid_number, '青森県八戸市山伏小路');
ok($zip->set_number('0310039')->is_valid_number, '青森県八戸市鳥屋部町');
ok($zip->set_number('0310041')->is_valid_number, '青森県八戸市廿三日町');
ok($zip->set_number('0310042')->is_valid_number, '青森県八戸市十三日町');
ok($zip->set_number('0310043')->is_valid_number, '青森県八戸市十六日町');
ok($zip->set_number('0310044')->is_valid_number, '青森県八戸市廿六日町');
ok($zip->set_number('0310045')->is_valid_number, '青森県八戸市本鍛冶町');
ok($zip->set_number('0310046')->is_valid_number, '青森県八戸市町組町');
ok($zip->set_number('0310047')->is_valid_number, '青森県八戸市常番町');
ok($zip->set_number('0310051')->is_valid_number, '青森県八戸市堤町');
ok($zip->set_number('0310052')->is_valid_number, '青森県八戸市本徒士町');
ok($zip->set_number('0310053')->is_valid_number, '青森県八戸市徒士町');
ok($zip->set_number('0310054')->is_valid_number, '青森県八戸市稲荷町');
ok($zip->set_number('0310055')->is_valid_number, '青森県八戸市荒町');
ok($zip->set_number('0310056')->is_valid_number, '青森県八戸市新荒町');
ok($zip->set_number('0310057')->is_valid_number, '青森県八戸市上徒士町');
ok($zip->set_number('0310058')->is_valid_number, '青森県八戸市上組町');
ok($zip->set_number('0310071')->is_valid_number, '青森県八戸市沼館');
ok($zip->set_number('0310072')->is_valid_number, '青森県八戸市城下');
ok($zip->set_number('0310073')->is_valid_number, '青森県八戸市売市');
ok($zip->set_number('0310074')->is_valid_number, '青森県八戸市馬場町');
ok($zip->set_number('0310075')->is_valid_number, '青森県八戸市内丸');
ok($zip->set_number('0310076')->is_valid_number, '青森県八戸市堀端町');
ok($zip->set_number('0310077')->is_valid_number, '青森県八戸市長根');
ok($zip->set_number('0310081')->is_valid_number, '青森県八戸市柏崎');
ok($zip->set_number('0310082')->is_valid_number, '青森県八戸市常海町');
ok($zip->set_number('0310083')->is_valid_number, '青森県八戸市窪町');
ok($zip->set_number('0310084')->is_valid_number, '青森県八戸市十八日町');
ok($zip->set_number('0310085')->is_valid_number, '青森県八戸市十一日町');
ok($zip->set_number('0310086')->is_valid_number, '青森県八戸市八日町');
ok($zip->set_number('0310087')->is_valid_number, '青森県八戸市朔日町');
ok($zip->set_number('0310088')->is_valid_number, '青森県八戸市岩泉町');
ok($zip->set_number('0310089')->is_valid_number, '青森県八戸市長横町');
ok($zip->set_number('0310111')->is_valid_number, '青森県八戸市南郷市野沢');
ok($zip->set_number('0310112')->is_valid_number, '青森県八戸市南郷大森');
ok($zip->set_number('0310113')->is_valid_number, '青森県八戸市南郷泉清水');
ok($zip->set_number('0310114')->is_valid_number, '青森県八戸市南郷中野');
ok($zip->set_number('0310115')->is_valid_number, '青森県八戸市南郷泥障作');
ok($zip->set_number('0310201')->is_valid_number, '青森県八戸市南郷頃巻沢');
ok($zip->set_number('0310202')->is_valid_number, '青森県八戸市南郷島守');
ok($zip->set_number('0310801')->is_valid_number, '青森県八戸市江陽');
ok($zip->set_number('0310802')->is_valid_number, '青森県八戸市小中野');
ok($zip->set_number('0310803')->is_valid_number, '青森県八戸市諏訪');
ok($zip->set_number('0310804')->is_valid_number, '青森県八戸市青葉');
ok($zip->set_number('0310811')->is_valid_number, '青森県八戸市新湊');
ok($zip->set_number('0310812')->is_valid_number, '青森県八戸市湊町');
ok($zip->set_number('0310813')->is_valid_number, '青森県八戸市新井田');
ok($zip->set_number('0310814')->is_valid_number, '青森県八戸市妙');
ok($zip->set_number('0310815')->is_valid_number, '青森県八戸市松館');
ok($zip->set_number('0310816')->is_valid_number, '青森県八戸市新井田西');
ok($zip->set_number('0310821')->is_valid_number, '青森県八戸市白銀');
ok($zip->set_number('0310822')->is_valid_number, '青森県八戸市白銀町');
ok($zip->set_number('0310823')->is_valid_number, '青森県八戸市湊高台');
ok($zip->set_number('0310824')->is_valid_number, '青森県八戸市旭ケ丘');
ok($zip->set_number('0310831')->is_valid_number, '青森県八戸市築港街');
ok($zip->set_number('0310832')->is_valid_number, '青森県八戸市白銀台');
ok($zip->set_number('0310833')->is_valid_number, '青森県八戸市大久保');
ok($zip->set_number('0310834')->is_valid_number, '青森県八戸市桜ケ丘');
ok($zip->set_number('0310841')->is_valid_number, '青森県八戸市鮫町');
ok($zip->set_number('0310842')->is_valid_number, '青森県八戸市岬台');
ok($zip->set_number('0310843')->is_valid_number, '青森県八戸市金浜');
ok($zip->set_number('0310844')->is_valid_number, '青森県八戸市美保野');
ok($zip->set_number('0330000')->is_valid_number, '青森県三沢市以下に掲載がない場合');
ok($zip->set_number('0330001')->is_valid_number, '青森県三沢市中央町');
ok($zip->set_number('0330011')->is_valid_number, '青森県三沢市幸町');
ok($zip->set_number('0330012')->is_valid_number, '青森県三沢市平畑');
ok($zip->set_number('0330021')->is_valid_number, '青森県三沢市岡三沢');
ok($zip->set_number('0330022')->is_valid_number, '青森県三沢市三沢');
ok($zip->set_number('0330023')->is_valid_number, '青森県三沢市下久保');
ok($zip->set_number('0330024')->is_valid_number, '青森県三沢市東岡三沢');
ok($zip->set_number('0330031')->is_valid_number, '青森県三沢市桜町');
ok($zip->set_number('0330032')->is_valid_number, '青森県三沢市緑町');
ok($zip->set_number('0330033')->is_valid_number, '青森県三沢市美野原');
ok($zip->set_number('0330034')->is_valid_number, '青森県三沢市東町');
ok($zip->set_number('0330035')->is_valid_number, '青森県三沢市松原町');
ok($zip->set_number('0330036')->is_valid_number, '青森県三沢市南町');
ok($zip->set_number('0330037')->is_valid_number, '青森県三沢市松園町');
ok($zip->set_number('0330041')->is_valid_number, '青森県三沢市大町');
ok($zip->set_number('0330042')->is_valid_number, '青森県三沢市栄町');
ok($zip->set_number('0330043')->is_valid_number, '青森県三沢市千代田町');
ok($zip->set_number('0330044')->is_valid_number, '青森県三沢市古間木山');
ok($zip->set_number('0330045')->is_valid_number, '青森県三沢市薬師町');
ok($zip->set_number('0330051')->is_valid_number, '青森県三沢市古間木');
ok($zip->set_number('0330052')->is_valid_number, '青森県三沢市本町');
ok($zip->set_number('0330053')->is_valid_number, '青森県三沢市春日台');
ok($zip->set_number('0330061')->is_valid_number, '青森県三沢市花園町');
ok($zip->set_number('0330062')->is_valid_number, '青森県三沢市新町');
ok($zip->set_number('0330063')->is_valid_number, '青森県三沢市上久保');
ok($zip->set_number('0330071')->is_valid_number, '青森県上北郡六戸町犬落瀬(内金矢、内山、岡沼、金沢、金矢、上淋代、木越、権現沢、');
ok($zip->set_number('0330071')->is_valid_number, '青森県上北郡六戸町四木、七百、下久保「174を除く」、下淋代、高森、通目木、坪毛沢「2');
ok($zip->set_number('0330071')->is_valid_number, '青森県上北郡六戸町5、637、641、643、647を除く」、中屋敷、沼久保、根古橋、堀切');
ok($zip->set_number('0330071')->is_valid_number, '青森県上北郡六戸町沢、南平、柳沢、大曲)');
ok($zip->set_number('0330072')->is_valid_number, '青森県上北郡六戸町折茂(今熊「213~234、240、247、262、266、27');
ok($zip->set_number('0330072')->is_valid_number, '青森県上北郡六戸町5、277、280、295、1199、1206、1504を除く」、');
ok($zip->set_number('0330072')->is_valid_number, '青森県上北郡六戸町大原、沖山、上折茂「1-13、71-192を除く」)');
ok($zip->set_number('0330073')->is_valid_number, '青森県上北郡六戸町金矢');
ok($zip->set_number('0330074')->is_valid_number, '青森県上北郡六戸町小松ケ丘');
ok($zip->set_number('0330101')->is_valid_number, '青森県三沢市天ケ森');
ok($zip->set_number('0330102')->is_valid_number, '青森県三沢市砂森');
ok($zip->set_number('0330103')->is_valid_number, '青森県三沢市塩釜');
ok($zip->set_number('0330104')->is_valid_number, '青森県三沢市織笠');
ok($zip->set_number('0330105')->is_valid_number, '青森県三沢市新森');
ok($zip->set_number('0330111')->is_valid_number, '青森県三沢市六川目');
ok($zip->set_number('0330112')->is_valid_number, '青森県三沢市細谷');
ok($zip->set_number('0330113')->is_valid_number, '青森県三沢市淋代');
ok($zip->set_number('0330123')->is_valid_number, '青森県三沢市堀口');
ok($zip->set_number('0330131')->is_valid_number, '青森県三沢市五川目');
ok($zip->set_number('0330132')->is_valid_number, '青森県三沢市四川目');
ok($zip->set_number('0330133')->is_valid_number, '青森県三沢市鹿中');
ok($zip->set_number('0330134')->is_valid_number, '青森県三沢市大津');
ok($zip->set_number('0330141')->is_valid_number, '青森県三沢市港町');
ok($zip->set_number('0330142')->is_valid_number, '青森県三沢市三川目');
ok($zip->set_number('0330143')->is_valid_number, '青森県三沢市前平');
ok($zip->set_number('0330151')->is_valid_number, '青森県三沢市南山');
ok($zip->set_number('0330152')->is_valid_number, '青森県三沢市深谷');
ok($zip->set_number('0330153')->is_valid_number, '青森県三沢市泉町');
ok($zip->set_number('0330154')->is_valid_number, '青森県三沢市日の出');
ok($zip->set_number('0330155')->is_valid_number, '青森県三沢市さつきヶ丘');
ok($zip->set_number('0330161')->is_valid_number, '青森県三沢市八幡');
ok($zip->set_number('0330162')->is_valid_number, '青森県三沢市越下');
ok($zip->set_number('0330163')->is_valid_number, '青森県三沢市富崎');
ok($zip->set_number('0330164')->is_valid_number, '青森県三沢市谷地頭');
ok($zip->set_number('0330165')->is_valid_number, '青森県三沢市高野沢');
ok($zip->set_number('0330166')->is_valid_number, '青森県三沢市朝日');
ok($zip->set_number('0330167')->is_valid_number, '青森県三沢市根井');
ok($zip->set_number('0340000')->is_valid_number, '青森県十和田市以下に掲載がない場合');
ok($zip->set_number('0340001')->is_valid_number, '青森県十和田市三本木');
ok($zip->set_number('0340002')->is_valid_number, '青森県十和田市元町西');
ok($zip->set_number('0340003')->is_valid_number, '青森県十和田市元町東');
ok($zip->set_number('0340004')->is_valid_number, '青森県十和田市ひがしの');
ok($zip->set_number('0340005')->is_valid_number, '青森県十和田市一本木沢');
ok($zip->set_number('0340011')->is_valid_number, '青森県十和田市稲生町');
ok($zip->set_number('0340012')->is_valid_number, '青森県十和田市東一番町');
ok($zip->set_number('0340013')->is_valid_number, '青森県十和田市東十一番町');
ok($zip->set_number('0340014')->is_valid_number, '青森県十和田市東二十一番町');
ok($zip->set_number('0340015')->is_valid_number, '青森県十和田市東二十二番町');
ok($zip->set_number('0340016')->is_valid_number, '青森県十和田市東十二番町');
ok($zip->set_number('0340017')->is_valid_number, '青森県十和田市東二番町');
ok($zip->set_number('0340021')->is_valid_number, '青森県十和田市東二十三番町');
ok($zip->set_number('0340022')->is_valid_number, '青森県十和田市東二十四番町');
ok($zip->set_number('0340023')->is_valid_number, '青森県十和田市東十三番町');
ok($zip->set_number('0340024')->is_valid_number, '青森県十和田市東十四番町');
ok($zip->set_number('0340031')->is_valid_number, '青森県十和田市東三番町');
ok($zip->set_number('0340032')->is_valid_number, '青森県十和田市東四番町');
ok($zip->set_number('0340033')->is_valid_number, '青森県十和田市東五番町');
ok($zip->set_number('0340034')->is_valid_number, '青森県十和田市東十五番町');
ok($zip->set_number('0340035')->is_valid_number, '青森県十和田市東十六番町');
ok($zip->set_number('0340036')->is_valid_number, '青森県十和田市東六番町');
ok($zip->set_number('0340037')->is_valid_number, '青森県十和田市穂並町');
ok($zip->set_number('0340038')->is_valid_number, '青森県十和田市西六番町');
ok($zip->set_number('0340041')->is_valid_number, '青森県十和田市相坂');
ok($zip->set_number('0340051')->is_valid_number, '青森県十和田市伝法寺');
ok($zip->set_number('0340052')->is_valid_number, '青森県十和田市藤島');
ok($zip->set_number('0340061')->is_valid_number, '青森県十和田市切田');
ok($zip->set_number('0340071')->is_valid_number, '青森県十和田市赤沼');
ok($zip->set_number('0340081')->is_valid_number, '青森県十和田市西十三番町');
ok($zip->set_number('0340082')->is_valid_number, '青森県十和田市西二番町');
ok($zip->set_number('0340083')->is_valid_number, '青森県十和田市西三番町');
ok($zip->set_number('0340084')->is_valid_number, '青森県十和田市西四番町');
ok($zip->set_number('0340085')->is_valid_number, '青森県十和田市西五番町');
ok($zip->set_number('0340086')->is_valid_number, '青森県十和田市西十六番町');
ok($zip->set_number('0340087')->is_valid_number, '青森県十和田市西十五番町');
ok($zip->set_number('0340088')->is_valid_number, '青森県十和田市西十四番町');
ok($zip->set_number('0340089')->is_valid_number, '青森県十和田市西二十三番町');
ok($zip->set_number('0340091')->is_valid_number, '青森県十和田市西十一番町');
ok($zip->set_number('0340092')->is_valid_number, '青森県十和田市西一番町');
ok($zip->set_number('0340093')->is_valid_number, '青森県十和田市西十二番町');
ok($zip->set_number('0340094')->is_valid_number, '青森県十和田市西二十二番町');
ok($zip->set_number('0340095')->is_valid_number, '青森県十和田市西二十一番町');
ok($zip->set_number('0340101')->is_valid_number, '青森県十和田市馬洗場');
ok($zip->set_number('0340102')->is_valid_number, '青森県十和田市大沢田');
ok($zip->set_number('0340103')->is_valid_number, '青森県十和田市立崎');
ok($zip->set_number('0340104')->is_valid_number, '青森県十和田市豊ケ岡');
ok($zip->set_number('0340105')->is_valid_number, '青森県十和田市八斗沢');
ok($zip->set_number('0340106')->is_valid_number, '青森県十和田市深持');
ok($zip->set_number('0340107')->is_valid_number, '青森県十和田市洞内');
ok($zip->set_number('0340211')->is_valid_number, '青森県十和田市大不動');
ok($zip->set_number('0340212')->is_valid_number, '青森県十和田市米田');
ok($zip->set_number('0340213')->is_valid_number, '青森県十和田市滝沢');
ok($zip->set_number('0340301')->is_valid_number, '青森県十和田市奥瀬(その他)');
ok($zip->set_number('0340302')->is_valid_number, '青森県十和田市沢田');
ok($zip->set_number('0340303')->is_valid_number, '青森県十和田市法量');
ok($zip->set_number('0350000')->is_valid_number, '青森県むつ市以下に掲載がない場合');
ok($zip->set_number('0350000')->is_valid_number, '青森県下北郡東通村以下に掲載がない場合');
ok($zip->set_number('0350001')->is_valid_number, '青森県下北郡東通村大利');
ok($zip->set_number('0350002')->is_valid_number, '青森県下北郡東通村目名');
ok($zip->set_number('0350003')->is_valid_number, '青森県下北郡東通村野牛(稲崎平302番地・315番地、トクサ沢)');
ok($zip->set_number('0350004')->is_valid_number, '青森県下北郡東通村蒲野沢(その他)');
ok($zip->set_number('0350005')->is_valid_number, '青森県下北郡東通村田屋');
ok($zip->set_number('0350011')->is_valid_number, '青森県むつ市奥内');
ok($zip->set_number('0350012')->is_valid_number, '青森県むつ市中野沢');
ok($zip->set_number('0350021')->is_valid_number, '青森県むつ市田名部');
ok($zip->set_number('0350022')->is_valid_number, '青森県むつ市関根');
ok($zip->set_number('0350031')->is_valid_number, '青森県むつ市柳町');
ok($zip->set_number('0350032')->is_valid_number, '青森県むつ市上川町');
ok($zip->set_number('0350033')->is_valid_number, '青森県むつ市横迎町');
ok($zip->set_number('0350034')->is_valid_number, '青森県むつ市田名部町');
ok($zip->set_number('0350035')->is_valid_number, '青森県むつ市本町');
ok($zip->set_number('0350036')->is_valid_number, '青森県むつ市栗山町');
ok($zip->set_number('0350041')->is_valid_number, '青森県むつ市金曲');
ok($zip->set_number('0350042')->is_valid_number, '青森県むつ市大曲');
ok($zip->set_number('0350043')->is_valid_number, '青森県むつ市南赤川町');
ok($zip->set_number('0350044')->is_valid_number, '青森県むつ市赤川町');
ok($zip->set_number('0350045')->is_valid_number, '青森県むつ市松原町');
ok($zip->set_number('0350046')->is_valid_number, '青森県むつ市南町');
ok($zip->set_number('0350051')->is_valid_number, '青森県むつ市新町');
ok($zip->set_number('0350052')->is_valid_number, '青森県むつ市昭和町');
ok($zip->set_number('0350053')->is_valid_number, '青森県むつ市緑町');
ok($zip->set_number('0350054')->is_valid_number, '青森県むつ市海老川町');
ok($zip->set_number('0350055')->is_valid_number, '青森県むつ市苫生町');
ok($zip->set_number('0350061')->is_valid_number, '青森県むつ市下北町');
ok($zip->set_number('0350062')->is_valid_number, '青森県むつ市仲町');
ok($zip->set_number('0350063')->is_valid_number, '青森県むつ市若松町');
ok($zip->set_number('0350064')->is_valid_number, '青森県むつ市港町');
ok($zip->set_number('0350065')->is_valid_number, '青森県むつ市松山町');
ok($zip->set_number('0350066')->is_valid_number, '青森県むつ市緑ヶ丘');
ok($zip->set_number('0350067')->is_valid_number, '青森県むつ市十二林');
ok($zip->set_number('0350068')->is_valid_number, '青森県むつ市美里町');
ok($zip->set_number('0350071')->is_valid_number, '青森県むつ市小川町');
ok($zip->set_number('0350072')->is_valid_number, '青森県むつ市金谷');
ok($zip->set_number('0350073')->is_valid_number, '青森県むつ市中央');
ok($zip->set_number('0350074')->is_valid_number, '青森県むつ市大平');
ok($zip->set_number('0350075')->is_valid_number, '青森県むつ市真砂町');
ok($zip->set_number('0350076')->is_valid_number, '青森県むつ市旭町');
ok($zip->set_number('0350077')->is_valid_number, '青森県むつ市山田町');
ok($zip->set_number('0350078')->is_valid_number, '青森県むつ市松森町');
ok($zip->set_number('0350079')->is_valid_number, '青森県むつ市荒川町');
ok($zip->set_number('0350081')->is_valid_number, '青森県むつ市並川町');
ok($zip->set_number('0350082')->is_valid_number, '青森県むつ市文京町');
ok($zip->set_number('0350083')->is_valid_number, '青森県むつ市大平町');
ok($zip->set_number('0350084')->is_valid_number, '青森県むつ市大湊新町');
ok($zip->set_number('0350085')->is_valid_number, '青森県むつ市大湊浜町');
ok($zip->set_number('0350086')->is_valid_number, '青森県むつ市大湊上町');
ok($zip->set_number('0350091')->is_valid_number, '青森県むつ市川守町');
ok($zip->set_number('0350092')->is_valid_number, '青森県むつ市宇田町');
ok($zip->set_number('0350093')->is_valid_number, '青森県むつ市大湊町');
ok($zip->set_number('0350094')->is_valid_number, '青森県むつ市桜木町');
ok($zip->set_number('0350095')->is_valid_number, '青森県むつ市城ケ沢');
ok($zip->set_number('0350096')->is_valid_number, '青森県むつ市大湊');
ok($zip->set_number('0350103')->is_valid_number, '青森県下北郡東通村野牛(その他)');
ok($zip->set_number('0350104')->is_valid_number, '青森県下北郡東通村蒲野沢(稲崎、浜の平)');
ok($zip->set_number('0350111')->is_valid_number, '青森県下北郡東通村尻屋');
ok($zip->set_number('0350112')->is_valid_number, '青森県下北郡東通村尻労');
ok($zip->set_number('0350113')->is_valid_number, '青森県下北郡東通村岩屋');
ok($zip->set_number('0360000')->is_valid_number, '青森県弘前市以下に掲載がない場合');
ok($zip->set_number('0360100')->is_valid_number, '青森県平川市以下に掲載がない場合');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺一滝本');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺一村井');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺一早稲田');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺稲田');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺稲村');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺川原田');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺三滝本');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺三村井');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺三早稲田');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺釈迦口');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺白山');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺種元');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺西稲村');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺二滝本');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺二村井');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺二早稲田');
ok($zip->set_number('0360101')->is_valid_number, '青森県平川市大光寺四滝本');
ok($zip->set_number('0360102')->is_valid_number, '青森県平川市光城');
ok($zip->set_number('0360103')->is_valid_number, '青森県平川市本町北柳田');
ok($zip->set_number('0360103')->is_valid_number, '青森県平川市本町富岡');
ok($zip->set_number('0360103')->is_valid_number, '青森県平川市本町西宮');
ok($zip->set_number('0360103')->is_valid_number, '青森県平川市本町平野');
ok($zip->set_number('0360103')->is_valid_number, '青森県平川市本町南柳田');
ok($zip->set_number('0360103')->is_valid_number, '青森県平川市本町村元');
ok($zip->set_number('0360104')->is_valid_number, '青森県平川市柏木町東田');
ok($zip->set_number('0360104')->is_valid_number, '青森県平川市柏木町広田');
ok($zip->set_number('0360104')->is_valid_number, '青森県平川市柏木町藤山');
ok($zip->set_number('0360104')->is_valid_number, '青森県平川市柏木町柳田');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森上田川');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森上平田');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森上松岡');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森下田川');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森下平田');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森下松岡');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森種取');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森中松岡');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森福田');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森松川');
ok($zip->set_number('0360111')->is_valid_number, '青森県平川市小和森松村');
ok($zip->set_number('0360112')->is_valid_number, '青森県平川市荒田上駒田');
ok($zip->set_number('0360112')->is_valid_number, '青森県平川市荒田北稲村');
ok($zip->set_number('0360112')->is_valid_number, '青森県平川市荒田北岡部');
ok($zip->set_number('0360112')->is_valid_number, '青森県平川市荒田下駒田');
ok($zip->set_number('0360112')->is_valid_number, '青森県平川市荒田南稲村');
ok($zip->set_number('0360112')->is_valid_number, '青森県平川市荒田南岡部');
ok($zip->set_number('0360113')->is_valid_number, '青森県平川市平田森稲村');
ok($zip->set_number('0360113')->is_valid_number, '青森県平川市平田森上宮本');
ok($zip->set_number('0360113')->is_valid_number, '青森県平川市平田森下宮本');
ok($zip->set_number('0360113')->is_valid_number, '青森県平川市平田森前田');
ok($zip->set_number('0360113')->is_valid_number, '青森県平川市平田森若松');
ok($zip->set_number('0360114')->is_valid_number, '青森県平川市町居稲村');
ok($zip->set_number('0360114')->is_valid_number, '青森県平川市町居稲元');
ok($zip->set_number('0360114')->is_valid_number, '青森県平川市町居西田');
ok($zip->set_number('0360114')->is_valid_number, '青森県平川市町居南田');
ok($zip->set_number('0360114')->is_valid_number, '青森県平川市町居山下');
ok($zip->set_number('0360114')->is_valid_number, '青森県平川市町居山元');
ok($zip->set_number('0360114')->is_valid_number, '青森県平川市町居横山');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館後野');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館柏崎');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館駒泊');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館島村');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館野木和');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館東山');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館藤巻');
ok($zip->set_number('0360115')->is_valid_number, '青森県平川市新館藤山');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋稲村');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋長田');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋栄館');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋滝の沢');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋富山');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋平岡');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋平野');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋福嶋');
ok($zip->set_number('0360121')->is_valid_number, '青森県平川市新屋山下');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎浅井');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎稲元');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎岡田');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎川合');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎木戸口');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎里見');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎沢部');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎平山');
ok($zip->set_number('0360122')->is_valid_number, '青森県平川市尾崎安田');
ok($zip->set_number('0360131')->is_valid_number, '青森県平川市広船広沢');
ok($zip->set_number('0360131')->is_valid_number, '青森県平川市広船福田');
ok($zip->set_number('0360131')->is_valid_number, '青森県平川市広船山下');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹芦毛沢');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹阿蘇獄');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹井沢');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹苺原');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹川原田');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹小金森');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹小松原');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹高田');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹平山');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹堀合');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹水上');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹向川原田');
ok($zip->set_number('0360132')->is_valid_number, '青森県平川市唐竹薬師沢');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館長田');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館沢田');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館高田');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館永田');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館西田');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館比山館');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館宮崎');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館向野');
ok($zip->set_number('0360141')->is_valid_number, '青森県平川市沖館和田');
ok($zip->set_number('0360142')->is_valid_number, '青森県平川市高畑熊沢');
ok($zip->set_number('0360142')->is_valid_number, '青森県平川市高畑高田');
ok($zip->set_number('0360142')->is_valid_number, '青森県平川市高畑前田');
ok($zip->set_number('0360143')->is_valid_number, '青森県平川市吹上高田');
ok($zip->set_number('0360143')->is_valid_number, '青森県平川市吹上平岡');
ok($zip->set_number('0360143')->is_valid_number, '青森県平川市吹上安田');
ok($zip->set_number('0360144')->is_valid_number, '青森県平川市原田稲元');
ok($zip->set_number('0360144')->is_valid_number, '青森県平川市原田今井');
ok($zip->set_number('0360144')->is_valid_number, '青森県平川市原田沢田');
ok($zip->set_number('0360144')->is_valid_number, '青森県平川市原田村元');
ok($zip->set_number('0360145')->is_valid_number, '青森県平川市岩館長田');
ok($zip->set_number('0360145')->is_valid_number, '青森県平川市岩館下り松');
ok($zip->set_number('0360145')->is_valid_number, '青森県平川市岩館藤巻');
ok($zip->set_number('0360145')->is_valid_number, '青森県平川市岩館村元');
ok($zip->set_number('0360145')->is_valid_number, '青森県平川市岩館山の井');
ok($zip->set_number('0360146')->is_valid_number, '青森県平川市大坊竹内');
ok($zip->set_number('0360146')->is_valid_number, '青森県平川市大坊竹原');
ok($zip->set_number('0360146')->is_valid_number, '青森県平川市大坊福田');
ok($zip->set_number('0360146')->is_valid_number, '青森県平川市大坊前田');
ok($zip->set_number('0360151')->is_valid_number, '青森県平川市石郷沖中');
ok($zip->set_number('0360151')->is_valid_number, '青森県平川市石郷村元');
ok($zip->set_number('0360151')->is_valid_number, '青森県平川市石郷柳田');
ok($zip->set_number('0360152')->is_valid_number, '青森県平川市石畑岡元');
ok($zip->set_number('0360153')->is_valid_number, '青森県平川市小杉稲村');
ok($zip->set_number('0360153')->is_valid_number, '青森県平川市小杉扇田');
ok($zip->set_number('0360153')->is_valid_number, '青森県平川市小杉川崎');
ok($zip->set_number('0360153')->is_valid_number, '青森県平川市小杉竹内');
ok($zip->set_number('0360153')->is_valid_number, '青森県平川市小杉西田');
ok($zip->set_number('0360154')->is_valid_number, '青森県平川市四ツ屋亀田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田稲村');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田中前田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田西川原田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田西和田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田東稲村');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田東前田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田東和田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田前田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田南川原田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田元川原田');
ok($zip->set_number('0360155')->is_valid_number, '青森県平川市館田柳原');
ok($zip->set_number('0360161')->is_valid_number, '青森県平川市杉館滝元');
ok($zip->set_number('0360161')->is_valid_number, '青森県平川市杉館松橋');
ok($zip->set_number('0360161')->is_valid_number, '青森県平川市杉館宮元');
ok($zip->set_number('0360162')->is_valid_number, '青森県平川市館山板橋');
ok($zip->set_number('0360162')->is_valid_number, '青森県平川市館山上扇田');
ok($zip->set_number('0360162')->is_valid_number, '青森県平川市館山上亀岡');
ok($zip->set_number('0360162')->is_valid_number, '青森県平川市館山川合');
ok($zip->set_number('0360162')->is_valid_number, '青森県平川市館山下扇田');
ok($zip->set_number('0360162')->is_valid_number, '青森県平川市館山下亀岡');
ok($zip->set_number('0360162')->is_valid_number, '青森県平川市館山前田');
ok($zip->set_number('0360163')->is_valid_number, '青森県平川市苗生松一本柳');
ok($zip->set_number('0360163')->is_valid_number, '青森県平川市苗生松上東田');
ok($zip->set_number('0360163')->is_valid_number, '青森県平川市苗生松川崎');
ok($zip->set_number('0360163')->is_valid_number, '青森県平川市苗生松川原田');
ok($zip->set_number('0360163')->is_valid_number, '青森県平川市苗生松下東田');
ok($zip->set_number('0360163')->is_valid_number, '青森県平川市苗生松元東田');
ok($zip->set_number('0360164')->is_valid_number, '青森県平川市松崎亀井');
ok($zip->set_number('0360164')->is_valid_number, '青森県平川市松崎西田');
ok($zip->set_number('0360165')->is_valid_number, '青森県平川市松館浅井');
ok($zip->set_number('0360165')->is_valid_number, '青森県平川市松館井ノ上');
ok($zip->set_number('0360165')->is_valid_number, '青森県平川市松館西稲村');
ok($zip->set_number('0360165')->is_valid_number, '青森県平川市松館西川原田');
ok($zip->set_number('0360165')->is_valid_number, '青森県平川市松館東稲村');
ok($zip->set_number('0360165')->is_valid_number, '青森県平川市松館東川原田');
ok($zip->set_number('0360165')->is_valid_number, '青森県平川市松館松元');
ok($zip->set_number('0360171')->is_valid_number, '青森県平川市小国浅瀬石山');
ok($zip->set_number('0360171')->is_valid_number, '青森県平川市小国川辺');
ok($zip->set_number('0360171')->is_valid_number, '青森県平川市小国川原田');
ok($zip->set_number('0360171')->is_valid_number, '青森県平川市小国深沢');
ok($zip->set_number('0360171')->is_valid_number, '青森県平川市小国山下');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川浅瀬石山');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川一本木平');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川大川添');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川折戸');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川上の平');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川唐川平');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川葛川沢');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川葛川平');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川葛川出口');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川毛無森');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川砂子沢');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川田の沢口');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川長小股');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川平六沢上');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川平六村下');
ok($zip->set_number('0360172')->is_valid_number, '青森県平川市葛川家岸');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明浅瀬石山');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明上井戸');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明誉田邸');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明坂本');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明滝の森');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明滝候沢');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明津根川森');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明温川沢');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明温川森');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明螢沢');
ok($zip->set_number('0360173')->is_valid_number, '青森県平川市切明山下');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平上安原');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平上山崎');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平北豊田');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平下安原');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平西豊田');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平西山崎');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平西和田');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平東豊田');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平東和田');
ok($zip->set_number('0360201')->is_valid_number, '青森県平川市李平南豊田');
ok($zip->set_number('0360202')->is_valid_number, '青森県平川市金屋上松元');
ok($zip->set_number('0360202')->is_valid_number, '青森県平川市金屋上早稲田');
ok($zip->set_number('0360202')->is_valid_number, '青森県平川市金屋下松元');
ok($zip->set_number('0360202')->is_valid_number, '青森県平川市金屋下早稲田');
ok($zip->set_number('0360202')->is_valid_number, '青森県平川市金屋中松元');
ok($zip->set_number('0360202')->is_valid_number, '青森県平川市金屋中早稲田');
ok($zip->set_number('0360202')->is_valid_number, '青森県平川市金屋西松元');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中北林元');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中北原');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中北細田');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中北村井');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中中村井');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中西林元');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中西原');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中東林元');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中南林元');
ok($zip->set_number('0360203')->is_valid_number, '青森県平川市南田中村内');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木岡崎');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木岡田');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木岡部');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木豊岡');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木豊田');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木原田');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木原富');
ok($zip->set_number('0360211')->is_valid_number, '青森県平川市高木松元');
ok($zip->set_number('0360212')->is_valid_number, '青森県平川市尾上栄松');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町上沢田');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町北鶉野');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町下沢田');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町田川');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町松居');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町松下');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町松久');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町道ノ下');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町南鶉野');
ok($zip->set_number('0360213')->is_valid_number, '青森県平川市新屋町村元');
ok($zip->set_number('0360221')->is_valid_number, '青森県平川市中佐渡石田');
ok($zip->set_number('0360221')->is_valid_number, '青森県平川市中佐渡鎌田');
ok($zip->set_number('0360221')->is_valid_number, '青森県平川市中佐渡前田');
ok($zip->set_number('0360221')->is_valid_number, '青森県平川市中佐渡南田');
ok($zip->set_number('0360221')->is_valid_number, '青森県平川市中佐渡村元');
ok($zip->set_number('0360222')->is_valid_number, '青森県平川市長田沼田');
ok($zip->set_number('0360222')->is_valid_number, '青森県平川市長田野田');
ok($zip->set_number('0360222')->is_valid_number, '青森県平川市長田村下');
ok($zip->set_number('0360222')->is_valid_number, '青森県平川市長田元村');
ok($zip->set_number('0360223')->is_valid_number, '青森県平川市西野曽江川崎');
ok($zip->set_number('0360223')->is_valid_number, '青森県平川市西野曽江橋元');
ok($zip->set_number('0360223')->is_valid_number, '青森県平川市西野曽江広田');
ok($zip->set_number('0360231')->is_valid_number, '青森県平川市新山岡部');
ok($zip->set_number('0360231')->is_valid_number, '青森県平川市新山松橋');
ok($zip->set_number('0360231')->is_valid_number, '青森県平川市新山村元');
ok($zip->set_number('0360231')->is_valid_number, '青森県平川市新山柳田');
ok($zip->set_number('0360231')->is_valid_number, '青森県平川市新山早稲田');
ok($zip->set_number('0360232')->is_valid_number, '青森県平川市蒲田一本松');
ok($zip->set_number('0360232')->is_valid_number, '青森県平川市蒲田玉田');
ok($zip->set_number('0360232')->is_valid_number, '青森県平川市蒲田豊田');
ok($zip->set_number('0360232')->is_valid_number, '青森県平川市蒲田豊富');
ok($zip->set_number('0360232')->is_valid_number, '青森県平川市蒲田三原');
ok($zip->set_number('0360232')->is_valid_number, '青森県平川市蒲田元宮');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼一本柳');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼河原田');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼下川原');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼下袋');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼李田');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼高田');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼塚越');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼樋田');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼富田');
ok($zip->set_number('0360233')->is_valid_number, '青森県平川市日沼富岳');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎高野');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎高原');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎本林');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎松枝');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎松橋');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎宮田');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎宮本');
ok($zip->set_number('0360241')->is_valid_number, '青森県平川市八幡崎本宮');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀浅井');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀浅田');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀池上');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀池田');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀石林');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀上岡');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀上川');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀下岡');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀下川');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀下野');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀遠林');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀富岡');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀平塚');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀松枝');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀南田');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀南野');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀明堂');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀安岡');
ok($zip->set_number('0360242')->is_valid_number, '青森県平川市猿賀安田');
ok($zip->set_number('0360243')->is_valid_number, '青森県平川市原大野');
ok($zip->set_number('0360243')->is_valid_number, '青森県平川市原上原');
ok($zip->set_number('0360243')->is_valid_number, '青森県平川市原北原');
ok($zip->set_number('0360300')->is_valid_number, '青森県黒石市以下に掲載がない場合');
ok($zip->set_number('0360301')->is_valid_number, '青森県黒石市一番町');
ok($zip->set_number('0360302')->is_valid_number, '青森県黒石市油横丁');
ok($zip->set_number('0360303')->is_valid_number, '青森県黒石市株梗木横丁');
ok($zip->set_number('0360304')->is_valid_number, '青森県黒石市甲徳兵衛町');
ok($zip->set_number('0360305')->is_valid_number, '青森県黒石市乙徳兵衛町');
ok($zip->set_number('0360306')->is_valid_number, '青森県黒石市内町');
ok($zip->set_number('0360307')->is_valid_number, '青森県黒石市市ノ町');
ok($zip->set_number('0360308')->is_valid_number, '青森県黒石市寺小路');
ok($zip->set_number('0360311')->is_valid_number, '青森県黒石市吉乃町');
ok($zip->set_number('0360312')->is_valid_number, '青森県黒石市昭和町');
ok($zip->set_number('0360313')->is_valid_number, '青森県黒石市松葉町');
ok($zip->set_number('0360314')->is_valid_number, '青森県黒石市道北町');
ok($zip->set_number('0360315')->is_valid_number, '青森県黒石市寿町');
ok($zip->set_number('0360316')->is_valid_number, '青森県黒石市ぐみの木');
ok($zip->set_number('0360317')->is_valid_number, '青森県黒石市住吉町');
ok($zip->set_number('0360318')->is_valid_number, '青森県黒石市岩木町');
ok($zip->set_number('0360321')->is_valid_number, '青森県黒石市あけぼの町');
ok($zip->set_number('0360322')->is_valid_number, '青森県黒石市竹田町');
ok($zip->set_number('0360323')->is_valid_number, '青森県黒石市上十川');
ok($zip->set_number('0360324')->is_valid_number, '青森県黒石市東野添');
ok($zip->set_number('0360325')->is_valid_number, '青森県黒石市青山');
ok($zip->set_number('0360326')->is_valid_number, '青森県黒石市野添町');
ok($zip->set_number('0360331')->is_valid_number, '青森県黒石市八甲');
ok($zip->set_number('0360332')->is_valid_number, '青森県黒石市牡丹平');
ok($zip->set_number('0360333')->is_valid_number, '青森県黒石市柵ノ木');
ok($zip->set_number('0360334')->is_valid_number, '青森県黒石市東新町');
ok($zip->set_number('0360335')->is_valid_number, '青森県黒石市幸町');
ok($zip->set_number('0360336')->is_valid_number, '青森県黒石市桜木町');
ok($zip->set_number('0360337')->is_valid_number, '青森県黒石市角田');
ok($zip->set_number('0360338')->is_valid_number, '青森県黒石市春日町');
ok($zip->set_number('0360339')->is_valid_number, '青森県黒石市美原町');
ok($zip->set_number('0360341')->is_valid_number, '青森県黒石市豊岡');
ok($zip->set_number('0360342')->is_valid_number, '青森県黒石市石名坂');
ok($zip->set_number('0360343')->is_valid_number, '青森県黒石市浅瀬石');
ok($zip->set_number('0360344')->is_valid_number, '青森県黒石市高賀野');
ok($zip->set_number('0360345')->is_valid_number, '青森県黒石市中川');
ok($zip->set_number('0360351')->is_valid_number, '青森県黒石市黒石');
ok($zip->set_number('0360352')->is_valid_number, '青森県黒石市甲大工町');
ok($zip->set_number('0360353')->is_valid_number, '青森県黒石市乙大工町');
ok($zip->set_number('0360354')->is_valid_number, '青森県黒石市後大工町');
ok($zip->set_number('0360355')->is_valid_number, '青森県黒石市袋井');
ok($zip->set_number('0360356')->is_valid_number, '青森県黒石市ちとせ');
ok($zip->set_number('0360357')->is_valid_number, '青森県黒石市追子野木');
ok($zip->set_number('0360361')->is_valid_number, '青森県黒石市弥生町');
ok($zip->set_number('0360362')->is_valid_number, '青森県黒石市京町');
ok($zip->set_number('0360363')->is_valid_number, '青森県黒石市鍛治町');
ok($zip->set_number('0360364')->is_valid_number, '青森県黒石市山形町');
ok($zip->set_number('0360365')->is_valid_number, '青森県黒石市長崎');
ok($zip->set_number('0360366')->is_valid_number, '青森県黒石市浦町');
ok($zip->set_number('0360367')->is_valid_number, '青森県黒石市前町');
ok($zip->set_number('0360368')->is_valid_number, '青森県黒石市横町');
ok($zip->set_number('0360371')->is_valid_number, '青森県黒石市花園町');
ok($zip->set_number('0360372')->is_valid_number, '青森県黒石市錦町');
ok($zip->set_number('0360373')->is_valid_number, '青森県黒石市東町');
ok($zip->set_number('0360374')->is_valid_number, '青森県黒石市泉町');
ok($zip->set_number('0360375')->is_valid_number, '青森県黒石市若葉町');
ok($zip->set_number('0360376')->is_valid_number, '青森県黒石市旭町');
ok($zip->set_number('0360377')->is_valid_number, '青森県黒石市中町');
ok($zip->set_number('0360378')->is_valid_number, '青森県黒石市浜町');
ok($zip->set_number('0360381')->is_valid_number, '青森県黒石市株梗木');
ok($zip->set_number('0360382')->is_valid_number, '青森県黒石市作場町');
ok($zip->set_number('0360383')->is_valid_number, '青森県黒石市緑町');
ok($zip->set_number('0360384')->is_valid_number, '青森県黒石市大町');
ok($zip->set_number('0360385')->is_valid_number, '青森県黒石市大板町');
ok($zip->set_number('0360386')->is_valid_number, '青森県黒石市上町');
ok($zip->set_number('0360387')->is_valid_number, '青森県黒石市元町');
ok($zip->set_number('0360388')->is_valid_number, '青森県黒石市西ケ丘');
ok($zip->set_number('0360389')->is_valid_number, '青森県黒石市境松');
ok($zip->set_number('0360401')->is_valid_number, '青森県黒石市大川原');
ok($zip->set_number('0360402')->is_valid_number, '青森県黒石市沖浦');
ok($zip->set_number('0360403')->is_valid_number, '青森県黒石市二庄内');
ok($zip->set_number('0360404')->is_valid_number, '青森県黒石市板留');
ok($zip->set_number('0360405')->is_valid_number, '青森県黒石市南中野');
ok($zip->set_number('0360411')->is_valid_number, '青森県黒石市温湯');
ok($zip->set_number('0360412')->is_valid_number, '青森県黒石市袋');
ok($zip->set_number('0360413')->is_valid_number, '青森県黒石市花巻');
ok($zip->set_number('0360414')->is_valid_number, '青森県黒石市下山形');
ok($zip->set_number('0360415')->is_valid_number, '青森県黒石市上山形');
ok($zip->set_number('0360501')->is_valid_number, '青森県黒石市東馬場尻');
ok($zip->set_number('0360502')->is_valid_number, '青森県黒石市馬場尻北');
ok($zip->set_number('0360503')->is_valid_number, '青森県黒石市馬場尻下');
ok($zip->set_number('0360504')->is_valid_number, '青森県黒石市馬場尻東');
ok($zip->set_number('0360505')->is_valid_number, '青森県黒石市馬場尻南');
ok($zip->set_number('0360506')->is_valid_number, '青森県黒石市馬場尻西');
ok($zip->set_number('0360507')->is_valid_number, '青森県黒石市西馬場尻');
ok($zip->set_number('0360511')->is_valid_number, '青森県黒石市小屋敷');
ok($zip->set_number('0360512')->is_valid_number, '青森県黒石市小屋敷南');
ok($zip->set_number('0360513')->is_valid_number, '青森県黒石市小屋敷西');
ok($zip->set_number('0360514')->is_valid_number, '青森県黒石市富田');
ok($zip->set_number('0360515')->is_valid_number, '青森県黒石市富士見');
ok($zip->set_number('0360516')->is_valid_number, '青森県黒石市相野');
ok($zip->set_number('0360517')->is_valid_number, '青森県黒石市松原');
ok($zip->set_number('0360521')->is_valid_number, '青森県黒石市末広');
ok($zip->set_number('0360522')->is_valid_number, '青森県黒石市田中');
ok($zip->set_number('0360523')->is_valid_number, '青森県黒石市北田中');
ok($zip->set_number('0360524')->is_valid_number, '青森県黒石市緑ケ丘');
ok($zip->set_number('0360531')->is_valid_number, '青森県黒石市飛内');
ok($zip->set_number('0360532')->is_valid_number, '青森県黒石市飛内北');
ok($zip->set_number('0360533')->is_valid_number, '青森県黒石市二双子');
ok($zip->set_number('0360534')->is_valid_number, '青森県黒石市竹鼻');
ok($zip->set_number('0360535')->is_valid_number, '青森県黒石市高舘');
ok($zip->set_number('0360536')->is_valid_number, '青森県黒石市三島');
ok($zip->set_number('0360537')->is_valid_number, '青森県黒石市赤坂');
ok($zip->set_number('0360538')->is_valid_number, '青森県黒石市上目内澤');
ok($zip->set_number('0360539')->is_valid_number, '青森県黒石市下目内澤');
ok($zip->set_number('0360541')->is_valid_number, '青森県黒石市北美町');
ok($zip->set_number('0360542')->is_valid_number, '青森県黒石市野際');
ok($zip->set_number('0361201')->is_valid_number, '青森県弘前市十腰内');
ok($zip->set_number('0361202')->is_valid_number, '青森県弘前市十面沢');
ok($zip->set_number('0361203')->is_valid_number, '青森県弘前市大森');
ok($zip->set_number('0361204')->is_valid_number, '青森県弘前市貝沢');
ok($zip->set_number('0361205')->is_valid_number, '青森県弘前市鬼沢');
ok($zip->set_number('0361206')->is_valid_number, '青森県弘前市楢木');
ok($zip->set_number('0361301')->is_valid_number, '青森県弘前市鼻和');
ok($zip->set_number('0361302')->is_valid_number, '青森県弘前市愛宕');
ok($zip->set_number('0361303')->is_valid_number, '青森県弘前市葛原');
ok($zip->set_number('0361304')->is_valid_number, '青森県弘前市新岡');
ok($zip->set_number('0361311')->is_valid_number, '青森県弘前市横町');
ok($zip->set_number('0361312')->is_valid_number, '青森県弘前市高屋');
ok($zip->set_number('0361313')->is_valid_number, '青森県弘前市賀田');
ok($zip->set_number('0361314')->is_valid_number, '青森県弘前市八幡');
ok($zip->set_number('0361321')->is_valid_number, '青森県弘前市熊嶋');
ok($zip->set_number('0361322')->is_valid_number, '青森県弘前市駒越');
ok($zip->set_number('0361323')->is_valid_number, '青森県弘前市真土');
ok($zip->set_number('0361324')->is_valid_number, '青森県弘前市龍ノ口');
ok($zip->set_number('0361325')->is_valid_number, '青森県弘前市一町田');
ok($zip->set_number('0361331')->is_valid_number, '青森県弘前市五代');
ok($zip->set_number('0361332')->is_valid_number, '青森県弘前市兼平');
ok($zip->set_number('0361333')->is_valid_number, '青森県弘前市鳥井野');
ok($zip->set_number('0361334')->is_valid_number, '青森県弘前市如来瀬');
ok($zip->set_number('0361341')->is_valid_number, '青森県弘前市宮地');
ok($zip->set_number('0361342')->is_valid_number, '青森県弘前市新法師');
ok($zip->set_number('0361343')->is_valid_number, '青森県弘前市百沢');
ok($zip->set_number('0361344')->is_valid_number, '青森県弘前市高岡');
ok($zip->set_number('0361345')->is_valid_number, '青森県弘前市常盤野');
ok($zip->set_number('0361361')->is_valid_number, '青森県弘前市弥生');
ok($zip->set_number('0361400')->is_valid_number, '青森県中津軽郡西目屋村以下に掲載がない場合');
ok($zip->set_number('0361411')->is_valid_number, '青森県中津軽郡西目屋村田代');
ok($zip->set_number('0361412')->is_valid_number, '青森県中津軽郡西目屋村杉ケ沢');
ok($zip->set_number('0361413')->is_valid_number, '青森県中津軽郡西目屋村大秋');
ok($zip->set_number('0361414')->is_valid_number, '青森県中津軽郡西目屋村白沢');
ok($zip->set_number('0361415')->is_valid_number, '青森県中津軽郡西目屋村村市');
ok($zip->set_number('0361421')->is_valid_number, '青森県中津軽郡西目屋村藤川');
ok($zip->set_number('0361422')->is_valid_number, '青森県中津軽郡西目屋村居森平');
ok($zip->set_number('0361423')->is_valid_number, '青森県中津軽郡西目屋村砂子瀬');
ok($zip->set_number('0361424')->is_valid_number, '青森県中津軽郡西目屋村川原平');
ok($zip->set_number('0361431')->is_valid_number, '青森県弘前市高野');
ok($zip->set_number('0361432')->is_valid_number, '青森県弘前市館後');
ok($zip->set_number('0361433')->is_valid_number, '青森県弘前市国吉');
ok($zip->set_number('0361434')->is_valid_number, '青森県弘前市黒土');
ok($zip->set_number('0361435')->is_valid_number, '青森県弘前市吉川');
ok($zip->set_number('0361441')->is_valid_number, '青森県弘前市桜庭');
ok($zip->set_number('0361442')->is_valid_number, '青森県弘前市平山');
ok($zip->set_number('0361443')->is_valid_number, '青森県弘前市米ケ袋');
ok($zip->set_number('0361451')->is_valid_number, '青森県弘前市中野(その他)');
ok($zip->set_number('0361452')->is_valid_number, '青森県弘前市中畑');
ok($zip->set_number('0361453')->is_valid_number, '青森県弘前市番館');
ok($zip->set_number('0361501')->is_valid_number, '青森県弘前市湯口');
ok($zip->set_number('0361502')->is_valid_number, '青森県弘前市黒滝');
ok($zip->set_number('0361503')->is_valid_number, '青森県弘前市五所');
ok($zip->set_number('0361504')->is_valid_number, '青森県弘前市紙漉沢');
ok($zip->set_number('0361505')->is_valid_number, '青森県弘前市水木在家');
ok($zip->set_number('0361506')->is_valid_number, '青森県弘前市昴');
ok($zip->set_number('0361511')->is_valid_number, '青森県弘前市坂市');
ok($zip->set_number('0361512')->is_valid_number, '青森県弘前市藤沢');
ok($zip->set_number('0361513')->is_valid_number, '青森県弘前市大助');
ok($zip->set_number('0361514')->is_valid_number, '青森県弘前市沢田');
ok($zip->set_number('0361515')->is_valid_number, '青森県弘前市相馬');
ok($zip->set_number('0361516')->is_valid_number, '青森県弘前市藍内');
ok($zip->set_number('0368001')->is_valid_number, '青森県弘前市代官町');
ok($zip->set_number('0368002')->is_valid_number, '青森県弘前市駅前');
ok($zip->set_number('0368003')->is_valid_number, '青森県弘前市駅前町');
ok($zip->set_number('0368004')->is_valid_number, '青森県弘前市大町');
ok($zip->set_number('0368005')->is_valid_number, '青森県弘前市楮町');
ok($zip->set_number('0368006')->is_valid_number, '青森県弘前市南大町');
ok($zip->set_number('0368011')->is_valid_number, '青森県弘前市山下町');
ok($zip->set_number('0368012')->is_valid_number, '青森県弘前市北瓦ケ町');
ok($zip->set_number('0368013')->is_valid_number, '青森県弘前市上瓦ケ町');
ok($zip->set_number('0368014')->is_valid_number, '青森県弘前市南瓦ケ町');
ok($zip->set_number('0368015')->is_valid_number, '青森県弘前市中瓦ケ町');
ok($zip->set_number('0368016')->is_valid_number, '青森県弘前市坂本町');
ok($zip->set_number('0368017')->is_valid_number, '青森県弘前市西川岸町');
ok($zip->set_number('0368018')->is_valid_number, '青森県弘前市田代町');
ok($zip->set_number('0368021')->is_valid_number, '青森県弘前市和徳町');
ok($zip->set_number('0368022')->is_valid_number, '青森県弘前市萱町');
ok($zip->set_number('0368023')->is_valid_number, '青森県弘前市植田町');
ok($zip->set_number('0368024')->is_valid_number, '青森県弘前市緑町');
ok($zip->set_number('0368025')->is_valid_number, '青森県弘前市南柳町');
ok($zip->set_number('0368026')->is_valid_number, '青森県弘前市南横町');
ok($zip->set_number('0368031')->is_valid_number, '青森県弘前市北柳町');
ok($zip->set_number('0368032')->is_valid_number, '青森県弘前市徳田町');
ok($zip->set_number('0368033')->is_valid_number, '青森県弘前市徒町川端町');
ok($zip->set_number('0368034')->is_valid_number, '青森県弘前市徒町');
ok($zip->set_number('0368035')->is_valid_number, '青森県弘前市百石町');
ok($zip->set_number('0368036')->is_valid_number, '青森県弘前市鉄砲町');
ok($zip->set_number('0368041')->is_valid_number, '青森県弘前市俵元');
ok($zip->set_number('0368042')->is_valid_number, '青森県弘前市松ケ枝');
ok($zip->set_number('0368043')->is_valid_number, '青森県弘前市東和徳町');
ok($zip->set_number('0368044')->is_valid_number, '青森県弘前市茶畑町');
ok($zip->set_number('0368045')->is_valid_number, '青森県弘前市野田');
ok($zip->set_number('0368046')->is_valid_number, '青森県弘前市北横町');
ok($zip->set_number('0368051')->is_valid_number, '青森県弘前市宮川');
ok($zip->set_number('0368052')->is_valid_number, '青森県弘前市堅田');
ok($zip->set_number('0368053')->is_valid_number, '青森県弘前市和泉');
ok($zip->set_number('0368054')->is_valid_number, '青森県弘前市田町');
ok($zip->set_number('0368055')->is_valid_number, '青森県弘前市田茂木町');
ok($zip->set_number('0368056')->is_valid_number, '青森県弘前市禰宜町');
ok($zip->set_number('0368057')->is_valid_number, '青森県弘前市八幡町');
ok($zip->set_number('0368061')->is_valid_number, '青森県弘前市神田');
ok($zip->set_number('0368062')->is_valid_number, '青森県弘前市青山');
ok($zip->set_number('0368063')->is_valid_number, '青森県弘前市宮園');
ok($zip->set_number('0368064')->is_valid_number, '青森県弘前市東城北');
ok($zip->set_number('0368065')->is_valid_number, '青森県弘前市西城北');
ok($zip->set_number('0368066')->is_valid_number, '青森県弘前市向外瀬');
ok($zip->set_number('0368071')->is_valid_number, '青森県弘前市大久保');
ok($zip->set_number('0368072')->is_valid_number, '青森県弘前市清野袋');
ok($zip->set_number('0368073')->is_valid_number, '青森県弘前市岩賀');
ok($zip->set_number('0368074')->is_valid_number, '青森県弘前市津賀野(瀬ノ上)');
ok($zip->set_number('0368075')->is_valid_number, '青森県弘前市撫牛子');
ok($zip->set_number('0368076')->is_valid_number, '青森県弘前市境関');
ok($zip->set_number('0368081')->is_valid_number, '青森県弘前市福田');
ok($zip->set_number('0368082')->is_valid_number, '青森県弘前市福村');
ok($zip->set_number('0368083')->is_valid_number, '青森県弘前市新里');
ok($zip->set_number('0368084')->is_valid_number, '青森県弘前市高田');
ok($zip->set_number('0368085')->is_valid_number, '青森県弘前市末広');
ok($zip->set_number('0368086')->is_valid_number, '青森県弘前市田園');
ok($zip->set_number('0368087')->is_valid_number, '青森県弘前市早稲田');
ok($zip->set_number('0368091')->is_valid_number, '青森県弘前市高崎');
ok($zip->set_number('0368092')->is_valid_number, '青森県弘前市城東北');
ok($zip->set_number('0368093')->is_valid_number, '青森県弘前市城東中央');
ok($zip->set_number('0368094')->is_valid_number, '青森県弘前市外崎');
ok($zip->set_number('0368095')->is_valid_number, '青森県弘前市城東');
ok($zip->set_number('0368096')->is_valid_number, '青森県弘前市表町');
ok($zip->set_number('0368097')->is_valid_number, '青森県弘前市稲田');
ok($zip->set_number('0368101')->is_valid_number, '青森県弘前市豊田');
ok($zip->set_number('0368102')->is_valid_number, '青森県弘前市小比内');
ok($zip->set_number('0368103')->is_valid_number, '青森県弘前市川先');
ok($zip->set_number('0368104')->is_valid_number, '青森県弘前市扇町');
ok($zip->set_number('0368111')->is_valid_number, '青森県弘前市門外');
ok($zip->set_number('0368112')->is_valid_number, '青森県弘前市堀越');
ok($zip->set_number('0368113')->is_valid_number, '青森県弘前市清水森');
ok($zip->set_number('0368114')->is_valid_number, '青森県弘前市川合');
ok($zip->set_number('0368115')->is_valid_number, '青森県弘前市広野');
ok($zip->set_number('0368121')->is_valid_number, '青森県弘前市薬師堂');
ok($zip->set_number('0368122')->is_valid_number, '青森県弘前市乳井');
ok($zip->set_number('0368123')->is_valid_number, '青森県弘前市小金崎');
ok($zip->set_number('0368124')->is_valid_number, '青森県弘前市石川');
ok($zip->set_number('0368125')->is_valid_number, '青森県弘前市大沢');
ok($zip->set_number('0368126')->is_valid_number, '青森県弘前市松木平');
ok($zip->set_number('0368127')->is_valid_number, '青森県弘前市小栗山');
ok($zip->set_number('0368131')->is_valid_number, '青森県弘前市千年');
ok($zip->set_number('0368132')->is_valid_number, '青森県弘前市狼森');
ok($zip->set_number('0368133')->is_valid_number, '青森県弘前市大和沢');
ok($zip->set_number('0368134')->is_valid_number, '青森県弘前市一野渡');
ok($zip->set_number('0368141')->is_valid_number, '青森県弘前市松原東');
ok($zip->set_number('0368142')->is_valid_number, '青森県弘前市松原西');
ok($zip->set_number('0368143')->is_valid_number, '青森県弘前市富士見台');
ok($zip->set_number('0368144')->is_valid_number, '青森県弘前市原ケ平');
ok($zip->set_number('0368151')->is_valid_number, '青森県弘前市北園');
ok($zip->set_number('0368152')->is_valid_number, '青森県弘前市学園町');
ok($zip->set_number('0368153')->is_valid_number, '青森県弘前市三岳町');
ok($zip->set_number('0368154')->is_valid_number, '青森県弘前市豊原');
ok($zip->set_number('0368155')->is_valid_number, '青森県弘前市中野(丁目)');
ok($zip->set_number('0368161')->is_valid_number, '青森県弘前市大清水');
ok($zip->set_number('0368162')->is_valid_number, '青森県弘前市安原');
ok($zip->set_number('0368163')->is_valid_number, '青森県弘前市清原');
ok($zip->set_number('0368164')->is_valid_number, '青森県弘前市泉野');
ok($zip->set_number('0368171')->is_valid_number, '青森県弘前市取上');
ok($zip->set_number('0368172')->is_valid_number, '青森県弘前市南富田町');
ok($zip->set_number('0368173')->is_valid_number, '青森県弘前市富田町');
ok($zip->set_number('0368174')->is_valid_number, '青森県弘前市富野町');
ok($zip->set_number('0368175')->is_valid_number, '青森県弘前市大富町');
ok($zip->set_number('0368181')->is_valid_number, '青森県弘前市山道町');
ok($zip->set_number('0368182')->is_valid_number, '青森県弘前市土手町');
ok($zip->set_number('0368183')->is_valid_number, '青森県弘前市品川町');
ok($zip->set_number('0368184')->is_valid_number, '青森県弘前市松森町');
ok($zip->set_number('0368185')->is_valid_number, '青森県弘前市御幸町');
ok($zip->set_number('0368186')->is_valid_number, '青森県弘前市富田');
ok($zip->set_number('0368187')->is_valid_number, '青森県弘前市住吉町');
ok($zip->set_number('0368188')->is_valid_number, '青森県弘前市吉野町');
ok($zip->set_number('0368191')->is_valid_number, '青森県弘前市親方町');
ok($zip->set_number('0368192')->is_valid_number, '青森県弘前市鍛冶町');
ok($zip->set_number('0368193')->is_valid_number, '青森県弘前市新鍛冶町');
ok($zip->set_number('0368194')->is_valid_number, '青森県弘前市北川端町');
ok($zip->set_number('0368195')->is_valid_number, '青森県弘前市南川端町');
ok($zip->set_number('0368196')->is_valid_number, '青森県弘前市銅屋町');
ok($zip->set_number('0368197')->is_valid_number, '青森県弘前市桶屋町');
ok($zip->set_number('0368198')->is_valid_number, '青森県弘前市元長町');
ok($zip->set_number('0368201')->is_valid_number, '青森県弘前市一番町');
ok($zip->set_number('0368202')->is_valid_number, '青森県弘前市元大工町');
ok($zip->set_number('0368203')->is_valid_number, '青森県弘前市本町');
ok($zip->set_number('0368204')->is_valid_number, '青森県弘前市覚仙町');
ok($zip->set_number('0368205')->is_valid_number, '青森県弘前市森町');
ok($zip->set_number('0368206')->is_valid_number, '青森県弘前市塩分町');
ok($zip->set_number('0368207')->is_valid_number, '青森県弘前市上白銀町');
ok($zip->set_number('0368211')->is_valid_number, '青森県弘前市相良町');
ok($zip->set_number('0368212')->is_valid_number, '青森県弘前市南塘町');
ok($zip->set_number('0368213')->is_valid_number, '青森県弘前市北新寺町');
ok($zip->set_number('0368214')->is_valid_number, '青森県弘前市新寺町');
ok($zip->set_number('0368215')->is_valid_number, '青森県弘前市新寺町新割町');
ok($zip->set_number('0368216')->is_valid_number, '青森県弘前市在府町');
ok($zip->set_number('0368217')->is_valid_number, '青森県弘前市茂森町');
ok($zip->set_number('0368221')->is_valid_number, '青森県弘前市紙漉町');
ok($zip->set_number('0368222')->is_valid_number, '青森県弘前市桜林町');
ok($zip->set_number('0368223')->is_valid_number, '青森県弘前市富士見町');
ok($zip->set_number('0368224')->is_valid_number, '青森県弘前市文京町');
ok($zip->set_number('0368225')->is_valid_number, '青森県弘前市西ケ丘町');
ok($zip->set_number('0368226')->is_valid_number, '青森県弘前市寒沢町');
ok($zip->set_number('0368227')->is_valid_number, '青森県弘前市桔梗野');
ok($zip->set_number('0368228')->is_valid_number, '青森県弘前市樹木');
ok($zip->set_number('0368231')->is_valid_number, '青森県弘前市稔町');
ok($zip->set_number('0368232')->is_valid_number, '青森県弘前市城南');
ok($zip->set_number('0368233')->is_valid_number, '青森県弘前市山崎');
ok($zip->set_number('0368234')->is_valid_number, '青森県弘前市館野');
ok($zip->set_number('0368241')->is_valid_number, '青森県弘前市桜ケ丘');
ok($zip->set_number('0368242')->is_valid_number, '青森県弘前市大原');
ok($zip->set_number('0368243')->is_valid_number, '青森県弘前市小沢');
ok($zip->set_number('0368244')->is_valid_number, '青森県弘前市坂元');
ok($zip->set_number('0368245')->is_valid_number, '青森県弘前市金属町');
ok($zip->set_number('0368246')->is_valid_number, '青森県弘前市青樹町');
ok($zip->set_number('0368247')->is_valid_number, '青森県弘前市大開');
ok($zip->set_number('0368251')->is_valid_number, '青森県弘前市清富町');
ok($zip->set_number('0368252')->is_valid_number, '青森県弘前市旭ケ丘');
ok($zip->set_number('0368253')->is_valid_number, '青森県弘前市緑ケ丘');
ok($zip->set_number('0368254')->is_valid_number, '青森県弘前市清水');
ok($zip->set_number('0368255')->is_valid_number, '青森県弘前市若葉');
ok($zip->set_number('0368261')->is_valid_number, '青森県弘前市茂森新町');
ok($zip->set_number('0368262')->is_valid_number, '青森県弘前市清水富田');
ok($zip->set_number('0368263')->is_valid_number, '青森県弘前市常盤坂');
ok($zip->set_number('0368264')->is_valid_number, '青森県弘前市悪戸');
ok($zip->set_number('0368265')->is_valid_number, '青森県弘前市下湯口');
ok($zip->set_number('0368266')->is_valid_number, '青森県弘前市自由ケ丘');
ok($zip->set_number('0368271')->is_valid_number, '青森県弘前市鷹匠町');
ok($zip->set_number('0368272')->is_valid_number, '青森県弘前市南袋町');
ok($zip->set_number('0368273')->is_valid_number, '青森県弘前市西茂森');
ok($zip->set_number('0368274')->is_valid_number, '青森県弘前市南城西');
ok($zip->set_number('0368275')->is_valid_number, '青森県弘前市城西');
ok($zip->set_number('0368276')->is_valid_number, '青森県弘前市樋の口町');
ok($zip->set_number('0368277')->is_valid_number, '青森県弘前市河原町');
ok($zip->set_number('0368278')->is_valid_number, '青森県弘前市樋の口');
ok($zip->set_number('0368279')->is_valid_number, '青森県弘前市茜町');
ok($zip->set_number('0368301')->is_valid_number, '青森県弘前市糠坪');
ok($zip->set_number('0368302')->is_valid_number, '青森県弘前市高杉');
ok($zip->set_number('0368303')->is_valid_number, '青森県弘前市前坂');
ok($zip->set_number('0368311')->is_valid_number, '青森県弘前市大川');
ok($zip->set_number('0368312')->is_valid_number, '青森県弘前市三世寺');
ok($zip->set_number('0368313')->is_valid_number, '青森県弘前市中崎');
ok($zip->set_number('0368314')->is_valid_number, '青森県弘前市町田');
ok($zip->set_number('0368315')->is_valid_number, '青森県弘前市船水');
ok($zip->set_number('0368316')->is_valid_number, '青森県弘前市石渡');
ok($zip->set_number('0368317')->is_valid_number, '青森県弘前市外瀬');
ok($zip->set_number('0368318')->is_valid_number, '青森県弘前市八代町');
ok($zip->set_number('0368319')->is_valid_number, '青森県弘前市藤内町');
ok($zip->set_number('0368321')->is_valid_number, '青森県弘前市萢中');
ok($zip->set_number('0368323')->is_valid_number, '青森県弘前市浜の町東');
ok($zip->set_number('0368324')->is_valid_number, '青森県弘前市浜の町西');
ok($zip->set_number('0368325')->is_valid_number, '青森県弘前市浜の町北');
ok($zip->set_number('0368326')->is_valid_number, '青森県弘前市藤野');
ok($zip->set_number('0368331')->is_valid_number, '青森県弘前市小人町');
ok($zip->set_number('0368332')->is_valid_number, '青森県弘前市亀甲町');
ok($zip->set_number('0368333')->is_valid_number, '青森県弘前市若党町');
ok($zip->set_number('0368334')->is_valid_number, '青森県弘前市馬喰町');
ok($zip->set_number('0368335')->is_valid_number, '青森県弘前市春日町');
ok($zip->set_number('0368336')->is_valid_number, '青森県弘前市栄町');
ok($zip->set_number('0368341')->is_valid_number, '青森県弘前市山王町');
ok($zip->set_number('0368342')->is_valid_number, '青森県弘前市笹森町');
ok($zip->set_number('0368343')->is_valid_number, '青森県弘前市東長町');
ok($zip->set_number('0368344')->is_valid_number, '青森県弘前市長坂町');
ok($zip->set_number('0368345')->is_valid_number, '青森県弘前市蔵主町');
ok($zip->set_number('0368346')->is_valid_number, '青森県弘前市大浦町');
ok($zip->set_number('0368351')->is_valid_number, '青森県弘前市百石町小路');
ok($zip->set_number('0368352')->is_valid_number, '青森県弘前市元寺町小路');
ok($zip->set_number('0368353')->is_valid_number, '青森県弘前市下鞘師町');
ok($zip->set_number('0368354')->is_valid_number, '青森県弘前市上鞘師町');
ok($zip->set_number('0368355')->is_valid_number, '青森県弘前市元寺町');
ok($zip->set_number('0368356')->is_valid_number, '青森県弘前市下白銀町');
ok($zip->set_number('0368357')->is_valid_number, '青森県弘前市馬屋町');
ok($zip->set_number('0368361')->is_valid_number, '青森県弘前市紺屋町');
ok($zip->set_number('0368362')->is_valid_number, '青森県弘前市五十石町');
ok($zip->set_number('0368363')->is_valid_number, '青森県弘前市袋町');
ok($zip->set_number('0368364')->is_valid_number, '青森県弘前市新町');
ok($zip->set_number('0368365')->is_valid_number, '青森県弘前市西大工町');
ok($zip->set_number('0368366')->is_valid_number, '青森県弘前市駒越町');
ok($zip->set_number('0368367')->is_valid_number, '青森県弘前市平岡町');
ok($zip->set_number('0368368')->is_valid_number, '青森県弘前市和田町');
ok($zip->set_number('0368371')->is_valid_number, '青森県弘前市蒔苗');
ok($zip->set_number('0368372')->is_valid_number, '青森県弘前市元薬師堂');
ok($zip->set_number('0368373')->is_valid_number, '青森県弘前市藤代');
ok($zip->set_number('0368374')->is_valid_number, '青森県弘前市土堂');
ok($zip->set_number('0368375')->is_valid_number, '青森県弘前市細越');
ok($zip->set_number('0368381')->is_valid_number, '青森県弘前市独狐');
ok($zip->set_number('0368382')->is_valid_number, '青森県弘前市富栄');
ok($zip->set_number('0368383')->is_valid_number, '青森県弘前市折笠');
ok($zip->set_number('0368384')->is_valid_number, '青森県弘前市宮舘');
ok($zip->set_number('0368385')->is_valid_number, '青森県弘前市中別所');
ok($zip->set_number('0370000')->is_valid_number, '青森県五所川原市以下に掲載がない場合');
ok($zip->set_number('0370001')->is_valid_number, '青森県五所川原市下岩崎');
ok($zip->set_number('0370002')->is_valid_number, '青森県五所川原市飯詰');
ok($zip->set_number('0370003')->is_valid_number, '青森県五所川原市吹畑');
ok($zip->set_number('0370004')->is_valid_number, '青森県五所川原市唐笠柳');
ok($zip->set_number('0370005')->is_valid_number, '青森県五所川原市石岡');
ok($zip->set_number('0370006')->is_valid_number, '青森県五所川原市松島町');
ok($zip->set_number('0370011')->is_valid_number, '青森県五所川原市金山');
ok($zip->set_number('0370012')->is_valid_number, '青森県五所川原市水野尾');
ok($zip->set_number('0370013')->is_valid_number, '青森県五所川原市米田');
ok($zip->set_number('0370014')->is_valid_number, '青森県五所川原市稲実');
ok($zip->set_number('0370015')->is_valid_number, '青森県五所川原市姥萢');
ok($zip->set_number('0370016')->is_valid_number, '青森県五所川原市一ツ谷');
ok($zip->set_number('0370017')->is_valid_number, '青森県五所川原市漆川');
ok($zip->set_number('0370021')->is_valid_number, '青森県五所川原市中泉');
ok($zip->set_number('0370022')->is_valid_number, '青森県五所川原市梅田');
ok($zip->set_number('0370023')->is_valid_number, '青森県五所川原市広田');
ok($zip->set_number('0370024')->is_valid_number, '青森県五所川原市みどり町');
ok($zip->set_number('0370025')->is_valid_number, '青森県五所川原市七ツ館');
ok($zip->set_number('0370032')->is_valid_number, '青森県五所川原市烏森');
ok($zip->set_number('0370033')->is_valid_number, '青森県五所川原市鎌谷町');
ok($zip->set_number('0370034')->is_valid_number, '青森県五所川原市八重菊');
ok($zip->set_number('0370035')->is_valid_number, '青森県五所川原市湊');
ok($zip->set_number('0370036')->is_valid_number, '青森県五所川原市中央');
ok($zip->set_number('0370041')->is_valid_number, '青森県五所川原市田町');
ok($zip->set_number('0370042')->is_valid_number, '青森県五所川原市不魚住');
ok($zip->set_number('0370043')->is_valid_number, '青森県五所川原市蓮沼');
ok($zip->set_number('0370044')->is_valid_number, '青森県五所川原市元町');
ok($zip->set_number('0370045')->is_valid_number, '青森県五所川原市新町');
ok($zip->set_number('0370046')->is_valid_number, '青森県五所川原市栄町');
ok($zip->set_number('0370051')->is_valid_number, '青森県五所川原市弥生町');
ok($zip->set_number('0370052')->is_valid_number, '青森県五所川原市東町');
ok($zip->set_number('0370053')->is_valid_number, '青森県五所川原市布屋町');
ok($zip->set_number('0370054')->is_valid_number, '青森県五所川原市上平井町');
ok($zip->set_number('0370055')->is_valid_number, '青森県五所川原市柏原町');
ok($zip->set_number('0370056')->is_valid_number, '青森県五所川原市末広町');
ok($zip->set_number('0370057')->is_valid_number, '青森県五所川原市幾島町');
ok($zip->set_number('0370058')->is_valid_number, '青森県五所川原市錦町');
ok($zip->set_number('0370061')->is_valid_number, '青森県五所川原市雛田');
ok($zip->set_number('0370062')->is_valid_number, '青森県五所川原市旭町');
ok($zip->set_number('0370063')->is_valid_number, '青森県五所川原市大町');
ok($zip->set_number('0370064')->is_valid_number, '青森県五所川原市下平井町');
ok($zip->set_number('0370065')->is_valid_number, '青森県五所川原市幾世森');
ok($zip->set_number('0370066')->is_valid_number, '青森県五所川原市中平井町');
ok($zip->set_number('0370067')->is_valid_number, '青森県五所川原市敷島町');
ok($zip->set_number('0370068')->is_valid_number, '青森県五所川原市長橋');
ok($zip->set_number('0370069')->is_valid_number, '青森県五所川原市若葉');
ok($zip->set_number('0370071')->is_valid_number, '青森県五所川原市本町');
ok($zip->set_number('0370072')->is_valid_number, '青森県五所川原市川端町');
ok($zip->set_number('0370073')->is_valid_number, '青森県五所川原市柳町');
ok($zip->set_number('0370074')->is_valid_number, '青森県五所川原市岩木町');
ok($zip->set_number('0370075')->is_valid_number, '青森県五所川原市寺町');
ok($zip->set_number('0370076')->is_valid_number, '青森県五所川原市小曲');
ok($zip->set_number('0370081')->is_valid_number, '青森県五所川原市新宮');
ok($zip->set_number('0370082')->is_valid_number, '青森県五所川原市種井');
ok($zip->set_number('0370083')->is_valid_number, '青森県五所川原市新宮町');
ok($zip->set_number('0370084')->is_valid_number, '青森県五所川原市蘇鉄');
ok($zip->set_number('0370085')->is_valid_number, '青森県五所川原市芭蕉');
ok($zip->set_number('0370086')->is_valid_number, '青森県五所川原市田川');
ok($zip->set_number('0370087')->is_valid_number, '青森県五所川原市高瀬');
ok($zip->set_number('0370088')->is_valid_number, '青森県五所川原市鶴ケ岡');
ok($zip->set_number('0370089')->is_valid_number, '青森県五所川原市藻川');
ok($zip->set_number('0370091')->is_valid_number, '青森県五所川原市太刀打');
ok($zip->set_number('0370092')->is_valid_number, '青森県五所川原市沖飯詰');
ok($zip->set_number('0370093')->is_valid_number, '青森県五所川原市一野坪');
ok($zip->set_number('0370094')->is_valid_number, '青森県五所川原市川山');
ok($zip->set_number('0370095')->is_valid_number, '青森県五所川原市桜田');
ok($zip->set_number('0370096')->is_valid_number, '青森県五所川原市毘沙門');
ok($zip->set_number('0370097')->is_valid_number, '青森県五所川原市長富');
ok($zip->set_number('0370101')->is_valid_number, '青森県つがる市稲垣町下繁田');
ok($zip->set_number('0370102')->is_valid_number, '青森県つがる市稲垣町繁田');
ok($zip->set_number('0370103')->is_valid_number, '青森県つがる市稲垣町穂積');
ok($zip->set_number('0370104')->is_valid_number, '青森県つがる市稲垣町豊川');
ok($zip->set_number('0370105')->is_valid_number, '青森県つがる市稲垣町福富');
ok($zip->set_number('0370106')->is_valid_number, '青森県つがる市稲垣町沼崎');
ok($zip->set_number('0370107')->is_valid_number, '青森県つがる市稲垣町沼舘');
ok($zip->set_number('0370108')->is_valid_number, '青森県つがる市稲垣町吉出');
ok($zip->set_number('0370109')->is_valid_number, '青森県つがる市稲垣町千年');
ok($zip->set_number('0370201')->is_valid_number, '青森県五所川原市金木町川倉');
ok($zip->set_number('0370202')->is_valid_number, '青森県五所川原市金木町');
ok($zip->set_number('0370203')->is_valid_number, '青森県五所川原市金木町喜良市');
ok($zip->set_number('0370204')->is_valid_number, '青森県五所川原市金木町嘉瀬');
ok($zip->set_number('0370205')->is_valid_number, '青森県五所川原市金木町中柏木');
ok($zip->set_number('0370206')->is_valid_number, '青森県五所川原市金木町神原');
ok($zip->set_number('0370207')->is_valid_number, '青森県五所川原市金木町蒔田');
ok($zip->set_number('0370208')->is_valid_number, '青森県五所川原市金木町藤枝');
ok($zip->set_number('0370300')->is_valid_number, '青森県北津軽郡中泊町以下に掲載がない場合');
ok($zip->set_number('0370301')->is_valid_number, '青森県北津軽郡中泊町今泉');
ok($zip->set_number('0370302')->is_valid_number, '青森県北津軽郡中泊町薄市');
ok($zip->set_number('0370303')->is_valid_number, '青森県北津軽郡中泊町高根');
ok($zip->set_number('0370304')->is_valid_number, '青森県北津軽郡中泊町尾別');
ok($zip->set_number('0370305')->is_valid_number, '青森県北津軽郡中泊町中里');
ok($zip->set_number('0370306')->is_valid_number, '青森県北津軽郡中泊町宮川');
ok($zip->set_number('0370307')->is_valid_number, '青森県北津軽郡中泊町宮野沢');
ok($zip->set_number('0370308')->is_valid_number, '青森県北津軽郡中泊町深郷田');
ok($zip->set_number('0370309')->is_valid_number, '青森県北津軽郡中泊町八幡');
ok($zip->set_number('0370311')->is_valid_number, '青森県北津軽郡中泊町大沢内');
ok($zip->set_number('0370312')->is_valid_number, '青森県北津軽郡中泊町豊島');
ok($zip->set_number('0370313')->is_valid_number, '青森県北津軽郡中泊町富野');
ok($zip->set_number('0370314')->is_valid_number, '青森県北津軽郡中泊町福浦');
ok($zip->set_number('0370315')->is_valid_number, '青森県北津軽郡中泊町豊岡');
ok($zip->set_number('0370316')->is_valid_number, '青森県北津軽郡中泊町芦野');
ok($zip->set_number('0370317')->is_valid_number, '青森県北津軽郡中泊町長泥');
ok($zip->set_number('0370318')->is_valid_number, '青森県北津軽郡中泊町田茂木');
ok($zip->set_number('0370401')->is_valid_number, '青森県五所川原市相内');
ok($zip->set_number('0370402')->is_valid_number, '青森県五所川原市太田');
ok($zip->set_number('0370403')->is_valid_number, '青森県五所川原市十三');
ok($zip->set_number('0370404')->is_valid_number, '青森県五所川原市磯松');
ok($zip->set_number('0370405')->is_valid_number, '青森県五所川原市脇元');
ok($zip->set_number('0370511')->is_valid_number, '青森県北津軽郡中泊町小泊砂山');
ok($zip->set_number('0370512')->is_valid_number, '青森県北津軽郡中泊町小泊朝間');
ok($zip->set_number('0370513')->is_valid_number, '青森県北津軽郡中泊町小泊割長根');
ok($zip->set_number('0370514')->is_valid_number, '青森県北津軽郡中泊町小泊浜野');
ok($zip->set_number('0370521')->is_valid_number, '青森県北津軽郡中泊町小泊折戸');
ok($zip->set_number('0370522')->is_valid_number, '青森県北津軽郡中泊町小泊小泊');
ok($zip->set_number('0370523')->is_valid_number, '青森県北津軽郡中泊町小泊稲荷');
ok($zip->set_number('0370524')->is_valid_number, '青森県北津軽郡中泊町小泊水澗');
ok($zip->set_number('0370525')->is_valid_number, '青森県北津軽郡中泊町小泊鮫貝');
ok($zip->set_number('0370531')->is_valid_number, '青森県北津軽郡中泊町小泊長坂');
ok($zip->set_number('0370532')->is_valid_number, '青森県北津軽郡中泊町小泊梨子木平');
ok($zip->set_number('0370533')->is_valid_number, '青森県北津軽郡中泊町小泊白倉');
ok($zip->set_number('0370534')->is_valid_number, '青森県北津軽郡中泊町小泊漆流');
ok($zip->set_number('0370535')->is_valid_number, '青森県北津軽郡中泊町小泊尾崎道');
ok($zip->set_number('0370536')->is_valid_number, '青森県北津軽郡中泊町小泊中間');
ok($zip->set_number('0370537')->is_valid_number, '青森県北津軽郡中泊町小泊渕岩');
ok($zip->set_number('0370538')->is_valid_number, '青森県北津軽郡中泊町小泊下前');
ok($zip->set_number('0370541')->is_valid_number, '青森県北津軽郡中泊町小泊嗽沢');
ok($zip->set_number('0370542')->is_valid_number, '青森県北津軽郡中泊町小泊大山長根');
ok($zip->set_number('0370543')->is_valid_number, '青森県北津軽郡中泊町小泊坊主沢');
ok($zip->set_number('0370601')->is_valid_number, '青森県五所川原市戸沢');
ok($zip->set_number('0370602')->is_valid_number, '青森県五所川原市松野木');
ok($zip->set_number('0370611')->is_valid_number, '青森県五所川原市神山');
ok($zip->set_number('0370612')->is_valid_number, '青森県五所川原市福山');
ok($zip->set_number('0370613')->is_valid_number, '青森県五所川原市浅井');
ok($zip->set_number('0370614')->is_valid_number, '青森県五所川原市野里');
ok($zip->set_number('0370621')->is_valid_number, '青森県五所川原市豊成');
ok($zip->set_number('0370622')->is_valid_number, '青森県五所川原市原子');
ok($zip->set_number('0370623')->is_valid_number, '青森県五所川原市俵元');
ok($zip->set_number('0370631')->is_valid_number, '青森県五所川原市前田野目');
ok($zip->set_number('0370632')->is_valid_number, '青森県五所川原市高野');
ok($zip->set_number('0370641')->is_valid_number, '青森県五所川原市羽野木沢');
ok($zip->set_number('0370642')->is_valid_number, '青森県五所川原市持子沢');
ok($zip->set_number('0380000')->is_valid_number, '青森県青森市以下に掲載がない場合');
ok($zip->set_number('0380001')->is_valid_number, '青森県青森市新田');
ok($zip->set_number('0380002')->is_valid_number, '青森県青森市沖館');
ok($zip->set_number('0380003')->is_valid_number, '青森県青森市石江');
ok($zip->set_number('0380004')->is_valid_number, '青森県青森市富田');
ok($zip->set_number('0380006')->is_valid_number, '青森県青森市三好');
ok($zip->set_number('0380011')->is_valid_number, '青森県青森市篠田');
ok($zip->set_number('0380012')->is_valid_number, '青森県青森市柳川');
ok($zip->set_number('0380013')->is_valid_number, '青森県青森市久須志');
ok($zip->set_number('0380014')->is_valid_number, '青森県青森市西滝');
ok($zip->set_number('0380015')->is_valid_number, '青森県青森市千刈');
ok($zip->set_number('0380021')->is_valid_number, '青森県青森市安田');
ok($zip->set_number('0380022')->is_valid_number, '青森県青森市浪館');
ok($zip->set_number('0380023')->is_valid_number, '青森県青森市細越');
ok($zip->set_number('0380024')->is_valid_number, '青森県青森市浪館前田');
ok($zip->set_number('0380031')->is_valid_number, '青森県青森市三内');
ok($zip->set_number('0380032')->is_valid_number, '青森県青森市里見');
ok($zip->set_number('0380041')->is_valid_number, '青森県青森市岡町');
ok($zip->set_number('0380042')->is_valid_number, '青森県青森市新城');
ok($zip->set_number('0380043')->is_valid_number, '青森県青森市岩渡');
ok($zip->set_number('0380044')->is_valid_number, '青森県青森市孫内');
ok($zip->set_number('0380045')->is_valid_number, '青森県青森市鶴ケ坂');
ok($zip->set_number('0380046')->is_valid_number, '青森県青森市戸門');
ok($zip->set_number('0380051')->is_valid_number, '青森県青森市内真部');
ok($zip->set_number('0380052')->is_valid_number, '青森県青森市清水');
ok($zip->set_number('0380053')->is_valid_number, '青森県青森市前田');
ok($zip->set_number('0380054')->is_valid_number, '青森県青森市奥内');
ok($zip->set_number('0380055')->is_valid_number, '青森県青森市瀬戸子');
ok($zip->set_number('0380056')->is_valid_number, '青森県青森市飛鳥');
ok($zip->set_number('0380057')->is_valid_number, '青森県青森市西田沢');
ok($zip->set_number('0380058')->is_valid_number, '青森県青森市羽白');
ok($zip->set_number('0380059')->is_valid_number, '青森県青森市油川');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関相沢');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関阿原');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関雷林');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関碇石');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関岩井');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関大葉平');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関大落前');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関折橋');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関鯨森');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関小落前');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関山神堂');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関白沢');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関諏訪平');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関外白沢');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関高田');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関樋ケ沢');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関西碇ケ関山');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関東碇ケ関山');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関樋ノ口');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関船岡');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関踏田切');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関三笠山');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関水溜');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関湯向川添');
ok($zip->set_number('0380101')->is_valid_number, '青森県平川市碇ケ関横町');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸上程森');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸沢田');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸樋ケ沢');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸堂ノ上');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸鳥井');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸西不動野');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸東不動野');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸不動沢大石');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸不動野');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸南不動野');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸向安田');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸門前');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸門前屋岸');
ok($zip->set_number('0380102')->is_valid_number, '青森県平川市碇ケ関古懸安田');
ok($zip->set_number('0380103')->is_valid_number, '青森県平川市碇ケ関久吉蕷ケ平');
ok($zip->set_number('0380103')->is_valid_number, '青森県平川市碇ケ関久吉二ノ渡');
ok($zip->set_number('0380103')->is_valid_number, '青森県平川市碇ケ関久吉山岸');
ok($zip->set_number('0380200')->is_valid_number, '青森県南津軽郡大鰐町以下に掲載がない場合');
ok($zip->set_number('0380201')->is_valid_number, '青森県南津軽郡大鰐町苦木');
ok($zip->set_number('0380202')->is_valid_number, '青森県南津軽郡大鰐町長峰');
ok($zip->set_number('0380203')->is_valid_number, '青森県南津軽郡大鰐町駒木');
ok($zip->set_number('0380204')->is_valid_number, '青森県南津軽郡大鰐町唐牛');
ok($zip->set_number('0380211')->is_valid_number, '青森県南津軽郡大鰐町大鰐');
ok($zip->set_number('0380212')->is_valid_number, '青森県南津軽郡大鰐町蔵館');
ok($zip->set_number('0380221')->is_valid_number, '青森県南津軽郡大鰐町虹貝');
ok($zip->set_number('0380222')->is_valid_number, '青森県南津軽郡大鰐町早瀬野');
ok($zip->set_number('0380223')->is_valid_number, '青森県南津軽郡大鰐町島田');
ok($zip->set_number('0380231')->is_valid_number, '青森県南津軽郡大鰐町宿川原');
ok($zip->set_number('0380232')->is_valid_number, '青森県南津軽郡大鰐町三ツ目内');
ok($zip->set_number('0380233')->is_valid_number, '青森県南津軽郡大鰐町居土');
ok($zip->set_number('0380241')->is_valid_number, '青森県南津軽郡大鰐町鯖石');
ok($zip->set_number('0380242')->is_valid_number, '青森県南津軽郡大鰐町森山');
ok($zip->set_number('0380243')->is_valid_number, '青森県南津軽郡大鰐町八幡館');
ok($zip->set_number('0381100')->is_valid_number, '青森県南津軽郡田舎館村以下に掲載がない場合');
ok($zip->set_number('0381101')->is_valid_number, '青森県南津軽郡田舎館村東光寺');
ok($zip->set_number('0381102')->is_valid_number, '青森県南津軽郡田舎館村堂野前');
ok($zip->set_number('0381103')->is_valid_number, '青森県南津軽郡田舎館村十二川原');
ok($zip->set_number('0381104')->is_valid_number, '青森県南津軽郡田舎館村枝川');
ok($zip->set_number('0381111')->is_valid_number, '青森県南津軽郡田舎館村高樋');
ok($zip->set_number('0381112')->is_valid_number, '青森県南津軽郡田舎館村垂柳');
ok($zip->set_number('0381113')->is_valid_number, '青森県南津軽郡田舎館村田舎舘');
ok($zip->set_number('0381121')->is_valid_number, '青森県南津軽郡田舎館村畑中');
ok($zip->set_number('0381122')->is_valid_number, '青森県南津軽郡田舎館村八反田');
ok($zip->set_number('0381123')->is_valid_number, '青森県南津軽郡田舎館村大曲');
ok($zip->set_number('0381131')->is_valid_number, '青森県南津軽郡田舎館村大袋');
ok($zip->set_number('0381132')->is_valid_number, '青森県南津軽郡田舎館村諏訪堂');
ok($zip->set_number('0381133')->is_valid_number, '青森県南津軽郡田舎館村大根子');
ok($zip->set_number('0381134')->is_valid_number, '青森県南津軽郡田舎館村豊蒔');
ok($zip->set_number('0381141')->is_valid_number, '青森県南津軽郡田舎館村川部');
ok($zip->set_number('0381142')->is_valid_number, '青森県南津軽郡田舎館村和泉');
ok($zip->set_number('0381143')->is_valid_number, '青森県南津軽郡田舎館村境森');
ok($zip->set_number('0381144')->is_valid_number, '青森県南津軽郡田舎館村前田屋敷');
ok($zip->set_number('0381145')->is_valid_number, '青森県南津軽郡田舎館村土矢倉');
ok($zip->set_number('0381201')->is_valid_number, '青森県南津軽郡藤崎町福舘');
ok($zip->set_number('0381202')->is_valid_number, '青森県南津軽郡藤崎町富柳');
ok($zip->set_number('0381203')->is_valid_number, '青森県南津軽郡藤崎町久井名舘');
ok($zip->set_number('0381204')->is_valid_number, '青森県南津軽郡藤崎町水木');
ok($zip->set_number('0381205')->is_valid_number, '青森県南津軽郡藤崎町吉野田');
ok($zip->set_number('0381206')->is_valid_number, '青森県南津軽郡藤崎町郷山前');
ok($zip->set_number('0381207')->is_valid_number, '青森県南津軽郡藤崎町増館');
ok($zip->set_number('0381211')->is_valid_number, '青森県南津軽郡藤崎町福島');
ok($zip->set_number('0381212')->is_valid_number, '青森県南津軽郡藤崎町三ツ屋');
ok($zip->set_number('0381213')->is_valid_number, '青森県南津軽郡藤崎町徳下');
ok($zip->set_number('0381214')->is_valid_number, '青森県南津軽郡藤崎町常盤');
ok($zip->set_number('0381215')->is_valid_number, '青森県南津軽郡藤崎町若松');
ok($zip->set_number('0381216')->is_valid_number, '青森県南津軽郡藤崎町榊');
ok($zip->set_number('0381301')->is_valid_number, '青森県青森市浪岡大釈迦');
ok($zip->set_number('0381302')->is_valid_number, '青森県青森市浪岡長沼');
ok($zip->set_number('0381303')->is_valid_number, '青森県青森市浪岡徳才子');
ok($zip->set_number('0381304')->is_valid_number, '青森県青森市浪岡高屋敷');
ok($zip->set_number('0381305')->is_valid_number, '青森県青森市浪岡杉沢');
ok($zip->set_number('0381306')->is_valid_number, '青森県青森市浪岡福田');
ok($zip->set_number('0381311')->is_valid_number, '青森県青森市浪岡浪岡');
ok($zip->set_number('0381312')->is_valid_number, '青森県青森市浪岡五本松');
ok($zip->set_number('0381313')->is_valid_number, '青森県青森市浪岡王余魚沢');
ok($zip->set_number('0381321')->is_valid_number, '青森県青森市浪岡相沢');
ok($zip->set_number('0381322')->is_valid_number, '青森県青森市浪岡細野');
ok($zip->set_number('0381323')->is_valid_number, '青森県青森市浪岡本郷');
ok($zip->set_number('0381324')->is_valid_number, '青森県青森市浪岡吉内');
ok($zip->set_number('0381325')->is_valid_number, '青森県青森市浪岡北中野');
ok($zip->set_number('0381331')->is_valid_number, '青森県青森市浪岡女鹿沢');
ok($zip->set_number('0381332')->is_valid_number, '青森県青森市浪岡下十川');
ok($zip->set_number('0381333')->is_valid_number, '青森県青森市浪岡増館');
ok($zip->set_number('0381341')->is_valid_number, '青森県青森市浪岡銀');
ok($zip->set_number('0381342')->is_valid_number, '青森県青森市浪岡樽沢');
ok($zip->set_number('0381343')->is_valid_number, '青森県青森市浪岡郷山前');
ok($zip->set_number('0381344')->is_valid_number, '青森県青森市浪岡吉野田');
ok($zip->set_number('0381345')->is_valid_number, '青森県青森市浪岡下石川');
ok($zip->set_number('0382201')->is_valid_number, '青森県西津軽郡深浦町沢辺');
ok($zip->set_number('0382202')->is_valid_number, '青森県西津軽郡深浦町岩崎');
ok($zip->set_number('0382203')->is_valid_number, '青森県西津軽郡深浦町正道尻');
ok($zip->set_number('0382204')->is_valid_number, '青森県西津軽郡深浦町久田');
ok($zip->set_number('0382205')->is_valid_number, '青森県西津軽郡深浦町森山');
ok($zip->set_number('0382206')->is_valid_number, '青森県西津軽郡深浦町松神');
ok($zip->set_number('0382207')->is_valid_number, '青森県西津軽郡深浦町黒崎');
ok($zip->set_number('0382208')->is_valid_number, '青森県西津軽郡深浦町大間越');
ok($zip->set_number('0382300')->is_valid_number, '青森県西津軽郡深浦町以下に掲載がない場合');
ok($zip->set_number('0382321')->is_valid_number, '青森県西津軽郡深浦町広戸');
ok($zip->set_number('0382322')->is_valid_number, '青森県西津軽郡深浦町長慶平');
ok($zip->set_number('0382323')->is_valid_number, '青森県西津軽郡深浦町上長慶平');
ok($zip->set_number('0382324')->is_valid_number, '青森県西津軽郡深浦町深浦');
ok($zip->set_number('0382325')->is_valid_number, '青森県西津軽郡深浦町横磯');
ok($zip->set_number('0382326')->is_valid_number, '青森県西津軽郡深浦町月屋');
ok($zip->set_number('0382327')->is_valid_number, '青森県西津軽郡深浦町舮作');
ok($zip->set_number('0382411')->is_valid_number, '青森県西津軽郡深浦町風合瀬');
ok($zip->set_number('0382412')->is_valid_number, '青森県西津軽郡深浦町驫木');
ok($zip->set_number('0382413')->is_valid_number, '青森県西津軽郡深浦町追良瀬');
ok($zip->set_number('0382501')->is_valid_number, '青森県西津軽郡深浦町柳田');
ok($zip->set_number('0382502')->is_valid_number, '青森県西津軽郡深浦町岩坂');
ok($zip->set_number('0382503')->is_valid_number, '青森県西津軽郡深浦町関');
ok($zip->set_number('0382504')->is_valid_number, '青森県西津軽郡深浦町北金ケ沢');
ok($zip->set_number('0382505')->is_valid_number, '青森県西津軽郡深浦町田野沢');
ok($zip->set_number('0382700')->is_valid_number, '青森県西津軽郡鰺ヶ沢町以下に掲載がない場合');
ok($zip->set_number('0382701')->is_valid_number, '青森県西津軽郡鰺ヶ沢町北浮田町');
ok($zip->set_number('0382702')->is_valid_number, '青森県西津軽郡鰺ヶ沢町建石町');
ok($zip->set_number('0382703')->is_valid_number, '青森県西津軽郡鰺ヶ沢町小屋敷町');
ok($zip->set_number('0382704')->is_valid_number, '青森県西津軽郡鰺ヶ沢町湯舟町');
ok($zip->set_number('0382705')->is_valid_number, '青森県西津軽郡鰺ヶ沢町南浮田町');
ok($zip->set_number('0382711')->is_valid_number, '青森県西津軽郡鰺ヶ沢町中村町');
ok($zip->set_number('0382712')->is_valid_number, '青森県西津軽郡鰺ヶ沢町長平町');
ok($zip->set_number('0382713')->is_valid_number, '青森県西津軽郡鰺ヶ沢町松代町');
ok($zip->set_number('0382714')->is_valid_number, '青森県西津軽郡鰺ヶ沢町芦萢町');
ok($zip->set_number('0382715')->is_valid_number, '青森県西津軽郡鰺ヶ沢町浜横沢町');
ok($zip->set_number('0382721')->is_valid_number, '青森県西津軽郡鰺ヶ沢町深谷町');
ok($zip->set_number('0382722')->is_valid_number, '青森県西津軽郡鰺ヶ沢町小森町');
ok($zip->set_number('0382723')->is_valid_number, '青森県西津軽郡鰺ヶ沢町一ツ森町');
ok($zip->set_number('0382724')->is_valid_number, '青森県西津軽郡鰺ヶ沢町鬼袋町');
ok($zip->set_number('0382725')->is_valid_number, '青森県西津軽郡鰺ヶ沢町種里町');
ok($zip->set_number('0382731')->is_valid_number, '青森県西津軽郡鰺ヶ沢町赤石町');
ok($zip->set_number('0382732')->is_valid_number, '青森県西津軽郡鰺ヶ沢町日照田町');
ok($zip->set_number('0382733')->is_valid_number, '青森県西津軽郡鰺ヶ沢町館前町');
ok($zip->set_number('0382734')->is_valid_number, '青森県西津軽郡鰺ヶ沢町南金沢町');
ok($zip->set_number('0382735')->is_valid_number, '青森県西津軽郡鰺ヶ沢町姥袋町');
ok($zip->set_number('0382741')->is_valid_number, '青森県西津軽郡鰺ヶ沢町浜町');
ok($zip->set_number('0382742')->is_valid_number, '青森県西津軽郡鰺ヶ沢町新町');
ok($zip->set_number('0382743')->is_valid_number, '青森県西津軽郡鰺ヶ沢町釣町');
ok($zip->set_number('0382744')->is_valid_number, '青森県西津軽郡鰺ヶ沢町漁師町');
ok($zip->set_number('0382745')->is_valid_number, '青森県西津軽郡鰺ヶ沢町新地町');
ok($zip->set_number('0382746')->is_valid_number, '青森県西津軽郡鰺ヶ沢町富根町');
ok($zip->set_number('0382747')->is_valid_number, '青森県西津軽郡鰺ヶ沢町淀町');
ok($zip->set_number('0382751')->is_valid_number, '青森県西津軽郡鰺ヶ沢町田中町');
ok($zip->set_number('0382752')->is_valid_number, '青森県西津軽郡鰺ヶ沢町七ツ石町');
ok($zip->set_number('0382753')->is_valid_number, '青森県西津軽郡鰺ヶ沢町本町');
ok($zip->set_number('0382754')->is_valid_number, '青森県西津軽郡鰺ヶ沢町米町');
ok($zip->set_number('0382761')->is_valid_number, '青森県西津軽郡鰺ヶ沢町舞戸町');
ok($zip->set_number('0382801')->is_valid_number, '青森県つがる市木造丸山');
ok($zip->set_number('0382803')->is_valid_number, '青森県つがる市木造下福原');
ok($zip->set_number('0382804')->is_valid_number, '青森県つがる市木造三ツ館');
ok($zip->set_number('0382806')->is_valid_number, '青森県つがる市木造越水');
ok($zip->set_number('0382808')->is_valid_number, '青森県つがる市木造吹原');
ok($zip->set_number('0382811')->is_valid_number, '青森県つがる市森田町上相野');
ok($zip->set_number('0382812')->is_valid_number, '青森県つがる市森田町下相野');
ok($zip->set_number('0382813')->is_valid_number, '青森県つがる市森田町妙堂崎');
ok($zip->set_number('0382814')->is_valid_number, '青森県つがる市森田町中田');
ok($zip->set_number('0382815')->is_valid_number, '青森県つがる市森田町山田');
ok($zip->set_number('0382816')->is_valid_number, '青森県つがる市森田町森田');
ok($zip->set_number('0382817')->is_valid_number, '青森県つがる市森田町床舞');
ok($zip->set_number('0382818')->is_valid_number, '青森県つがる市森田町大館');
ok($zip->set_number('0383100')->is_valid_number, '青森県つがる市以下に掲載がない場合');
ok($zip->set_number('0383101')->is_valid_number, '青森県つがる市柏鷺坂');
ok($zip->set_number('0383102')->is_valid_number, '青森県つがる市柏下古川');
ok($zip->set_number('0383103')->is_valid_number, '青森県つがる市柏上古川');
ok($zip->set_number('0383104')->is_valid_number, '青森県つがる市柏桑野木田');
ok($zip->set_number('0383105')->is_valid_number, '青森県つがる市柏広須');
ok($zip->set_number('0383106')->is_valid_number, '青森県つがる市柏玉水');
ok($zip->set_number('0383107')->is_valid_number, '青森県つがる市柏稲盛');
ok($zip->set_number('0383111')->is_valid_number, '青森県つがる市木造豊田');
ok($zip->set_number('0383112')->is_valid_number, '青森県つがる市木造川除');
ok($zip->set_number('0383113')->is_valid_number, '青森県つがる市木造芦沼');
ok($zip->set_number('0383114')->is_valid_number, '青森県つがる市木造成田');
ok($zip->set_number('0383115')->is_valid_number, '青森県つがる市木造蓮川');
ok($zip->set_number('0383121')->is_valid_number, '青森県つがる市木造早田');
ok($zip->set_number('0383122')->is_valid_number, '青森県つがる市木造追広');
ok($zip->set_number('0383123')->is_valid_number, '青森県つがる市木造藤田');
ok($zip->set_number('0383124')->is_valid_number, '青森県つがる市木造朝日');
ok($zip->set_number('0383125')->is_valid_number, '青森県つがる市木造鶴泊');
ok($zip->set_number('0383126')->is_valid_number, '青森県つがる市木造森内');
ok($zip->set_number('0383127')->is_valid_number, '青森県つがる市木造森山');
ok($zip->set_number('0383128')->is_valid_number, '青森県つがる市木造森本');
ok($zip->set_number('0383131')->is_valid_number, '青森県つがる市木造千年');
ok($zip->set_number('0383132')->is_valid_number, '青森県つがる市木造清水');
ok($zip->set_number('0383133')->is_valid_number, '青森県つがる市木造末広');
ok($zip->set_number('0383134')->is_valid_number, '青森県つがる市木造種取');
ok($zip->set_number('0383135')->is_valid_number, '青森県つがる市木造有楽町');
ok($zip->set_number('0383136')->is_valid_number, '青森県つがる市木造萩野');
ok($zip->set_number('0383137')->is_valid_number, '青森県つがる市木造若宮');
ok($zip->set_number('0383138')->is_valid_number, '青森県つがる市木造若緑');
ok($zip->set_number('0383139')->is_valid_number, '青森県つがる市木造萩流');
ok($zip->set_number('0383141')->is_valid_number, '青森県つがる市木造浮巣');
ok($zip->set_number('0383142')->is_valid_number, '青森県つがる市木造赤根');
ok($zip->set_number('0383143')->is_valid_number, '青森県つがる市木造日向');
ok($zip->set_number('0383144')->is_valid_number, '青森県つがる市木造曙');
ok($zip->set_number('0383145')->is_valid_number, '青森県つがる市木造千代町');
ok($zip->set_number('0383146')->is_valid_number, '青森県つがる市木造桜木');
ok($zip->set_number('0383151')->is_valid_number, '青森県つがる市木造若竹');
ok($zip->set_number('0383152')->is_valid_number, '青森県つがる市木造藤岡');
ok($zip->set_number('0383153')->is_valid_number, '青森県つがる市木造野宮');
ok($zip->set_number('0383154')->is_valid_number, '青森県つがる市木造照日');
ok($zip->set_number('0383155')->is_valid_number, '青森県つがる市木造増田');
ok($zip->set_number('0383156')->is_valid_number, '青森県つがる市木造宮井');
ok($zip->set_number('0383157')->is_valid_number, '青森県つがる市木造宮崎');
ok($zip->set_number('0383158')->is_valid_number, '青森県つがる市木造房松');
ok($zip->set_number('0383159')->is_valid_number, '青森県つがる市木造桜川');
ok($zip->set_number('0383161')->is_valid_number, '青森県つがる市木造濁川');
ok($zip->set_number('0383162')->is_valid_number, '青森県つがる市木造浦船');
ok($zip->set_number('0383163')->is_valid_number, '青森県つがる市木造中館');
ok($zip->set_number('0383164')->is_valid_number, '青森県つがる市木造柴田');
ok($zip->set_number('0383165')->is_valid_number, '青森県つがる市木造菊川');
ok($zip->set_number('0383166')->is_valid_number, '青森県つがる市木造福原');
ok($zip->set_number('0383167')->is_valid_number, '青森県つがる市木造千代田');
ok($zip->set_number('0383271')->is_valid_number, '青森県つがる市木造善積');
ok($zip->set_number('0383272')->is_valid_number, '青森県つがる市木造兼館');
ok($zip->set_number('0383273')->is_valid_number, '青森県つがる市木造出野里');
ok($zip->set_number('0383274')->is_valid_number, '青森県つがる市木造蓮花田');
ok($zip->set_number('0383275')->is_valid_number, '青森県つがる市木造永田');
ok($zip->set_number('0383276')->is_valid_number, '青森県つがる市木造林');
ok($zip->set_number('0383277')->is_valid_number, '青森県つがる市木造大畑');
ok($zip->set_number('0383278')->is_valid_number, '青森県つがる市木造土滝');
ok($zip->set_number('0383281')->is_valid_number, '青森県つがる市木造平滝');
ok($zip->set_number('0383282')->is_valid_number, '青森県つがる市木造筒木坂');
ok($zip->set_number('0383283')->is_valid_number, '青森県つがる市木造館岡');
ok($zip->set_number('0383284')->is_valid_number, '青森県つがる市木造亀ケ岡');
ok($zip->set_number('0383285')->is_valid_number, '青森県つがる市木造大湯町');
ok($zip->set_number('0383286')->is_valid_number, '青森県つがる市木造菰槌');
ok($zip->set_number('0383287')->is_valid_number, '青森県つがる市木造下遠山里');
ok($zip->set_number('0383288')->is_valid_number, '青森県つがる市木造出来島');
ok($zip->set_number('0383301')->is_valid_number, '青森県つがる市富萢町');
ok($zip->set_number('0383302')->is_valid_number, '青森県つがる市豊富町');
ok($zip->set_number('0383303')->is_valid_number, '青森県つがる市車力町');
ok($zip->set_number('0383304')->is_valid_number, '青森県つがる市下車力町');
ok($zip->set_number('0383305')->is_valid_number, '青森県つがる市牛潟町');
ok($zip->set_number('0383306')->is_valid_number, '青森県つがる市下牛潟町');
ok($zip->set_number('0383500')->is_valid_number, '青森県北津軽郡鶴田町以下に掲載がない場合');
ok($zip->set_number('0383501')->is_valid_number, '青森県北津軽郡鶴田町大巻');
ok($zip->set_number('0383502')->is_valid_number, '青森県北津軽郡鶴田町強巻');
ok($zip->set_number('0383503')->is_valid_number, '青森県北津軽郡鶴田町鶴田');
ok($zip->set_number('0383511')->is_valid_number, '青森県北津軽郡鶴田町横萢');
ok($zip->set_number('0383512')->is_valid_number, '青森県北津軽郡鶴田町瀬良沢');
ok($zip->set_number('0383513')->is_valid_number, '青森県北津軽郡鶴田町沖');
ok($zip->set_number('0383514')->is_valid_number, '青森県北津軽郡鶴田町中野');
ok($zip->set_number('0383515')->is_valid_number, '青森県北津軽郡鶴田町山道');
ok($zip->set_number('0383521')->is_valid_number, '青森県北津軽郡鶴田町菖蒲川');
ok($zip->set_number('0383522')->is_valid_number, '青森県北津軽郡鶴田町鶴泊');
ok($zip->set_number('0383523')->is_valid_number, '青森県北津軽郡鶴田町胡桃舘');
ok($zip->set_number('0383524')->is_valid_number, '青森県北津軽郡鶴田町境');
ok($zip->set_number('0383525')->is_valid_number, '青森県北津軽郡鶴田町大性');
ok($zip->set_number('0383531')->is_valid_number, '青森県北津軽郡鶴田町木筒');
ok($zip->set_number('0383532')->is_valid_number, '青森県北津軽郡鶴田町野木');
ok($zip->set_number('0383541')->is_valid_number, '青森県北津軽郡鶴田町尾原');
ok($zip->set_number('0383542')->is_valid_number, '青森県北津軽郡鶴田町廻堰');
ok($zip->set_number('0383543')->is_valid_number, '青森県北津軽郡鶴田町妙堂崎');
ok($zip->set_number('0383600')->is_valid_number, '青森県北津軽郡板柳町以下に掲載がない場合');
ok($zip->set_number('0383611')->is_valid_number, '青森県弘前市三和');
ok($zip->set_number('0383612')->is_valid_number, '青森県弘前市笹舘');
ok($zip->set_number('0383613')->is_valid_number, '青森県弘前市小友');
ok($zip->set_number('0383614')->is_valid_number, '青森県弘前市種市');
ok($zip->set_number('0383615')->is_valid_number, '青森県弘前市青女子');
ok($zip->set_number('0383621')->is_valid_number, '青森県北津軽郡板柳町五林平');
ok($zip->set_number('0383622')->is_valid_number, '青森県北津軽郡板柳町夕顔関');
ok($zip->set_number('0383623')->is_valid_number, '青森県北津軽郡板柳町常海橋');
ok($zip->set_number('0383624')->is_valid_number, '青森県北津軽郡板柳町滝井');
ok($zip->set_number('0383625')->is_valid_number, '青森県北津軽郡板柳町舘野越');
ok($zip->set_number('0383631')->is_valid_number, '青森県北津軽郡板柳町牡丹森');
ok($zip->set_number('0383632')->is_valid_number, '青森県北津軽郡板柳町柏木');
ok($zip->set_number('0383633')->is_valid_number, '青森県北津軽郡板柳町狐森');
ok($zip->set_number('0383634')->is_valid_number, '青森県北津軽郡板柳町高増');
ok($zip->set_number('0383635')->is_valid_number, '青森県北津軽郡板柳町大俵');
ok($zip->set_number('0383636')->is_valid_number, '青森県北津軽郡板柳町五幾形');
ok($zip->set_number('0383641')->is_valid_number, '青森県北津軽郡板柳町深味');
ok($zip->set_number('0383642')->is_valid_number, '青森県北津軽郡板柳町太田');
ok($zip->set_number('0383643')->is_valid_number, '青森県北津軽郡板柳町長野');
ok($zip->set_number('0383644')->is_valid_number, '青森県北津軽郡板柳町横沢');
ok($zip->set_number('0383645')->is_valid_number, '青森県北津軽郡板柳町辻');
ok($zip->set_number('0383651')->is_valid_number, '青森県北津軽郡板柳町飯田');
ok($zip->set_number('0383661')->is_valid_number, '青森県北津軽郡板柳町福野田');
ok($zip->set_number('0383662')->is_valid_number, '青森県北津軽郡板柳町板柳');
ok($zip->set_number('0383671')->is_valid_number, '青森県北津軽郡板柳町掛落林');
ok($zip->set_number('0383672')->is_valid_number, '青森県北津軽郡板柳町灰沼');
ok($zip->set_number('0383673')->is_valid_number, '青森県北津軽郡板柳町小幡');
ok($zip->set_number('0383681')->is_valid_number, '青森県北津軽郡板柳町野中');
ok($zip->set_number('0383682')->is_valid_number, '青森県北津軽郡板柳町石野');
ok($zip->set_number('0383683')->is_valid_number, '青森県北津軽郡板柳町赤田');
ok($zip->set_number('0383684')->is_valid_number, '青森県北津軽郡板柳町三千石');
ok($zip->set_number('0383685')->is_valid_number, '青森県北津軽郡板柳町いたや町');
ok($zip->set_number('0383800')->is_valid_number, '青森県南津軽郡藤崎町以下に掲載がない場合');
ok($zip->set_number('0383801')->is_valid_number, '青森県南津軽郡藤崎町藤越');
ok($zip->set_number('0383802')->is_valid_number, '青森県南津軽郡藤崎町藤崎');
ok($zip->set_number('0383803')->is_valid_number, '青森県南津軽郡藤崎町西豊田');
ok($zip->set_number('0383804')->is_valid_number, '青森県南津軽郡藤崎町葛野');
ok($zip->set_number('0383805')->is_valid_number, '青森県南津軽郡藤崎町五林');
ok($zip->set_number('0383806')->is_valid_number, '青森県南津軽郡藤崎町林崎');
ok($zip->set_number('0383811')->is_valid_number, '青森県南津軽郡藤崎町中島');
ok($zip->set_number('0383812')->is_valid_number, '青森県南津軽郡藤崎町小畑');
ok($zip->set_number('0383813')->is_valid_number, '青森県南津軽郡藤崎町矢沢');
ok($zip->set_number('0383814')->is_valid_number, '青森県南津軽郡藤崎町水沼');
ok($zip->set_number('0383821')->is_valid_number, '青森県弘前市百田');
ok($zip->set_number('0383831')->is_valid_number, '青森県南津軽郡藤崎町中野目');
ok($zip->set_number('0383832')->is_valid_number, '青森県南津軽郡藤崎町吉向');
ok($zip->set_number('0383833')->is_valid_number, '青森県南津軽郡藤崎町亀岡');
ok($zip->set_number('0383834')->is_valid_number, '青森県南津軽郡藤崎町西中野目');
ok($zip->set_number('0383835')->is_valid_number, '青森県南津軽郡藤崎町俵舛');
ok($zip->set_number('0383836')->is_valid_number, '青森県南津軽郡藤崎町下俵舛');
ok($zip->set_number('0383837')->is_valid_number, '青森県南津軽郡藤崎町柏木堰');
ok($zip->set_number('0383874')->is_valid_number, '青森県弘前市津賀野(その他)');
ok($zip->set_number('0390100')->is_valid_number, '青森県三戸郡三戸町以下に掲載がない場合');
ok($zip->set_number('0390100')->is_valid_number, '青森県三戸郡南部町以下に掲載がない場合');
ok($zip->set_number('0390101')->is_valid_number, '青森県三戸郡南部町玉掛');
ok($zip->set_number('0390102')->is_valid_number, '青森県三戸郡南部町赤石');
ok($zip->set_number('0390103')->is_valid_number, '青森県三戸郡南部町大向');
ok($zip->set_number('0390104')->is_valid_number, '青森県三戸郡南部町小向');
ok($zip->set_number('0390105')->is_valid_number, '青森県三戸郡南部町沖田面');
ok($zip->set_number('0390106')->is_valid_number, '青森県三戸郡南部町相内(その他)');
ok($zip->set_number('0390111')->is_valid_number, '青森県三戸郡三戸町泉山');
ok($zip->set_number('0390112')->is_valid_number, '青森県三戸郡三戸町梅内');
ok($zip->set_number('0390113')->is_valid_number, '青森県三戸郡三戸町目時');
ok($zip->set_number('0390121')->is_valid_number, '青森県三戸郡三戸町豊川');
ok($zip->set_number('0390122')->is_valid_number, '青森県三戸郡三戸町斗内');
ok($zip->set_number('0390131')->is_valid_number, '青森県三戸郡三戸町二日町');
ok($zip->set_number('0390132')->is_valid_number, '青森県三戸郡三戸町在府小路町');
ok($zip->set_number('0390133')->is_valid_number, '青森県三戸郡三戸町馬喰町');
ok($zip->set_number('0390134')->is_valid_number, '青森県三戸郡三戸町同心町');
ok($zip->set_number('0390135')->is_valid_number, '青森県三戸郡三戸町八日町');
ok($zip->set_number('0390141')->is_valid_number, '青森県三戸郡三戸町川守田');
ok($zip->set_number('0390142')->is_valid_number, '青森県三戸郡三戸町久慈町');
ok($zip->set_number('0390143')->is_valid_number, '青森県三戸郡三戸町川守田町');
ok($zip->set_number('0390144')->is_valid_number, '青森県三戸郡三戸町六日町');
ok($zip->set_number('0390200')->is_valid_number, '青森県三戸郡田子町以下に掲載がない場合');
ok($zip->set_number('0390201')->is_valid_number, '青森県三戸郡田子町田子');
ok($zip->set_number('0390202')->is_valid_number, '青森県三戸郡田子町相米');
ok($zip->set_number('0390311')->is_valid_number, '青森県三戸郡田子町原');
ok($zip->set_number('0390312')->is_valid_number, '青森県三戸郡田子町石亀');
ok($zip->set_number('0390313')->is_valid_number, '青森県三戸郡田子町茂市');
ok($zip->set_number('0390314')->is_valid_number, '青森県三戸郡田子町遠瀬');
ok($zip->set_number('0390315')->is_valid_number, '青森県三戸郡田子町夏坂');
ok($zip->set_number('0390316')->is_valid_number, '青森県三戸郡田子町関');
ok($zip->set_number('0390317')->is_valid_number, '青森県三戸郡田子町山口');
ok($zip->set_number('0390451')->is_valid_number, '青森県三戸郡三戸町蛇沼');
ok($zip->set_number('0390452')->is_valid_number, '青森県三戸郡三戸町袴田');
ok($zip->set_number('0390453')->is_valid_number, '青森県三戸郡三戸町貝守');
ok($zip->set_number('0390501')->is_valid_number, '青森県三戸郡南部町上名久井');
ok($zip->set_number('0390502')->is_valid_number, '青森県三戸郡南部町下名久井');
ok($zip->set_number('0390503')->is_valid_number, '青森県三戸郡南部町平');
ok($zip->set_number('0390504')->is_valid_number, '青森県三戸郡南部町鳥舌内');
ok($zip->set_number('0390505')->is_valid_number, '青森県三戸郡南部町鳥谷');
ok($zip->set_number('0390506')->is_valid_number, '青森県三戸郡南部町法光寺');
ok($zip->set_number('0390507')->is_valid_number, '青森県三戸郡南部町高瀬');
ok($zip->set_number('0390606')->is_valid_number, '青森県三戸郡南部町相内(柏木久保、鴨ノ首、留ノ沢、沼久保、屋敷久保)');
ok($zip->set_number('0390611')->is_valid_number, '青森県三戸郡南部町斗賀');
ok($zip->set_number('0390612')->is_valid_number, '青森県三戸郡南部町剣吉');
ok($zip->set_number('0390613')->is_valid_number, '青森県三戸郡南部町森越');
ok($zip->set_number('0390614')->is_valid_number, '青森県三戸郡南部町虎渡');
ok($zip->set_number('0390801')->is_valid_number, '青森県三戸郡南部町片岸');
ok($zip->set_number('0390802')->is_valid_number, '青森県三戸郡南部町苫米地');
ok($zip->set_number('0390803')->is_valid_number, '青森県三戸郡南部町麦沢');
ok($zip->set_number('0390804')->is_valid_number, '青森県三戸郡南部町高橋');
ok($zip->set_number('0390805')->is_valid_number, '青森県三戸郡南部町小泉');
ok($zip->set_number('0390811')->is_valid_number, '青森県三戸郡南部町法師岡');
ok($zip->set_number('0390812')->is_valid_number, '青森県三戸郡南部町椛木');
ok($zip->set_number('0390813')->is_valid_number, '青森県三戸郡南部町杉沢');
ok($zip->set_number('0390814')->is_valid_number, '青森県三戸郡南部町埖渡');
ok($zip->set_number('0390815')->is_valid_number, '青森県三戸郡南部町福田');
ok($zip->set_number('0391101')->is_valid_number, '青森県八戸市尻内町');
ok($zip->set_number('0391102')->is_valid_number, '青森県八戸市一番町');
ok($zip->set_number('0391103')->is_valid_number, '青森県八戸市長苗代');
ok($zip->set_number('0391104')->is_valid_number, '青森県八戸市田面木');
ok($zip->set_number('0391105')->is_valid_number, '青森県八戸市八幡');
ok($zip->set_number('0391106')->is_valid_number, '青森県八戸市坂牛');
ok($zip->set_number('0391107')->is_valid_number, '青森県八戸市櫛引(その他)');
ok($zip->set_number('0391108')->is_valid_number, '青森県八戸市上野');
ok($zip->set_number('0391109')->is_valid_number, '青森県八戸市豊崎町');
ok($zip->set_number('0391111')->is_valid_number, '青森県八戸市東白山台');
ok($zip->set_number('0391112')->is_valid_number, '青森県八戸市南白山台');
ok($zip->set_number('0391113')->is_valid_number, '青森県八戸市西白山台');
ok($zip->set_number('0391114')->is_valid_number, '青森県八戸市北白山台');
ok($zip->set_number('0391121')->is_valid_number, '青森県八戸市卸センター');
ok($zip->set_number('0391160')->is_valid_number, '青森県八戸市小田');
ok($zip->set_number('0391161')->is_valid_number, '青森県八戸市河原木');
ok($zip->set_number('0391162')->is_valid_number, '青森県八戸市豊洲');
ok($zip->set_number('0391163')->is_valid_number, '青森県八戸市高州');
ok($zip->set_number('0391164')->is_valid_number, '青森県八戸市下長');
ok($zip->set_number('0391165')->is_valid_number, '青森県八戸市石堂');
ok($zip->set_number('0391166')->is_valid_number, '青森県八戸市根城');
ok($zip->set_number('0391167')->is_valid_number, '青森県八戸市沢里');
ok($zip->set_number('0391168')->is_valid_number, '青森県八戸市八太郎');
ok($zip->set_number('0391169')->is_valid_number, '青森県八戸市日計');
ok($zip->set_number('0391200')->is_valid_number, '青森県三戸郡階上町以下に掲載がない場合');
ok($zip->set_number('0391201')->is_valid_number, '青森県三戸郡階上町道仏');
ok($zip->set_number('0391202')->is_valid_number, '青森県三戸郡階上町赤保内');
ok($zip->set_number('0391203')->is_valid_number, '青森県三戸郡階上町鳥屋部');
ok($zip->set_number('0391204')->is_valid_number, '青森県三戸郡階上町平内');
ok($zip->set_number('0391205')->is_valid_number, '青森県三戸郡階上町晴山沢');
ok($zip->set_number('0391206')->is_valid_number, '青森県三戸郡階上町田代');
ok($zip->set_number('0391207')->is_valid_number, '青森県三戸郡階上町金山沢');
ok($zip->set_number('0391208')->is_valid_number, '青森県三戸郡階上町角柄折');
ok($zip->set_number('0391211')->is_valid_number, '青森県三戸郡階上町蒼前東');
ok($zip->set_number('0391212')->is_valid_number, '青森県三戸郡階上町蒼前西');
ok($zip->set_number('0391500')->is_valid_number, '青森県三戸郡五戸町以下に掲載がない場合');
ok($zip->set_number('0391501')->is_valid_number, '青森県三戸郡五戸町上市川');
ok($zip->set_number('0391502')->is_valid_number, '青森県三戸郡五戸町切谷内(その他)');
ok($zip->set_number('0391503')->is_valid_number, '青森県三戸郡五戸町大久保');
ok($zip->set_number('0391503')->is_valid_number, '青森県三戸郡五戸町佐野上谷地');
ok($zip->set_number('0391503')->is_valid_number, '青森県三戸郡五戸町鮫ノ口');
ok($zip->set_number('0391504')->is_valid_number, '青森県三戸郡五戸町兎内');
ok($zip->set_number('0391504')->is_valid_number, '青森県三戸郡五戸町兎内上保土沢');
ok($zip->set_number('0391504')->is_valid_number, '青森県三戸郡五戸町兎内下保土沢');
ok($zip->set_number('0391504')->is_valid_number, '青森県三戸郡五戸町兎内下川原');
ok($zip->set_number('0391504')->is_valid_number, '青森県三戸郡五戸町兎内下谷地');
ok($zip->set_number('0391504')->is_valid_number, '青森県三戸郡五戸町上兎内');
ok($zip->set_number('0391505')->is_valid_number, '青森県三戸郡五戸町石仏');
ok($zip->set_number('0391505')->is_valid_number, '青森県三戸郡五戸町石仏上川原');
ok($zip->set_number('0391505')->is_valid_number, '青森県三戸郡五戸町石仏下川原');
ok($zip->set_number('0391505')->is_valid_number, '青森県三戸郡五戸町石仏前');
ok($zip->set_number('0391506')->is_valid_number, '青森県三戸郡五戸町熊野林');
ok($zip->set_number('0391506')->is_valid_number, '青森県三戸郡五戸町熊野林後');
ok($zip->set_number('0391506')->is_valid_number, '青森県三戸郡五戸町熊野林前');
ok($zip->set_number('0391507')->is_valid_number, '青森県三戸郡五戸町蛯川後');
ok($zip->set_number('0391507')->is_valid_number, '青森県三戸郡五戸町蛯川前川原');
ok($zip->set_number('0391507')->is_valid_number, '青森県三戸郡五戸町蛯川村');
ok($zip->set_number('0391507')->is_valid_number, '青森県三戸郡五戸町上谷地');
ok($zip->set_number('0391507')->is_valid_number, '青森県三戸郡五戸町中森');
ok($zip->set_number('0391508')->is_valid_number, '青森県三戸郡五戸町赤川');
ok($zip->set_number('0391508')->is_valid_number, '青森県三戸郡五戸町赤川前');
ok($zip->set_number('0391508')->is_valid_number, '青森県三戸郡五戸町上新道');
ok($zip->set_number('0391508')->is_valid_number, '青森県三戸郡五戸町下新道');
ok($zip->set_number('0391508')->is_valid_number, '青森県三戸郡五戸町土取場');
ok($zip->set_number('0391508')->is_valid_number, '青森県三戸郡五戸町中寄');
ok($zip->set_number('0391511')->is_valid_number, '青森県三戸郡五戸町鍜冶屋窪');
ok($zip->set_number('0391511')->is_valid_number, '青森県三戸郡五戸町鍜冶屋窪上ミ');
ok($zip->set_number('0391511')->is_valid_number, '青森県三戸郡五戸町鍜冶屋敷');
ok($zip->set_number('0391511')->is_valid_number, '青森県三戸郡五戸町丁塚');
ok($zip->set_number('0391512')->is_valid_number, '青森県三戸郡五戸町西ノ沢');
ok($zip->set_number('0391513')->is_valid_number, '青森県三戸郡五戸町古館');
ok($zip->set_number('0391513')->is_valid_number, '青森県三戸郡五戸町古館向');
ok($zip->set_number('0391513')->is_valid_number, '青森県三戸郡五戸町古館向川原');
ok($zip->set_number('0391513')->is_valid_number, '青森県三戸郡五戸町古館脇');
ok($zip->set_number('0391514')->is_valid_number, '青森県三戸郡五戸町下中崎');
ok($zip->set_number('0391514')->is_valid_number, '青森県三戸郡五戸町中崎');
ok($zip->set_number('0391515')->is_valid_number, '青森県三戸郡五戸町熊ノ沢');
ok($zip->set_number('0391515')->is_valid_number, '青森県三戸郡五戸町熊ノ沢頭');
ok($zip->set_number('0391515')->is_valid_number, '青森県三戸郡五戸町治郎左エ門長根');
ok($zip->set_number('0391516')->is_valid_number, '青森県三戸郡五戸町市川道十文字');
ok($zip->set_number('0391517')->is_valid_number, '青森県三戸郡五戸町沢向');
ok($zip->set_number('0391518')->is_valid_number, '青森県三戸郡五戸町下モ沢向');
ok($zip->set_number('0391519')->is_valid_number, '青森県三戸郡五戸町天満');
ok($zip->set_number('0391519')->is_valid_number, '青森県三戸郡五戸町天満後');
ok($zip->set_number('0391519')->is_valid_number, '青森県三戸郡五戸町天満下川原');
ok($zip->set_number('0391521')->is_valid_number, '青森県三戸郡五戸町五百窪');
ok($zip->set_number('0391521')->is_valid_number, '青森県三戸郡五戸町泉窪');
ok($zip->set_number('0391521')->is_valid_number, '青森県三戸郡五戸町大渡');
ok($zip->set_number('0391521')->is_valid_number, '青森県三戸郡五戸町大渡道ノ下');
ok($zip->set_number('0391521')->is_valid_number, '青森県三戸郡五戸町久蔵窪');
ok($zip->set_number('0391522')->is_valid_number, '青森県三戸郡五戸町小渡');
ok($zip->set_number('0391522')->is_valid_number, '青森県三戸郡五戸町小渡頭');
ok($zip->set_number('0391522')->is_valid_number, '青森県三戸郡五戸町徳良窪');
ok($zip->set_number('0391522')->is_valid_number, '青森県三戸郡五戸町苗代沢');
ok($zip->set_number('0391523')->is_valid_number, '青森県三戸郡五戸町上保土沢');
ok($zip->set_number('0391523')->is_valid_number, '青森県三戸郡五戸町下保土沢');
ok($zip->set_number('0391523')->is_valid_number, '青森県三戸郡五戸町新蔵長根');
ok($zip->set_number('0391524')->is_valid_number, '青森県三戸郡五戸町豊間内');
ok($zip->set_number('0391525')->is_valid_number, '青森県三戸郡五戸町地蔵岱');
ok($zip->set_number('0391526')->is_valid_number, '青森県三戸郡五戸町上長下');
ok($zip->set_number('0391526')->is_valid_number, '青森県三戸郡五戸町下長下');
ok($zip->set_number('0391526')->is_valid_number, '青森県三戸郡五戸町惣林橋');
ok($zip->set_number('0391527')->is_valid_number, '青森県三戸郡五戸町扇田');
ok($zip->set_number('0391528')->is_valid_number, '青森県三戸郡五戸町浅水');
ok($zip->set_number('0391529')->is_valid_number, '青森県三戸郡五戸町手倉橋');
ok($zip->set_number('0391531')->is_valid_number, '青森県三戸郡五戸町狐森');
ok($zip->set_number('0391531')->is_valid_number, '青森県三戸郡五戸町狐森北');
ok($zip->set_number('0391532')->is_valid_number, '青森県三戸郡五戸町観音堂');
ok($zip->set_number('0391533')->is_valid_number, '青森県三戸郡五戸町上大町');
ok($zip->set_number('0391533')->is_valid_number, '青森県三戸郡五戸町野月');
ok($zip->set_number('0391534')->is_valid_number, '青森県三戸郡五戸町荒町');
ok($zip->set_number('0391535')->is_valid_number, '青森県三戸郡五戸町新丁');
ok($zip->set_number('0391536')->is_valid_number, '青森県三戸郡五戸町愛宕後');
ok($zip->set_number('0391536')->is_valid_number, '青森県三戸郡五戸町愛宕下タ');
ok($zip->set_number('0391536')->is_valid_number, '青森県三戸郡五戸町愛宕丁');
ok($zip->set_number('0391537')->is_valid_number, '青森県三戸郡五戸町ウルエ長根');
ok($zip->set_number('0391537')->is_valid_number, '青森県三戸郡五戸町ウルエ長根下');
ok($zip->set_number('0391537')->is_valid_number, '青森県三戸郡五戸町追分');
ok($zip->set_number('0391537')->is_valid_number, '青森県三戸郡五戸町二本柳');
ok($zip->set_number('0391537')->is_valid_number, '青森県三戸郡五戸町二本柳向');
ok($zip->set_number('0391538')->is_valid_number, '青森県三戸郡五戸町塚無岱');
ok($zip->set_number('0391538')->is_valid_number, '青森県三戸郡五戸町古街道長根');
ok($zip->set_number('0391539')->is_valid_number, '青森県三戸郡五戸町石沢境');
ok($zip->set_number('0391539')->is_valid_number, '青森県三戸郡五戸町中ノ沢');
ok($zip->set_number('0391539')->is_valid_number, '青森県三戸郡五戸町中ノ沢西張');
ok($zip->set_number('0391541')->is_valid_number, '青森県三戸郡五戸町新田窪');
ok($zip->set_number('0391542')->is_valid_number, '青森県三戸郡五戸町中道');
ok($zip->set_number('0391542')->is_valid_number, '青森県三戸郡五戸町中道十文字');
ok($zip->set_number('0391543')->is_valid_number, '青森県三戸郡五戸町竹原');
ok($zip->set_number('0391544')->is_valid_number, '青森県三戸郡五戸町二階平');
ok($zip->set_number('0391544')->is_valid_number, '青森県三戸郡五戸町二階平下タ');
ok($zip->set_number('0391545')->is_valid_number, '青森県三戸郡五戸町正場沢');
ok($zip->set_number('0391545')->is_valid_number, '青森県三戸郡五戸町正場沢長根');
ok($zip->set_number('0391546')->is_valid_number, '青森県三戸郡五戸町下タノ沢');
ok($zip->set_number('0391546')->is_valid_number, '青森県三戸郡五戸町下タノ沢頭');
ok($zip->set_number('0391546')->is_valid_number, '青森県三戸郡五戸町土井頭');
ok($zip->set_number('0391547')->is_valid_number, '青森県三戸郡五戸町神明後');
ok($zip->set_number('0391548')->is_valid_number, '青森県三戸郡五戸町新町');
ok($zip->set_number('0391551')->is_valid_number, '青森県三戸郡五戸町上新井田');
ok($zip->set_number('0391551')->is_valid_number, '青森県三戸郡五戸町上新井田前');
ok($zip->set_number('0391552')->is_valid_number, '青森県三戸郡五戸町姥堤');
ok($zip->set_number('0391552')->is_valid_number, '青森県三戸郡五戸町上高田');
ok($zip->set_number('0391552')->is_valid_number, '青森県三戸郡五戸町筒口川原');
ok($zip->set_number('0391552')->is_valid_number, '青森県三戸郡五戸町中高田');
ok($zip->set_number('0391553')->is_valid_number, '青森県三戸郡五戸町川原町下裏');
ok($zip->set_number('0391553')->is_valid_number, '青森県三戸郡五戸町川原町西裏');
ok($zip->set_number('0391554')->is_valid_number, '青森県三戸郡五戸町川原町');
ok($zip->set_number('0391554')->is_valid_number, '青森県三戸郡五戸町川原町裏');
ok($zip->set_number('0391554')->is_valid_number, '青森県三戸郡五戸町傳兵ヱ丁');
ok($zip->set_number('0391555')->is_valid_number, '青森県三戸郡五戸町下高田');
ok($zip->set_number('0391555')->is_valid_number, '青森県三戸郡五戸町古堂');
ok($zip->set_number('0391555')->is_valid_number, '青森県三戸郡五戸町古堂後');
ok($zip->set_number('0391556')->is_valid_number, '青森県三戸郡五戸町油出');
ok($zip->set_number('0391557')->is_valid_number, '青森県三戸郡五戸町上川原');
ok($zip->set_number('0391557')->is_valid_number, '青森県三戸郡五戸町八景');
ok($zip->set_number('0391558')->is_valid_number, '青森県三戸郡五戸町沢');
ok($zip->set_number('0391558')->is_valid_number, '青森県三戸郡五戸町館');
ok($zip->set_number('0391558')->is_valid_number, '青森県三戸郡五戸町博労町');
ok($zip->set_number('0391558')->is_valid_number, '青森県三戸郡五戸町堀合');
ok($zip->set_number('0391559')->is_valid_number, '青森県三戸郡五戸町下大町');
ok($zip->set_number('0391559')->is_valid_number, '青森県三戸郡五戸町横丁');
ok($zip->set_number('0391561')->is_valid_number, '青森県三戸郡五戸町赤坂');
ok($zip->set_number('0391561')->is_valid_number, '青森県三戸郡五戸町越掛沢');
ok($zip->set_number('0391561')->is_valid_number, '青森県三戸郡五戸町越掛沢前');
ok($zip->set_number('0391561')->is_valid_number, '青森県三戸郡五戸町越掛沢道下モ');
ok($zip->set_number('0391562')->is_valid_number, '青森県三戸郡五戸町鹿内');
ok($zip->set_number('0391562')->is_valid_number, '青森県三戸郡五戸町鹿内沖');
ok($zip->set_number('0391562')->is_valid_number, '青森県三戸郡五戸町鹿内下モ');
ok($zip->set_number('0391562')->is_valid_number, '青森県三戸郡五戸町鹿内前');
ok($zip->set_number('0391562')->is_valid_number, '青森県三戸郡五戸町白山');
ok($zip->set_number('0391562')->is_valid_number, '青森県三戸郡五戸町白山前');
ok($zip->set_number('0391563')->is_valid_number, '青森県三戸郡五戸町岡谷地');
ok($zip->set_number('0391563')->is_valid_number, '青森県三戸郡五戸町毛無森');
ok($zip->set_number('0391563')->is_valid_number, '青森県三戸郡五戸町大学沢');
ok($zip->set_number('0391563')->is_valid_number, '青森県三戸郡五戸町大学沢向');
ok($zip->set_number('0391563')->is_valid_number, '青森県三戸郡五戸町大工窪');
ok($zip->set_number('0391563')->is_valid_number, '青森県三戸郡五戸町平佐窪');
ok($zip->set_number('0391564')->is_valid_number, '青森県三戸郡五戸町古館下川原');
ok($zip->set_number('0391564')->is_valid_number, '青森県三戸郡五戸町六角');
ok($zip->set_number('0391565')->is_valid_number, '青森県三戸郡五戸町下新井田');
ok($zip->set_number('0391565')->is_valid_number, '青森県三戸郡五戸町下新井田前');
ok($zip->set_number('0391565')->is_valid_number, '青森県三戸郡五戸町花道川原');
ok($zip->set_number('0391566')->is_valid_number, '青森県三戸郡五戸町幸ノ神');
ok($zip->set_number('0391566')->is_valid_number, '青森県三戸郡五戸町幸ノ神前');
ok($zip->set_number('0391567')->is_valid_number, '青森県三戸郡五戸町上大平楽');
ok($zip->set_number('0391567')->is_valid_number, '青森県三戸郡五戸町下大平楽');
ok($zip->set_number('0391568')->is_valid_number, '青森県三戸郡五戸町銀杏木');
ok($zip->set_number('0391568')->is_valid_number, '青森県三戸郡五戸町銀杏木前');
ok($zip->set_number('0391568')->is_valid_number, '青森県三戸郡五戸町一本木');
ok($zip->set_number('0391568')->is_valid_number, '青森県三戸郡五戸町一本木前');
ok($zip->set_number('0391568')->is_valid_number, '青森県三戸郡五戸町應田');
ok($zip->set_number('0391568')->is_valid_number, '青森県三戸郡五戸町傘松');
ok($zip->set_number('0391568')->is_valid_number, '青森県三戸郡五戸町傘松前');
ok($zip->set_number('0391569')->is_valid_number, '青森県三戸郡五戸町根岸');
ok($zip->set_number('0391569')->is_valid_number, '青森県三戸郡五戸町虫追塚前');
ok($zip->set_number('0391701')->is_valid_number, '青森県三戸郡五戸町倉石石沢');
ok($zip->set_number('0391702')->is_valid_number, '青森県三戸郡五戸町倉石中市');
ok($zip->set_number('0391703')->is_valid_number, '青森県三戸郡五戸町倉石又重');
ok($zip->set_number('0391800')->is_valid_number, '青森県三戸郡新郷村以下に掲載がない場合');
ok($zip->set_number('0391801')->is_valid_number, '青森県三戸郡新郷村戸来');
ok($zip->set_number('0391802')->is_valid_number, '青森県三戸郡新郷村西越');
ok($zip->set_number('0392102')->is_valid_number, '青森県上北郡おいらせ町豊栄');
ok($zip->set_number('0392111')->is_valid_number, '青森県上北郡おいらせ町西後谷地');
ok($zip->set_number('0392112')->is_valid_number, '青森県上北郡おいらせ町中野平');
ok($zip->set_number('0392113')->is_valid_number, '青森県上北郡おいらせ町犬毛谷地');
ok($zip->set_number('0392114')->is_valid_number, '青森県上北郡おいらせ町高田');
ok($zip->set_number('0392115')->is_valid_number, '青森県上北郡おいらせ町菜飯');
ok($zip->set_number('0392116')->is_valid_number, '青森県上北郡おいらせ町秋堂');
ok($zip->set_number('0392117')->is_valid_number, '青森県上北郡おいらせ町川端');
ok($zip->set_number('0392118')->is_valid_number, '青森県上北郡おいらせ町彦七川原');
ok($zip->set_number('0392121')->is_valid_number, '青森県上北郡おいらせ町下境');
ok($zip->set_number('0392122')->is_valid_number, '青森県上北郡おいらせ町沼小屋');
ok($zip->set_number('0392123')->is_valid_number, '青森県上北郡おいらせ町西下谷地');
ok($zip->set_number('0392124')->is_valid_number, '青森県上北郡おいらせ町境田');
ok($zip->set_number('0392125')->is_valid_number, '青森県上北郡おいらせ町三本木');
ok($zip->set_number('0392126')->is_valid_number, '青森県上北郡おいらせ町間木');
ok($zip->set_number('0392127')->is_valid_number, '青森県上北郡おいらせ町木崎');
ok($zip->set_number('0392128')->is_valid_number, '青森県上北郡おいらせ町染屋');
ok($zip->set_number('0392129')->is_valid_number, '青森県上北郡おいらせ町中平下長根山');
ok($zip->set_number('0392131')->is_valid_number, '青森県上北郡おいらせ町向川原');
ok($zip->set_number('0392132')->is_valid_number, '青森県上北郡おいらせ町西前川原');
ok($zip->set_number('0392133')->is_valid_number, '青森県上北郡おいらせ町上川原');
ok($zip->set_number('0392134')->is_valid_number, '青森県上北郡おいらせ町馳下り');
ok($zip->set_number('0392135')->is_valid_number, '青森県上北郡おいらせ町立蛇');
ok($zip->set_number('0392136')->is_valid_number, '青森県上北郡おいらせ町中下田');
ok($zip->set_number('0392141')->is_valid_number, '青森県上北郡おいらせ町明土');
ok($zip->set_number('0392142')->is_valid_number, '青森県上北郡おいらせ町小前谷地');
ok($zip->set_number('0392143')->is_valid_number, '青森県上北郡おいらせ町上水下');
ok($zip->set_number('0392144')->is_valid_number, '青森県上北郡おいらせ町丈の端');
ok($zip->set_number('0392145')->is_valid_number, '青森県上北郡おいらせ町上谷地');
ok($zip->set_number('0392146')->is_valid_number, '青森県上北郡おいらせ町中谷地');
ok($zip->set_number('0392147')->is_valid_number, '青森県上北郡おいらせ町赤田前');
ok($zip->set_number('0392151')->is_valid_number, '青森県上北郡おいらせ町向山');
ok($zip->set_number('0392152')->is_valid_number, '青森県上北郡おいらせ町向山東');
ok($zip->set_number('0392153')->is_valid_number, '青森県上北郡おいらせ町山崎');
ok($zip->set_number('0392154')->is_valid_number, '青森県上北郡おいらせ町豊原');
ok($zip->set_number('0392155')->is_valid_number, '青森県上北郡おいらせ町木ノ下西');
ok($zip->set_number('0392156')->is_valid_number, '青森県上北郡おいらせ町木ノ下南');
ok($zip->set_number('0392157')->is_valid_number, '青森県上北郡おいらせ町木ノ下東');
ok($zip->set_number('0392158')->is_valid_number, '青森県上北郡おいらせ町向山南');
ok($zip->set_number('0392161')->is_valid_number, '青森県上北郡おいらせ町西下川原');
ok($zip->set_number('0392162')->is_valid_number, '青森県上北郡おいらせ町南下田');
ok($zip->set_number('0392163')->is_valid_number, '青森県上北郡おいらせ町館越');
ok($zip->set_number('0392164')->is_valid_number, '青森県上北郡おいらせ町神明前');
ok($zip->set_number('0392165')->is_valid_number, '青森県上北郡おいらせ町阿光坊');
ok($zip->set_number('0392171')->is_valid_number, '青森県上北郡おいらせ町新敷');
ok($zip->set_number('0392172')->is_valid_number, '青森県上北郡おいらせ町洗平');
ok($zip->set_number('0392173')->is_valid_number, '青森県上北郡おいらせ町瓢');
ok($zip->set_number('0392180')->is_valid_number, '青森県上北郡おいらせ町住吉');
ok($zip->set_number('0392181')->is_valid_number, '青森県上北郡おいらせ町古間木山');
ok($zip->set_number('0392182')->is_valid_number, '青森県上北郡おいらせ町鶉久保');
ok($zip->set_number('0392183')->is_valid_number, '青森県上北郡おいらせ町鶉久保山');
ok($zip->set_number('0392184')->is_valid_number, '青森県上北郡おいらせ町浜道');
ok($zip->set_number('0392185')->is_valid_number, '青森県上北郡おいらせ町上久保');
ok($zip->set_number('0392186')->is_valid_number, '青森県上北郡おいらせ町北下田');
ok($zip->set_number('0392187')->is_valid_number, '青森県上北郡おいらせ町緑ケ丘');
ok($zip->set_number('0392188')->is_valid_number, '青森県上北郡おいらせ町若葉');
ok($zip->set_number('0392189')->is_valid_number, '青森県上北郡おいらせ町青葉');
ok($zip->set_number('0392200')->is_valid_number, '青森県上北郡おいらせ町以下に掲載がない場合');
ok($zip->set_number('0392201')->is_valid_number, '青森県上北郡おいらせ町二川目');
ok($zip->set_number('0392202')->is_valid_number, '青森県上北郡おいらせ町向平');
ok($zip->set_number('0392203')->is_valid_number, '青森県上北郡おいらせ町一川目');
ok($zip->set_number('0392204')->is_valid_number, '青森県上北郡おいらせ町深沢');
ok($zip->set_number('0392205')->is_valid_number, '青森県上北郡おいらせ町深沢平');
ok($zip->set_number('0392206')->is_valid_number, '青森県上北郡おいらせ町松原');
ok($zip->set_number('0392211')->is_valid_number, '青森県上北郡おいらせ町新田');
ok($zip->set_number('0392212')->is_valid_number, '青森県上北郡おいらせ町東下川原');
ok($zip->set_number('0392213')->is_valid_number, '青森県上北郡おいらせ町堀ノ内');
ok($zip->set_number('0392214')->is_valid_number, '青森県上北郡おいらせ町東前川原');
ok($zip->set_number('0392215')->is_valid_number, '青森県上北郡おいらせ町下屋敷');
ok($zip->set_number('0392216')->is_valid_number, '青森県上北郡おいらせ町後田');
ok($zip->set_number('0392217')->is_valid_number, '青森県上北郡おいらせ町牛込平');
ok($zip->set_number('0392221')->is_valid_number, '青森県上北郡おいらせ町上前田');
ok($zip->set_number('0392222')->is_valid_number, '青森県上北郡おいらせ町下前田');
ok($zip->set_number('0392223')->is_valid_number, '青森県上北郡おいらせ町苗平谷地');
ok($zip->set_number('0392224')->is_valid_number, '青森県上北郡おいらせ町下明堂');
ok($zip->set_number('0392225')->is_valid_number, '青森県上北郡おいらせ町上明堂');
ok($zip->set_number('0392226')->is_valid_number, '青森県上北郡おいらせ町新助川原');
ok($zip->set_number('0392231')->is_valid_number, '青森県上北郡おいらせ町東下谷地');
ok($zip->set_number('0392232')->is_valid_number, '青森県上北郡おいらせ町東後谷地');
ok($zip->set_number('0392233')->is_valid_number, '青森県上北郡おいらせ町沼端');
ok($zip->set_number('0392234')->is_valid_number, '青森県上北郡おいらせ町堤田');
ok($zip->set_number('0392235')->is_valid_number, '青森県上北郡おいらせ町千刈田');
ok($zip->set_number('0392236')->is_valid_number, '青森県上北郡おいらせ町洋光台');
ok($zip->set_number('0392241')->is_valid_number, '青森県八戸市市川町');
ok($zip->set_number('0392242')->is_valid_number, '青森県八戸市多賀台');
ok($zip->set_number('0392243')->is_valid_number, '青森県八戸市松ケ丘');
ok($zip->set_number('0392245')->is_valid_number, '青森県八戸市北インター工業団地');
ok($zip->set_number('0392246')->is_valid_number, '青森県八戸市桔梗野工業団地');
ok($zip->set_number('0392251')->is_valid_number, '青森県上北郡おいらせ町向坂');
ok($zip->set_number('0392252')->is_valid_number, '青森県上北郡おいらせ町黒坂谷地');
ok($zip->set_number('0392253')->is_valid_number, '青森県上北郡おいらせ町獺野');
ok($zip->set_number('0392254')->is_valid_number, '青森県上北郡おいらせ町苗振谷地');
ok($zip->set_number('0392255')->is_valid_number, '青森県上北郡おいらせ町土取');
ok($zip->set_number('0392300')->is_valid_number, '青森県上北郡六戸町以下に掲載がない場合');
ok($zip->set_number('0392302')->is_valid_number, '青森県三戸郡五戸町切谷内(北田ノ沢)');
ok($zip->set_number('0392311')->is_valid_number, '青森県上北郡六戸町上吉田');
ok($zip->set_number('0392312')->is_valid_number, '青森県上北郡六戸町下吉田');
ok($zip->set_number('0392313')->is_valid_number, '青森県上北郡六戸町鶴喰');
ok($zip->set_number('0392314')->is_valid_number, '青森県上北郡六戸町小平');
ok($zip->set_number('0392315')->is_valid_number, '青森県上北郡六戸町柳町');
ok($zip->set_number('0392371')->is_valid_number, '青森県上北郡六戸町犬落瀬(その他)');
ok($zip->set_number('0392372')->is_valid_number, '青森県上北郡六戸町折茂(その他)');
ok($zip->set_number('0392401')->is_valid_number, '青森県上北郡東北町上野');
ok($zip->set_number('0392402')->is_valid_number, '青森県上北郡東北町大浦');
ok($zip->set_number('0392403')->is_valid_number, '青森県上北郡東北町新舘');
ok($zip->set_number('0392404')->is_valid_number, '青森県上北郡東北町上北北');
ok($zip->set_number('0392405')->is_valid_number, '青森県上北郡東北町上北南');
ok($zip->set_number('0392406')->is_valid_number, '青森県上北郡東北町旭北');
ok($zip->set_number('0392407')->is_valid_number, '青森県上北郡東北町旭南');
ok($zip->set_number('0392500')->is_valid_number, '青森県上北郡七戸町以下に掲載がない場合');
ok($zip->set_number('0392501')->is_valid_number, '青森県上北郡七戸町荒熊内');
ok($zip->set_number('0392502')->is_valid_number, '青森県上北郡七戸町大沢');
ok($zip->set_number('0392503')->is_valid_number, '青森県上北郡七戸町豊間内');
ok($zip->set_number('0392504')->is_valid_number, '青森県上北郡七戸町寒水');
ok($zip->set_number('0392505')->is_valid_number, '青森県上北郡七戸町立野頭');
ok($zip->set_number('0392506')->is_valid_number, '青森県上北郡七戸町膝森');
ok($zip->set_number('0392507')->is_valid_number, '青森県上北郡七戸町えぞ花');
ok($zip->set_number('0392508')->is_valid_number, '青森県上北郡七戸町大池');
ok($zip->set_number('0392511')->is_valid_number, '青森県上北郡七戸町笊田川久保');
ok($zip->set_number('0392512')->is_valid_number, '青森県上北郡七戸町笊田');
ok($zip->set_number('0392513')->is_valid_number, '青森県上北郡七戸町東槻木');
ok($zip->set_number('0392514')->is_valid_number, '青森県上北郡七戸町太田野');
ok($zip->set_number('0392515')->is_valid_number, '青森県上北郡七戸町蒼前');
ok($zip->set_number('0392516')->is_valid_number, '青森県上北郡七戸町舘野');
ok($zip->set_number('0392517')->is_valid_number, '青森県上北郡七戸町夏焼');
ok($zip->set_number('0392518')->is_valid_number, '青森県上北郡七戸町天神林');
ok($zip->set_number('0392521')->is_valid_number, '青森県上北郡七戸町天王');
ok($zip->set_number('0392522')->is_valid_number, '青森県上北郡七戸町倉越');
ok($zip->set_number('0392523')->is_valid_number, '青森県上北郡七戸町影津内');
ok($zip->set_number('0392524')->is_valid_number, '青森県上北郡七戸町寺裏');
ok($zip->set_number('0392525')->is_valid_number, '青森県上北郡七戸町七戸');
ok($zip->set_number('0392526')->is_valid_number, '青森県上北郡七戸町上町野');
ok($zip->set_number('0392527')->is_valid_number, '青森県上北郡七戸町町');
ok($zip->set_number('0392531')->is_valid_number, '青森県上北郡七戸町太田');
ok($zip->set_number('0392532')->is_valid_number, '青森県上北郡七戸町大林');
ok($zip->set_number('0392533')->is_valid_number, '青森県上北郡七戸町川去');
ok($zip->set_number('0392534')->is_valid_number, '青森県上北郡七戸町荒屋');
ok($zip->set_number('0392535')->is_valid_number, '青森県上北郡七戸町沼ノ沢');
ok($zip->set_number('0392536')->is_valid_number, '青森県上北郡七戸町野佐掛');
ok($zip->set_number('0392537')->is_valid_number, '青森県上北郡七戸町賽ノ神');
ok($zip->set_number('0392538')->is_valid_number, '青森県上北郡七戸町寺下');
ok($zip->set_number('0392539')->is_valid_number, '青森県上北郡七戸町中村');
ok($zip->set_number('0392541')->is_valid_number, '青森県上北郡七戸町都平');
ok($zip->set_number('0392542')->is_valid_number, '青森県上北郡七戸町萩ノ沢');
ok($zip->set_number('0392543')->is_valid_number, '青森県上北郡七戸町有田沢');
ok($zip->set_number('0392544')->is_valid_number, '青森県上北郡七戸町八栗平');
ok($zip->set_number('0392545')->is_valid_number, '青森県上北郡七戸町別曽');
ok($zip->set_number('0392546')->is_valid_number, '青森県上北郡七戸町清水頭');
ok($zip->set_number('0392547')->is_valid_number, '青森県上北郡七戸町矢倉');
ok($zip->set_number('0392548')->is_valid_number, '青森県上北郡七戸町見町');
ok($zip->set_number('0392549')->is_valid_number, '青森県上北郡七戸町下見町');
ok($zip->set_number('0392551')->is_valid_number, '青森県上北郡七戸町薬師平');
ok($zip->set_number('0392552')->is_valid_number, '青森県上北郡七戸町鶴打田');
ok($zip->set_number('0392553')->is_valid_number, '青森県上北郡七戸町八尺堂');
ok($zip->set_number('0392554')->is_valid_number, '青森県上北郡七戸町中岫');
ok($zip->set_number('0392555')->is_valid_number, '青森県上北郡七戸町前田');
ok($zip->set_number('0392556')->is_valid_number, '青森県上北郡七戸町西槻木');
ok($zip->set_number('0392557')->is_valid_number, '青森県上北郡七戸町西野');
ok($zip->set_number('0392558')->is_valid_number, '青森県上北郡七戸町高屋敷');
ok($zip->set_number('0392559')->is_valid_number, '青森県上北郡七戸町山屋');
ok($zip->set_number('0392561')->is_valid_number, '青森県上北郡七戸町銀南木');
ok($zip->set_number('0392562')->is_valid_number, '青森県上北郡七戸町倉岡');
ok($zip->set_number('0392563')->is_valid_number, '青森県上北郡七戸町向平');
ok($zip->set_number('0392564')->is_valid_number, '青森県上北郡七戸町古屋敷');
ok($zip->set_number('0392565')->is_valid_number, '青森県上北郡七戸町治部袋');
ok($zip->set_number('0392566')->is_valid_number, '青森県上北郡七戸町放森');
ok($zip->set_number('0392567')->is_valid_number, '青森県上北郡七戸町鶴児平');
ok($zip->set_number('0392568')->is_valid_number, '青森県上北郡七戸町左組');
ok($zip->set_number('0392569')->is_valid_number, '青森県上北郡七戸町馬門川原');
ok($zip->set_number('0392571')->is_valid_number, '青森県上北郡七戸町蛇坂');
ok($zip->set_number('0392572')->is_valid_number, '青森県上北郡七戸町城ノ後');
ok($zip->set_number('0392573')->is_valid_number, '青森県上北郡七戸町野続');
ok($zip->set_number('0392574')->is_valid_number, '青森県上北郡七戸町宇道坂');
ok($zip->set_number('0392575')->is_valid_number, '青森県上北郡七戸町作田');
ok($zip->set_number('0392576')->is_valid_number, '青森県上北郡七戸町桜田');
ok($zip->set_number('0392577')->is_valid_number, '青森県上北郡七戸町鍛治林');
ok($zip->set_number('0392578')->is_valid_number, '青森県上北郡七戸町貝ノ口');
ok($zip->set_number('0392579')->is_valid_number, '青森県上北郡七戸町十役野');
ok($zip->set_number('0392581')->is_valid_number, '青森県上北郡七戸町東上川原');
ok($zip->set_number('0392582')->is_valid_number, '青森県上北郡七戸町西上川原');
ok($zip->set_number('0392583')->is_valid_number, '青森県上北郡七戸町前川原');
ok($zip->set_number('0392584')->is_valid_number, '青森県上北郡七戸町後川原');
ok($zip->set_number('0392585')->is_valid_number, '青森県上北郡七戸町上ノ山');
ok($zip->set_number('0392586')->is_valid_number, '青森県上北郡七戸町海内');
ok($zip->set_number('0392587')->is_valid_number, '青森県上北郡七戸町上屋田');
ok($zip->set_number('0392588')->is_valid_number, '青森県上北郡七戸町和田下');
ok($zip->set_number('0392589')->is_valid_number, '青森県上北郡七戸町和田');
ok($zip->set_number('0392600')->is_valid_number, '青森県上北郡東北町以下に掲載がない場合');
ok($zip->set_number('0392601')->is_valid_number, '青森県上北郡東北町ガス平');
ok($zip->set_number('0392602')->is_valid_number, '青森県上北郡東北町五十嵐');
ok($zip->set_number('0392602')->is_valid_number, '青森県上北郡東北町細津橋ノ上');
ok($zip->set_number('0392603')->is_valid_number, '青森県上北郡東北町横沢山');
ok($zip->set_number('0392604')->is_valid_number, '青森県上北郡東北町空久保');
ok($zip->set_number('0392604')->is_valid_number, '青森県上北郡東北町饅頭長根');
ok($zip->set_number('0392604')->is_valid_number, '青森県上北郡東北町水流');
ok($zip->set_number('0392604')->is_valid_number, '青森県上北郡東北町横沢');
ok($zip->set_number('0392604')->is_valid_number, '青森県上北郡東北町横沢頭');
ok($zip->set_number('0392605')->is_valid_number, '青森県上北郡東北町淋代');
ok($zip->set_number('0392605')->is_valid_number, '青森県上北郡東北町高森');
ok($zip->set_number('0392606')->is_valid_number, '青森県上北郡東北町数牛');
ok($zip->set_number('0392606')->is_valid_number, '青森県上北郡東北町谷地頭');
ok($zip->set_number('0392607')->is_valid_number, '青森県上北郡東北町姥沢');
ok($zip->set_number('0392611')->is_valid_number, '青森県上北郡東北町中村道ノ上');
ok($zip->set_number('0392611')->is_valid_number, '青森県上北郡東北町中村道ノ下');
ok($zip->set_number('0392612')->is_valid_number, '青森県上北郡東北町狼ノ沢');
ok($zip->set_number('0392612')->is_valid_number, '青森県上北郡東北町沼添左ノ平');
ok($zip->set_number('0392612')->is_valid_number, '青森県上北郡東北町浜台');
ok($zip->set_number('0392613')->is_valid_number, '青森県上北郡東北町子ノ鳥平');
ok($zip->set_number('0392613')->is_valid_number, '青森県上北郡東北町野田頭');
ok($zip->set_number('0392613')->is_valid_number, '青森県上北郡東北町野田頭山');
ok($zip->set_number('0392613')->is_valid_number, '青森県上北郡東北町野田尻');
ok($zip->set_number('0392614')->is_valid_number, '青森県上北郡東北町切左坂道ノ下');
ok($zip->set_number('0392615')->is_valid_number, '青森県上北郡東北町細津');
ok($zip->set_number('0392615')->is_valid_number, '青森県上北郡東北町萌出道ノ上');
ok($zip->set_number('0392615')->is_valid_number, '青森県上北郡東北町萌出道ノ下');
ok($zip->set_number('0392616')->is_valid_number, '青森県上北郡東北町切左坂道ノ上');
ok($zip->set_number('0392617')->is_valid_number, '青森県上北郡東北町水喰');
ok($zip->set_number('0392617')->is_valid_number, '青森県上北郡東北町水喰向');
ok($zip->set_number('0392621')->is_valid_number, '青森県上北郡東北町田ノ沢');
ok($zip->set_number('0392622')->is_valid_number, '青森県上北郡東北町浜家苫');
ok($zip->set_number('0392622')->is_valid_number, '青森県上北郡東北町船ケ沢');
ok($zip->set_number('0392623')->is_valid_number, '青森県上北郡東北町大久保');
ok($zip->set_number('0392623')->is_valid_number, '青森県上北郡東北町鶴ケ崎');
ok($zip->set_number('0392623')->is_valid_number, '青森県上北郡東北町横志多');
ok($zip->set_number('0392624')->is_valid_number, '青森県上北郡東北町蓼内久保');
ok($zip->set_number('0392624')->is_valid_number, '青森県上北郡東北町古屋敷');
ok($zip->set_number('0392624')->is_valid_number, '青森県上北郡東北町道ノ北');
ok($zip->set_number('0392625')->is_valid_number, '青森県上北郡東北町長久保');
ok($zip->set_number('0392626')->is_valid_number, '青森県上北郡東北町後久保');
ok($zip->set_number('0392626')->is_valid_number, '青森県上北郡東北町上久保');
ok($zip->set_number('0392626')->is_valid_number, '青森県上北郡東北町堤尻');
ok($zip->set_number('0392627')->is_valid_number, '青森県上北郡東北町漆玉');
ok($zip->set_number('0392631')->is_valid_number, '青森県上北郡東北町滝沢平');
ok($zip->set_number('0392632')->is_valid_number, '青森県上北郡東北町日影林ノ上山');
ok($zip->set_number('0392633')->is_valid_number, '青森県上北郡東北町素柄邸');
ok($zip->set_number('0392633')->is_valid_number, '青森県上北郡東北町和山平');
ok($zip->set_number('0392634')->is_valid_number, '青森県上北郡東北町往来ノ下');
ok($zip->set_number('0392635')->is_valid_number, '青森県上北郡東北町乙越');
ok($zip->set_number('0392635')->is_valid_number, '青森県上北郡東北町舘');
ok($zip->set_number('0392635')->is_valid_number, '青森県上北郡東北町鳥口平');
ok($zip->set_number('0392636')->is_valid_number, '青森県上北郡東北町往来ノ上');
ok($zip->set_number('0392641')->is_valid_number, '青森県上北郡東北町枋木');
ok($zip->set_number('0392642')->is_valid_number, '青森県上北郡東北町寒水');
ok($zip->set_number('0392642')->is_valid_number, '青森県上北郡東北町寒水下');
ok($zip->set_number('0392642')->is_valid_number, '青森県上北郡東北町寒水山');
ok($zip->set_number('0392643')->is_valid_number, '青森県上北郡東北町乙部道ノ上');
ok($zip->set_number('0392643')->is_valid_number, '青森県上北郡東北町乙部道ノ下');
ok($zip->set_number('0392644')->is_valid_number, '青森県上北郡東北町保戸沢家ノ上');
ok($zip->set_number('0392644')->is_valid_number, '青森県上北郡東北町保戸沢家ノ前');
ok($zip->set_number('0392644')->is_valid_number, '青森県上北郡東北町保戸沢家ノ後');
ok($zip->set_number('0392645')->is_valid_number, '青森県上北郡東北町外蛯沢前平');
ok($zip->set_number('0392646')->is_valid_number, '青森県上北郡東北町外蛯沢西平');
ok($zip->set_number('0392647')->is_valid_number, '青森県上北郡東北町外蛯沢後久保');
ok($zip->set_number('0392648')->is_valid_number, '青森県上北郡東北町外蛯沢北久保');
ok($zip->set_number('0392651')->is_valid_number, '青森県上北郡東北町大沢');
ok($zip->set_number('0392652')->is_valid_number, '青森県上北郡東北町ほとけ沢');
ok($zip->set_number('0392653')->is_valid_number, '青森県上北郡東北町下山');
ok($zip->set_number('0392654')->is_valid_number, '青森県上北郡東北町塔ノ沢山');
ok($zip->set_number('0392655')->is_valid_number, '青森県上北郡東北町内蛯沢道ノ上');
ok($zip->set_number('0392656')->is_valid_number, '青森県上北郡東北町内蛯沢向');
ok($zip->set_number('0392657')->is_valid_number, '青森県上北郡東北町赤川道');
ok($zip->set_number('0392661')->is_valid_number, '青森県上北郡東北町上笹橋');
ok($zip->set_number('0392662')->is_valid_number, '青森県上北郡東北町下笹橋');
ok($zip->set_number('0392663')->is_valid_number, '青森県上北郡東北町舘花');
ok($zip->set_number('0392664')->is_valid_number, '青森県上北郡東北町乙供');
ok($zip->set_number('0392665')->is_valid_number, '青森県上北郡東北町柳沢');
ok($zip->set_number('0392666')->is_valid_number, '青森県上北郡東北町乙供山');
ok($zip->set_number('0392667')->is_valid_number, '青森県上北郡東北町膳前');
ok($zip->set_number('0392668')->is_valid_number, '青森県上北郡東北町北膳前');
ok($zip->set_number('0392668')->is_valid_number, '青森県上北郡東北町篠内平');
ok($zip->set_number('0392671')->is_valid_number, '青森県上北郡東北町小沢');
ok($zip->set_number('0392672')->is_valid_number, '青森県上北郡東北町栗山添');
ok($zip->set_number('0392672')->is_valid_number, '青森県上北郡東北町向籏屋');
ok($zip->set_number('0392673')->is_valid_number, '青森県上北郡東北町馬尻');
ok($zip->set_number('0392673')->is_valid_number, '青森県上北郡東北町大籏屋');
ok($zip->set_number('0392673')->is_valid_number, '青森県上北郡東北町向屋敷');
ok($zip->set_number('0392673')->is_valid_number, '青森県上北郡東北町山ノ下');
ok($zip->set_number('0392674')->is_valid_number, '青森県上北郡東北町千曳下山');
ok($zip->set_number('0392674')->is_valid_number, '青森県上北郡東北町夫雑原');
ok($zip->set_number('0392675')->is_valid_number, '青森県上北郡東北町千曳');
ok($zip->set_number('0392676')->is_valid_number, '青森県上北郡東北町下板橋');
ok($zip->set_number('0392677')->is_valid_number, '青森県上北郡東北町夫雑原下山');
ok($zip->set_number('0392678')->is_valid_number, '青森県上北郡東北町狐沢山');
ok($zip->set_number('0392678')->is_valid_number, '青森県上北郡東北町坂ノ下');
ok($zip->set_number('0392678')->is_valid_number, '青森県上北郡東北町田面木');
ok($zip->set_number('0392678')->is_valid_number, '青森県上北郡東北町長者久保');
ok($zip->set_number('0392681')->is_valid_number, '青森県上北郡東北町家ノ前');
ok($zip->set_number('0392681')->is_valid_number, '青森県上北郡東北町山添');
ok($zip->set_number('0392682')->is_valid_number, '青森県上北郡東北町石坂');
ok($zip->set_number('0392682')->is_valid_number, '青森県上北郡東北町湯沢');
ok($zip->set_number('0392683')->is_valid_number, '青森県上北郡東北町板橋山');
ok($zip->set_number('0392683')->is_valid_number, '青森県上北郡東北町大平');
ok($zip->set_number('0392684')->is_valid_number, '青森県上北郡東北町向平');
ok($zip->set_number('0392685')->is_valid_number, '青森県上北郡東北町家ノ下タ');
ok($zip->set_number('0392685')->is_valid_number, '青森県上北郡東北町上板橋家ノ後');
ok($zip->set_number('0392686')->is_valid_number, '青森県上北郡東北町宇道坂');
ok($zip->set_number('0392686')->is_valid_number, '青森県上北郡東北町塞ノ神');
ok($zip->set_number('0392686')->is_valid_number, '青森県上北郡東北町添ノ沢');
ok($zip->set_number('0392687')->is_valid_number, '青森県上北郡東北町上清水目');
ok($zip->set_number('0392687')->is_valid_number, '青森県上北郡東北町林ノ下');
ok($zip->set_number('0392688')->is_valid_number, '青森県上北郡東北町大撫沢');
ok($zip->set_number('0392711')->is_valid_number, '青森県上北郡七戸町中天間舘');
ok($zip->set_number('0392712')->is_valid_number, '青森県上北郡七戸町北天間舘');
ok($zip->set_number('0392713')->is_valid_number, '青森県上北郡七戸町東天間舘');
ok($zip->set_number('0392714')->is_valid_number, '青森県上北郡七戸町上志多');
ok($zip->set_number('0392715')->is_valid_number, '青森県上北郡七戸町尾山頭');
ok($zip->set_number('0392716')->is_valid_number, '青森県上北郡七戸町菩提木');
ok($zip->set_number('0392717')->is_valid_number, '青森県上北郡七戸町柳平');
ok($zip->set_number('0392721')->is_valid_number, '青森県上北郡七戸町志茂川原');
ok($zip->set_number('0392722')->is_valid_number, '青森県上北郡七戸町向川原');
ok($zip->set_number('0392723')->is_valid_number, '青森県上北郡七戸町下志多');
ok($zip->set_number('0392724')->is_valid_number, '青森県上北郡七戸町上平');
ok($zip->set_number('0392725')->is_valid_number, '青森県上北郡七戸町上川原');
ok($zip->set_number('0392726')->is_valid_number, '青森県上北郡七戸町李川原');
ok($zip->set_number('0392731')->is_valid_number, '青森県上北郡七戸町後平');
ok($zip->set_number('0392732')->is_valid_number, '青森県上北郡七戸町卒古沢');
ok($zip->set_number('0392733')->is_valid_number, '青森県上北郡七戸町天間舘前川原');
ok($zip->set_number('0392741')->is_valid_number, '青森県上北郡七戸町猪ノ鼻');
ok($zip->set_number('0392742')->is_valid_number, '青森県上北郡七戸町舟場向川久保');
ok($zip->set_number('0392743')->is_valid_number, '青森県上北郡七戸町寺沢前');
ok($zip->set_number('0392744')->is_valid_number, '青森県上北郡七戸町塚長根');
ok($zip->set_number('0392745')->is_valid_number, '青森県上北郡七戸町夷堂');
ok($zip->set_number('0392746')->is_valid_number, '青森県上北郡七戸町附田川目');
ok($zip->set_number('0392747')->is_valid_number, '青森県上北郡七戸町附田家ノ前');
ok($zip->set_number('0392748')->is_valid_number, '青森県上北郡七戸町南舘向');
ok($zip->set_number('0392751')->is_valid_number, '青森県上北郡七戸町貝塚家ノ前');
ok($zip->set_number('0392752')->is_valid_number, '青森県上北郡七戸町鉢森平');
ok($zip->set_number('0392753')->is_valid_number, '青森県上北郡七戸町竿打川原');
ok($zip->set_number('0392754')->is_valid_number, '青森県上北郡七戸町地蔵堂');
ok($zip->set_number('0392755')->is_valid_number, '青森県上北郡七戸町榎林家ノ前');
ok($zip->set_number('0392756')->is_valid_number, '青森県上北郡七戸町榎林家ノ後');
ok($zip->set_number('0392757')->is_valid_number, '青森県上北郡七戸町卒古沢南平');
ok($zip->set_number('0392761')->is_valid_number, '青森県上北郡七戸町二ツ森家ノ後');
ok($zip->set_number('0392762')->is_valid_number, '青森県上北郡七戸町二ツ森家ノ下');
ok($zip->set_number('0392763')->is_valid_number, '青森県上北郡七戸町二ツ森家ノ表');
ok($zip->set_number('0392771')->is_valid_number, '青森県上北郡七戸町姥沢');
ok($zip->set_number('0392772')->is_valid_number, '青森県上北郡七戸町下田坪');
ok($zip->set_number('0392773')->is_valid_number, '青森県上北郡七戸町前左野');
ok($zip->set_number('0392774')->is_valid_number, '青森県上北郡七戸町柴舘道ノ下');
ok($zip->set_number('0392775')->is_valid_number, '青森県上北郡七戸町李沢道ノ下');
ok($zip->set_number('0392776')->is_valid_number, '青森県上北郡七戸町李沢家ノ前');
ok($zip->set_number('0392777')->is_valid_number, '青森県上北郡七戸町李沢家ノ後');
ok($zip->set_number('0392778')->is_valid_number, '青森県上北郡七戸町坂ノ外');
ok($zip->set_number('0392779')->is_valid_number, '青森県上北郡七戸町榎林古屋敷');
ok($zip->set_number('0392781')->is_valid_number, '青森県上北郡七戸町花松林ノ根');
ok($zip->set_number('0392782')->is_valid_number, '青森県上北郡七戸町中岫太田嶋');
ok($zip->set_number('0392783')->is_valid_number, '青森県上北郡七戸町中岫番屋');
ok($zip->set_number('0392784')->is_valid_number, '青森県上北郡七戸町中岫長沢下');
ok($zip->set_number('0392785')->is_valid_number, '青森県上北郡七戸町中岫村ノ上');
ok($zip->set_number('0392786')->is_valid_number, '青森県上北郡七戸町中岫東道添');
ok($zip->set_number('0392801')->is_valid_number, '青森県上北郡七戸町野崎');
ok($zip->set_number('0392802')->is_valid_number, '青森県上北郡七戸町野崎前平');
ok($zip->set_number('0392803')->is_valid_number, '青森県上北郡七戸町野崎森ノ下');
ok($zip->set_number('0392804')->is_valid_number, '青森県上北郡七戸町野崎狐久保');
ok($zip->set_number('0392805')->is_valid_number, '青森県上北郡七戸町原久保');
ok($zip->set_number('0392811')->is_valid_number, '青森県上北郡七戸町天間舘荒谷');
ok($zip->set_number('0392812')->is_valid_number, '青森県上北郡七戸町小田下');
ok($zip->set_number('0392813')->is_valid_number, '青森県上北郡七戸町小田平');
ok($zip->set_number('0392814')->is_valid_number, '青森県上北郡七戸町道ノ下');
ok($zip->set_number('0392815')->is_valid_number, '青森県上北郡七戸町森ノ下');
ok($zip->set_number('0392816')->is_valid_number, '青森県上北郡七戸町家ノ裏');
ok($zip->set_number('0392821')->is_valid_number, '青森県上北郡七戸町大平');
ok($zip->set_number('0392822')->is_valid_number, '青森県上北郡七戸町小又');
ok($zip->set_number('0392823')->is_valid_number, '青森県上北郡七戸町館ノ下');
ok($zip->set_number('0392824')->is_valid_number, '青森県上北郡七戸町家ノ下');
ok($zip->set_number('0392825')->is_valid_number, '青森県上北郡七戸町家ノ上');
ok($zip->set_number('0392826')->is_valid_number, '青森県上北郡七戸町中野');
ok($zip->set_number('0392827')->is_valid_number, '青森県上北郡七戸町森ノ上');
ok($zip->set_number('0392828')->is_valid_number, '青森県上北郡七戸町森ケ沢');
ok($zip->set_number('0392831')->is_valid_number, '青森県上北郡七戸町金沢平');
ok($zip->set_number('0392832')->is_valid_number, '青森県上北郡七戸町道ノ上');
ok($zip->set_number('0392833')->is_valid_number, '青森県上北郡七戸町家ノ前');
ok($zip->set_number('0392834')->is_valid_number, '青森県上北郡七戸町向中野川向');
ok($zip->set_number('0392835')->is_valid_number, '青森県上北郡七戸町松ケ沢');
ok($zip->set_number('0392841')->is_valid_number, '青森県上北郡七戸町下鳥谷部');
ok($zip->set_number('0392842')->is_valid_number, '青森県上北郡七戸町中鳥谷');
ok($zip->set_number('0392843')->is_valid_number, '青森県上北郡七戸町橋ノ上');
ok($zip->set_number('0392844')->is_valid_number, '青森県上北郡七戸町手代森');
ok($zip->set_number('0392845')->is_valid_number, '青森県上北郡七戸町作田道');
ok($zip->set_number('0392846')->is_valid_number, '青森県上北郡七戸町鳥谷部');
ok($zip->set_number('0392851')->is_valid_number, '青森県上北郡七戸町堰根');
ok($zip->set_number('0392852')->is_valid_number, '青森県上北郡七戸町さそう');
ok($zip->set_number('0392853')->is_valid_number, '青森県上北郡七戸町さそう平');
ok($zip->set_number('0392854')->is_valid_number, '青森県上北郡七戸町高井名');
ok($zip->set_number('0392855')->is_valid_number, '青森県上北郡七戸町底田');
ok($zip->set_number('0392856')->is_valid_number, '青森県上北郡七戸町古和備');
ok($zip->set_number('0392857')->is_valid_number, '青森県上北郡七戸町天間舘倉越');
ok($zip->set_number('0392861')->is_valid_number, '青森県上北郡七戸町天間舘大沢');
ok($zip->set_number('0392862')->is_valid_number, '青森県上北郡七戸町夏間木');
ok($zip->set_number('0392863')->is_valid_number, '青森県上北郡七戸町十枝内');
ok($zip->set_number('0392864')->is_valid_number, '青森県上北郡七戸町下モ川原');
ok($zip->set_number('0392865')->is_valid_number, '青森県上北郡七戸町市ノ渡');
ok($zip->set_number('0392866')->is_valid_number, '青森県上北郡七戸町栗ノ木沢');
ok($zip->set_number('0392871')->is_valid_number, '青森県上北郡七戸町白石');
ok($zip->set_number('0392872')->is_valid_number, '青森県上北郡七戸町下タ川原');
ok($zip->set_number('0392873')->is_valid_number, '青森県上北郡七戸町天間舘寒水');
ok($zip->set_number('0392874')->is_valid_number, '青森県上北郡七戸町坪川原');
ok($zip->set_number('0392875')->is_valid_number, '青森県上北郡七戸町淋代');
ok($zip->set_number('0392876')->is_valid_number, '青森県上北郡七戸町堰代');
ok($zip->set_number('0392877')->is_valid_number, '青森県上北郡七戸町五庵ノ下');
ok($zip->set_number('0393100')->is_valid_number, '青森県上北郡野辺地町以下に掲載がない場合');
ok($zip->set_number('0393101')->is_valid_number, '青森県上北郡野辺地町浜掛');
ok($zip->set_number('0393102')->is_valid_number, '青森県上北郡野辺地町米内沢');
ok($zip->set_number('0393103')->is_valid_number, '青森県上北郡野辺地町田名部道');
ok($zip->set_number('0393104')->is_valid_number, '青森県上北郡野辺地町大月平');
ok($zip->set_number('0393105')->is_valid_number, '青森県上北郡野辺地町有戸鳥井平');
ok($zip->set_number('0393105')->is_valid_number, '青森県上北郡野辺地町木明');
ok($zip->set_number('0393105')->is_valid_number, '青森県上北郡野辺地町東太田沢');
ok($zip->set_number('0393105')->is_valid_number, '青森県上北郡野辺地町干草橋');
ok($zip->set_number('0393106')->is_valid_number, '青森県上北郡野辺地町蟹田');
ok($zip->set_number('0393106')->is_valid_number, '青森県上北郡野辺地町古明前');
ok($zip->set_number('0393106')->is_valid_number, '青森県上北郡野辺地町明前');
ok($zip->set_number('0393107')->is_valid_number, '青森県上北郡野辺地町小沢平');
ok($zip->set_number('0393108')->is_valid_number, '青森県上北郡野辺地町有戸');
ok($zip->set_number('0393108')->is_valid_number, '青森県上北郡野辺地町下道');
ok($zip->set_number('0393108')->is_valid_number, '青森県上北郡野辺地町中田');
ok($zip->set_number('0393109')->is_valid_number, '青森県上北郡野辺地町向田');
ok($zip->set_number('0393111')->is_valid_number, '青森県上北郡野辺地町石神裏');
ok($zip->set_number('0393112')->is_valid_number, '青森県上北郡野辺地町中道');
ok($zip->set_number('0393113')->is_valid_number, '青森県上北郡野辺地町田狭沢');
ok($zip->set_number('0393114')->is_valid_number, '青森県上北郡野辺地町助佐小路');
ok($zip->set_number('0393115')->is_valid_number, '青森県上北郡野辺地町タラノ木');
ok($zip->set_number('0393116')->is_valid_number, '青森県上北郡野辺地町赤坂');
ok($zip->set_number('0393117')->is_valid_number, '青森県上北郡野辺地町下坂');
ok($zip->set_number('0393118')->is_valid_number, '青森県上北郡野辺地町寺ノ沢');
ok($zip->set_number('0393121')->is_valid_number, '青森県上北郡野辺地町船橋');
ok($zip->set_number('0393122')->is_valid_number, '青森県上北郡野辺地町雑吉沢');
ok($zip->set_number('0393123')->is_valid_number, '青森県上北郡野辺地町種川');
ok($zip->set_number('0393124')->is_valid_number, '青森県上北郡野辺地町白岩');
ok($zip->set_number('0393125')->is_valid_number, '青森県上北郡野辺地町坊ノ塚');
ok($zip->set_number('0393126')->is_valid_number, '青森県上北郡野辺地町下前田');
ok($zip->set_number('0393127')->is_valid_number, '青森県上北郡野辺地町上川原');
ok($zip->set_number('0393128')->is_valid_number, '青森県上北郡野辺地町上前田');
ok($zip->set_number('0393128')->is_valid_number, '青森県上北郡野辺地町昼場');
ok($zip->set_number('0393129')->is_valid_number, '青森県上北郡野辺地町新田');
ok($zip->set_number('0393129')->is_valid_number, '青森県上北郡野辺地町戸田ノ沢');
ok($zip->set_number('0393129')->is_valid_number, '青森県上北郡野辺地町餅粟川原');
ok($zip->set_number('0393131')->is_valid_number, '青森県上北郡野辺地町野辺地');
ok($zip->set_number('0393141')->is_valid_number, '青森県上北郡野辺地町鳴沢');
ok($zip->set_number('0393142')->is_valid_number, '青森県上北郡野辺地町久田');
ok($zip->set_number('0393143')->is_valid_number, '青森県上北郡野辺地町川目');
ok($zip->set_number('0393143')->is_valid_number, '青森県上北郡野辺地町中屋敷');
ok($zip->set_number('0393144')->is_valid_number, '青森県上北郡野辺地町一ノ渡');
ok($zip->set_number('0393145')->is_valid_number, '青森県上北郡野辺地町松ノ木平');
ok($zip->set_number('0393146')->is_valid_number, '青森県上北郡野辺地町下松ノ木平');
ok($zip->set_number('0393147')->is_valid_number, '青森県上北郡野辺地町下与田川');
ok($zip->set_number('0393148')->is_valid_number, '青森県上北郡野辺地町与田川尻');
ok($zip->set_number('0393151')->is_valid_number, '青森県上北郡野辺地町白岩向');
ok($zip->set_number('0393152')->is_valid_number, '青森県上北郡野辺地町下小中野');
ok($zip->set_number('0393153')->is_valid_number, '青森県上北郡野辺地町中小中野');
ok($zip->set_number('0393154')->is_valid_number, '青森県上北郡野辺地町上小中野');
ok($zip->set_number('0393155')->is_valid_number, '青森県上北郡野辺地町切明');
ok($zip->set_number('0393156')->is_valid_number, '青森県上北郡野辺地町枇杷野');
ok($zip->set_number('0393157')->is_valid_number, '青森県上北郡野辺地町獅子沢');
ok($zip->set_number('0393157')->is_valid_number, '青森県上北郡野辺地町松ノ木');
ok($zip->set_number('0393158')->is_valid_number, '青森県上北郡野辺地町観音林後');
ok($zip->set_number('0393159')->is_valid_number, '青森県上北郡野辺地町観音林脇');
ok($zip->set_number('0393161')->is_valid_number, '青森県上北郡野辺地町馬門道');
ok($zip->set_number('0393162')->is_valid_number, '青森県上北郡野辺地町笹館');
ok($zip->set_number('0393163')->is_valid_number, '青森県上北郡野辺地町新町裏');
ok($zip->set_number('0393164')->is_valid_number, '青森県上北郡野辺地町前田');
ok($zip->set_number('0393165')->is_valid_number, '青森県上北郡野辺地町観音林前田');
ok($zip->set_number('0393166')->is_valid_number, '青森県上北郡野辺地町二本木向前田');
ok($zip->set_number('0393167')->is_valid_number, '青森県上北郡野辺地町二本木向');
ok($zip->set_number('0393168')->is_valid_number, '青森県上北郡野辺地町前平');
ok($zip->set_number('0393171')->is_valid_number, '青森県上北郡野辺地町上御手洗瀬');
ok($zip->set_number('0393171')->is_valid_number, '青森県上北郡野辺地町下御手洗瀬');
ok($zip->set_number('0393171')->is_valid_number, '青森県上北郡野辺地町滝田');
ok($zip->set_number('0393171')->is_valid_number, '青森県上北郡野辺地町槻ノ木');
ok($zip->set_number('0393171')->is_valid_number, '青森県上北郡野辺地町二本木');
ok($zip->set_number('0393171')->is_valid_number, '青森県上北郡野辺地町二十平');
ok($zip->set_number('0393171')->is_valid_number, '青森県上北郡野辺地町御手洗瀬');
ok($zip->set_number('0393172')->is_valid_number, '青森県上北郡野辺地町鳥井平');
ok($zip->set_number('0393173')->is_valid_number, '青森県上北郡野辺地町陣場川原');
ok($zip->set_number('0393174')->is_valid_number, '青森県上北郡野辺地町大平下');
ok($zip->set_number('0393174')->is_valid_number, '青森県上北郡野辺地町上河渡頭');
ok($zip->set_number('0393174')->is_valid_number, '青森県上北郡野辺地町下河渡頭');
ok($zip->set_number('0393174')->is_valid_number, '青森県上北郡野辺地町田端');
ok($zip->set_number('0393175')->is_valid_number, '青森県上北郡野辺地町地続山');
ok($zip->set_number('0393175')->is_valid_number, '青森県上北郡野辺地町湯沢');
ok($zip->set_number('0393175')->is_valid_number, '青森県上北郡野辺地町湯沢尻');
ok($zip->set_number('0393176')->is_valid_number, '青森県上北郡野辺地町中渡');
ok($zip->set_number('0393177')->is_valid_number, '青森県上北郡野辺地町柴崎');
ok($zip->set_number('0393177')->is_valid_number, '青森県上北郡野辺地町八ノ木谷地');
ok($zip->set_number('0393178')->is_valid_number, '青森県上北郡野辺地町家ノ上');
ok($zip->set_number('0393179')->is_valid_number, '青森県上北郡野辺地町馬門');
ok($zip->set_number('0393200')->is_valid_number, '青森県上北郡六ヶ所村以下に掲載がない場合');
ok($zip->set_number('0393211')->is_valid_number, '青森県上北郡六ヶ所村出戸');
ok($zip->set_number('0393212')->is_valid_number, '青森県上北郡六ヶ所村尾駮');
ok($zip->set_number('0393213')->is_valid_number, '青森県上北郡六ヶ所村鷹架');
ok($zip->set_number('0393214')->is_valid_number, '青森県上北郡六ヶ所村平沼');
ok($zip->set_number('0393215')->is_valid_number, '青森県上北郡六ヶ所村倉内');
ok($zip->set_number('0393300')->is_valid_number, '青森県東津軽郡平内町以下に掲載がない場合');
ok($zip->set_number('0393301')->is_valid_number, '青森県東津軽郡平内町東田沢');
ok($zip->set_number('0393302')->is_valid_number, '青森県東津軽郡平内町白砂');
ok($zip->set_number('0393303')->is_valid_number, '青森県東津軽郡平内町東滝');
ok($zip->set_number('0393311')->is_valid_number, '青森県東津軽郡平内町福館');
ok($zip->set_number('0393312')->is_valid_number, '青森県東津軽郡平内町浅所');
ok($zip->set_number('0393313')->is_valid_number, '青森県東津軽郡平内町沼館');
ok($zip->set_number('0393314')->is_valid_number, '青森県東津軽郡平内町盛田');
ok($zip->set_number('0393315')->is_valid_number, '青森県東津軽郡平内町福島');
ok($zip->set_number('0393321')->is_valid_number, '青森県東津軽郡平内町小湊');
ok($zip->set_number('0393331')->is_valid_number, '青森県東津軽郡平内町浜子');
ok($zip->set_number('0393332')->is_valid_number, '青森県東津軽郡平内町清水川');
ok($zip->set_number('0393333')->is_valid_number, '青森県東津軽郡平内町松野木');
ok($zip->set_number('0393341')->is_valid_number, '青森県東津軽郡平内町薬師野');
ok($zip->set_number('0393342')->is_valid_number, '青森県東津軽郡平内町口広');
ok($zip->set_number('0393343')->is_valid_number, '青森県東津軽郡平内町狩場沢');
ok($zip->set_number('0393351')->is_valid_number, '青森県東津軽郡平内町外童子');
ok($zip->set_number('0393352')->is_valid_number, '青森県東津軽郡平内町内童子');
ok($zip->set_number('0393353')->is_valid_number, '青森県東津軽郡平内町田茂木');
ok($zip->set_number('0393361')->is_valid_number, '青森県東津軽郡平内町藤沢');
ok($zip->set_number('0393362')->is_valid_number, '青森県東津軽郡平内町増田');
ok($zip->set_number('0393363')->is_valid_number, '青森県東津軽郡平内町山口');
ok($zip->set_number('0393364')->is_valid_number, '青森県東津軽郡平内町小豆沢');
ok($zip->set_number('0393371')->is_valid_number, '青森県東津軽郡平内町中野');
ok($zip->set_number('0393372')->is_valid_number, '青森県東津軽郡平内町土屋');
ok($zip->set_number('0393373')->is_valid_number, '青森県東津軽郡平内町浪打');
ok($zip->set_number('0393381')->is_valid_number, '青森県東津軽郡平内町茂浦');
ok($zip->set_number('0393382')->is_valid_number, '青森県東津軽郡平内町稲生');
ok($zip->set_number('0393501')->is_valid_number, '青森県青森市浅虫');
ok($zip->set_number('0393502')->is_valid_number, '青森県青森市久栗坂');
ok($zip->set_number('0393503')->is_valid_number, '青森県青森市野内');
ok($zip->set_number('0393504')->is_valid_number, '青森県青森市矢田');
ok($zip->set_number('0393505')->is_valid_number, '青森県青森市宮田');
ok($zip->set_number('0393506')->is_valid_number, '青森県青森市三本木');
ok($zip->set_number('0393507')->is_valid_number, '青森県青森市馬屋尻');
ok($zip->set_number('0393524')->is_valid_number, '青森県青森市滝沢(その他)');
ok($zip->set_number('0394100')->is_valid_number, '青森県上北郡横浜町以下に掲載がない場合');
ok($zip->set_number('0394101')->is_valid_number, '青森県上北郡横浜町林尻');
ok($zip->set_number('0394102')->is_valid_number, '青森県上北郡横浜町浜田');
ok($zip->set_number('0394103')->is_valid_number, '青森県上北郡横浜町川太郎川目');
ok($zip->set_number('0394104')->is_valid_number, '青森県上北郡横浜町下苗代川目');
ok($zip->set_number('0394105')->is_valid_number, '青森県上北郡横浜町苗代川目');
ok($zip->set_number('0394106')->is_valid_number, '青森県上北郡横浜町有畑');
ok($zip->set_number('0394111')->is_valid_number, '青森県上北郡横浜町大畑');
ok($zip->set_number('0394112')->is_valid_number, '青森県上北郡横浜町夷ケ沢平');
ok($zip->set_number('0394113')->is_valid_number, '青森県上北郡横浜町家ノ前川目');
ok($zip->set_number('0394114')->is_valid_number, '青森県上北郡横浜町大豆田');
ok($zip->set_number('0394115')->is_valid_number, '青森県上北郡横浜町稲荷平');
ok($zip->set_number('0394116')->is_valid_number, '青森県上北郡横浜町中畑');
ok($zip->set_number('0394117')->is_valid_number, '青森県上北郡横浜町鶏沢');
ok($zip->set_number('0394121')->is_valid_number, '青森県上北郡横浜町桧木');
ok($zip->set_number('0394122')->is_valid_number, '青森県上北郡横浜町鶏ケ唄');
ok($zip->set_number('0394123')->is_valid_number, '青森県上北郡横浜町茅平');
ok($zip->set_number('0394124')->is_valid_number, '青森県上北郡横浜町川尻');
ok($zip->set_number('0394131')->is_valid_number, '青森県上北郡横浜町椛名木');
ok($zip->set_number('0394132')->is_valid_number, '青森県上北郡横浜町太郎須田');
ok($zip->set_number('0394133')->is_valid_number, '青森県上北郡横浜町舘の後');
ok($zip->set_number('0394134')->is_valid_number, '青森県上北郡横浜町林の脇');
ok($zip->set_number('0394135')->is_valid_number, '青森県上北郡横浜町林の後');
ok($zip->set_number('0394136')->is_valid_number, '青森県上北郡横浜町横浜');
ok($zip->set_number('0394137')->is_valid_number, '青森県上北郡横浜町下川原');
ok($zip->set_number('0394138')->is_valid_number, '青森県上北郡横浜町塚名平');
ok($zip->set_number('0394141')->is_valid_number, '青森県上北郡横浜町三保野');
ok($zip->set_number('0394142')->is_valid_number, '青森県上北郡横浜町上イタヤノ木');
ok($zip->set_number('0394143')->is_valid_number, '青森県上北郡横浜町屋敷形');
ok($zip->set_number('0394144')->is_valid_number, '青森県上北郡横浜町浜懸');
ok($zip->set_number('0394145')->is_valid_number, '青森県上北郡横浜町寺下');
ok($zip->set_number('0394151')->is_valid_number, '青森県上北郡横浜町向平');
ok($zip->set_number('0394152')->is_valid_number, '青森県上北郡横浜町百目木');
ok($zip->set_number('0394153')->is_valid_number, '青森県上北郡横浜町吹越');
ok($zip->set_number('0394154')->is_valid_number, '青森県上北郡横浜町明神平');
ok($zip->set_number('0394155')->is_valid_number, '青森県上北郡横浜町豊栄平');
ok($zip->set_number('0394156')->is_valid_number, '青森県上北郡横浜町雲雀平');
ok($zip->set_number('0394157')->is_valid_number, '青森県上北郡横浜町二又');
ok($zip->set_number('0394221')->is_valid_number, '青森県下北郡東通村猿ケ森');
ok($zip->set_number('0394222')->is_valid_number, '青森県下北郡東通村砂子又');
ok($zip->set_number('0394223')->is_valid_number, '青森県下北郡東通村小田野沢');
ok($zip->set_number('0394224')->is_valid_number, '青森県下北郡東通村白糠');
ok($zip->set_number('0394301')->is_valid_number, '青森県上北郡六ヶ所村泊');
ok($zip->set_number('0394401')->is_valid_number, '青森県むつ市大畑町');
ok($zip->set_number('0394402')->is_valid_number, '青森県むつ市大畑町正津川');
ok($zip->set_number('0394500')->is_valid_number, '青森県下北郡風間浦村以下に掲載がない場合');
ok($zip->set_number('0394501')->is_valid_number, '青森県下北郡風間浦村下風呂');
ok($zip->set_number('0394502')->is_valid_number, '青森県下北郡風間浦村易国間');
ok($zip->set_number('0394503')->is_valid_number, '青森県下北郡風間浦村蛇浦');
ok($zip->set_number('0394600')->is_valid_number, '青森県下北郡大間町以下に掲載がない場合');
ok($zip->set_number('0394601')->is_valid_number, '青森県下北郡大間町大間');
ok($zip->set_number('0394602')->is_valid_number, '青森県下北郡大間町奥戸');
ok($zip->set_number('0394700')->is_valid_number, '青森県下北郡佐井村以下に掲載がない場合');
ok($zip->set_number('0394701')->is_valid_number, '青森県むつ市川内町(板家戸、野平、福浦山)');
ok($zip->set_number('0394711')->is_valid_number, '青森県下北郡佐井村佐井');
ok($zip->set_number('0394712')->is_valid_number, '青森県下北郡佐井村長後');
ok($zip->set_number('0395201')->is_valid_number, '青森県むつ市川内町(その他)');
ok($zip->set_number('0395202')->is_valid_number, '青森県むつ市川内町桧川');
ok($zip->set_number('0395203')->is_valid_number, '青森県むつ市川内町宿野部');
ok($zip->set_number('0395204')->is_valid_number, '青森県むつ市川内町蛎崎(その他)');
ok($zip->set_number('0395304')->is_valid_number, '青森県むつ市川内町蛎崎(半右エ門沢)');
ok($zip->set_number('0395321')->is_valid_number, '青森県むつ市脇野沢源藤城');
ok($zip->set_number('0395322')->is_valid_number, '青森県むつ市脇野沢滝山');
ok($zip->set_number('0395323')->is_valid_number, '青森県むつ市脇野沢七引');
ok($zip->set_number('0395324')->is_valid_number, '青森県むつ市脇野沢田ノ頭');
ok($zip->set_number('0395325')->is_valid_number, '青森県むつ市脇野沢辰内');
ok($zip->set_number('0395326')->is_valid_number, '青森県むつ市脇野沢桂沢');
ok($zip->set_number('0395327')->is_valid_number, '青森県むつ市脇野沢本村');
ok($zip->set_number('0395331')->is_valid_number, '青森県むつ市脇野沢渡向');
ok($zip->set_number('0395332')->is_valid_number, '青森県むつ市脇野沢瀬野川目');
ok($zip->set_number('0395333')->is_valid_number, '青森県むつ市脇野沢黒岩');
ok($zip->set_number('0395334')->is_valid_number, '青森県むつ市脇野沢新井田');
ok($zip->set_number('0395335')->is_valid_number, '青森県むつ市脇野沢寄浪');
ok($zip->set_number('0395336')->is_valid_number, '青森県むつ市脇野沢蛸田');
ok($zip->set_number('0395337')->is_valid_number, '青森県むつ市脇野沢九艘泊');
ok($zip->set_number('0395341')->is_valid_number, '青森県むつ市脇野沢鹿間平');
ok($zip->set_number('0395342')->is_valid_number, '青森県むつ市脇野沢小沢');
ok($zip->set_number('0395343')->is_valid_number, '青森県むつ市脇野沢小サ沢');
ok($zip->set_number('0395344')->is_valid_number, '青森県むつ市脇野沢稲平');
ok($zip->set_number('0395345')->is_valid_number, '青森県むつ市脇野沢赤坂');
ok($zip->set_number('0395346')->is_valid_number, '青森県むつ市脇野沢口広');
ok($zip->set_number('0400000')->is_valid_number, '北海道函館市以下に掲載がない場合');
ok($zip->set_number('0400001')->is_valid_number, '北海道函館市五稜郭町');
ok($zip->set_number('0400002')->is_valid_number, '北海道函館市柳町');
ok($zip->set_number('0400003')->is_valid_number, '北海道函館市松陰町');
ok($zip->set_number('0400004')->is_valid_number, '北海道函館市杉並町');
ok($zip->set_number('0400005')->is_valid_number, '北海道函館市人見町');
ok($zip->set_number('0400011')->is_valid_number, '北海道函館市本町');
ok($zip->set_number('0400012')->is_valid_number, '北海道函館市時任町');
ok($zip->set_number('0400013')->is_valid_number, '北海道函館市千代台町');
ok($zip->set_number('0400014')->is_valid_number, '北海道函館市中島町');
ok($zip->set_number('0400015')->is_valid_number, '北海道函館市梁川町');
ok($zip->set_number('0400021')->is_valid_number, '北海道函館市的場町');
ok($zip->set_number('0400022')->is_valid_number, '北海道函館市日乃出町');
ok($zip->set_number('0400023')->is_valid_number, '北海道函館市宇賀浦町');
ok($zip->set_number('0400024')->is_valid_number, '北海道函館市高盛町');
ok($zip->set_number('0400025')->is_valid_number, '北海道函館市堀川町');
ok($zip->set_number('0400031')->is_valid_number, '北海道函館市上新川町');
ok($zip->set_number('0400032')->is_valid_number, '北海道函館市新川町');
ok($zip->set_number('0400033')->is_valid_number, '北海道函館市千歳町');
ok($zip->set_number('0400034')->is_valid_number, '北海道函館市大森町');
ok($zip->set_number('0400035')->is_valid_number, '北海道函館市松風町');
ok($zip->set_number('0400036')->is_valid_number, '北海道函館市東雲町');
ok($zip->set_number('0400037')->is_valid_number, '北海道函館市旭町');
ok($zip->set_number('0400041')->is_valid_number, '北海道函館市栄町');
ok($zip->set_number('0400042')->is_valid_number, '北海道函館市東川町');
ok($zip->set_number('0400043')->is_valid_number, '北海道函館市宝来町');
ok($zip->set_number('0400044')->is_valid_number, '北海道函館市青柳町');
ok($zip->set_number('0400045')->is_valid_number, '北海道函館市住吉町');
ok($zip->set_number('0400046')->is_valid_number, '北海道函館市谷地頭町');
ok($zip->set_number('0400051')->is_valid_number, '北海道函館市弁天町');
ok($zip->set_number('0400052')->is_valid_number, '北海道函館市大町');
ok($zip->set_number('0400053')->is_valid_number, '北海道函館市末広町');
ok($zip->set_number('0400054')->is_valid_number, '北海道函館市元町');
ok($zip->set_number('0400055')->is_valid_number, '北海道函館市船見町');
ok($zip->set_number('0400056')->is_valid_number, '北海道函館市弥生町');
ok($zip->set_number('0400057')->is_valid_number, '北海道函館市入舟町');
ok($zip->set_number('0400061')->is_valid_number, '北海道函館市海岸町');
ok($zip->set_number('0400062')->is_valid_number, '北海道函館市大縄町');
ok($zip->set_number('0400063')->is_valid_number, '北海道函館市若松町');
ok($zip->set_number('0400064')->is_valid_number, '北海道函館市大手町');
ok($zip->set_number('0400065')->is_valid_number, '北海道函館市豊川町');
ok($zip->set_number('0400071')->is_valid_number, '北海道函館市追分町');
ok($zip->set_number('0400072')->is_valid_number, '北海道函館市亀田町');
ok($zip->set_number('0400073')->is_valid_number, '北海道函館市宮前町');
ok($zip->set_number('0400074')->is_valid_number, '北海道函館市松川町');
ok($zip->set_number('0400075')->is_valid_number, '北海道函館市万代町');
ok($zip->set_number('0400076')->is_valid_number, '北海道函館市浅野町');
ok($zip->set_number('0400077')->is_valid_number, '北海道函館市吉川町');
ok($zip->set_number('0400078')->is_valid_number, '北海道函館市北浜町');
ok($zip->set_number('0400081')->is_valid_number, '北海道函館市田家町');
ok($zip->set_number('0400082')->is_valid_number, '北海道函館市白鳥町');
ok($zip->set_number('0400083')->is_valid_number, '北海道函館市八幡町');
ok($zip->set_number('0400084')->is_valid_number, '北海道函館市大川町');
ok($zip->set_number('0410251')->is_valid_number, '北海道函館市小安町');
ok($zip->set_number('0410252')->is_valid_number, '北海道函館市釜谷町');
ok($zip->set_number('0410253')->is_valid_number, '北海道函館市小安山町');
ok($zip->set_number('0410261')->is_valid_number, '北海道函館市石崎町');
ok($zip->set_number('0410262')->is_valid_number, '北海道函館市古川町');
ok($zip->set_number('0410263')->is_valid_number, '北海道函館市豊原町');
ok($zip->set_number('0410264')->is_valid_number, '北海道函館市鶴野町');
ok($zip->set_number('0410265')->is_valid_number, '北海道函館市白石町');
ok($zip->set_number('0410301')->is_valid_number, '北海道函館市汐首町');
ok($zip->set_number('0410302')->is_valid_number, '北海道函館市瀬田来町');
ok($zip->set_number('0410303')->is_valid_number, '北海道函館市弁才町');
ok($zip->set_number('0410304')->is_valid_number, '北海道函館市泊町');
ok($zip->set_number('0410305')->is_valid_number, '北海道函館市館町');
ok($zip->set_number('0410306')->is_valid_number, '北海道函館市丸山町');
ok($zip->set_number('0410311')->is_valid_number, '北海道函館市浜町');
ok($zip->set_number('0410312')->is_valid_number, '北海道函館市新二見町');
ok($zip->set_number('0410313')->is_valid_number, '北海道函館市原木町');
ok($zip->set_number('0410401')->is_valid_number, '北海道函館市日浦町');
ok($zip->set_number('0410402')->is_valid_number, '北海道函館市豊浦町');
ok($zip->set_number('0410403')->is_valid_number, '北海道函館市大澗町');
ok($zip->set_number('0410404')->is_valid_number, '北海道函館市中浜町');
ok($zip->set_number('0410405')->is_valid_number, '北海道函館市川上町');
ok($zip->set_number('0410406')->is_valid_number, '北海道函館市女那川町');
ok($zip->set_number('0410407')->is_valid_number, '北海道函館市日和山町');
ok($zip->set_number('0410408')->is_valid_number, '北海道函館市吉畑町');
ok($zip->set_number('0410521')->is_valid_number, '北海道函館市御崎町');
ok($zip->set_number('0410522')->is_valid_number, '北海道函館市恵山町');
ok($zip->set_number('0410523')->is_valid_number, '北海道函館市柏野町');
ok($zip->set_number('0410524')->is_valid_number, '北海道函館市古武井町');
ok($zip->set_number('0410525')->is_valid_number, '北海道函館市日ノ浜町');
ok($zip->set_number('0410526')->is_valid_number, '北海道函館市高岱町');
ok($zip->set_number('0410601')->is_valid_number, '北海道函館市新八幡町');
ok($zip->set_number('0410602')->is_valid_number, '北海道函館市島泊町');
ok($zip->set_number('0410603')->is_valid_number, '北海道函館市富浦町');
ok($zip->set_number('0410604')->is_valid_number, '北海道函館市元村町');
ok($zip->set_number('0410605')->is_valid_number, '北海道函館市恵山岬町');
ok($zip->set_number('0410606')->is_valid_number, '北海道函館市新恵山町');
ok($zip->set_number('0410611')->is_valid_number, '北海道函館市新浜町');
ok($zip->set_number('0410612')->is_valid_number, '北海道函館市銚子町');
ok($zip->set_number('0410613')->is_valid_number, '北海道函館市絵紙山町');
ok($zip->set_number('0410801')->is_valid_number, '北海道函館市桔梗町');
ok($zip->set_number('0410802')->is_valid_number, '北海道函館市石川町');
ok($zip->set_number('0410803')->is_valid_number, '北海道函館市亀田中野町');
ok($zip->set_number('0410804')->is_valid_number, '北海道函館市赤川町');
ok($zip->set_number('0410805')->is_valid_number, '北海道函館市赤川');
ok($zip->set_number('0410806')->is_valid_number, '北海道函館市美原');
ok($zip->set_number('0410807')->is_valid_number, '北海道函館市北美原');
ok($zip->set_number('0410808')->is_valid_number, '北海道函館市桔梗');
ok($zip->set_number('0410811')->is_valid_number, '北海道函館市富岡町');
ok($zip->set_number('0410812')->is_valid_number, '北海道函館市昭和');
ok($zip->set_number('0410813')->is_valid_number, '北海道函館市亀田本町');
ok($zip->set_number('0410821')->is_valid_number, '北海道函館市港町');
ok($zip->set_number('0410822')->is_valid_number, '北海道函館市亀田港町');
ok($zip->set_number('0410823')->is_valid_number, '北海道函館市昭和町');
ok($zip->set_number('0410824')->is_valid_number, '北海道函館市西桔梗町');
ok($zip->set_number('0410831')->is_valid_number, '北海道函館市神山町');
ok($zip->set_number('0410832')->is_valid_number, '北海道函館市神山');
ok($zip->set_number('0410833')->is_valid_number, '北海道函館市陣川町');
ok($zip->set_number('0410834')->is_valid_number, '北海道函館市東山町');
ok($zip->set_number('0410835')->is_valid_number, '北海道函館市東山');
ok($zip->set_number('0410836')->is_valid_number, '北海道函館市山の手');
ok($zip->set_number('0410837')->is_valid_number, '北海道函館市陣川');
ok($zip->set_number('0410841')->is_valid_number, '北海道函館市日吉町');
ok($zip->set_number('0410843')->is_valid_number, '北海道函館市花園町');
ok($zip->set_number('0410844')->is_valid_number, '北海道函館市川原町');
ok($zip->set_number('0410851')->is_valid_number, '北海道函館市本通');
ok($zip->set_number('0410852')->is_valid_number, '北海道函館市鍛治');
ok($zip->set_number('0410853')->is_valid_number, '北海道函館市中道');
ok($zip->set_number('0411100')->is_valid_number, '北海道亀田郡七飯町以下に掲載がない場合');
ok($zip->set_number('0411101')->is_valid_number, '北海道亀田郡七飯町仁山');
ok($zip->set_number('0411102')->is_valid_number, '北海道亀田郡七飯町峠下');
ok($zip->set_number('0411103')->is_valid_number, '北海道亀田郡七飯町藤城');
ok($zip->set_number('0411104')->is_valid_number, '北海道亀田郡七飯町上藤城');
ok($zip->set_number('0411105')->is_valid_number, '北海道亀田郡七飯町桜町');
ok($zip->set_number('0411111')->is_valid_number, '北海道亀田郡七飯町本町');
ok($zip->set_number('0411112')->is_valid_number, '北海道亀田郡七飯町鳴川');
ok($zip->set_number('0411112')->is_valid_number, '北海道亀田郡七飯町鳴川町');
ok($zip->set_number('0411121')->is_valid_number, '北海道亀田郡七飯町大中山');
ok($zip->set_number('0411122')->is_valid_number, '北海道亀田郡七飯町大川');
ok($zip->set_number('0411131')->is_valid_number, '北海道亀田郡七飯町中野');
ok($zip->set_number('0411132')->is_valid_number, '北海道亀田郡七飯町豊田');
ok($zip->set_number('0411133')->is_valid_number, '北海道亀田郡七飯町中島');
ok($zip->set_number('0411134')->is_valid_number, '北海道亀田郡七飯町鶴野');
ok($zip->set_number('0411135')->is_valid_number, '北海道亀田郡七飯町緑町');
ok($zip->set_number('0411136')->is_valid_number, '北海道亀田郡七飯町飯田町');
ok($zip->set_number('0411201')->is_valid_number, '北海道北斗市本町');
ok($zip->set_number('0411211')->is_valid_number, '北海道北斗市白川');
ok($zip->set_number('0411212')->is_valid_number, '北海道北斗市細入');
ok($zip->set_number('0411213')->is_valid_number, '北海道北斗市開発');
ok($zip->set_number('0411214')->is_valid_number, '北海道北斗市東前');
ok($zip->set_number('0411215')->is_valid_number, '北海道北斗市萩野');
ok($zip->set_number('0411221')->is_valid_number, '北海道北斗市清水川');
ok($zip->set_number('0411222')->is_valid_number, '北海道北斗市千代田');
ok($zip->set_number('0411223')->is_valid_number, '北海道北斗市一本木');
ok($zip->set_number('0411224')->is_valid_number, '北海道北斗市南大野');
ok($zip->set_number('0411225')->is_valid_number, '北海道北斗市文月');
ok($zip->set_number('0411226')->is_valid_number, '北海道北斗市村内');
ok($zip->set_number('0411231')->is_valid_number, '北海道北斗市向野');
ok($zip->set_number('0411241')->is_valid_number, '北海道北斗市稲里');
ok($zip->set_number('0411242')->is_valid_number, '北海道北斗市市渡');
ok($zip->set_number('0411243')->is_valid_number, '北海道北斗市中山');
ok($zip->set_number('0411244')->is_valid_number, '北海道北斗市村山');
ok($zip->set_number('0411251')->is_valid_number, '北海道北斗市本郷');
ok($zip->set_number('0411351')->is_valid_number, '北海道亀田郡七飯町東大沼');
ok($zip->set_number('0411352')->is_valid_number, '北海道亀田郡七飯町軍川');
ok($zip->set_number('0411353')->is_valid_number, '北海道亀田郡七飯町上軍川');
ok($zip->set_number('0411354')->is_valid_number, '北海道亀田郡七飯町大沼町');
ok($zip->set_number('0411355')->is_valid_number, '北海道亀田郡七飯町西大沼');
ok($zip->set_number('0411400')->is_valid_number, '北海道茅部郡鹿部町以下に掲載がない場合');
ok($zip->set_number('0411401')->is_valid_number, '北海道茅部郡鹿部町大岩');
ok($zip->set_number('0411402')->is_valid_number, '北海道茅部郡鹿部町鹿部');
ok($zip->set_number('0411403')->is_valid_number, '北海道茅部郡鹿部町宮浜');
ok($zip->set_number('0411404')->is_valid_number, '北海道茅部郡鹿部町本別');
ok($zip->set_number('0411405')->is_valid_number, '北海道茅部郡鹿部町駒見');
ok($zip->set_number('0411601')->is_valid_number, '北海道函館市古部町');
ok($zip->set_number('0411602')->is_valid_number, '北海道函館市木直町');
ok($zip->set_number('0411603')->is_valid_number, '北海道函館市尾札部町');
ok($zip->set_number('0411611')->is_valid_number, '北海道函館市川汲町');
ok($zip->set_number('0411612')->is_valid_number, '北海道函館市安浦町');
ok($zip->set_number('0411613')->is_valid_number, '北海道函館市臼尻町');
ok($zip->set_number('0411621')->is_valid_number, '北海道函館市豊崎町');
ok($zip->set_number('0411622')->is_valid_number, '北海道函館市大船町');
ok($zip->set_number('0411623')->is_valid_number, '北海道函館市双見町');
ok($zip->set_number('0411624')->is_valid_number, '北海道函館市岩戸町');
ok($zip->set_number('0420901')->is_valid_number, '北海道函館市蛾眉野町');
ok($zip->set_number('0420902')->is_valid_number, '北海道函館市鉄山町');
ok($zip->set_number('0420903')->is_valid_number, '北海道函館市東畑町');
ok($zip->set_number('0420904')->is_valid_number, '北海道函館市庵原町');
ok($zip->set_number('0420905')->is_valid_number, '北海道函館市紅葉山町');
ok($zip->set_number('0420906')->is_valid_number, '北海道函館市三森町');
ok($zip->set_number('0420907')->is_valid_number, '北海道函館市鱒川町');
ok($zip->set_number('0420908')->is_valid_number, '北海道函館市銅山町');
ok($zip->set_number('0420911')->is_valid_number, '北海道函館市石倉町');
ok($zip->set_number('0420912')->is_valid_number, '北海道函館市中野町');
ok($zip->set_number('0420913')->is_valid_number, '北海道函館市赤坂町');
ok($zip->set_number('0420914')->is_valid_number, '北海道函館市上湯川町');
ok($zip->set_number('0420915')->is_valid_number, '北海道函館市西旭岡町');
ok($zip->set_number('0420916')->is_valid_number, '北海道函館市旭岡町');
ok($zip->set_number('0420917')->is_valid_number, '北海道函館市亀尾町');
ok($zip->set_number('0420918')->is_valid_number, '北海道函館市米原町');
ok($zip->set_number('0420921')->is_valid_number, '北海道函館市新湊町');
ok($zip->set_number('0420922')->is_valid_number, '北海道函館市銭亀町');
ok($zip->set_number('0420923')->is_valid_number, '北海道函館市志海苔町');
ok($zip->set_number('0420924')->is_valid_number, '北海道函館市根崎町');
ok($zip->set_number('0420931')->is_valid_number, '北海道函館市榎本町');
ok($zip->set_number('0420932')->is_valid_number, '北海道函館市湯川町');
ok($zip->set_number('0420933')->is_valid_number, '北海道函館市湯浜町');
ok($zip->set_number('0420934')->is_valid_number, '北海道函館市広野町');
ok($zip->set_number('0420935')->is_valid_number, '北海道函館市駒場町');
ok($zip->set_number('0420941')->is_valid_number, '北海道函館市深堀町');
ok($zip->set_number('0420942')->is_valid_number, '北海道函館市柏木町');
ok($zip->set_number('0420943')->is_valid_number, '北海道函館市乃木町');
ok($zip->set_number('0420944')->is_valid_number, '北海道函館市金堀町');
ok($zip->set_number('0420951')->is_valid_number, '北海道函館市瀬戸川町');
ok($zip->set_number('0420952')->is_valid_number, '北海道函館市高松町');
ok($zip->set_number('0420953')->is_valid_number, '北海道函館市戸倉町');
ok($zip->set_number('0420954')->is_valid_number, '北海道函館市上野町');
ok($zip->set_number('0420955')->is_valid_number, '北海道函館市高丘町');
ok($zip->set_number('0420956')->is_valid_number, '北海道函館市見晴町');
ok($zip->set_number('0420957')->is_valid_number, '北海道函館市滝沢町');
ok($zip->set_number('0420958')->is_valid_number, '北海道函館市鈴蘭丘町');
ok($zip->set_number('0430000')->is_valid_number, '北海道檜山郡江差町以下に掲載がない場合');
ok($zip->set_number('0430011')->is_valid_number, '北海道檜山郡江差町五厘沢町');
ok($zip->set_number('0430012')->is_valid_number, '北海道檜山郡江差町鰔川町');
ok($zip->set_number('0430013')->is_valid_number, '北海道檜山郡江差町朝日町');
ok($zip->set_number('0430014')->is_valid_number, '北海道檜山郡江差町小黒部町');
ok($zip->set_number('0430015')->is_valid_number, '北海道檜山郡江差町中網町');
ok($zip->set_number('0430016')->is_valid_number, '北海道檜山郡江差町越前町');
ok($zip->set_number('0430017')->is_valid_number, '北海道檜山郡江差町水堀町');
ok($zip->set_number('0430021')->is_valid_number, '北海道檜山郡江差町柳崎町');
ok($zip->set_number('0430022')->is_valid_number, '北海道檜山郡江差町伏木戸町');
ok($zip->set_number('0430023')->is_valid_number, '北海道檜山郡江差町田沢町');
ok($zip->set_number('0430024')->is_valid_number, '北海道檜山郡江差町尾山町');
ok($zip->set_number('0430025')->is_valid_number, '北海道檜山郡江差町泊町');
ok($zip->set_number('0430026')->is_valid_number, '北海道檜山郡江差町大澗町');
ok($zip->set_number('0430031')->is_valid_number, '北海道檜山郡江差町愛宕町');
ok($zip->set_number('0430032')->is_valid_number, '北海道檜山郡江差町新栄町');
ok($zip->set_number('0430033')->is_valid_number, '北海道檜山郡江差町豊川町');
ok($zip->set_number('0430034')->is_valid_number, '北海道檜山郡江差町中歌町');
ok($zip->set_number('0430035')->is_valid_number, '北海道檜山郡江差町桧岱');
ok($zip->set_number('0430036')->is_valid_number, '北海道檜山郡江差町東山');
ok($zip->set_number('0430041')->is_valid_number, '北海道檜山郡江差町姥神町');
ok($zip->set_number('0430042')->is_valid_number, '北海道檜山郡江差町上野町');
ok($zip->set_number('0430043')->is_valid_number, '北海道檜山郡江差町本町');
ok($zip->set_number('0430044')->is_valid_number, '北海道檜山郡江差町橋本町');
ok($zip->set_number('0430045')->is_valid_number, '北海道檜山郡江差町鴎島');
ok($zip->set_number('0430046')->is_valid_number, '北海道檜山郡江差町江差港北埠頭');
ok($zip->set_number('0430051')->is_valid_number, '北海道檜山郡江差町津花町');
ok($zip->set_number('0430052')->is_valid_number, '北海道檜山郡江差町茂尻町');
ok($zip->set_number('0430053')->is_valid_number, '北海道檜山郡江差町新地町');
ok($zip->set_number('0430054')->is_valid_number, '北海道檜山郡江差町緑丘');
ok($zip->set_number('0430055')->is_valid_number, '北海道檜山郡江差町円山');
ok($zip->set_number('0430056')->is_valid_number, '北海道檜山郡江差町陣屋町');
ok($zip->set_number('0430057')->is_valid_number, '北海道檜山郡江差町海岸町');
ok($zip->set_number('0430061')->is_valid_number, '北海道檜山郡江差町南が丘');
ok($zip->set_number('0430062')->is_valid_number, '北海道檜山郡江差町萩の岱');
ok($zip->set_number('0430063')->is_valid_number, '北海道檜山郡江差町南浜町');
ok($zip->set_number('0430064')->is_valid_number, '北海道檜山郡江差町柏町');
ok($zip->set_number('0430065')->is_valid_number, '北海道檜山郡江差町砂川');
ok($zip->set_number('0430066')->is_valid_number, '北海道檜山郡江差町とど川町');
ok($zip->set_number('0430100')->is_valid_number, '北海道爾志郡乙部町以下に掲載がない場合');
ok($zip->set_number('0430101')->is_valid_number, '北海道爾志郡乙部町滝瀬');
ok($zip->set_number('0430102')->is_valid_number, '北海道爾志郡乙部町元町');
ok($zip->set_number('0430103')->is_valid_number, '北海道爾志郡乙部町緑町');
ok($zip->set_number('0430104')->is_valid_number, '北海道爾志郡乙部町館浦');
ok($zip->set_number('0430111')->is_valid_number, '北海道爾志郡乙部町鳥山');
ok($zip->set_number('0430112')->is_valid_number, '北海道爾志郡乙部町栄野');
ok($zip->set_number('0430113')->is_valid_number, '北海道爾志郡乙部町栄浜');
ok($zip->set_number('0430114')->is_valid_number, '北海道爾志郡乙部町元和');
ok($zip->set_number('0430115')->is_valid_number, '北海道爾志郡乙部町富岡');
ok($zip->set_number('0430116')->is_valid_number, '北海道爾志郡乙部町旭岱');
ok($zip->set_number('0430117')->is_valid_number, '北海道爾志郡乙部町姫川');
ok($zip->set_number('0430231')->is_valid_number, '北海道爾志郡乙部町豊浜');
ok($zip->set_number('0430232')->is_valid_number, '北海道爾志郡乙部町花磯');
ok($zip->set_number('0430233')->is_valid_number, '北海道爾志郡乙部町潮見');
ok($zip->set_number('0430234')->is_valid_number, '北海道爾志郡乙部町三ツ谷');
ok($zip->set_number('0430331')->is_valid_number, '北海道二海郡八雲町熊石折戸町');
ok($zip->set_number('0430332')->is_valid_number, '北海道二海郡八雲町熊石相沼町');
ok($zip->set_number('0430333')->is_valid_number, '北海道二海郡八雲町熊石館平町');
ok($zip->set_number('0430334')->is_valid_number, '北海道二海郡八雲町熊石泊川町');
ok($zip->set_number('0430335')->is_valid_number, '北海道二海郡八雲町熊石黒岩町');
ok($zip->set_number('0430401')->is_valid_number, '北海道二海郡八雲町熊石見日町');
ok($zip->set_number('0430402')->is_valid_number, '北海道二海郡八雲町熊石鮎川町');
ok($zip->set_number('0430403')->is_valid_number, '北海道二海郡八雲町熊石平町');
ok($zip->set_number('0430404')->is_valid_number, '北海道二海郡八雲町熊石畳岩町');
ok($zip->set_number('0430405')->is_valid_number, '北海道二海郡八雲町熊石大谷町');
ok($zip->set_number('0430415')->is_valid_number, '北海道二海郡八雲町熊石根崎町');
ok($zip->set_number('0430416')->is_valid_number, '北海道二海郡八雲町熊石雲石町');
ok($zip->set_number('0430417')->is_valid_number, '北海道二海郡八雲町熊石鳴神町');
ok($zip->set_number('0430418')->is_valid_number, '北海道二海郡八雲町熊石関内町');
ok($zip->set_number('0430419')->is_valid_number, '北海道二海郡八雲町熊石西浜町');
ok($zip->set_number('0430421')->is_valid_number, '北海道久遠郡せたな町大成区長磯');
ok($zip->set_number('0430501')->is_valid_number, '北海道久遠郡せたな町大成区太田');
ok($zip->set_number('0430502')->is_valid_number, '北海道久遠郡せたな町大成区富磯');
ok($zip->set_number('0430503')->is_valid_number, '北海道久遠郡せたな町大成区上浦');
ok($zip->set_number('0430504')->is_valid_number, '北海道久遠郡せたな町大成区都');
ok($zip->set_number('0430505')->is_valid_number, '北海道久遠郡せたな町大成区本陣');
ok($zip->set_number('0430511')->is_valid_number, '北海道久遠郡せたな町大成区久遠');
ok($zip->set_number('0430512')->is_valid_number, '北海道久遠郡せたな町大成区花歌');
ok($zip->set_number('0430513')->is_valid_number, '北海道久遠郡せたな町大成区宮野');
ok($zip->set_number('0430514')->is_valid_number, '北海道久遠郡せたな町大成区平浜');
ok($zip->set_number('0430515')->is_valid_number, '北海道久遠郡せたな町大成区貝取澗');
ok($zip->set_number('0431100')->is_valid_number, '北海道檜山郡厚沢部町以下に掲載がない場合');
ok($zip->set_number('0431101')->is_valid_number, '北海道檜山郡厚沢部町清水');
ok($zip->set_number('0431102')->is_valid_number, '北海道檜山郡厚沢部町稲見');
ok($zip->set_number('0431103')->is_valid_number, '北海道檜山郡厚沢部町滝野');
ok($zip->set_number('0431104')->is_valid_number, '北海道檜山郡厚沢部町上里');
ok($zip->set_number('0431111')->is_valid_number, '北海道檜山郡厚沢部町赤沼町');
ok($zip->set_number('0431112')->is_valid_number, '北海道檜山郡厚沢部町緑町');
ok($zip->set_number('0431113')->is_valid_number, '北海道檜山郡厚沢部町新町');
ok($zip->set_number('0431114')->is_valid_number, '北海道檜山郡厚沢部町本町');
ok($zip->set_number('0431115')->is_valid_number, '北海道檜山郡厚沢部町松園町');
ok($zip->set_number('0431116')->is_valid_number, '北海道檜山郡厚沢部町上の山');
ok($zip->set_number('0431117')->is_valid_number, '北海道檜山郡厚沢部町美和');
ok($zip->set_number('0431118')->is_valid_number, '北海道檜山郡厚沢部町富栄');
ok($zip->set_number('0431231')->is_valid_number, '北海道檜山郡厚沢部町共和');
ok($zip->set_number('0431232')->is_valid_number, '北海道檜山郡厚沢部町相生');
ok($zip->set_number('0431233')->is_valid_number, '北海道檜山郡厚沢部町旭丘');
ok($zip->set_number('0431234')->is_valid_number, '北海道檜山郡厚沢部町木間内');
ok($zip->set_number('0431235')->is_valid_number, '北海道檜山郡厚沢部町峠下');
ok($zip->set_number('0431236')->is_valid_number, '北海道檜山郡厚沢部町社の山(その他)');
ok($zip->set_number('0431237')->is_valid_number, '北海道檜山郡厚沢部町鶉町');
ok($zip->set_number('0431238')->is_valid_number, '北海道檜山郡厚沢部町鶉');
ok($zip->set_number('0431351')->is_valid_number, '北海道檜山郡厚沢部町館町');
ok($zip->set_number('0431361')->is_valid_number, '北海道檜山郡厚沢部町社の山(中の沢)');
ok($zip->set_number('0431362')->is_valid_number, '北海道檜山郡厚沢部町須賀');
ok($zip->set_number('0431363')->is_valid_number, '北海道檜山郡厚沢部町富里');
ok($zip->set_number('0431364')->is_valid_number, '北海道檜山郡厚沢部町城丘');
ok($zip->set_number('0431365')->is_valid_number, '北海道檜山郡厚沢部町南館町');
ok($zip->set_number('0431366')->is_valid_number, '北海道檜山郡厚沢部町当路');
ok($zip->set_number('0431367')->is_valid_number, '北海道檜山郡厚沢部町新栄');
ok($zip->set_number('0431368')->is_valid_number, '北海道檜山郡厚沢部町中館');
ok($zip->set_number('0431400')->is_valid_number, '北海道奥尻郡奥尻町以下に掲載がない場合');
ok($zip->set_number('0431401')->is_valid_number, '北海道奥尻郡奥尻町奥尻');
ok($zip->set_number('0431402')->is_valid_number, '北海道奥尻郡奥尻町赤石');
ok($zip->set_number('0431403')->is_valid_number, '北海道奥尻郡奥尻町球浦');
ok($zip->set_number('0431404')->is_valid_number, '北海道奥尻郡奥尻町宮津');
ok($zip->set_number('0431405')->is_valid_number, '北海道奥尻郡奥尻町稲穂');
ok($zip->set_number('0431406')->is_valid_number, '北海道奥尻郡奥尻町湯浜(その他)');
ok($zip->set_number('0431521')->is_valid_number, '北海道奥尻郡奥尻町青苗');
ok($zip->set_number('0431522')->is_valid_number, '北海道奥尻郡奥尻町富里');
ok($zip->set_number('0431523')->is_valid_number, '北海道奥尻郡奥尻町松江');
ok($zip->set_number('0431524')->is_valid_number, '北海道奥尻郡奥尻町米岡');
ok($zip->set_number('0431525')->is_valid_number, '北海道奥尻郡奥尻町湯浜(神威脇、幌内)');
ok($zip->set_number('0440000')->is_valid_number, '北海道虻田郡倶知安町以下に掲載がない場合');
ok($zip->set_number('0440001')->is_valid_number, '北海道虻田郡倶知安町北一条東');
ok($zip->set_number('0440002')->is_valid_number, '北海道虻田郡倶知安町北二条東');
ok($zip->set_number('0440003')->is_valid_number, '北海道虻田郡倶知安町北三条東');
ok($zip->set_number('0440004')->is_valid_number, '北海道虻田郡倶知安町北四条東');
ok($zip->set_number('0440005')->is_valid_number, '北海道虻田郡倶知安町北五条東');
ok($zip->set_number('0440006')->is_valid_number, '北海道虻田郡倶知安町北六条東');
ok($zip->set_number('0440007')->is_valid_number, '北海道虻田郡倶知安町北七条東');
ok($zip->set_number('0440011')->is_valid_number, '北海道虻田郡倶知安町南一条東');
ok($zip->set_number('0440012')->is_valid_number, '北海道虻田郡倶知安町南二条東');
ok($zip->set_number('0440013')->is_valid_number, '北海道虻田郡倶知安町南三条東');
ok($zip->set_number('0440014')->is_valid_number, '北海道虻田郡倶知安町南四条東');
ok($zip->set_number('0440015')->is_valid_number, '北海道虻田郡倶知安町南五条東');
ok($zip->set_number('0440016')->is_valid_number, '北海道虻田郡倶知安町南六条東');
ok($zip->set_number('0440021')->is_valid_number, '北海道虻田郡倶知安町南七条東');
ok($zip->set_number('0440022')->is_valid_number, '北海道虻田郡倶知安町南八条東');
ok($zip->set_number('0440023')->is_valid_number, '北海道虻田郡倶知安町南九条東');
ok($zip->set_number('0440024')->is_valid_number, '北海道虻田郡倶知安町南十条東');
ok($zip->set_number('0440025')->is_valid_number, '北海道虻田郡倶知安町南十一条東');
ok($zip->set_number('0440031')->is_valid_number, '北海道虻田郡倶知安町南一条西');
ok($zip->set_number('0440032')->is_valid_number, '北海道虻田郡倶知安町南二条西');
ok($zip->set_number('0440033')->is_valid_number, '北海道虻田郡倶知安町南三条西');
ok($zip->set_number('0440034')->is_valid_number, '北海道虻田郡倶知安町南四条西');
ok($zip->set_number('0440035')->is_valid_number, '北海道虻田郡倶知安町南五条西');
ok($zip->set_number('0440036')->is_valid_number, '北海道虻田郡倶知安町南六条西');
ok($zip->set_number('0440041')->is_valid_number, '北海道虻田郡倶知安町南七条西');
ok($zip->set_number('0440042')->is_valid_number, '北海道虻田郡倶知安町南八条西');
ok($zip->set_number('0440043')->is_valid_number, '北海道虻田郡倶知安町南九条西');
ok($zip->set_number('0440044')->is_valid_number, '北海道虻田郡倶知安町南十条西');
ok($zip->set_number('0440045')->is_valid_number, '北海道虻田郡倶知安町南十一条西');
ok($zip->set_number('0440051')->is_valid_number, '北海道虻田郡倶知安町北一条西');
ok($zip->set_number('0440052')->is_valid_number, '北海道虻田郡倶知安町北二条西');
ok($zip->set_number('0440053')->is_valid_number, '北海道虻田郡倶知安町北三条西');
ok($zip->set_number('0440054')->is_valid_number, '北海道虻田郡倶知安町北四条西');
ok($zip->set_number('0440055')->is_valid_number, '北海道虻田郡倶知安町北五条西');
ok($zip->set_number('0440056')->is_valid_number, '北海道虻田郡倶知安町北六条西');
ok($zip->set_number('0440057')->is_valid_number, '北海道虻田郡倶知安町北七条西');
ok($zip->set_number('0440061')->is_valid_number, '北海道虻田郡倶知安町大和');
ok($zip->set_number('0440062')->is_valid_number, '北海道虻田郡倶知安町扶桑');
ok($zip->set_number('0440063')->is_valid_number, '北海道虻田郡倶知安町末広');
ok($zip->set_number('0440064')->is_valid_number, '北海道虻田郡倶知安町出雲');
ok($zip->set_number('0440065')->is_valid_number, '北海道虻田郡倶知安町高見');
ok($zip->set_number('0440066')->is_valid_number, '北海道虻田郡倶知安町琴平');
ok($zip->set_number('0440067')->is_valid_number, '北海道虻田郡倶知安町瑞穂');
ok($zip->set_number('0440068')->is_valid_number, '北海道虻田郡倶知安町緑');
ok($zip->set_number('0440071')->is_valid_number, '北海道虻田郡倶知安町寒別');
ok($zip->set_number('0440072')->is_valid_number, '北海道虻田郡倶知安町八幡');
ok($zip->set_number('0440073')->is_valid_number, '北海道虻田郡倶知安町豊岡');
ok($zip->set_number('0440074')->is_valid_number, '北海道虻田郡倶知安町巽');
ok($zip->set_number('0440075')->is_valid_number, '北海道虻田郡倶知安町富士見');
ok($zip->set_number('0440076')->is_valid_number, '北海道虻田郡倶知安町高砂');
ok($zip->set_number('0440077')->is_valid_number, '北海道虻田郡倶知安町比羅夫');
ok($zip->set_number('0440078')->is_valid_number, '北海道虻田郡倶知安町樺山');
ok($zip->set_number('0440080')->is_valid_number, '北海道虻田郡倶知安町ニセコひらふ一条');
ok($zip->set_number('0440081')->is_valid_number, '北海道虻田郡倶知安町山田');
ok($zip->set_number('0440082')->is_valid_number, '北海道虻田郡倶知安町岩尾別');
ok($zip->set_number('0440083')->is_valid_number, '北海道虻田郡倶知安町旭');
ok($zip->set_number('0440084')->is_valid_number, '北海道虻田郡倶知安町花園');
ok($zip->set_number('0440085')->is_valid_number, '北海道虻田郡倶知安町峠下');
ok($zip->set_number('0440086')->is_valid_number, '北海道虻田郡倶知安町ニセコひらふ五条');
ok($zip->set_number('0440087')->is_valid_number, '北海道虻田郡倶知安町ニセコひらふ四条');
ok($zip->set_number('0440088')->is_valid_number, '北海道虻田郡倶知安町ニセコひらふ三条');
ok($zip->set_number('0440089')->is_valid_number, '北海道虻田郡倶知安町ニセコひらふ二条');
ok($zip->set_number('0440100')->is_valid_number, '北海道虻田郡京極町以下に掲載がない場合');
ok($zip->set_number('0440101')->is_valid_number, '北海道虻田郡京極町京極');
ok($zip->set_number('0440111')->is_valid_number, '北海道虻田郡京極町北岡');
ok($zip->set_number('0440112')->is_valid_number, '北海道虻田郡京極町春日');
ok($zip->set_number('0440113')->is_valid_number, '北海道虻田郡京極町松川');
ok($zip->set_number('0440121')->is_valid_number, '北海道虻田郡京極町三崎');
ok($zip->set_number('0440122')->is_valid_number, '北海道虻田郡京極町大富');
ok($zip->set_number('0440123')->is_valid_number, '北海道虻田郡京極町脇方');
ok($zip->set_number('0440124')->is_valid_number, '北海道虻田郡京極町錦');
ok($zip->set_number('0440125')->is_valid_number, '北海道虻田郡京極町東花');
ok($zip->set_number('0440131')->is_valid_number, '北海道虻田郡京極町川西');
ok($zip->set_number('0440132')->is_valid_number, '北海道虻田郡京極町更進');
ok($zip->set_number('0440200')->is_valid_number, '北海道虻田郡喜茂別町以下に掲載がない場合');
ok($zip->set_number('0440201')->is_valid_number, '北海道虻田郡喜茂別町旭町');
ok($zip->set_number('0440201')->is_valid_number, '北海道虻田郡喜茂別町大町');
ok($zip->set_number('0440201')->is_valid_number, '北海道虻田郡喜茂別町喜茂別');
ok($zip->set_number('0440201')->is_valid_number, '北海道虻田郡喜茂別町幸町');
ok($zip->set_number('0440201')->is_valid_number, '北海道虻田郡喜茂別町末広町');
ok($zip->set_number('0440201')->is_valid_number, '北海道虻田郡喜茂別町本町');
ok($zip->set_number('0440201')->is_valid_number, '北海道虻田郡喜茂別町緑町');
ok($zip->set_number('0440211')->is_valid_number, '北海道虻田郡喜茂別町富士見台');
ok($zip->set_number('0440212')->is_valid_number, '北海道虻田郡喜茂別町留産');
ok($zip->set_number('0440213')->is_valid_number, '北海道虻田郡喜茂別町比羅岡');
ok($zip->set_number('0440214')->is_valid_number, '北海道虻田郡喜茂別町尻別');
ok($zip->set_number('0440215')->is_valid_number, '北海道虻田郡喜茂別町相川');
ok($zip->set_number('0440221')->is_valid_number, '北海道虻田郡喜茂別町伏見');
ok($zip->set_number('0440222')->is_valid_number, '北海道虻田郡喜茂別町栄');
ok($zip->set_number('0440223')->is_valid_number, '北海道虻田郡喜茂別町川上');
ok($zip->set_number('0440224')->is_valid_number, '北海道虻田郡喜茂別町知来別');
ok($zip->set_number('0440225')->is_valid_number, '北海道虻田郡喜茂別町福島');
ok($zip->set_number('0440441')->is_valid_number, '北海道伊達市大滝区愛地町');
ok($zip->set_number('0440442')->is_valid_number, '北海道伊達市大滝区宮城町');
ok($zip->set_number('0440443')->is_valid_number, '北海道伊達市大滝区清原町');
ok($zip->set_number('0440444')->is_valid_number, '北海道伊達市大滝区豊里町');
ok($zip->set_number('0440451')->is_valid_number, '北海道虻田郡喜茂別町上尻別');
ok($zip->set_number('0440451')->is_valid_number, '北海道虻田郡喜茂別町鈴川');
ok($zip->set_number('0440452')->is_valid_number, '北海道虻田郡喜茂別町福丘');
ok($zip->set_number('0440453')->is_valid_number, '北海道虻田郡喜茂別町共栄');
ok($zip->set_number('0440453')->is_valid_number, '北海道虻田郡喜茂別町御園');
ok($zip->set_number('0440454')->is_valid_number, '北海道虻田郡喜茂別町金山');
ok($zip->set_number('0440461')->is_valid_number, '北海道虻田郡喜茂別町中里');
ok($zip->set_number('0440461')->is_valid_number, '北海道虻田郡喜茂別町福里');
ok($zip->set_number('0440462')->is_valid_number, '北海道虻田郡喜茂別町花丘');
ok($zip->set_number('0440463')->is_valid_number, '北海道虻田郡喜茂別町双葉');
ok($zip->set_number('0450000')->is_valid_number, '北海道岩内郡岩内町以下に掲載がない場合');
ok($zip->set_number('0450001')->is_valid_number, '北海道岩内郡岩内町大浜');
ok($zip->set_number('0450002')->is_valid_number, '北海道岩内郡岩内町東山');
ok($zip->set_number('0450003')->is_valid_number, '北海道岩内郡岩内町万代');
ok($zip->set_number('0450011')->is_valid_number, '北海道岩内郡岩内町栄');
ok($zip->set_number('0450012')->is_valid_number, '北海道岩内郡岩内町宮園');
ok($zip->set_number('0450013')->is_valid_number, '北海道岩内郡岩内町高台');
ok($zip->set_number('0450021')->is_valid_number, '北海道岩内郡岩内町大和');
ok($zip->set_number('0450022')->is_valid_number, '北海道岩内郡岩内町清住');
ok($zip->set_number('0450023')->is_valid_number, '北海道岩内郡岩内町相生');
ok($zip->set_number('0450024')->is_valid_number, '北海道岩内郡岩内町野束');
ok($zip->set_number('0450025')->is_valid_number, '北海道岩内郡岩内町敷島内');
ok($zip->set_number('0450026')->is_valid_number, '北海道岩内郡岩内町御崎');
ok($zip->set_number('0450031')->is_valid_number, '北海道岩内郡共和町梨野舞納');
ok($zip->set_number('0450032')->is_valid_number, '北海道岩内郡共和町老古美');
ok($zip->set_number('0450121')->is_valid_number, '北海道岩内郡共和町幌似');
ok($zip->set_number('0450122')->is_valid_number, '北海道岩内郡共和町発足');
ok($zip->set_number('0450123')->is_valid_number, '北海道岩内郡共和町宮丘');
ok($zip->set_number('0450200')->is_valid_number, '北海道古宇郡泊村以下に掲載がない場合');
ok($zip->set_number('0450201')->is_valid_number, '北海道古宇郡泊村堀株村');
ok($zip->set_number('0450202')->is_valid_number, '北海道古宇郡泊村茅沼村');
ok($zip->set_number('0450203')->is_valid_number, '北海道古宇郡泊村泊村');
ok($zip->set_number('0450204')->is_valid_number, '北海道古宇郡泊村盃村');
ok($zip->set_number('0450205')->is_valid_number, '北海道古宇郡泊村興志内村');
ok($zip->set_number('0450300')->is_valid_number, '北海道古宇郡神恵内村以下に掲載がない場合');
ok($zip->set_number('0450301')->is_valid_number, '北海道古宇郡神恵内村神恵内村');
ok($zip->set_number('0450302')->is_valid_number, '北海道古宇郡神恵内村赤石村');
ok($zip->set_number('0450303')->is_valid_number, '北海道古宇郡神恵内村珊内村');
ok($zip->set_number('0460000')->is_valid_number, '北海道余市郡余市町以下に掲載がない場合');
ok($zip->set_number('0460001')->is_valid_number, '北海道余市郡余市町栄町');
ok($zip->set_number('0460002')->is_valid_number, '北海道余市郡余市町登町');
ok($zip->set_number('0460003')->is_valid_number, '北海道余市郡余市町黒川町');
ok($zip->set_number('0460004')->is_valid_number, '北海道余市郡余市町大川町');
ok($zip->set_number('0460011')->is_valid_number, '北海道余市郡余市町入舟町');
ok($zip->set_number('0460012')->is_valid_number, '北海道余市郡余市町山田町');
ok($zip->set_number('0460013')->is_valid_number, '北海道余市郡余市町豊丘町');
ok($zip->set_number('0460014')->is_valid_number, '北海道余市郡余市町美園町');
ok($zip->set_number('0460015')->is_valid_number, '北海道余市郡余市町朝日町');
ok($zip->set_number('0460021')->is_valid_number, '北海道余市郡余市町浜中町');
ok($zip->set_number('0460022')->is_valid_number, '北海道余市郡余市町沢町');
ok($zip->set_number('0460023')->is_valid_number, '北海道余市郡余市町梅川町');
ok($zip->set_number('0460024')->is_valid_number, '北海道余市郡余市町港町');
ok($zip->set_number('0460025')->is_valid_number, '北海道余市郡余市町富沢町');
ok($zip->set_number('0460031')->is_valid_number, '北海道余市郡余市町白岩町');
ok($zip->set_number('0460032')->is_valid_number, '北海道余市郡余市町豊浜町');
ok($zip->set_number('0460033')->is_valid_number, '北海道余市郡余市町潮見町');
ok($zip->set_number('0460100')->is_valid_number, '北海道古平郡古平町以下に掲載がない場合');
ok($zip->set_number('0460101')->is_valid_number, '北海道古平郡古平町御崎町');
ok($zip->set_number('0460102')->is_valid_number, '北海道古平郡古平町丸山町');
ok($zip->set_number('0460103')->is_valid_number, '北海道古平郡古平町本町');
ok($zip->set_number('0460104')->is_valid_number, '北海道古平郡古平町入船町');
ok($zip->set_number('0460111')->is_valid_number, '北海道古平郡古平町群来町');
ok($zip->set_number('0460112')->is_valid_number, '北海道古平郡古平町新地町');
ok($zip->set_number('0460113')->is_valid_number, '北海道古平郡古平町港町');
ok($zip->set_number('0460121')->is_valid_number, '北海道古平郡古平町浜町');
ok($zip->set_number('0460131')->is_valid_number, '北海道古平郡古平町沢江町');
ok($zip->set_number('0460132')->is_valid_number, '北海道古平郡古平町歌棄町');
ok($zip->set_number('0460133')->is_valid_number, '北海道古平郡古平町沖町');
ok($zip->set_number('0460200')->is_valid_number, '北海道積丹郡積丹町以下に掲載がない場合');
ok($zip->set_number('0460201')->is_valid_number, '北海道積丹郡積丹町美国町');
ok($zip->set_number('0460202')->is_valid_number, '北海道積丹郡積丹町婦美町');
ok($zip->set_number('0460321')->is_valid_number, '北海道積丹郡積丹町神岬町');
ok($zip->set_number('0460322')->is_valid_number, '北海道積丹郡積丹町余別町');
ok($zip->set_number('0460323')->is_valid_number, '北海道積丹郡積丹町来岸町');
ok($zip->set_number('0460324')->is_valid_number, '北海道積丹郡積丹町西河町');
ok($zip->set_number('0460325')->is_valid_number, '北海道積丹郡積丹町野塚町');
ok($zip->set_number('0460326')->is_valid_number, '北海道積丹郡積丹町日司町');
ok($zip->set_number('0460327')->is_valid_number, '北海道積丹郡積丹町入舸町');
ok($zip->set_number('0460328')->is_valid_number, '北海道積丹郡積丹町幌武意町');
ok($zip->set_number('0460500')->is_valid_number, '北海道余市郡赤井川村以下に掲載がない場合');
ok($zip->set_number('0460501')->is_valid_number, '北海道余市郡赤井川村赤井川');
ok($zip->set_number('0460511')->is_valid_number, '北海道余市郡赤井川村日ノ出');
ok($zip->set_number('0460512')->is_valid_number, '北海道余市郡赤井川村山梨');
ok($zip->set_number('0460521')->is_valid_number, '北海道余市郡赤井川村池田');
ok($zip->set_number('0460531')->is_valid_number, '北海道余市郡赤井川村旭丘');
ok($zip->set_number('0460532')->is_valid_number, '北海道余市郡赤井川村富田');
ok($zip->set_number('0460541')->is_valid_number, '北海道余市郡赤井川村都');
ok($zip->set_number('0460542')->is_valid_number, '北海道余市郡赤井川村曲川');
ok($zip->set_number('0460551')->is_valid_number, '北海道余市郡赤井川村轟');
ok($zip->set_number('0460552')->is_valid_number, '北海道余市郡赤井川村明治');
ok($zip->set_number('0460561')->is_valid_number, '北海道余市郡赤井川村落合');
ok($zip->set_number('0460571')->is_valid_number, '北海道余市郡赤井川村常盤');
ok($zip->set_number('0470000')->is_valid_number, '北海道小樽市以下に掲載がない場合');
ok($zip->set_number('0470001')->is_valid_number, '北海道小樽市若竹町');
ok($zip->set_number('0470002')->is_valid_number, '北海道小樽市潮見台');
ok($zip->set_number('0470003')->is_valid_number, '北海道小樽市真栄');
ok($zip->set_number('0470004')->is_valid_number, '北海道小樽市新富町');
ok($zip->set_number('0470005')->is_valid_number, '北海道小樽市勝納町');
ok($zip->set_number('0470006')->is_valid_number, '北海道小樽市有幌町');
ok($zip->set_number('0470007')->is_valid_number, '北海道小樽市港町');
ok($zip->set_number('0470008')->is_valid_number, '北海道小樽市築港');
ok($zip->set_number('0470011')->is_valid_number, '北海道小樽市天神');
ok($zip->set_number('0470012')->is_valid_number, '北海道小樽市天狗山');
ok($zip->set_number('0470013')->is_valid_number, '北海道小樽市奥沢');
ok($zip->set_number('0470014')->is_valid_number, '北海道小樽市住ノ江');
ok($zip->set_number('0470015')->is_valid_number, '北海道小樽市住吉町');
ok($zip->set_number('0470016')->is_valid_number, '北海道小樽市信香町');
ok($zip->set_number('0470017')->is_valid_number, '北海道小樽市若松');
ok($zip->set_number('0470021')->is_valid_number, '北海道小樽市入船');
ok($zip->set_number('0470022')->is_valid_number, '北海道小樽市松ケ枝');
ok($zip->set_number('0470023')->is_valid_number, '北海道小樽市最上');
ok($zip->set_number('0470024')->is_valid_number, '北海道小樽市花園');
ok($zip->set_number('0470025')->is_valid_number, '北海道小樽市山田町');
ok($zip->set_number('0470026')->is_valid_number, '北海道小樽市東雲町');
ok($zip->set_number('0470027')->is_valid_number, '北海道小樽市堺町');
ok($zip->set_number('0470028')->is_valid_number, '北海道小樽市相生町');
ok($zip->set_number('0470031')->is_valid_number, '北海道小樽市色内');
ok($zip->set_number('0470032')->is_valid_number, '北海道小樽市稲穂');
ok($zip->set_number('0470033')->is_valid_number, '北海道小樽市富岡');
ok($zip->set_number('0470034')->is_valid_number, '北海道小樽市緑');
ok($zip->set_number('0470035')->is_valid_number, '北海道小樽市旭町');
ok($zip->set_number('0470036')->is_valid_number, '北海道小樽市長橋');
ok($zip->set_number('0470037')->is_valid_number, '北海道小樽市幸');
ok($zip->set_number('0470038')->is_valid_number, '北海道小樽市石山町');
ok($zip->set_number('0470039')->is_valid_number, '北海道小樽市錦町');
ok($zip->set_number('0470041')->is_valid_number, '北海道小樽市手宮');
ok($zip->set_number('0470042')->is_valid_number, '北海道小樽市末広町');
ok($zip->set_number('0470043')->is_valid_number, '北海道小樽市豊川町');
ok($zip->set_number('0470044')->is_valid_number, '北海道小樽市梅ケ枝町');
ok($zip->set_number('0470045')->is_valid_number, '北海道小樽市清水町');
ok($zip->set_number('0470046')->is_valid_number, '北海道小樽市赤岩');
ok($zip->set_number('0470047')->is_valid_number, '北海道小樽市祝津');
ok($zip->set_number('0470048')->is_valid_number, '北海道小樽市高島');
ok($zip->set_number('0470151')->is_valid_number, '北海道小樽市朝里');
ok($zip->set_number('0470152')->is_valid_number, '北海道小樽市新光');
ok($zip->set_number('0470153')->is_valid_number, '北海道小樽市新光町');
ok($zip->set_number('0470154')->is_valid_number, '北海道小樽市朝里川温泉');
ok($zip->set_number('0470155')->is_valid_number, '北海道小樽市望洋台');
ok($zip->set_number('0470156')->is_valid_number, '北海道小樽市桜');
ok($zip->set_number('0470157')->is_valid_number, '北海道小樽市船浜町');
ok($zip->set_number('0470261')->is_valid_number, '北海道小樽市銭函(1~3丁目)');
ok($zip->set_number('0470262')->is_valid_number, '北海道小樽市星野町');
ok($zip->set_number('0470263')->is_valid_number, '北海道小樽市見晴町');
ok($zip->set_number('0470264')->is_valid_number, '北海道小樽市桂岡町');
ok($zip->set_number('0470265')->is_valid_number, '北海道小樽市春香町');
ok($zip->set_number('0470266')->is_valid_number, '北海道小樽市張碓町');
ok($zip->set_number('0480100')->is_valid_number, '北海道寿都郡黒松内町以下に掲載がない場合');
ok($zip->set_number('0480101')->is_valid_number, '北海道寿都郡黒松内町黒松内');
ok($zip->set_number('0480111')->is_valid_number, '北海道寿都郡黒松内町中里');
ok($zip->set_number('0480112')->is_valid_number, '北海道寿都郡黒松内町貝殻');
ok($zip->set_number('0480113')->is_valid_number, '北海道寿都郡黒松内町豊幌');
ok($zip->set_number('0480114')->is_valid_number, '北海道寿都郡黒松内町歌才');
ok($zip->set_number('0480115')->is_valid_number, '北海道寿都郡黒松内町西沢');
ok($zip->set_number('0480116')->is_valid_number, '北海道寿都郡黒松内町旭野');
ok($zip->set_number('0480117')->is_valid_number, '北海道寿都郡黒松内町添別');
ok($zip->set_number('0480121')->is_valid_number, '北海道寿都郡黒松内町熱郛');
ok($zip->set_number('0480122')->is_valid_number, '北海道寿都郡黒松内町白炭');
ok($zip->set_number('0480123')->is_valid_number, '北海道寿都郡黒松内町中ノ川');
ok($zip->set_number('0480124')->is_valid_number, '北海道寿都郡黒松内町五十嵐');
ok($zip->set_number('0480125')->is_valid_number, '北海道寿都郡黒松内町目名');
ok($zip->set_number('0480126')->is_valid_number, '北海道寿都郡黒松内町北作開');
ok($zip->set_number('0480127')->is_valid_number, '北海道寿都郡黒松内町南作開');
ok($zip->set_number('0480131')->is_valid_number, '北海道寿都郡黒松内町西熱郛原野');
ok($zip->set_number('0480132')->is_valid_number, '北海道寿都郡黒松内町チョポシナイ');
ok($zip->set_number('0480133')->is_valid_number, '北海道寿都郡黒松内町大谷地');
ok($zip->set_number('0480134')->is_valid_number, '北海道寿都郡黒松内町白井川');
ok($zip->set_number('0480135')->is_valid_number, '北海道寿都郡黒松内町角十');
ok($zip->set_number('0480136')->is_valid_number, '北海道寿都郡黒松内町赤井川');
ok($zip->set_number('0480137')->is_valid_number, '北海道寿都郡黒松内町婆沢');
ok($zip->set_number('0480141')->is_valid_number, '北海道寿都郡黒松内町上豊幌');
ok($zip->set_number('0480142')->is_valid_number, '北海道寿都郡黒松内町東栄');
ok($zip->set_number('0480143')->is_valid_number, '北海道寿都郡黒松内町大成');
ok($zip->set_number('0480144')->is_valid_number, '北海道寿都郡黒松内町東川');
ok($zip->set_number('0480145')->is_valid_number, '北海道寿都郡黒松内町上大成');
ok($zip->set_number('0480351')->is_valid_number, '北海道寿都郡寿都町磯谷町');
ok($zip->set_number('0480400')->is_valid_number, '北海道寿都郡寿都町以下に掲載がない場合');
ok($zip->set_number('0480401')->is_valid_number, '北海道寿都郡寿都町新栄町');
ok($zip->set_number('0480402')->is_valid_number, '北海道寿都郡寿都町矢追町');
ok($zip->set_number('0480403')->is_valid_number, '北海道寿都郡寿都町政泊町');
ok($zip->set_number('0480404')->is_valid_number, '北海道寿都郡寿都町大磯町');
ok($zip->set_number('0480405')->is_valid_number, '北海道寿都郡寿都町開進町');
ok($zip->set_number('0480406')->is_valid_number, '北海道寿都郡寿都町渡島町');
ok($zip->set_number('0480411')->is_valid_number, '北海道寿都郡寿都町六条町');
ok($zip->set_number('0480412')->is_valid_number, '北海道寿都郡寿都町岩崎町');
ok($zip->set_number('0480413')->is_valid_number, '北海道寿都郡寿都町樽岸町');
ok($zip->set_number('0480414')->is_valid_number, '北海道寿都郡寿都町湯別町');
ok($zip->set_number('0480415')->is_valid_number, '北海道寿都郡寿都町歌棄町');
ok($zip->set_number('0480600')->is_valid_number, '北海道島牧郡島牧村以下に掲載がない場合');
ok($zip->set_number('0480601')->is_valid_number, '北海道島牧郡島牧村富浦');
ok($zip->set_number('0480602')->is_valid_number, '北海道島牧郡島牧村歌島');
ok($zip->set_number('0480603')->is_valid_number, '北海道島牧郡島牧村本目');
ok($zip->set_number('0480604')->is_valid_number, '北海道島牧郡島牧村港');
ok($zip->set_number('0480611')->is_valid_number, '北海道島牧郡島牧村栄磯');
ok($zip->set_number('0480612')->is_valid_number, '北海道島牧郡島牧村豊浜');
ok($zip->set_number('0480613')->is_valid_number, '北海道島牧郡島牧村大平');
ok($zip->set_number('0480614')->is_valid_number, '北海道島牧郡島牧村永豊町');
ok($zip->set_number('0480621')->is_valid_number, '北海道島牧郡島牧村泊');
ok($zip->set_number('0480622')->is_valid_number, '北海道島牧郡島牧村豊平');
ok($zip->set_number('0480623')->is_valid_number, '北海道島牧郡島牧村江の島');
ok($zip->set_number('0480631')->is_valid_number, '北海道島牧郡島牧村千走');
ok($zip->set_number('0480632')->is_valid_number, '北海道島牧郡島牧村元町');
ok($zip->set_number('0480633')->is_valid_number, '北海道島牧郡島牧村原歌町');
ok($zip->set_number('0480634')->is_valid_number, '北海道島牧郡島牧村栄浜');
ok($zip->set_number('0481251')->is_valid_number, '北海道磯谷郡蘭越町相生');
ok($zip->set_number('0481252')->is_valid_number, '北海道磯谷郡蘭越町讃岐');
ok($zip->set_number('0481253')->is_valid_number, '北海道磯谷郡蘭越町田下');
ok($zip->set_number('0481254')->is_valid_number, '北海道磯谷郡蘭越町上目名');
ok($zip->set_number('0481261')->is_valid_number, '北海道磯谷郡蘭越町目名町');
ok($zip->set_number('0481262')->is_valid_number, '北海道磯谷郡蘭越町貝川');
ok($zip->set_number('0481263')->is_valid_number, '北海道磯谷郡蘭越町三笠');
ok($zip->set_number('0481264')->is_valid_number, '北海道磯谷郡蘭越町清水');
ok($zip->set_number('0481265')->is_valid_number, '北海道磯谷郡蘭越町鮎川');
ok($zip->set_number('0481300')->is_valid_number, '北海道磯谷郡蘭越町以下に掲載がない場合');
ok($zip->set_number('0481301')->is_valid_number, '北海道磯谷郡蘭越町蘭越町');
ok($zip->set_number('0481302')->is_valid_number, '北海道磯谷郡蘭越町昆布町');
ok($zip->set_number('0481303')->is_valid_number, '北海道磯谷郡蘭越町立川');
ok($zip->set_number('0481304')->is_valid_number, '北海道磯谷郡蘭越町水上');
ok($zip->set_number('0481305')->is_valid_number, '北海道磯谷郡蘭越町大谷');
ok($zip->set_number('0481306')->is_valid_number, '北海道磯谷郡蘭越町淀川');
ok($zip->set_number('0481307')->is_valid_number, '北海道磯谷郡蘭越町トンカラ');
ok($zip->set_number('0481307')->is_valid_number, '北海道磯谷郡蘭越町名駒町');
ok($zip->set_number('0481311')->is_valid_number, '北海道磯谷郡蘭越町吉国');
ok($zip->set_number('0481312')->is_valid_number, '北海道磯谷郡蘭越町冷水');
ok($zip->set_number('0481312')->is_valid_number, '北海道磯谷郡蘭越町三和');
ok($zip->set_number('0481313')->is_valid_number, '北海道磯谷郡蘭越町上里');
ok($zip->set_number('0481314')->is_valid_number, '北海道磯谷郡蘭越町御成');
ok($zip->set_number('0481315')->is_valid_number, '北海道磯谷郡蘭越町共栄');
ok($zip->set_number('0481316')->is_valid_number, '北海道磯谷郡蘭越町大曲');
ok($zip->set_number('0481316')->is_valid_number, '北海道磯谷郡蘭越町初田');
ok($zip->set_number('0481321')->is_valid_number, '北海道磯谷郡蘭越町昆布温泉');
ok($zip->set_number('0481321')->is_valid_number, '北海道磯谷郡蘭越町湯里');
ok($zip->set_number('0481322')->is_valid_number, '北海道磯谷郡蘭越町日出');
ok($zip->set_number('0481323')->is_valid_number, '北海道磯谷郡蘭越町黄金');
ok($zip->set_number('0481324')->is_valid_number, '北海道磯谷郡蘭越町豊国');
ok($zip->set_number('0481325')->is_valid_number, '北海道磯谷郡蘭越町栄');
ok($zip->set_number('0481326')->is_valid_number, '北海道磯谷郡蘭越町富岡');
ok($zip->set_number('0481327')->is_valid_number, '北海道磯谷郡蘭越町新見');
ok($zip->set_number('0481341')->is_valid_number, '北海道磯谷郡蘭越町港町');
ok($zip->set_number('0481500')->is_valid_number, '北海道虻田郡ニセコ町以下に掲載がない場合');
ok($zip->set_number('0481501')->is_valid_number, '北海道虻田郡ニセコ町富士見');
ok($zip->set_number('0481502')->is_valid_number, '北海道虻田郡ニセコ町本通');
ok($zip->set_number('0481511')->is_valid_number, '北海道虻田郡ニセコ町ニセコ');
ok($zip->set_number('0481512')->is_valid_number, '北海道虻田郡ニセコ町中央通');
ok($zip->set_number('0481521')->is_valid_number, '北海道虻田郡ニセコ町東山');
ok($zip->set_number('0481522')->is_valid_number, '北海道虻田郡ニセコ町曽我');
ok($zip->set_number('0481531')->is_valid_number, '北海道虻田郡ニセコ町有島');
ok($zip->set_number('0481541')->is_valid_number, '北海道虻田郡ニセコ町羊蹄');
ok($zip->set_number('0481542')->is_valid_number, '北海道虻田郡ニセコ町近藤');
ok($zip->set_number('0481543')->is_valid_number, '北海道虻田郡ニセコ町豊里');
ok($zip->set_number('0481544')->is_valid_number, '北海道虻田郡ニセコ町元町');
ok($zip->set_number('0481551')->is_valid_number, '北海道虻田郡ニセコ町里見');
ok($zip->set_number('0481552')->is_valid_number, '北海道虻田郡ニセコ町宮田');
ok($zip->set_number('0481553')->is_valid_number, '北海道虻田郡ニセコ町黒川');
ok($zip->set_number('0481554')->is_valid_number, '北海道虻田郡ニセコ町富川');
ok($zip->set_number('0481561')->is_valid_number, '北海道虻田郡ニセコ町福井');
ok($zip->set_number('0481562')->is_valid_number, '北海道虻田郡ニセコ町桂台');
ok($zip->set_number('0481563')->is_valid_number, '北海道虻田郡ニセコ町西富');
ok($zip->set_number('0481600')->is_valid_number, '北海道虻田郡真狩村以下に掲載がない場合');
ok($zip->set_number('0481601')->is_valid_number, '北海道虻田郡真狩村美原');
ok($zip->set_number('0481602')->is_valid_number, '北海道虻田郡真狩村泉');
ok($zip->set_number('0481603')->is_valid_number, '北海道虻田郡真狩村共明');
ok($zip->set_number('0481604')->is_valid_number, '北海道虻田郡真狩村富里');
ok($zip->set_number('0481605')->is_valid_number, '北海道虻田郡真狩村社');
ok($zip->set_number('0481611')->is_valid_number, '北海道虻田郡真狩村光');
ok($zip->set_number('0481612')->is_valid_number, '北海道虻田郡真狩村見晴');
ok($zip->set_number('0481613')->is_valid_number, '北海道虻田郡真狩村南部');
ok($zip->set_number('0481614')->is_valid_number, '北海道虻田郡真狩村桜川');
ok($zip->set_number('0481615')->is_valid_number, '北海道虻田郡真狩村緑岡');
ok($zip->set_number('0481621')->is_valid_number, '北海道虻田郡真狩村豊川');
ok($zip->set_number('0481622')->is_valid_number, '北海道虻田郡真狩村加野');
ok($zip->set_number('0481623')->is_valid_number, '北海道虻田郡真狩村川崎');
ok($zip->set_number('0481624')->is_valid_number, '北海道虻田郡真狩村神里');
ok($zip->set_number('0481631')->is_valid_number, '北海道虻田郡真狩村真狩');
ok($zip->set_number('0481700')->is_valid_number, '北海道虻田郡留寿都村以下に掲載がない場合');
ok($zip->set_number('0481711')->is_valid_number, '北海道虻田郡留寿都村泉川');
ok($zip->set_number('0481712')->is_valid_number, '北海道虻田郡留寿都村豊岡');
ok($zip->set_number('0481721')->is_valid_number, '北海道虻田郡留寿都村向丘');
ok($zip->set_number('0481722')->is_valid_number, '北海道虻田郡留寿都村黒田');
ok($zip->set_number('0481723')->is_valid_number, '北海道虻田郡留寿都村三ノ原');
ok($zip->set_number('0481724')->is_valid_number, '北海道虻田郡留寿都村三豊');
ok($zip->set_number('0481731')->is_valid_number, '北海道虻田郡留寿都村留寿都');
ok($zip->set_number('0481741')->is_valid_number, '北海道虻田郡留寿都村西ノ原');
ok($zip->set_number('0481751')->is_valid_number, '北海道虻田郡留寿都村登');
ok($zip->set_number('0481752')->is_valid_number, '北海道虻田郡留寿都村旭野');
ok($zip->set_number('0482141')->is_valid_number, '北海道岩内郡共和町ワイス');
ok($zip->set_number('0482142')->is_valid_number, '北海道岩内郡共和町小沢');
ok($zip->set_number('0482143')->is_valid_number, '北海道岩内郡共和町国富');
ok($zip->set_number('0482200')->is_valid_number, '北海道岩内郡共和町以下に掲載がない場合');
ok($zip->set_number('0482201')->is_valid_number, '北海道岩内郡共和町前田');
ok($zip->set_number('0482202')->is_valid_number, '北海道岩内郡共和町南幌似');
ok($zip->set_number('0482331')->is_valid_number, '北海道余市郡仁木町大江(2丁目651、662、668番地、3丁目103、118、');
ok($zip->set_number('0482331')->is_valid_number, '北海道余市郡仁木町210、254、267、372、444、469番地)');
ok($zip->set_number('0482332')->is_valid_number, '北海道余市郡仁木町長沢西');
ok($zip->set_number('0482333')->is_valid_number, '北海道余市郡仁木町長沢南');
ok($zip->set_number('0482334')->is_valid_number, '北海道余市郡仁木町尾根内');
ok($zip->set_number('0482335')->is_valid_number, '北海道余市郡仁木町銀山');
ok($zip->set_number('0482400')->is_valid_number, '北海道余市郡仁木町以下に掲載がない場合');
ok($zip->set_number('0482401')->is_valid_number, '北海道余市郡仁木町旭台');
ok($zip->set_number('0482402')->is_valid_number, '北海道余市郡仁木町大江(1丁目、2丁目「651、662、668番地」以外、3丁目5、1');
ok($zip->set_number('0482402')->is_valid_number, '北海道余市郡仁木町3-4、20、678、687番地)');
ok($zip->set_number('0482403')->is_valid_number, '北海道余市郡仁木町然別');
ok($zip->set_number('0482404')->is_valid_number, '北海道余市郡仁木町砥の川');
ok($zip->set_number('0482405')->is_valid_number, '北海道余市郡仁木町北町');
ok($zip->set_number('0482406')->is_valid_number, '北海道余市郡仁木町西町');
ok($zip->set_number('0482411')->is_valid_number, '北海道余市郡仁木町東町');
ok($zip->set_number('0482412')->is_valid_number, '北海道余市郡仁木町東町緑ケ丘');
ok($zip->set_number('0482413')->is_valid_number, '北海道余市郡仁木町南町');
ok($zip->set_number('0482561')->is_valid_number, '北海道小樽市忍路');
ok($zip->set_number('0482562')->is_valid_number, '北海道小樽市蘭島');
ok($zip->set_number('0482671')->is_valid_number, '北海道小樽市オタモイ');
ok($zip->set_number('0482672')->is_valid_number, '北海道小樽市塩谷');
ok($zip->set_number('0482673')->is_valid_number, '北海道小樽市桃内');
ok($zip->set_number('0490100')->is_valid_number, '北海道北斗市以下に掲載がない場合');
ok($zip->set_number('0490101')->is_valid_number, '北海道北斗市追分');
ok($zip->set_number('0490111')->is_valid_number, '北海道北斗市七重浜');
ok($zip->set_number('0490121')->is_valid_number, '北海道北斗市久根別');
ok($zip->set_number('0490122')->is_valid_number, '北海道北斗市東浜');
ok($zip->set_number('0490131')->is_valid_number, '北海道北斗市富川');
ok($zip->set_number('0490132')->is_valid_number, '北海道北斗市館野');
ok($zip->set_number('0490133')->is_valid_number, '北海道北斗市柳沢');
ok($zip->set_number('0490134')->is_valid_number, '北海道北斗市三好');
ok($zip->set_number('0490135')->is_valid_number, '北海道北斗市水無');
ok($zip->set_number('0490136')->is_valid_number, '北海道北斗市峨朗');
ok($zip->set_number('0490141')->is_valid_number, '北海道北斗市谷好');
ok($zip->set_number('0490142')->is_valid_number, '北海道北斗市昭和');
ok($zip->set_number('0490143')->is_valid_number, '北海道北斗市公園通');
ok($zip->set_number('0490151')->is_valid_number, '北海道北斗市桜岱');
ok($zip->set_number('0490152')->is_valid_number, '北海道北斗市押上');
ok($zip->set_number('0490153')->is_valid_number, '北海道北斗市大工川');
ok($zip->set_number('0490154')->is_valid_number, '北海道北斗市添山');
ok($zip->set_number('0490155')->is_valid_number, '北海道北斗市中野');
ok($zip->set_number('0490156')->is_valid_number, '北海道北斗市中野通');
ok($zip->set_number('0490157')->is_valid_number, '北海道北斗市清川');
ok($zip->set_number('0490158')->is_valid_number, '北海道北斗市野崎');
ok($zip->set_number('0490161')->is_valid_number, '北海道北斗市飯生');
ok($zip->set_number('0490162')->is_valid_number, '北海道北斗市中央');
ok($zip->set_number('0490171')->is_valid_number, '北海道北斗市常盤');
ok($zip->set_number('0490281')->is_valid_number, '北海道北斗市茂辺地');
ok($zip->set_number('0490282')->is_valid_number, '北海道北斗市当別');
ok($zip->set_number('0490283')->is_valid_number, '北海道北斗市三ツ石');
ok($zip->set_number('0490284')->is_valid_number, '北海道北斗市湯ノ沢');
ok($zip->set_number('0490285')->is_valid_number, '北海道北斗市茂辺地市ノ渡');
ok($zip->set_number('0490286')->is_valid_number, '北海道北斗市矢不来');
ok($zip->set_number('0490400')->is_valid_number, '北海道上磯郡木古内町以下に掲載がない場合');
ok($zip->set_number('0490401')->is_valid_number, '北海道上磯郡木古内町大釜谷');
ok($zip->set_number('0490402')->is_valid_number, '北海道上磯郡木古内町御宮野');
ok($zip->set_number('0490403')->is_valid_number, '北海道上磯郡木古内町釜谷');
ok($zip->set_number('0490404')->is_valid_number, '北海道上磯郡木古内町亀川');
ok($zip->set_number('0490405')->is_valid_number, '北海道上磯郡木古内町泉沢');
ok($zip->set_number('0490406')->is_valid_number, '北海道上磯郡木古内町二乃岱');
ok($zip->set_number('0490407')->is_valid_number, '北海道上磯郡木古内町橋呉');
ok($zip->set_number('0490408')->is_valid_number, '北海道上磯郡木古内町幸連');
ok($zip->set_number('0490411')->is_valid_number, '北海道上磯郡木古内町札苅');
ok($zip->set_number('0490412')->is_valid_number, '北海道上磯郡木古内町大平');
ok($zip->set_number('0490421')->is_valid_number, '北海道上磯郡木古内町前浜');
ok($zip->set_number('0490422')->is_valid_number, '北海道上磯郡木古内町本町');
ok($zip->set_number('0490431')->is_valid_number, '北海道上磯郡木古内町木古内');
ok($zip->set_number('0490441')->is_valid_number, '北海道上磯郡木古内町中野');
ok($zip->set_number('0490451')->is_valid_number, '北海道上磯郡木古内町新道');
ok($zip->set_number('0490452')->is_valid_number, '北海道上磯郡木古内町建川');
ok($zip->set_number('0490453')->is_valid_number, '北海道上磯郡木古内町大川');
ok($zip->set_number('0490454')->is_valid_number, '北海道上磯郡木古内町瓜谷');
ok($zip->set_number('0490455')->is_valid_number, '北海道上磯郡木古内町鶴岡');
ok($zip->set_number('0490561')->is_valid_number, '北海道檜山郡上ノ国町神明');
ok($zip->set_number('0490562')->is_valid_number, '北海道檜山郡上ノ国町湯ノ岱');
ok($zip->set_number('0490563')->is_valid_number, '北海道檜山郡上ノ国町宮越');
ok($zip->set_number('0490564')->is_valid_number, '北海道檜山郡上ノ国町早瀬');
ok($zip->set_number('0490600')->is_valid_number, '北海道檜山郡上ノ国町以下に掲載がない場合');
ok($zip->set_number('0490601')->is_valid_number, '北海道檜山郡上ノ国町勝山');
ok($zip->set_number('0490602')->is_valid_number, '北海道檜山郡上ノ国町原歌');
ok($zip->set_number('0490603')->is_valid_number, '北海道檜山郡上ノ国町大崎');
ok($zip->set_number('0490604')->is_valid_number, '北海道檜山郡上ノ国町大安在');
ok($zip->set_number('0490605')->is_valid_number, '北海道檜山郡上ノ国町小安在');
ok($zip->set_number('0490606')->is_valid_number, '北海道檜山郡上ノ国町木ノ子');
ok($zip->set_number('0490607')->is_valid_number, '北海道檜山郡上ノ国町扇石');
ok($zip->set_number('0490608')->is_valid_number, '北海道檜山郡上ノ国町汐吹');
ok($zip->set_number('0490611')->is_valid_number, '北海道檜山郡上ノ国町大留');
ok($zip->set_number('0490612')->is_valid_number, '北海道檜山郡上ノ国町上ノ国');
ok($zip->set_number('0490613')->is_valid_number, '北海道檜山郡上ノ国町向浜');
ok($zip->set_number('0490621')->is_valid_number, '北海道檜山郡上ノ国町内郷');
ok($zip->set_number('0490622')->is_valid_number, '北海道檜山郡上ノ国町北村');
ok($zip->set_number('0490623')->is_valid_number, '北海道檜山郡上ノ国町新村');
ok($zip->set_number('0490624')->is_valid_number, '北海道檜山郡上ノ国町中須田');
ok($zip->set_number('0490625')->is_valid_number, '北海道檜山郡上ノ国町豊田');
ok($zip->set_number('0490626')->is_valid_number, '北海道檜山郡上ノ国町桂岡');
ok($zip->set_number('0490627')->is_valid_number, '北海道檜山郡上ノ国町小森');
ok($zip->set_number('0490741')->is_valid_number, '北海道檜山郡上ノ国町石崎');
ok($zip->set_number('0490742')->is_valid_number, '北海道檜山郡上ノ国町館野');
ok($zip->set_number('0490743')->is_valid_number, '北海道檜山郡上ノ国町小砂子');
ok($zip->set_number('0490744')->is_valid_number, '北海道檜山郡上ノ国町早川');
ok($zip->set_number('0491100')->is_valid_number, '北海道上磯郡知内町以下に掲載がない場合');
ok($zip->set_number('0491101')->is_valid_number, '北海道上磯郡知内町中ノ川');
ok($zip->set_number('0491102')->is_valid_number, '北海道上磯郡知内町森越');
ok($zip->set_number('0491103')->is_valid_number, '北海道上磯郡知内町重内');
ok($zip->set_number('0491104')->is_valid_number, '北海道上磯郡知内町涌元');
ok($zip->set_number('0491105')->is_valid_number, '北海道上磯郡知内町小谷石');
ok($zip->set_number('0491106')->is_valid_number, '北海道上磯郡知内町元町');
ok($zip->set_number('0491107')->is_valid_number, '北海道上磯郡知内町上雷');
ok($zip->set_number('0491221')->is_valid_number, '北海道上磯郡知内町湯ノ里');
ok($zip->set_number('0491300')->is_valid_number, '北海道松前郡福島町以下に掲載がない場合');
ok($zip->set_number('0491301')->is_valid_number, '北海道松前郡福島町白符');
ok($zip->set_number('0491302')->is_valid_number, '北海道松前郡福島町日向');
ok($zip->set_number('0491311')->is_valid_number, '北海道松前郡福島町桧倉');
ok($zip->set_number('0491312')->is_valid_number, '北海道松前郡福島町上町');
ok($zip->set_number('0491312')->is_valid_number, '北海道松前郡福島町川原町');
ok($zip->set_number('0491312')->is_valid_number, '北海道松前郡福島町館古');
ok($zip->set_number('0491312')->is_valid_number, '北海道松前郡福島町福島');
ok($zip->set_number('0491312')->is_valid_number, '北海道松前郡福島町本町');
ok($zip->set_number('0491312')->is_valid_number, '北海道松前郡福島町吉田町');
ok($zip->set_number('0491321')->is_valid_number, '北海道松前郡福島町月崎');
ok($zip->set_number('0491321')->is_valid_number, '北海道松前郡福島町丸山団地');
ok($zip->set_number('0491321')->is_valid_number, '北海道松前郡福島町緑町');
ok($zip->set_number('0491322')->is_valid_number, '北海道松前郡福島町塩釜');
ok($zip->set_number('0491323')->is_valid_number, '北海道松前郡福島町浦和');
ok($zip->set_number('0491324')->is_valid_number, '北海道松前郡福島町日の出');
ok($zip->set_number('0491325')->is_valid_number, '北海道松前郡福島町岩部');
ok($zip->set_number('0491331')->is_valid_number, '北海道松前郡福島町新栄町');
ok($zip->set_number('0491331')->is_valid_number, '北海道松前郡福島町三岳');
ok($zip->set_number('0491332')->is_valid_number, '北海道松前郡福島町千軒');
ok($zip->set_number('0491451')->is_valid_number, '北海道松前郡福島町宮歌');
ok($zip->set_number('0491452')->is_valid_number, '北海道松前郡福島町豊浜');
ok($zip->set_number('0491453')->is_valid_number, '北海道松前郡福島町美山');
ok($zip->set_number('0491453')->is_valid_number, '北海道松前郡福島町吉岡');
ok($zip->set_number('0491454')->is_valid_number, '北海道松前郡福島町館崎');
ok($zip->set_number('0491455')->is_valid_number, '北海道松前郡福島町吉野');
ok($zip->set_number('0491456')->is_valid_number, '北海道松前郡福島町松浦');
ok($zip->set_number('0491500')->is_valid_number, '北海道松前郡松前町以下に掲載がない場合');
ok($zip->set_number('0491501')->is_valid_number, '北海道松前郡松前町建石');
ok($zip->set_number('0491502')->is_valid_number, '北海道松前郡松前町弁天');
ok($zip->set_number('0491503')->is_valid_number, '北海道松前郡松前町大磯');
ok($zip->set_number('0491504')->is_valid_number, '北海道松前郡松前町愛宕');
ok($zip->set_number('0491505')->is_valid_number, '北海道松前郡松前町博多');
ok($zip->set_number('0491506')->is_valid_number, '北海道松前郡松前町唐津');
ok($zip->set_number('0491507')->is_valid_number, '北海道松前郡松前町西館');
ok($zip->set_number('0491511')->is_valid_number, '北海道松前郡松前町松城');
ok($zip->set_number('0491512')->is_valid_number, '北海道松前郡松前町福山');
ok($zip->set_number('0491513')->is_valid_number, '北海道松前郡松前町神明');
ok($zip->set_number('0491514')->is_valid_number, '北海道松前郡松前町豊岡');
ok($zip->set_number('0491515')->is_valid_number, '北海道松前郡松前町月島');
ok($zip->set_number('0491516')->is_valid_number, '北海道松前郡松前町東山');
ok($zip->set_number('0491517')->is_valid_number, '北海道松前郡松前町朝日');
ok($zip->set_number('0491521')->is_valid_number, '北海道松前郡松前町上川');
ok($zip->set_number('0491522')->is_valid_number, '北海道松前郡松前町大沢');
ok($zip->set_number('0491523')->is_valid_number, '北海道松前郡松前町荒谷');
ok($zip->set_number('0491524')->is_valid_number, '北海道松前郡松前町白神');
ok($zip->set_number('0491641')->is_valid_number, '北海道松前郡松前町館浜');
ok($zip->set_number('0491642')->is_valid_number, '北海道松前郡松前町札前');
ok($zip->set_number('0491643')->is_valid_number, '北海道松前郡松前町赤神');
ok($zip->set_number('0491644')->is_valid_number, '北海道松前郡松前町静浦');
ok($zip->set_number('0491645')->is_valid_number, '北海道松前郡松前町茂草');
ok($zip->set_number('0491761')->is_valid_number, '北海道松前郡松前町神山');
ok($zip->set_number('0491762')->is_valid_number, '北海道松前郡松前町原口');
ok($zip->set_number('0491763')->is_valid_number, '北海道松前郡松前町白坂');
ok($zip->set_number('0491764')->is_valid_number, '北海道松前郡松前町二越');
ok($zip->set_number('0491771')->is_valid_number, '北海道松前郡松前町江良');
ok($zip->set_number('0491781')->is_valid_number, '北海道松前郡松前町大津');
ok($zip->set_number('0491782')->is_valid_number, '北海道松前郡松前町高野');
ok($zip->set_number('0491783')->is_valid_number, '北海道松前郡松前町清部');
ok($zip->set_number('0491784')->is_valid_number, '北海道松前郡松前町小浜');
ok($zip->set_number('0492141')->is_valid_number, '北海道茅部郡森町駒ケ岳');
ok($zip->set_number('0492142')->is_valid_number, '北海道茅部郡森町赤井川');
ok($zip->set_number('0492221')->is_valid_number, '北海道茅部郡森町砂原西');
ok($zip->set_number('0492222')->is_valid_number, '北海道茅部郡森町砂原');
ok($zip->set_number('0492223')->is_valid_number, '北海道茅部郡森町砂原東');
ok($zip->set_number('0492300')->is_valid_number, '北海道茅部郡森町以下に掲載がない場合');
ok($zip->set_number('0492301')->is_valid_number, '北海道茅部郡森町尾白内町');
ok($zip->set_number('0492302')->is_valid_number, '北海道茅部郡森町港町');
ok($zip->set_number('0492303')->is_valid_number, '北海道茅部郡森町東森町');
ok($zip->set_number('0492304')->is_valid_number, '北海道茅部郡森町新川町');
ok($zip->set_number('0492305')->is_valid_number, '北海道茅部郡森町常盤町');
ok($zip->set_number('0492306')->is_valid_number, '北海道茅部郡森町姫川');
ok($zip->set_number('0492307')->is_valid_number, '北海道茅部郡森町白川');
ok($zip->set_number('0492308')->is_valid_number, '北海道茅部郡森町栄町');
ok($zip->set_number('0492311')->is_valid_number, '北海道茅部郡森町上台町');
ok($zip->set_number('0492312')->is_valid_number, '北海道茅部郡森町霞台');
ok($zip->set_number('0492313')->is_valid_number, '北海道茅部郡森町森川町');
ok($zip->set_number('0492321')->is_valid_number, '北海道茅部郡森町鷲ノ木町');
ok($zip->set_number('0492322')->is_valid_number, '北海道茅部郡森町富士見町');
ok($zip->set_number('0492323')->is_valid_number, '北海道茅部郡森町鳥崎町');
ok($zip->set_number('0492324')->is_valid_number, '北海道茅部郡森町栗ケ丘');
ok($zip->set_number('0492325')->is_valid_number, '北海道茅部郡森町本町');
ok($zip->set_number('0492326')->is_valid_number, '北海道茅部郡森町御幸町');
ok($zip->set_number('0492327')->is_valid_number, '北海道茅部郡森町清澄町');
ok($zip->set_number('0492461')->is_valid_number, '北海道茅部郡森町三岱');
ok($zip->set_number('0492462')->is_valid_number, '北海道茅部郡森町濁川');
ok($zip->set_number('0492463')->is_valid_number, '北海道茅部郡森町石倉町');
ok($zip->set_number('0492464')->is_valid_number, '北海道茅部郡森町本茅部町');
ok($zip->set_number('0492465')->is_valid_number, '北海道茅部郡森町蛯谷町');
ok($zip->set_number('0492561')->is_valid_number, '北海道二海郡八雲町旭丘');
ok($zip->set_number('0492562')->is_valid_number, '北海道二海郡八雲町落部');
ok($zip->set_number('0492563')->is_valid_number, '北海道二海郡八雲町栄浜');
ok($zip->set_number('0492564')->is_valid_number, '北海道二海郡八雲町入沢');
ok($zip->set_number('0492565')->is_valid_number, '北海道二海郡八雲町下の湯');
ok($zip->set_number('0492566')->is_valid_number, '北海道二海郡八雲町上の湯');
ok($zip->set_number('0492671')->is_valid_number, '北海道二海郡八雲町山越');
ok($zip->set_number('0492672')->is_valid_number, '北海道二海郡八雲町野田生');
ok($zip->set_number('0492673')->is_valid_number, '北海道二海郡八雲町東野');
ok($zip->set_number('0492674')->is_valid_number, '北海道二海郡八雲町わらび野');
ok($zip->set_number('0492675')->is_valid_number, '北海道二海郡八雲町桜野');
ok($zip->set_number('0493100')->is_valid_number, '北海道二海郡八雲町以下に掲載がない場合');
ok($zip->set_number('0493101')->is_valid_number, '北海道二海郡八雲町元町');
ok($zip->set_number('0493102')->is_valid_number, '北海道二海郡八雲町東町');
ok($zip->set_number('0493103')->is_valid_number, '北海道二海郡八雲町豊河町');
ok($zip->set_number('0493104')->is_valid_number, '北海道二海郡八雲町内浦町');
ok($zip->set_number('0493105')->is_valid_number, '北海道二海郡八雲町東雲町');
ok($zip->set_number('0493106')->is_valid_number, '北海道二海郡八雲町富士見町');
ok($zip->set_number('0493107')->is_valid_number, '北海道二海郡八雲町本町');
ok($zip->set_number('0493111')->is_valid_number, '北海道二海郡八雲町住初町');
ok($zip->set_number('0493112')->is_valid_number, '北海道二海郡八雲町末広町');
ok($zip->set_number('0493113')->is_valid_number, '北海道二海郡八雲町相生町');
ok($zip->set_number('0493114')->is_valid_number, '北海道二海郡八雲町三杉町');
ok($zip->set_number('0493115')->is_valid_number, '北海道二海郡八雲町出雲町');
ok($zip->set_number('0493116')->is_valid_number, '北海道二海郡八雲町宮園町');
ok($zip->set_number('0493117')->is_valid_number, '北海道二海郡八雲町栄町');
ok($zip->set_number('0493118')->is_valid_number, '北海道二海郡八雲町緑町');
ok($zip->set_number('0493121')->is_valid_number, '北海道二海郡八雲町上八雲');
ok($zip->set_number('0493121')->is_valid_number, '北海道二海郡八雲町富咲');
ok($zip->set_number('0493122')->is_valid_number, '北海道二海郡八雲町花浦');
ok($zip->set_number('0493123')->is_valid_number, '北海道二海郡八雲町立岩');
ok($zip->set_number('0493124')->is_valid_number, '北海道二海郡八雲町浜松');
ok($zip->set_number('0493125')->is_valid_number, '北海道二海郡八雲町熱田');
ok($zip->set_number('0493126')->is_valid_number, '北海道二海郡八雲町大新');
ok($zip->set_number('0493127')->is_valid_number, '北海道二海郡八雲町春日');
ok($zip->set_number('0493128')->is_valid_number, '北海道二海郡八雲町鉛川');
ok($zip->set_number('0493341')->is_valid_number, '北海道二海郡八雲町黒岩');
ok($zip->set_number('0493342')->is_valid_number, '北海道二海郡八雲町山崎');
ok($zip->set_number('0493461')->is_valid_number, '北海道山越郡長万部町花岡');
ok($zip->set_number('0493462')->is_valid_number, '北海道山越郡長万部町国縫');
ok($zip->set_number('0493463')->is_valid_number, '北海道山越郡長万部町豊野');
ok($zip->set_number('0493464')->is_valid_number, '北海道山越郡長万部町豊津');
ok($zip->set_number('0493465')->is_valid_number, '北海道山越郡長万部町茶屋川');
ok($zip->set_number('0493500')->is_valid_number, '北海道山越郡長万部町以下に掲載がない場合');
ok($zip->set_number('0493501')->is_valid_number, '北海道山越郡長万部町大峰');
ok($zip->set_number('0493501')->is_valid_number, '北海道山越郡長万部町双葉');
ok($zip->set_number('0493502')->is_valid_number, '北海道山越郡長万部町知来');
ok($zip->set_number('0493503')->is_valid_number, '北海道山越郡長万部町蕨岱');
ok($zip->set_number('0493504')->is_valid_number, '北海道山越郡長万部町美畑');
ok($zip->set_number('0493511')->is_valid_number, '北海道山越郡長万部町大浜');
ok($zip->set_number('0493512')->is_valid_number, '北海道山越郡長万部町中の沢');
ok($zip->set_number('0493513')->is_valid_number, '北海道山越郡長万部町平里');
ok($zip->set_number('0493514')->is_valid_number, '北海道山越郡長万部町富野');
ok($zip->set_number('0493515')->is_valid_number, '北海道山越郡長万部町栗岡');
ok($zip->set_number('0493516')->is_valid_number, '北海道山越郡長万部町栄原');
ok($zip->set_number('0493517')->is_valid_number, '北海道山越郡長万部町共立');
ok($zip->set_number('0493518')->is_valid_number, '北海道山越郡長万部町静狩(3-1番地)');
ok($zip->set_number('0493519')->is_valid_number, '北海道山越郡長万部町旭浜');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町曙町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町大町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町長万部');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町温泉町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町新開町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町陣屋町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町住吉町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町高砂町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町本町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町南栄町');
ok($zip->set_number('0493521')->is_valid_number, '北海道山越郡長万部町元町');
ok($zip->set_number('0494151')->is_valid_number, '北海道瀬棚郡今金町美利河');
ok($zip->set_number('0494152')->is_valid_number, '北海道瀬棚郡今金町宮島');
ok($zip->set_number('0494153')->is_valid_number, '北海道瀬棚郡今金町花石');
ok($zip->set_number('0494154')->is_valid_number, '北海道瀬棚郡今金町中里');
ok($zip->set_number('0494155')->is_valid_number, '北海道瀬棚郡今金町奥沢');
ok($zip->set_number('0494156')->is_valid_number, '北海道瀬棚郡今金町住吉');
ok($zip->set_number('0494157')->is_valid_number, '北海道瀬棚郡今金町上種川');
ok($zip->set_number('0494300')->is_valid_number, '北海道瀬棚郡今金町以下に掲載がない場合');
ok($zip->set_number('0494301')->is_valid_number, '北海道瀬棚郡今金町東町');
ok($zip->set_number('0494302')->is_valid_number, '北海道瀬棚郡今金町日の出町');
ok($zip->set_number('0494303')->is_valid_number, '北海道瀬棚郡今金町曙町');
ok($zip->set_number('0494304')->is_valid_number, '北海道瀬棚郡今金町寒昇');
ok($zip->set_number('0494305')->is_valid_number, '北海道瀬棚郡今金町南栄町');
ok($zip->set_number('0494306')->is_valid_number, '北海道瀬棚郡今金町高美町');
ok($zip->set_number('0494307')->is_valid_number, '北海道瀬棚郡今金町八幡町');
ok($zip->set_number('0494308')->is_valid_number, '北海道瀬棚郡今金町今金');
ok($zip->set_number('0494311')->is_valid_number, '北海道瀬棚郡今金町栄町');
ok($zip->set_number('0494312')->is_valid_number, '北海道瀬棚郡今金町旭町');
ok($zip->set_number('0494313')->is_valid_number, '北海道瀬棚郡今金町本町');
ok($zip->set_number('0494314')->is_valid_number, '北海道瀬棚郡今金町昭和町');
ok($zip->set_number('0494315')->is_valid_number, '北海道瀬棚郡今金町末広町');
ok($zip->set_number('0494316')->is_valid_number, '北海道瀬棚郡今金町南町');
ok($zip->set_number('0494317')->is_valid_number, '北海道瀬棚郡今金町緑町');
ok($zip->set_number('0494318')->is_valid_number, '北海道瀬棚郡今金町大和町');
ok($zip->set_number('0494321')->is_valid_number, '北海道瀬棚郡今金町鈴岡');
ok($zip->set_number('0494322')->is_valid_number, '北海道瀬棚郡今金町御影');
ok($zip->set_number('0494323')->is_valid_number, '北海道瀬棚郡今金町光台');
ok($zip->set_number('0494324')->is_valid_number, '北海道瀬棚郡今金町種川');
ok($zip->set_number('0494325')->is_valid_number, '北海道瀬棚郡今金町稲穂');
ok($zip->set_number('0494326')->is_valid_number, '北海道瀬棚郡今金町商工団地');
ok($zip->set_number('0494327')->is_valid_number, '北海道瀬棚郡今金町神丘');
ok($zip->set_number('0494331')->is_valid_number, '北海道瀬棚郡今金町田代');
ok($zip->set_number('0494332')->is_valid_number, '北海道瀬棚郡今金町白石');
ok($zip->set_number('0494333')->is_valid_number, '北海道瀬棚郡今金町日進');
ok($zip->set_number('0494334')->is_valid_number, '北海道瀬棚郡今金町八束');
ok($zip->set_number('0494335')->is_valid_number, '北海道瀬棚郡今金町金原');
ok($zip->set_number('0494336')->is_valid_number, '北海道瀬棚郡今金町鈴金');
ok($zip->set_number('0494337')->is_valid_number, '北海道瀬棚郡今金町豊田');
ok($zip->set_number('0494431')->is_valid_number, '北海道久遠郡せたな町北檜山区小倉山');
ok($zip->set_number('0494432')->is_valid_number, '北海道久遠郡せたな町北檜山区東丹羽');
ok($zip->set_number('0494433')->is_valid_number, '北海道久遠郡せたな町北檜山区丹羽');
ok($zip->set_number('0494434')->is_valid_number, '北海道久遠郡せたな町北檜山区西丹羽');
ok($zip->set_number('0494500')->is_valid_number, '北海道久遠郡せたな町以下に掲載がない場合');
ok($zip->set_number('0494501')->is_valid_number, '北海道久遠郡せたな町北檜山区北檜山');
ok($zip->set_number('0494511')->is_valid_number, '北海道久遠郡せたな町北檜山区松岡');
ok($zip->set_number('0494512')->is_valid_number, '北海道久遠郡せたな町北檜山区徳島');
ok($zip->set_number('0494513')->is_valid_number, '北海道久遠郡せたな町北檜山区愛知');
ok($zip->set_number('0494514')->is_valid_number, '北海道久遠郡せたな町北檜山区豊岡');
ok($zip->set_number('0494515')->is_valid_number, '北海道久遠郡せたな町北檜山区兜野');
ok($zip->set_number('0494516')->is_valid_number, '北海道久遠郡せたな町北檜山区共和');
ok($zip->set_number('0494517')->is_valid_number, '北海道久遠郡せたな町北檜山区太櫓');
ok($zip->set_number('0494518')->is_valid_number, '北海道久遠郡せたな町北檜山区新成');
ok($zip->set_number('0494751')->is_valid_number, '北海道久遠郡せたな町北檜山区栄');
ok($zip->set_number('0494752')->is_valid_number, '北海道久遠郡せたな町北檜山区若松');
ok($zip->set_number('0494753')->is_valid_number, '北海道久遠郡せたな町北檜山区小川');
ok($zip->set_number('0494754')->is_valid_number, '北海道久遠郡せたな町北檜山区二俣');
ok($zip->set_number('0494755')->is_valid_number, '北海道久遠郡せたな町北檜山区富里');
ok($zip->set_number('0494801')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(1区)');
ok($zip->set_number('0494802')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(2区)');
ok($zip->set_number('0494803')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(3区)');
ok($zip->set_number('0494804')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(4区)');
ok($zip->set_number('0494805')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(5区)');
ok($zip->set_number('0494811')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(6区)');
ok($zip->set_number('0494812')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(7区)');
ok($zip->set_number('0494813')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(8区)');
ok($zip->set_number('0494814')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(9区)');
ok($zip->set_number('0494815')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町(10区)');
ok($zip->set_number('0494816')->is_valid_number, '北海道久遠郡せたな町瀬棚区本町');
ok($zip->set_number('0494821')->is_valid_number, '北海道久遠郡せたな町瀬棚区三本杉');
ok($zip->set_number('0494822')->is_valid_number, '北海道久遠郡せたな町瀬棚区元浦');
ok($zip->set_number('0494823')->is_valid_number, '北海道久遠郡せたな町瀬棚区島歌');
ok($zip->set_number('0494824')->is_valid_number, '北海道久遠郡せたな町瀬棚区北島歌');
ok($zip->set_number('0494825')->is_valid_number, '北海道久遠郡せたな町瀬棚区西大里');
ok($zip->set_number('0494826')->is_valid_number, '北海道久遠郡せたな町瀬棚区東大里');
ok($zip->set_number('0494827')->is_valid_number, '北海道久遠郡せたな町瀬棚区共和');
ok($zip->set_number('0494828')->is_valid_number, '北海道久遠郡せたな町瀬棚区南川');
ok($zip->set_number('0495141')->is_valid_number, '北海道山越郡長万部町静狩(その他)');
ok($zip->set_number('0495331')->is_valid_number, '北海道虻田郡豊浦町豊泉');
ok($zip->set_number('0495332')->is_valid_number, '北海道虻田郡豊浦町大岸');
ok($zip->set_number('0495333')->is_valid_number, '北海道虻田郡豊浦町礼文華');
ok($zip->set_number('0495400')->is_valid_number, '北海道虻田郡豊浦町以下に掲載がない場合');
ok($zip->set_number('0495401')->is_valid_number, '北海道虻田郡豊浦町山梨');
ok($zip->set_number('0495402')->is_valid_number, '北海道虻田郡豊浦町大和');
ok($zip->set_number('0495403')->is_valid_number, '北海道虻田郡豊浦町美和');
ok($zip->set_number('0495404')->is_valid_number, '北海道虻田郡豊浦町桜');
ok($zip->set_number('0495405')->is_valid_number, '北海道虻田郡豊浦町高岡');
ok($zip->set_number('0495406')->is_valid_number, '北海道虻田郡豊浦町新山梨');
ok($zip->set_number('0495407')->is_valid_number, '北海道虻田郡豊浦町上泉');
ok($zip->set_number('0495408')->is_valid_number, '北海道虻田郡豊浦町新富');
ok($zip->set_number('0495411')->is_valid_number, '北海道虻田郡豊浦町東雲町');
ok($zip->set_number('0495412')->is_valid_number, '北海道虻田郡豊浦町旭町');
ok($zip->set_number('0495413')->is_valid_number, '北海道虻田郡豊浦町海岸町');
ok($zip->set_number('0495414')->is_valid_number, '北海道虻田郡豊浦町幸町');
ok($zip->set_number('0495415')->is_valid_number, '北海道虻田郡豊浦町浜町');
ok($zip->set_number('0495416')->is_valid_number, '北海道虻田郡豊浦町船見町');
ok($zip->set_number('0495600')->is_valid_number, '北海道虻田郡洞爺湖町以下に掲載がない場合');
ok($zip->set_number('0495601')->is_valid_number, '北海道虻田郡洞爺湖町青葉町');
ok($zip->set_number('0495602')->is_valid_number, '北海道虻田郡洞爺湖町泉');
ok($zip->set_number('0495603')->is_valid_number, '北海道虻田郡洞爺湖町入江');
ok($zip->set_number('0495604')->is_valid_number, '北海道虻田郡洞爺湖町栄町');
ok($zip->set_number('0495605')->is_valid_number, '北海道虻田郡洞爺湖町高砂町');
ok($zip->set_number('0495611')->is_valid_number, '北海道虻田郡洞爺湖町旭町');
ok($zip->set_number('0495612')->is_valid_number, '北海道虻田郡洞爺湖町大磯町');
ok($zip->set_number('0495613')->is_valid_number, '北海道虻田郡洞爺湖町清水(その他)');
ok($zip->set_number('0495614')->is_valid_number, '北海道虻田郡洞爺湖町浜町');
ok($zip->set_number('0495615')->is_valid_number, '北海道虻田郡洞爺湖町本町');
ok($zip->set_number('0495616')->is_valid_number, '北海道虻田郡洞爺湖町三豊');
ok($zip->set_number('0495721')->is_valid_number, '北海道虻田郡洞爺湖町洞爺湖温泉');
ok($zip->set_number('0495722')->is_valid_number, '北海道虻田郡洞爺湖町清水(336番地)');
ok($zip->set_number('0495723')->is_valid_number, '北海道虻田郡洞爺湖町月浦');
ok($zip->set_number('0495724')->is_valid_number, '北海道虻田郡洞爺湖町花和');
ok($zip->set_number('0495731')->is_valid_number, '北海道有珠郡壮瞥町洞爺湖温泉(1~7番地)');
ok($zip->set_number('0495801')->is_valid_number, '北海道虻田郡洞爺湖町旭浦');
ok($zip->set_number('0495802')->is_valid_number, '北海道虻田郡洞爺湖町洞爺町');
ok($zip->set_number('0495811')->is_valid_number, '北海道虻田郡洞爺湖町岩屋');
ok($zip->set_number('0495812')->is_valid_number, '北海道虻田郡洞爺湖町川東');
ok($zip->set_number('0495813')->is_valid_number, '北海道虻田郡洞爺湖町財田');
ok($zip->set_number('0495814')->is_valid_number, '北海道虻田郡洞爺湖町早月');
ok($zip->set_number('0495821')->is_valid_number, '北海道虻田郡洞爺湖町大原');
ok($zip->set_number('0495822')->is_valid_number, '北海道虻田郡洞爺湖町富丘');
ok($zip->set_number('0495831')->is_valid_number, '北海道虻田郡洞爺湖町香川');
ok($zip->set_number('0495832')->is_valid_number, '北海道虻田郡洞爺湖町成香');
ok($zip->set_number('0495833')->is_valid_number, '北海道虻田郡洞爺湖町伏見');
ok($zip->set_number('0500000')->is_valid_number, '北海道室蘭市以下に掲載がない場合');
ok($zip->set_number('0500051')->is_valid_number, '北海道室蘭市石川町');
ok($zip->set_number('0500052')->is_valid_number, '北海道室蘭市香川町');
ok($zip->set_number('0500053')->is_valid_number, '北海道室蘭市神代町');
ok($zip->set_number('0500054')->is_valid_number, '北海道室蘭市白鳥台');
ok($zip->set_number('0500055')->is_valid_number, '北海道室蘭市崎守町');
ok($zip->set_number('0500061')->is_valid_number, '北海道室蘭市八丁平');
ok($zip->set_number('0500062')->is_valid_number, '北海道室蘭市高平町');
ok($zip->set_number('0500063')->is_valid_number, '北海道室蘭市港北町');
ok($zip->set_number('0500064')->is_valid_number, '北海道室蘭市柏木町');
ok($zip->set_number('0500065')->is_valid_number, '北海道室蘭市本輪西町');
ok($zip->set_number('0500066')->is_valid_number, '北海道室蘭市幌萌町');
ok($zip->set_number('0500067')->is_valid_number, '北海道室蘭市陣屋町');
ok($zip->set_number('0500071')->is_valid_number, '北海道室蘭市水元町');
ok($zip->set_number('0500072')->is_valid_number, '北海道室蘭市高砂町');
ok($zip->set_number('0500073')->is_valid_number, '北海道室蘭市宮の森町');
ok($zip->set_number('0500074')->is_valid_number, '北海道室蘭市中島町');
ok($zip->set_number('0500075')->is_valid_number, '北海道室蘭市中島本町');
ok($zip->set_number('0500076')->is_valid_number, '北海道室蘭市知利別町');
ok($zip->set_number('0500077')->is_valid_number, '北海道室蘭市天神町');
ok($zip->set_number('0500081')->is_valid_number, '北海道室蘭市日の出町');
ok($zip->set_number('0500082')->is_valid_number, '北海道室蘭市寿町');
ok($zip->set_number('0500083')->is_valid_number, '北海道室蘭市東町');
ok($zip->set_number('0500084')->is_valid_number, '北海道室蘭市みゆき町');
ok($zip->set_number('0500085')->is_valid_number, '北海道室蘭市輪西町');
ok($zip->set_number('0500086')->is_valid_number, '北海道室蘭市大沢町');
ok($zip->set_number('0500087')->is_valid_number, '北海道室蘭市仲町');
ok($zip->set_number('0510001')->is_valid_number, '北海道室蘭市御崎町');
ok($zip->set_number('0510002')->is_valid_number, '北海道室蘭市御前水町');
ok($zip->set_number('0510003')->is_valid_number, '北海道室蘭市母恋南町');
ok($zip->set_number('0510004')->is_valid_number, '北海道室蘭市母恋北町');
ok($zip->set_number('0510005')->is_valid_number, '北海道室蘭市新富町');
ok($zip->set_number('0510006')->is_valid_number, '北海道室蘭市茶津町');
ok($zip->set_number('0510011')->is_valid_number, '北海道室蘭市中央町');
ok($zip->set_number('0510012')->is_valid_number, '北海道室蘭市山手町');
ok($zip->set_number('0510013')->is_valid_number, '北海道室蘭市舟見町');
ok($zip->set_number('0510014')->is_valid_number, '北海道室蘭市栄町');
ok($zip->set_number('0510015')->is_valid_number, '北海道室蘭市本町');
ok($zip->set_number('0510016')->is_valid_number, '北海道室蘭市幸町');
ok($zip->set_number('0510021')->is_valid_number, '北海道室蘭市緑町');
ok($zip->set_number('0510022')->is_valid_number, '北海道室蘭市海岸町');
ok($zip->set_number('0510023')->is_valid_number, '北海道室蘭市入江町');
ok($zip->set_number('0510024')->is_valid_number, '北海道室蘭市幕西町');
ok($zip->set_number('0510025')->is_valid_number, '北海道室蘭市常盤町');
ok($zip->set_number('0510026')->is_valid_number, '北海道室蘭市清水町');
ok($zip->set_number('0510027')->is_valid_number, '北海道室蘭市沢町');
ok($zip->set_number('0510028')->is_valid_number, '北海道室蘭市西小路町');
ok($zip->set_number('0510031')->is_valid_number, '北海道室蘭市築地町');
ok($zip->set_number('0510032')->is_valid_number, '北海道室蘭市港南町');
ok($zip->set_number('0510033')->is_valid_number, '北海道室蘭市小橋内町');
ok($zip->set_number('0510034')->is_valid_number, '北海道室蘭市増市町');
ok($zip->set_number('0510035')->is_valid_number, '北海道室蘭市絵鞆町');
ok($zip->set_number('0510036')->is_valid_number, '北海道室蘭市祝津町');
ok($zip->set_number('0520000')->is_valid_number, '北海道伊達市以下に掲載がない場合');
ok($zip->set_number('0520001')->is_valid_number, '北海道伊達市喜門別町');
ok($zip->set_number('0520001')->is_valid_number, '北海道伊達市志門気町');
ok($zip->set_number('0520002')->is_valid_number, '北海道伊達市乾町');
ok($zip->set_number('0520003')->is_valid_number, '北海道伊達市幌美内町');
ok($zip->set_number('0520004')->is_valid_number, '北海道伊達市萩原町');
ok($zip->set_number('0520005')->is_valid_number, '北海道伊達市清住町');
ok($zip->set_number('0520006')->is_valid_number, '北海道伊達市東関内町');
ok($zip->set_number('0520007')->is_valid_number, '北海道伊達市西関内町');
ok($zip->set_number('0520008')->is_valid_number, '北海道伊達市上館山町');
ok($zip->set_number('0520011')->is_valid_number, '北海道伊達市竹原町');
ok($zip->set_number('0520012')->is_valid_number, '北海道伊達市松ケ枝町');
ok($zip->set_number('0520013')->is_valid_number, '北海道伊達市弄月町');
ok($zip->set_number('0520014')->is_valid_number, '北海道伊達市舟岡町');
ok($zip->set_number('0520015')->is_valid_number, '北海道伊達市旭町');
ok($zip->set_number('0520016')->is_valid_number, '北海道伊達市東浜町');
ok($zip->set_number('0520021')->is_valid_number, '北海道伊達市末永町');
ok($zip->set_number('0520022')->is_valid_number, '北海道伊達市梅本町');
ok($zip->set_number('0520023')->is_valid_number, '北海道伊達市元町');
ok($zip->set_number('0520024')->is_valid_number, '北海道伊達市鹿島町');
ok($zip->set_number('0520025')->is_valid_number, '北海道伊達市網代町');
ok($zip->set_number('0520026')->is_valid_number, '北海道伊達市錦町');
ok($zip->set_number('0520027')->is_valid_number, '北海道伊達市大町');
ok($zip->set_number('0520031')->is_valid_number, '北海道伊達市館山町');
ok($zip->set_number('0520032')->is_valid_number, '北海道伊達市山下町');
ok($zip->set_number('0520033')->is_valid_number, '北海道伊達市西浜町');
ok($zip->set_number('0520034')->is_valid_number, '北海道伊達市館山下町');
ok($zip->set_number('0520035')->is_valid_number, '北海道伊達市長和町');
ok($zip->set_number('0520036')->is_valid_number, '北海道伊達市上長和町');
ok($zip->set_number('0520100')->is_valid_number, '北海道有珠郡壮瞥町以下に掲載がない場合');
ok($zip->set_number('0520101')->is_valid_number, '北海道有珠郡壮瞥町滝之町');
ok($zip->set_number('0520102')->is_valid_number, '北海道有珠郡壮瞥町昭和新山');
ok($zip->set_number('0520103')->is_valid_number, '北海道有珠郡壮瞥町壮瞥温泉');
ok($zip->set_number('0520104')->is_valid_number, '北海道有珠郡壮瞥町東湖畔');
ok($zip->set_number('0520105')->is_valid_number, '北海道有珠郡壮瞥町仲洞爺');
ok($zip->set_number('0520106')->is_valid_number, '北海道有珠郡壮瞥町立香');
ok($zip->set_number('0520107')->is_valid_number, '北海道有珠郡壮瞥町洞爺湖温泉(その他)');
ok($zip->set_number('0520111')->is_valid_number, '北海道有珠郡壮瞥町上久保内');
ok($zip->set_number('0520112')->is_valid_number, '北海道有珠郡壮瞥町久保内');
ok($zip->set_number('0520113')->is_valid_number, '北海道有珠郡壮瞥町蟠渓');
ok($zip->set_number('0520114')->is_valid_number, '北海道有珠郡壮瞥町幸内');
ok($zip->set_number('0520115')->is_valid_number, '北海道有珠郡壮瞥町弁景');
ok($zip->set_number('0520116')->is_valid_number, '北海道有珠郡壮瞥町南久保内');
ok($zip->set_number('0520301')->is_valid_number, '北海道伊達市大滝区本町');
ok($zip->set_number('0520302')->is_valid_number, '北海道伊達市大滝区清陵町');
ok($zip->set_number('0520303')->is_valid_number, '北海道伊達市大滝区三階滝町');
ok($zip->set_number('0520311')->is_valid_number, '北海道伊達市大滝区本郷町');
ok($zip->set_number('0520312')->is_valid_number, '北海道伊達市大滝区上野町');
ok($zip->set_number('0520313')->is_valid_number, '北海道伊達市大滝区大成町');
ok($zip->set_number('0520314')->is_valid_number, '北海道伊達市大滝区円山町');
ok($zip->set_number('0520315')->is_valid_number, '北海道伊達市大滝区昭園町');
ok($zip->set_number('0520316')->is_valid_number, '北海道伊達市大滝区北湯沢温泉町');
ok($zip->set_number('0520317')->is_valid_number, '北海道伊達市大滝区優徳町');
ok($zip->set_number('0530000')->is_valid_number, '北海道苫小牧市以下に掲載がない場合');
ok($zip->set_number('0530001')->is_valid_number, '北海道苫小牧市一本松町(6~15番地)');
ok($zip->set_number('0530002')->is_valid_number, '北海道苫小牧市晴海町(43番地)');
ok($zip->set_number('0530003')->is_valid_number, '北海道苫小牧市入船町');
ok($zip->set_number('0530004')->is_valid_number, '北海道苫小牧市港町');
ok($zip->set_number('0530005')->is_valid_number, '北海道苫小牧市元中野町');
ok($zip->set_number('0530006')->is_valid_number, '北海道苫小牧市新中野町');
ok($zip->set_number('0530007')->is_valid_number, '北海道苫小牧市船見町');
ok($zip->set_number('0530011')->is_valid_number, '北海道苫小牧市末広町');
ok($zip->set_number('0530012')->is_valid_number, '北海道苫小牧市汐見町');
ok($zip->set_number('0530013')->is_valid_number, '北海道苫小牧市高砂町');
ok($zip->set_number('0530014')->is_valid_number, '北海道苫小牧市浜町');
ok($zip->set_number('0530015')->is_valid_number, '北海道苫小牧市本幸町');
ok($zip->set_number('0530016')->is_valid_number, '北海道苫小牧市寿町');
ok($zip->set_number('0530017')->is_valid_number, '北海道苫小牧市栄町');
ok($zip->set_number('0530018')->is_valid_number, '北海道苫小牧市旭町');
ok($zip->set_number('0530021')->is_valid_number, '北海道苫小牧市若草町');
ok($zip->set_number('0530022')->is_valid_number, '北海道苫小牧市表町');
ok($zip->set_number('0530023')->is_valid_number, '北海道苫小牧市錦町');
ok($zip->set_number('0530024')->is_valid_number, '北海道苫小牧市大町');
ok($zip->set_number('0530025')->is_valid_number, '北海道苫小牧市本町');
ok($zip->set_number('0530026')->is_valid_number, '北海道苫小牧市幸町');
ok($zip->set_number('0530027')->is_valid_number, '北海道苫小牧市王子町');
ok($zip->set_number('0530031')->is_valid_number, '北海道苫小牧市春日町');
ok($zip->set_number('0530032')->is_valid_number, '北海道苫小牧市緑町');
ok($zip->set_number('0530033')->is_valid_number, '北海道苫小牧市木場町');
ok($zip->set_number('0530034')->is_valid_number, '北海道苫小牧市清水町');
ok($zip->set_number('0530035')->is_valid_number, '北海道苫小牧市高丘');
ok($zip->set_number('0530041')->is_valid_number, '北海道苫小牧市美園町');
ok($zip->set_number('0530042')->is_valid_number, '北海道苫小牧市三光町');
ok($zip->set_number('0530043')->is_valid_number, '北海道苫小牧市日の出町');
ok($zip->set_number('0530044')->is_valid_number, '北海道苫小牧市音羽町');
ok($zip->set_number('0530045')->is_valid_number, '北海道苫小牧市双葉町');
ok($zip->set_number('0530046')->is_valid_number, '北海道苫小牧市住吉町');
ok($zip->set_number('0530047')->is_valid_number, '北海道苫小牧市泉町');
ok($zip->set_number('0530051')->is_valid_number, '北海道苫小牧市明野元町');
ok($zip->set_number('0530052')->is_valid_number, '北海道苫小牧市新開町');
ok($zip->set_number('0530053')->is_valid_number, '北海道苫小牧市柳町');
ok($zip->set_number('0530054')->is_valid_number, '北海道苫小牧市明野新町');
ok($zip->set_number('0530055')->is_valid_number, '北海道苫小牧市新明町');
ok($zip->set_number('0530056')->is_valid_number, '北海道苫小牧市あけぼの町(3~5丁目)');
ok($zip->set_number('0530801')->is_valid_number, '北海道苫小牧市白金町');
ok($zip->set_number('0530802')->is_valid_number, '北海道苫小牧市弥生町');
ok($zip->set_number('0530803')->is_valid_number, '北海道苫小牧市矢代町');
ok($zip->set_number('0530804')->is_valid_number, '北海道苫小牧市元町');
ok($zip->set_number('0530805')->is_valid_number, '北海道苫小牧市新富町');
ok($zip->set_number('0530806')->is_valid_number, '北海道苫小牧市大成町');
ok($zip->set_number('0530807')->is_valid_number, '北海道苫小牧市青葉町');
ok($zip->set_number('0530811')->is_valid_number, '北海道苫小牧市光洋町');
ok($zip->set_number('0530812')->is_valid_number, '北海道苫小牧市有明町');
ok($zip->set_number('0530813')->is_valid_number, '北海道苫小牧市小糸井町');
ok($zip->set_number('0530814')->is_valid_number, '北海道苫小牧市糸井');
ok($zip->set_number('0530815')->is_valid_number, '北海道苫小牧市永福町');
ok($zip->set_number('0530816')->is_valid_number, '北海道苫小牧市日吉町');
ok($zip->set_number('0530821')->is_valid_number, '北海道苫小牧市しらかば町');
ok($zip->set_number('0530822')->is_valid_number, '北海道苫小牧市川沿町');
ok($zip->set_number('0530823')->is_valid_number, '北海道苫小牧市柏木町');
ok($zip->set_number('0530831')->is_valid_number, '北海道苫小牧市豊川町');
ok($zip->set_number('0530832')->is_valid_number, '北海道苫小牧市桜木町');
ok($zip->set_number('0530833')->is_valid_number, '北海道苫小牧市日新町');
ok($zip->set_number('0530841')->is_valid_number, '北海道苫小牧市松風町');
ok($zip->set_number('0530842')->is_valid_number, '北海道苫小牧市有珠の沢町');
ok($zip->set_number('0530843')->is_valid_number, '北海道苫小牧市桜坂町');
ok($zip->set_number('0530844')->is_valid_number, '北海道苫小牧市宮の森町');
ok($zip->set_number('0530845')->is_valid_number, '北海道苫小牧市はまなす町(1丁目)');
ok($zip->set_number('0530851')->is_valid_number, '北海道苫小牧市山手町');
ok($zip->set_number('0530852')->is_valid_number, '北海道苫小牧市北光町');
ok($zip->set_number('0530853')->is_valid_number, '北海道苫小牧市花園町');
ok($zip->set_number('0530854')->is_valid_number, '北海道苫小牧市啓北町');
ok($zip->set_number('0530855')->is_valid_number, '北海道苫小牧市見山町');
ok($zip->set_number('0540000')->is_valid_number, '北海道勇払郡むかわ町以下に掲載がない場合');
ok($zip->set_number('0540001')->is_valid_number, '北海道勇払郡むかわ町旭岡');
ok($zip->set_number('0540002')->is_valid_number, '北海道勇払郡むかわ町春日');
ok($zip->set_number('0540003')->is_valid_number, '北海道勇払郡むかわ町豊城');
ok($zip->set_number('0540004')->is_valid_number, '北海道勇払郡むかわ町田浦');
ok($zip->set_number('0540005')->is_valid_number, '北海道勇払郡むかわ町二宮');
ok($zip->set_number('0540011')->is_valid_number, '北海道勇払郡むかわ町有明');
ok($zip->set_number('0540012')->is_valid_number, '北海道勇払郡むかわ町生田');
ok($zip->set_number('0540013')->is_valid_number, '北海道勇払郡むかわ町花岡');
ok($zip->set_number('0540014')->is_valid_number, '北海道勇払郡むかわ町米原');
ok($zip->set_number('0540015')->is_valid_number, '北海道勇払郡むかわ町汐見');
ok($zip->set_number('0540016')->is_valid_number, '北海道勇払郡むかわ町宮戸');
ok($zip->set_number('0540021')->is_valid_number, '北海道勇払郡むかわ町大原');
ok($zip->set_number('0540022')->is_valid_number, '北海道勇払郡むかわ町花園');
ok($zip->set_number('0540023')->is_valid_number, '北海道勇払郡むかわ町末広');
ok($zip->set_number('0540031')->is_valid_number, '北海道勇払郡むかわ町青葉');
ok($zip->set_number('0540032')->is_valid_number, '北海道勇払郡むかわ町福住');
ok($zip->set_number('0540041')->is_valid_number, '北海道勇払郡むかわ町松風');
ok($zip->set_number('0540042')->is_valid_number, '北海道勇払郡むかわ町美幸');
ok($zip->set_number('0540051')->is_valid_number, '北海道勇払郡むかわ町文京');
ok($zip->set_number('0540052')->is_valid_number, '北海道勇払郡むかわ町大成');
ok($zip->set_number('0540061')->is_valid_number, '北海道勇払郡むかわ町洋光');
ok($zip->set_number('0540062')->is_valid_number, '北海道勇払郡むかわ町若草');
ok($zip->set_number('0540063')->is_valid_number, '北海道勇払郡むかわ町駒場');
ok($zip->set_number('0540064')->is_valid_number, '北海道勇払郡むかわ町晴海');
ok($zip->set_number('0540141')->is_valid_number, '北海道勇払郡むかわ町穂別栄');
ok($zip->set_number('0540142')->is_valid_number, '北海道勇払郡むかわ町穂別仁和');
ok($zip->set_number('0540143')->is_valid_number, '北海道勇払郡むかわ町穂別和泉');
ok($zip->set_number('0540144')->is_valid_number, '北海道勇払郡むかわ町穂別豊田(その他)');
ok($zip->set_number('0540201')->is_valid_number, '北海道勇払郡むかわ町穂別稲里');
ok($zip->set_number('0540202')->is_valid_number, '北海道勇払郡むかわ町穂別長和');
ok($zip->set_number('0540203')->is_valid_number, '北海道勇払郡むかわ町穂別豊田(新興)');
ok($zip->set_number('0540204')->is_valid_number, '北海道勇払郡むかわ町穂別平丘(川向)');
ok($zip->set_number('0540211')->is_valid_number, '北海道勇払郡むかわ町穂別');
ok($zip->set_number('0540361')->is_valid_number, '北海道勇払郡むかわ町穂別福山');
ok($zip->set_number('0540362')->is_valid_number, '北海道勇払郡むかわ町穂別安住');
ok($zip->set_number('0540363')->is_valid_number, '北海道勇払郡むかわ町穂別平丘(その他)');
ok($zip->set_number('0540364')->is_valid_number, '北海道勇払郡むかわ町穂別富内');
ok($zip->set_number('0550000')->is_valid_number, '北海道沙流郡日高町以下に掲載がない場合');
ok($zip->set_number('0550001')->is_valid_number, '北海道沙流郡日高町富川北');
ok($zip->set_number('0550002')->is_valid_number, '北海道沙流郡日高町平賀');
ok($zip->set_number('0550003')->is_valid_number, '北海道沙流郡日高町福満');
ok($zip->set_number('0550004')->is_valid_number, '北海道沙流郡日高町富川東');
ok($zip->set_number('0550005')->is_valid_number, '北海道沙流郡日高町富浜');
ok($zip->set_number('0550006')->is_valid_number, '北海道沙流郡日高町富川南');
ok($zip->set_number('0550007')->is_valid_number, '北海道沙流郡日高町富川西');
ok($zip->set_number('0550008')->is_valid_number, '北海道沙流郡日高町富川駒丘');
ok($zip->set_number('0550100')->is_valid_number, '北海道沙流郡平取町以下に掲載がない場合');
ok($zip->set_number('0550101')->is_valid_number, '北海道沙流郡平取町二風谷');
ok($zip->set_number('0550102')->is_valid_number, '北海道沙流郡平取町小平');
ok($zip->set_number('0550103')->is_valid_number, '北海道沙流郡平取町川向');
ok($zip->set_number('0550104')->is_valid_number, '北海道沙流郡平取町紫雲古津');
ok($zip->set_number('0550105')->is_valid_number, '北海道沙流郡平取町去場');
ok($zip->set_number('0550106')->is_valid_number, '北海道沙流郡平取町荷菜');
ok($zip->set_number('0550107')->is_valid_number, '北海道沙流郡平取町本町');
ok($zip->set_number('0550321')->is_valid_number, '北海道沙流郡平取町貫気別');
ok($zip->set_number('0550322')->is_valid_number, '北海道沙流郡平取町旭');
ok($zip->set_number('0550323')->is_valid_number, '北海道沙流郡平取町芽生');
ok($zip->set_number('0550324')->is_valid_number, '北海道沙流郡平取町荷負');
ok($zip->set_number('0550325')->is_valid_number, '北海道沙流郡平取町長知内');
ok($zip->set_number('0550411')->is_valid_number, '北海道沙流郡平取町振内町');
ok($zip->set_number('0550412')->is_valid_number, '北海道沙流郡平取町幌毛志');
ok($zip->set_number('0550413')->is_valid_number, '北海道沙流郡平取町仁世宇');
ok($zip->set_number('0550414')->is_valid_number, '北海道沙流郡平取町岩知志');
ok($zip->set_number('0550415')->is_valid_number, '北海道沙流郡平取町豊糠');
ok($zip->set_number('0552301')->is_valid_number, '北海道沙流郡日高町本町東');
ok($zip->set_number('0552302')->is_valid_number, '北海道沙流郡日高町本町西');
ok($zip->set_number('0552303')->is_valid_number, '北海道沙流郡日高町栄町東');
ok($zip->set_number('0552304')->is_valid_number, '北海道沙流郡日高町栄町西');
ok($zip->set_number('0552305')->is_valid_number, '北海道沙流郡日高町新町');
ok($zip->set_number('0552306')->is_valid_number, '北海道沙流郡日高町宮下町');
ok($zip->set_number('0552307')->is_valid_number, '北海道沙流郡日高町松風町');
ok($zip->set_number('0552308')->is_valid_number, '北海道沙流郡日高町山手町');
ok($zip->set_number('0552309')->is_valid_number, '北海道沙流郡日高町若葉町');
ok($zip->set_number('0552311')->is_valid_number, '北海道沙流郡日高町日高(1区)');
ok($zip->set_number('0552312')->is_valid_number, '北海道沙流郡日高町日高(2区)');
ok($zip->set_number('0552313')->is_valid_number, '北海道沙流郡日高町日高(3区)');
ok($zip->set_number('0552314')->is_valid_number, '北海道沙流郡日高町千栄');
ok($zip->set_number('0552315')->is_valid_number, '北海道沙流郡日高町富岡');
ok($zip->set_number('0552316')->is_valid_number, '北海道沙流郡日高町三岩');
ok($zip->set_number('0560000')->is_valid_number, '北海道日高郡新ひだか町以下に掲載がない場合');
ok($zip->set_number('0560001')->is_valid_number, '北海道日高郡新ひだか町静内目名(その他)');
ok($zip->set_number('0560002')->is_valid_number, '北海道日高郡新ひだか町静内神森');
ok($zip->set_number('0560003')->is_valid_number, '北海道日高郡新ひだか町静内旭町');
ok($zip->set_number('0560004')->is_valid_number, '北海道日高郡新ひだか町静内緑町');
ok($zip->set_number('0560005')->is_valid_number, '北海道日高郡新ひだか町静内こうせい町');
ok($zip->set_number('0560006')->is_valid_number, '北海道日高郡新ひだか町静内中野町');
ok($zip->set_number('0560007')->is_valid_number, '北海道日高郡新ひだか町静内清水丘');
ok($zip->set_number('0560011')->is_valid_number, '北海道日高郡新ひだか町静内真歌');
ok($zip->set_number('0560013')->is_valid_number, '北海道日高郡新ひだか町静内入船町');
ok($zip->set_number('0560014')->is_valid_number, '北海道日高郡新ひだか町静内古川町');
ok($zip->set_number('0560015')->is_valid_number, '北海道日高郡新ひだか町静内海岸町');
ok($zip->set_number('0560016')->is_valid_number, '北海道日高郡新ひだか町静内本町');
ok($zip->set_number('0560017')->is_valid_number, '北海道日高郡新ひだか町静内御幸町');
ok($zip->set_number('0560018')->is_valid_number, '北海道日高郡新ひだか町静内吉野町');
ok($zip->set_number('0560019')->is_valid_number, '北海道日高郡新ひだか町静内青柳町');
ok($zip->set_number('0560021')->is_valid_number, '北海道日高郡新ひだか町静内花園');
ok($zip->set_number('0560022')->is_valid_number, '北海道日高郡新ひだか町静内高砂町');
ok($zip->set_number('0560023')->is_valid_number, '北海道日高郡新ひだか町静内ときわ町');
ok($zip->set_number('0560024')->is_valid_number, '北海道日高郡新ひだか町静内山手町');
ok($zip->set_number('0560025')->is_valid_number, '北海道日高郡新ひだか町静内木場町');
ok($zip->set_number('0560026')->is_valid_number, '北海道日高郡新ひだか町静内末広町');
ok($zip->set_number('0560027')->is_valid_number, '北海道日高郡新ひだか町静内駒場');
ok($zip->set_number('0560028')->is_valid_number, '北海道日高郡新ひだか町静内柏台');
ok($zip->set_number('0560141')->is_valid_number, '北海道日高郡新ひだか町静内御園');
ok($zip->set_number('0560142')->is_valid_number, '北海道日高郡新ひだか町静内農屋');
ok($zip->set_number('0560143')->is_valid_number, '北海道日高郡新ひだか町静内豊畑');
ok($zip->set_number('0560144')->is_valid_number, '北海道日高郡新ひだか町静内田原');
ok($zip->set_number('0560145')->is_valid_number, '北海道日高郡新ひだか町静内目名(18、127、453、465-2、466、480番地)');
ok($zip->set_number('0560146')->is_valid_number, '北海道日高郡新ひだか町静内高見');
ok($zip->set_number('0570000')->is_valid_number, '北海道浦河郡浦河町以下に掲載がない場合');
ok($zip->set_number('0570001')->is_valid_number, '北海道浦河郡浦河町東幌別(1~131番地)');
ok($zip->set_number('0570002')->is_valid_number, '北海道浦河郡浦河町西幌別');
ok($zip->set_number('0570003')->is_valid_number, '北海道浦河郡浦河町白泉');
ok($zip->set_number('0570004')->is_valid_number, '北海道浦河郡浦河町月寒');
ok($zip->set_number('0570005')->is_valid_number, '北海道浦河郡浦河町東町うしお');
ok($zip->set_number('0570006')->is_valid_number, '北海道浦河郡浦河町東町かしわ');
ok($zip->set_number('0570007')->is_valid_number, '北海道浦河郡浦河町東町ちのみ');
ok($zip->set_number('0570011')->is_valid_number, '北海道浦河郡浦河町旭町');
ok($zip->set_number('0570012')->is_valid_number, '北海道浦河郡浦河町常盤町');
ok($zip->set_number('0570013')->is_valid_number, '北海道浦河郡浦河町大通');
ok($zip->set_number('0570014')->is_valid_number, '北海道浦河郡浦河町入船町');
ok($zip->set_number('0570015')->is_valid_number, '北海道浦河郡浦河町浜町');
ok($zip->set_number('0570021')->is_valid_number, '北海道浦河郡浦河町潮見町');
ok($zip->set_number('0570022')->is_valid_number, '北海道浦河郡浦河町昌平町');
ok($zip->set_number('0570023')->is_valid_number, '北海道浦河郡浦河町栄丘');
ok($zip->set_number('0570024')->is_valid_number, '北海道浦河郡浦河町築地');
ok($zip->set_number('0570025')->is_valid_number, '北海道浦河郡浦河町緑町');
ok($zip->set_number('0570026')->is_valid_number, '北海道浦河郡浦河町向別');
ok($zip->set_number('0570027')->is_valid_number, '北海道浦河郡浦河町上向別');
ok($zip->set_number('0570031')->is_valid_number, '北海道浦河郡浦河町向が丘東');
ok($zip->set_number('0570032')->is_valid_number, '北海道浦河郡浦河町向が丘西');
ok($zip->set_number('0570033')->is_valid_number, '北海道浦河郡浦河町堺町東');
ok($zip->set_number('0570034')->is_valid_number, '北海道浦河郡浦河町堺町西');
ok($zip->set_number('0570035')->is_valid_number, '北海道浦河郡浦河町井寒台');
ok($zip->set_number('0570036')->is_valid_number, '北海道浦河郡浦河町絵笛');
ok($zip->set_number('0570171')->is_valid_number, '北海道浦河郡浦河町西舎');
ok($zip->set_number('0570172')->is_valid_number, '北海道浦河郡浦河町杵臼');
ok($zip->set_number('0570173')->is_valid_number, '北海道浦河郡浦河町上杵臼');
ok($zip->set_number('0570174')->is_valid_number, '北海道浦河郡浦河町上西舎');
ok($zip->set_number('0580000')->is_valid_number, '北海道様似郡様似町以下に掲載がない場合');
ok($zip->set_number('0580001')->is_valid_number, '北海道様似郡様似町旭');
ok($zip->set_number('0580002')->is_valid_number, '北海道様似郡様似町幌満');
ok($zip->set_number('0580003')->is_valid_number, '北海道様似郡様似町冬島');
ok($zip->set_number('0580004')->is_valid_number, '北海道様似郡様似町平宇');
ok($zip->set_number('0580011')->is_valid_number, '北海道様似郡様似町田代');
ok($zip->set_number('0580012')->is_valid_number, '北海道様似郡様似町朝日丘');
ok($zip->set_number('0580013')->is_valid_number, '北海道様似郡様似町緑町');
ok($zip->set_number('0580014')->is_valid_number, '北海道様似郡様似町大通');
ok($zip->set_number('0580015')->is_valid_number, '北海道様似郡様似町錦町');
ok($zip->set_number('0580021')->is_valid_number, '北海道様似郡様似町新富');
ok($zip->set_number('0580022')->is_valid_number, '北海道様似郡様似町岡田');
ok($zip->set_number('0580023')->is_valid_number, '北海道様似郡様似町栄町');
ok($zip->set_number('0580024')->is_valid_number, '北海道様似郡様似町会所町');
ok($zip->set_number('0580025')->is_valid_number, '北海道様似郡様似町港町');
ok($zip->set_number('0580026')->is_valid_number, '北海道様似郡様似町本町');
ok($zip->set_number('0580027')->is_valid_number, '北海道様似郡様似町潮見台');
ok($zip->set_number('0580031')->is_valid_number, '北海道様似郡様似町西様似');
ok($zip->set_number('0580032')->is_valid_number, '北海道様似郡様似町西町');
ok($zip->set_number('0580033')->is_valid_number, '北海道様似郡様似町鵜苫');
ok($zip->set_number('0580041')->is_valid_number, '北海道浦河郡浦河町東幌別(その他)');
ok($zip->set_number('0580200')->is_valid_number, '北海道幌泉郡えりも町以下に掲載がない場合');
ok($zip->set_number('0580201')->is_valid_number, '北海道幌泉郡えりも町東洋(歌露、坂岸、エンドモ、エンドマカゲ)');
ok($zip->set_number('0580202')->is_valid_number, '北海道幌泉郡えりも町歌別');
ok($zip->set_number('0580203')->is_valid_number, '北海道幌泉郡えりも町新浜');
ok($zip->set_number('0580204')->is_valid_number, '北海道幌泉郡えりも町本町');
ok($zip->set_number('0580205')->is_valid_number, '北海道幌泉郡えりも町大和');
ok($zip->set_number('0580206')->is_valid_number, '北海道幌泉郡えりも町笛舞');
ok($zip->set_number('0580207')->is_valid_number, '北海道幌泉郡えりも町近浦');
ok($zip->set_number('0580341')->is_valid_number, '北海道幌泉郡えりも町苫別');
ok($zip->set_number('0580342')->is_valid_number, '北海道幌泉郡えりも町えりも岬');
ok($zip->set_number('0580343')->is_valid_number, '北海道幌泉郡えりも町東洋(油駒、南東洋、132~156、158~354、366、367番地)');
ok($zip->set_number('0580421')->is_valid_number, '北海道幌泉郡えりも町庶野');
ok($zip->set_number('0580422')->is_valid_number, '北海道幌泉郡えりも町目黒');
ok($zip->set_number('0590000')->is_valid_number, '北海道登別市以下に掲載がない場合');
ok($zip->set_number('0590001')->is_valid_number, '北海道登別市新栄町');
ok($zip->set_number('0590002')->is_valid_number, '北海道登別市幸町');
ok($zip->set_number('0590003')->is_valid_number, '北海道登別市千歳町');
ok($zip->set_number('0590004')->is_valid_number, '北海道登別市来馬町');
ok($zip->set_number('0590005')->is_valid_number, '北海道登別市札内町(5、9、11-12、36、42-2、62、80、95、');
ok($zip->set_number('0590005')->is_valid_number, '北海道登別市184、231、389-2、499、500番地)');
ok($zip->set_number('0590011')->is_valid_number, '北海道登別市常盤町');
ok($zip->set_number('0590012')->is_valid_number, '北海道登別市中央町');
ok($zip->set_number('0590013')->is_valid_number, '北海道登別市幌別町');
ok($zip->set_number('0590014')->is_valid_number, '北海道登別市富士町');
ok($zip->set_number('0590015')->is_valid_number, '北海道登別市新川町');
ok($zip->set_number('0590016')->is_valid_number, '北海道登別市片倉町');
ok($zip->set_number('0590017')->is_valid_number, '北海道登別市柏木町');
ok($zip->set_number('0590021')->is_valid_number, '北海道登別市鉱山町');
ok($zip->set_number('0590022')->is_valid_number, '北海道登別市川上町');
ok($zip->set_number('0590023')->is_valid_number, '北海道登別市桜木町');
ok($zip->set_number('0590024')->is_valid_number, '北海道登別市緑町');
ok($zip->set_number('0590025')->is_valid_number, '北海道登別市大和町');
ok($zip->set_number('0590026')->is_valid_number, '北海道登別市若山町');
ok($zip->set_number('0590027')->is_valid_number, '北海道登別市青葉町');
ok($zip->set_number('0590028')->is_valid_number, '北海道登別市富岸町');
ok($zip->set_number('0590031')->is_valid_number, '北海道登別市上鷲別町');
ok($zip->set_number('0590032')->is_valid_number, '北海道登別市新生町');
ok($zip->set_number('0590033')->is_valid_number, '北海道登別市栄町');
ok($zip->set_number('0590034')->is_valid_number, '北海道登別市鷲別町');
ok($zip->set_number('0590035')->is_valid_number, '北海道登別市若草町');
ok($zip->set_number('0590036')->is_valid_number, '北海道登別市美園町');
ok($zip->set_number('0590151')->is_valid_number, '北海道伊達市有珠町');
ok($zip->set_number('0590152')->is_valid_number, '北海道伊達市北有珠町');
ok($zip->set_number('0590153')->is_valid_number, '北海道伊達市大平町');
ok($zip->set_number('0590154')->is_valid_number, '北海道伊達市東有珠町');
ok($zip->set_number('0590155')->is_valid_number, '北海道伊達市若生町');
ok($zip->set_number('0590156')->is_valid_number, '北海道伊達市南有珠町');
ok($zip->set_number('0590157')->is_valid_number, '北海道伊達市向有珠町');
ok($zip->set_number('0590271')->is_valid_number, '北海道伊達市南黄金町');
ok($zip->set_number('0590272')->is_valid_number, '北海道伊達市北黄金町');
ok($zip->set_number('0590273')->is_valid_number, '北海道伊達市南稀府町');
ok($zip->set_number('0590274')->is_valid_number, '北海道伊達市中稀府町');
ok($zip->set_number('0590275')->is_valid_number, '北海道伊達市北稀府町');
ok($zip->set_number('0590461')->is_valid_number, '北海道登別市札内町(その他)');
ok($zip->set_number('0590462')->is_valid_number, '北海道登別市富浦町');
ok($zip->set_number('0590463')->is_valid_number, '北海道登別市中登別町');
ok($zip->set_number('0590464')->is_valid_number, '北海道登別市登別東町');
ok($zip->set_number('0590465')->is_valid_number, '北海道登別市登別本町');
ok($zip->set_number('0590466')->is_valid_number, '北海道登別市登別港町');
ok($zip->set_number('0590551')->is_valid_number, '北海道登別市登別温泉町');
ok($zip->set_number('0590552')->is_valid_number, '北海道登別市上登別町');
ok($zip->set_number('0590553')->is_valid_number, '北海道登別市カルルス町');
ok($zip->set_number('0590641')->is_valid_number, '北海道白老郡白老町虎杖浜');
ok($zip->set_number('0590642')->is_valid_number, '北海道白老郡白老町竹浦');
ok($zip->set_number('0590900')->is_valid_number, '北海道白老郡白老町以下に掲載がない場合');
ok($zip->set_number('0590901')->is_valid_number, '北海道白老郡白老町社台');
ok($zip->set_number('0590902')->is_valid_number, '北海道白老郡白老町若草町');
ok($zip->set_number('0590903')->is_valid_number, '北海道白老郡白老町日の出町');
ok($zip->set_number('0590904')->is_valid_number, '北海道白老郡白老町東町');
ok($zip->set_number('0590905')->is_valid_number, '北海道白老郡白老町大町');
ok($zip->set_number('0590906')->is_valid_number, '北海道白老郡白老町本町');
ok($zip->set_number('0590907')->is_valid_number, '北海道白老郡白老町末広町');
ok($zip->set_number('0590908')->is_valid_number, '北海道白老郡白老町緑丘');
ok($zip->set_number('0590911')->is_valid_number, '北海道白老郡白老町森野');
ok($zip->set_number('0590912')->is_valid_number, '北海道白老郡白老町陣屋町');
ok($zip->set_number('0590913')->is_valid_number, '北海道白老郡白老町緑町');
ok($zip->set_number('0590914')->is_valid_number, '北海道白老郡白老町栄町');
ok($zip->set_number('0590915')->is_valid_number, '北海道白老郡白老町川沿');
ok($zip->set_number('0590916')->is_valid_number, '北海道白老郡白老町高砂町');
ok($zip->set_number('0590921')->is_valid_number, '北海道白老郡白老町石山');
ok($zip->set_number('0590922')->is_valid_number, '北海道白老郡白老町萩野');
ok($zip->set_number('0590923')->is_valid_number, '北海道白老郡白老町北吉原');
ok($zip->set_number('0591261')->is_valid_number, '北海道苫小牧市ときわ町');
ok($zip->set_number('0591262')->is_valid_number, '北海道苫小牧市美原町');
ok($zip->set_number('0591263')->is_valid_number, '北海道苫小牧市青雲町');
ok($zip->set_number('0591264')->is_valid_number, '北海道苫小牧市宮前町');
ok($zip->set_number('0591265')->is_valid_number, '北海道苫小牧市樽前');
ok($zip->set_number('0591266')->is_valid_number, '北海道苫小牧市錦西町');
ok($zip->set_number('0591271')->is_valid_number, '北海道苫小牧市澄川町');
ok($zip->set_number('0591272')->is_valid_number, '北海道苫小牧市のぞみ町');
ok($zip->set_number('0591273')->is_valid_number, '北海道苫小牧市明徳町');
ok($zip->set_number('0591274')->is_valid_number, '北海道苫小牧市もえぎ町');
ok($zip->set_number('0591275')->is_valid_number, '北海道苫小牧市錦岡');
ok($zip->set_number('0591276')->is_valid_number, '北海道苫小牧市はまなす町(2丁目)');
ok($zip->set_number('0591277')->is_valid_number, '北海道苫小牧市北星町');
ok($zip->set_number('0591301')->is_valid_number, '北海道苫小牧市東開町');
ok($zip->set_number('0591302')->is_valid_number, '北海道苫小牧市拓勇西町');
ok($zip->set_number('0591303')->is_valid_number, '北海道苫小牧市拓勇東町');
ok($zip->set_number('0591304')->is_valid_number, '北海道苫小牧市北栄町');
ok($zip->set_number('0591305')->is_valid_number, '北海道苫小牧市沼ノ端中央');
ok($zip->set_number('0591306')->is_valid_number, '北海道苫小牧市ウトナイ北');
ok($zip->set_number('0591307')->is_valid_number, '北海道苫小牧市ウトナイ南');
ok($zip->set_number('0591361')->is_valid_number, '北海道苫小牧市美沢');
ok($zip->set_number('0591362')->is_valid_number, '北海道苫小牧市柏原');
ok($zip->set_number('0591363')->is_valid_number, '北海道苫小牧市静川');
ok($zip->set_number('0591364')->is_valid_number, '北海道苫小牧市沼ノ端');
ok($zip->set_number('0591365')->is_valid_number, '北海道苫小牧市植苗');
ok($zip->set_number('0591366')->is_valid_number, '北海道苫小牧市あけぼの町(1、2丁目)');
ok($zip->set_number('0591371')->is_valid_number, '北海道苫小牧市弁天');
ok($zip->set_number('0591372')->is_valid_number, '北海道苫小牧市勇払');
ok($zip->set_number('0591373')->is_valid_number, '北海道苫小牧市真砂町');
ok($zip->set_number('0591374')->is_valid_number, '北海道苫小牧市晴海町(1~42番地)');
ok($zip->set_number('0591375')->is_valid_number, '北海道苫小牧市一本松町(1~5番地)');
ok($zip->set_number('0591431')->is_valid_number, '北海道勇払郡安平町早来新栄');
ok($zip->set_number('0591432')->is_valid_number, '北海道勇払郡安平町早来源武');
ok($zip->set_number('0591433')->is_valid_number, '北海道勇払郡安平町遠浅');
ok($zip->set_number('0591434')->is_valid_number, '北海道勇払郡安平町早来富岡');
ok($zip->set_number('0591500')->is_valid_number, '北海道勇払郡安平町以下に掲載がない場合');
ok($zip->set_number('0591501')->is_valid_number, '北海道勇払郡安平町早来大町');
ok($zip->set_number('0591502')->is_valid_number, '北海道勇払郡安平町早来北進');
ok($zip->set_number('0591503')->is_valid_number, '北海道勇払郡安平町東早来');
ok($zip->set_number('0591504')->is_valid_number, '北海道勇払郡安平町早来守田');
ok($zip->set_number('0591505')->is_valid_number, '北海道勇払郡安平町早来栄町');
ok($zip->set_number('0591506')->is_valid_number, '北海道勇払郡安平町早来北町');
ok($zip->set_number('0591511')->is_valid_number, '北海道勇払郡安平町安平');
ok($zip->set_number('0591512')->is_valid_number, '北海道勇払郡安平町早来瑞穂');
ok($zip->set_number('0591513')->is_valid_number, '北海道勇払郡安平町早来緑丘');
ok($zip->set_number('0591600')->is_valid_number, '北海道勇払郡厚真町以下に掲載がない場合');
ok($zip->set_number('0591601')->is_valid_number, '北海道勇払郡厚真町京町');
ok($zip->set_number('0591602')->is_valid_number, '北海道勇払郡厚真町表町');
ok($zip->set_number('0591603')->is_valid_number, '北海道勇払郡厚真町本町');
ok($zip->set_number('0591604')->is_valid_number, '北海道勇払郡厚真町錦町');
ok($zip->set_number('0591605')->is_valid_number, '北海道勇払郡厚真町本郷');
ok($zip->set_number('0591606')->is_valid_number, '北海道勇払郡厚真町朝日');
ok($zip->set_number('0591611')->is_valid_number, '北海道勇払郡厚真町幌里');
ok($zip->set_number('0591612')->is_valid_number, '北海道勇払郡厚真町桜丘');
ok($zip->set_number('0591613')->is_valid_number, '北海道勇払郡厚真町吉野');
ok($zip->set_number('0591614')->is_valid_number, '北海道勇払郡厚真町富里');
ok($zip->set_number('0591615')->is_valid_number, '北海道勇払郡厚真町高丘');
ok($zip->set_number('0591616')->is_valid_number, '北海道勇払郡厚真町幌内');
ok($zip->set_number('0591621')->is_valid_number, '北海道勇払郡厚真町東和');
ok($zip->set_number('0591622')->is_valid_number, '北海道勇払郡厚真町宇隆');
ok($zip->set_number('0591623')->is_valid_number, '北海道勇払郡厚真町新町');
ok($zip->set_number('0591624')->is_valid_number, '北海道勇払郡厚真町豊沢');
ok($zip->set_number('0591625')->is_valid_number, '北海道勇払郡厚真町美里');
ok($zip->set_number('0591741')->is_valid_number, '北海道勇払郡厚真町上厚真');
ok($zip->set_number('0591742')->is_valid_number, '北海道勇払郡厚真町浜厚真');
ok($zip->set_number('0591743')->is_valid_number, '北海道勇払郡厚真町共和');
ok($zip->set_number('0591744')->is_valid_number, '北海道勇払郡厚真町共栄');
ok($zip->set_number('0591745')->is_valid_number, '北海道勇払郡厚真町豊川');
ok($zip->set_number('0591746')->is_valid_number, '北海道勇払郡厚真町上野');
ok($zip->set_number('0591747')->is_valid_number, '北海道勇払郡厚真町富野');
ok($zip->set_number('0591748')->is_valid_number, '北海道勇払郡厚真町厚和');
ok($zip->set_number('0591749')->is_valid_number, '北海道勇払郡厚真町清住');
ok($zip->set_number('0591751')->is_valid_number, '北海道勇払郡厚真町鯉沼');
ok($zip->set_number('0591752')->is_valid_number, '北海道勇払郡厚真町軽舞');
ok($zip->set_number('0591753')->is_valid_number, '北海道勇払郡厚真町豊丘');
ok($zip->set_number('0591754')->is_valid_number, '北海道勇払郡厚真町鹿沼');
ok($zip->set_number('0591911')->is_valid_number, '北海道勇払郡安平町追分本町');
ok($zip->set_number('0591921')->is_valid_number, '北海道勇払郡安平町追分柏が丘');
ok($zip->set_number('0591931')->is_valid_number, '北海道勇払郡安平町追分中央');
ok($zip->set_number('0591941')->is_valid_number, '北海道勇払郡安平町追分青葉');
ok($zip->set_number('0591942')->is_valid_number, '北海道勇払郡安平町追分白樺');
ok($zip->set_number('0591951')->is_valid_number, '北海道勇払郡安平町追分若草');
ok($zip->set_number('0591961')->is_valid_number, '北海道勇払郡安平町追分花園');
ok($zip->set_number('0591971')->is_valid_number, '北海道勇払郡安平町追分緑が丘');
ok($zip->set_number('0591982')->is_valid_number, '北海道勇払郡安平町追分美園');
ok($zip->set_number('0591983')->is_valid_number, '北海道勇払郡安平町追分旭');
ok($zip->set_number('0591984')->is_valid_number, '北海道勇払郡安平町追分向陽');
ok($zip->set_number('0591985')->is_valid_number, '北海道勇払郡安平町追分春日');
ok($zip->set_number('0591986')->is_valid_number, '北海道勇払郡安平町追分弥生');
ok($zip->set_number('0591987')->is_valid_number, '北海道勇払郡安平町追分豊栄');
ok($zip->set_number('0592121')->is_valid_number, '北海道沙流郡日高町門別本町');
ok($zip->set_number('0592122')->is_valid_number, '北海道沙流郡日高町緑町');
ok($zip->set_number('0592123')->is_valid_number, '北海道沙流郡日高町幾千世');
ok($zip->set_number('0592124')->is_valid_number, '北海道沙流郡日高町庫富');
ok($zip->set_number('0592125')->is_valid_number, '北海道沙流郡日高町広富');
ok($zip->set_number('0592126')->is_valid_number, '北海道沙流郡日高町豊郷');
ok($zip->set_number('0592127')->is_valid_number, '北海道沙流郡日高町旭町');
ok($zip->set_number('0592241')->is_valid_number, '北海道沙流郡日高町豊田');
ok($zip->set_number('0592242')->is_valid_number, '北海道沙流郡日高町美原');
ok($zip->set_number('0592243')->is_valid_number, '北海道沙流郡日高町厚賀町');
ok($zip->set_number('0592244')->is_valid_number, '北海道沙流郡日高町賀張');
ok($zip->set_number('0592245')->is_valid_number, '北海道沙流郡日高町清畠');
ok($zip->set_number('0592251')->is_valid_number, '北海道新冠郡新冠町共栄');
ok($zip->set_number('0592252')->is_valid_number, '北海道新冠郡新冠町東川');
ok($zip->set_number('0592253')->is_valid_number, '北海道新冠郡新冠町大狩部(436、516、567番地)');
ok($zip->set_number('0592331')->is_valid_number, '北海道沙流郡日高町正和');
ok($zip->set_number('0592332')->is_valid_number, '北海道沙流郡日高町三和');
ok($zip->set_number('0592341')->is_valid_number, '北海道新冠郡新冠町新和');
ok($zip->set_number('0592342')->is_valid_number, '北海道新冠郡新冠町里平');
ok($zip->set_number('0592343')->is_valid_number, '北海道新冠郡新冠町太陽');
ok($zip->set_number('0592344')->is_valid_number, '北海道新冠郡新冠町美宇');
ok($zip->set_number('0592400')->is_valid_number, '北海道新冠郡新冠町以下に掲載がない場合');
ok($zip->set_number('0592401')->is_valid_number, '北海道新冠郡新冠町本町');
ok($zip->set_number('0592402')->is_valid_number, '北海道新冠郡新冠町中央町');
ok($zip->set_number('0592403')->is_valid_number, '北海道新冠郡新冠町北星町');
ok($zip->set_number('0592404')->is_valid_number, '北海道新冠郡新冠町東町');
ok($zip->set_number('0592411')->is_valid_number, '北海道新冠郡新冠町大狩部(その他)');
ok($zip->set_number('0592412')->is_valid_number, '北海道新冠郡新冠町節婦町');
ok($zip->set_number('0592413')->is_valid_number, '北海道新冠郡新冠町高江');
ok($zip->set_number('0592414')->is_valid_number, '北海道新冠郡新冠町朝日');
ok($zip->set_number('0592415')->is_valid_number, '北海道新冠郡新冠町緑丘');
ok($zip->set_number('0592416')->is_valid_number, '北海道新冠郡新冠町古岸');
ok($zip->set_number('0592417')->is_valid_number, '北海道新冠郡新冠町東泊津');
ok($zip->set_number('0592418')->is_valid_number, '北海道新冠郡新冠町西泊津');
ok($zip->set_number('0592421')->is_valid_number, '北海道新冠郡新冠町若園');
ok($zip->set_number('0592422')->is_valid_number, '北海道新冠郡新冠町岩清水');
ok($zip->set_number('0592423')->is_valid_number, '北海道新冠郡新冠町泉');
ok($zip->set_number('0592424')->is_valid_number, '北海道新冠郡新冠町新栄');
ok($zip->set_number('0592425')->is_valid_number, '北海道新冠郡新冠町明和');
ok($zip->set_number('0592426')->is_valid_number, '北海道新冠郡新冠町万世');
ok($zip->set_number('0592427')->is_valid_number, '北海道新冠郡新冠町大富');
ok($zip->set_number('0592561')->is_valid_number, '北海道日高郡新ひだか町東静内');
ok($zip->set_number('0592562')->is_valid_number, '北海道日高郡新ひだか町静内浦和');
ok($zip->set_number('0592563')->is_valid_number, '北海道日高郡新ひだか町静内川合');
ok($zip->set_number('0592564')->is_valid_number, '北海道日高郡新ひだか町静内西川');
ok($zip->set_number('0592565')->is_valid_number, '北海道日高郡新ひだか町静内春立');
ok($zip->set_number('0592566')->is_valid_number, '北海道日高郡新ひだか町静内東別');
ok($zip->set_number('0592571')->is_valid_number, '北海道日高郡新ひだか町三石西端');
ok($zip->set_number('0593101')->is_valid_number, '北海道日高郡新ひだか町三石富沢');
ok($zip->set_number('0593102')->is_valid_number, '北海道日高郡新ひだか町三石福畑');
ok($zip->set_number('0593103')->is_valid_number, '北海道日高郡新ひだか町三石豊岡');
ok($zip->set_number('0593104')->is_valid_number, '北海道日高郡新ひだか町三石蓬栄');
ok($zip->set_number('0593105')->is_valid_number, '北海道日高郡新ひだか町三石東蓬莱');
ok($zip->set_number('0593106')->is_valid_number, '北海道日高郡新ひだか町三石西蓬莱');
ok($zip->set_number('0593107')->is_valid_number, '北海道日高郡新ひだか町三石旭町');
ok($zip->set_number('0593108')->is_valid_number, '北海道日高郡新ひだか町三石本町');
ok($zip->set_number('0593111')->is_valid_number, '北海道日高郡新ひだか町三石越海町');
ok($zip->set_number('0593112')->is_valid_number, '北海道日高郡新ひだか町三石港町');
ok($zip->set_number('0593231')->is_valid_number, '北海道日高郡新ひだか町三石本桐');
ok($zip->set_number('0593232')->is_valid_number, '北海道日高郡新ひだか町三石美野和');
ok($zip->set_number('0593233')->is_valid_number, '北海道日高郡新ひだか町三石鳧舞');
ok($zip->set_number('0593351')->is_valid_number, '北海道日高郡新ひだか町三石歌笛');
ok($zip->set_number('0593352')->is_valid_number, '北海道日高郡新ひだか町三石稲見');
ok($zip->set_number('0593353')->is_valid_number, '北海道日高郡新ひだか町三石清瀬');
ok($zip->set_number('0593354')->is_valid_number, '北海道日高郡新ひだか町三石川上');
ok($zip->set_number('0593355')->is_valid_number, '北海道日高郡新ひだか町三石美河');
ok($zip->set_number('0593451')->is_valid_number, '北海道浦河郡浦河町荻伏町');
ok($zip->set_number('0593453')->is_valid_number, '北海道浦河郡浦河町瑞穂');
ok($zip->set_number('0593454')->is_valid_number, '北海道浦河郡浦河町野深');
ok($zip->set_number('0593461')->is_valid_number, '北海道浦河郡浦河町東栄');
ok($zip->set_number('0593462')->is_valid_number, '北海道浦河郡浦河町富里');
ok($zip->set_number('0593463')->is_valid_number, '北海道浦河郡浦河町姉茶');
ok($zip->set_number('0600000')->is_valid_number, '北海道札幌市中央区以下に掲載がない場合');
ok($zip->set_number('0600001')->is_valid_number, '北海道札幌市中央区北一条西(1~19丁目)');
ok($zip->set_number('0600002')->is_valid_number, '北海道札幌市中央区北二条西(1~19丁目)');
ok($zip->set_number('0600003')->is_valid_number, '北海道札幌市中央区北三条西(1~19丁目)');
ok($zip->set_number('0600004')->is_valid_number, '北海道札幌市中央区北四条西(1~19丁目)');
ok($zip->set_number('0600005')->is_valid_number, '北海道札幌市中央区北五条西(1~24丁目)');
ok($zip->set_number('0600006')->is_valid_number, '北海道札幌市中央区北六条西(10~25丁目)');
ok($zip->set_number('0600007')->is_valid_number, '北海道札幌市中央区北七条西');
ok($zip->set_number('0600008')->is_valid_number, '北海道札幌市中央区北八条西');
ok($zip->set_number('0600009')->is_valid_number, '北海道札幌市中央区北九条西');
ok($zip->set_number('0600010')->is_valid_number, '北海道札幌市中央区北十条西');
ok($zip->set_number('0600011')->is_valid_number, '北海道札幌市中央区北十一条西');
ok($zip->set_number('0600012')->is_valid_number, '北海道札幌市中央区北十二条西');
ok($zip->set_number('0600013')->is_valid_number, '北海道札幌市中央区北十三条西');
ok($zip->set_number('0600014')->is_valid_number, '北海道札幌市中央区北十四条西');
ok($zip->set_number('0600015')->is_valid_number, '北海道札幌市中央区北十五条西');
ok($zip->set_number('0600016')->is_valid_number, '北海道札幌市中央区北十六条西');
ok($zip->set_number('0600017')->is_valid_number, '北海道札幌市中央区北十七条西');
ok($zip->set_number('0600018')->is_valid_number, '北海道札幌市中央区北十八条西');
ok($zip->set_number('0600020')->is_valid_number, '北海道札幌市中央区北二十条西');
ok($zip->set_number('0600021')->is_valid_number, '北海道札幌市中央区北二十一条西');
ok($zip->set_number('0600022')->is_valid_number, '北海道札幌市中央区北二十二条西');
ok($zip->set_number('0600031')->is_valid_number, '北海道札幌市中央区北一条東');
ok($zip->set_number('0600032')->is_valid_number, '北海道札幌市中央区北二条東');
ok($zip->set_number('0600033')->is_valid_number, '北海道札幌市中央区北三条東');
ok($zip->set_number('0600034')->is_valid_number, '北海道札幌市中央区北四条東(1~8丁目)');
ok($zip->set_number('0600035')->is_valid_number, '北海道札幌市中央区北五条東');
ok($zip->set_number('0600041')->is_valid_number, '北海道札幌市中央区大通東');
ok($zip->set_number('0600042')->is_valid_number, '北海道札幌市中央区大通西(1~19丁目)');
ok($zip->set_number('0600051')->is_valid_number, '北海道札幌市中央区南一条東');
ok($zip->set_number('0600052')->is_valid_number, '北海道札幌市中央区南二条東');
ok($zip->set_number('0600053')->is_valid_number, '北海道札幌市中央区南三条東');
ok($zip->set_number('0600054')->is_valid_number, '北海道札幌市中央区南四条東');
ok($zip->set_number('0600055')->is_valid_number, '北海道札幌市中央区南五条東');
ok($zip->set_number('0600056')->is_valid_number, '北海道札幌市中央区南六条東');
ok($zip->set_number('0600057')->is_valid_number, '北海道札幌市中央区南七条東');
ok($zip->set_number('0600061')->is_valid_number, '北海道札幌市中央区南一条西(1~19丁目)');
ok($zip->set_number('0600062')->is_valid_number, '北海道札幌市中央区南二条西(1~19丁目)');
ok($zip->set_number('0600063')->is_valid_number, '北海道札幌市中央区南三条西(1~18丁目)');
ok($zip->set_number('0600806')->is_valid_number, '北海道札幌市北区北六条西');
ok($zip->set_number('0600807')->is_valid_number, '北海道札幌市北区北七条西');
ok($zip->set_number('0600808')->is_valid_number, '北海道札幌市北区北八条西');
ok($zip->set_number('0600809')->is_valid_number, '北海道札幌市北区北九条西');
ok($zip->set_number('0600810')->is_valid_number, '北海道札幌市北区北十条西(5~11丁目)');
ok($zip->set_number('0600811')->is_valid_number, '北海道札幌市北区北十一条西(5~11丁目)');
ok($zip->set_number('0600812')->is_valid_number, '北海道札幌市北区北十二条西(5~12丁目)');
ok($zip->set_number('0600813')->is_valid_number, '北海道札幌市北区北十三条西(5~12丁目)');
ok($zip->set_number('0600814')->is_valid_number, '北海道札幌市北区北十四条西(5~13丁目)');
ok($zip->set_number('0600815')->is_valid_number, '北海道札幌市北区北十五条西(6~13丁目)');
ok($zip->set_number('0600816')->is_valid_number, '北海道札幌市北区北十六条西(7~13丁目)');
ok($zip->set_number('0600817')->is_valid_number, '北海道札幌市北区北十七条西(7~13丁目)');
ok($zip->set_number('0600818')->is_valid_number, '北海道札幌市北区北十八条西(8~13丁目)');
ok($zip->set_number('0600819')->is_valid_number, '北海道札幌市北区北十九条西(8~13丁目)');
ok($zip->set_number('0600820')->is_valid_number, '北海道札幌市北区北二十条西(11~13丁目)');
ok($zip->set_number('0600905')->is_valid_number, '北海道札幌市東区北五条東(4~7丁目)');
ok($zip->set_number('0600906')->is_valid_number, '北海道札幌市東区北六条東(1~7丁目)');
ok($zip->set_number('0600907')->is_valid_number, '北海道札幌市東区北七条東(1~7丁目)');
ok($zip->set_number('0600908')->is_valid_number, '北海道札幌市東区北八条東(1~7丁目)');
ok($zip->set_number('0600909')->is_valid_number, '北海道札幌市東区北九条東(1~7丁目)');
ok($zip->set_number('0610200')->is_valid_number, '北海道石狩郡当別町以下に掲載がない場合');
ok($zip->set_number('0610201')->is_valid_number, '北海道石狩郡当別町青山');
ok($zip->set_number('0610202')->is_valid_number, '北海道石狩郡当別町茂平沢');
ok($zip->set_number('0610203')->is_valid_number, '北海道石狩郡当別町みどり野');
ok($zip->set_number('0610204')->is_valid_number, '北海道石狩郡当別町若葉');
ok($zip->set_number('0610205')->is_valid_number, '北海道石狩郡当別町下川町');
ok($zip->set_number('0610206')->is_valid_number, '北海道石狩郡当別町川下(その他)');
ok($zip->set_number('0610207')->is_valid_number, '北海道石狩郡当別町上当別');
ok($zip->set_number('0610208')->is_valid_number, '北海道石狩郡当別町弁華別');
ok($zip->set_number('0610211')->is_valid_number, '北海道石狩郡当別町中小屋');
ok($zip->set_number('0610212')->is_valid_number, '北海道石狩郡当別町金沢');
ok($zip->set_number('0610213')->is_valid_number, '北海道石狩郡当別町東裏');
ok($zip->set_number('0610214')->is_valid_number, '北海道石狩郡当別町蕨岱');
ok($zip->set_number('0610215')->is_valid_number, '北海道石狩郡当別町対雁');
ok($zip->set_number('0610216')->is_valid_number, '北海道石狩郡当別町栄町');
ok($zip->set_number('0610217')->is_valid_number, '北海道石狩郡当別町幸町');
ok($zip->set_number('0610218')->is_valid_number, '北海道石狩郡当別町樺戸町');
ok($zip->set_number('0610221')->is_valid_number, '北海道石狩郡当別町東町');
ok($zip->set_number('0610222')->is_valid_number, '北海道石狩郡当別町元町');
ok($zip->set_number('0610223')->is_valid_number, '北海道石狩郡当別町弥生');
ok($zip->set_number('0610224')->is_valid_number, '北海道石狩郡当別町末広');
ok($zip->set_number('0610225')->is_valid_number, '北海道石狩郡当別町美里');
ok($zip->set_number('0610226')->is_valid_number, '北海道石狩郡当別町錦町');
ok($zip->set_number('0610227')->is_valid_number, '北海道石狩郡当別町園生');
ok($zip->set_number('0610228')->is_valid_number, '北海道石狩郡当別町緑町');
ok($zip->set_number('0610231')->is_valid_number, '北海道石狩郡当別町六軒町');
ok($zip->set_number('0610232')->is_valid_number, '北海道石狩郡当別町春日町');
ok($zip->set_number('0610233')->is_valid_number, '北海道石狩郡当別町白樺町');
ok($zip->set_number('0610234')->is_valid_number, '北海道石狩郡当別町西町');
ok($zip->set_number('0610235')->is_valid_number, '北海道石狩郡当別町北栄町');
ok($zip->set_number('0610251')->is_valid_number, '北海道石狩郡当別町青山奥四番川');
ok($zip->set_number('0610252')->is_valid_number, '北海道石狩郡当別町青山奥三番川');
ok($zip->set_number('0610253')->is_valid_number, '北海道石狩郡当別町青山奥二番川');
ok($zip->set_number('0610254')->is_valid_number, '北海道石狩郡当別町青山中央(青山奥)');
ok($zip->set_number('0610500')->is_valid_number, '北海道樺戸郡月形町以下に掲載がない場合');
ok($zip->set_number('0610501')->is_valid_number, '北海道樺戸郡月形町新生');
ok($zip->set_number('0610502')->is_valid_number, '北海道樺戸郡月形町北農場');
ok($zip->set_number('0610503')->is_valid_number, '北海道樺戸郡月形町豊ケ丘');
ok($zip->set_number('0610504')->is_valid_number, '北海道樺戸郡月形町新富');
ok($zip->set_number('0610505')->is_valid_number, '北海道樺戸郡月形町札比内');
ok($zip->set_number('0610506')->is_valid_number, '北海道樺戸郡月形町新宮');
ok($zip->set_number('0610507')->is_valid_number, '北海道樺戸郡月形町南札比内');
ok($zip->set_number('0610508')->is_valid_number, '北海道樺戸郡月形町厚栄');
ok($zip->set_number('0610511')->is_valid_number, '北海道樺戸郡月形町市北');
ok($zip->set_number('0610512')->is_valid_number, '北海道樺戸郡月形町市南');
ok($zip->set_number('0610513')->is_valid_number, '北海道樺戸郡月形町農事会');
ok($zip->set_number('0610514')->is_valid_number, '北海道樺戸郡月形町麻生');
ok($zip->set_number('0610515')->is_valid_number, '北海道樺戸郡月形町五耕地山');
ok($zip->set_number('0610516')->is_valid_number, '北海道樺戸郡月形町知来乙');
ok($zip->set_number('0610517')->is_valid_number, '北海道樺戸郡月形町北郷');
ok($zip->set_number('0610518')->is_valid_number, '北海道樺戸郡月形町赤川');
ok($zip->set_number('0610521')->is_valid_number, '北海道樺戸郡月形町南耕地');
ok($zip->set_number('0610522')->is_valid_number, '北海道樺戸郡月形町月浜');
ok($zip->set_number('0610523')->is_valid_number, '北海道樺戸郡月形町昭栄');
ok($zip->set_number('0610524')->is_valid_number, '北海道樺戸郡月形町南新田');
ok($zip->set_number('0610525')->is_valid_number, '北海道樺戸郡月形町新栄');
ok($zip->set_number('0610526')->is_valid_number, '北海道樺戸郡月形町新田');
ok($zip->set_number('0610527')->is_valid_number, '北海道樺戸郡月形町共和');
ok($zip->set_number('0610528')->is_valid_number, '北海道樺戸郡月形町月ケ岡');
ok($zip->set_number('0610529')->is_valid_number, '北海道樺戸郡月形町月ヶ杜');
ok($zip->set_number('0610600')->is_valid_number, '北海道樺戸郡浦臼町以下に掲載がない場合');
ok($zip->set_number('0610601')->is_valid_number, '北海道樺戸郡浦臼町鶴沼第1');
ok($zip->set_number('0610602')->is_valid_number, '北海道樺戸郡浦臼町鶴沼第2');
ok($zip->set_number('0610603')->is_valid_number, '北海道樺戸郡浦臼町鶴沼第3');
ok($zip->set_number('0610611')->is_valid_number, '北海道樺戸郡浦臼町浦臼第1');
ok($zip->set_number('0610612')->is_valid_number, '北海道樺戸郡浦臼町浦臼第2');
ok($zip->set_number('0610613')->is_valid_number, '北海道樺戸郡浦臼町浦臼第3');
ok($zip->set_number('0610614')->is_valid_number, '北海道樺戸郡浦臼町浦臼第4');
ok($zip->set_number('0610615')->is_valid_number, '北海道樺戸郡浦臼町浦臼第5');
ok($zip->set_number('0610616')->is_valid_number, '北海道樺戸郡浦臼町浦臼第6');
ok($zip->set_number('0610617')->is_valid_number, '北海道樺戸郡浦臼町浦臼第7');
ok($zip->set_number('0610618')->is_valid_number, '北海道樺戸郡浦臼町浦臼第8');
ok($zip->set_number('0610621')->is_valid_number, '北海道樺戸郡浦臼町晩生内第1');
ok($zip->set_number('0610622')->is_valid_number, '北海道樺戸郡浦臼町晩生内第2');
ok($zip->set_number('0610623')->is_valid_number, '北海道樺戸郡浦臼町晩生内第3');
ok($zip->set_number('0611100')->is_valid_number, '北海道北広島市以下に掲載がない場合');
ok($zip->set_number('0611101')->is_valid_number, '北海道北広島市中の沢(その他)');
ok($zip->set_number('0611102')->is_valid_number, '北海道北広島市西の里');
ok($zip->set_number('0611103')->is_valid_number, '北海道北広島市虹ケ丘');
ok($zip->set_number('0611104')->is_valid_number, '北海道北広島市西の里北');
ok($zip->set_number('0611105')->is_valid_number, '北海道北広島市西の里東');
ok($zip->set_number('0611106')->is_valid_number, '北海道北広島市西の里南');
ok($zip->set_number('0611111')->is_valid_number, '北海道北広島市北の里');
ok($zip->set_number('0611112')->is_valid_number, '北海道北広島市共栄');
ok($zip->set_number('0611113')->is_valid_number, '北海道北広島市共栄町');
ok($zip->set_number('0611114')->is_valid_number, '北海道北広島市東共栄');
ok($zip->set_number('0611115')->is_valid_number, '北海道北広島市美咲き野');
ok($zip->set_number('0611116')->is_valid_number, '北海道北広島市Fビレッジ');
ok($zip->set_number('0611121')->is_valid_number, '北海道北広島市中央');
ok($zip->set_number('0611122')->is_valid_number, '北海道北広島市広島');
ok($zip->set_number('0611123')->is_valid_number, '北海道北広島市朝日町');
ok($zip->set_number('0611124')->is_valid_number, '北海道北広島市稲穂町西');
ok($zip->set_number('0611125')->is_valid_number, '北海道北広島市稲穂町東');
ok($zip->set_number('0611126')->is_valid_number, '北海道北広島市新富町東');
ok($zip->set_number('0611127')->is_valid_number, '北海道北広島市新富町西');
ok($zip->set_number('0611131')->is_valid_number, '北海道北広島市美沢');
ok($zip->set_number('0611132')->is_valid_number, '北海道北広島市北進町');
ok($zip->set_number('0611133')->is_valid_number, '北海道北広島市栄町');
ok($zip->set_number('0611134')->is_valid_number, '北海道北広島市広葉町');
ok($zip->set_number('0611135')->is_valid_number, '北海道北広島市輝美町');
ok($zip->set_number('0611136')->is_valid_number, '北海道北広島市松葉町');
ok($zip->set_number('0611137')->is_valid_number, '北海道北広島市緑陽町');
ok($zip->set_number('0611141')->is_valid_number, '北海道北広島市青葉町');
ok($zip->set_number('0611142')->is_valid_number, '北海道北広島市若葉町');
ok($zip->set_number('0611143')->is_valid_number, '北海道北広島市南町');
ok($zip->set_number('0611144')->is_valid_number, '北海道北広島市白樺町');
ok($zip->set_number('0611145')->is_valid_number, '北海道北広島市泉町');
ok($zip->set_number('0611146')->is_valid_number, '北海道北広島市高台町');
ok($zip->set_number('0611147')->is_valid_number, '北海道北広島市里見町');
ok($zip->set_number('0611148')->is_valid_number, '北海道北広島市山手町');
ok($zip->set_number('0611151')->is_valid_number, '北海道北広島市東の里');
ok($zip->set_number('0611152')->is_valid_number, '北海道北広島市中の沢(557~736番地)');
ok($zip->set_number('0611153')->is_valid_number, '北海道北広島市富ケ岡');
ok($zip->set_number('0611154')->is_valid_number, '北海道北広島市南の里');
ok($zip->set_number('0611261')->is_valid_number, '北海道北広島市希望ケ丘');
ok($zip->set_number('0611264')->is_valid_number, '北海道北広島市輪厚');
ok($zip->set_number('0611265')->is_valid_number, '北海道北広島市島松');
ok($zip->set_number('0611266')->is_valid_number, '北海道北広島市三島');
ok($zip->set_number('0611267')->is_valid_number, '北海道北広島市仁別');
ok($zip->set_number('0611268')->is_valid_number, '北海道北広島市輪厚中央');
ok($zip->set_number('0611269')->is_valid_number, '北海道北広島市輪厚元町');
ok($zip->set_number('0611270')->is_valid_number, '北海道北広島市大曲');
ok($zip->set_number('0611271')->is_valid_number, '北海道北広島市大曲中央');
ok($zip->set_number('0611272')->is_valid_number, '北海道北広島市大曲末広');
ok($zip->set_number('0611273')->is_valid_number, '北海道北広島市大曲柏葉');
ok($zip->set_number('0611274')->is_valid_number, '北海道北広島市大曲工業団地');
ok($zip->set_number('0611275')->is_valid_number, '北海道北広島市大曲南ケ丘');
ok($zip->set_number('0611276')->is_valid_number, '北海道北広島市大曲緑ケ丘');
ok($zip->set_number('0611277')->is_valid_number, '北海道北広島市大曲光');
ok($zip->set_number('0611278')->is_valid_number, '北海道北広島市大曲幸町');
ok($zip->set_number('0611279')->is_valid_number, '北海道北広島市大曲並木');
ok($zip->set_number('0611281')->is_valid_number, '北海道北広島市輪厚工業団地');
ok($zip->set_number('0611351')->is_valid_number, '北海道恵庭市島松東町');
ok($zip->set_number('0611352')->is_valid_number, '北海道恵庭市島松仲町');
ok($zip->set_number('0611353')->is_valid_number, '北海道恵庭市島松本町');
ok($zip->set_number('0611354')->is_valid_number, '北海道恵庭市島松旭町');
ok($zip->set_number('0611355')->is_valid_number, '北海道恵庭市島松寿町');
ok($zip->set_number('0611356')->is_valid_number, '北海道恵庭市西島松');
ok($zip->set_number('0611361')->is_valid_number, '北海道恵庭市林田');
ok($zip->set_number('0611362')->is_valid_number, '北海道恵庭市中島松');
ok($zip->set_number('0611363')->is_valid_number, '北海道恵庭市桜森');
ok($zip->set_number('0611363')->is_valid_number, '北海道恵庭市島松沢');
ok($zip->set_number('0611364')->is_valid_number, '北海道恵庭市下島松');
ok($zip->set_number('0611365')->is_valid_number, '北海道恵庭市穂栄');
ok($zip->set_number('0611366')->is_valid_number, '北海道恵庭市北島');
ok($zip->set_number('0611371')->is_valid_number, '北海道恵庭市恵み野東');
ok($zip->set_number('0611372')->is_valid_number, '北海道恵庭市恵み野南');
ok($zip->set_number('0611373')->is_valid_number, '北海道恵庭市恵み野西');
ok($zip->set_number('0611374')->is_valid_number, '北海道恵庭市恵み野北');
ok($zip->set_number('0611375')->is_valid_number, '北海道恵庭市南島松');
ok($zip->set_number('0611376')->is_valid_number, '北海道恵庭市恵み野里美');
ok($zip->set_number('0611400')->is_valid_number, '北海道恵庭市以下に掲載がない場合');
ok($zip->set_number('0611401')->is_valid_number, '北海道恵庭市漁太');
ok($zip->set_number('0611402')->is_valid_number, '北海道恵庭市春日');
ok($zip->set_number('0611403')->is_valid_number, '北海道恵庭市中央');
ok($zip->set_number('0611404')->is_valid_number, '北海道恵庭市上山口');
ok($zip->set_number('0611405')->is_valid_number, '北海道恵庭市戸磯');
ok($zip->set_number('0611406')->is_valid_number, '北海道恵庭市和光町');
ok($zip->set_number('0611407')->is_valid_number, '北海道恵庭市黄金北');
ok($zip->set_number('0611409')->is_valid_number, '北海道恵庭市黄金南');
ok($zip->set_number('0611411')->is_valid_number, '北海道恵庭市恵南');
ok($zip->set_number('0611412')->is_valid_number, '北海道恵庭市白樺町');
ok($zip->set_number('0611413')->is_valid_number, '北海道恵庭市本町');
ok($zip->set_number('0611414')->is_valid_number, '北海道恵庭市漁町');
ok($zip->set_number('0611415')->is_valid_number, '北海道恵庭市泉町');
ok($zip->set_number('0611416')->is_valid_number, '北海道恵庭市桜町');
ok($zip->set_number('0611417')->is_valid_number, '北海道恵庭市駒場町');
ok($zip->set_number('0611421')->is_valid_number, '北海道恵庭市牧場');
ok($zip->set_number('0611422')->is_valid_number, '北海道恵庭市盤尻');
ok($zip->set_number('0611423')->is_valid_number, '北海道恵庭市柏木町');
ok($zip->set_number('0611424')->is_valid_number, '北海道恵庭市大町');
ok($zip->set_number('0611425')->is_valid_number, '北海道恵庭市文京町');
ok($zip->set_number('0611426')->is_valid_number, '北海道恵庭市幸町');
ok($zip->set_number('0611427')->is_valid_number, '北海道恵庭市美咲野');
ok($zip->set_number('0611431')->is_valid_number, '北海道恵庭市有明町');
ok($zip->set_number('0611432')->is_valid_number, '北海道恵庭市恵央町');
ok($zip->set_number('0611433')->is_valid_number, '北海道恵庭市北柏木町');
ok($zip->set_number('0611434')->is_valid_number, '北海道恵庭市柏陽町');
ok($zip->set_number('0611435')->is_valid_number, '北海道恵庭市中島町');
ok($zip->set_number('0611441')->is_valid_number, '北海道恵庭市住吉町');
ok($zip->set_number('0611442')->is_valid_number, '北海道恵庭市緑町');
ok($zip->set_number('0611443')->is_valid_number, '北海道恵庭市栄恵町');
ok($zip->set_number('0611444')->is_valid_number, '北海道恵庭市京町');
ok($zip->set_number('0611445')->is_valid_number, '北海道恵庭市新町');
ok($zip->set_number('0611446')->is_valid_number, '北海道恵庭市末広町');
ok($zip->set_number('0611447')->is_valid_number, '北海道恵庭市福住町');
ok($zip->set_number('0611448')->is_valid_number, '北海道恵庭市相生町');
ok($zip->set_number('0611449')->is_valid_number, '北海道恵庭市黄金中央');
ok($zip->set_number('0612261')->is_valid_number, '北海道札幌市南区簾舞一条');
ok($zip->set_number('0612262')->is_valid_number, '北海道札幌市南区簾舞二条');
ok($zip->set_number('0612263')->is_valid_number, '北海道札幌市南区簾舞三条');
ok($zip->set_number('0612264')->is_valid_number, '北海道札幌市南区簾舞四条');
ok($zip->set_number('0612265')->is_valid_number, '北海道札幌市南区簾舞五条');
ok($zip->set_number('0612266')->is_valid_number, '北海道札幌市南区簾舞六条');
ok($zip->set_number('0612271')->is_valid_number, '北海道札幌市南区藤野(その他)');
ok($zip->set_number('0612272')->is_valid_number, '北海道札幌市南区簾舞(その他)');
ok($zip->set_number('0612273')->is_valid_number, '北海道札幌市南区豊滝');
ok($zip->set_number('0612274')->is_valid_number, '北海道札幌市南区小金湯');
ok($zip->set_number('0612275')->is_valid_number, '北海道札幌市南区砥山');
ok($zip->set_number('0612276')->is_valid_number, '北海道札幌市南区白川');
ok($zip->set_number('0612281')->is_valid_number, '北海道札幌市南区藤野一条');
ok($zip->set_number('0612282')->is_valid_number, '北海道札幌市南区藤野二条');
ok($zip->set_number('0612283')->is_valid_number, '北海道札幌市南区藤野三条');
ok($zip->set_number('0612284')->is_valid_number, '北海道札幌市南区藤野四条');
ok($zip->set_number('0612285')->is_valid_number, '北海道札幌市南区藤野五条');
ok($zip->set_number('0612286')->is_valid_number, '北海道札幌市南区藤野六条');
ok($zip->set_number('0612301')->is_valid_number, '北海道札幌市南区定山渓');
ok($zip->set_number('0612302')->is_valid_number, '北海道札幌市南区定山渓温泉東');
ok($zip->set_number('0612303')->is_valid_number, '北海道札幌市南区定山渓温泉西');
ok($zip->set_number('0613101')->is_valid_number, '北海道石狩市浜益区浜益');
ok($zip->set_number('0613102')->is_valid_number, '北海道石狩市浜益区群別');
ok($zip->set_number('0613103')->is_valid_number, '北海道石狩市浜益区幌');
ok($zip->set_number('0613104')->is_valid_number, '北海道石狩市浜益区床丹');
ok($zip->set_number('0613105')->is_valid_number, '北海道石狩市浜益区千代志別');
ok($zip->set_number('0613106')->is_valid_number, '北海道石狩市浜益区川下');
ok($zip->set_number('0613107')->is_valid_number, '北海道石狩市浜益区柏木');
ok($zip->set_number('0613108')->is_valid_number, '北海道石狩市浜益区実田');
ok($zip->set_number('0613109')->is_valid_number, '北海道石狩市浜益区御料地');
ok($zip->set_number('0613111')->is_valid_number, '北海道石狩市浜益区毘砂別');
ok($zip->set_number('0613112')->is_valid_number, '北海道石狩市浜益区送毛');
ok($zip->set_number('0613113')->is_valid_number, '北海道石狩市浜益区濃昼');
ok($zip->set_number('0613151')->is_valid_number, '北海道石狩市厚田区濃昼');
ok($zip->set_number('0613200')->is_valid_number, '北海道石狩市以下に掲載がない場合');
ok($zip->set_number('0613201')->is_valid_number, '北海道石狩市花川南一条');
ok($zip->set_number('0613202')->is_valid_number, '北海道石狩市花川南二条');
ok($zip->set_number('0613203')->is_valid_number, '北海道石狩市花川南三条');
ok($zip->set_number('0613204')->is_valid_number, '北海道石狩市花川南四条');
ok($zip->set_number('0613205')->is_valid_number, '北海道石狩市花川南五条');
ok($zip->set_number('0613206')->is_valid_number, '北海道石狩市花川南六条');
ok($zip->set_number('0613207')->is_valid_number, '北海道石狩市花川南七条');
ok($zip->set_number('0613208')->is_valid_number, '北海道石狩市花川南八条');
ok($zip->set_number('0613209')->is_valid_number, '北海道石狩市花川南九条');
ok($zip->set_number('0613210')->is_valid_number, '北海道石狩市花川南十条');
ok($zip->set_number('0613211')->is_valid_number, '北海道石狩市花川北一条');
ok($zip->set_number('0613212')->is_valid_number, '北海道石狩市花川北二条');
ok($zip->set_number('0613213')->is_valid_number, '北海道石狩市花川北三条');
ok($zip->set_number('0613214')->is_valid_number, '北海道石狩市花川北四条');
ok($zip->set_number('0613215')->is_valid_number, '北海道石狩市花川北五条');
ok($zip->set_number('0613216')->is_valid_number, '北海道石狩市花川北六条');
ok($zip->set_number('0613217')->is_valid_number, '北海道石狩市花川北七条');
ok($zip->set_number('0613218')->is_valid_number, '北海道石狩市花畔(その他)');
ok($zip->set_number('0613219')->is_valid_number, '北海道石狩市花川');
ok($zip->set_number('0613220')->is_valid_number, '北海道石狩市志美');
ok($zip->set_number('0613221')->is_valid_number, '北海道石狩市緑苑台東一条');
ok($zip->set_number('0613222')->is_valid_number, '北海道石狩市緑苑台東二条');
ok($zip->set_number('0613223')->is_valid_number, '北海道石狩市緑苑台東三条');
ok($zip->set_number('0613230')->is_valid_number, '北海道石狩市緑苑台中央');
ok($zip->set_number('0613231')->is_valid_number, '北海道石狩市緑苑台西一条');
ok($zip->set_number('0613232')->is_valid_number, '北海道石狩市緑苑台西二条');
ok($zip->set_number('0613241')->is_valid_number, '北海道石狩市新港西');
ok($zip->set_number('0613242')->is_valid_number, '北海道石狩市新港中央');
ok($zip->set_number('0613243')->is_valid_number, '北海道石狩市新港東');
ok($zip->set_number('0613244')->is_valid_number, '北海道石狩市新港南');
ok($zip->set_number('0613245')->is_valid_number, '北海道石狩市生振');
ok($zip->set_number('0613248')->is_valid_number, '北海道石狩市花川東');
ok($zip->set_number('0613251')->is_valid_number, '北海道石狩市樽川(その他)');
ok($zip->set_number('0613253')->is_valid_number, '北海道石狩市樽川三条');
ok($zip->set_number('0613254')->is_valid_number, '北海道石狩市樽川四条');
ok($zip->set_number('0613255')->is_valid_number, '北海道石狩市樽川五条');
ok($zip->set_number('0613256')->is_valid_number, '北海道石狩市樽川六条');
ok($zip->set_number('0613257')->is_valid_number, '北海道石狩市樽川七条');
ok($zip->set_number('0613258')->is_valid_number, '北海道石狩市樽川八条');
ok($zip->set_number('0613259')->is_valid_number, '北海道石狩市樽川九条');
ok($zip->set_number('0613261')->is_valid_number, '北海道石狩市花川東一条');
ok($zip->set_number('0613262')->is_valid_number, '北海道石狩市花川東二条');
ok($zip->set_number('0613271')->is_valid_number, '北海道小樽市銭函(4~5丁目)');
ok($zip->set_number('0613281')->is_valid_number, '北海道石狩市花畔一条');
ok($zip->set_number('0613282')->is_valid_number, '北海道石狩市花畔二条');
ok($zip->set_number('0613283')->is_valid_number, '北海道石狩市花畔三条');
ok($zip->set_number('0613284')->is_valid_number, '北海道石狩市花畔四条');
ok($zip->set_number('0613331')->is_valid_number, '北海道石狩市厚田区聚富(中央、シラツカリ)');
ok($zip->set_number('0613332')->is_valid_number, '北海道石狩市厚田区虹が原');
ok($zip->set_number('0613361')->is_valid_number, '北海道石狩市八幡(その他)');
ok($zip->set_number('0613362')->is_valid_number, '北海道石狩市北生振');
ok($zip->set_number('0613363')->is_valid_number, '北海道石狩市若生町');
ok($zip->set_number('0613365')->is_valid_number, '北海道石狩市親船東一条');
ok($zip->set_number('0613366')->is_valid_number, '北海道石狩市親船東二条');
ok($zip->set_number('0613367')->is_valid_number, '北海道石狩市親船東三条');
ok($zip->set_number('0613368')->is_valid_number, '北海道石狩市美登位');
ok($zip->set_number('0613371')->is_valid_number, '北海道石狩市浜町');
ok($zip->set_number('0613372')->is_valid_number, '北海道石狩市弁天町');
ok($zip->set_number('0613373')->is_valid_number, '北海道石狩市新町');
ok($zip->set_number('0613374')->is_valid_number, '北海道石狩市仲町');
ok($zip->set_number('0613375')->is_valid_number, '北海道石狩市本町');
ok($zip->set_number('0613376')->is_valid_number, '北海道石狩市横町');
ok($zip->set_number('0613377')->is_valid_number, '北海道石狩市親船町');
ok($zip->set_number('0613378')->is_valid_number, '北海道石狩市船場町');
ok($zip->set_number('0613441')->is_valid_number, '北海道石狩市厚田区聚富(その他)');
ok($zip->set_number('0613480')->is_valid_number, '北海道石狩市八幡町(五の沢)');
ok($zip->set_number('0613481')->is_valid_number, '北海道石狩市八幡町(高岡)');
ok($zip->set_number('0613482')->is_valid_number, '北海道石狩市八幡町(その他)');
ok($zip->set_number('0613483')->is_valid_number, '北海道石狩市緑ケ原');
ok($zip->set_number('0613484')->is_valid_number, '北海道石狩市八幡(5丁目1番地)');
ok($zip->set_number('0613521')->is_valid_number, '北海道石狩市厚田区古潭');
ok($zip->set_number('0613522')->is_valid_number, '北海道石狩市厚田区嶺泊');
ok($zip->set_number('0613523')->is_valid_number, '北海道石狩市厚田区望来');
ok($zip->set_number('0613601')->is_valid_number, '北海道石狩市厚田区厚田');
ok($zip->set_number('0613602')->is_valid_number, '北海道石狩市厚田区押琴');
ok($zip->set_number('0613603')->is_valid_number, '北海道石狩市厚田区小谷');
ok($zip->set_number('0613605')->is_valid_number, '北海道石狩市厚田区別狩');
ok($zip->set_number('0613606')->is_valid_number, '北海道石狩市厚田区安瀬');
ok($zip->set_number('0613771')->is_valid_number, '北海道石狩郡当別町高岡');
ok($zip->set_number('0613772')->is_valid_number, '北海道石狩郡当別町獅子内');
ok($zip->set_number('0613773')->is_valid_number, '北海道石狩郡当別町当別太');
ok($zip->set_number('0613774')->is_valid_number, '北海道石狩郡当別町川下(782-13、5363-7~8、5382-3、5405');
ok($zip->set_number('0613774')->is_valid_number, '北海道石狩郡当別町-4、5407-5、5445~5446-4番地)');
ok($zip->set_number('0613775')->is_valid_number, '北海道石狩郡当別町ビトエ(その他)');
ok($zip->set_number('0613776')->is_valid_number, '北海道石狩郡当別町太美町');
ok($zip->set_number('0613777')->is_valid_number, '北海道石狩郡当別町スウェーデンヒルズ');
ok($zip->set_number('0613778')->is_valid_number, '北海道石狩郡当別町太美南');
ok($zip->set_number('0613779')->is_valid_number, '北海道石狩郡当別町太美スターライト');
ok($zip->set_number('0620000')->is_valid_number, '北海道札幌市豊平区以下に掲載がない場合');
ok($zip->set_number('0620001')->is_valid_number, '北海道札幌市豊平区美園一条');
ok($zip->set_number('0620002')->is_valid_number, '北海道札幌市豊平区美園二条');
ok($zip->set_number('0620003')->is_valid_number, '北海道札幌市豊平区美園三条');
ok($zip->set_number('0620004')->is_valid_number, '北海道札幌市豊平区美園四条');
ok($zip->set_number('0620005')->is_valid_number, '北海道札幌市豊平区美園五条');
ok($zip->set_number('0620006')->is_valid_number, '北海道札幌市豊平区美園六条');
ok($zip->set_number('0620007')->is_valid_number, '北海道札幌市豊平区美園七条');
ok($zip->set_number('0620008')->is_valid_number, '北海道札幌市豊平区美園八条');
ok($zip->set_number('0620009')->is_valid_number, '北海道札幌市豊平区美園九条');
ok($zip->set_number('0620010')->is_valid_number, '北海道札幌市豊平区美園十条');
ok($zip->set_number('0620011')->is_valid_number, '北海道札幌市豊平区美園十一条');
ok($zip->set_number('0620012')->is_valid_number, '北海道札幌市豊平区美園十二条');
ok($zip->set_number('0620020')->is_valid_number, '北海道札幌市豊平区月寒中央通');
ok($zip->set_number('0620021')->is_valid_number, '北海道札幌市豊平区月寒西一条');
ok($zip->set_number('0620022')->is_valid_number, '北海道札幌市豊平区月寒西二条');
ok($zip->set_number('0620023')->is_valid_number, '北海道札幌市豊平区月寒西三条');
ok($zip->set_number('0620024')->is_valid_number, '北海道札幌市豊平区月寒西四条');
ok($zip->set_number('0620025')->is_valid_number, '北海道札幌市豊平区月寒西五条');
ok($zip->set_number('0620031')->is_valid_number, '北海道札幌市豊平区西岡一条');
ok($zip->set_number('0620032')->is_valid_number, '北海道札幌市豊平区西岡二条');
ok($zip->set_number('0620033')->is_valid_number, '北海道札幌市豊平区西岡三条');
ok($zip->set_number('0620034')->is_valid_number, '北海道札幌市豊平区西岡四条');
ok($zip->set_number('0620035')->is_valid_number, '北海道札幌市豊平区西岡五条');
ok($zip->set_number('0620039')->is_valid_number, '北海道札幌市豊平区西岡');
ok($zip->set_number('0620041')->is_valid_number, '北海道札幌市豊平区福住一条');
ok($zip->set_number('0620042')->is_valid_number, '北海道札幌市豊平区福住二条');
ok($zip->set_number('0620043')->is_valid_number, '北海道札幌市豊平区福住三条');
ok($zip->set_number('0620045')->is_valid_number, '北海道札幌市豊平区羊ケ丘');
ok($zip->set_number('0620051')->is_valid_number, '北海道札幌市豊平区月寒東一条');
ok($zip->set_number('0620052')->is_valid_number, '北海道札幌市豊平区月寒東二条');
ok($zip->set_number('0620053')->is_valid_number, '北海道札幌市豊平区月寒東三条');
ok($zip->set_number('0620054')->is_valid_number, '北海道札幌市豊平区月寒東四条');
ok($zip->set_number('0620055')->is_valid_number, '北海道札幌市豊平区月寒東五条');
ok($zip->set_number('0620901')->is_valid_number, '北海道札幌市豊平区豊平一条');
ok($zip->set_number('0620902')->is_valid_number, '北海道札幌市豊平区豊平二条');
ok($zip->set_number('0620903')->is_valid_number, '北海道札幌市豊平区豊平三条');
ok($zip->set_number('0620904')->is_valid_number, '北海道札幌市豊平区豊平四条');
ok($zip->set_number('0620905')->is_valid_number, '北海道札幌市豊平区豊平五条');
ok($zip->set_number('0620906')->is_valid_number, '北海道札幌市豊平区豊平六条');
ok($zip->set_number('0620907')->is_valid_number, '北海道札幌市豊平区豊平七条');
ok($zip->set_number('0620908')->is_valid_number, '北海道札幌市豊平区豊平八条');
ok($zip->set_number('0620909')->is_valid_number, '北海道札幌市豊平区豊平九条');
ok($zip->set_number('0620911')->is_valid_number, '北海道札幌市豊平区旭町');
ok($zip->set_number('0620912')->is_valid_number, '北海道札幌市豊平区水車町');
ok($zip->set_number('0620921')->is_valid_number, '北海道札幌市豊平区中の島一条');
ok($zip->set_number('0620922')->is_valid_number, '北海道札幌市豊平区中の島二条');
ok($zip->set_number('0620931')->is_valid_number, '北海道札幌市豊平区平岸一条');
ok($zip->set_number('0620932')->is_valid_number, '北海道札幌市豊平区平岸二条');
ok($zip->set_number('0620933')->is_valid_number, '北海道札幌市豊平区平岸三条');
ok($zip->set_number('0620934')->is_valid_number, '北海道札幌市豊平区平岸四条');
ok($zip->set_number('0620935')->is_valid_number, '北海道札幌市豊平区平岸五条');
ok($zip->set_number('0620936')->is_valid_number, '北海道札幌市豊平区平岸六条');
ok($zip->set_number('0620937')->is_valid_number, '北海道札幌市豊平区平岸七条');
ok($zip->set_number('0620938')->is_valid_number, '北海道札幌市豊平区平岸八条');
ok($zip->set_number('0630000')->is_valid_number, '北海道札幌市西区以下に掲載がない場合');
ok($zip->set_number('0630001')->is_valid_number, '北海道札幌市西区山の手一条');
ok($zip->set_number('0630002')->is_valid_number, '北海道札幌市西区山の手二条');
ok($zip->set_number('0630003')->is_valid_number, '北海道札幌市西区山の手三条');
ok($zip->set_number('0630004')->is_valid_number, '北海道札幌市西区山の手四条');
ok($zip->set_number('0630005')->is_valid_number, '北海道札幌市西区山の手五条');
ok($zip->set_number('0630006')->is_valid_number, '北海道札幌市西区山の手六条');
ok($zip->set_number('0630007')->is_valid_number, '北海道札幌市西区山の手七条');
ok($zip->set_number('0630009')->is_valid_number, '北海道札幌市西区山の手');
ok($zip->set_number('0630011')->is_valid_number, '北海道札幌市西区小別沢');
ok($zip->set_number('0630012')->is_valid_number, '北海道札幌市西区福井');
ok($zip->set_number('0630021')->is_valid_number, '北海道札幌市西区平和一条');
ok($zip->set_number('0630022')->is_valid_number, '北海道札幌市西区平和二条');
ok($zip->set_number('0630023')->is_valid_number, '北海道札幌市西区平和三条');
ok($zip->set_number('0630029')->is_valid_number, '北海道札幌市西区平和');
ok($zip->set_number('0630031')->is_valid_number, '北海道札幌市西区西野一条');
ok($zip->set_number('0630032')->is_valid_number, '北海道札幌市西区西野二条');
ok($zip->set_number('0630033')->is_valid_number, '北海道札幌市西区西野三条');
ok($zip->set_number('0630034')->is_valid_number, '北海道札幌市西区西野四条');
ok($zip->set_number('0630035')->is_valid_number, '北海道札幌市西区西野五条');
ok($zip->set_number('0630036')->is_valid_number, '北海道札幌市西区西野六条');
ok($zip->set_number('0630037')->is_valid_number, '北海道札幌市西区西野七条');
ok($zip->set_number('0630038')->is_valid_number, '北海道札幌市西区西野八条');
ok($zip->set_number('0630039')->is_valid_number, '北海道札幌市西区西野九条');
ok($zip->set_number('0630040')->is_valid_number, '北海道札幌市西区西野十条');
ok($zip->set_number('0630041')->is_valid_number, '北海道札幌市西区西野十一条');
ok($zip->set_number('0630042')->is_valid_number, '北海道札幌市西区西野十二条');
ok($zip->set_number('0630043')->is_valid_number, '北海道札幌市西区西野十三条');
ok($zip->set_number('0630044')->is_valid_number, '北海道札幌市西区西野十四条');
ok($zip->set_number('0630049')->is_valid_number, '北海道札幌市西区西野');
ok($zip->set_number('0630051')->is_valid_number, '北海道札幌市西区宮の沢一条');
ok($zip->set_number('0630052')->is_valid_number, '北海道札幌市西区宮の沢二条');
ok($zip->set_number('0630053')->is_valid_number, '北海道札幌市西区宮の沢三条');
ok($zip->set_number('0630054')->is_valid_number, '北海道札幌市西区宮の沢四条');
ok($zip->set_number('0630059')->is_valid_number, '北海道札幌市西区宮の沢');
ok($zip->set_number('0630061')->is_valid_number, '北海道札幌市西区西町北');
ok($zip->set_number('0630062')->is_valid_number, '北海道札幌市西区西町南');
ok($zip->set_number('0630801')->is_valid_number, '北海道札幌市西区二十四軒一条');
ok($zip->set_number('0630802')->is_valid_number, '北海道札幌市西区二十四軒二条');
ok($zip->set_number('0630803')->is_valid_number, '北海道札幌市西区二十四軒三条');
ok($zip->set_number('0630804')->is_valid_number, '北海道札幌市西区二十四軒四条');
ok($zip->set_number('0630811')->is_valid_number, '北海道札幌市西区琴似一条');
ok($zip->set_number('0630812')->is_valid_number, '北海道札幌市西区琴似二条');
ok($zip->set_number('0630813')->is_valid_number, '北海道札幌市西区琴似三条');
ok($zip->set_number('0630814')->is_valid_number, '北海道札幌市西区琴似四条');
ok($zip->set_number('0630821')->is_valid_number, '北海道札幌市西区発寒一条');
ok($zip->set_number('0630822')->is_valid_number, '北海道札幌市西区発寒二条');
ok($zip->set_number('0630823')->is_valid_number, '北海道札幌市西区発寒三条');
ok($zip->set_number('0630824')->is_valid_number, '北海道札幌市西区発寒四条');
ok($zip->set_number('0630825')->is_valid_number, '北海道札幌市西区発寒五条');
ok($zip->set_number('0630826')->is_valid_number, '北海道札幌市西区発寒六条');
ok($zip->set_number('0630827')->is_valid_number, '北海道札幌市西区発寒七条');
ok($zip->set_number('0630828')->is_valid_number, '北海道札幌市西区発寒八条');
ok($zip->set_number('0630829')->is_valid_number, '北海道札幌市西区発寒九条');
ok($zip->set_number('0630830')->is_valid_number, '北海道札幌市西区発寒十条');
ok($zip->set_number('0630831')->is_valid_number, '北海道札幌市西区発寒十一条');
ok($zip->set_number('0630832')->is_valid_number, '北海道札幌市西区発寒十二条');
ok($zip->set_number('0630833')->is_valid_number, '北海道札幌市西区発寒十三条');
ok($zip->set_number('0630834')->is_valid_number, '北海道札幌市西区発寒十四条');
ok($zip->set_number('0630835')->is_valid_number, '北海道札幌市西区発寒十五条');
ok($zip->set_number('0630836')->is_valid_number, '北海道札幌市西区発寒十六条');
ok($zip->set_number('0630837')->is_valid_number, '北海道札幌市西区発寒十七条');
ok($zip->set_number('0630841')->is_valid_number, '北海道札幌市西区八軒一条西');
ok($zip->set_number('0630842')->is_valid_number, '北海道札幌市西区八軒二条西');
ok($zip->set_number('0630843')->is_valid_number, '北海道札幌市西区八軒三条西');
ok($zip->set_number('0630844')->is_valid_number, '北海道札幌市西区八軒四条西');
ok($zip->set_number('0630845')->is_valid_number, '北海道札幌市西区八軒五条西');
ok($zip->set_number('0630846')->is_valid_number, '北海道札幌市西区八軒六条西');
ok($zip->set_number('0630847')->is_valid_number, '北海道札幌市西区八軒七条西');
ok($zip->set_number('0630848')->is_valid_number, '北海道札幌市西区八軒八条西');
ok($zip->set_number('0630849')->is_valid_number, '北海道札幌市西区八軒九条西');
ok($zip->set_number('0630850')->is_valid_number, '北海道札幌市西区八軒十条西');
ok($zip->set_number('0630861')->is_valid_number, '北海道札幌市西区八軒一条東');
ok($zip->set_number('0630862')->is_valid_number, '北海道札幌市西区八軒二条東');
ok($zip->set_number('0630863')->is_valid_number, '北海道札幌市西区八軒三条東');
ok($zip->set_number('0630864')->is_valid_number, '北海道札幌市西区八軒四条東');
ok($zip->set_number('0630865')->is_valid_number, '北海道札幌市西区八軒五条東');
ok($zip->set_number('0630866')->is_valid_number, '北海道札幌市西区八軒六条東');
ok($zip->set_number('0630867')->is_valid_number, '北海道札幌市西区八軒七条東');
ok($zip->set_number('0630868')->is_valid_number, '北海道札幌市西区八軒八条東');
ok($zip->set_number('0630869')->is_valid_number, '北海道札幌市西区八軒九条東');
ok($zip->set_number('0630870')->is_valid_number, '北海道札幌市西区八軒十条東');
ok($zip->set_number('0640801')->is_valid_number, '北海道札幌市中央区南一条西(20~28丁目)');
ok($zip->set_number('0640802')->is_valid_number, '北海道札幌市中央区南二条西(20~28丁目)');
ok($zip->set_number('0640803')->is_valid_number, '北海道札幌市中央区南三条西(20~28丁目)');
ok($zip->set_number('0640804')->is_valid_number, '北海道札幌市中央区南四条西');
ok($zip->set_number('0640805')->is_valid_number, '北海道札幌市中央区南五条西');
ok($zip->set_number('0640806')->is_valid_number, '北海道札幌市中央区南六条西');
ok($zip->set_number('0640807')->is_valid_number, '北海道札幌市中央区南七条西');
ok($zip->set_number('0640808')->is_valid_number, '北海道札幌市中央区南八条西');
ok($zip->set_number('0640809')->is_valid_number, '北海道札幌市中央区南九条西');
ok($zip->set_number('0640810')->is_valid_number, '北海道札幌市中央区南十条西');
ok($zip->set_number('0640811')->is_valid_number, '北海道札幌市中央区南十一条西');
ok($zip->set_number('0640820')->is_valid_number, '北海道札幌市中央区大通西(20~28丁目)');
ok($zip->set_number('0640821')->is_valid_number, '北海道札幌市中央区北一条西(20~28丁目)');
ok($zip->set_number('0640822')->is_valid_number, '北海道札幌市中央区北二条西(20~28丁目)');
ok($zip->set_number('0640823')->is_valid_number, '北海道札幌市中央区北三条西(20~30丁目)');
ok($zip->set_number('0640824')->is_valid_number, '北海道札幌市中央区北四条西(20~30丁目)');
ok($zip->set_number('0640825')->is_valid_number, '北海道札幌市中央区北五条西(25~29丁目)');
ok($zip->set_number('0640826')->is_valid_number, '北海道札幌市中央区北六条西(26~28丁目)');
ok($zip->set_number('0640912')->is_valid_number, '北海道札幌市中央区南十二条西');
ok($zip->set_number('0640913')->is_valid_number, '北海道札幌市中央区南十三条西');
ok($zip->set_number('0640914')->is_valid_number, '北海道札幌市中央区南十四条西');
ok($zip->set_number('0640915')->is_valid_number, '北海道札幌市中央区南十五条西');
ok($zip->set_number('0640916')->is_valid_number, '北海道札幌市中央区南十六条西');
ok($zip->set_number('0640917')->is_valid_number, '北海道札幌市中央区南十七条西');
ok($zip->set_number('0640918')->is_valid_number, '北海道札幌市中央区南十八条西');
ok($zip->set_number('0640919')->is_valid_number, '北海道札幌市中央区南十九条西');
ok($zip->set_number('0640920')->is_valid_number, '北海道札幌市中央区南二十条西');
ok($zip->set_number('0640921')->is_valid_number, '北海道札幌市中央区南二十一条西');
ok($zip->set_number('0640922')->is_valid_number, '北海道札幌市中央区南二十二条西');
ok($zip->set_number('0640923')->is_valid_number, '北海道札幌市中央区南二十三条西');
ok($zip->set_number('0640924')->is_valid_number, '北海道札幌市中央区南二十四条西');
ok($zip->set_number('0640925')->is_valid_number, '北海道札幌市中央区南二十五条西');
ok($zip->set_number('0640926')->is_valid_number, '北海道札幌市中央区南二十六条西');
ok($zip->set_number('0640927')->is_valid_number, '北海道札幌市中央区南二十七条西');
ok($zip->set_number('0640928')->is_valid_number, '北海道札幌市中央区南二十八条西');
ok($zip->set_number('0640929')->is_valid_number, '北海道札幌市中央区南二十九条西');
ok($zip->set_number('0640930')->is_valid_number, '北海道札幌市中央区南三十条西(9~11丁目)');
ok($zip->set_number('0640931')->is_valid_number, '北海道札幌市中央区中島公園');
ok($zip->set_number('0640941')->is_valid_number, '北海道札幌市中央区旭ケ丘');
ok($zip->set_number('0640942')->is_valid_number, '北海道札幌市中央区伏見');
ok($zip->set_number('0640943')->is_valid_number, '北海道札幌市中央区界川');
ok($zip->set_number('0640944')->is_valid_number, '北海道札幌市中央区円山西町');
ok($zip->set_number('0640945')->is_valid_number, '北海道札幌市中央区盤渓');
ok($zip->set_number('0640946')->is_valid_number, '北海道札幌市中央区双子山');
ok($zip->set_number('0640951')->is_valid_number, '北海道札幌市中央区宮の森一条');
ok($zip->set_number('0640952')->is_valid_number, '北海道札幌市中央区宮の森二条');
ok($zip->set_number('0640953')->is_valid_number, '北海道札幌市中央区宮の森三条');
ok($zip->set_number('0640954')->is_valid_number, '北海道札幌市中央区宮の森四条');
ok($zip->set_number('0640958')->is_valid_number, '北海道札幌市中央区宮の森');
ok($zip->set_number('0640959')->is_valid_number, '北海道札幌市中央区宮ケ丘');
ok($zip->set_number('0650000')->is_valid_number, '北海道札幌市東区以下に掲載がない場合');
ok($zip->set_number('0650004')->is_valid_number, '北海道札幌市東区北四条東(9~16丁目)');
ok($zip->set_number('0650005')->is_valid_number, '北海道札幌市東区北五条東(8~17丁目)');
ok($zip->set_number('0650006')->is_valid_number, '北海道札幌市東区北六条東(8~20丁目)');
ok($zip->set_number('0650007')->is_valid_number, '北海道札幌市東区北七条東(8~20丁目)');
ok($zip->set_number('0650008')->is_valid_number, '北海道札幌市東区北八条東(8~19丁目)');
ok($zip->set_number('0650009')->is_valid_number, '北海道札幌市東区北九条東(8~16丁目)');
ok($zip->set_number('0650010')->is_valid_number, '北海道札幌市東区北十条東');
ok($zip->set_number('0650011')->is_valid_number, '北海道札幌市東区北十一条東');
ok($zip->set_number('0650012')->is_valid_number, '北海道札幌市東区北十二条東');
ok($zip->set_number('0650013')->is_valid_number, '北海道札幌市東区北十三条東');
ok($zip->set_number('0650014')->is_valid_number, '北海道札幌市東区北十四条東');
ok($zip->set_number('0650015')->is_valid_number, '北海道札幌市東区北十五条東');
ok($zip->set_number('0650016')->is_valid_number, '北海道札幌市東区北十六条東');
ok($zip->set_number('0650017')->is_valid_number, '北海道札幌市東区北十七条東');
ok($zip->set_number('0650018')->is_valid_number, '北海道札幌市東区北十八条東');
ok($zip->set_number('0650019')->is_valid_number, '北海道札幌市東区北十九条東');
ok($zip->set_number('0650020')->is_valid_number, '北海道札幌市東区北二十条東');
ok($zip->set_number('0650021')->is_valid_number, '北海道札幌市東区北二十一条東');
ok($zip->set_number('0650022')->is_valid_number, '北海道札幌市東区北二十二条東');
ok($zip->set_number('0650023')->is_valid_number, '北海道札幌市東区北二十三条東');
ok($zip->set_number('0650024')->is_valid_number, '北海道札幌市東区北二十四条東');
ok($zip->set_number('0650025')->is_valid_number, '北海道札幌市東区北二十五条東');
ok($zip->set_number('0650026')->is_valid_number, '北海道札幌市東区北二十六条東');
ok($zip->set_number('0650027')->is_valid_number, '北海道札幌市東区北二十七条東');
ok($zip->set_number('0650028')->is_valid_number, '北海道札幌市東区北二十八条東');
ok($zip->set_number('0650030')->is_valid_number, '北海道札幌市東区北三十条東');
ok($zip->set_number('0650031')->is_valid_number, '北海道札幌市東区北三十一条東');
ok($zip->set_number('0650032')->is_valid_number, '北海道札幌市東区北三十二条東');
ok($zip->set_number('0650033')->is_valid_number, '北海道札幌市東区北三十三条東');
ok($zip->set_number('0650041')->is_valid_number, '北海道札幌市東区本町一条');
ok($zip->set_number('0650042')->is_valid_number, '北海道札幌市東区本町二条');
ok($zip->set_number('0650043')->is_valid_number, '北海道札幌市東区苗穂町');
ok($zip->set_number('0660000')->is_valid_number, '北海道千歳市以下に掲載がない場合');
ok($zip->set_number('0660001')->is_valid_number, '北海道千歳市長都');
ok($zip->set_number('0660002')->is_valid_number, '北海道千歳市釜加');
ok($zip->set_number('0660003')->is_valid_number, '北海道千歳市都');
ok($zip->set_number('0660004')->is_valid_number, '北海道千歳市泉郷');
ok($zip->set_number('0660005')->is_valid_number, '北海道千歳市協和(88-2、271-10、343-2、404-1、427-');
ok($zip->set_number('0660005')->is_valid_number, '北海道千歳市3、431-12、443-6、608-2、641-8、814、842-');
ok($zip->set_number('0660005')->is_valid_number, '北海道千歳市5、1137-3、1392、1657、1752番地)');
ok($zip->set_number('0660006')->is_valid_number, '北海道千歳市祝梅');
ok($zip->set_number('0660007')->is_valid_number, '北海道千歳市中央');
ok($zip->set_number('0660008')->is_valid_number, '北海道千歳市根志越');
ok($zip->set_number('0660009')->is_valid_number, '北海道千歳市柏台南');
ok($zip->set_number('0660011')->is_valid_number, '北海道千歳市駒里');
ok($zip->set_number('0660012')->is_valid_number, '北海道千歳市美々');
ok($zip->set_number('0660013')->is_valid_number, '北海道千歳市柏台');
ok($zip->set_number('0660014')->is_valid_number, '北海道千歳市青葉丘');
ok($zip->set_number('0660015')->is_valid_number, '北海道千歳市青葉');
ok($zip->set_number('0660016')->is_valid_number, '北海道千歳市日の出丘');
ok($zip->set_number('0660017')->is_valid_number, '北海道千歳市日の出');
ok($zip->set_number('0660018')->is_valid_number, '北海道千歳市旭ケ丘');
ok($zip->set_number('0660019')->is_valid_number, '北海道千歳市流通');
ok($zip->set_number('0660021')->is_valid_number, '北海道千歳市東郊');
ok($zip->set_number('0660022')->is_valid_number, '北海道千歳市豊里');
ok($zip->set_number('0660023')->is_valid_number, '北海道千歳市寿');
ok($zip->set_number('0660024')->is_valid_number, '北海道千歳市弥生');
ok($zip->set_number('0660025')->is_valid_number, '北海道千歳市梅ケ丘');
ok($zip->set_number('0660026')->is_valid_number, '北海道千歳市住吉');
ok($zip->set_number('0660027')->is_valid_number, '北海道千歳市末広');
ok($zip->set_number('0660028')->is_valid_number, '北海道千歳市花園');
ok($zip->set_number('0660029')->is_valid_number, '北海道千歳市稲穂');
ok($zip->set_number('0660031')->is_valid_number, '北海道千歳市長都駅前');
ok($zip->set_number('0660032')->is_valid_number, '北海道千歳市北陽');
ok($zip->set_number('0660033')->is_valid_number, '北海道千歳市北光');
ok($zip->set_number('0660034')->is_valid_number, '北海道千歳市富丘');
ok($zip->set_number('0660035')->is_valid_number, '北海道千歳市高台');
ok($zip->set_number('0660036')->is_valid_number, '北海道千歳市北栄');
ok($zip->set_number('0660037')->is_valid_number, '北海道千歳市新富');
ok($zip->set_number('0660038')->is_valid_number, '北海道千歳市信濃');
ok($zip->set_number('0660039')->is_valid_number, '北海道千歳市富士');
ok($zip->set_number('0660041')->is_valid_number, '北海道千歳市清水町');
ok($zip->set_number('0660042')->is_valid_number, '北海道千歳市東雲町');
ok($zip->set_number('0660043')->is_valid_number, '北海道千歳市朝日町');
ok($zip->set_number('0660044')->is_valid_number, '北海道千歳市平和');
ok($zip->set_number('0660045')->is_valid_number, '北海道千歳市真々地');
ok($zip->set_number('0660046')->is_valid_number, '北海道千歳市真町');
ok($zip->set_number('0660047')->is_valid_number, '北海道千歳市本町');
ok($zip->set_number('0660051')->is_valid_number, '北海道千歳市泉沢');
ok($zip->set_number('0660052')->is_valid_number, '北海道千歳市文京');
ok($zip->set_number('0660053')->is_valid_number, '北海道千歳市福住');
ok($zip->set_number('0660054')->is_valid_number, '北海道千歳市柏陽');
ok($zip->set_number('0660055')->is_valid_number, '北海道千歳市里美');
ok($zip->set_number('0660056')->is_valid_number, '北海道千歳市白樺');
ok($zip->set_number('0660057')->is_valid_number, '北海道千歳市若草');
ok($zip->set_number('0660061')->is_valid_number, '北海道千歳市栄町');
ok($zip->set_number('0660062')->is_valid_number, '北海道千歳市千代田町');
ok($zip->set_number('0660063')->is_valid_number, '北海道千歳市幸町');
ok($zip->set_number('0660064')->is_valid_number, '北海道千歳市錦町');
ok($zip->set_number('0660065')->is_valid_number, '北海道千歳市春日町');
ok($zip->set_number('0660066')->is_valid_number, '北海道千歳市大和');
ok($zip->set_number('0660067')->is_valid_number, '北海道千歳市桂木');
ok($zip->set_number('0660068')->is_valid_number, '北海道千歳市蘭越');
ok($zip->set_number('0660069')->is_valid_number, '北海道千歳市新星');
ok($zip->set_number('0660071')->is_valid_number, '北海道千歳市桜木');
ok($zip->set_number('0660072')->is_valid_number, '北海道千歳市自由ケ丘');
ok($zip->set_number('0660073')->is_valid_number, '北海道千歳市北斗');
ok($zip->set_number('0660074')->is_valid_number, '北海道千歳市緑町');
ok($zip->set_number('0660075')->is_valid_number, '北海道千歳市北信濃');
ok($zip->set_number('0660076')->is_valid_number, '北海道千歳市あずさ');
ok($zip->set_number('0660077')->is_valid_number, '北海道千歳市上長都');
ok($zip->set_number('0660078')->is_valid_number, '北海道千歳市勇舞');
ok($zip->set_number('0660081')->is_valid_number, '北海道千歳市清流');
ok($zip->set_number('0660082')->is_valid_number, '北海道千歳市幸福');
ok($zip->set_number('0660083')->is_valid_number, '北海道千歳市みどり台北');
ok($zip->set_number('0660084')->is_valid_number, '北海道千歳市みどり台南');
ok($zip->set_number('0660271')->is_valid_number, '北海道苫小牧市丸山');
ok($zip->set_number('0660281')->is_valid_number, '北海道千歳市支笏湖温泉');
ok($zip->set_number('0660282')->is_valid_number, '北海道千歳市水明郷');
ok($zip->set_number('0660283')->is_valid_number, '北海道千歳市モラップ');
ok($zip->set_number('0660284')->is_valid_number, '北海道千歳市支寒内');
ok($zip->set_number('0660285')->is_valid_number, '北海道千歳市美笛');
ok($zip->set_number('0660286')->is_valid_number, '北海道千歳市奥潭');
ok($zip->set_number('0660287')->is_valid_number, '北海道千歳市幌美内');
ok($zip->set_number('0670000')->is_valid_number, '北海道江別市以下に掲載がない場合');
ok($zip->set_number('0670001')->is_valid_number, '北海道江別市王子');
ok($zip->set_number('0670002')->is_valid_number, '北海道江別市緑町西');
ok($zip->set_number('0670003')->is_valid_number, '北海道江別市緑町東');
ok($zip->set_number('0670004')->is_valid_number, '北海道江別市若草町');
ok($zip->set_number('0670005')->is_valid_number, '北海道江別市牧場町');
ok($zip->set_number('0670011')->is_valid_number, '北海道江別市1条');
ok($zip->set_number('0670012')->is_valid_number, '北海道江別市2条');
ok($zip->set_number('0670013')->is_valid_number, '北海道江別市3条');
ok($zip->set_number('0670014')->is_valid_number, '北海道江別市4条');
ok($zip->set_number('0670015')->is_valid_number, '北海道江別市5条');
ok($zip->set_number('0670016')->is_valid_number, '北海道江別市6条');
ok($zip->set_number('0670017')->is_valid_number, '北海道江別市7条');
ok($zip->set_number('0670018')->is_valid_number, '北海道江別市8条');
ok($zip->set_number('0670021')->is_valid_number, '北海道江別市豊幌');
ok($zip->set_number('0670022')->is_valid_number, '北海道江別市江別太');
ok($zip->set_number('0670023')->is_valid_number, '北海道江別市東光町');
ok($zip->set_number('0670024')->is_valid_number, '北海道江別市朝日町');
ok($zip->set_number('0670025')->is_valid_number, '北海道江別市あけぼの町');
ok($zip->set_number('0670026')->is_valid_number, '北海道江別市豊幌花園町');
ok($zip->set_number('0670027')->is_valid_number, '北海道江別市豊幌美咲町');
ok($zip->set_number('0670028')->is_valid_number, '北海道江別市豊幌はみんぐ町');
ok($zip->set_number('0670031')->is_valid_number, '北海道江別市元町');
ok($zip->set_number('0670032')->is_valid_number, '北海道江別市元江別');
ok($zip->set_number('0670033')->is_valid_number, '北海道江別市対雁');
ok($zip->set_number('0670034')->is_valid_number, '北海道江別市いずみ野');
ok($zip->set_number('0670041')->is_valid_number, '北海道江別市元江別本町');
ok($zip->set_number('0670042')->is_valid_number, '北海道江別市見晴台');
ok($zip->set_number('0670051')->is_valid_number, '北海道江別市工栄町');
ok($zip->set_number('0670052')->is_valid_number, '北海道江別市角山');
ok($zip->set_number('0670053')->is_valid_number, '北海道江別市中島');
ok($zip->set_number('0670054')->is_valid_number, '北海道江別市八幡');
ok($zip->set_number('0670055')->is_valid_number, '北海道江別市篠津');
ok($zip->set_number('0670056')->is_valid_number, '北海道江別市美原');
ok($zip->set_number('0670057')->is_valid_number, '北海道江別市萌えぎ野東');
ok($zip->set_number('0670058')->is_valid_number, '北海道江別市萌えぎ野中央');
ok($zip->set_number('0670059')->is_valid_number, '北海道江別市萌えぎ野西');
ok($zip->set_number('0670061')->is_valid_number, '北海道江別市上江別東町');
ok($zip->set_number('0670062')->is_valid_number, '北海道江別市上江別南町');
ok($zip->set_number('0670063')->is_valid_number, '北海道江別市上江別西町');
ok($zip->set_number('0670064')->is_valid_number, '北海道江別市上江別');
ok($zip->set_number('0670065')->is_valid_number, '北海道江別市ゆめみ野東町');
ok($zip->set_number('0670066')->is_valid_number, '北海道江別市ゆめみ野南町');
ok($zip->set_number('0670071')->is_valid_number, '北海道江別市萩ケ岡');
ok($zip->set_number('0670072')->is_valid_number, '北海道江別市一番町');
ok($zip->set_number('0670073')->is_valid_number, '北海道江別市弥生町');
ok($zip->set_number('0670074')->is_valid_number, '北海道江別市高砂町');
ok($zip->set_number('0670075')->is_valid_number, '北海道江別市向ケ丘');
ok($zip->set_number('0680000')->is_valid_number, '北海道岩見沢市以下に掲載がない場合');
ok($zip->set_number('0680001')->is_valid_number, '北海道岩見沢市一条東');
ok($zip->set_number('0680002')->is_valid_number, '北海道岩見沢市二条東');
ok($zip->set_number('0680003')->is_valid_number, '北海道岩見沢市三条東');
ok($zip->set_number('0680004')->is_valid_number, '北海道岩見沢市四条東');
ok($zip->set_number('0680005')->is_valid_number, '北海道岩見沢市五条東');
ok($zip->set_number('0680006')->is_valid_number, '北海道岩見沢市六条東');
ok($zip->set_number('0680007')->is_valid_number, '北海道岩見沢市七条東');
ok($zip->set_number('0680008')->is_valid_number, '北海道岩見沢市八条東');
ok($zip->set_number('0680009')->is_valid_number, '北海道岩見沢市九条東');
ok($zip->set_number('0680010')->is_valid_number, '北海道岩見沢市十条東');
ok($zip->set_number('0680011')->is_valid_number, '北海道岩見沢市十一条東');
ok($zip->set_number('0680012')->is_valid_number, '北海道岩見沢市十二条東');
ok($zip->set_number('0680013')->is_valid_number, '北海道岩見沢市東町一条');
ok($zip->set_number('0680014')->is_valid_number, '北海道岩見沢市東町二条');
ok($zip->set_number('0680015')->is_valid_number, '北海道岩見沢市東町');
ok($zip->set_number('0680016')->is_valid_number, '北海道岩見沢市稔町');
ok($zip->set_number('0680021')->is_valid_number, '北海道岩見沢市一条西');
ok($zip->set_number('0680022')->is_valid_number, '北海道岩見沢市二条西');
ok($zip->set_number('0680023')->is_valid_number, '北海道岩見沢市三条西');
ok($zip->set_number('0680024')->is_valid_number, '北海道岩見沢市四条西');
ok($zip->set_number('0680025')->is_valid_number, '北海道岩見沢市五条西');
ok($zip->set_number('0680026')->is_valid_number, '北海道岩見沢市六条西');
ok($zip->set_number('0680027')->is_valid_number, '北海道岩見沢市七条西');
ok($zip->set_number('0680028')->is_valid_number, '北海道岩見沢市八条西');
ok($zip->set_number('0680029')->is_valid_number, '北海道岩見沢市九条西');
ok($zip->set_number('0680030')->is_valid_number, '北海道岩見沢市十条西');
ok($zip->set_number('0680031')->is_valid_number, '北海道岩見沢市十一条西');
ok($zip->set_number('0680032')->is_valid_number, '北海道岩見沢市十二条西');
ok($zip->set_number('0680033')->is_valid_number, '北海道岩見沢市十三条西');
ok($zip->set_number('0680034')->is_valid_number, '北海道岩見沢市有明町南');
ok($zip->set_number('0680035')->is_valid_number, '北海道岩見沢市有明町中央');
ok($zip->set_number('0680041')->is_valid_number, '北海道岩見沢市北一条西');
ok($zip->set_number('0680042')->is_valid_number, '北海道岩見沢市北二条西');
ok($zip->set_number('0680043')->is_valid_number, '北海道岩見沢市北三条西');
ok($zip->set_number('0680044')->is_valid_number, '北海道岩見沢市北四条西');
ok($zip->set_number('0680045')->is_valid_number, '北海道岩見沢市北五条西');
ok($zip->set_number('0680046')->is_valid_number, '北海道岩見沢市緑町');
ok($zip->set_number('0680047')->is_valid_number, '北海道岩見沢市若松町');
ok($zip->set_number('0680048')->is_valid_number, '北海道岩見沢市西川町');
ok($zip->set_number('0680051')->is_valid_number, '北海道岩見沢市元町一条西');
ok($zip->set_number('0680052')->is_valid_number, '北海道岩見沢市元町二条西');
ok($zip->set_number('0680053')->is_valid_number, '北海道岩見沢市北本町西');
ok($zip->set_number('0680054')->is_valid_number, '北海道岩見沢市元町一条東');
ok($zip->set_number('0680055')->is_valid_number, '北海道岩見沢市元町二条東');
ok($zip->set_number('0680056')->is_valid_number, '北海道岩見沢市元町三条東');
ok($zip->set_number('0680057')->is_valid_number, '北海道岩見沢市北本町東');
ok($zip->set_number('0680058')->is_valid_number, '北海道岩見沢市桜木一条');
ok($zip->set_number('0680061')->is_valid_number, '北海道岩見沢市北六条西');
ok($zip->set_number('0680101')->is_valid_number, '北海道岩見沢市栗沢町北斗');
ok($zip->set_number('0680102')->is_valid_number, '北海道岩見沢市栗沢町栗部');
ok($zip->set_number('0680103')->is_valid_number, '北海道岩見沢市栗沢町砺波');
ok($zip->set_number('0680104')->is_valid_number, '北海道岩見沢市栗沢町耕成');
ok($zip->set_number('0680105')->is_valid_number, '北海道岩見沢市栗沢町自協');
ok($zip->set_number('0680106')->is_valid_number, '北海道岩見沢市栗沢町越前');
ok($zip->set_number('0680111')->is_valid_number, '北海道岩見沢市栗沢町由良');
ok($zip->set_number('0680112')->is_valid_number, '北海道岩見沢市栗沢町上幌');
ok($zip->set_number('0680113')->is_valid_number, '北海道岩見沢市栗沢町宮村(その他)');
ok($zip->set_number('0680114')->is_valid_number, '北海道岩見沢市栗沢町茂世丑');
ok($zip->set_number('0680115')->is_valid_number, '北海道岩見沢市栗沢町最上');
ok($zip->set_number('0680121')->is_valid_number, '北海道岩見沢市栗沢町北本町');
ok($zip->set_number('0680122')->is_valid_number, '北海道岩見沢市栗沢町北幸穂');
ok($zip->set_number('0680123')->is_valid_number, '北海道岩見沢市栗沢町東本町');
ok($zip->set_number('0680124')->is_valid_number, '北海道岩見沢市栗沢町幸穂町');
ok($zip->set_number('0680125')->is_valid_number, '北海道岩見沢市栗沢町南本町');
ok($zip->set_number('0680126')->is_valid_number, '北海道岩見沢市栗沢町西本町');
ok($zip->set_number('0680127')->is_valid_number, '北海道岩見沢市栗沢町本町');
ok($zip->set_number('0680131')->is_valid_number, '北海道岩見沢市栗沢町小西');
ok($zip->set_number('0680132')->is_valid_number, '北海道岩見沢市栗沢町南幸穂');
ok($zip->set_number('0680133')->is_valid_number, '北海道岩見沢市栗沢町加茂川');
ok($zip->set_number('0680134')->is_valid_number, '北海道岩見沢市栗沢町栗丘');
ok($zip->set_number('0680135')->is_valid_number, '北海道岩見沢市栗沢町岐阜');
ok($zip->set_number('0680136')->is_valid_number, '北海道岩見沢市栗沢町必成');
ok($zip->set_number('0680351')->is_valid_number, '北海道夕張郡栗山町阿野呂');
ok($zip->set_number('0680352')->is_valid_number, '北海道夕張郡栗山町大井分');
ok($zip->set_number('0680353')->is_valid_number, '北海道夕張郡栗山町継立');
ok($zip->set_number('0680354')->is_valid_number, '北海道夕張郡栗山町日出');
ok($zip->set_number('0680355')->is_valid_number, '北海道夕張郡栗山町御園');
ok($zip->set_number('0680356')->is_valid_number, '北海道夕張郡栗山町南角田');
ok($zip->set_number('0680357')->is_valid_number, '北海道夕張郡栗山町南学田');
ok($zip->set_number('0680358')->is_valid_number, '北海道夕張郡栗山町桜山(200、269番地)');
ok($zip->set_number('0680361')->is_valid_number, '北海道夕張郡栗山町滝下');
ok($zip->set_number('0680362')->is_valid_number, '北海道夕張郡栗山町円山');
ok($zip->set_number('0680363')->is_valid_number, '北海道夕張郡栗山町円山東山');
ok($zip->set_number('0680400')->is_valid_number, '北海道夕張市以下に掲載がない場合');
ok($zip->set_number('0680401')->is_valid_number, '北海道夕張市高松');
ok($zip->set_number('0680402')->is_valid_number, '北海道夕張市社光');
ok($zip->set_number('0680403')->is_valid_number, '北海道夕張市本町');
ok($zip->set_number('0680404')->is_valid_number, '北海道夕張市昭和');
ok($zip->set_number('0680405')->is_valid_number, '北海道夕張市旭町');
ok($zip->set_number('0680406')->is_valid_number, '北海道夕張市住初');
ok($zip->set_number('0680407')->is_valid_number, '北海道夕張市福住');
ok($zip->set_number('0680408')->is_valid_number, '北海道夕張市富岡');
ok($zip->set_number('0680409')->is_valid_number, '北海道夕張市丁未');
ok($zip->set_number('0680411')->is_valid_number, '北海道夕張市末広');
ok($zip->set_number('0680412')->is_valid_number, '北海道夕張市鹿の谷東丘町');
ok($zip->set_number('0680413')->is_valid_number, '北海道夕張市鹿の谷');
ok($zip->set_number('0680414')->is_valid_number, '北海道夕張市鹿の谷山手町');
ok($zip->set_number('0680421')->is_valid_number, '北海道夕張市常盤');
ok($zip->set_number('0680422')->is_valid_number, '北海道夕張市日吉');
ok($zip->set_number('0680423')->is_valid_number, '北海道夕張市平和');
ok($zip->set_number('0680424')->is_valid_number, '北海道夕張市千代田');
ok($zip->set_number('0680425')->is_valid_number, '北海道夕張市若菜');
ok($zip->set_number('0680426')->is_valid_number, '北海道夕張市富野');
ok($zip->set_number('0680531')->is_valid_number, '北海道夕張市清水沢');
ok($zip->set_number('0680532')->is_valid_number, '北海道夕張市清水沢清栄町');
ok($zip->set_number('0680533')->is_valid_number, '北海道夕張市清水沢清湖町');
ok($zip->set_number('0680534')->is_valid_number, '北海道夕張市清水沢宮前町');
ok($zip->set_number('0680535')->is_valid_number, '北海道夕張市清水沢清陵町');
ok($zip->set_number('0680536')->is_valid_number, '北海道夕張市南清水沢');
ok($zip->set_number('0680540')->is_valid_number, '北海道夕張市南部住の江町');
ok($zip->set_number('0680541')->is_valid_number, '北海道夕張市南部遠幌町');
ok($zip->set_number('0680542')->is_valid_number, '北海道夕張市南部夕南町');
ok($zip->set_number('0680543')->is_valid_number, '北海道夕張市南部若美町');
ok($zip->set_number('0680544')->is_valid_number, '北海道夕張市南部大宮町');
ok($zip->set_number('0680545')->is_valid_number, '北海道夕張市南部東町');
ok($zip->set_number('0680546')->is_valid_number, '北海道夕張市南部青葉町');
ok($zip->set_number('0680546')->is_valid_number, '北海道夕張市南部菊水町');
ok($zip->set_number('0680547')->is_valid_number, '北海道夕張市南部新光町');
ok($zip->set_number('0680548')->is_valid_number, '北海道夕張市南部幌南町');
ok($zip->set_number('0680549')->is_valid_number, '北海道夕張市南部岳見町');
ok($zip->set_number('0680661')->is_valid_number, '北海道夕張市鹿島白金');
ok($zip->set_number('0680662')->is_valid_number, '北海道夕張市鹿島明石町');
ok($zip->set_number('0680663')->is_valid_number, '北海道夕張市鹿島千年町');
ok($zip->set_number('0680664')->is_valid_number, '北海道夕張市鹿島錦町');
ok($zip->set_number('0680665')->is_valid_number, '北海道夕張市鹿島宝町');
ok($zip->set_number('0680671')->is_valid_number, '北海道夕張市鹿島緑町');
ok($zip->set_number('0680672')->is_valid_number, '北海道夕張市鹿島富士見町');
ok($zip->set_number('0680673')->is_valid_number, '北海道夕張市鹿島栄町');
ok($zip->set_number('0680674')->is_valid_number, '北海道夕張市鹿島代々木町');
ok($zip->set_number('0680675')->is_valid_number, '北海道夕張市鹿島北栄町');
ok($zip->set_number('0680751')->is_valid_number, '北海道夕張市沼ノ沢');
ok($zip->set_number('0680752')->is_valid_number, '北海道夕張市真谷地');
ok($zip->set_number('0680753')->is_valid_number, '北海道夕張市登川');
ok($zip->set_number('0680754')->is_valid_number, '北海道夕張市楓');
ok($zip->set_number('0680755')->is_valid_number, '北海道夕張市紅葉山');
ok($zip->set_number('0680756')->is_valid_number, '北海道夕張市滝ノ上');
ok($zip->set_number('0680801')->is_valid_number, '北海道岩見沢市南町一条');
ok($zip->set_number('0680802')->is_valid_number, '北海道岩見沢市南町二条');
ok($zip->set_number('0680803')->is_valid_number, '北海道岩見沢市南町三条');
ok($zip->set_number('0680804')->is_valid_number, '北海道岩見沢市南町四条');
ok($zip->set_number('0680805')->is_valid_number, '北海道岩見沢市南町五条');
ok($zip->set_number('0680806')->is_valid_number, '北海道岩見沢市南町六条');
ok($zip->set_number('0680807')->is_valid_number, '北海道岩見沢市南町七条');
ok($zip->set_number('0680808')->is_valid_number, '北海道岩見沢市南町八条');
ok($zip->set_number('0680809')->is_valid_number, '北海道岩見沢市南町九条');
ok($zip->set_number('0680810')->is_valid_number, '北海道岩見沢市南町');
ok($zip->set_number('0680811')->is_valid_number, '北海道岩見沢市美園一条');
ok($zip->set_number('0680812')->is_valid_number, '北海道岩見沢市美園二条');
ok($zip->set_number('0680813')->is_valid_number, '北海道岩見沢市美園三条');
ok($zip->set_number('0680814')->is_valid_number, '北海道岩見沢市美園四条');
ok($zip->set_number('0680815')->is_valid_number, '北海道岩見沢市美園五条');
ok($zip->set_number('0680816')->is_valid_number, '北海道岩見沢市美園六条');
ok($zip->set_number('0680817')->is_valid_number, '北海道岩見沢市美園七条');
ok($zip->set_number('0680818')->is_valid_number, '北海道岩見沢市並木町');
ok($zip->set_number('0680820')->is_valid_number, '北海道岩見沢市東山');
ok($zip->set_number('0680821')->is_valid_number, '北海道岩見沢市栄町');
ok($zip->set_number('0680822')->is_valid_number, '北海道岩見沢市日の出台');
ok($zip->set_number('0680823')->is_valid_number, '北海道岩見沢市日の出南');
ok($zip->set_number('0680824')->is_valid_number, '北海道岩見沢市日の出北');
ok($zip->set_number('0680825')->is_valid_number, '北海道岩見沢市日の出町');
ok($zip->set_number('0680826')->is_valid_number, '北海道岩見沢市東山町');
ok($zip->set_number('0680827')->is_valid_number, '北海道岩見沢市春日町');
ok($zip->set_number('0680828')->is_valid_number, '北海道岩見沢市鳩が丘');
ok($zip->set_number('0680829')->is_valid_number, '北海道岩見沢市かえで町');
ok($zip->set_number('0680830')->is_valid_number, '北海道岩見沢市若駒');
ok($zip->set_number('0680831')->is_valid_number, '北海道岩見沢市ふじ町一条');
ok($zip->set_number('0680832')->is_valid_number, '北海道岩見沢市ふじ町二条');
ok($zip->set_number('0680833')->is_valid_number, '北海道岩見沢市志文町');
ok($zip->set_number('0680834')->is_valid_number, '北海道岩見沢市駒園');
ok($zip->set_number('0680835')->is_valid_number, '北海道岩見沢市緑が丘');
ok($zip->set_number('0680836')->is_valid_number, '北海道岩見沢市上志文町');
ok($zip->set_number('0680837')->is_valid_number, '北海道岩見沢市宝水町');
ok($zip->set_number('0680841')->is_valid_number, '北海道岩見沢市志文本町一条');
ok($zip->set_number('0680842')->is_valid_number, '北海道岩見沢市志文本町二条');
ok($zip->set_number('0680843')->is_valid_number, '北海道岩見沢市志文本町三条');
ok($zip->set_number('0680844')->is_valid_number, '北海道岩見沢市志文本町四条');
ok($zip->set_number('0680845')->is_valid_number, '北海道岩見沢市志文本町五条');
ok($zip->set_number('0680846')->is_valid_number, '北海道岩見沢市下志文町');
ok($zip->set_number('0680847')->is_valid_number, '北海道岩見沢市金子町');
ok($zip->set_number('0680851')->is_valid_number, '北海道岩見沢市大和一条');
ok($zip->set_number('0680852')->is_valid_number, '北海道岩見沢市大和二条');
ok($zip->set_number('0680853')->is_valid_number, '北海道岩見沢市大和三条');
ok($zip->set_number('0680854')->is_valid_number, '北海道岩見沢市大和四条');
ok($zip->set_number('0680855')->is_valid_number, '北海道岩見沢市大和町');
ok($zip->set_number('0681100')->is_valid_number, '北海道石狩郡新篠津村以下に掲載がない場合');
ok($zip->set_number('0681101')->is_valid_number, '北海道石狩郡新篠津村萌出');
ok($zip->set_number('0681102')->is_valid_number, '北海道石狩郡新篠津村いなほ');
ok($zip->set_number('0681103')->is_valid_number, '北海道石狩郡新篠津村西の里');
ok($zip->set_number('0681104')->is_valid_number, '北海道石狩郡新篠津村かつら');
ok($zip->set_number('0681105')->is_valid_number, '北海道石狩郡新篠津村みのり');
ok($zip->set_number('0681111')->is_valid_number, '北海道石狩郡新篠津村東明');
ok($zip->set_number('0681112')->is_valid_number, '北海道石狩郡新篠津村あけぼの');
ok($zip->set_number('0681113')->is_valid_number, '北海道石狩郡新篠津村ふらわ');
ok($zip->set_number('0681114')->is_valid_number, '北海道石狩郡新篠津村南ケ丘');
ok($zip->set_number('0681115')->is_valid_number, '北海道石狩郡新篠津村みずほ');
ok($zip->set_number('0681116')->is_valid_number, '北海道石狩郡新篠津村上達布');
ok($zip->set_number('0681121')->is_valid_number, '北海道石狩郡新篠津村新湧');
ok($zip->set_number('0681122')->is_valid_number, '北海道石狩郡新篠津村北新');
ok($zip->set_number('0681123')->is_valid_number, '北海道石狩郡新篠津村川上');
ok($zip->set_number('0681124')->is_valid_number, '北海道石狩郡新篠津村高倉');
ok($zip->set_number('0681125')->is_valid_number, '北海道石狩郡新篠津村上篠津');
ok($zip->set_number('0681126')->is_valid_number, '北海道石狩郡新篠津村豊ケ丘');
ok($zip->set_number('0681127')->is_valid_number, '北海道石狩郡新篠津村沼之端');
ok($zip->set_number('0681131')->is_valid_number, '北海道石狩郡新篠津村基線');
ok($zip->set_number('0681132')->is_valid_number, '北海道石狩郡新篠津村豊野');
ok($zip->set_number('0681133')->is_valid_number, '北海道石狩郡新篠津村平安');
ok($zip->set_number('0681134')->is_valid_number, '北海道石狩郡新篠津村宍粟');
ok($zip->set_number('0681135')->is_valid_number, '北海道石狩郡新篠津村袋達布');
ok($zip->set_number('0681136')->is_valid_number, '北海道石狩郡新篠津村下達布');
ok($zip->set_number('0681137')->is_valid_number, '北海道石狩郡新篠津村中篠津');
ok($zip->set_number('0681138')->is_valid_number, '北海道石狩郡新篠津村新西篠津');
ok($zip->set_number('0681141')->is_valid_number, '北海道石狩郡新篠津村西篠津');
ok($zip->set_number('0681142')->is_valid_number, '北海道石狩郡新篠津村新樺');
ok($zip->set_number('0681143')->is_valid_number, '北海道石狩郡新篠津村武田');
ok($zip->set_number('0681144')->is_valid_number, '北海道石狩郡新篠津村拓新');
ok($zip->set_number('0681145')->is_valid_number, '北海道石狩郡新篠津村西高倉');
ok($zip->set_number('0681146')->is_valid_number, '北海道石狩郡新篠津村新高倉');
ok($zip->set_number('0681151')->is_valid_number, '北海道石狩郡新篠津村西原');
ok($zip->set_number('0681152')->is_valid_number, '北海道石狩郡新篠津村川下');
ok($zip->set_number('0681153')->is_valid_number, '北海道石狩郡新篠津村中原');
ok($zip->set_number('0681161')->is_valid_number, '北海道岩見沢市北村北都(新中島)');
ok($zip->set_number('0681201')->is_valid_number, '北海道岩見沢市北村豊正');
ok($zip->set_number('0681202')->is_valid_number, '北海道岩見沢市北村中小屋');
ok($zip->set_number('0681203')->is_valid_number, '北海道岩見沢市北村大願');
ok($zip->set_number('0681204')->is_valid_number, '北海道岩見沢市北村栄町');
ok($zip->set_number('0681205')->is_valid_number, '北海道岩見沢市北村豊里');
ok($zip->set_number('0681211')->is_valid_number, '北海道岩見沢市北村北都(その他)');
ok($zip->set_number('0681212')->is_valid_number, '北海道岩見沢市北村中央');
ok($zip->set_number('0681213')->is_valid_number, '北海道岩見沢市北村赤川');
ok($zip->set_number('0681214')->is_valid_number, '北海道岩見沢市北村美唄達布');
ok($zip->set_number('0681215')->is_valid_number, '北海道岩見沢市北村幌達布');
ok($zip->set_number('0681231')->is_valid_number, '北海道樺戸郡月形町雁里');
ok($zip->set_number('0682100')->is_valid_number, '北海道三笠市以下に掲載がない場合');
ok($zip->set_number('0682101')->is_valid_number, '北海道三笠市桂沢');
ok($zip->set_number('0682102')->is_valid_number, '北海道三笠市西桂沢');
ok($zip->set_number('0682103')->is_valid_number, '北海道三笠市奔別新町');
ok($zip->set_number('0682104')->is_valid_number, '北海道三笠市東清住町');
ok($zip->set_number('0682105')->is_valid_number, '北海道三笠市清住町');
ok($zip->set_number('0682106')->is_valid_number, '北海道三笠市美園町');
ok($zip->set_number('0682107')->is_valid_number, '北海道三笠市若草町');
ok($zip->set_number('0682108')->is_valid_number, '北海道三笠市柏町');
ok($zip->set_number('0682111')->is_valid_number, '北海道三笠市幾春別錦町');
ok($zip->set_number('0682112')->is_valid_number, '北海道三笠市幾春別川向町');
ok($zip->set_number('0682113')->is_valid_number, '北海道三笠市幾春別山手町');
ok($zip->set_number('0682114')->is_valid_number, '北海道三笠市幾春別栗丘町');
ok($zip->set_number('0682115')->is_valid_number, '北海道三笠市幾春別滝見町');
ok($zip->set_number('0682116')->is_valid_number, '北海道三笠市幾春別町');
ok($zip->set_number('0682117')->is_valid_number, '北海道三笠市幾春別中島町');
ok($zip->set_number('0682118')->is_valid_number, '北海道三笠市幾春別千住町');
ok($zip->set_number('0682121')->is_valid_number, '北海道三笠市弥生桜木町');
ok($zip->set_number('0682122')->is_valid_number, '北海道三笠市弥生並木町');
ok($zip->set_number('0682123')->is_valid_number, '北海道三笠市弥生桃山町');
ok($zip->set_number('0682124')->is_valid_number, '北海道三笠市弥生花園町');
ok($zip->set_number('0682125')->is_valid_number, '北海道三笠市弥生橘町');
ok($zip->set_number('0682126')->is_valid_number, '北海道三笠市弥生町');
ok($zip->set_number('0682127')->is_valid_number, '北海道三笠市弥生柳町');
ok($zip->set_number('0682128')->is_valid_number, '北海道三笠市弥生藤枝町');
ok($zip->set_number('0682131')->is_valid_number, '北海道三笠市唐松春光町');
ok($zip->set_number('0682132')->is_valid_number, '北海道三笠市唐松緑町');
ok($zip->set_number('0682133')->is_valid_number, '北海道三笠市唐松常盤町');
ok($zip->set_number('0682134')->is_valid_number, '北海道三笠市唐松千代田町');
ok($zip->set_number('0682135')->is_valid_number, '北海道三笠市唐松町');
ok($zip->set_number('0682136')->is_valid_number, '北海道三笠市唐松栄町');
ok($zip->set_number('0682137')->is_valid_number, '北海道三笠市唐松青山町');
ok($zip->set_number('0682141')->is_valid_number, '北海道三笠市本町');
ok($zip->set_number('0682142')->is_valid_number, '北海道三笠市幌内住吉町');
ok($zip->set_number('0682143')->is_valid_number, '北海道三笠市幌内北星町');
ok($zip->set_number('0682144')->is_valid_number, '北海道三笠市幌内金谷町');
ok($zip->set_number('0682145')->is_valid_number, '北海道三笠市幌内町');
ok($zip->set_number('0682146')->is_valid_number, '北海道三笠市幌内春日町');
ok($zip->set_number('0682147')->is_valid_number, '北海道三笠市幌内新栄町');
ok($zip->set_number('0682148')->is_valid_number, '北海道三笠市幌内初音町');
ok($zip->set_number('0682151')->is_valid_number, '北海道三笠市有明町');
ok($zip->set_number('0682152')->is_valid_number, '北海道三笠市多賀町');
ok($zip->set_number('0682153')->is_valid_number, '北海道三笠市幸町');
ok($zip->set_number('0682154')->is_valid_number, '北海道三笠市高美町');
ok($zip->set_number('0682155')->is_valid_number, '北海道三笠市榊町');
ok($zip->set_number('0682156')->is_valid_number, '北海道三笠市宮本町');
ok($zip->set_number('0682157')->is_valid_number, '北海道三笠市若松町');
ok($zip->set_number('0682158')->is_valid_number, '北海道三笠市堤町');
ok($zip->set_number('0682161')->is_valid_number, '北海道三笠市本郷町');
ok($zip->set_number('0682162')->is_valid_number, '北海道三笠市川内');
ok($zip->set_number('0682163')->is_valid_number, '北海道三笠市達布');
ok($zip->set_number('0682164')->is_valid_number, '北海道三笠市いちきしり');
ok($zip->set_number('0682165')->is_valid_number, '北海道三笠市岡山');
ok($zip->set_number('0682166')->is_valid_number, '北海道三笠市萱野');
ok($zip->set_number('0682167')->is_valid_number, '北海道三笠市大里');
ok($zip->set_number('0682168')->is_valid_number, '北海道三笠市美和');
ok($zip->set_number('0682181')->is_valid_number, '北海道美唄市光珠内町南(2794-12番地)');
ok($zip->set_number('0683151')->is_valid_number, '北海道岩見沢市栗沢町万字大平');
ok($zip->set_number('0683152')->is_valid_number, '北海道岩見沢市栗沢町万字幸町');
ok($zip->set_number('0683153')->is_valid_number, '北海道岩見沢市栗沢町万字仲町');
ok($zip->set_number('0683154')->is_valid_number, '北海道岩見沢市栗沢町万字曙町');
ok($zip->set_number('0683155')->is_valid_number, '北海道岩見沢市栗沢町万字寿町');
ok($zip->set_number('0683156')->is_valid_number, '北海道岩見沢市栗沢町万字英町');
ok($zip->set_number('0683157')->is_valid_number, '北海道岩見沢市栗沢町万字睦町');
ok($zip->set_number('0683158')->is_valid_number, '北海道岩見沢市栗沢町万字巴町');
ok($zip->set_number('0683159')->is_valid_number, '北海道岩見沢市栗沢町万字二見町');
ok($zip->set_number('0683161')->is_valid_number, '北海道岩見沢市栗沢町宮村(248、339、726、780、800、806番地)');
ok($zip->set_number('0683162')->is_valid_number, '北海道岩見沢市栗沢町万字旭町');
ok($zip->set_number('0683163')->is_valid_number, '北海道岩見沢市栗沢町万字西原町');
ok($zip->set_number('0683164')->is_valid_number, '北海道岩見沢市栗沢町万字錦町');
ok($zip->set_number('0683165')->is_valid_number, '北海道岩見沢市栗沢町西万字');
ok($zip->set_number('0683171')->is_valid_number, '北海道岩見沢市栗沢町美流渡本町');
ok($zip->set_number('0683172')->is_valid_number, '北海道岩見沢市栗沢町美流渡栄町');
ok($zip->set_number('0683173')->is_valid_number, '北海道岩見沢市栗沢町美流渡若葉町');
ok($zip->set_number('0683174')->is_valid_number, '北海道岩見沢市栗沢町美流渡吉野町');
ok($zip->set_number('0683175')->is_valid_number, '北海道岩見沢市栗沢町美流渡西町');
ok($zip->set_number('0683176')->is_valid_number, '北海道岩見沢市栗沢町美流渡東栄町');
ok($zip->set_number('0683177')->is_valid_number, '北海道岩見沢市栗沢町美流渡末広町');
ok($zip->set_number('0683178')->is_valid_number, '北海道岩見沢市栗沢町美流渡錦町');
ok($zip->set_number('0683179')->is_valid_number, '北海道岩見沢市栗沢町美流渡桜町');
ok($zip->set_number('0683180')->is_valid_number, '北海道岩見沢市栗沢町美流渡東町');
ok($zip->set_number('0683181')->is_valid_number, '北海道岩見沢市栗沢町美流渡南町');
ok($zip->set_number('0683182')->is_valid_number, '北海道岩見沢市栗沢町美流渡緑町');
ok($zip->set_number('0683183')->is_valid_number, '北海道岩見沢市栗沢町美流渡楓町');
ok($zip->set_number('0683185')->is_valid_number, '北海道岩見沢市朝日町');
ok($zip->set_number('0683186')->is_valid_number, '北海道岩見沢市清水町');
ok($zip->set_number('0683187')->is_valid_number, '北海道岩見沢市奈良町');
ok($zip->set_number('0683188')->is_valid_number, '北海道岩見沢市毛陽町');
ok($zip->set_number('0690200')->is_valid_number, '北海道空知郡南幌町以下に掲載がない場合');
ok($zip->set_number('0690207')->is_valid_number, '北海道空知郡南幌町南7線西');
ok($zip->set_number('0690208')->is_valid_number, '北海道空知郡南幌町南8線西');
ok($zip->set_number('0690209')->is_valid_number, '北海道空知郡南幌町南9線西');
ok($zip->set_number('0690210')->is_valid_number, '北海道空知郡南幌町南10線西');
ok($zip->set_number('0690211')->is_valid_number, '北海道空知郡南幌町南11線西');
ok($zip->set_number('0690212')->is_valid_number, '北海道空知郡南幌町南12線西');
ok($zip->set_number('0690213')->is_valid_number, '北海道空知郡南幌町南13線西');
ok($zip->set_number('0690214')->is_valid_number, '北海道空知郡南幌町南14線西');
ok($zip->set_number('0690215')->is_valid_number, '北海道空知郡南幌町南15線西');
ok($zip->set_number('0690216')->is_valid_number, '北海道空知郡南幌町南16線西');
ok($zip->set_number('0690217')->is_valid_number, '北海道空知郡南幌町南17線西');
ok($zip->set_number('0690218')->is_valid_number, '北海道空知郡南幌町南18線西');
ok($zip->set_number('0690219')->is_valid_number, '北海道空知郡南幌町南19線西');
ok($zip->set_number('0690220')->is_valid_number, '北海道空知郡南幌町南20線西');
ok($zip->set_number('0690221')->is_valid_number, '北海道空知郡南幌町南21線西');
ok($zip->set_number('0690231')->is_valid_number, '北海道空知郡南幌町北町');
ok($zip->set_number('0690232')->is_valid_number, '北海道空知郡南幌町緑町');
ok($zip->set_number('0690233')->is_valid_number, '北海道空知郡南幌町東町');
ok($zip->set_number('0690234')->is_valid_number, '北海道空知郡南幌町美園');
ok($zip->set_number('0690235')->is_valid_number, '北海道空知郡南幌町中央');
ok($zip->set_number('0690236')->is_valid_number, '北海道空知郡南幌町西町');
ok($zip->set_number('0690237')->is_valid_number, '北海道空知郡南幌町栄町');
ok($zip->set_number('0690238')->is_valid_number, '北海道空知郡南幌町元町');
ok($zip->set_number('0690239')->is_valid_number, '北海道空知郡南幌町稲穂');
ok($zip->set_number('0690351')->is_valid_number, '北海道岩見沢市北村砂浜');
ok($zip->set_number('0690361')->is_valid_number, '北海道岩見沢市上幌向北一条');
ok($zip->set_number('0690362')->is_valid_number, '北海道岩見沢市上幌向南一条');
ok($zip->set_number('0690363')->is_valid_number, '北海道岩見沢市上幌向南二条');
ok($zip->set_number('0690364')->is_valid_number, '北海道岩見沢市上幌向南三条');
ok($zip->set_number('0690365')->is_valid_number, '北海道岩見沢市上幌向町');
ok($zip->set_number('0690366')->is_valid_number, '北海道岩見沢市双葉町');
ok($zip->set_number('0690371')->is_valid_number, '北海道岩見沢市幌向南一条');
ok($zip->set_number('0690372')->is_valid_number, '北海道岩見沢市幌向南二条');
ok($zip->set_number('0690373')->is_valid_number, '北海道岩見沢市幌向南三条');
ok($zip->set_number('0690374')->is_valid_number, '北海道岩見沢市幌向南四条');
ok($zip->set_number('0690375')->is_valid_number, '北海道岩見沢市幌向南五条');
ok($zip->set_number('0690376')->is_valid_number, '北海道岩見沢市中幌向町');
ok($zip->set_number('0690381')->is_valid_number, '北海道岩見沢市幌向北一条');
ok($zip->set_number('0690382')->is_valid_number, '北海道岩見沢市幌向北二条');
ok($zip->set_number('0690383')->is_valid_number, '北海道岩見沢市幌向町');
ok($zip->set_number('0690384')->is_valid_number, '北海道岩見沢市御茶の水町');
ok($zip->set_number('0690801')->is_valid_number, '北海道江別市中央町');
ok($zip->set_number('0690802')->is_valid_number, '北海道江別市野幌寿町');
ok($zip->set_number('0690803')->is_valid_number, '北海道江別市野幌屯田町');
ok($zip->set_number('0690804')->is_valid_number, '北海道江別市野幌美幸町');
ok($zip->set_number('0690805')->is_valid_number, '北海道江別市元野幌(その他)');
ok($zip->set_number('0690806')->is_valid_number, '北海道江別市新栄台');
ok($zip->set_number('0690811')->is_valid_number, '北海道江別市錦町');
ok($zip->set_number('0690812')->is_valid_number, '北海道江別市幸町');
ok($zip->set_number('0690813')->is_valid_number, '北海道江別市野幌町');
ok($zip->set_number('0690814')->is_valid_number, '北海道江別市野幌松並町');
ok($zip->set_number('0690815')->is_valid_number, '北海道江別市野幌末広町');
ok($zip->set_number('0690816')->is_valid_number, '北海道江別市野幌住吉町');
ok($zip->set_number('0690817')->is_valid_number, '北海道江別市野幌代々木町');
ok($zip->set_number('0690821')->is_valid_number, '北海道江別市東野幌町');
ok($zip->set_number('0690822')->is_valid_number, '北海道江別市東野幌');
ok($zip->set_number('0690823')->is_valid_number, '北海道江別市緑ケ丘');
ok($zip->set_number('0690824')->is_valid_number, '北海道江別市東野幌本町');
ok($zip->set_number('0690825')->is_valid_number, '北海道江別市野幌東町');
ok($zip->set_number('0690826')->is_valid_number, '北海道江別市あさひが丘');
ok($zip->set_number('0690831')->is_valid_number, '北海道江別市野幌若葉町');
ok($zip->set_number('0690832')->is_valid_number, '北海道江別市西野幌');
ok($zip->set_number('0690833')->is_valid_number, '北海道江別市文京台');
ok($zip->set_number('0690834')->is_valid_number, '北海道江別市文京台東町');
ok($zip->set_number('0690835')->is_valid_number, '北海道江別市文京台南町');
ok($zip->set_number('0690836')->is_valid_number, '北海道江別市文京台緑町');
ok($zip->set_number('0690841')->is_valid_number, '北海道江別市大麻元町');
ok($zip->set_number('0690842')->is_valid_number, '北海道江別市大麻沢町');
ok($zip->set_number('0690843')->is_valid_number, '北海道江別市大麻扇町');
ok($zip->set_number('0690844')->is_valid_number, '北海道江別市大麻西町');
ok($zip->set_number('0690845')->is_valid_number, '北海道江別市大麻');
ok($zip->set_number('0690846')->is_valid_number, '北海道江別市大麻桜木町');
ok($zip->set_number('0690847')->is_valid_number, '北海道江別市大麻ひかり町');
ok($zip->set_number('0690851')->is_valid_number, '北海道江別市大麻園町');
ok($zip->set_number('0690852')->is_valid_number, '北海道江別市大麻東町');
ok($zip->set_number('0690853')->is_valid_number, '北海道江別市大麻高町');
ok($zip->set_number('0690854')->is_valid_number, '北海道江別市大麻中町');
ok($zip->set_number('0690855')->is_valid_number, '北海道江別市大麻宮町');
ok($zip->set_number('0690861')->is_valid_number, '北海道江別市大麻北町');
ok($zip->set_number('0690862')->is_valid_number, '北海道江別市大麻栄町');
ok($zip->set_number('0690863')->is_valid_number, '北海道江別市大麻新町');
ok($zip->set_number('0690864')->is_valid_number, '北海道江別市大麻泉町');
ok($zip->set_number('0690865')->is_valid_number, '北海道江別市大麻南樹町');
ok($zip->set_number('0690866')->is_valid_number, '北海道江別市大麻晴美町');
ok($zip->set_number('0690867')->is_valid_number, '北海道江別市元野幌(1~440番地)');
ok($zip->set_number('0691131')->is_valid_number, '北海道夕張郡由仁町三川泉町');
ok($zip->set_number('0691132')->is_valid_number, '北海道夕張郡由仁町三川錦町');
ok($zip->set_number('0691133')->is_valid_number, '北海道夕張郡由仁町三川旭町');
ok($zip->set_number('0691134')->is_valid_number, '北海道夕張郡由仁町三川緑町');
ok($zip->set_number('0691135')->is_valid_number, '北海道夕張郡由仁町西三川(その他)');
ok($zip->set_number('0691136')->is_valid_number, '北海道夕張郡由仁町熊本(その他)');
ok($zip->set_number('0691141')->is_valid_number, '北海道夕張郡由仁町川端');
ok($zip->set_number('0691142')->is_valid_number, '北海道夕張郡由仁町東三川');
ok($zip->set_number('0691143')->is_valid_number, '北海道夕張郡由仁町中三川');
ok($zip->set_number('0691144')->is_valid_number, '北海道夕張郡由仁町本三川(その他)');
ok($zip->set_number('0691181')->is_valid_number, '北海道千歳市東丘');
ok($zip->set_number('0691182')->is_valid_number, '北海道千歳市協和(その他)');
ok($zip->set_number('0691183')->is_valid_number, '北海道千歳市幌加');
ok($zip->set_number('0691184')->is_valid_number, '北海道千歳市新川');
ok($zip->set_number('0691200')->is_valid_number, '北海道夕張郡由仁町以下に掲載がない場合');
ok($zip->set_number('0691201')->is_valid_number, '北海道夕張郡由仁町北栄');
ok($zip->set_number('0691202')->is_valid_number, '北海道夕張郡由仁町古川');
ok($zip->set_number('0691203')->is_valid_number, '北海道夕張郡由仁町東栄');
ok($zip->set_number('0691204')->is_valid_number, '北海道夕張郡由仁町新光');
ok($zip->set_number('0691205')->is_valid_number, '北海道夕張郡由仁町中央');
ok($zip->set_number('0691206')->is_valid_number, '北海道夕張郡由仁町本町');
ok($zip->set_number('0691207')->is_valid_number, '北海道夕張郡由仁町馬追');
ok($zip->set_number('0691208')->is_valid_number, '北海道夕張郡由仁町山形');
ok($zip->set_number('0691211')->is_valid_number, '北海道夕張郡由仁町岩内');
ok($zip->set_number('0691212')->is_valid_number, '北海道夕張郡由仁町山桝');
ok($zip->set_number('0691213')->is_valid_number, '北海道夕張郡由仁町本三川(89、210、212番地)');
ok($zip->set_number('0691214')->is_valid_number, '北海道夕張郡由仁町西三川(1、17番地)');
ok($zip->set_number('0691215')->is_valid_number, '北海道夕張郡由仁町熊本(10、38、314、623、626番地)');
ok($zip->set_number('0691216')->is_valid_number, '北海道夕張郡由仁町古山');
ok($zip->set_number('0691217')->is_valid_number, '北海道夕張郡由仁町光栄');
ok($zip->set_number('0691218')->is_valid_number, '北海道夕張郡由仁町伏見');
ok($zip->set_number('0691219')->is_valid_number, '北海道夕張郡由仁町東光');
ok($zip->set_number('0691300')->is_valid_number, '北海道夕張郡長沼町以下に掲載がない場合');
ok($zip->set_number('0691301')->is_valid_number, '北海道夕張郡長沼町1区');
ok($zip->set_number('0691302')->is_valid_number, '北海道夕張郡長沼町2区');
ok($zip->set_number('0691303')->is_valid_number, '北海道夕張郡長沼町3区');
ok($zip->set_number('0691304')->is_valid_number, '北海道夕張郡長沼町北市区');
ok($zip->set_number('0691304')->is_valid_number, '北海道夕張郡長沼町4区');
ok($zip->set_number('0691305')->is_valid_number, '北海道夕張郡長沼町5区');
ok($zip->set_number('0691306')->is_valid_number, '北海道夕張郡長沼町6区');
ok($zip->set_number('0691307')->is_valid_number, '北海道夕張郡長沼町7区');
ok($zip->set_number('0691308')->is_valid_number, '北海道夕張郡長沼町8区');
ok($zip->set_number('0691309')->is_valid_number, '北海道夕張郡長沼町9区');
ok($zip->set_number('0691310')->is_valid_number, '北海道夕張郡長沼町10区');
ok($zip->set_number('0691311')->is_valid_number, '北海道夕張郡長沼町フシコ');
ok($zip->set_number('0691311')->is_valid_number, '北海道夕張郡長沼町11区');
ok($zip->set_number('0691312')->is_valid_number, '北海道夕張郡長沼町12区');
ok($zip->set_number('0691313')->is_valid_number, '北海道夕張郡長沼町13区');
ok($zip->set_number('0691314')->is_valid_number, '北海道夕張郡長沼町14区');
ok($zip->set_number('0691315')->is_valid_number, '北海道夕張郡長沼町南町');
ok($zip->set_number('0691315')->is_valid_number, '北海道夕張郡長沼町15区');
ok($zip->set_number('0691316')->is_valid_number, '北海道夕張郡長沼町加賀団体');
ok($zip->set_number('0691316')->is_valid_number, '北海道夕張郡長沼町16区');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東1線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東2線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東3線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東4線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東5線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東6線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東7線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東8線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東9線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東10線北');
ok($zip->set_number('0691317')->is_valid_number, '北海道夕張郡長沼町東11線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西1線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西2線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西3線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西4線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西5線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西6線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西7線北');
ok($zip->set_number('0691318')->is_valid_number, '北海道夕張郡長沼町西8線北');
ok($zip->set_number('0691320')->is_valid_number, '北海道夕張郡長沼町市街地');
ok($zip->set_number('0691321')->is_valid_number, '北海道夕張郡長沼町馬追');
ok($zip->set_number('0691322')->is_valid_number, '北海道夕張郡長沼町馬追原野');
ok($zip->set_number('0691329')->is_valid_number, '北海道夕張郡長沼町木詰');
ok($zip->set_number('0691329')->is_valid_number, '北海道夕張郡長沼町幌向原野');
ok($zip->set_number('0691329')->is_valid_number, '北海道夕張郡長沼町29区');
ok($zip->set_number('0691331')->is_valid_number, '北海道夕張郡長沼町銀座');
ok($zip->set_number('0691332')->is_valid_number, '北海道夕張郡長沼町中央');
ok($zip->set_number('0691333')->is_valid_number, '北海道夕張郡長沼町本町');
ok($zip->set_number('0691334')->is_valid_number, '北海道夕張郡長沼町錦町北');
ok($zip->set_number('0691334')->is_valid_number, '北海道夕張郡長沼町錦町南');
ok($zip->set_number('0691335')->is_valid_number, '北海道夕張郡長沼町あかね');
ok($zip->set_number('0691336')->is_valid_number, '北海道夕張郡長沼町川沿');
ok($zip->set_number('0691336')->is_valid_number, '北海道夕張郡長沼町栄町');
ok($zip->set_number('0691341')->is_valid_number, '北海道夕張郡長沼町宮下');
ok($zip->set_number('0691342')->is_valid_number, '北海道夕張郡長沼町東町');
ok($zip->set_number('0691343')->is_valid_number, '北海道夕張郡長沼町旭町');
ok($zip->set_number('0691344')->is_valid_number, '北海道夕張郡長沼町曙町');
ok($zip->set_number('0691345')->is_valid_number, '北海道夕張郡長沼町しらかば');
ok($zip->set_number('0691346')->is_valid_number, '北海道夕張郡長沼町西町');
ok($zip->set_number('0691347')->is_valid_number, '北海道夕張郡長沼町北町');
ok($zip->set_number('0691451')->is_valid_number, '北海道夕張郡長沼町東1線南');
ok($zip->set_number('0691452')->is_valid_number, '北海道夕張郡長沼町東2線南');
ok($zip->set_number('0691453')->is_valid_number, '北海道夕張郡長沼町東3線南');
ok($zip->set_number('0691454')->is_valid_number, '北海道夕張郡長沼町東4線南');
ok($zip->set_number('0691455')->is_valid_number, '北海道夕張郡長沼町東5線南');
ok($zip->set_number('0691456')->is_valid_number, '北海道夕張郡長沼町東6線南');
ok($zip->set_number('0691457')->is_valid_number, '北海道夕張郡長沼町東7線南');
ok($zip->set_number('0691458')->is_valid_number, '北海道夕張郡長沼町東8線南');
ok($zip->set_number('0691459')->is_valid_number, '北海道夕張郡長沼町東9線南');
ok($zip->set_number('0691460')->is_valid_number, '北海道夕張郡長沼町東10線南');
ok($zip->set_number('0691461')->is_valid_number, '北海道夕張郡長沼町東11線南');
ok($zip->set_number('0691462')->is_valid_number, '北海道夕張郡長沼町東12線南');
ok($zip->set_number('0691463')->is_valid_number, '北海道夕張郡長沼町東13線南');
ok($zip->set_number('0691464')->is_valid_number, '北海道夕張郡長沼町幌内');
ok($zip->set_number('0691471')->is_valid_number, '北海道夕張郡長沼町西1線南');
ok($zip->set_number('0691472')->is_valid_number, '北海道夕張郡長沼町西2線南');
ok($zip->set_number('0691473')->is_valid_number, '北海道夕張郡長沼町西3線南');
ok($zip->set_number('0691474')->is_valid_number, '北海道夕張郡長沼町西4線南');
ok($zip->set_number('0691475')->is_valid_number, '北海道夕張郡長沼町西5線南');
ok($zip->set_number('0691476')->is_valid_number, '北海道夕張郡長沼町西6線南');
ok($zip->set_number('0691477')->is_valid_number, '北海道夕張郡長沼町西7線南');
ok($zip->set_number('0691478')->is_valid_number, '北海道夕張郡長沼町西8線南');
ok($zip->set_number('0691479')->is_valid_number, '北海道夕張郡長沼町西9線南');
ok($zip->set_number('0691480')->is_valid_number, '北海道夕張郡長沼町西10線南');
ok($zip->set_number('0691481')->is_valid_number, '北海道夕張郡長沼町西11線南');
ok($zip->set_number('0691482')->is_valid_number, '北海道夕張郡長沼町西12線南');
ok($zip->set_number('0691483')->is_valid_number, '北海道夕張郡長沼町西13線南');
ok($zip->set_number('0691484')->is_valid_number, '北海道夕張郡長沼町西14線南');
ok($zip->set_number('0691485')->is_valid_number, '北海道夕張郡長沼町30区');
ok($zip->set_number('0691500')->is_valid_number, '北海道夕張郡栗山町以下に掲載がない場合');
ok($zip->set_number('0691501')->is_valid_number, '北海道夕張郡栗山町桜丘');
ok($zip->set_number('0691502')->is_valid_number, '北海道夕張郡栗山町鳩山');
ok($zip->set_number('0691502')->is_valid_number, '北海道夕張郡栗山町森');
ok($zip->set_number('0691503')->is_valid_number, '北海道夕張郡栗山町雨煙別');
ok($zip->set_number('0691503')->is_valid_number, '北海道夕張郡栗山町緑丘');
ok($zip->set_number('0691504')->is_valid_number, '北海道夕張郡栗山町北学田');
ok($zip->set_number('0691505')->is_valid_number, '北海道夕張郡栗山町桜山(その他)');
ok($zip->set_number('0691505')->is_valid_number, '北海道夕張郡栗山町本沢');
ok($zip->set_number('0691506')->is_valid_number, '北海道夕張郡栗山町杵臼');
ok($zip->set_number('0691507')->is_valid_number, '北海道夕張郡栗山町旭台');
ok($zip->set_number('0691508')->is_valid_number, '北海道夕張郡栗山町湯地');
ok($zip->set_number('0691511')->is_valid_number, '北海道夕張郡栗山町中央');
ok($zip->set_number('0691512')->is_valid_number, '北海道夕張郡栗山町松風');
ok($zip->set_number('0691513')->is_valid_number, '北海道夕張郡栗山町朝日');
ok($zip->set_number('0691521')->is_valid_number, '北海道夕張郡栗山町錦');
ok($zip->set_number('0691522')->is_valid_number, '北海道夕張郡栗山町中里');
ok($zip->set_number('0691523')->is_valid_number, '北海道夕張郡栗山町共和');
ok($zip->set_number('0691524')->is_valid_number, '北海道夕張郡栗山町角田');
ok($zip->set_number('0691525')->is_valid_number, '北海道夕張郡栗山町三日月');
ok($zip->set_number('0691526')->is_valid_number, '北海道夕張郡栗山町富士');
ok($zip->set_number('0700000')->is_valid_number, '北海道旭川市以下に掲載がない場合');
ok($zip->set_number('0700001')->is_valid_number, '北海道旭川市新富1条');
ok($zip->set_number('0700002')->is_valid_number, '北海道旭川市新富2条');
ok($zip->set_number('0700003')->is_valid_number, '北海道旭川市新富3条');
ok($zip->set_number('0700010')->is_valid_number, '北海道旭川市大雪通');
ok($zip->set_number('0700011')->is_valid_number, '北海道旭川市パルプ町1条');
ok($zip->set_number('0700012')->is_valid_number, '北海道旭川市パルプ町2条');
ok($zip->set_number('0700013')->is_valid_number, '北海道旭川市パルプ町');
ok($zip->set_number('0700014')->is_valid_number, '北海道旭川市新星町');
ok($zip->set_number('0700021')->is_valid_number, '北海道旭川市東1条');
ok($zip->set_number('0700022')->is_valid_number, '北海道旭川市東2条');
ok($zip->set_number('0700023')->is_valid_number, '北海道旭川市東3条');
ok($zip->set_number('0700024')->is_valid_number, '北海道旭川市東4条');
ok($zip->set_number('0700025')->is_valid_number, '北海道旭川市東5条');
ok($zip->set_number('0700026')->is_valid_number, '北海道旭川市東6条');
ok($zip->set_number('0700027')->is_valid_number, '北海道旭川市東7条');
ok($zip->set_number('0700028')->is_valid_number, '北海道旭川市東8条');
ok($zip->set_number('0700029')->is_valid_number, '北海道旭川市金星町');
ok($zip->set_number('0700030')->is_valid_number, '北海道旭川市宮下通(1~17丁目)');
ok($zip->set_number('0700031')->is_valid_number, '北海道旭川市1条通(1~17丁目)');
ok($zip->set_number('0700032')->is_valid_number, '北海道旭川市2条通(1~17丁目)');
ok($zip->set_number('0700033')->is_valid_number, '北海道旭川市3条通(1~17丁目)');
ok($zip->set_number('0700034')->is_valid_number, '北海道旭川市4条通(1~17丁目)');
ok($zip->set_number('0700035')->is_valid_number, '北海道旭川市5条通(1~17丁目)');
ok($zip->set_number('0700036')->is_valid_number, '北海道旭川市6条通(1~17丁目)');
ok($zip->set_number('0700037')->is_valid_number, '北海道旭川市7条通(1~17丁目)');
ok($zip->set_number('0700038')->is_valid_number, '北海道旭川市8条通(1~17丁目)');
ok($zip->set_number('0700039')->is_valid_number, '北海道旭川市9条通(1~17丁目)');
ok($zip->set_number('0700040')->is_valid_number, '北海道旭川市10条通(8~17丁目)');
ok($zip->set_number('0700041')->is_valid_number, '北海道旭川市上常盤町');
ok($zip->set_number('0700042')->is_valid_number, '北海道旭川市中常盤町');
ok($zip->set_number('0700043')->is_valid_number, '北海道旭川市常盤通');
ok($zip->set_number('0700044')->is_valid_number, '北海道旭川市常磐公園');
ok($zip->set_number('0700052')->is_valid_number, '北海道旭川市2条西');
ok($zip->set_number('0700053')->is_valid_number, '北海道旭川市3条西');
ok($zip->set_number('0700054')->is_valid_number, '北海道旭川市4条西');
ok($zip->set_number('0700055')->is_valid_number, '北海道旭川市5条西');
ok($zip->set_number('0700056')->is_valid_number, '北海道旭川市6条西');
ok($zip->set_number('0700057')->is_valid_number, '北海道旭川市7条西');
ok($zip->set_number('0700058')->is_valid_number, '北海道旭川市8条西');
ok($zip->set_number('0700059')->is_valid_number, '北海道旭川市9条西');
ok($zip->set_number('0700061')->is_valid_number, '北海道旭川市曙1条');
ok($zip->set_number('0700062')->is_valid_number, '北海道旭川市曙2条');
ok($zip->set_number('0700063')->is_valid_number, '北海道旭川市曙3条');
ok($zip->set_number('0700072')->is_valid_number, '北海道旭川市曙北2条');
ok($zip->set_number('0700073')->is_valid_number, '北海道旭川市曙北3条');
ok($zip->set_number('0700081')->is_valid_number, '北海道旭川市亀吉1条');
ok($zip->set_number('0700082')->is_valid_number, '北海道旭川市亀吉2条');
ok($zip->set_number('0700083')->is_valid_number, '北海道旭川市亀吉3条');
ok($zip->set_number('0700810')->is_valid_number, '北海道旭川市本町');
ok($zip->set_number('0700811')->is_valid_number, '北海道旭川市川端町1条');
ok($zip->set_number('0700812')->is_valid_number, '北海道旭川市川端町2条');
ok($zip->set_number('0700813')->is_valid_number, '北海道旭川市川端町3条');
ok($zip->set_number('0700814')->is_valid_number, '北海道旭川市川端町4条');
ok($zip->set_number('0700815')->is_valid_number, '北海道旭川市川端町5条');
ok($zip->set_number('0700816')->is_valid_number, '北海道旭川市川端町6条');
ok($zip->set_number('0700817')->is_valid_number, '北海道旭川市川端町7条');
ok($zip->set_number('0700821')->is_valid_number, '北海道旭川市近文町');
ok($zip->set_number('0700822')->is_valid_number, '北海道旭川市旭岡');
ok($zip->set_number('0700823')->is_valid_number, '北海道旭川市緑町');
ok($zip->set_number('0700824')->is_valid_number, '北海道旭川市錦町');
ok($zip->set_number('0700825')->is_valid_number, '北海道旭川市北門町');
ok($zip->set_number('0700831')->is_valid_number, '北海道旭川市旭町1条');
ok($zip->set_number('0700832')->is_valid_number, '北海道旭川市旭町2条');
ok($zip->set_number('0700841')->is_valid_number, '北海道旭川市大町1条');
ok($zip->set_number('0700842')->is_valid_number, '北海道旭川市大町2条');
ok($zip->set_number('0700843')->is_valid_number, '北海道旭川市大町3条');
ok($zip->set_number('0700864')->is_valid_number, '北海道旭川市住吉4条');
ok($zip->set_number('0700865')->is_valid_number, '北海道旭川市住吉5条');
ok($zip->set_number('0700866')->is_valid_number, '北海道旭川市住吉6条');
ok($zip->set_number('0700867')->is_valid_number, '北海道旭川市住吉7条');
ok($zip->set_number('0700871')->is_valid_number, '北海道旭川市春光1条');
ok($zip->set_number('0700872')->is_valid_number, '北海道旭川市春光2条');
ok($zip->set_number('0700873')->is_valid_number, '北海道旭川市春光3条');
ok($zip->set_number('0700874')->is_valid_number, '北海道旭川市春光4条');
ok($zip->set_number('0700875')->is_valid_number, '北海道旭川市春光5条');
ok($zip->set_number('0700876')->is_valid_number, '北海道旭川市春光6条');
ok($zip->set_number('0700877')->is_valid_number, '北海道旭川市春光7条');
ok($zip->set_number('0700901')->is_valid_number, '北海道旭川市花咲町');
ok($zip->set_number('0700902')->is_valid_number, '北海道旭川市春光町');
ok($zip->set_number('0700971')->is_valid_number, '北海道旭川市4区1条');
ok($zip->set_number('0700972')->is_valid_number, '北海道旭川市4区2条');
ok($zip->set_number('0700973')->is_valid_number, '北海道旭川市4区3条');
ok($zip->set_number('0708001')->is_valid_number, '北海道旭川市神楽1条');
ok($zip->set_number('0708002')->is_valid_number, '北海道旭川市神楽2条');
ok($zip->set_number('0708003')->is_valid_number, '北海道旭川市神楽3条');
ok($zip->set_number('0708004')->is_valid_number, '北海道旭川市神楽4条');
ok($zip->set_number('0708005')->is_valid_number, '北海道旭川市神楽5条');
ok($zip->set_number('0708006')->is_valid_number, '北海道旭川市神楽6条');
ok($zip->set_number('0708007')->is_valid_number, '北海道旭川市神楽7条');
ok($zip->set_number('0708011')->is_valid_number, '北海道旭川市神居1条');
ok($zip->set_number('0708012')->is_valid_number, '北海道旭川市神居2条');
ok($zip->set_number('0708013')->is_valid_number, '北海道旭川市神居3条');
ok($zip->set_number('0708014')->is_valid_number, '北海道旭川市神居4条');
ok($zip->set_number('0708015')->is_valid_number, '北海道旭川市神居5条');
ok($zip->set_number('0708016')->is_valid_number, '北海道旭川市神居6条');
ok($zip->set_number('0708017')->is_valid_number, '北海道旭川市神居7条');
ok($zip->set_number('0708018')->is_valid_number, '北海道旭川市神居8条');
ok($zip->set_number('0708019')->is_valid_number, '北海道旭川市神居9条');
ok($zip->set_number('0708021')->is_valid_number, '北海道旭川市神居町忠和');
ok($zip->set_number('0708022')->is_valid_number, '北海道旭川市神居町台場');
ok($zip->set_number('0708023')->is_valid_number, '北海道旭川市神居町春志内');
ok($zip->set_number('0708024')->is_valid_number, '北海道旭川市神居町富沢');
ok($zip->set_number('0708025')->is_valid_number, '北海道旭川市神居町富岡');
ok($zip->set_number('0708026')->is_valid_number, '北海道旭川市神居町神岡');
ok($zip->set_number('0708027')->is_valid_number, '北海道旭川市台場東');
ok($zip->set_number('0708028')->is_valid_number, '北海道旭川市南が丘');
ok($zip->set_number('0708031')->is_valid_number, '北海道旭川市神居町神華');
ok($zip->set_number('0708032')->is_valid_number, '北海道旭川市神居町共栄');
ok($zip->set_number('0708033')->is_valid_number, '北海道旭川市神居町雨紛');
ok($zip->set_number('0708034')->is_valid_number, '北海道旭川市神居町上雨紛');
ok($zip->set_number('0708041')->is_valid_number, '北海道旭川市忠和1条');
ok($zip->set_number('0708042')->is_valid_number, '北海道旭川市忠和2条');
ok($zip->set_number('0708043')->is_valid_number, '北海道旭川市忠和3条');
ok($zip->set_number('0708044')->is_valid_number, '北海道旭川市忠和4条');
ok($zip->set_number('0708045')->is_valid_number, '北海道旭川市忠和5条');
ok($zip->set_number('0708046')->is_valid_number, '北海道旭川市忠和6条');
ok($zip->set_number('0708047')->is_valid_number, '北海道旭川市忠和7条');
ok($zip->set_number('0708048')->is_valid_number, '北海道旭川市忠和8条');
ok($zip->set_number('0708049')->is_valid_number, '北海道旭川市忠和9条');
ok($zip->set_number('0708051')->is_valid_number, '北海道旭川市江丹別町嵐山');
ok($zip->set_number('0708052')->is_valid_number, '北海道旭川市江丹別町春日');
ok($zip->set_number('0708053')->is_valid_number, '北海道旭川市江丹別町共和');
ok($zip->set_number('0708061')->is_valid_number, '北海道旭川市高砂台');
ok($zip->set_number('0708071')->is_valid_number, '北海道旭川市台場1条');
ok($zip->set_number('0708072')->is_valid_number, '北海道旭川市台場2条');
ok($zip->set_number('0708073')->is_valid_number, '北海道旭川市台場3条');
ok($zip->set_number('0708074')->is_valid_number, '北海道旭川市台場4条');
ok($zip->set_number('0710171')->is_valid_number, '北海道旭川市西神楽南1条');
ok($zip->set_number('0710172')->is_valid_number, '北海道旭川市西神楽南2条');
ok($zip->set_number('0710173')->is_valid_number, '北海道旭川市西神楽北1条');
ok($zip->set_number('0710174')->is_valid_number, '北海道旭川市西神楽北2条');
ok($zip->set_number('0710184')->is_valid_number, '北海道旭川市西神楽4線');
ok($zip->set_number('0710185')->is_valid_number, '北海道旭川市西神楽5線');
ok($zip->set_number('0710186')->is_valid_number, '北海道旭川市西神楽南');
ok($zip->set_number('0710200')->is_valid_number, '北海道上川郡美瑛町以下に掲載がない場合');
ok($zip->set_number('0710201')->is_valid_number, '北海道上川郡美瑛町丸山');
ok($zip->set_number('0710202')->is_valid_number, '北海道上川郡美瑛町南町');
ok($zip->set_number('0710203')->is_valid_number, '北海道上川郡美瑛町西町');
ok($zip->set_number('0710204')->is_valid_number, '北海道上川郡美瑛町大町');
ok($zip->set_number('0710205')->is_valid_number, '北海道上川郡美瑛町栄町');
ok($zip->set_number('0710206')->is_valid_number, '北海道上川郡美瑛町北町');
ok($zip->set_number('0710207')->is_valid_number, '北海道上川郡美瑛町中町');
ok($zip->set_number('0710208')->is_valid_number, '北海道上川郡美瑛町本町');
ok($zip->set_number('0710209')->is_valid_number, '北海道上川郡美瑛町寿町');
ok($zip->set_number('0710211')->is_valid_number, '北海道上川郡美瑛町錦町');
ok($zip->set_number('0710212')->is_valid_number, '北海道上川郡美瑛町旭町');
ok($zip->set_number('0710213')->is_valid_number, '北海道上川郡美瑛町東町');
ok($zip->set_number('0710214')->is_valid_number, '北海道上川郡美瑛町幸町');
ok($zip->set_number('0710215')->is_valid_number, '北海道上川郡美瑛町扇町');
ok($zip->set_number('0710216')->is_valid_number, '北海道上川郡美瑛町大村(大久保)');
ok($zip->set_number('0710217')->is_valid_number, '北海道上川郡美瑛町大村(石山)');
ok($zip->set_number('0710218')->is_valid_number, '北海道上川郡美瑛町大村(村山)');
ok($zip->set_number('0710219')->is_valid_number, '北海道上川郡美瑛町大村(中本)');
ok($zip->set_number('0710221')->is_valid_number, '北海道上川郡美瑛町美田(夕張)');
ok($zip->set_number('0710222')->is_valid_number, '北海道上川郡美瑛町美田');
ok($zip->set_number('0710223')->is_valid_number, '北海道上川郡美瑛町五稜');
ok($zip->set_number('0710224')->is_valid_number, '北海道上川郡美瑛町北瑛');
ok($zip->set_number('0710225')->is_valid_number, '北海道上川郡美瑛町明治(大三)');
ok($zip->set_number('0710226')->is_valid_number, '北海道上川郡美瑛町下宇莫別');
ok($zip->set_number('0710227')->is_valid_number, '北海道上川郡美瑛町中宇莫別(赤羽)');
ok($zip->set_number('0710228')->is_valid_number, '北海道上川郡美瑛町中宇莫別');
ok($zip->set_number('0710229')->is_valid_number, '北海道上川郡美瑛町上宇莫別');
ok($zip->set_number('0710231')->is_valid_number, '北海道上川郡美瑛町明治');
ok($zip->set_number('0710232')->is_valid_number, '北海道上川郡美瑛町明治(沼崎)');
ok($zip->set_number('0710233')->is_valid_number, '北海道上川郡美瑛町新区画');
ok($zip->set_number('0710234')->is_valid_number, '北海道上川郡美瑛町置杵牛');
ok($zip->set_number('0710235')->is_valid_number, '北海道上川郡美瑛町白金');
ok($zip->set_number('0710236')->is_valid_number, '北海道上川郡美瑛町美沢');
ok($zip->set_number('0710237')->is_valid_number, '北海道上川郡美瑛町福富(豊栄)');
ok($zip->set_number('0710238')->is_valid_number, '北海道上川郡美瑛町藤野');
ok($zip->set_number('0710239')->is_valid_number, '北海道上川郡美瑛町美瑛原野(原野)');
ok($zip->set_number('0710240')->is_valid_number, '北海道上川郡美瑛町三愛(緑)');
ok($zip->set_number('0710241')->is_valid_number, '北海道上川郡美瑛町水沢(水上)');
ok($zip->set_number('0710242')->is_valid_number, '北海道上川郡美瑛町水沢');
ok($zip->set_number('0710243')->is_valid_number, '北海道上川郡美瑛町福富(間宮)');
ok($zip->set_number('0710244')->is_valid_number, '北海道上川郡美瑛町福富(福美沢)');
ok($zip->set_number('0710245')->is_valid_number, '北海道上川郡美瑛町福富(福富瑛進)');
ok($zip->set_number('0710246')->is_valid_number, '北海道上川郡美瑛町福富(福富憩)');
ok($zip->set_number('0710247')->is_valid_number, '北海道上川郡美瑛町三愛(大曲)');
ok($zip->set_number('0710248')->is_valid_number, '北海道上川郡美瑛町花園');
ok($zip->set_number('0710249')->is_valid_number, '北海道上川郡美瑛町憩町');
ok($zip->set_number('0710251')->is_valid_number, '北海道上川郡美瑛町憩が丘');
ok($zip->set_number('0710261')->is_valid_number, '北海道上川郡美瑛町旭');
ok($zip->set_number('0710351')->is_valid_number, '北海道上川郡美瑛町横牛');
ok($zip->set_number('0710352')->is_valid_number, '北海道上川郡美瑛町朗根内');
ok($zip->set_number('0710353')->is_valid_number, '北海道上川郡美瑛町俵真布');
ok($zip->set_number('0710355')->is_valid_number, '北海道上川郡美瑛町天人峡');
ok($zip->set_number('0710461')->is_valid_number, '北海道上川郡美瑛町美馬牛北');
ok($zip->set_number('0710462')->is_valid_number, '北海道上川郡美瑛町美馬牛南');
ok($zip->set_number('0710471')->is_valid_number, '北海道上川郡美瑛町美馬牛');
ok($zip->set_number('0710472')->is_valid_number, '北海道上川郡美瑛町美馬牛市街地');
ok($zip->set_number('0710473')->is_valid_number, '北海道上川郡美瑛町新星');
ok($zip->set_number('0710474')->is_valid_number, '北海道上川郡美瑛町拓進');
ok($zip->set_number('0710475')->is_valid_number, '北海道上川郡美瑛町常盤');
ok($zip->set_number('0710476')->is_valid_number, '北海道上川郡美瑛町御牧');
ok($zip->set_number('0710477')->is_valid_number, '北海道上川郡美瑛町二股');
ok($zip->set_number('0710478')->is_valid_number, '北海道上川郡美瑛町瑠辺蘂');
ok($zip->set_number('0710479')->is_valid_number, '北海道上川郡美瑛町美園');
ok($zip->set_number('0710500')->is_valid_number, '北海道空知郡上富良野町以下に掲載がない場合');
ok($zip->set_number('0710501')->is_valid_number, '北海道空知郡上富良野町西1線北');
ok($zip->set_number('0710502')->is_valid_number, '北海道空知郡上富良野町西2線北');
ok($zip->set_number('0710503')->is_valid_number, '北海道空知郡上富良野町西3線北');
ok($zip->set_number('0710504')->is_valid_number, '北海道空知郡上富良野町西4線北');
ok($zip->set_number('0710505')->is_valid_number, '北海道空知郡上富良野町西5線北');
ok($zip->set_number('0710506')->is_valid_number, '北海道空知郡上富良野町西6線北');
ok($zip->set_number('0710507')->is_valid_number, '北海道空知郡上富良野町西7線北');
ok($zip->set_number('0710508')->is_valid_number, '北海道空知郡上富良野町西8線北');
ok($zip->set_number('0710509')->is_valid_number, '北海道空知郡上富良野町西9線北');
ok($zip->set_number('0710510')->is_valid_number, '北海道空知郡上富良野町西10線北');
ok($zip->set_number('0710511')->is_valid_number, '北海道空知郡上富良野町西11線北');
ok($zip->set_number('0710512')->is_valid_number, '北海道空知郡上富良野町西12線北');
ok($zip->set_number('0710513')->is_valid_number, '北海道空知郡上富良野町西13線北');
ok($zip->set_number('0710514')->is_valid_number, '北海道空知郡上富良野町西14線北');
ok($zip->set_number('0710515')->is_valid_number, '北海道空知郡上富良野町西15線北');
ok($zip->set_number('0710516')->is_valid_number, '北海道空知郡上富良野町西16線北');
ok($zip->set_number('0710517')->is_valid_number, '北海道空知郡上富良野町沼崎農場');
ok($zip->set_number('0710520')->is_valid_number, '北海道空知郡上富良野町基線北');
ok($zip->set_number('0710521')->is_valid_number, '北海道空知郡上富良野町東1線北');
ok($zip->set_number('0710522')->is_valid_number, '北海道空知郡上富良野町東2線北');
ok($zip->set_number('0710523')->is_valid_number, '北海道空知郡上富良野町東3線北');
ok($zip->set_number('0710524')->is_valid_number, '北海道空知郡上富良野町東4線北');
ok($zip->set_number('0710525')->is_valid_number, '北海道空知郡上富良野町東5線北');
ok($zip->set_number('0710526')->is_valid_number, '北海道空知郡上富良野町東6線北');
ok($zip->set_number('0710527')->is_valid_number, '北海道空知郡上富良野町東7線北');
ok($zip->set_number('0710528')->is_valid_number, '北海道空知郡上富良野町東8線北');
ok($zip->set_number('0710529')->is_valid_number, '北海道空知郡上富良野町東9線北');
ok($zip->set_number('0710530')->is_valid_number, '北海道空知郡上富良野町東10線北');
ok($zip->set_number('0710531')->is_valid_number, '北海道空知郡上富良野町東11線北');
ok($zip->set_number('0710532')->is_valid_number, '北海道空知郡上富良野町東12線北');
ok($zip->set_number('0710533')->is_valid_number, '北海道空知郡上富良野町倍本農場');
ok($zip->set_number('0710534')->is_valid_number, '北海道空知郡上富良野町西谷牧場');
ok($zip->set_number('0710541')->is_valid_number, '北海道空知郡上富良野町富町');
ok($zip->set_number('0710542')->is_valid_number, '北海道空知郡上富良野町錦町');
ok($zip->set_number('0710543')->is_valid_number, '北海道空知郡上富良野町中町');
ok($zip->set_number('0710544')->is_valid_number, '北海道空知郡上富良野町栄町');
ok($zip->set_number('0710545')->is_valid_number, '北海道空知郡上富良野町光町');
ok($zip->set_number('0710546')->is_valid_number, '北海道空知郡上富良野町西町');
ok($zip->set_number('0710547')->is_valid_number, '北海道空知郡上富良野町泉町');
ok($zip->set_number('0710548')->is_valid_number, '北海道空知郡上富良野町扇町');
ok($zip->set_number('0710549')->is_valid_number, '北海道空知郡上富良野町北町');
ok($zip->set_number('0710551')->is_valid_number, '北海道空知郡上富良野町本町');
ok($zip->set_number('0710552')->is_valid_number, '北海道空知郡上富良野町宮町');
ok($zip->set_number('0710553')->is_valid_number, '北海道空知郡上富良野町旭町');
ok($zip->set_number('0710554')->is_valid_number, '北海道空知郡上富良野町新町');
ok($zip->set_number('0710555')->is_valid_number, '北海道空知郡上富良野町東町');
ok($zip->set_number('0710561')->is_valid_number, '北海道空知郡上富良野町大町');
ok($zip->set_number('0710562')->is_valid_number, '北海道空知郡上富良野町南町');
ok($zip->set_number('0710563')->is_valid_number, '北海道空知郡上富良野町緑町');
ok($zip->set_number('0710564')->is_valid_number, '北海道空知郡上富良野町桜町');
ok($zip->set_number('0710565')->is_valid_number, '北海道空知郡上富良野町丘町');
ok($zip->set_number('0710566')->is_valid_number, '北海道空知郡上富良野町向町');
ok($zip->set_number('0710571')->is_valid_number, '北海道空知郡上富良野町新井牧場');
ok($zip->set_number('0710572')->is_valid_number, '北海道空知郡上富良野町細野農場');
ok($zip->set_number('0710573')->is_valid_number, '北海道空知郡上富良野町松井牧場');
ok($zip->set_number('0710574')->is_valid_number, '北海道空知郡上富良野町第1安井牧場');
ok($zip->set_number('0710575')->is_valid_number, '北海道空知郡上富良野町第2安井牧場');
ok($zip->set_number('0710576')->is_valid_number, '北海道空知郡上富良野町十人牧場');
ok($zip->set_number('0710577')->is_valid_number, '北海道空知郡上富良野町中の沢');
ok($zip->set_number('0710578')->is_valid_number, '北海道空知郡上富良野町山加農場');
ok($zip->set_number('0710579')->is_valid_number, '北海道空知郡上富良野町吹上');
ok($zip->set_number('0710583')->is_valid_number, '北海道空知郡上富良野町津郷農場');
ok($zip->set_number('0710700')->is_valid_number, '北海道空知郡中富良野町以下に掲載がない場合');
ok($zip->set_number('0710704')->is_valid_number, '北海道空知郡中富良野町基線北');
ok($zip->set_number('0710705')->is_valid_number, '北海道空知郡中富良野町西1線北');
ok($zip->set_number('0710706')->is_valid_number, '北海道空知郡中富良野町西2線北');
ok($zip->set_number('0710707')->is_valid_number, '北海道空知郡中富良野町西3線北');
ok($zip->set_number('0710711')->is_valid_number, '北海道空知郡中富良野町ベベルイ(本幸、北13号沢)');
ok($zip->set_number('0710714')->is_valid_number, '北海道空知郡中富良野町宮町');
ok($zip->set_number('0710726')->is_valid_number, '北海道空知郡中富良野町東町');
ok($zip->set_number('0710731')->is_valid_number, '北海道空知郡中富良野町新田中農場');
ok($zip->set_number('0710732')->is_valid_number, '北海道空知郡中富良野町田中農場(鈴和、山仁農場、山仁牧場)');
ok($zip->set_number('0710733')->is_valid_number, '北海道空知郡中富良野町伊藤農場(渋毛牛)');
ok($zip->set_number('0710734')->is_valid_number, '北海道空知郡中富良野町鹿討農場(鹿討)');
ok($zip->set_number('0710735')->is_valid_number, '北海道空知郡中富良野町日進');
ok($zip->set_number('0710736')->is_valid_number, '北海道空知郡中富良野町吉井農場(吉井)');
ok($zip->set_number('0710737')->is_valid_number, '北海道空知郡中富良野町奈江');
ok($zip->set_number('0710742')->is_valid_number, '北海道空知郡中富良野町福原農場(福原)');
ok($zip->set_number('0710751')->is_valid_number, '北海道空知郡中富良野町北町');
ok($zip->set_number('0710752')->is_valid_number, '北海道空知郡中富良野町本町');
ok($zip->set_number('0710753')->is_valid_number, '北海道空知郡中富良野町南町');
ok($zip->set_number('0710754')->is_valid_number, '北海道空知郡中富良野町新町');
ok($zip->set_number('0710755')->is_valid_number, '北海道空知郡中富良野町旭町');
ok($zip->set_number('0710761')->is_valid_number, '北海道空知郡中富良野町西町');
ok($zip->set_number('0710762')->is_valid_number, '北海道空知郡中富良野町丘町');
ok($zip->set_number('0710770')->is_valid_number, '北海道空知郡中富良野町暁町');
ok($zip->set_number('0710771')->is_valid_number, '北海道空知郡中富良野町東1線北');
ok($zip->set_number('0710772')->is_valid_number, '北海道空知郡中富良野町東2線北');
ok($zip->set_number('0710773')->is_valid_number, '北海道空知郡中富良野町東3線北');
ok($zip->set_number('0710774')->is_valid_number, '北海道空知郡中富良野町東4線北');
ok($zip->set_number('0710775')->is_valid_number, '北海道空知郡中富良野町東5線北');
ok($zip->set_number('0710776')->is_valid_number, '北海道空知郡中富良野町東6線北');
ok($zip->set_number('0710777')->is_valid_number, '北海道空知郡中富良野町東7線北');
ok($zip->set_number('0710778')->is_valid_number, '北海道空知郡中富良野町東8線北');
ok($zip->set_number('0710779')->is_valid_number, '北海道空知郡中富良野町東9線北');
ok($zip->set_number('0710780')->is_valid_number, '北海道空知郡中富良野町東10線北');
ok($zip->set_number('0710781')->is_valid_number, '北海道空知郡中富良野町東11線北');
ok($zip->set_number('0711171')->is_valid_number, '北海道旭川市江丹別町清水');
ok($zip->set_number('0711172')->is_valid_number, '北海道旭川市江丹別町拓北');
ok($zip->set_number('0711173')->is_valid_number, '北海道旭川市江丹別町中央');
ok($zip->set_number('0711174')->is_valid_number, '北海道旭川市江丹別町富原');
ok($zip->set_number('0711175')->is_valid_number, '北海道旭川市江丹別町中園');
ok($zip->set_number('0711176')->is_valid_number, '北海道旭川市江丹別町西里');
ok($zip->set_number('0711177')->is_valid_number, '北海道旭川市江丹別町芳野');
ok($zip->set_number('0711200')->is_valid_number, '北海道上川郡鷹栖町以下に掲載がない場合');
ok($zip->set_number('0711201')->is_valid_number, '北海道上川郡鷹栖町南一条');
ok($zip->set_number('0711202')->is_valid_number, '北海道上川郡鷹栖町南二条');
ok($zip->set_number('0711211')->is_valid_number, '北海道上川郡鷹栖町北一条');
ok($zip->set_number('0711221')->is_valid_number, '北海道上川郡鷹栖町北野東一条');
ok($zip->set_number('0711222')->is_valid_number, '北海道上川郡鷹栖町北野東二条');
ok($zip->set_number('0711223')->is_valid_number, '北海道上川郡鷹栖町北野東三条');
ok($zip->set_number('0711224')->is_valid_number, '北海道上川郡鷹栖町北野東四条');
ok($zip->set_number('0711225')->is_valid_number, '北海道上川郡鷹栖町北野東五条');
ok($zip->set_number('0711231')->is_valid_number, '北海道上川郡鷹栖町北野西一条');
ok($zip->set_number('0711232')->is_valid_number, '北海道上川郡鷹栖町北野西二条');
ok($zip->set_number('0711233')->is_valid_number, '北海道上川郡鷹栖町北野西三条');
ok($zip->set_number('0711234')->is_valid_number, '北海道上川郡鷹栖町北野西四条');
ok($zip->set_number('0711235')->is_valid_number, '北海道上川郡鷹栖町北野西五条');
ok($zip->set_number('0711247')->is_valid_number, '北海道上川郡鷹栖町7線');
ok($zip->set_number('0711248')->is_valid_number, '北海道上川郡鷹栖町8線');
ok($zip->set_number('0711249')->is_valid_number, '北海道上川郡鷹栖町9線');
ok($zip->set_number('0711250')->is_valid_number, '北海道上川郡鷹栖町10線');
ok($zip->set_number('0711251')->is_valid_number, '北海道上川郡鷹栖町11線');
ok($zip->set_number('0711252')->is_valid_number, '北海道上川郡鷹栖町12線');
ok($zip->set_number('0711253')->is_valid_number, '北海道上川郡鷹栖町13線');
ok($zip->set_number('0711254')->is_valid_number, '北海道上川郡鷹栖町14線');
ok($zip->set_number('0711255')->is_valid_number, '北海道上川郡鷹栖町15線');
ok($zip->set_number('0711256')->is_valid_number, '北海道上川郡鷹栖町16線');
ok($zip->set_number('0711257')->is_valid_number, '北海道上川郡鷹栖町17線');
ok($zip->set_number('0711258')->is_valid_number, '北海道上川郡鷹栖町18線');
ok($zip->set_number('0711259')->is_valid_number, '北海道上川郡鷹栖町19線');
ok($zip->set_number('0711260')->is_valid_number, '北海道上川郡鷹栖町20線');
ok($zip->set_number('0711261')->is_valid_number, '北海道上川郡鷹栖町21線');
ok($zip->set_number('0711262')->is_valid_number, '北海道上川郡鷹栖町22線');
ok($zip->set_number('0711263')->is_valid_number, '北海道上川郡鷹栖町23線');
ok($zip->set_number('0711264')->is_valid_number, '北海道上川郡鷹栖町24線');
ok($zip->set_number('0711265')->is_valid_number, '北海道上川郡鷹栖町25線');
ok($zip->set_number('0711266')->is_valid_number, '北海道上川郡鷹栖町26線');
ok($zip->set_number('0711267')->is_valid_number, '北海道上川郡鷹栖町27線');
ok($zip->set_number('0711400')->is_valid_number, '北海道上川郡東川町以下に掲載がない場合');
ok($zip->set_number('0711402')->is_valid_number, '北海道上川郡東川町西2号北');
ok($zip->set_number('0711403')->is_valid_number, '北海道上川郡東川町西3号北');
ok($zip->set_number('0711404')->is_valid_number, '北海道上川郡東川町西4号北');
ok($zip->set_number('0711405')->is_valid_number, '北海道上川郡東川町西5号北');
ok($zip->set_number('0711406')->is_valid_number, '北海道上川郡東川町西6号北');
ok($zip->set_number('0711407')->is_valid_number, '北海道上川郡東川町西7号北');
ok($zip->set_number('0711408')->is_valid_number, '北海道上川郡東川町西8号北');
ok($zip->set_number('0711409')->is_valid_number, '北海道上川郡東川町西9号北');
ok($zip->set_number('0711410')->is_valid_number, '北海道上川郡東川町西10号北');
ok($zip->set_number('0711411')->is_valid_number, '北海道上川郡東川町西11号北');
ok($zip->set_number('0711412')->is_valid_number, '北海道上川郡東川町西12号北');
ok($zip->set_number('0711413')->is_valid_number, '北海道上川郡東川町新栄東');
ok($zip->set_number('0711414')->is_valid_number, '北海道上川郡東川町新栄南');
ok($zip->set_number('0711415')->is_valid_number, '北海道上川郡東川町新栄西');
ok($zip->set_number('0711416')->is_valid_number, '北海道上川郡東川町新栄北');
ok($zip->set_number('0711418')->is_valid_number, '北海道上川郡東川町キトウシ南');
ok($zip->set_number('0711419')->is_valid_number, '北海道上川郡東川町キトウシ西');
ok($zip->set_number('0711422')->is_valid_number, '北海道上川郡東川町西2号南');
ok($zip->set_number('0711423')->is_valid_number, '北海道上川郡東川町東町');
ok($zip->set_number('0711424')->is_valid_number, '北海道上川郡東川町南町');
ok($zip->set_number('0711425')->is_valid_number, '北海道上川郡東川町西町');
ok($zip->set_number('0711426')->is_valid_number, '北海道上川郡東川町北町');
ok($zip->set_number('0711431')->is_valid_number, '北海道上川郡東川町1号北');
ok($zip->set_number('0711432')->is_valid_number, '北海道上川郡東川町東2号北');
ok($zip->set_number('0711433')->is_valid_number, '北海道上川郡東川町東3号北');
ok($zip->set_number('0711434')->is_valid_number, '北海道上川郡東川町東4号北');
ok($zip->set_number('0711435')->is_valid_number, '北海道上川郡東川町東5号北');
ok($zip->set_number('0711436')->is_valid_number, '北海道上川郡東川町東6号北');
ok($zip->set_number('0711437')->is_valid_number, '北海道上川郡東川町東7号北');
ok($zip->set_number('0711438')->is_valid_number, '北海道上川郡東川町東8号北');
ok($zip->set_number('0711439')->is_valid_number, '北海道上川郡東川町東9号北');
ok($zip->set_number('0711440')->is_valid_number, '北海道上川郡東川町東10号北');
ok($zip->set_number('0711441')->is_valid_number, '北海道上川郡東川町東11号北');
ok($zip->set_number('0711442')->is_valid_number, '北海道上川郡東川町東12号北');
ok($zip->set_number('0711451')->is_valid_number, '北海道上川郡東川町1号南');
ok($zip->set_number('0711452')->is_valid_number, '北海道上川郡東川町東2号南');
ok($zip->set_number('0711453')->is_valid_number, '北海道上川郡東川町東3号南');
ok($zip->set_number('0711454')->is_valid_number, '北海道上川郡東川町東4号南');
ok($zip->set_number('0711455')->is_valid_number, '北海道上川郡東川町東5号南');
ok($zip->set_number('0711456')->is_valid_number, '北海道上川郡東川町東6号南');
ok($zip->set_number('0711457')->is_valid_number, '北海道上川郡東川町東7号南');
ok($zip->set_number('0711458')->is_valid_number, '北海道上川郡東川町東8号南');
ok($zip->set_number('0711459')->is_valid_number, '北海道上川郡東川町東9号南');
ok($zip->set_number('0711460')->is_valid_number, '北海道上川郡東川町東10号南');
ok($zip->set_number('0711461')->is_valid_number, '北海道上川郡東川町東11号南');
ok($zip->set_number('0711462')->is_valid_number, '北海道上川郡東川町北2線東');
ok($zip->set_number('0711463')->is_valid_number, '北海道上川郡東川町北3線東');
ok($zip->set_number('0711464')->is_valid_number, '北海道上川郡東川町進化台');
ok($zip->set_number('0711465')->is_valid_number, '北海道上川郡東川町北5線');
ok($zip->set_number('0711466')->is_valid_number, '北海道上川郡東川町北7線');
ok($zip->set_number('0711467')->is_valid_number, '北海道上川郡東川町北7線東');
ok($zip->set_number('0711471')->is_valid_number, '北海道上川郡東川町ノカナン');
ok($zip->set_number('0711472')->is_valid_number, '北海道上川郡東川町勇駒別');
ok($zip->set_number('0711473')->is_valid_number, '北海道上川郡東川町松山温泉');
ok($zip->set_number('0711474')->is_valid_number, '北海道上川郡美瑛町忠別');
ok($zip->set_number('0711500')->is_valid_number, '北海道上川郡東神楽町以下に掲載がない場合');
ok($zip->set_number('0711501')->is_valid_number, '北海道上川郡東神楽町南一条西');
ok($zip->set_number('0711502')->is_valid_number, '北海道上川郡東神楽町南一条東');
ok($zip->set_number('0711503')->is_valid_number, '北海道上川郡東神楽町南二条西');
ok($zip->set_number('0711504')->is_valid_number, '北海道上川郡東神楽町南二条東');
ok($zip->set_number('0711505')->is_valid_number, '北海道上川郡東神楽町南三条東');
ok($zip->set_number('0711511')->is_valid_number, '北海道上川郡東神楽町北一条西');
ok($zip->set_number('0711512')->is_valid_number, '北海道上川郡東神楽町北一条東');
ok($zip->set_number('0711513')->is_valid_number, '北海道上川郡東神楽町北二条西');
ok($zip->set_number('0711514')->is_valid_number, '北海道上川郡東神楽町北二条東');
ok($zip->set_number('0711515')->is_valid_number, '北海道上川郡東神楽町北三条東');
ok($zip->set_number('0711521')->is_valid_number, '北海道上川郡東神楽町ひじり野北一条');
ok($zip->set_number('0711522')->is_valid_number, '北海道上川郡東神楽町ひじり野北二条');
ok($zip->set_number('0711523')->is_valid_number, '北海道上川郡東神楽町ひじり野南一条');
ok($zip->set_number('0711524')->is_valid_number, '北海道上川郡東神楽町ひじり野南二条');
ok($zip->set_number('0711525')->is_valid_number, '北海道上川郡東神楽町ひじり野南三条');
ok($zip->set_number('0711533')->is_valid_number, '北海道上川郡東神楽町3号');
ok($zip->set_number('0711534')->is_valid_number, '北海道上川郡東神楽町4号');
ok($zip->set_number('0711535')->is_valid_number, '北海道上川郡東神楽町5号');
ok($zip->set_number('0711536')->is_valid_number, '北海道上川郡東神楽町6号');
ok($zip->set_number('0711537')->is_valid_number, '北海道上川郡東神楽町7号');
ok($zip->set_number('0711538')->is_valid_number, '北海道上川郡東神楽町8号');
ok($zip->set_number('0711539')->is_valid_number, '北海道上川郡東神楽町9号');
ok($zip->set_number('0711540')->is_valid_number, '北海道上川郡東神楽町10号');
ok($zip->set_number('0711541')->is_valid_number, '北海道上川郡東神楽町11号');
ok($zip->set_number('0711542')->is_valid_number, '北海道上川郡東神楽町12号');
ok($zip->set_number('0711543')->is_valid_number, '北海道上川郡東神楽町13号');
ok($zip->set_number('0711544')->is_valid_number, '北海道上川郡東神楽町14号');
ok($zip->set_number('0711545')->is_valid_number, '北海道上川郡東神楽町15号');
ok($zip->set_number('0711546')->is_valid_number, '北海道上川郡東神楽町16号');
ok($zip->set_number('0711547')->is_valid_number, '北海道上川郡東神楽町17号');
ok($zip->set_number('0711548')->is_valid_number, '北海道上川郡東神楽町18号');
ok($zip->set_number('0711549')->is_valid_number, '北海道上川郡東神楽町19号');
ok($zip->set_number('0711550')->is_valid_number, '北海道上川郡東神楽町20号');
ok($zip->set_number('0711551')->is_valid_number, '北海道上川郡東神楽町21号');
ok($zip->set_number('0711552')->is_valid_number, '北海道上川郡東神楽町22号');
ok($zip->set_number('0711553')->is_valid_number, '北海道上川郡東神楽町23号');
ok($zip->set_number('0711554')->is_valid_number, '北海道上川郡東神楽町24号');
ok($zip->set_number('0711555')->is_valid_number, '北海道上川郡東神楽町25号');
ok($zip->set_number('0711556')->is_valid_number, '北海道上川郡東神楽町26号');
ok($zip->set_number('0711557')->is_valid_number, '北海道上川郡東神楽町27号');
ok($zip->set_number('0711560')->is_valid_number, '北海道上川郡東神楽町基線');
ok($zip->set_number('0711561')->is_valid_number, '北海道上川郡東神楽町東一線');
ok($zip->set_number('0711562')->is_valid_number, '北海道上川郡東神楽町東二線');
ok($zip->set_number('0711563')->is_valid_number, '北海道上川郡東神楽町東三線');
ok($zip->set_number('0711564')->is_valid_number, '北海道上川郡東神楽町東四線');
ok($zip->set_number('0711565')->is_valid_number, '北海道上川郡東神楽町東五線');
ok($zip->set_number('0711570')->is_valid_number, '北海道上川郡東神楽町南13号');
ok($zip->set_number('0711571')->is_valid_number, '北海道上川郡東神楽町南1番通');
ok($zip->set_number('0711572')->is_valid_number, '北海道上川郡東神楽町南2線');
ok($zip->set_number('0711573')->is_valid_number, '北海道上川郡東神楽町南3線');
ok($zip->set_number('0711574')->is_valid_number, '北海道上川郡東神楽町南4線');
ok($zip->set_number('0711575')->is_valid_number, '北海道上川郡東神楽町南5線');
ok($zip->set_number('0711577')->is_valid_number, '北海道上川郡東神楽町八千代ケ岡');
ok($zip->set_number('0711581')->is_valid_number, '北海道上川郡東神楽町栄岡');
ok($zip->set_number('0711582')->is_valid_number, '北海道上川郡東神楽町志比内');
ok($zip->set_number('0718101')->is_valid_number, '北海道旭川市東鷹栖1条');
ok($zip->set_number('0718102')->is_valid_number, '北海道旭川市東鷹栖2条');
ok($zip->set_number('0718103')->is_valid_number, '北海道旭川市東鷹栖3条');
ok($zip->set_number('0718104')->is_valid_number, '北海道旭川市東鷹栖4条');
ok($zip->set_number('0718111')->is_valid_number, '北海道旭川市東鷹栖東1条');
ok($zip->set_number('0718112')->is_valid_number, '北海道旭川市東鷹栖東2条');
ok($zip->set_number('0718113')->is_valid_number, '北海道旭川市東鷹栖東3条');
ok($zip->set_number('0718114')->is_valid_number, '北海道旭川市東鷹栖東1線');
ok($zip->set_number('0718121')->is_valid_number, '北海道旭川市末広東1条');
ok($zip->set_number('0718122')->is_valid_number, '北海道旭川市末広東2条');
ok($zip->set_number('0718123')->is_valid_number, '北海道旭川市末広東3条');
ok($zip->set_number('0718130')->is_valid_number, '北海道旭川市物流団地1条');
ok($zip->set_number('0718131')->is_valid_number, '北海道旭川市末広1条');
ok($zip->set_number('0718132')->is_valid_number, '北海道旭川市末広2条');
ok($zip->set_number('0718133')->is_valid_number, '北海道旭川市末広3条');
ok($zip->set_number('0718134')->is_valid_number, '北海道旭川市末広4条');
ok($zip->set_number('0718135')->is_valid_number, '北海道旭川市末広5条');
ok($zip->set_number('0718136')->is_valid_number, '北海道旭川市末広6条');
ok($zip->set_number('0718137')->is_valid_number, '北海道旭川市末広7条');
ok($zip->set_number('0718138')->is_valid_number, '北海道旭川市末広8条');
ok($zip->set_number('0718139')->is_valid_number, '北海道旭川市物流団地2条');
ok($zip->set_number('0718141')->is_valid_number, '北海道旭川市春光台1条');
ok($zip->set_number('0718142')->is_valid_number, '北海道旭川市春光台2条');
ok($zip->set_number('0718143')->is_valid_number, '北海道旭川市春光台3条');
ok($zip->set_number('0718144')->is_valid_number, '北海道旭川市春光台4条');
ok($zip->set_number('0718145')->is_valid_number, '北海道旭川市春光台5条');
ok($zip->set_number('0718151')->is_valid_number, '北海道旭川市東鷹栖1線');
ok($zip->set_number('0718152')->is_valid_number, '北海道旭川市東鷹栖2線');
ok($zip->set_number('0718153')->is_valid_number, '北海道旭川市東鷹栖3線');
ok($zip->set_number('0718154')->is_valid_number, '北海道旭川市東鷹栖4線');
ok($zip->set_number('0718155')->is_valid_number, '北海道旭川市東鷹栖5線');
ok($zip->set_number('0718156')->is_valid_number, '北海道旭川市東鷹栖6線');
ok($zip->set_number('0718157')->is_valid_number, '北海道旭川市東鷹栖7線');
ok($zip->set_number('0718158')->is_valid_number, '北海道旭川市東鷹栖8線');
ok($zip->set_number('0718159')->is_valid_number, '北海道旭川市東鷹栖9線');
ok($zip->set_number('0718160')->is_valid_number, '北海道旭川市東鷹栖10線');
ok($zip->set_number('0718161')->is_valid_number, '北海道旭川市東鷹栖11線');
ok($zip->set_number('0718162')->is_valid_number, '北海道旭川市東鷹栖12線');
ok($zip->set_number('0718163')->is_valid_number, '北海道旭川市東鷹栖13線');
ok($zip->set_number('0718164')->is_valid_number, '北海道旭川市東鷹栖14線');
ok($zip->set_number('0718165')->is_valid_number, '北海道旭川市東鷹栖15線');
ok($zip->set_number('0718166')->is_valid_number, '北海道旭川市緑台');
ok($zip->set_number('0718171')->is_valid_number, '北海道旭川市東山');
ok($zip->set_number('0720000')->is_valid_number, '北海道美唄市以下に掲載がない場合');
ok($zip->set_number('0720001')->is_valid_number, '北海道美唄市大通東一条北');
ok($zip->set_number('0720002')->is_valid_number, '北海道美唄市東一条北');
ok($zip->set_number('0720003')->is_valid_number, '北海道美唄市東二条北');
ok($zip->set_number('0720004')->is_valid_number, '北海道美唄市東三条北');
ok($zip->set_number('0720005')->is_valid_number, '北海道美唄市東四条北');
ok($zip->set_number('0720006')->is_valid_number, '北海道美唄市東五条北');
ok($zip->set_number('0720007')->is_valid_number, '北海道美唄市東六条北');
ok($zip->set_number('0720008')->is_valid_number, '北海道美唄市癸巳町奔美唄');
ok($zip->set_number('0720009')->is_valid_number, '北海道美唄市癸巳町');
ok($zip->set_number('0720011')->is_valid_number, '北海道美唄市大通東一条南');
ok($zip->set_number('0720012')->is_valid_number, '北海道美唄市東一条南');
ok($zip->set_number('0720013')->is_valid_number, '北海道美唄市東二条南');
ok($zip->set_number('0720014')->is_valid_number, '北海道美唄市東三条南');
ok($zip->set_number('0720015')->is_valid_number, '北海道美唄市東四条南');
ok($zip->set_number('0720016')->is_valid_number, '北海道美唄市東五条南');
ok($zip->set_number('0720017')->is_valid_number, '北海道美唄市東六条南');
ok($zip->set_number('0720021')->is_valid_number, '北海道美唄市大通西一条北');
ok($zip->set_number('0720022')->is_valid_number, '北海道美唄市西一条北');
ok($zip->set_number('0720023')->is_valid_number, '北海道美唄市大通西一条南');
ok($zip->set_number('0720024')->is_valid_number, '北海道美唄市西一条南');
ok($zip->set_number('0720025')->is_valid_number, '北海道美唄市西二条南');
ok($zip->set_number('0720026')->is_valid_number, '北海道美唄市西三条南');
ok($zip->set_number('0720027')->is_valid_number, '北海道美唄市西四条南');
ok($zip->set_number('0720028')->is_valid_number, '北海道美唄市西五条南');
ok($zip->set_number('0720031')->is_valid_number, '北海道美唄市西二条北');
ok($zip->set_number('0720032')->is_valid_number, '北海道美唄市西三条北');
ok($zip->set_number('0720033')->is_valid_number, '北海道美唄市西四条北');
ok($zip->set_number('0720034')->is_valid_number, '北海道美唄市西五条北');
ok($zip->set_number('0720035')->is_valid_number, '北海道美唄市沼の内町中央');
ok($zip->set_number('0720036')->is_valid_number, '北海道美唄市沼の内町南');
ok($zip->set_number('0720037')->is_valid_number, '北海道美唄市沼の内町北');
ok($zip->set_number('0720038')->is_valid_number, '北海道美唄市沼の内町西');
ok($zip->set_number('0720041')->is_valid_number, '北海道美唄市進徳町東');
ok($zip->set_number('0720042')->is_valid_number, '北海道美唄市進徳町');
ok($zip->set_number('0720043')->is_valid_number, '北海道美唄市進徳町西');
ok($zip->set_number('0720044')->is_valid_number, '北海道美唄市一心町');
ok($zip->set_number('0720045')->is_valid_number, '北海道美唄市開発町南');
ok($zip->set_number('0720046')->is_valid_number, '北海道美唄市開発町北');
ok($zip->set_number('0720047')->is_valid_number, '北海道美唄市開発町親和');
ok($zip->set_number('0720051')->is_valid_number, '北海道美唄市上美唄町');
ok($zip->set_number('0720052')->is_valid_number, '北海道美唄市上美唄町東');
ok($zip->set_number('0720053')->is_valid_number, '北海道美唄市上美唄町中央');
ok($zip->set_number('0720054')->is_valid_number, '北海道美唄市上美唄町沼の端');
ok($zip->set_number('0720055')->is_valid_number, '北海道美唄市西美唄町元村');
ok($zip->set_number('0720056')->is_valid_number, '北海道美唄市西美唄町山形');
ok($zip->set_number('0720057')->is_valid_number, '北海道美唄市西美唄町大曲');
ok($zip->set_number('0720058')->is_valid_number, '北海道美唄市西美唄町富樫');
ok($zip->set_number('0720059')->is_valid_number, '北海道美唄市西美唄町元村美富');
ok($zip->set_number('0720801')->is_valid_number, '北海道美唄市東七条北');
ok($zip->set_number('0720802')->is_valid_number, '北海道美唄市東八条北');
ok($zip->set_number('0720803')->is_valid_number, '北海道美唄市東明一条');
ok($zip->set_number('0720804')->is_valid_number, '北海道美唄市東明二条');
ok($zip->set_number('0720805')->is_valid_number, '北海道美唄市東明三条');
ok($zip->set_number('0720806')->is_valid_number, '北海道美唄市東明四条');
ok($zip->set_number('0720807')->is_valid_number, '北海道美唄市東明五条');
ok($zip->set_number('0720808')->is_valid_number, '北海道美唄市東明町');
ok($zip->set_number('0720811')->is_valid_number, '北海道美唄市東七条南');
ok($zip->set_number('0720812')->is_valid_number, '北海道美唄市東八条南');
ok($zip->set_number('0720813')->is_valid_number, '北海道美唄市南美唄町旭町');
ok($zip->set_number('0720814')->is_valid_number, '北海道美唄市南美唄町山の手');
ok($zip->set_number('0720815')->is_valid_number, '北海道美唄市南美唄町南町');
ok($zip->set_number('0720816')->is_valid_number, '北海道美唄市南美唄町仲町');
ok($zip->set_number('0720817')->is_valid_number, '北海道美唄市南美唄町北町');
ok($zip->set_number('0720818')->is_valid_number, '北海道美唄市南美唄町中央通り');
ok($zip->set_number('0720819')->is_valid_number, '北海道美唄市共練町東');
ok($zip->set_number('0720819')->is_valid_number, '北海道美唄市共練町西');
ok($zip->set_number('0720821')->is_valid_number, '北海道美唄市南美唄町上');
ok($zip->set_number('0720822')->is_valid_number, '北海道美唄市南美唄町大通り');
ok($zip->set_number('0720823')->is_valid_number, '北海道美唄市南美唄町下');
ok($zip->set_number('0720824')->is_valid_number, '北海道美唄市南美唄町新富町');
ok($zip->set_number('0720825')->is_valid_number, '北海道美唄市南美唄町桜井町');
ok($zip->set_number('0720826')->is_valid_number, '北海道美唄市南美唄町栄町南');
ok($zip->set_number('0720827')->is_valid_number, '北海道美唄市南美唄町栄町北');
ok($zip->set_number('0720828')->is_valid_number, '北海道美唄市南美唄町西町');
ok($zip->set_number('0720831')->is_valid_number, '北海道美唄市落合町栄町');
ok($zip->set_number('0720832')->is_valid_number, '北海道美唄市落合町本町');
ok($zip->set_number('0720833')->is_valid_number, '北海道美唄市落合町緑が丘');
ok($zip->set_number('0720834')->is_valid_number, '北海道美唄市落合町住吉');
ok($zip->set_number('0720835')->is_valid_number, '北海道美唄市落合町入初');
ok($zip->set_number('0720841')->is_valid_number, '北海道美唄市盤の沢町滝の上');
ok($zip->set_number('0720842')->is_valid_number, '北海道美唄市盤の沢町本町');
ok($zip->set_number('0720843')->is_valid_number, '北海道美唄市盤の沢町高台');
ok($zip->set_number('0720844')->is_valid_number, '北海道美唄市盤の沢町桜が丘');
ok($zip->set_number('0720851')->is_valid_number, '北海道美唄市我路町一条');
ok($zip->set_number('0720852')->is_valid_number, '北海道美唄市我路町二条');
ok($zip->set_number('0720853')->is_valid_number, '北海道美唄市我路町三条');
ok($zip->set_number('0720854')->is_valid_number, '北海道美唄市我路町四条');
ok($zip->set_number('0720855')->is_valid_number, '北海道美唄市我路町公園通り');
ok($zip->set_number('0720856')->is_valid_number, '北海道美唄市我路町新町');
ok($zip->set_number('0720857')->is_valid_number, '北海道美唄市我路町菊水');
ok($zip->set_number('0730000')->is_valid_number, '北海道滝川市以下に掲載がない場合');
ok($zip->set_number('0730001')->is_valid_number, '北海道滝川市北滝の川');
ok($zip->set_number('0730002')->is_valid_number, '北海道滝川市屯田町西');
ok($zip->set_number('0730003')->is_valid_number, '北海道滝川市滝の川町西');
ok($zip->set_number('0730004')->is_valid_number, '北海道滝川市滝の川町東');
ok($zip->set_number('0730005')->is_valid_number, '北海道滝川市二の坂町東');
ok($zip->set_number('0730006')->is_valid_number, '北海道滝川市二の坂町西');
ok($zip->set_number('0730011')->is_valid_number, '北海道滝川市黄金町西');
ok($zip->set_number('0730012')->is_valid_number, '北海道滝川市黄金町東');
ok($zip->set_number('0730013')->is_valid_number, '北海道滝川市南滝の川');
ok($zip->set_number('0730014')->is_valid_number, '北海道滝川市文京町');
ok($zip->set_number('0730015')->is_valid_number, '北海道滝川市朝日町東');
ok($zip->set_number('0730016')->is_valid_number, '北海道滝川市一の坂町東');
ok($zip->set_number('0730017')->is_valid_number, '北海道滝川市一の坂町西');
ok($zip->set_number('0730018')->is_valid_number, '北海道滝川市朝日町西');
ok($zip->set_number('0730021')->is_valid_number, '北海道滝川市本町');
ok($zip->set_number('0730022')->is_valid_number, '北海道滝川市大町');
ok($zip->set_number('0730023')->is_valid_number, '北海道滝川市緑町');
ok($zip->set_number('0730024')->is_valid_number, '北海道滝川市東町');
ok($zip->set_number('0730025')->is_valid_number, '北海道滝川市流通団地');
ok($zip->set_number('0730026')->is_valid_number, '北海道滝川市東滝川');
ok($zip->set_number('0730027')->is_valid_number, '北海道滝川市東滝川町');
ok($zip->set_number('0730031')->is_valid_number, '北海道滝川市栄町');
ok($zip->set_number('0730032')->is_valid_number, '北海道滝川市明神町');
ok($zip->set_number('0730033')->is_valid_number, '北海道滝川市新町');
ok($zip->set_number('0730034')->is_valid_number, '北海道滝川市空知町');
ok($zip->set_number('0730035')->is_valid_number, '北海道滝川市中島町');
ok($zip->set_number('0730036')->is_valid_number, '北海道滝川市花月町');
ok($zip->set_number('0730041')->is_valid_number, '北海道滝川市西滝川');
ok($zip->set_number('0730042')->is_valid_number, '北海道滝川市泉町');
ok($zip->set_number('0730043')->is_valid_number, '北海道滝川市幸町');
ok($zip->set_number('0730044')->is_valid_number, '北海道滝川市西町');
ok($zip->set_number('0730045')->is_valid_number, '北海道滝川市有明町');
ok($zip->set_number('0730046')->is_valid_number, '北海道滝川市扇町');
ok($zip->set_number('0730085')->is_valid_number, '北海道砂川市富平(その他)');
ok($zip->set_number('0730100')->is_valid_number, '北海道砂川市以下に掲載がない場合');
ok($zip->set_number('0730101')->is_valid_number, '北海道砂川市空知太東一条');
ok($zip->set_number('0730102')->is_valid_number, '北海道砂川市空知太東二条');
ok($zip->set_number('0730103')->is_valid_number, '北海道砂川市空知太東三条');
ok($zip->set_number('0730104')->is_valid_number, '北海道砂川市空知太東四条');
ok($zip->set_number('0730105')->is_valid_number, '北海道砂川市空知太東五条');
ok($zip->set_number('0730106')->is_valid_number, '北海道砂川市空知太(その他)');
ok($zip->set_number('0730107')->is_valid_number, '北海道砂川市一の沢');
ok($zip->set_number('0730108')->is_valid_number, '北海道砂川市北光');
ok($zip->set_number('0730111')->is_valid_number, '北海道砂川市晴見一条北');
ok($zip->set_number('0730112')->is_valid_number, '北海道砂川市晴見二条北');
ok($zip->set_number('0730113')->is_valid_number, '北海道砂川市晴見三条北');
ok($zip->set_number('0730114')->is_valid_number, '北海道砂川市晴見四条北');
ok($zip->set_number('0730115')->is_valid_number, '北海道砂川市焼山');
ok($zip->set_number('0730116')->is_valid_number, '北海道砂川市鶉');
ok($zip->set_number('0730117')->is_valid_number, '北海道砂川市南吉野町');
ok($zip->set_number('0730118')->is_valid_number, '北海道砂川市北吉野町');
ok($zip->set_number('0730121')->is_valid_number, '北海道砂川市吉野一条南');
ok($zip->set_number('0730122')->is_valid_number, '北海道砂川市吉野二条南');
ok($zip->set_number('0730123')->is_valid_number, '北海道砂川市吉野三条南');
ok($zip->set_number('0730124')->is_valid_number, '北海道砂川市吉野四条南');
ok($zip->set_number('0730125')->is_valid_number, '北海道砂川市宮城の沢');
ok($zip->set_number('0730126')->is_valid_number, '北海道砂川市東豊沼');
ok($zip->set_number('0730127')->is_valid_number, '北海道砂川市日の出一条南');
ok($zip->set_number('0730131')->is_valid_number, '北海道砂川市東一条南');
ok($zip->set_number('0730132')->is_valid_number, '北海道砂川市東二条南');
ok($zip->set_number('0730133')->is_valid_number, '北海道砂川市東三条南');
ok($zip->set_number('0730134')->is_valid_number, '北海道砂川市東四条南');
ok($zip->set_number('0730135')->is_valid_number, '北海道砂川市東五条南');
ok($zip->set_number('0730136')->is_valid_number, '北海道砂川市東六条南');
ok($zip->set_number('0730137')->is_valid_number, '北海道砂川市東七条南');
ok($zip->set_number('0730138')->is_valid_number, '北海道砂川市豊沼町');
ok($zip->set_number('0730141')->is_valid_number, '北海道砂川市西一条南');
ok($zip->set_number('0730142')->is_valid_number, '北海道砂川市西二条南');
ok($zip->set_number('0730143')->is_valid_number, '北海道砂川市西三条南');
ok($zip->set_number('0730144')->is_valid_number, '北海道砂川市西四条南');
ok($zip->set_number('0730145')->is_valid_number, '北海道砂川市西五条南');
ok($zip->set_number('0730146')->is_valid_number, '北海道砂川市西六条南');
ok($zip->set_number('0730147')->is_valid_number, '北海道砂川市西七条南');
ok($zip->set_number('0730148')->is_valid_number, '北海道砂川市西豊沼');
ok($zip->set_number('0730151')->is_valid_number, '北海道砂川市東一条北');
ok($zip->set_number('0730152')->is_valid_number, '北海道砂川市東二条北');
ok($zip->set_number('0730153')->is_valid_number, '北海道砂川市東三条北');
ok($zip->set_number('0730154')->is_valid_number, '北海道砂川市東四条北');
ok($zip->set_number('0730155')->is_valid_number, '北海道砂川市東五条北');
ok($zip->set_number('0730156')->is_valid_number, '北海道砂川市東六条北');
ok($zip->set_number('0730157')->is_valid_number, '北海道砂川市三砂町');
ok($zip->set_number('0730158')->is_valid_number, '北海道砂川市吉野一条北');
ok($zip->set_number('0730159')->is_valid_number, '北海道砂川市吉野二条北');
ok($zip->set_number('0730161')->is_valid_number, '北海道砂川市西一条北');
ok($zip->set_number('0730162')->is_valid_number, '北海道砂川市西二条北');
ok($zip->set_number('0730163')->is_valid_number, '北海道砂川市西三条北');
ok($zip->set_number('0730164')->is_valid_number, '北海道砂川市西四条北');
ok($zip->set_number('0730165')->is_valid_number, '北海道砂川市西五条北');
ok($zip->set_number('0730166')->is_valid_number, '北海道砂川市西六条北');
ok($zip->set_number('0730167')->is_valid_number, '北海道砂川市西七条北');
ok($zip->set_number('0730168')->is_valid_number, '北海道砂川市西八条北');
ok($zip->set_number('0730171')->is_valid_number, '北海道砂川市空知太西一条');
ok($zip->set_number('0730172')->is_valid_number, '北海道砂川市空知太西二条');
ok($zip->set_number('0730173')->is_valid_number, '北海道砂川市空知太西三条');
ok($zip->set_number('0730174')->is_valid_number, '北海道砂川市空知太西四条');
ok($zip->set_number('0730175')->is_valid_number, '北海道砂川市空知太西五条');
ok($zip->set_number('0730176')->is_valid_number, '北海道砂川市空知太西六条');
ok($zip->set_number('0730177')->is_valid_number, '北海道砂川市空知太(1~349番地)');
ok($zip->set_number('0730178')->is_valid_number, '北海道砂川市袋地');
ok($zip->set_number('0730181')->is_valid_number, '北海道樺戸郡新十津川町弥生(堤防用地)');
ok($zip->set_number('0730200')->is_valid_number, '北海道空知郡上砂川町以下に掲載がない場合');
ok($zip->set_number('0730201')->is_valid_number, '北海道空知郡上砂川町中央');
ok($zip->set_number('0730202')->is_valid_number, '北海道空知郡上砂川町東町');
ok($zip->set_number('0730203')->is_valid_number, '北海道空知郡上砂川町中町');
ok($zip->set_number('0730204')->is_valid_number, '北海道空知郡上砂川町本町');
ok($zip->set_number('0730205')->is_valid_number, '北海道空知郡上砂川町朝駒');
ok($zip->set_number('0730206')->is_valid_number, '北海道空知郡上砂川町東山');
ok($zip->set_number('0730211')->is_valid_number, '北海道空知郡上砂川町東鶉');
ok($zip->set_number('0730212')->is_valid_number, '北海道空知郡上砂川町鶉');
ok($zip->set_number('0730213')->is_valid_number, '北海道空知郡上砂川町緑が丘');
ok($zip->set_number('0730221')->is_valid_number, '北海道空知郡上砂川町鶉本町');
ok($zip->set_number('0730222')->is_valid_number, '北海道空知郡上砂川町下鶉');
ok($zip->set_number('0730400')->is_valid_number, '北海道歌志内市以下に掲載がない場合');
ok($zip->set_number('0730401')->is_valid_number, '北海道歌志内市上歌');
ok($zip->set_number('0730402')->is_valid_number, '北海道歌志内市東光');
ok($zip->set_number('0730403')->is_valid_number, '北海道歌志内市本町');
ok($zip->set_number('0730404')->is_valid_number, '北海道歌志内市歌神');
ok($zip->set_number('0730405')->is_valid_number, '北海道歌志内市神威');
ok($zip->set_number('0730406')->is_valid_number, '北海道歌志内市中村');
ok($zip->set_number('0730407')->is_valid_number, '北海道歌志内市文珠');
ok($zip->set_number('0731100')->is_valid_number, '北海道樺戸郡新十津川町以下に掲載がない場合');
ok($zip->set_number('0731101')->is_valid_number, '北海道樺戸郡新十津川町士寸');
ok($zip->set_number('0731102')->is_valid_number, '北海道樺戸郡新十津川町大和');
ok($zip->set_number('0731103')->is_valid_number, '北海道樺戸郡新十津川町中央');
ok($zip->set_number('0731104')->is_valid_number, '北海道樺戸郡新十津川町弥生(その他)');
ok($zip->set_number('0731105')->is_valid_number, '北海道樺戸郡新十津川町花月');
ok($zip->set_number('0731106')->is_valid_number, '北海道樺戸郡新十津川町総進');
ok($zip->set_number('0731107')->is_valid_number, '北海道樺戸郡新十津川町トップ');
ok($zip->set_number('0731321')->is_valid_number, '北海道樺戸郡新十津川町学園');
ok($zip->set_number('0731322')->is_valid_number, '北海道樺戸郡新十津川町吉野');
ok($zip->set_number('0731323')->is_valid_number, '北海道樺戸郡新十津川町幌加');
ok($zip->set_number('0740000')->is_valid_number, '北海道深川市以下に掲載がない場合');
ok($zip->set_number('0740001')->is_valid_number, '北海道深川市一条');
ok($zip->set_number('0740002')->is_valid_number, '北海道深川市二条');
ok($zip->set_number('0740003')->is_valid_number, '北海道深川市三条');
ok($zip->set_number('0740004')->is_valid_number, '北海道深川市四条');
ok($zip->set_number('0740005')->is_valid_number, '北海道深川市五条');
ok($zip->set_number('0740006')->is_valid_number, '北海道深川市六条');
ok($zip->set_number('0740007')->is_valid_number, '北海道深川市七条');
ok($zip->set_number('0740008')->is_valid_number, '北海道深川市八条');
ok($zip->set_number('0740009')->is_valid_number, '北海道深川市九条');
ok($zip->set_number('0740011')->is_valid_number, '北海道深川市緑町');
ok($zip->set_number('0740012')->is_valid_number, '北海道深川市西町');
ok($zip->set_number('0740013')->is_valid_number, '北海道深川市文光町');
ok($zip->set_number('0740014')->is_valid_number, '北海道深川市開西町');
ok($zip->set_number('0740015')->is_valid_number, '北海道深川市深川町メム');
ok($zip->set_number('0740016')->is_valid_number, '北海道深川市深川町オーホ');
ok($zip->set_number('0740021')->is_valid_number, '北海道深川市稲穂町');
ok($zip->set_number('0740022')->is_valid_number, '北海道深川市北光町');
ok($zip->set_number('0740023')->is_valid_number, '北海道深川市太子町');
ok($zip->set_number('0740024')->is_valid_number, '北海道深川市新光町');
ok($zip->set_number('0740025')->is_valid_number, '北海道深川市錦町');
ok($zip->set_number('0740026')->is_valid_number, '北海道深川市錦町西');
ok($zip->set_number('0740027')->is_valid_number, '北海道深川市錦町北');
ok($zip->set_number('0740028')->is_valid_number, '北海道深川市一已町');
ok($zip->set_number('0740031')->is_valid_number, '北海道深川市あけぼの町');
ok($zip->set_number('0740141')->is_valid_number, '北海道深川市多度志');
ok($zip->set_number('0740142')->is_valid_number, '北海道深川市宇摩');
ok($zip->set_number('0740143')->is_valid_number, '北海道深川市ウッカ');
ok($zip->set_number('0740144')->is_valid_number, '北海道深川市鷹泊');
ok($zip->set_number('0740145')->is_valid_number, '北海道深川市幌内');
ok($zip->set_number('0740146')->is_valid_number, '北海道深川市湯内');
ok($zip->set_number('0740147')->is_valid_number, '北海道深川市多度志南');
ok($zip->set_number('0740400')->is_valid_number, '北海道雨竜郡幌加内町以下に掲載がない場合');
ok($zip->set_number('0740401')->is_valid_number, '北海道雨竜郡幌加内町平和');
ok($zip->set_number('0740402')->is_valid_number, '北海道雨竜郡幌加内町新成生');
ok($zip->set_number('0740403')->is_valid_number, '北海道雨竜郡幌加内町下幌加内');
ok($zip->set_number('0740404')->is_valid_number, '北海道雨竜郡幌加内町沼牛');
ok($zip->set_number('0740405')->is_valid_number, '北海道雨竜郡幌加内町弥運内');
ok($zip->set_number('0740411')->is_valid_number, '北海道雨竜郡幌加内町幌加内');
ok($zip->set_number('0740412')->is_valid_number, '北海道雨竜郡幌加内町親和');
ok($zip->set_number('0740413')->is_valid_number, '北海道雨竜郡幌加内町雨煙内');
ok($zip->set_number('0740414')->is_valid_number, '北海道雨竜郡幌加内町清月');
ok($zip->set_number('0740415')->is_valid_number, '北海道雨竜郡幌加内町長留内');
ok($zip->set_number('0740421')->is_valid_number, '北海道雨竜郡幌加内町東栄');
ok($zip->set_number('0740422')->is_valid_number, '北海道雨竜郡幌加内町振興');
ok($zip->set_number('0740423')->is_valid_number, '北海道雨竜郡幌加内町上幌加内');
ok($zip->set_number('0740424')->is_valid_number, '北海道雨竜郡幌加内町雨煙別');
ok($zip->set_number('0740425')->is_valid_number, '北海道雨竜郡幌加内町政和第一');
ok($zip->set_number('0740426')->is_valid_number, '北海道雨竜郡幌加内町政和第二');
ok($zip->set_number('0740427')->is_valid_number, '北海道雨竜郡幌加内町政和第三');
ok($zip->set_number('0740741')->is_valid_number, '北海道雨竜郡幌加内町母子里');
ok($zip->set_number('0740742')->is_valid_number, '北海道雨竜郡幌加内町朱鞠内');
ok($zip->set_number('0740743')->is_valid_number, '北海道雨竜郡幌加内町共栄');
ok($zip->set_number('0740744')->is_valid_number, '北海道雨竜郡幌加内町大曲');
ok($zip->set_number('0740745')->is_valid_number, '北海道雨竜郡幌加内町北星');
ok($zip->set_number('0740746')->is_valid_number, '北海道雨竜郡幌加内町添牛内');
ok($zip->set_number('0740747')->is_valid_number, '北海道雨竜郡幌加内町新富');
ok($zip->set_number('0741161')->is_valid_number, '北海道深川市音江町(更進)');
ok($zip->set_number('0741162')->is_valid_number, '北海道深川市音江町(菊丘)');
ok($zip->set_number('0741163')->is_valid_number, '北海道深川市音江町(吉住)');
ok($zip->set_number('0741164')->is_valid_number, '北海道深川市音江町(国見23~298番地)');
ok($zip->set_number('0741181')->is_valid_number, '北海道旭川市神居町西丘(その他)');
ok($zip->set_number('0741182')->is_valid_number, '北海道旭川市神居町豊里');
ok($zip->set_number('0741271')->is_valid_number, '北海道深川市音江町(広里)');
ok($zip->set_number('0741271')->is_valid_number, '北海道深川市広里町(1~5丁目)');
ok($zip->set_number('0741272')->is_valid_number, '北海道深川市音江町(国見その他)');
ok($zip->set_number('0741273')->is_valid_number, '北海道深川市音江町(1~2丁目)');
ok($zip->set_number('0741273')->is_valid_number, '北海道深川市音江町(音江)');
ok($zip->set_number('0741274')->is_valid_number, '北海道深川市音江町(豊泉)');
ok($zip->set_number('0741275')->is_valid_number, '北海道深川市音江町(向陽)');
ok($zip->set_number('0741276')->is_valid_number, '北海道深川市音江町(稲田)');
ok($zip->set_number('0750000')->is_valid_number, '北海道芦別市以下に掲載がない場合');
ok($zip->set_number('0750001')->is_valid_number, '北海道芦別市北一条西');
ok($zip->set_number('0750002')->is_valid_number, '北海道芦別市北二条西');
ok($zip->set_number('0750003')->is_valid_number, '北海道芦別市北三条西');
ok($zip->set_number('0750004')->is_valid_number, '北海道芦別市北四条西');
ok($zip->set_number('0750005')->is_valid_number, '北海道芦別市北五条西');
ok($zip->set_number('0750006')->is_valid_number, '北海道芦別市北六条西');
ok($zip->set_number('0750007')->is_valid_number, '北海道芦別市北七条西');
ok($zip->set_number('0750011')->is_valid_number, '北海道芦別市北一条東');
ok($zip->set_number('0750012')->is_valid_number, '北海道芦別市北二条東');
ok($zip->set_number('0750013')->is_valid_number, '北海道芦別市北三条東');
ok($zip->set_number('0750014')->is_valid_number, '北海道芦別市北四条東');
ok($zip->set_number('0750015')->is_valid_number, '北海道芦別市北五条東');
ok($zip->set_number('0750016')->is_valid_number, '北海道芦別市北六条東');
ok($zip->set_number('0750017')->is_valid_number, '北海道芦別市福住町');
ok($zip->set_number('0750018')->is_valid_number, '北海道芦別市常磐町');
ok($zip->set_number('0750019')->is_valid_number, '北海道芦別市高根町');
ok($zip->set_number('0750021')->is_valid_number, '北海道芦別市南一条西');
ok($zip->set_number('0750031')->is_valid_number, '北海道芦別市南一条東');
ok($zip->set_number('0750032')->is_valid_number, '北海道芦別市南二条東');
ok($zip->set_number('0750033')->is_valid_number, '北海道芦別市南三条東');
ok($zip->set_number('0750034')->is_valid_number, '北海道芦別市幌内');
ok($zip->set_number('0750035')->is_valid_number, '北海道芦別市旭町油谷');
ok($zip->set_number('0750036')->is_valid_number, '北海道芦別市旭町');
ok($zip->set_number('0750041')->is_valid_number, '北海道芦別市本町');
ok($zip->set_number('0750161')->is_valid_number, '北海道芦別市西芦別町');
ok($zip->set_number('0750162')->is_valid_number, '北海道芦別市東頼城町');
ok($zip->set_number('0750163')->is_valid_number, '北海道芦別市緑泉町');
ok($zip->set_number('0750164')->is_valid_number, '北海道芦別市頼城町');
ok($zip->set_number('0750165')->is_valid_number, '北海道芦別市青木沢');
ok($zip->set_number('0750166')->is_valid_number, '北海道芦別市川岸');
ok($zip->set_number('0750167')->is_valid_number, '北海道芦別市中の丘町');
ok($zip->set_number('0750251')->is_valid_number, '北海道芦別市新城町');
ok($zip->set_number('0750252')->is_valid_number, '北海道芦別市黄金町');
ok($zip->set_number('0750253')->is_valid_number, '北海道芦別市豊岡町');
ok($zip->set_number('0750254')->is_valid_number, '北海道芦別市豊岡');
ok($zip->set_number('0760000')->is_valid_number, '北海道富良野市以下に掲載がない場合');
ok($zip->set_number('0760001')->is_valid_number, '北海道富良野市北扇山');
ok($zip->set_number('0760002')->is_valid_number, '北海道富良野市南扇山');
ok($zip->set_number('0760003')->is_valid_number, '北海道富良野市布部石綿');
ok($zip->set_number('0760004')->is_valid_number, '北海道富良野市布部市街地');
ok($zip->set_number('0760005')->is_valid_number, '北海道富良野市布部一');
ok($zip->set_number('0760006')->is_valid_number, '北海道富良野市西扇山');
ok($zip->set_number('0760007')->is_valid_number, '北海道富良野市南町');
ok($zip->set_number('0760008')->is_valid_number, '北海道富良野市扇町');
ok($zip->set_number('0760011')->is_valid_number, '北海道富良野市末広町');
ok($zip->set_number('0760012')->is_valid_number, '北海道富良野市下五区');
ok($zip->set_number('0760013')->is_valid_number, '北海道富良野市中五区');
ok($zip->set_number('0760014')->is_valid_number, '北海道富良野市上五区');
ok($zip->set_number('0760015')->is_valid_number, '北海道富良野市上御料');
ok($zip->set_number('0760016')->is_valid_number, '北海道富良野市中御料');
ok($zip->set_number('0760017')->is_valid_number, '北海道富良野市下御料');
ok($zip->set_number('0760018')->is_valid_number, '北海道富良野市弥生町');
ok($zip->set_number('0760021')->is_valid_number, '北海道富良野市緑町');
ok($zip->set_number('0760022')->is_valid_number, '北海道富良野市若葉町');
ok($zip->set_number('0760023')->is_valid_number, '北海道富良野市栄町');
ok($zip->set_number('0760024')->is_valid_number, '北海道富良野市幸町');
ok($zip->set_number('0760025')->is_valid_number, '北海道富良野市日の出町');
ok($zip->set_number('0760026')->is_valid_number, '北海道富良野市朝日町');
ok($zip->set_number('0760027')->is_valid_number, '北海道富良野市花園町');
ok($zip->set_number('0760028')->is_valid_number, '北海道富良野市錦町');
ok($zip->set_number('0760031')->is_valid_number, '北海道富良野市本町');
ok($zip->set_number('0760032')->is_valid_number, '北海道富良野市若松町');
ok($zip->set_number('0760033')->is_valid_number, '北海道富良野市新富町');
ok($zip->set_number('0760034')->is_valid_number, '北海道富良野市北の峰町');
ok($zip->set_number('0760035')->is_valid_number, '北海道富良野市学田三区');
ok($zip->set_number('0760036')->is_valid_number, '北海道富良野市島ノ下');
ok($zip->set_number('0760037')->is_valid_number, '北海道富良野市西町');
ok($zip->set_number('0760038')->is_valid_number, '北海道富良野市桂木町');
ok($zip->set_number('0760039')->is_valid_number, '北海道富良野市信濃沢');
ok($zip->set_number('0760041')->is_valid_number, '北海道富良野市東鳥沼');
ok($zip->set_number('0760042')->is_valid_number, '北海道富良野市西鳥沼');
ok($zip->set_number('0760043')->is_valid_number, '北海道富良野市南大沼');
ok($zip->set_number('0760044')->is_valid_number, '北海道富良野市北大沼');
ok($zip->set_number('0760045')->is_valid_number, '北海道富良野市東学田二区');
ok($zip->set_number('0760046')->is_valid_number, '北海道富良野市北斗町');
ok($zip->set_number('0760047')->is_valid_number, '北海道富良野市西学田二区');
ok($zip->set_number('0760048')->is_valid_number, '北海道富良野市清水山');
ok($zip->set_number('0760050')->is_valid_number, '北海道富良野市東雲町');
ok($zip->set_number('0760051')->is_valid_number, '北海道富良野市東麻町');
ok($zip->set_number('0760052')->is_valid_number, '北海道富良野市南麻町');
ok($zip->set_number('0760053')->is_valid_number, '北海道富良野市東町');
ok($zip->set_number('0760054')->is_valid_number, '北海道富良野市春日町');
ok($zip->set_number('0760055')->is_valid_number, '北海道富良野市西麻町');
ok($zip->set_number('0760056')->is_valid_number, '北海道富良野市瑞穂町');
ok($zip->set_number('0760057')->is_valid_number, '北海道富良野市住吉町');
ok($zip->set_number('0760058')->is_valid_number, '北海道富良野市新光町');
ok($zip->set_number('0760059')->is_valid_number, '北海道富良野市北麻町');
ok($zip->set_number('0760081')->is_valid_number, '北海道芦別市泉');
ok($zip->set_number('0760161')->is_valid_number, '北海道富良野市麓郷市街地');
ok($zip->set_number('0760162')->is_valid_number, '北海道富良野市東麓郷');
ok($zip->set_number('0760163')->is_valid_number, '北海道富良野市西麓郷');
ok($zip->set_number('0760164')->is_valid_number, '北海道富良野市南麓郷');
ok($zip->set_number('0760165')->is_valid_number, '北海道富良野市北麓郷');
ok($zip->set_number('0760171')->is_valid_number, '北海道富良野市布礼別市街地');
ok($zip->set_number('0760172')->is_valid_number, '北海道富良野市東布礼別');
ok($zip->set_number('0760173')->is_valid_number, '北海道富良野市西布礼別');
ok($zip->set_number('0760174')->is_valid_number, '北海道富良野市南布礼別');
ok($zip->set_number('0760175')->is_valid_number, '北海道富良野市北布礼別');
ok($zip->set_number('0760176')->is_valid_number, '北海道富良野市中布礼別');
ok($zip->set_number('0760181')->is_valid_number, '北海道富良野市東富丘');
ok($zip->set_number('0760182')->is_valid_number, '北海道富良野市西富丘');
ok($zip->set_number('0760183')->is_valid_number, '北海道富良野市富丘更生');
ok($zip->set_number('0760184')->is_valid_number, '北海道富良野市八幡丘');
ok($zip->set_number('0760201')->is_valid_number, '北海道富良野市西達布');
ok($zip->set_number('0760202')->is_valid_number, '北海道富良野市東山(その他)');
ok($zip->set_number('0760203')->is_valid_number, '北海道富良野市老節布');
ok($zip->set_number('0760204')->is_valid_number, '北海道富良野市平沢');
ok($zip->set_number('0770000')->is_valid_number, '北海道留萌市以下に掲載がない場合');
ok($zip->set_number('0770001')->is_valid_number, '北海道留萌市三泊町');
ok($zip->set_number('0770002')->is_valid_number, '北海道留萌市塩見町');
ok($zip->set_number('0770003')->is_valid_number, '北海道留萌市春日町');
ok($zip->set_number('0770004')->is_valid_number, '北海道留萌市元町');
ok($zip->set_number('0770005')->is_valid_number, '北海道留萌市船場町');
ok($zip->set_number('0770006')->is_valid_number, '北海道留萌市末広町');
ok($zip->set_number('0770007')->is_valid_number, '北海道留萌市栄町');
ok($zip->set_number('0770011')->is_valid_number, '北海道留萌市東雲町');
ok($zip->set_number('0770012')->is_valid_number, '北海道留萌市大和田');
ok($zip->set_number('0770013')->is_valid_number, '北海道留萌市潮静');
ok($zip->set_number('0770013')->is_valid_number, '北海道留萌市留萌原野(1~12線)');
ok($zip->set_number('0770014')->is_valid_number, '北海道留萌市南町');
ok($zip->set_number('0770015')->is_valid_number, '北海道留萌市緑ケ丘町');
ok($zip->set_number('0770016')->is_valid_number, '北海道留萌市元川町');
ok($zip->set_number('0770021')->is_valid_number, '北海道留萌市高砂町');
ok($zip->set_number('0770022')->is_valid_number, '北海道留萌市堀川町');
ok($zip->set_number('0770023')->is_valid_number, '北海道留萌市五十嵐町');
ok($zip->set_number('0770024')->is_valid_number, '北海道留萌市千鳥町');
ok($zip->set_number('0770025')->is_valid_number, '北海道留萌市野本町');
ok($zip->set_number('0770026')->is_valid_number, '北海道留萌市泉町');
ok($zip->set_number('0770027')->is_valid_number, '北海道留萌市住之江町');
ok($zip->set_number('0770028')->is_valid_number, '北海道留萌市花園町');
ok($zip->set_number('0770031')->is_valid_number, '北海道留萌市幸町');
ok($zip->set_number('0770032')->is_valid_number, '北海道留萌市宮園町');
ok($zip->set_number('0770033')->is_valid_number, '北海道留萌市見晴町');
ok($zip->set_number('0770034')->is_valid_number, '北海道留萌市平和台');
ok($zip->set_number('0770035')->is_valid_number, '北海道留萌市礼受町');
ok($zip->set_number('0770036')->is_valid_number, '北海道留萌市浜中町');
ok($zip->set_number('0770037')->is_valid_number, '北海道留萌市沖見町');
ok($zip->set_number('0770038')->is_valid_number, '北海道留萌市寿町');
ok($zip->set_number('0770041')->is_valid_number, '北海道留萌市明元町');
ok($zip->set_number('0770042')->is_valid_number, '北海道留萌市開運町');
ok($zip->set_number('0770043')->is_valid_number, '北海道留萌市旭町');
ok($zip->set_number('0770044')->is_valid_number, '北海道留萌市錦町');
ok($zip->set_number('0770045')->is_valid_number, '北海道留萌市本町');
ok($zip->set_number('0770046')->is_valid_number, '北海道留萌市港町');
ok($zip->set_number('0770047')->is_valid_number, '北海道留萌市瀬越町');
ok($zip->set_number('0770048')->is_valid_number, '北海道留萌市大町');
ok($zip->set_number('0770131')->is_valid_number, '北海道増毛郡増毛町阿分');
ok($zip->set_number('0770132')->is_valid_number, '北海道増毛郡増毛町舎熊(その他)');
ok($zip->set_number('0770133')->is_valid_number, '北海道増毛郡増毛町信砂');
ok($zip->set_number('0770134')->is_valid_number, '北海道増毛郡増毛町御料');
ok($zip->set_number('0770200')->is_valid_number, '北海道増毛郡増毛町以下に掲載がない場合');
ok($zip->set_number('0770201')->is_valid_number, '北海道増毛郡増毛町永寿町');
ok($zip->set_number('0770202')->is_valid_number, '北海道増毛郡増毛町野塚町');
ok($zip->set_number('0770203')->is_valid_number, '北海道増毛郡増毛町稲葉海岸町');
ok($zip->set_number('0770204')->is_valid_number, '北海道増毛郡増毛町稲葉町');
ok($zip->set_number('0770205')->is_valid_number, '北海道増毛郡増毛町弁天町');
ok($zip->set_number('0770206')->is_valid_number, '北海道増毛郡増毛町中歌');
ok($zip->set_number('0770207')->is_valid_number, '北海道増毛郡増毛町箸別');
ok($zip->set_number('0770208')->is_valid_number, '北海道増毛郡増毛町湯の沢');
ok($zip->set_number('0770209')->is_valid_number, '北海道増毛郡増毛町舎熊(917番地)');
ok($zip->set_number('0770211')->is_valid_number, '北海道増毛郡増毛町暑寒海岸町');
ok($zip->set_number('0770212')->is_valid_number, '北海道増毛郡増毛町七源町');
ok($zip->set_number('0770213')->is_valid_number, '北海道増毛郡増毛町畠中北町');
ok($zip->set_number('0770214')->is_valid_number, '北海道増毛郡増毛町畠中町');
ok($zip->set_number('0770215')->is_valid_number, '北海道増毛郡増毛町暑寒町');
ok($zip->set_number('0770216')->is_valid_number, '北海道増毛郡増毛町暑寒沢');
ok($zip->set_number('0770217')->is_valid_number, '北海道増毛郡増毛町別苅');
ok($zip->set_number('0770218')->is_valid_number, '北海道増毛郡増毛町栄町');
ok($zip->set_number('0770221')->is_valid_number, '北海道増毛郡増毛町港町');
ok($zip->set_number('0770222')->is_valid_number, '北海道増毛郡増毛町見晴町');
ok($zip->set_number('0770223')->is_valid_number, '北海道増毛郡増毛町南永寿町');
ok($zip->set_number('0770224')->is_valid_number, '北海道増毛郡増毛町南畠中町');
ok($zip->set_number('0770225')->is_valid_number, '北海道増毛郡増毛町南暑寒町');
ok($zip->set_number('0770341')->is_valid_number, '北海道増毛郡増毛町雄冬');
ok($zip->set_number('0770344')->is_valid_number, '北海道増毛郡増毛町岩老');
ok($zip->set_number('0770345')->is_valid_number, '北海道増毛郡増毛町岩尾');
ok($zip->set_number('0770351')->is_valid_number, '北海道石狩市浜益区雄冬');
ok($zip->set_number('0770461')->is_valid_number, '北海道留萌郡小平町川上');
ok($zip->set_number('0770462')->is_valid_number, '北海道留萌郡小平町滝下');
ok($zip->set_number('0770463')->is_valid_number, '北海道留萌郡小平町達布');
ok($zip->set_number('0770464')->is_valid_number, '北海道留萌郡小平町住吉');
ok($zip->set_number('0770465')->is_valid_number, '北海道留萌郡小平町寧楽');
ok($zip->set_number('0770466')->is_valid_number, '北海道留萌郡小平町平和(2区)');
ok($zip->set_number('0780151')->is_valid_number, '北海道深川市納内町');
ok($zip->set_number('0780152')->is_valid_number, '北海道深川市音江町(内園)');
ok($zip->set_number('0780153')->is_valid_number, '北海道深川市納内町北');
ok($zip->set_number('0780154')->is_valid_number, '北海道深川市納内町グリーンタウン');
ok($zip->set_number('0780185')->is_valid_number, '北海道旭川市神居町神居古潭');
ok($zip->set_number('0780186')->is_valid_number, '北海道旭川市神居町西丘(8~22番地)');
ok($zip->set_number('0780300')->is_valid_number, '北海道上川郡比布町以下に掲載がない場合');
ok($zip->set_number('0780310')->is_valid_number, '北海道上川郡比布町基線');
ok($zip->set_number('0780311')->is_valid_number, '北海道上川郡比布町南1線');
ok($zip->set_number('0780321')->is_valid_number, '北海道上川郡比布町北1線');
ok($zip->set_number('0780322')->is_valid_number, '北海道上川郡比布町北2線');
ok($zip->set_number('0780323')->is_valid_number, '北海道上川郡比布町北3線');
ok($zip->set_number('0780324')->is_valid_number, '北海道上川郡比布町北4線');
ok($zip->set_number('0780325')->is_valid_number, '北海道上川郡比布町北5線');
ok($zip->set_number('0780326')->is_valid_number, '北海道上川郡比布町北6線');
ok($zip->set_number('0780327')->is_valid_number, '北海道上川郡比布町北7線');
ok($zip->set_number('0780328')->is_valid_number, '北海道上川郡比布町北8線');
ok($zip->set_number('0780329')->is_valid_number, '北海道上川郡比布町北9線');
ok($zip->set_number('0780330')->is_valid_number, '北海道上川郡比布町北10線');
ok($zip->set_number('0780331')->is_valid_number, '北海道上川郡比布町北11線');
ok($zip->set_number('0780332')->is_valid_number, '北海道上川郡比布町北12線');
ok($zip->set_number('0780333')->is_valid_number, '北海道上川郡比布町北13線');
ok($zip->set_number('0780334')->is_valid_number, '北海道上川郡比布町北14線');
ok($zip->set_number('0780335')->is_valid_number, '北海道上川郡比布町北15線');
ok($zip->set_number('0780341')->is_valid_number, '北海道上川郡比布町市街地');
ok($zip->set_number('0780342')->is_valid_number, '北海道上川郡比布町西町');
ok($zip->set_number('0780343')->is_valid_number, '北海道上川郡比布町中町');
ok($zip->set_number('0780344')->is_valid_number, '北海道上川郡比布町緑町');
ok($zip->set_number('0780345')->is_valid_number, '北海道上川郡比布町南町');
ok($zip->set_number('0780346')->is_valid_number, '北海道上川郡比布町新町');
ok($zip->set_number('0780347')->is_valid_number, '北海道上川郡比布町東町');
ok($zip->set_number('0780348')->is_valid_number, '北海道上川郡比布町北町');
ok($zip->set_number('0780349')->is_valid_number, '北海道上川郡比布町寿町');
ok($zip->set_number('0781271')->is_valid_number, '北海道旭川市東旭川町東桜岡(その他)');
ok($zip->set_number('0781272')->is_valid_number, '北海道旭川市東旭川町豊田(その他)');
ok($zip->set_number('0781273')->is_valid_number, '北海道旭川市東旭川町米原');
ok($zip->set_number('0781274')->is_valid_number, '北海道旭川市東旭川町瑞穂');
ok($zip->set_number('0781300')->is_valid_number, '北海道上川郡当麻町以下に掲載がない場合');
ok($zip->set_number('0781303')->is_valid_number, '北海道上川郡当麻町三条西');
ok($zip->set_number('0781304')->is_valid_number, '北海道上川郡当麻町四条西');
ok($zip->set_number('0781305')->is_valid_number, '北海道上川郡当麻町五条西');
ok($zip->set_number('0781306')->is_valid_number, '北海道上川郡当麻町六条西');
ok($zip->set_number('0781313')->is_valid_number, '北海道上川郡当麻町三条東');
ok($zip->set_number('0781314')->is_valid_number, '北海道上川郡当麻町四条東');
ok($zip->set_number('0781315')->is_valid_number, '北海道上川郡当麻町五条東');
ok($zip->set_number('0781316')->is_valid_number, '北海道上川郡当麻町六条東');
ok($zip->set_number('0781324')->is_valid_number, '北海道上川郡当麻町四条南');
ok($zip->set_number('0781331')->is_valid_number, '北海道上川郡当麻町中央');
ok($zip->set_number('0781332')->is_valid_number, '北海道上川郡当麻町宇園別');
ok($zip->set_number('0781333')->is_valid_number, '北海道上川郡当麻町伊香牛');
ok($zip->set_number('0781334')->is_valid_number, '北海道上川郡当麻町北星');
ok($zip->set_number('0781335')->is_valid_number, '北海道上川郡当麻町緑郷');
ok($zip->set_number('0781337')->is_valid_number, '北海道上川郡当麻町東');
ok($zip->set_number('0781341')->is_valid_number, '北海道上川郡当麻町開明');
ok($zip->set_number('0781400')->is_valid_number, '北海道上川郡愛別町以下に掲載がない場合');
ok($zip->set_number('0781401')->is_valid_number, '北海道上川郡愛別町愛別');
ok($zip->set_number('0781402')->is_valid_number, '北海道上川郡愛別町東町');
ok($zip->set_number('0781403')->is_valid_number, '北海道上川郡愛別町南町');
ok($zip->set_number('0781404')->is_valid_number, '北海道上川郡愛別町北町');
ok($zip->set_number('0781405')->is_valid_number, '北海道上川郡愛別町本町');
ok($zip->set_number('0781411')->is_valid_number, '北海道上川郡愛別町金富');
ok($zip->set_number('0781412')->is_valid_number, '北海道上川郡愛別町厚生');
ok($zip->set_number('0781413')->is_valid_number, '北海道上川郡愛別町伏古');
ok($zip->set_number('0781414')->is_valid_number, '北海道上川郡愛別町協和');
ok($zip->set_number('0781415')->is_valid_number, '北海道上川郡愛別町徳星');
ok($zip->set_number('0781651')->is_valid_number, '北海道上川郡愛別町豊里');
ok($zip->set_number('0781652')->is_valid_number, '北海道上川郡愛別町中央');
ok($zip->set_number('0781653')->is_valid_number, '北海道上川郡愛別町愛山');
ok($zip->set_number('0781654')->is_valid_number, '北海道上川郡愛別町愛山町');
ok($zip->set_number('0781700')->is_valid_number, '北海道上川郡上川町以下に掲載がない場合');
ok($zip->set_number('0781701')->is_valid_number, '北海道上川郡上川町層雲峡');
ok($zip->set_number('0781711')->is_valid_number, '北海道上川郡上川町清川');
ok($zip->set_number('0781712')->is_valid_number, '北海道上川郡上川町白川');
ok($zip->set_number('0781721')->is_valid_number, '北海道上川郡上川町菊水');
ok($zip->set_number('0781722')->is_valid_number, '北海道上川郡上川町新光町');
ok($zip->set_number('0781731')->is_valid_number, '北海道上川郡上川町東雲');
ok($zip->set_number('0781732')->is_valid_number, '北海道上川郡上川町共進');
ok($zip->set_number('0781733')->is_valid_number, '北海道上川郡上川町栄町');
ok($zip->set_number('0781741')->is_valid_number, '北海道上川郡上川町中央町');
ok($zip->set_number('0781742')->is_valid_number, '北海道上川郡上川町西町');
ok($zip->set_number('0781743')->is_valid_number, '北海道上川郡上川町花園町');
ok($zip->set_number('0781744')->is_valid_number, '北海道上川郡上川町北町');
ok($zip->set_number('0781751')->is_valid_number, '北海道上川郡上川町本町');
ok($zip->set_number('0781752')->is_valid_number, '北海道上川郡上川町川端町');
ok($zip->set_number('0781753')->is_valid_number, '北海道上川郡上川町南町');
ok($zip->set_number('0781761')->is_valid_number, '北海道上川郡上川町旭町');
ok($zip->set_number('0781762')->is_valid_number, '北海道上川郡上川町新町');
ok($zip->set_number('0781763')->is_valid_number, '北海道上川郡上川町東町');
ok($zip->set_number('0781771')->is_valid_number, '北海道上川郡上川町中越');
ok($zip->set_number('0781772')->is_valid_number, '北海道上川郡上川町天幕');
ok($zip->set_number('0781773')->is_valid_number, '北海道上川郡上川町日東');
ok($zip->set_number('0781774')->is_valid_number, '北海道上川郡上川町豊原');
ok($zip->set_number('0781775')->is_valid_number, '北海道上川郡上川町越路');
ok($zip->set_number('0782100')->is_valid_number, '北海道雨竜郡秩父別町以下に掲載がない場合');
ok($zip->set_number('0782101')->is_valid_number, '北海道雨竜郡秩父別町1条');
ok($zip->set_number('0782102')->is_valid_number, '北海道雨竜郡秩父別町2条');
ok($zip->set_number('0782103')->is_valid_number, '北海道雨竜郡秩父別町3条');
ok($zip->set_number('0782104')->is_valid_number, '北海道雨竜郡秩父別町4条');
ok($zip->set_number('0782105')->is_valid_number, '北海道雨竜郡秩父別町5条');
ok($zip->set_number('0782106')->is_valid_number, '北海道雨竜郡秩父別町6条');
ok($zip->set_number('0782107')->is_valid_number, '北海道雨竜郡秩父別町7条');
ok($zip->set_number('0782108')->is_valid_number, '北海道雨竜郡秩父別町8条');
ok($zip->set_number('0782109')->is_valid_number, '北海道雨竜郡秩父別町9条');
ok($zip->set_number('0782111')->is_valid_number, '北海道雨竜郡秩父別町南1条');
ok($zip->set_number('0782112')->is_valid_number, '北海道雨竜郡秩父別町南2条');
ok($zip->set_number('0782121')->is_valid_number, '北海道雨竜郡秩父別町滝の上');
ok($zip->set_number('0782122')->is_valid_number, '北海道雨竜郡秩父別町中山');
ok($zip->set_number('0782123')->is_valid_number, '北海道雨竜郡秩父別町東山');
ok($zip->set_number('0782124')->is_valid_number, '北海道雨竜郡秩父別町南山');
ok($zip->set_number('0782200')->is_valid_number, '北海道雨竜郡沼田町以下に掲載がない場合');
ok($zip->set_number('0782201')->is_valid_number, '北海道雨竜郡沼田町旭町');
ok($zip->set_number('0782202')->is_valid_number, '北海道雨竜郡沼田町南一条');
ok($zip->set_number('0782203')->is_valid_number, '北海道雨竜郡沼田町本通');
ok($zip->set_number('0782204')->is_valid_number, '北海道雨竜郡沼田町西町');
ok($zip->set_number('0782205')->is_valid_number, '北海道雨竜郡沼田町北一条');
ok($zip->set_number('0782206')->is_valid_number, '北海道雨竜郡沼田町緑町');
ok($zip->set_number('0782211')->is_valid_number, '北海道雨竜郡沼田町更新');
ok($zip->set_number('0782212')->is_valid_number, '北海道雨竜郡沼田町東予');
ok($zip->set_number('0782213')->is_valid_number, '北海道雨竜郡沼田町共成');
ok($zip->set_number('0782214')->is_valid_number, '北海道雨竜郡沼田町高穂');
ok($zip->set_number('0782221')->is_valid_number, '北海道雨竜郡沼田町真布');
ok($zip->set_number('0782222')->is_valid_number, '北海道雨竜郡沼田町沼田');
ok($zip->set_number('0782223')->is_valid_number, '北海道雨竜郡沼田町北竜');
ok($zip->set_number('0782224')->is_valid_number, '北海道雨竜郡沼田町恵比島');
ok($zip->set_number('0782225')->is_valid_number, '北海道雨竜郡沼田町幌新');
ok($zip->set_number('0782500')->is_valid_number, '北海道雨竜郡北竜町以下に掲載がない場合');
ok($zip->set_number('0782501')->is_valid_number, '北海道雨竜郡北竜町美葉牛');
ok($zip->set_number('0782502')->is_valid_number, '北海道雨竜郡北竜町岩村');
ok($zip->set_number('0782503')->is_valid_number, '北海道雨竜郡北竜町碧水');
ok($zip->set_number('0782511')->is_valid_number, '北海道雨竜郡北竜町板谷');
ok($zip->set_number('0782512')->is_valid_number, '北海道雨竜郡北竜町和');
ok($zip->set_number('0782513')->is_valid_number, '北海道雨竜郡北竜町三谷');
ok($zip->set_number('0782514')->is_valid_number, '北海道雨竜郡北竜町恵岱別');
ok($zip->set_number('0782515')->is_valid_number, '北海道雨竜郡北竜町竜西');
ok($zip->set_number('0782516')->is_valid_number, '北海道雨竜郡北竜町西川');
ok($zip->set_number('0782531')->is_valid_number, '北海道雨竜郡雨竜町第5町内(3)');
ok($zip->set_number('0782600')->is_valid_number, '北海道雨竜郡雨竜町以下に掲載がない場合');
ok($zip->set_number('0782631')->is_valid_number, '北海道雨竜郡雨竜町第1町内');
ok($zip->set_number('0782632')->is_valid_number, '北海道雨竜郡雨竜町第2町内');
ok($zip->set_number('0782633')->is_valid_number, '北海道雨竜郡雨竜町第3町内');
ok($zip->set_number('0782634')->is_valid_number, '北海道雨竜郡雨竜町第4町内');
ok($zip->set_number('0782635')->is_valid_number, '北海道雨竜郡雨竜町第5町内(その他)');
ok($zip->set_number('0782636')->is_valid_number, '北海道雨竜郡雨竜町第6町内');
ok($zip->set_number('0782637')->is_valid_number, '北海道雨竜郡雨竜町第7町内');
ok($zip->set_number('0782638')->is_valid_number, '北海道雨竜郡雨竜町第8町内');
ok($zip->set_number('0782639')->is_valid_number, '北海道雨竜郡雨竜町第9町内');
ok($zip->set_number('0782641')->is_valid_number, '北海道雨竜郡雨竜町第10町内');
ok($zip->set_number('0782642')->is_valid_number, '北海道雨竜郡雨竜町第11町内');
ok($zip->set_number('0782651')->is_valid_number, '北海道樺戸郡新十津川町美沢');
ok($zip->set_number('0783161')->is_valid_number, '北海道留萌市留萌村(峠下)');
ok($zip->set_number('0783162')->is_valid_number, '北海道留萌市東幌町');
ok($zip->set_number('0783163')->is_valid_number, '北海道留萌市南幌町');
ok($zip->set_number('0783164')->is_valid_number, '北海道留萌市留萌村(幌糠)');
ok($zip->set_number('0783165')->is_valid_number, '北海道留萌市藤山町');
ok($zip->set_number('0783165')->is_valid_number, '北海道留萌市留萌原野(その他)');
ok($zip->set_number('0783166')->is_valid_number, '北海道留萌市中幌町');
ok($zip->set_number('0783167')->is_valid_number, '北海道留萌市樽真布町');
ok($zip->set_number('0783168')->is_valid_number, '北海道留萌市幌糠町');
ok($zip->set_number('0783300')->is_valid_number, '北海道留萌郡小平町以下に掲載がない場合');
ok($zip->set_number('0783301')->is_valid_number, '北海道留萌郡小平町小平町');
ok($zip->set_number('0783302')->is_valid_number, '北海道留萌郡小平町臼谷');
ok($zip->set_number('0783303')->is_valid_number, '北海道留萌郡小平町豊平');
ok($zip->set_number('0783304')->is_valid_number, '北海道留萌郡小平町本郷');
ok($zip->set_number('0783305')->is_valid_number, '北海道留萌郡小平町桑園');
ok($zip->set_number('0783306')->is_valid_number, '北海道留萌郡小平町菊岡');
ok($zip->set_number('0783307')->is_valid_number, '北海道留萌郡小平町豊岡');
ok($zip->set_number('0783308')->is_valid_number, '北海道留萌郡小平町岐富');
ok($zip->set_number('0783309')->is_valid_number, '北海道留萌郡小平町沖内');
ok($zip->set_number('0783311')->is_valid_number, '北海道留萌郡小平町花岡');
ok($zip->set_number('0783312')->is_valid_number, '北海道留萌郡小平町富里');
ok($zip->set_number('0783313')->is_valid_number, '北海道留萌郡小平町平和(1区)');
ok($zip->set_number('0783441')->is_valid_number, '北海道留萌郡小平町鬼鹿港町');
ok($zip->set_number('0783442')->is_valid_number, '北海道留萌郡小平町鬼鹿田代');
ok($zip->set_number('0783451')->is_valid_number, '北海道留萌郡小平町鬼鹿豊浜');
ok($zip->set_number('0783452')->is_valid_number, '北海道留萌郡小平町鬼鹿千松');
ok($zip->set_number('0783453')->is_valid_number, '北海道留萌郡小平町鬼鹿元浜');
ok($zip->set_number('0783454')->is_valid_number, '北海道留萌郡小平町鬼鹿広富');
ok($zip->set_number('0783455')->is_valid_number, '北海道留萌郡小平町鬼鹿秀浦');
ok($zip->set_number('0783456')->is_valid_number, '北海道留萌郡小平町鬼鹿富岡');
ok($zip->set_number('0783457')->is_valid_number, '北海道留萌郡小平町大椴');
ok($zip->set_number('0783541')->is_valid_number, '北海道苫前郡苫前町力昼');
ok($zip->set_number('0783621')->is_valid_number, '北海道苫前郡苫前町古丹別');
ok($zip->set_number('0783631')->is_valid_number, '北海道苫前郡苫前町香川(338~849番地)');
ok($zip->set_number('0783632')->is_valid_number, '北海道苫前郡苫前町長島');
ok($zip->set_number('0783633')->is_valid_number, '北海道苫前郡苫前町小川');
ok($zip->set_number('0783634')->is_valid_number, '北海道苫前郡苫前町岩見');
ok($zip->set_number('0783635')->is_valid_number, '北海道苫前郡苫前町東川');
ok($zip->set_number('0783636')->is_valid_number, '北海道苫前郡苫前町霧立');
ok($zip->set_number('0783637')->is_valid_number, '北海道苫前郡苫前町九重');
ok($zip->set_number('0783638')->is_valid_number, '北海道苫前郡苫前町三渓');
ok($zip->set_number('0783700')->is_valid_number, '北海道苫前郡苫前町以下に掲載がない場合');
ok($zip->set_number('0783701')->is_valid_number, '北海道苫前郡苫前町苫前');
ok($zip->set_number('0783702')->is_valid_number, '北海道苫前郡苫前町栄浜');
ok($zip->set_number('0783711')->is_valid_number, '北海道苫前郡苫前町旭');
ok($zip->set_number('0783712')->is_valid_number, '北海道苫前郡苫前町上平');
ok($zip->set_number('0783713')->is_valid_number, '北海道苫前郡苫前町興津');
ok($zip->set_number('0783714')->is_valid_number, '北海道苫前郡苫前町香川(その他)');
ok($zip->set_number('0783715')->is_valid_number, '北海道苫前郡苫前町昭和');
ok($zip->set_number('0783716')->is_valid_number, '北海道苫前郡苫前町豊浦');
ok($zip->set_number('0783717')->is_valid_number, '北海道苫前郡苫前町三豊');
ok($zip->set_number('0783871')->is_valid_number, '北海道苫前郡羽幌町焼尻');
ok($zip->set_number('0783951')->is_valid_number, '北海道苫前郡羽幌町天売(相影)');
ok($zip->set_number('0783952')->is_valid_number, '北海道苫前郡羽幌町天売(富磯)');
ok($zip->set_number('0783953')->is_valid_number, '北海道苫前郡羽幌町天売(和浦)');
ok($zip->set_number('0783954')->is_valid_number, '北海道苫前郡羽幌町天売(前浜)');
ok($zip->set_number('0783955')->is_valid_number, '北海道苫前郡羽幌町天売(弁天)');
ok($zip->set_number('0784100')->is_valid_number, '北海道苫前郡羽幌町以下に掲載がない場合');
ok($zip->set_number('0784101')->is_valid_number, '北海道苫前郡羽幌町南一条');
ok($zip->set_number('0784102')->is_valid_number, '北海道苫前郡羽幌町南二条');
ok($zip->set_number('0784103')->is_valid_number, '北海道苫前郡羽幌町南三条');
ok($zip->set_number('0784104')->is_valid_number, '北海道苫前郡羽幌町南四条');
ok($zip->set_number('0784105')->is_valid_number, '北海道苫前郡羽幌町南五条');
ok($zip->set_number('0784106')->is_valid_number, '北海道苫前郡羽幌町南六条');
ok($zip->set_number('0784107')->is_valid_number, '北海道苫前郡羽幌町南七条');
ok($zip->set_number('0784108')->is_valid_number, '北海道苫前郡羽幌町南大通');
ok($zip->set_number('0784110')->is_valid_number, '北海道苫前郡羽幌町北大通');
ok($zip->set_number('0784111')->is_valid_number, '北海道苫前郡羽幌町北一条');
ok($zip->set_number('0784112')->is_valid_number, '北海道苫前郡羽幌町北二条');
ok($zip->set_number('0784113')->is_valid_number, '北海道苫前郡羽幌町北三条');
ok($zip->set_number('0784114')->is_valid_number, '北海道苫前郡羽幌町北四条');
ok($zip->set_number('0784115')->is_valid_number, '北海道苫前郡羽幌町北五条');
ok($zip->set_number('0784116')->is_valid_number, '北海道苫前郡羽幌町北六条');
ok($zip->set_number('0784117')->is_valid_number, '北海道苫前郡羽幌町朝日');
ok($zip->set_number('0784118')->is_valid_number, '北海道苫前郡羽幌町浜町');
ok($zip->set_number('0784119')->is_valid_number, '北海道苫前郡羽幌町北町');
ok($zip->set_number('0784120')->is_valid_number, '北海道苫前郡羽幌町港町');
ok($zip->set_number('0784121')->is_valid_number, '北海道苫前郡羽幌町幸町');
ok($zip->set_number('0784122')->is_valid_number, '北海道苫前郡羽幌町南町');
ok($zip->set_number('0784123')->is_valid_number, '北海道苫前郡羽幌町栄町');
ok($zip->set_number('0784130')->is_valid_number, '北海道苫前郡羽幌町緑町');
ok($zip->set_number('0784131')->is_valid_number, '北海道苫前郡羽幌町寿町');
ok($zip->set_number('0784132')->is_valid_number, '北海道苫前郡羽幌町中央');
ok($zip->set_number('0784133')->is_valid_number, '北海道苫前郡羽幌町平');
ok($zip->set_number('0784134')->is_valid_number, '北海道苫前郡羽幌町上羽幌');
ok($zip->set_number('0784140')->is_valid_number, '北海道苫前郡羽幌町汐見');
ok($zip->set_number('0784141')->is_valid_number, '北海道苫前郡羽幌町築別');
ok($zip->set_number('0784142')->is_valid_number, '北海道苫前郡羽幌町上築');
ok($zip->set_number('0784143')->is_valid_number, '北海道苫前郡羽幌町高台');
ok($zip->set_number('0784144')->is_valid_number, '北海道苫前郡羽幌町曙');
ok($zip->set_number('0784145')->is_valid_number, '北海道苫前郡羽幌町築別炭砿');
ok($zip->set_number('0784400')->is_valid_number, '北海道苫前郡初山別村以下に掲載がない場合');
ok($zip->set_number('0784411')->is_valid_number, '北海道苫前郡初山別村有明');
ok($zip->set_number('0784412')->is_valid_number, '北海道苫前郡初山別村栄');
ok($zip->set_number('0784421')->is_valid_number, '北海道苫前郡初山別村初山別');
ok($zip->set_number('0784422')->is_valid_number, '北海道苫前郡初山別村千代田');
ok($zip->set_number('0784431')->is_valid_number, '北海道苫前郡初山別村豊岬');
ok($zip->set_number('0784432')->is_valid_number, '北海道苫前郡初山別村明里');
ok($zip->set_number('0784433')->is_valid_number, '北海道苫前郡初山別村共成');
ok($zip->set_number('0788201')->is_valid_number, '北海道旭川市東旭川町東桜岡(30~499番地)');
ok($zip->set_number('0788202')->is_valid_number, '北海道旭川市東旭川町豊田(1~9番地)');
ok($zip->set_number('0788203')->is_valid_number, '北海道旭川市東旭川町日ノ出');
ok($zip->set_number('0788204')->is_valid_number, '北海道旭川市東旭川町桜岡');
ok($zip->set_number('0788205')->is_valid_number, '北海道旭川市東旭川町倉沼');
ok($zip->set_number('0788206')->is_valid_number, '北海道旭川市東旭川町忠別');
ok($zip->set_number('0788207')->is_valid_number, '北海道旭川市東旭川町上兵村');
ok($zip->set_number('0788208')->is_valid_number, '北海道旭川市東旭川町下兵村');
ok($zip->set_number('0788211')->is_valid_number, '北海道旭川市1条通(18~25丁目)');
ok($zip->set_number('0788212')->is_valid_number, '北海道旭川市2条通(18~25丁目)');
ok($zip->set_number('0788213')->is_valid_number, '北海道旭川市3条通(18~25丁目)');
ok($zip->set_number('0788214')->is_valid_number, '北海道旭川市4条通(18~25丁目)');
ok($zip->set_number('0788215')->is_valid_number, '北海道旭川市5条通(18~25丁目)');
ok($zip->set_number('0788216')->is_valid_number, '北海道旭川市6条通(18~25丁目)');
ok($zip->set_number('0788217')->is_valid_number, '北海道旭川市7条通(18~25丁目)');
ok($zip->set_number('0788218')->is_valid_number, '北海道旭川市8条通(18~25丁目)');
ok($zip->set_number('0788219')->is_valid_number, '北海道旭川市9条通(18~25丁目)');
ok($zip->set_number('0788220')->is_valid_number, '北海道旭川市10条通(18~25丁目)');
ok($zip->set_number('0788221')->is_valid_number, '北海道旭川市11条通');
ok($zip->set_number('0788231')->is_valid_number, '北海道旭川市豊岡1条');
ok($zip->set_number('0788232')->is_valid_number, '北海道旭川市豊岡2条');
ok($zip->set_number('0788233')->is_valid_number, '北海道旭川市豊岡3条');
ok($zip->set_number('0788234')->is_valid_number, '北海道旭川市豊岡4条');
ok($zip->set_number('0788235')->is_valid_number, '北海道旭川市豊岡5条');
ok($zip->set_number('0788236')->is_valid_number, '北海道旭川市豊岡6条');
ok($zip->set_number('0788237')->is_valid_number, '北海道旭川市豊岡7条');
ok($zip->set_number('0788238')->is_valid_number, '北海道旭川市豊岡8条');
ok($zip->set_number('0788239')->is_valid_number, '北海道旭川市豊岡9条');
ok($zip->set_number('0788240')->is_valid_number, '北海道旭川市豊岡10条');
ok($zip->set_number('0788241')->is_valid_number, '北海道旭川市豊岡11条');
ok($zip->set_number('0788242')->is_valid_number, '北海道旭川市豊岡12条');
ok($zip->set_number('0788243')->is_valid_number, '北海道旭川市豊岡13条');
ok($zip->set_number('0788244')->is_valid_number, '北海道旭川市豊岡14条');
ok($zip->set_number('0788245')->is_valid_number, '北海道旭川市豊岡15条');
ok($zip->set_number('0788246')->is_valid_number, '北海道旭川市豊岡16条');
ok($zip->set_number('0788251')->is_valid_number, '北海道旭川市東旭川北1条');
ok($zip->set_number('0788252')->is_valid_number, '北海道旭川市東旭川北2条');
ok($zip->set_number('0788253')->is_valid_number, '北海道旭川市東旭川北3条');
ok($zip->set_number('0788261')->is_valid_number, '北海道旭川市東旭川南1条');
ok($zip->set_number('0788262')->is_valid_number, '北海道旭川市東旭川南2条');
ok($zip->set_number('0788271')->is_valid_number, '北海道旭川市工業団地1条');
ok($zip->set_number('0788272')->is_valid_number, '北海道旭川市工業団地2条');
ok($zip->set_number('0788273')->is_valid_number, '北海道旭川市工業団地3条');
ok($zip->set_number('0788274')->is_valid_number, '北海道旭川市工業団地4条');
ok($zip->set_number('0788275')->is_valid_number, '北海道旭川市工業団地5条');
ok($zip->set_number('0788301')->is_valid_number, '北海道旭川市緑が丘1条');
ok($zip->set_number('0788302')->is_valid_number, '北海道旭川市緑が丘2条');
ok($zip->set_number('0788303')->is_valid_number, '北海道旭川市緑が丘3条');
ok($zip->set_number('0788304')->is_valid_number, '北海道旭川市緑が丘4条');
ok($zip->set_number('0788305')->is_valid_number, '北海道旭川市緑が丘5条');
ok($zip->set_number('0788308')->is_valid_number, '北海道旭川市旭神町');
ok($zip->set_number('0788311')->is_valid_number, '北海道旭川市神楽岡1条');
ok($zip->set_number('0788312')->is_valid_number, '北海道旭川市神楽岡2条');
ok($zip->set_number('0788313')->is_valid_number, '北海道旭川市神楽岡3条');
ok($zip->set_number('0788314')->is_valid_number, '北海道旭川市神楽岡4条');
ok($zip->set_number('0788315')->is_valid_number, '北海道旭川市神楽岡5条');
ok($zip->set_number('0788316')->is_valid_number, '北海道旭川市神楽岡6条');
ok($zip->set_number('0788317')->is_valid_number, '北海道旭川市神楽岡7条');
ok($zip->set_number('0788318')->is_valid_number, '北海道旭川市神楽岡8条');
ok($zip->set_number('0788319')->is_valid_number, '北海道旭川市神楽岡9条');
ok($zip->set_number('0788320')->is_valid_number, '北海道旭川市神楽岡10条');
ok($zip->set_number('0788321')->is_valid_number, '北海道旭川市神楽岡11条');
ok($zip->set_number('0788322')->is_valid_number, '北海道旭川市神楽岡12条');
ok($zip->set_number('0788323')->is_valid_number, '北海道旭川市神楽岡13条');
ok($zip->set_number('0788324')->is_valid_number, '北海道旭川市神楽岡14条');
ok($zip->set_number('0788325')->is_valid_number, '北海道旭川市神楽岡15条');
ok($zip->set_number('0788326')->is_valid_number, '北海道旭川市神楽岡16条');
ok($zip->set_number('0788327')->is_valid_number, '北海道旭川市神楽岡公園');
ok($zip->set_number('0788330')->is_valid_number, '北海道旭川市宮下通(18~26丁目)');
ok($zip->set_number('0788331')->is_valid_number, '北海道旭川市南1条通');
ok($zip->set_number('0788332')->is_valid_number, '北海道旭川市南2条通');
ok($zip->set_number('0788333')->is_valid_number, '北海道旭川市南3条通');
ok($zip->set_number('0788334')->is_valid_number, '北海道旭川市南4条通');
ok($zip->set_number('0788335')->is_valid_number, '北海道旭川市南5条通');
ok($zip->set_number('0788336')->is_valid_number, '北海道旭川市南6条通');
ok($zip->set_number('0788337')->is_valid_number, '北海道旭川市南7条通');
ok($zip->set_number('0788338')->is_valid_number, '北海道旭川市南8条通');
ok($zip->set_number('0788339')->is_valid_number, '北海道旭川市南9条通');
ok($zip->set_number('0788340')->is_valid_number, '北海道旭川市東旭川町共栄');
ok($zip->set_number('0788341')->is_valid_number, '北海道旭川市東光1条');
ok($zip->set_number('0788342')->is_valid_number, '北海道旭川市東光2条');
ok($zip->set_number('0788343')->is_valid_number, '北海道旭川市東光3条');
ok($zip->set_number('0788344')->is_valid_number, '北海道旭川市東光4条');
ok($zip->set_number('0788345')->is_valid_number, '北海道旭川市東光5条');
ok($zip->set_number('0788346')->is_valid_number, '北海道旭川市東光6条');
ok($zip->set_number('0788347')->is_valid_number, '北海道旭川市東光7条');
ok($zip->set_number('0788348')->is_valid_number, '北海道旭川市東光8条');
ok($zip->set_number('0788349')->is_valid_number, '北海道旭川市東光9条');
ok($zip->set_number('0788350')->is_valid_number, '北海道旭川市東光10条');
ok($zip->set_number('0788351')->is_valid_number, '北海道旭川市東光11条');
ok($zip->set_number('0788352')->is_valid_number, '北海道旭川市東光12条');
ok($zip->set_number('0788353')->is_valid_number, '北海道旭川市東光13条');
ok($zip->set_number('0788354')->is_valid_number, '北海道旭川市東光14条');
ok($zip->set_number('0788355')->is_valid_number, '北海道旭川市東光15条');
ok($zip->set_number('0788356')->is_valid_number, '北海道旭川市東光16条');
ok($zip->set_number('0788357')->is_valid_number, '北海道旭川市東光17条');
ok($zip->set_number('0788358')->is_valid_number, '北海道旭川市東光18条');
ok($zip->set_number('0788359')->is_valid_number, '北海道旭川市東光19条');
ok($zip->set_number('0788360')->is_valid_number, '北海道旭川市東光20条');
ok($zip->set_number('0788361')->is_valid_number, '北海道旭川市東光21条');
ok($zip->set_number('0788362')->is_valid_number, '北海道旭川市東光22条');
ok($zip->set_number('0788363')->is_valid_number, '北海道旭川市東光23条');
ok($zip->set_number('0788364')->is_valid_number, '北海道旭川市東光24条');
ok($zip->set_number('0788365')->is_valid_number, '北海道旭川市東光25条');
ok($zip->set_number('0788366')->is_valid_number, '北海道旭川市東光26条');
ok($zip->set_number('0788367')->is_valid_number, '北海道旭川市東光27条');
ok($zip->set_number('0788368')->is_valid_number, '北海道旭川市東旭川町旭正');
ok($zip->set_number('0788371')->is_valid_number, '北海道旭川市旭神1条');
ok($zip->set_number('0788372')->is_valid_number, '北海道旭川市旭神2条');
ok($zip->set_number('0788373')->is_valid_number, '北海道旭川市旭神3条');
ok($zip->set_number('0788381')->is_valid_number, '北海道旭川市西神楽1線');
ok($zip->set_number('0788382')->is_valid_number, '北海道旭川市西神楽2線');
ok($zip->set_number('0788383')->is_valid_number, '北海道旭川市西神楽3線');
ok($zip->set_number('0788391')->is_valid_number, '北海道旭川市宮前1条');
ok($zip->set_number('0788392')->is_valid_number, '北海道旭川市宮前2条');
ok($zip->set_number('0788801')->is_valid_number, '北海道旭川市緑が丘東1条');
ok($zip->set_number('0788802')->is_valid_number, '北海道旭川市緑が丘東2条');
ok($zip->set_number('0788803')->is_valid_number, '北海道旭川市緑が丘東3条');
ok($zip->set_number('0788804')->is_valid_number, '北海道旭川市緑が丘東4条');
ok($zip->set_number('0788805')->is_valid_number, '北海道旭川市緑が丘東5条');
ok($zip->set_number('0788811')->is_valid_number, '北海道旭川市緑が丘南1条');
ok($zip->set_number('0788812')->is_valid_number, '北海道旭川市緑が丘南2条');
ok($zip->set_number('0788813')->is_valid_number, '北海道旭川市緑が丘南3条');
ok($zip->set_number('0788814')->is_valid_number, '北海道旭川市緑が丘南4条');
ok($zip->set_number('0788815')->is_valid_number, '北海道旭川市緑が丘南5条');
ok($zip->set_number('0788821')->is_valid_number, '北海道旭川市西御料1条');
ok($zip->set_number('0788822')->is_valid_number, '北海道旭川市西御料2条');
ok($zip->set_number('0788823')->is_valid_number, '北海道旭川市西御料3条');
ok($zip->set_number('0788824')->is_valid_number, '北海道旭川市西御料4条');
ok($zip->set_number('0788825')->is_valid_number, '北海道旭川市西御料5条');
ok($zip->set_number('0790161')->is_valid_number, '北海道美唄市光珠内拓北');
ok($zip->set_number('0790162')->is_valid_number, '北海道美唄市光珠内北');
ok($zip->set_number('0790164')->is_valid_number, '北海道美唄市光珠内下中の沢');
ok($zip->set_number('0790165')->is_valid_number, '北海道美唄市光珠内上中の沢');
ok($zip->set_number('0790166')->is_valid_number, '北海道美唄市光珠内東山');
ok($zip->set_number('0790167')->is_valid_number, '北海道美唄市光珠内町南(その他)');
ok($zip->set_number('0790171')->is_valid_number, '北海道美唄市光珠内中央');
ok($zip->set_number('0790172')->is_valid_number, '北海道美唄市峰延町東');
ok($zip->set_number('0790173')->is_valid_number, '北海道美唄市峰延町公園');
ok($zip->set_number('0790174')->is_valid_number, '北海道美唄市峰延町本町');
ok($zip->set_number('0790175')->is_valid_number, '北海道美唄市峰延町峰樺');
ok($zip->set_number('0790176')->is_valid_number, '北海道美唄市豊葦町');
ok($zip->set_number('0790177')->is_valid_number, '北海道美唄市上美唄町(協和、南)');
ok($zip->set_number('0790181')->is_valid_number, '北海道岩見沢市岡山町');
ok($zip->set_number('0790182')->is_valid_number, '北海道岩見沢市峰延町');
ok($zip->set_number('0790183')->is_valid_number, '北海道岩見沢市大願町');
ok($zip->set_number('0790261')->is_valid_number, '北海道美唄市茶志内町');
ok($zip->set_number('0790262')->is_valid_number, '北海道美唄市日東町栄町');
ok($zip->set_number('0790263')->is_valid_number, '北海道美唄市日東町住吉');
ok($zip->set_number('0790264')->is_valid_number, '北海道美唄市日東町本町');
ok($zip->set_number('0790265')->is_valid_number, '北海道美唄市日東町富の郷');
ok($zip->set_number('0790266')->is_valid_number, '北海道美唄市茶志内町本町');
ok($zip->set_number('0790267')->is_valid_number, '北海道美唄市茶志内町協和');
ok($zip->set_number('0790271')->is_valid_number, '北海道美唄市中村町南');
ok($zip->set_number('0790272')->is_valid_number, '北海道美唄市中村町中央');
ok($zip->set_number('0790273')->is_valid_number, '北海道美唄市中村町北');
ok($zip->set_number('0790274')->is_valid_number, '北海道美唄市北美唄町');
ok($zip->set_number('0790300')->is_valid_number, '北海道空知郡奈井江町以下に掲載がない場合');
ok($zip->set_number('0790301')->is_valid_number, '北海道空知郡奈井江町厳島');
ok($zip->set_number('0790302')->is_valid_number, '北海道空知郡奈井江町白山');
ok($zip->set_number('0790303')->is_valid_number, '北海道空知郡奈井江町向ケ丘');
ok($zip->set_number('0790304')->is_valid_number, '北海道空知郡奈井江町宮村');
ok($zip->set_number('0790305')->is_valid_number, '北海道空知郡奈井江町茶志内');
ok($zip->set_number('0790306')->is_valid_number, '北海道空知郡奈井江町東町');
ok($zip->set_number('0790311')->is_valid_number, '北海道空知郡奈井江町大和');
ok($zip->set_number('0790312')->is_valid_number, '北海道空知郡奈井江町北町');
ok($zip->set_number('0790313')->is_valid_number, '北海道空知郡奈井江町本町');
ok($zip->set_number('0790314')->is_valid_number, '北海道空知郡奈井江町南町');
ok($zip->set_number('0790315')->is_valid_number, '北海道空知郡奈井江町高島');
ok($zip->set_number('0790316')->is_valid_number, '北海道空知郡奈井江町キナウスナイ');
ok($zip->set_number('0790317')->is_valid_number, '北海道空知郡奈井江町瑞穂');
ok($zip->set_number('0790461')->is_valid_number, '北海道滝川市江部乙町');
ok($zip->set_number('0790462')->is_valid_number, '北海道滝川市江部乙町西');
ok($zip->set_number('0790463')->is_valid_number, '北海道滝川市江部乙町東');
ok($zip->set_number('0790500')->is_valid_number, '北海道雨竜郡妹背牛町以下に掲載がない場合');
ok($zip->set_number('0790501')->is_valid_number, '北海道雨竜郡妹背牛町1区');
ok($zip->set_number('0790502')->is_valid_number, '北海道雨竜郡妹背牛町2区');
ok($zip->set_number('0790503')->is_valid_number, '北海道雨竜郡妹背牛町3区');
ok($zip->set_number('0790504')->is_valid_number, '北海道雨竜郡妹背牛町4区');
ok($zip->set_number('0790505')->is_valid_number, '北海道雨竜郡妹背牛町5区');
ok($zip->set_number('0790506')->is_valid_number, '北海道雨竜郡妹背牛町6区');
ok($zip->set_number('0790507')->is_valid_number, '北海道雨竜郡妹背牛町7区');
ok($zip->set_number('0790508')->is_valid_number, '北海道雨竜郡妹背牛町8区');
ok($zip->set_number('0790509')->is_valid_number, '北海道雨竜郡妹背牛町9区');
ok($zip->set_number('0790510')->is_valid_number, '北海道雨竜郡妹背牛町10区');
ok($zip->set_number('0790511')->is_valid_number, '北海道雨竜郡妹背牛町11区');
ok($zip->set_number('0791100')->is_valid_number, '北海道赤平市以下に掲載がない場合');
ok($zip->set_number('0791101')->is_valid_number, '北海道赤平市共和町');
ok($zip->set_number('0791102')->is_valid_number, '北海道赤平市幌岡町');
ok($zip->set_number('0791111')->is_valid_number, '北海道赤平市若木町北');
ok($zip->set_number('0791112')->is_valid_number, '北海道赤平市若木町西');
ok($zip->set_number('0791113')->is_valid_number, '北海道赤平市若木町東');
ok($zip->set_number('0791114')->is_valid_number, '北海道赤平市若木町南');
ok($zip->set_number('0791121')->is_valid_number, '北海道赤平市北文京町');
ok($zip->set_number('0791122')->is_valid_number, '北海道赤平市西文京町');
ok($zip->set_number('0791123')->is_valid_number, '北海道赤平市東文京町');
ok($zip->set_number('0791124')->is_valid_number, '北海道赤平市豊丘町');
ok($zip->set_number('0791131')->is_valid_number, '北海道赤平市西豊里町');
ok($zip->set_number('0791132')->is_valid_number, '北海道赤平市東豊里町');
ok($zip->set_number('0791133')->is_valid_number, '北海道赤平市豊里');
ok($zip->set_number('0791134')->is_valid_number, '北海道赤平市泉町');
ok($zip->set_number('0791135')->is_valid_number, '北海道赤平市錦町');
ok($zip->set_number('0791136')->is_valid_number, '北海道赤平市本町');
ok($zip->set_number('0791141')->is_valid_number, '北海道赤平市大町');
ok($zip->set_number('0791142')->is_valid_number, '北海道赤平市東大町');
ok($zip->set_number('0791143')->is_valid_number, '北海道赤平市赤平');
ok($zip->set_number('0791144')->is_valid_number, '北海道赤平市美園町');
ok($zip->set_number('0791151')->is_valid_number, '北海道赤平市宮下町');
ok($zip->set_number('0791152')->is_valid_number, '北海道赤平市桜木町');
ok($zip->set_number('0791153')->is_valid_number, '北海道赤平市豊栄町');
ok($zip->set_number('0791154')->is_valid_number, '北海道赤平市幸町');
ok($zip->set_number('0791155')->is_valid_number, '北海道赤平市昭和町');
ok($zip->set_number('0791156')->is_valid_number, '北海道赤平市住吉町');
ok($zip->set_number('0791181')->is_valid_number, '北海道砂川市富平(331、459-4、543番地)');
ok($zip->set_number('0791261')->is_valid_number, '北海道赤平市茂尻中央町南');
ok($zip->set_number('0791261')->is_valid_number, '北海道赤平市茂尻中央町北');
ok($zip->set_number('0791262')->is_valid_number, '北海道赤平市茂尻春日町');
ok($zip->set_number('0791262')->is_valid_number, '北海道赤平市茂尻新春日町');
ok($zip->set_number('0791263')->is_valid_number, '北海道赤平市茂尻本町');
ok($zip->set_number('0791264')->is_valid_number, '北海道赤平市茂尻旭町');
ok($zip->set_number('0791264')->is_valid_number, '北海道赤平市茂尻宮下町');
ok($zip->set_number('0791265')->is_valid_number, '北海道赤平市茂尻新町');
ok($zip->set_number('0791266')->is_valid_number, '北海道赤平市茂尻');
ok($zip->set_number('0791266')->is_valid_number, '北海道赤平市茂尻栄町');
ok($zip->set_number('0791267')->is_valid_number, '北海道赤平市茂尻元町南');
ok($zip->set_number('0791268')->is_valid_number, '北海道赤平市茂尻元町北');
ok($zip->set_number('0791271')->is_valid_number, '北海道赤平市百戸町北');
ok($zip->set_number('0791272')->is_valid_number, '北海道赤平市百戸町東');
ok($zip->set_number('0791273')->is_valid_number, '北海道赤平市百戸町西');
ok($zip->set_number('0791274')->is_valid_number, '北海道赤平市エルム町');
ok($zip->set_number('0791281')->is_valid_number, '北海道赤平市平岸新光町');
ok($zip->set_number('0791282')->is_valid_number, '北海道赤平市平岸仲町');
ok($zip->set_number('0791283')->is_valid_number, '北海道赤平市平岸東町');
ok($zip->set_number('0791284')->is_valid_number, '北海道赤平市平岸南町');
ok($zip->set_number('0791285')->is_valid_number, '北海道赤平市平岸曙町');
ok($zip->set_number('0791286')->is_valid_number, '北海道赤平市平岸西町');
ok($zip->set_number('0791287')->is_valid_number, '北海道赤平市平岸桂町');
ok($zip->set_number('0791371')->is_valid_number, '北海道芦別市上芦別町');
ok($zip->set_number('0791372')->is_valid_number, '北海道芦別市野花南町');
ok($zip->set_number('0791562')->is_valid_number, '北海道富良野市山部北町');
ok($zip->set_number('0791563')->is_valid_number, '北海道富良野市山部東町');
ok($zip->set_number('0791564')->is_valid_number, '北海道富良野市山部中町');
ok($zip->set_number('0791565')->is_valid_number, '北海道富良野市山部南町');
ok($zip->set_number('0791566')->is_valid_number, '北海道富良野市山部西町');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西12線');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西13線');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西14線');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西15線');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西16線');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西17線');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西18線');
ok($zip->set_number('0791571')->is_valid_number, '北海道富良野市山部西19線');
ok($zip->set_number('0791572')->is_valid_number, '北海道富良野市山部西20線');
ok($zip->set_number('0791572')->is_valid_number, '北海道富良野市山部西21線');
ok($zip->set_number('0791572')->is_valid_number, '北海道富良野市山部西22線');
ok($zip->set_number('0791572')->is_valid_number, '北海道富良野市山部西23線');
ok($zip->set_number('0791572')->is_valid_number, '北海道富良野市山部西24線');
ok($zip->set_number('0791573')->is_valid_number, '北海道富良野市山部西25線');
ok($zip->set_number('0791573')->is_valid_number, '北海道富良野市山部西26線');
ok($zip->set_number('0791573')->is_valid_number, '北海道富良野市山部西27線');
ok($zip->set_number('0791573')->is_valid_number, '北海道富良野市山部西28線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東12線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東13線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東14線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東15線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東16線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東17線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東18線');
ok($zip->set_number('0791581')->is_valid_number, '北海道富良野市山部東19線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東20線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東21線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東22線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東23線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東24線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東25線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東26線');
ok($zip->set_number('0791582')->is_valid_number, '北海道富良野市山部東27線');
ok($zip->set_number('0792131')->is_valid_number, '北海道空知郡南富良野町金山');
ok($zip->set_number('0792132')->is_valid_number, '北海道空知郡南富良野町下金山');
ok($zip->set_number('0792133')->is_valid_number, '北海道富良野市東山(1710番地)');
ok($zip->set_number('0792200')->is_valid_number, '北海道勇払郡占冠村以下に掲載がない場合');
ok($zip->set_number('0792201')->is_valid_number, '北海道勇払郡占冠村中央');
ok($zip->set_number('0792202')->is_valid_number, '北海道勇払郡占冠村占冠');
ok($zip->set_number('0792203')->is_valid_number, '北海道勇払郡占冠村下トマム');
ok($zip->set_number('0792204')->is_valid_number, '北海道勇払郡占冠村中トマム');
ok($zip->set_number('0792205')->is_valid_number, '北海道勇払郡占冠村上トマム');
ok($zip->set_number('0792206')->is_valid_number, '北海道勇払郡占冠村双珠別');
ok($zip->set_number('0792207')->is_valid_number, '北海道勇払郡占冠村ニニウ');
ok($zip->set_number('0792400')->is_valid_number, '北海道空知郡南富良野町以下に掲載がない場合');
ok($zip->set_number('0792401')->is_valid_number, '北海道空知郡南富良野町幾寅(栄町)');
ok($zip->set_number('0792401')->is_valid_number, '北海道空知郡南富良野町幾寅(住吉町)');
ok($zip->set_number('0792401')->is_valid_number, '北海道空知郡南富良野町幾寅(内藤)');
ok($zip->set_number('0792401')->is_valid_number, '北海道空知郡南富良野町幾寅(仲町)');
ok($zip->set_number('0792402')->is_valid_number, '北海道空知郡南富良野町幾寅(西町)');
ok($zip->set_number('0792403')->is_valid_number, '北海道空知郡南富良野町幾寅(浅野)');
ok($zip->set_number('0792403')->is_valid_number, '北海道空知郡南富良野町幾寅(岐阜)');
ok($zip->set_number('0792403')->is_valid_number, '北海道空知郡南富良野町幾寅(久住)');
ok($zip->set_number('0792403')->is_valid_number, '北海道空知郡南富良野町幾寅(松井)');
ok($zip->set_number('0792403')->is_valid_number, '北海道空知郡南富良野町幾寅(山畔)');
ok($zip->set_number('0792404')->is_valid_number, '北海道空知郡南富良野町幾寅(朝日町)');
ok($zip->set_number('0792404')->is_valid_number, '北海道空知郡南富良野町幾寅(千木町)');
ok($zip->set_number('0792404')->is_valid_number, '北海道空知郡南富良野町幾寅(東町)');
ok($zip->set_number('0792411')->is_valid_number, '北海道空知郡南富良野町東鹿越');
ok($zip->set_number('0792412')->is_valid_number, '北海道空知郡南富良野町東幾寅');
ok($zip->set_number('0792551')->is_valid_number, '北海道空知郡南富良野町落合');
ok($zip->set_number('0792552')->is_valid_number, '北海道空知郡南富良野町北落合');
ok($zip->set_number('0798401')->is_valid_number, '北海道旭川市秋月1条');
ok($zip->set_number('0798402')->is_valid_number, '北海道旭川市秋月2条');
ok($zip->set_number('0798403')->is_valid_number, '北海道旭川市秋月3条');
ok($zip->set_number('0798411')->is_valid_number, '北海道旭川市永山1条');
ok($zip->set_number('0798412')->is_valid_number, '北海道旭川市永山2条');
ok($zip->set_number('0798413')->is_valid_number, '北海道旭川市永山3条');
ok($zip->set_number('0798414')->is_valid_number, '北海道旭川市永山4条');
ok($zip->set_number('0798415')->is_valid_number, '北海道旭川市永山5条');
ok($zip->set_number('0798416')->is_valid_number, '北海道旭川市永山6条');
ok($zip->set_number('0798417')->is_valid_number, '北海道旭川市永山7条');
ok($zip->set_number('0798418')->is_valid_number, '北海道旭川市永山8条');
ok($zip->set_number('0798419')->is_valid_number, '北海道旭川市永山9条');
ok($zip->set_number('0798420')->is_valid_number, '北海道旭川市永山10条');
ok($zip->set_number('0798421')->is_valid_number, '北海道旭川市永山11条');
ok($zip->set_number('0798422')->is_valid_number, '北海道旭川市永山12条');
ok($zip->set_number('0798423')->is_valid_number, '北海道旭川市永山13条');
ok($zip->set_number('0798424')->is_valid_number, '北海道旭川市永山14条');
ok($zip->set_number('0798431')->is_valid_number, '北海道旭川市永山町');
ok($zip->set_number('0798441')->is_valid_number, '北海道旭川市流通団地1条');
ok($zip->set_number('0798442')->is_valid_number, '北海道旭川市流通団地2条');
ok($zip->set_number('0798443')->is_valid_number, '北海道旭川市流通団地3条');
ok($zip->set_number('0798444')->is_valid_number, '北海道旭川市流通団地4条');
ok($zip->set_number('0798451')->is_valid_number, '北海道旭川市永山北1条');
ok($zip->set_number('0798452')->is_valid_number, '北海道旭川市永山北2条');
ok($zip->set_number('0798453')->is_valid_number, '北海道旭川市永山北3条');
ok($zip->set_number('0798454')->is_valid_number, '北海道旭川市永山北4条');
ok($zip->set_number('0800000')->is_valid_number, '北海道帯広市以下に掲載がない場合');
ok($zip->set_number('0800010')->is_valid_number, '北海道帯広市大通南');
ok($zip->set_number('0800011')->is_valid_number, '北海道帯広市西一条南');
ok($zip->set_number('0800012')->is_valid_number, '北海道帯広市西二条南');
ok($zip->set_number('0800013')->is_valid_number, '北海道帯広市西三条南');
ok($zip->set_number('0800014')->is_valid_number, '北海道帯広市西四条南');
ok($zip->set_number('0800015')->is_valid_number, '北海道帯広市西五条南');
ok($zip->set_number('0800016')->is_valid_number, '北海道帯広市西六条南');
ok($zip->set_number('0800017')->is_valid_number, '北海道帯広市西七条南');
ok($zip->set_number('0800018')->is_valid_number, '北海道帯広市西八条南');
ok($zip->set_number('0800019')->is_valid_number, '北海道帯広市西九条南');
ok($zip->set_number('0800020')->is_valid_number, '北海道帯広市西十条南');
ok($zip->set_number('0800021')->is_valid_number, '北海道帯広市西十一条南');
ok($zip->set_number('0800022')->is_valid_number, '北海道帯広市西十二条南');
ok($zip->set_number('0800023')->is_valid_number, '北海道帯広市西十三条南');
ok($zip->set_number('0800024')->is_valid_number, '北海道帯広市西十四条南');
ok($zip->set_number('0800025')->is_valid_number, '北海道帯広市西十五条南');
ok($zip->set_number('0800026')->is_valid_number, '北海道帯広市西十六条南');
ok($zip->set_number('0800027')->is_valid_number, '北海道帯広市西十七条南');
ok($zip->set_number('0800028')->is_valid_number, '北海道帯広市西十八条南');
ok($zip->set_number('0800029')->is_valid_number, '北海道帯広市西十九条南(35~38、41、42丁目)');
ok($zip->set_number('0800030')->is_valid_number, '北海道帯広市大通北');
ok($zip->set_number('0800031')->is_valid_number, '北海道帯広市西一条北');
ok($zip->set_number('0800032')->is_valid_number, '北海道帯広市西二条北');
ok($zip->set_number('0800033')->is_valid_number, '北海道帯広市西三条北');
ok($zip->set_number('0800034')->is_valid_number, '北海道帯広市西四条北');
ok($zip->set_number('0800035')->is_valid_number, '北海道帯広市西五条北');
ok($zip->set_number('0800036')->is_valid_number, '北海道帯広市西六条北');
ok($zip->set_number('0800037')->is_valid_number, '北海道帯広市西七条北');
ok($zip->set_number('0800038')->is_valid_number, '北海道帯広市西八条北');
ok($zip->set_number('0800039')->is_valid_number, '北海道帯広市西九条北');
ok($zip->set_number('0800040')->is_valid_number, '北海道帯広市西十条北');
ok($zip->set_number('0800041')->is_valid_number, '北海道帯広市西十一条北');
ok($zip->set_number('0800042')->is_valid_number, '北海道帯広市西十二条北');
ok($zip->set_number('0800043')->is_valid_number, '北海道帯広市西十三条北');
ok($zip->set_number('0800044')->is_valid_number, '北海道帯広市西十四条北');
ok($zip->set_number('0800045')->is_valid_number, '北海道帯広市西十五条北');
ok($zip->set_number('0800046')->is_valid_number, '北海道帯広市西十六条北');
ok($zip->set_number('0800047')->is_valid_number, '北海道帯広市西十七条北');
ok($zip->set_number('0800048')->is_valid_number, '北海道帯広市西十八条北');
ok($zip->set_number('0800050')->is_valid_number, '北海道帯広市白樺十六条東');
ok($zip->set_number('0800051')->is_valid_number, '北海道帯広市白樺十六条西');
ok($zip->set_number('0800052')->is_valid_number, '北海道帯広市新町東');
ok($zip->set_number('0800053')->is_valid_number, '北海道帯広市新町西');
ok($zip->set_number('0800054')->is_valid_number, '北海道帯広市柏林台北町');
ok($zip->set_number('0800055')->is_valid_number, '北海道帯広市柏林台東町');
ok($zip->set_number('0800056')->is_valid_number, '北海道帯広市柏林台南町');
ok($zip->set_number('0800057')->is_valid_number, '北海道帯広市柏林台中町');
ok($zip->set_number('0800058')->is_valid_number, '北海道帯広市柏林台西町');
ok($zip->set_number('0800100')->is_valid_number, '北海道河東郡音更町以下に掲載がない場合');
ok($zip->set_number('0800101')->is_valid_number, '北海道河東郡音更町大通');
ok($zip->set_number('0800102')->is_valid_number, '北海道河東郡音更町大通北');
ok($zip->set_number('0800103')->is_valid_number, '北海道河東郡音更町元町');
ok($zip->set_number('0800104')->is_valid_number, '北海道河東郡音更町新通');
ok($zip->set_number('0800105')->is_valid_number, '北海道河東郡音更町新通北');
ok($zip->set_number('0800106')->is_valid_number, '北海道河東郡音更町東通');
ok($zip->set_number('0800111')->is_valid_number, '北海道河東郡音更町木野大通東');
ok($zip->set_number('0800112')->is_valid_number, '北海道河東郡音更町木野東通');
ok($zip->set_number('0800121')->is_valid_number, '北海道河東郡音更町柳町北区');
ok($zip->set_number('0800122')->is_valid_number, '北海道河東郡音更町柳町仲区');
ok($zip->set_number('0800123')->is_valid_number, '北海道河東郡音更町柳町南区');
ok($zip->set_number('0800131')->is_valid_number, '北海道河東郡音更町宝来本通');
ok($zip->set_number('0800132')->is_valid_number, '北海道河東郡音更町宝来仲町北');
ok($zip->set_number('0800133')->is_valid_number, '北海道河東郡音更町宝来東町北');
ok($zip->set_number('0800134')->is_valid_number, '北海道河東郡音更町宝来西町南');
ok($zip->set_number('0800135')->is_valid_number, '北海道河東郡音更町宝来仲町南');
ok($zip->set_number('0800136')->is_valid_number, '北海道河東郡音更町宝来東町南');
ok($zip->set_number('0800137')->is_valid_number, '北海道河東郡音更町宝来南一条');
ok($zip->set_number('0800138')->is_valid_number, '北海道河東郡音更町宝来南二条');
ok($zip->set_number('0800139')->is_valid_number, '北海道河東郡音更町宝来西町北');
ok($zip->set_number('0800141')->is_valid_number, '北海道河東郡音更町宝来北一条');
ok($zip->set_number('0800142')->is_valid_number, '北海道河東郡音更町宝来北二条');
ok($zip->set_number('0800143')->is_valid_number, '北海道河東郡音更町宝来北三条');
ok($zip->set_number('0800144')->is_valid_number, '北海道河東郡音更町宝来北四条');
ok($zip->set_number('0800145')->is_valid_number, '北海道河東郡音更町宝来北五条');
ok($zip->set_number('0800146')->is_valid_number, '北海道河東郡音更町宝来北六条');
ok($zip->set_number('0800151')->is_valid_number, '北海道河東郡音更町東和');
ok($zip->set_number('0800161')->is_valid_number, '北海道河東郡音更町ひびき野東町');
ok($zip->set_number('0800162')->is_valid_number, '北海道河東郡音更町ひびき野仲町');
ok($zip->set_number('0800163')->is_valid_number, '北海道河東郡音更町ひびき野西町');
ok($zip->set_number('0800261')->is_valid_number, '北海道河東郡音更町十勝川温泉');
ok($zip->set_number('0800262')->is_valid_number, '北海道河東郡音更町十勝川温泉北');
ok($zip->set_number('0800263')->is_valid_number, '北海道河東郡音更町十勝川温泉南');
ok($zip->set_number('0800271')->is_valid_number, '北海道河東郡音更町長流枝');
ok($zip->set_number('0800271')->is_valid_number, '北海道河東郡音更町長流枝幹線');
ok($zip->set_number('0800272')->is_valid_number, '北海道河東郡音更町下士幌');
ok($zip->set_number('0800272')->is_valid_number, '北海道河東郡音更町下士幌幹線');
ok($zip->set_number('0800301')->is_valid_number, '北海道河東郡音更町木野大通西');
ok($zip->set_number('0800302')->is_valid_number, '北海道河東郡音更町木野西通');
ok($zip->set_number('0800303')->is_valid_number, '北海道河東郡音更町木野公園下町');
ok($zip->set_number('0800304')->is_valid_number, '北海道河東郡音更町木野新町');
ok($zip->set_number('0800305')->is_valid_number, '北海道河東郡音更町北鈴蘭北');
ok($zip->set_number('0800306')->is_valid_number, '北海道河東郡音更町北鈴蘭南');
ok($zip->set_number('0800307')->is_valid_number, '北海道河東郡音更町中鈴蘭北');
ok($zip->set_number('0800308')->is_valid_number, '北海道河東郡音更町中鈴蘭南');
ok($zip->set_number('0800309')->is_valid_number, '北海道河東郡音更町中鈴蘭元町');
ok($zip->set_number('0800311')->is_valid_number, '北海道河東郡音更町南鈴蘭北');
ok($zip->set_number('0800312')->is_valid_number, '北海道河東郡音更町南鈴蘭南');
ok($zip->set_number('0800313')->is_valid_number, '北海道河東郡音更町鈴蘭公園');
ok($zip->set_number('0800314')->is_valid_number, '北海道河東郡音更町共栄台西');
ok($zip->set_number('0800315')->is_valid_number, '北海道河東郡音更町共栄台東');
ok($zip->set_number('0800316')->is_valid_number, '北海道河東郡音更町緑陽台北区');
ok($zip->set_number('0800317')->is_valid_number, '北海道河東郡音更町緑陽台仲区');
ok($zip->set_number('0800318')->is_valid_number, '北海道河東郡音更町緑陽台南区');
ok($zip->set_number('0800321')->is_valid_number, '北海道河東郡音更町桜が丘');
ok($zip->set_number('0800322')->is_valid_number, '北海道河東郡音更町桜が丘西');
ok($zip->set_number('0800323')->is_valid_number, '北海道河東郡音更町住吉台');
ok($zip->set_number('0800324')->is_valid_number, '北海道河東郡音更町南住吉台');
ok($zip->set_number('0800325')->is_valid_number, '北海道河東郡音更町柏寿台');
ok($zip->set_number('0800326')->is_valid_number, '北海道河東郡音更町北明台');
ok($zip->set_number('0800327')->is_valid_number, '北海道河東郡音更町北陽台');
ok($zip->set_number('0800330')->is_valid_number, '北海道河東郡音更町雄飛が丘');
ok($zip->set_number('0800331')->is_valid_number, '北海道河東郡音更町雄飛が丘北区');
ok($zip->set_number('0800332')->is_valid_number, '北海道河東郡音更町雄飛が丘仲区');
ok($zip->set_number('0800333')->is_valid_number, '北海道河東郡音更町雄飛が丘南区');
ok($zip->set_number('0800334')->is_valid_number, '北海道河東郡音更町緑が丘');
ok($zip->set_number('0800335')->is_valid_number, '北海道河東郡音更町希望が丘');
ok($zip->set_number('0800341')->is_valid_number, '北海道河東郡音更町音更');
ok($zip->set_number('0800342')->is_valid_number, '北海道河東郡音更町下音更');
ok($zip->set_number('0800343')->is_valid_number, '北海道河東郡音更町東士狩');
ok($zip->set_number('0800344')->is_valid_number, '北海道河東郡音更町万年');
ok($zip->set_number('0800345')->is_valid_number, '北海道河東郡音更町高倉');
ok($zip->set_number('0800346')->is_valid_number, '北海道河東郡音更町なつぞら');
ok($zip->set_number('0800351')->is_valid_number, '北海道河東郡音更町然別');
ok($zip->set_number('0800361')->is_valid_number, '北海道河東郡音更町すずらん台北町');
ok($zip->set_number('0800362')->is_valid_number, '北海道河東郡音更町すずらん台仲町');
ok($zip->set_number('0800363')->is_valid_number, '北海道河東郡音更町すずらん台南町');
ok($zip->set_number('0800561')->is_valid_number, '北海道河東郡音更町豊田');
ok($zip->set_number('0800562')->is_valid_number, '北海道河東郡音更町東音更');
ok($zip->set_number('0800563')->is_valid_number, '北海道河東郡音更町駒場平和台');
ok($zip->set_number('0800564')->is_valid_number, '北海道河東郡音更町駒場北町');
ok($zip->set_number('0800564')->is_valid_number, '北海道河東郡音更町駒場北1条通');
ok($zip->set_number('0800564')->is_valid_number, '北海道河東郡音更町駒場北2条通');
ok($zip->set_number('0800565')->is_valid_number, '北海道河東郡音更町駒場本通');
ok($zip->set_number('0800566')->is_valid_number, '北海道河東郡音更町駒場南1条通');
ok($zip->set_number('0800566')->is_valid_number, '北海道河東郡音更町駒場南2条通');
ok($zip->set_number('0800567')->is_valid_number, '北海道河東郡音更町駒場南3条通');
ok($zip->set_number('0800567')->is_valid_number, '北海道河東郡音更町駒場南4条通');
ok($zip->set_number('0800568')->is_valid_number, '北海道河東郡音更町駒場東');
ok($zip->set_number('0800571')->is_valid_number, '北海道河東郡音更町駒場');
ok($zip->set_number('0800572')->is_valid_number, '北海道河東郡音更町駒場並木');
ok($zip->set_number('0800573')->is_valid_number, '北海道河東郡音更町駒場南');
ok($zip->set_number('0800574')->is_valid_number, '北海道河東郡音更町駒場西');
ok($zip->set_number('0800575')->is_valid_number, '北海道河東郡音更町上然別');
ok($zip->set_number('0800576')->is_valid_number, '北海道河東郡音更町南中音更');
ok($zip->set_number('0800577')->is_valid_number, '北海道河東郡音更町西中音更');
ok($zip->set_number('0800578')->is_valid_number, '北海道河東郡音更町中音更');
ok($zip->set_number('0800801')->is_valid_number, '北海道帯広市東一条南');
ok($zip->set_number('0800802')->is_valid_number, '北海道帯広市東二条南');
ok($zip->set_number('0800803')->is_valid_number, '北海道帯広市東三条南');
ok($zip->set_number('0800804')->is_valid_number, '北海道帯広市東四条南');
ok($zip->set_number('0800805')->is_valid_number, '北海道帯広市東五条南');
ok($zip->set_number('0800806')->is_valid_number, '北海道帯広市東六条南');
ok($zip->set_number('0800807')->is_valid_number, '北海道帯広市東七条南');
ok($zip->set_number('0800808')->is_valid_number, '北海道帯広市東八条南');
ok($zip->set_number('0800809')->is_valid_number, '北海道帯広市東九条南');
ok($zip->set_number('0800810')->is_valid_number, '北海道帯広市東十条南');
ok($zip->set_number('0800811')->is_valid_number, '北海道帯広市東十一条南');
ok($zip->set_number('0800812')->is_valid_number, '北海道帯広市東十二条南');
ok($zip->set_number('0800813')->is_valid_number, '北海道帯広市東十三条南');
ok($zip->set_number('0800814')->is_valid_number, '北海道帯広市東十四条南');
ok($zip->set_number('0800815')->is_valid_number, '北海道帯広市東十五条南');
ok($zip->set_number('0800816')->is_valid_number, '北海道帯広市大川町');
ok($zip->set_number('0800817')->is_valid_number, '北海道帯広市依田町');
ok($zip->set_number('0800821')->is_valid_number, '北海道帯広市東一条北');
ok($zip->set_number('0800822')->is_valid_number, '北海道帯広市東二条北');
ok($zip->set_number('0800823')->is_valid_number, '北海道帯広市東三条北');
ok($zip->set_number('0800824')->is_valid_number, '北海道帯広市東四条北');
ok($zip->set_number('0800831')->is_valid_number, '北海道帯広市稲田町南');
ok($zip->set_number('0800832')->is_valid_number, '北海道帯広市稲田町東');
ok($zip->set_number('0800833')->is_valid_number, '北海道帯広市稲田町基線');
ok($zip->set_number('0800834')->is_valid_number, '北海道帯広市稲田町西');
ok($zip->set_number('0800835')->is_valid_number, '北海道帯広市稲田町');
ok($zip->set_number('0800836')->is_valid_number, '北海道帯広市空港南町');
ok($zip->set_number('0800837')->is_valid_number, '北海道帯広市空港南町南');
ok($zip->set_number('0800838')->is_valid_number, '北海道帯広市大空町');
ok($zip->set_number('0800841')->is_valid_number, '北海道帯広市緑ケ丘一条通');
ok($zip->set_number('0800842')->is_valid_number, '北海道帯広市緑ケ丘二条通');
ok($zip->set_number('0800843')->is_valid_number, '北海道帯広市緑ケ丘三条通');
ok($zip->set_number('0800844')->is_valid_number, '北海道帯広市緑ケ丘東通東');
ok($zip->set_number('0800845')->is_valid_number, '北海道帯広市緑ケ丘東通西');
ok($zip->set_number('0800846')->is_valid_number, '北海道帯広市緑ケ丘');
ok($zip->set_number('0800847')->is_valid_number, '北海道帯広市公園東町');
ok($zip->set_number('0800848')->is_valid_number, '北海道帯広市自由が丘(1、2丁目)');
ok($zip->set_number('0800856')->is_valid_number, '北海道帯広市南町南');
ok($zip->set_number('0800857')->is_valid_number, '北海道帯広市南町');
ok($zip->set_number('0800861')->is_valid_number, '北海道帯広市南の森東');
ok($zip->set_number('0800862')->is_valid_number, '北海道帯広市南の森西');
ok($zip->set_number('0800871')->is_valid_number, '北海道帯広市清流東');
ok($zip->set_number('0800872')->is_valid_number, '北海道帯広市清流西');
ok($zip->set_number('0801189')->is_valid_number, '北海道河東郡士幌町中士幌');
ok($zip->set_number('0801200')->is_valid_number, '北海道河東郡士幌町以下に掲載がない場合');
ok($zip->set_number('0801205')->is_valid_number, '北海道河東郡士幌町士幌');
ok($zip->set_number('0801206')->is_valid_number, '北海道河東郡士幌町士幌仲通');
ok($zip->set_number('0801207')->is_valid_number, '北海道河東郡士幌町士幌本通西');
ok($zip->set_number('0801208')->is_valid_number, '北海道河東郡士幌町士幌本通東');
ok($zip->set_number('0801209')->is_valid_number, '北海道河東郡士幌町士幌東(1条~6条)');
ok($zip->set_number('0801210')->is_valid_number, '北海道河東郡士幌町士幌東(1線~19線)');
ok($zip->set_number('0801218')->is_valid_number, '北海道河東郡士幌町士幌西(1条~3条)');
ok($zip->set_number('0801219')->is_valid_number, '北海道河東郡士幌町士幌西(1線~3線)');
ok($zip->set_number('0801228')->is_valid_number, '北海道河東郡士幌町士幌幹線');
ok($zip->set_number('0801229')->is_valid_number, '北海道河東郡士幌町士幌幹東');
ok($zip->set_number('0801230')->is_valid_number, '北海道河東郡士幌町士幌幹西');
ok($zip->set_number('0801237')->is_valid_number, '北海道河東郡士幌町士幌基線');
ok($zip->set_number('0801249')->is_valid_number, '北海道河東郡士幌町上音更');
ok($zip->set_number('0801258')->is_valid_number, '北海道河東郡士幌町ウリマク');
ok($zip->set_number('0801259')->is_valid_number, '北海道河東郡士幌町ワッカクンネップ');
ok($zip->set_number('0801260')->is_valid_number, '北海道河東郡士幌町イショッポ');
ok($zip->set_number('0801273')->is_valid_number, '北海道河東郡士幌町中音更');
ok($zip->set_number('0801285')->is_valid_number, '北海道河東郡士幌町下居辺');
ok($zip->set_number('0801400')->is_valid_number, '北海道河東郡上士幌町以下に掲載がない場合');
ok($zip->set_number('0801401')->is_valid_number, '北海道河東郡上士幌町三股');
ok($zip->set_number('0801402')->is_valid_number, '北海道河東郡上士幌町幌加');
ok($zip->set_number('0801403')->is_valid_number, '北海道河東郡上士幌町ぬかびら源泉郷');
ok($zip->set_number('0801404')->is_valid_number, '北海道河東郡上士幌町黒石平');
ok($zip->set_number('0801405')->is_valid_number, '北海道河東郡上士幌町清水谷');
ok($zip->set_number('0801406')->is_valid_number, '北海道河東郡上士幌町居辺');
ok($zip->set_number('0801407')->is_valid_number, '北海道河東郡上士幌町上音更');
ok($zip->set_number('0801408')->is_valid_number, '北海道河東郡上士幌町上士幌');
ok($zip->set_number('0802101')->is_valid_number, '北海道帯広市清川町');
ok($zip->set_number('0802102')->is_valid_number, '北海道帯広市清川町基線');
ok($zip->set_number('0802103')->is_valid_number, '北海道帯広市清川町西');
ok($zip->set_number('0802104')->is_valid_number, '北海道帯広市清川町東');
ok($zip->set_number('0802105')->is_valid_number, '北海道帯広市太平町');
ok($zip->set_number('0802106')->is_valid_number, '北海道帯広市美栄町(その他)');
ok($zip->set_number('0802111')->is_valid_number, '北海道帯広市上清川町');
ok($zip->set_number('0802112')->is_valid_number, '北海道帯広市上清川町基線');
ok($zip->set_number('0802113')->is_valid_number, '北海道帯広市上清川町西');
ok($zip->set_number('0802114')->is_valid_number, '北海道帯広市上清川町東');
ok($zip->set_number('0802115')->is_valid_number, '北海道帯広市清川町仲通');
ok($zip->set_number('0802116')->is_valid_number, '北海道帯広市清川町本通');
ok($zip->set_number('0802117')->is_valid_number, '北海道帯広市太平町西');
ok($zip->set_number('0802121')->is_valid_number, '北海道帯広市岩内町');
ok($zip->set_number('0802122')->is_valid_number, '北海道帯広市岩内町第1基線');
ok($zip->set_number('0802123')->is_valid_number, '北海道帯広市岩内町西');
ok($zip->set_number('0802124')->is_valid_number, '北海道帯広市岩内町東');
ok($zip->set_number('0802331')->is_valid_number, '北海道帯広市基松町');
ok($zip->set_number('0802332')->is_valid_number, '北海道帯広市富士町(西4~8線49~78番地)');
ok($zip->set_number('0802333')->is_valid_number, '北海道帯広市美栄町(西5~8線79~110番地)');
ok($zip->set_number('0802334')->is_valid_number, '北海道帯広市上帯広町');
ok($zip->set_number('0802335')->is_valid_number, '北海道帯広市広野町');
ok($zip->set_number('0802336')->is_valid_number, '北海道帯広市八千代町');
ok($zip->set_number('0802337')->is_valid_number, '北海道帯広市拓成町');
ok($zip->set_number('0802459')->is_valid_number, '北海道帯広市西十九条北');
ok($zip->set_number('0802460')->is_valid_number, '北海道帯広市西二十条北');
ok($zip->set_number('0802461')->is_valid_number, '北海道帯広市西二十一条北');
ok($zip->set_number('0802462')->is_valid_number, '北海道帯広市西二十二条北');
ok($zip->set_number('0802463')->is_valid_number, '北海道帯広市西二十三条北');
ok($zip->set_number('0802464')->is_valid_number, '北海道帯広市西二十四条北');
ok($zip->set_number('0802465')->is_valid_number, '北海道帯広市西二十五条北');
ok($zip->set_number('0802469')->is_valid_number, '北海道帯広市西十九条南(1~5丁目)');
ok($zip->set_number('0802470')->is_valid_number, '北海道帯広市西二十条南');
ok($zip->set_number('0802471')->is_valid_number, '北海道帯広市西二十一条南');
ok($zip->set_number('0802472')->is_valid_number, '北海道帯広市西二十二条南');
ok($zip->set_number('0802473')->is_valid_number, '北海道帯広市西二十三条南');
ok($zip->set_number('0802474')->is_valid_number, '北海道帯広市西二十四条南');
ok($zip->set_number('0802475')->is_valid_number, '北海道帯広市西二十五条南');
ok($zip->set_number('0802476')->is_valid_number, '北海道帯広市自由が丘(3~7丁目)');
ok($zip->set_number('0810000')->is_valid_number, '北海道上川郡新得町以下に掲載がない場合');
ok($zip->set_number('0810001')->is_valid_number, '北海道上川郡新得町一条北');
ok($zip->set_number('0810002')->is_valid_number, '北海道上川郡新得町二条北');
ok($zip->set_number('0810003')->is_valid_number, '北海道上川郡新得町三条北');
ok($zip->set_number('0810005')->is_valid_number, '北海道上川郡新得町本通北');
ok($zip->set_number('0810006')->is_valid_number, '北海道上川郡新得町栄町');
ok($zip->set_number('0810007')->is_valid_number, '北海道上川郡新得町元町');
ok($zip->set_number('0810008')->is_valid_number, '北海道上川郡新得町本通南');
ok($zip->set_number('0810011')->is_valid_number, '北海道上川郡新得町一条南');
ok($zip->set_number('0810012')->is_valid_number, '北海道上川郡新得町二条南');
ok($zip->set_number('0810013')->is_valid_number, '北海道上川郡新得町三条南');
ok($zip->set_number('0810014')->is_valid_number, '北海道上川郡新得町四条南');
ok($zip->set_number('0810015')->is_valid_number, '北海道上川郡新得町五条南');
ok($zip->set_number('0810021')->is_valid_number, '北海道上川郡新得町西一条北');
ok($zip->set_number('0810022')->is_valid_number, '北海道上川郡新得町西二条北');
ok($zip->set_number('0810023')->is_valid_number, '北海道上川郡新得町西三条北');
ok($zip->set_number('0810031')->is_valid_number, '北海道上川郡新得町西一条南');
ok($zip->set_number('0810032')->is_valid_number, '北海道上川郡新得町西二条南');
ok($zip->set_number('0810033')->is_valid_number, '北海道上川郡新得町西三条南');
ok($zip->set_number('0810034')->is_valid_number, '北海道上川郡新得町西四条南');
ok($zip->set_number('0810035')->is_valid_number, '北海道上川郡新得町上佐幌');
ok($zip->set_number('0810036')->is_valid_number, '北海道上川郡新得町下佐幌');
ok($zip->set_number('0810037')->is_valid_number, '北海道上川郡新得町拓鉄');
ok($zip->set_number('0810038')->is_valid_number, '北海道上川郡新得町新得');
ok($zip->set_number('0810039')->is_valid_number, '北海道上川郡新得町新内');
ok($zip->set_number('0810151')->is_valid_number, '北海道上川郡新得町屈足旭町');
ok($zip->set_number('0810152')->is_valid_number, '北海道上川郡新得町屈足旭町東');
ok($zip->set_number('0810153')->is_valid_number, '北海道上川郡新得町屈足南町');
ok($zip->set_number('0810154')->is_valid_number, '北海道上川郡新得町屈足');
ok($zip->set_number('0810155')->is_valid_number, '北海道上川郡新得町屈足幸町');
ok($zip->set_number('0810156')->is_valid_number, '北海道上川郡新得町屈足幸町西');
ok($zip->set_number('0810161')->is_valid_number, '北海道上川郡新得町屈足柏町');
ok($zip->set_number('0810162')->is_valid_number, '北海道上川郡新得町屈足柏町東');
ok($zip->set_number('0810163')->is_valid_number, '北海道上川郡新得町屈足緑町');
ok($zip->set_number('0810164')->is_valid_number, '北海道上川郡新得町屈足緑町西');
ok($zip->set_number('0810200')->is_valid_number, '北海道河東郡鹿追町以下に掲載がない場合');
ok($zip->set_number('0810201')->is_valid_number, '北海道河東郡鹿追町新町');
ok($zip->set_number('0810202')->is_valid_number, '北海道河東郡鹿追町北町');
ok($zip->set_number('0810203')->is_valid_number, '北海道河東郡鹿追町緑町');
ok($zip->set_number('0810204')->is_valid_number, '北海道河東郡鹿追町笹川北');
ok($zip->set_number('0810205')->is_valid_number, '北海道河東郡鹿追町西笹川');
ok($zip->set_number('0810211')->is_valid_number, '北海道河東郡鹿追町仲町');
ok($zip->set_number('0810212')->is_valid_number, '北海道河東郡鹿追町泉町');
ok($zip->set_number('0810213')->is_valid_number, '北海道河東郡鹿追町西町');
ok($zip->set_number('0810214')->is_valid_number, '北海道河東郡鹿追町北鹿追北');
ok($zip->set_number('0810215')->is_valid_number, '北海道河東郡鹿追町鹿追南');
ok($zip->set_number('0810216')->is_valid_number, '北海道河東郡鹿追町鹿追北');
ok($zip->set_number('0810217')->is_valid_number, '北海道河東郡鹿追町鹿追基線');
ok($zip->set_number('0810218')->is_valid_number, '北海道河東郡鹿追町上然別西');
ok($zip->set_number('0810221')->is_valid_number, '北海道河東郡鹿追町栄町');
ok($zip->set_number('0810222')->is_valid_number, '北海道河東郡鹿追町東町');
ok($zip->set_number('0810223')->is_valid_number, '北海道河東郡鹿追町南町');
ok($zip->set_number('0810224')->is_valid_number, '北海道河東郡鹿追町元町');
ok($zip->set_number('0810225')->is_valid_number, '北海道河東郡鹿追町柏ケ丘');
ok($zip->set_number('0810226')->is_valid_number, '北海道河東郡鹿追町上幌内');
ok($zip->set_number('0810227')->is_valid_number, '北海道河東郡鹿追町幌内西');
ok($zip->set_number('0810228')->is_valid_number, '北海道河東郡鹿追町美蔓西');
ok($zip->set_number('0810341')->is_valid_number, '北海道河東郡鹿追町瓜幕西');
ok($zip->set_number('0810342')->is_valid_number, '北海道河東郡鹿追町瓜幕東');
ok($zip->set_number('0810343')->is_valid_number, '北海道河東郡鹿追町瓜幕南');
ok($zip->set_number('0810344')->is_valid_number, '北海道河東郡鹿追町北瓜幕');
ok($zip->set_number('0810345')->is_valid_number, '北海道河東郡鹿追町中瓜幕西');
ok($zip->set_number('0810346')->is_valid_number, '北海道河東郡鹿追町東瓜幕西');
ok($zip->set_number('0820000')->is_valid_number, '北海道河西郡芽室町以下に掲載がない場合');
ok($zip->set_number('0820001')->is_valid_number, '北海道河西郡芽室町平和');
ok($zip->set_number('0820002')->is_valid_number, '北海道河西郡芽室町北明(光勇)');
ok($zip->set_number('0820003')->is_valid_number, '北海道河西郡芽室町西士狩(国見)');
ok($zip->set_number('0820004')->is_valid_number, '北海道河西郡芽室町東芽室北(下美生)');
ok($zip->set_number('0820005')->is_valid_number, '北海道河西郡芽室町東芽室基線(日甜)');
ok($zip->set_number('0820006')->is_valid_number, '北海道河西郡芽室町東芽室南(大成)');
ok($zip->set_number('0820007')->is_valid_number, '北海道河西郡芽室町北芽室(芽室太、美藁)');
ok($zip->set_number('0820008')->is_valid_number, '北海道河西郡芽室町毛根');
ok($zip->set_number('0820009')->is_valid_number, '北海道河西郡芽室町祥栄西');
ok($zip->set_number('0820010')->is_valid_number, '北海道河西郡芽室町祥栄北');
ok($zip->set_number('0820011')->is_valid_number, '北海道河西郡芽室町東一条');
ok($zip->set_number('0820012')->is_valid_number, '北海道河西郡芽室町東二条');
ok($zip->set_number('0820013')->is_valid_number, '北海道河西郡芽室町東三条');
ok($zip->set_number('0820014')->is_valid_number, '北海道河西郡芽室町東四条');
ok($zip->set_number('0820015')->is_valid_number, '北海道河西郡芽室町東五条');
ok($zip->set_number('0820016')->is_valid_number, '北海道河西郡芽室町東六条');
ok($zip->set_number('0820017')->is_valid_number, '北海道河西郡芽室町東七条');
ok($zip->set_number('0820018')->is_valid_number, '北海道河西郡芽室町東八条');
ok($zip->set_number('0820019')->is_valid_number, '北海道河西郡芽室町東九条');
ok($zip->set_number('0820020')->is_valid_number, '北海道河西郡芽室町東十条');
ok($zip->set_number('0820021')->is_valid_number, '北海道河西郡芽室町東十一条');
ok($zip->set_number('0820022')->is_valid_number, '北海道河西郡芽室町東十二条');
ok($zip->set_number('0820030')->is_valid_number, '北海道河西郡芽室町本通');
ok($zip->set_number('0820031')->is_valid_number, '北海道河西郡芽室町西一条');
ok($zip->set_number('0820032')->is_valid_number, '北海道河西郡芽室町西二条');
ok($zip->set_number('0820033')->is_valid_number, '北海道河西郡芽室町西三条');
ok($zip->set_number('0820034')->is_valid_number, '北海道河西郡芽室町西四条');
ok($zip->set_number('0820035')->is_valid_number, '北海道河西郡芽室町西五条');
ok($zip->set_number('0820036')->is_valid_number, '北海道河西郡芽室町西六条');
ok($zip->set_number('0820037')->is_valid_number, '北海道河西郡芽室町西七条');
ok($zip->set_number('0820038')->is_valid_number, '北海道河西郡芽室町西八条');
ok($zip->set_number('0820039')->is_valid_number, '北海道河西郡芽室町西九条');
ok($zip->set_number('0820040')->is_valid_number, '北海道河西郡芽室町西十条');
ok($zip->set_number('0820041')->is_valid_number, '北海道河西郡芽室町西十一条');
ok($zip->set_number('0820042')->is_valid_number, '北海道河西郡芽室町芽室北(西芽室、中島)');
ok($zip->set_number('0820043')->is_valid_number, '北海道河西郡芽室町芽室基線(元町)');
ok($zip->set_number('0820044')->is_valid_number, '北海道河西郡芽室町芽室南(南弥生、高岩)');
ok($zip->set_number('0820051')->is_valid_number, '北海道河西郡芽室町東一条南');
ok($zip->set_number('0820052')->is_valid_number, '北海道河西郡芽室町東二条南');
ok($zip->set_number('0820053')->is_valid_number, '北海道河西郡芽室町東三条南');
ok($zip->set_number('0820054')->is_valid_number, '北海道河西郡芽室町東四条南');
ok($zip->set_number('0820056')->is_valid_number, '北海道河西郡芽室町東六条南');
ok($zip->set_number('0820057')->is_valid_number, '北海道河西郡芽室町東七条南');
ok($zip->set_number('0820060')->is_valid_number, '北海道河西郡芽室町本通南');
ok($zip->set_number('0820061')->is_valid_number, '北海道河西郡芽室町西一条南');
ok($zip->set_number('0820062')->is_valid_number, '北海道河西郡芽室町西二条南');
ok($zip->set_number('0820063')->is_valid_number, '北海道河西郡芽室町西三条南');
ok($zip->set_number('0820064')->is_valid_number, '北海道河西郡芽室町西四条南');
ok($zip->set_number('0820071')->is_valid_number, '北海道河西郡芽室町新生');
ok($zip->set_number('0820072')->is_valid_number, '北海道河西郡芽室町北伏古南');
ok($zip->set_number('0820073')->is_valid_number, '北海道河西郡芽室町中伏古');
ok($zip->set_number('0820074')->is_valid_number, '北海道河西郡芽室町栄(柏友、光栄、豊来、常盤、丸山)');
ok($zip->set_number('0820075')->is_valid_number, '北海道河西郡芽室町坂の上(博進)');
ok($zip->set_number('0820076')->is_valid_number, '北海道河西郡芽室町美生');
ok($zip->set_number('0820077')->is_valid_number, '北海道河西郡芽室町上芽室南');
ok($zip->set_number('0820078')->is_valid_number, '北海道河西郡芽室町渋山(その他)');
ok($zip->set_number('0820079')->is_valid_number, '北海道河西郡芽室町新朝日');
ok($zip->set_number('0820081')->is_valid_number, '北海道河西郡芽室町新生南');
ok($zip->set_number('0820082')->is_valid_number, '北海道河西郡芽室町北伏古東');
ok($zip->set_number('0820083')->is_valid_number, '北海道河西郡芽室町中伏古東');
ok($zip->set_number('0820084')->is_valid_number, '北海道河西郡芽室町上芽室北');
ok($zip->set_number('0820085')->is_valid_number, '北海道河西郡芽室町上芽室基線');
ok($zip->set_number('0820086')->is_valid_number, '北海道河西郡芽室町中美生');
ok($zip->set_number('0820087')->is_valid_number, '北海道河西郡芽室町上芽室東');
ok($zip->set_number('0820381')->is_valid_number, '北海道河西郡芽室町上伏古');
ok($zip->set_number('0820382')->is_valid_number, '北海道河西郡芽室町雄馬別');
ok($zip->set_number('0820383')->is_valid_number, '北海道河西郡芽室町伏美');
ok($zip->set_number('0820384')->is_valid_number, '北海道河西郡芽室町上美生');
ok($zip->set_number('0820385')->is_valid_number, '北海道河西郡芽室町渋山(上渋山)');
ok($zip->set_number('0820801')->is_valid_number, '北海道河西郡芽室町東めむろ一条北');
ok($zip->set_number('0820802')->is_valid_number, '北海道河西郡芽室町東めむろ二条北');
ok($zip->set_number('0820803')->is_valid_number, '北海道河西郡芽室町東めむろ三条北');
ok($zip->set_number('0820811')->is_valid_number, '北海道河西郡芽室町東めむろ一条南');
ok($zip->set_number('0820812')->is_valid_number, '北海道河西郡芽室町東めむろ二条南');
ok($zip->set_number('0820813')->is_valid_number, '北海道河西郡芽室町東めむろ三条南');
ok($zip->set_number('0830000')->is_valid_number, '北海道中川郡池田町以下に掲載がない場合');
ok($zip->set_number('0830001')->is_valid_number, '北海道中川郡池田町旭町');
ok($zip->set_number('0830002')->is_valid_number, '北海道中川郡池田町清見');
ok($zip->set_number('0830003')->is_valid_number, '北海道中川郡池田町清見ケ丘');
ok($zip->set_number('0830004')->is_valid_number, '北海道中川郡池田町様舞');
ok($zip->set_number('0830020')->is_valid_number, '北海道中川郡池田町大通南');
ok($zip->set_number('0830021')->is_valid_number, '北海道中川郡池田町西一条');
ok($zip->set_number('0830022')->is_valid_number, '北海道中川郡池田町西二条');
ok($zip->set_number('0830023')->is_valid_number, '北海道中川郡池田町西三条');
ok($zip->set_number('0830031')->is_valid_number, '北海道中川郡池田町利別西町');
ok($zip->set_number('0830032')->is_valid_number, '北海道中川郡池田町利別東町');
ok($zip->set_number('0830033')->is_valid_number, '北海道中川郡池田町利別南町');
ok($zip->set_number('0830034')->is_valid_number, '北海道中川郡池田町利別本町');
ok($zip->set_number('0830041')->is_valid_number, '北海道中川郡池田町川合');
ok($zip->set_number('0830042')->is_valid_number, '北海道中川郡池田町千代田');
ok($zip->set_number('0830043')->is_valid_number, '北海道中川郡池田町豊田');
ok($zip->set_number('0830044')->is_valid_number, '北海道中川郡池田町青山');
ok($zip->set_number('0830045')->is_valid_number, '北海道中川郡池田町富岡');
ok($zip->set_number('0830046')->is_valid_number, '北海道中川郡池田町東台');
ok($zip->set_number('0830047')->is_valid_number, '北海道中川郡池田町昭栄');
ok($zip->set_number('0830090')->is_valid_number, '北海道中川郡池田町大通');
ok($zip->set_number('0830091')->is_valid_number, '北海道中川郡池田町東一条');
ok($zip->set_number('0830092')->is_valid_number, '北海道中川郡池田町東二条');
ok($zip->set_number('0840901')->is_valid_number, '北海道釧路市昭和北');
ok($zip->set_number('0840902')->is_valid_number, '北海道釧路市昭和');
ok($zip->set_number('0840903')->is_valid_number, '北海道釧路市昭和町');
ok($zip->set_number('0840904')->is_valid_number, '北海道釧路市新富士町');
ok($zip->set_number('0840905')->is_valid_number, '北海道釧路市鳥取南');
ok($zip->set_number('0840906')->is_valid_number, '北海道釧路市鳥取大通');
ok($zip->set_number('0840907')->is_valid_number, '北海道釧路市鳥取北');
ok($zip->set_number('0840908')->is_valid_number, '北海道釧路市北園');
ok($zip->set_number('0840909')->is_valid_number, '北海道釧路市昭和南');
ok($zip->set_number('0840910')->is_valid_number, '北海道釧路市昭和中央');
ok($zip->set_number('0840911')->is_valid_number, '北海道釧路市星が浦北');
ok($zip->set_number('0840912')->is_valid_number, '北海道釧路市星が浦大通');
ok($zip->set_number('0840913')->is_valid_number, '北海道釧路市星が浦南');
ok($zip->set_number('0840914')->is_valid_number, '北海道釧路市西港');
ok($zip->set_number('0840915')->is_valid_number, '北海道釧路市大楽毛南');
ok($zip->set_number('0840916')->is_valid_number, '北海道釧路市大楽毛西');
ok($zip->set_number('0840917')->is_valid_number, '北海道釧路市大楽毛');
ok($zip->set_number('0840918')->is_valid_number, '北海道釧路市大楽毛北');
ok($zip->set_number('0840921')->is_valid_number, '北海道釧路市美濃');
ok($zip->set_number('0840922')->is_valid_number, '北海道釧路市北斗');
ok($zip->set_number('0840923')->is_valid_number, '北海道釧路市鶴野東');
ok($zip->set_number('0840924')->is_valid_number, '北海道釧路市鶴野');
ok($zip->set_number('0840925')->is_valid_number, '北海道釧路市新野');
ok($zip->set_number('0840926')->is_valid_number, '北海道釧路市鶴丘');
ok($zip->set_number('0840927')->is_valid_number, '北海道釧路市駒牧');
ok($zip->set_number('0840928')->is_valid_number, '北海道釧路市山花');
ok($zip->set_number('0840929')->is_valid_number, '北海道釧路市中鶴野');
ok($zip->set_number('0850000')->is_valid_number, '北海道釧路市以下に掲載がない場合');
ok($zip->set_number('0850001')->is_valid_number, '北海道釧路市古川町');
ok($zip->set_number('0850002')->is_valid_number, '北海道釧路市新釧路町');
ok($zip->set_number('0850003')->is_valid_number, '北海道釧路市川北町');
ok($zip->set_number('0850004')->is_valid_number, '北海道釧路市新富町');
ok($zip->set_number('0850005')->is_valid_number, '北海道釧路市松浦町');
ok($zip->set_number('0850006')->is_valid_number, '北海道釧路市双葉町');
ok($zip->set_number('0850007')->is_valid_number, '北海道釧路市堀川町');
ok($zip->set_number('0850008')->is_valid_number, '北海道釧路市入江町');
ok($zip->set_number('0850011')->is_valid_number, '北海道釧路市旭町');
ok($zip->set_number('0850012')->is_valid_number, '北海道釧路市川上町');
ok($zip->set_number('0850013')->is_valid_number, '北海道釧路市栄町');
ok($zip->set_number('0850014')->is_valid_number, '北海道釧路市末広町');
ok($zip->set_number('0850015')->is_valid_number, '北海道釧路市北大通');
ok($zip->set_number('0850016')->is_valid_number, '北海道釧路市錦町');
ok($zip->set_number('0850017')->is_valid_number, '北海道釧路市幸町');
ok($zip->set_number('0850018')->is_valid_number, '北海道釧路市黒金町');
ok($zip->set_number('0850021')->is_valid_number, '北海道釧路市浪花町');
ok($zip->set_number('0850022')->is_valid_number, '北海道釧路市南浜町');
ok($zip->set_number('0850023')->is_valid_number, '北海道釧路市海運');
ok($zip->set_number('0850024')->is_valid_number, '北海道釧路市浜町');
ok($zip->set_number('0850025')->is_valid_number, '北海道釧路市宝町');
ok($zip->set_number('0850026')->is_valid_number, '北海道釧路市寿');
ok($zip->set_number('0850027')->is_valid_number, '北海道釧路市仲浜町');
ok($zip->set_number('0850031')->is_valid_number, '北海道釧路市中島町');
ok($zip->set_number('0850032')->is_valid_number, '北海道釧路市新栄町');
ok($zip->set_number('0850033')->is_valid_number, '北海道釧路市若松町');
ok($zip->set_number('0850034')->is_valid_number, '北海道釧路市白金町');
ok($zip->set_number('0850035')->is_valid_number, '北海道釧路市共栄大通');
ok($zip->set_number('0850036')->is_valid_number, '北海道釧路市若竹町');
ok($zip->set_number('0850037')->is_valid_number, '北海道釧路市柳町');
ok($zip->set_number('0850038')->is_valid_number, '北海道釧路市花園町');
ok($zip->set_number('0850041')->is_valid_number, '北海道釧路市春日町');
ok($zip->set_number('0850042')->is_valid_number, '北海道釧路市若草町');
ok($zip->set_number('0850043')->is_valid_number, '北海道釧路市喜多町');
ok($zip->set_number('0850044')->is_valid_number, '北海道釧路市川端町');
ok($zip->set_number('0850045')->is_valid_number, '北海道釧路市住之江町');
ok($zip->set_number('0850046')->is_valid_number, '北海道釧路市新橋大通');
ok($zip->set_number('0850047')->is_valid_number, '北海道釧路市新川町');
ok($zip->set_number('0850048')->is_valid_number, '北海道釧路市駒場町');
ok($zip->set_number('0850051')->is_valid_number, '北海道釧路市光陽町');
ok($zip->set_number('0850052')->is_valid_number, '北海道釧路市中園町');
ok($zip->set_number('0850053')->is_valid_number, '北海道釧路市豊川町');
ok($zip->set_number('0850054')->is_valid_number, '北海道釧路市暁町');
ok($zip->set_number('0850055')->is_valid_number, '北海道釧路市治水町');
ok($zip->set_number('0850056')->is_valid_number, '北海道釧路市東川町');
ok($zip->set_number('0850057')->is_valid_number, '北海道釧路市愛国西');
ok($zip->set_number('0850058')->is_valid_number, '北海道釧路市愛国東');
ok($zip->set_number('0850061')->is_valid_number, '北海道釧路市芦野');
ok($zip->set_number('0850062')->is_valid_number, '北海道釧路市愛国');
ok($zip->set_number('0850063')->is_valid_number, '北海道釧路市文苑');
ok($zip->set_number('0850064')->is_valid_number, '北海道釧路市広里');
ok($zip->set_number('0850065')->is_valid_number, '北海道釧路市美原');
ok($zip->set_number('0850201')->is_valid_number, '北海道釧路市阿寒町仁々志別');
ok($zip->set_number('0850202')->is_valid_number, '北海道釧路市阿寒町上仁々志別');
ok($zip->set_number('0850203')->is_valid_number, '北海道釧路市阿寒町中仁々志別');
ok($zip->set_number('0850204')->is_valid_number, '北海道釧路市阿寒町下仁々志別');
ok($zip->set_number('0850205')->is_valid_number, '北海道釧路市阿寒町東栄');
ok($zip->set_number('0850206')->is_valid_number, '北海道釧路市阿寒町共和');
ok($zip->set_number('0850211')->is_valid_number, '北海道釧路市阿寒町下舌辛');
ok($zip->set_number('0850212')->is_valid_number, '北海道釧路市阿寒町旭町');
ok($zip->set_number('0850213')->is_valid_number, '北海道釧路市阿寒町仲町');
ok($zip->set_number('0850214')->is_valid_number, '北海道釧路市阿寒町富士見');
ok($zip->set_number('0850215')->is_valid_number, '北海道釧路市阿寒町中央');
ok($zip->set_number('0850216')->is_valid_number, '北海道釧路市阿寒町北新町');
ok($zip->set_number('0850217')->is_valid_number, '北海道釧路市阿寒町北町');
ok($zip->set_number('0850218')->is_valid_number, '北海道釧路市阿寒町新町');
ok($zip->set_number('0850220')->is_valid_number, '北海道釧路市阿寒町舌辛');
ok($zip->set_number('0850221')->is_valid_number, '北海道釧路市阿寒町上舌辛');
ok($zip->set_number('0850222')->is_valid_number, '北海道釧路市阿寒町布伏内');
ok($zip->set_number('0850223')->is_valid_number, '北海道釧路市阿寒町下布伏内');
ok($zip->set_number('0850224')->is_valid_number, '北海道釧路市阿寒町雄別横山');
ok($zip->set_number('0850225')->is_valid_number, '北海道釧路市阿寒町知茶布');
ok($zip->set_number('0850231')->is_valid_number, '北海道釧路市阿寒町下徹別');
ok($zip->set_number('0850232')->is_valid_number, '北海道釧路市阿寒町大正');
ok($zip->set_number('0850233')->is_valid_number, '北海道釧路市阿寒町西徹別');
ok($zip->set_number('0850234')->is_valid_number, '北海道釧路市阿寒町蘇牛');
ok($zip->set_number('0850235')->is_valid_number, '北海道釧路市阿寒町上徹別');
ok($zip->set_number('0850236')->is_valid_number, '北海道釧路市阿寒町中徹別');
ok($zip->set_number('0850237')->is_valid_number, '北海道釧路市阿寒町徹別中央');
ok($zip->set_number('0850238')->is_valid_number, '北海道釧路市阿寒町飽別');
ok($zip->set_number('0850241')->is_valid_number, '北海道釧路市阿寒町中阿寒');
ok($zip->set_number('0850242')->is_valid_number, '北海道釧路市阿寒町東舌辛');
ok($zip->set_number('0850243')->is_valid_number, '北海道釧路市阿寒町西阿寒');
ok($zip->set_number('0850244')->is_valid_number, '北海道釧路市阿寒町紀ノ丘');
ok($zip->set_number('0850245')->is_valid_number, '北海道釧路市阿寒町上阿寒');
ok($zip->set_number('0850251')->is_valid_number, '北海道釧路市桜田');
ok($zip->set_number('0850252')->is_valid_number, '北海道釧路市青山');
ok($zip->set_number('0850467')->is_valid_number, '北海道釧路市阿寒町阿寒湖温泉(1~6丁目)');
ok($zip->set_number('0850468')->is_valid_number, '北海道釧路市阿寒町オクルシュベ');
ok($zip->set_number('0850801')->is_valid_number, '北海道釧路市三津浦');
ok($zip->set_number('0850802')->is_valid_number, '北海道釧路市桂恋');
ok($zip->set_number('0850803')->is_valid_number, '北海道釧路市益浦');
ok($zip->set_number('0850804')->is_valid_number, '北海道釧路市白樺台');
ok($zip->set_number('0850805')->is_valid_number, '北海道釧路市桜ケ岡');
ok($zip->set_number('0850806')->is_valid_number, '北海道釧路市武佐');
ok($zip->set_number('0850807')->is_valid_number, '北海道釧路市高山');
ok($zip->set_number('0850811')->is_valid_number, '北海道釧路市興津');
ok($zip->set_number('0850812')->is_valid_number, '北海道釧路市紫雲台');
ok($zip->set_number('0850813')->is_valid_number, '北海道釧路市春採');
ok($zip->set_number('0850814')->is_valid_number, '北海道釧路市緑ケ岡');
ok($zip->set_number('0850815')->is_valid_number, '北海道釧路市材木町');
ok($zip->set_number('0850816')->is_valid_number, '北海道釧路市貝塚');
ok($zip->set_number('0850821')->is_valid_number, '北海道釧路市鶴ケ岱');
ok($zip->set_number('0850822')->is_valid_number, '北海道釧路市春湖台');
ok($zip->set_number('0850823')->is_valid_number, '北海道釧路市千代ノ浦');
ok($zip->set_number('0850824')->is_valid_number, '北海道釧路市柏木町');
ok($zip->set_number('0850825')->is_valid_number, '北海道釧路市千歳町');
ok($zip->set_number('0850826')->is_valid_number, '北海道釧路市城山');
ok($zip->set_number('0850831')->is_valid_number, '北海道釧路市住吉');
ok($zip->set_number('0850832')->is_valid_number, '北海道釧路市富士見');
ok($zip->set_number('0850833')->is_valid_number, '北海道釧路市宮本');
ok($zip->set_number('0850834')->is_valid_number, '北海道釧路市弥生');
ok($zip->set_number('0850835')->is_valid_number, '北海道釧路市浦見');
ok($zip->set_number('0850836')->is_valid_number, '北海道釧路市幣舞町');
ok($zip->set_number('0850837')->is_valid_number, '北海道釧路市大川町');
ok($zip->set_number('0850841')->is_valid_number, '北海道釧路市南大通');
ok($zip->set_number('0850842')->is_valid_number, '北海道釧路市米町');
ok($zip->set_number('0850843')->is_valid_number, '北海道釧路市弁天ケ浜');
ok($zip->set_number('0850844')->is_valid_number, '北海道釧路市知人町');
ok($zip->set_number('0850845')->is_valid_number, '北海道釧路市港町');
ok($zip->set_number('0850846')->is_valid_number, '北海道釧路市入舟');
ok($zip->set_number('0850847')->is_valid_number, '北海道釧路市大町');
ok($zip->set_number('0851131')->is_valid_number, '北海道阿寒郡鶴居村新幌呂');
ok($zip->set_number('0851132')->is_valid_number, '北海道阿寒郡鶴居村上幌呂');
ok($zip->set_number('0851133')->is_valid_number, '北海道阿寒郡鶴居村支幌呂');
ok($zip->set_number('0851134')->is_valid_number, '北海道阿寒郡鶴居村茂幌呂');
ok($zip->set_number('0851141')->is_valid_number, '北海道阿寒郡鶴居村幌呂西');
ok($zip->set_number('0851142')->is_valid_number, '北海道阿寒郡鶴居村幌呂東');
ok($zip->set_number('0851143')->is_valid_number, '北海道阿寒郡鶴居村中幌呂');
ok($zip->set_number('0851144')->is_valid_number, '北海道阿寒郡鶴居村下幌呂');
ok($zip->set_number('0851145')->is_valid_number, '北海道阿寒郡鶴居村温根内');
ok($zip->set_number('0851146')->is_valid_number, '北海道阿寒郡鶴居村アトコシヤラカ');
ok($zip->set_number('0851147')->is_valid_number, '北海道阿寒郡鶴居村幌呂');
ok($zip->set_number('0851200')->is_valid_number, '北海道阿寒郡鶴居村以下に掲載がない場合');
ok($zip->set_number('0851201')->is_valid_number, '北海道阿寒郡鶴居村鶴居北');
ok($zip->set_number('0851202')->is_valid_number, '北海道阿寒郡鶴居村中雪裡(西)');
ok($zip->set_number('0851203')->is_valid_number, '北海道阿寒郡鶴居村鶴居西');
ok($zip->set_number('0851204')->is_valid_number, '北海道阿寒郡鶴居村鶴居南');
ok($zip->set_number('0851205')->is_valid_number, '北海道阿寒郡鶴居村中雪裡(南)');
ok($zip->set_number('0851206')->is_valid_number, '北海道阿寒郡鶴居村鶴居東');
ok($zip->set_number('0851207')->is_valid_number, '北海道阿寒郡鶴居村中雪裡(東)');
ok($zip->set_number('0851211')->is_valid_number, '北海道阿寒郡鶴居村下雪裡');
ok($zip->set_number('0851212')->is_valid_number, '北海道阿寒郡鶴居村支雪裡');
ok($zip->set_number('0851213')->is_valid_number, '北海道阿寒郡鶴居村茂雪裡');
ok($zip->set_number('0851261')->is_valid_number, '北海道阿寒郡鶴居村中久著呂');
ok($zip->set_number('0851262')->is_valid_number, '北海道阿寒郡鶴居村下久著呂');
ok($zip->set_number('0852271')->is_valid_number, '北海道釧路郡釧路町跡永賀村');
ok($zip->set_number('0852272')->is_valid_number, '北海道釧路郡釧路町昆布森');
ok($zip->set_number('0852273')->is_valid_number, '北海道釧路郡釧路町昆布森村');
ok($zip->set_number('0860061')->is_valid_number, '北海道根室市明郷');
ok($zip->set_number('0860062')->is_valid_number, '北海道根室市湖南');
ok($zip->set_number('0860063')->is_valid_number, '北海道根室市東厚床');
ok($zip->set_number('0860064')->is_valid_number, '北海道根室市厚床');
ok($zip->set_number('0860065')->is_valid_number, '北海道根室市西厚床');
ok($zip->set_number('0860071')->is_valid_number, '北海道根室市槍昔');
ok($zip->set_number('0860072')->is_valid_number, '北海道根室市川口');
ok($zip->set_number('0860073')->is_valid_number, '北海道根室市酪陽');
ok($zip->set_number('0860074')->is_valid_number, '北海道根室市東梅');
ok($zip->set_number('0860075')->is_valid_number, '北海道根室市別当賀');
ok($zip->set_number('0860076')->is_valid_number, '北海道根室市初田牛');
ok($zip->set_number('0860081')->is_valid_number, '北海道厚岸郡浜中町厚陽');
ok($zip->set_number('0860131')->is_valid_number, '北海道野付郡別海町上風連');
ok($zip->set_number('0860200')->is_valid_number, '北海道野付郡別海町以下に掲載がない場合');
ok($zip->set_number('0860201')->is_valid_number, '北海道野付郡別海町別海宮舞町');
ok($zip->set_number('0860202')->is_valid_number, '北海道野付郡別海町別海旭町');
ok($zip->set_number('0860203')->is_valid_number, '北海道野付郡別海町別海西本町');
ok($zip->set_number('0860204')->is_valid_number, '北海道野付郡別海町別海新栄町');
ok($zip->set_number('0860205')->is_valid_number, '北海道野付郡別海町別海常盤町');
ok($zip->set_number('0860211')->is_valid_number, '北海道野付郡別海町別海寿町');
ok($zip->set_number('0860212')->is_valid_number, '北海道野付郡別海町別海鶴舞町');
ok($zip->set_number('0860213')->is_valid_number, '北海道野付郡別海町奥行');
ok($zip->set_number('0860214')->is_valid_number, '北海道野付郡別海町別海緑町');
ok($zip->set_number('0860215')->is_valid_number, '北海道野付郡別海町別海川上町');
ok($zip->set_number('0860216')->is_valid_number, '北海道野付郡別海町別海');
ok($zip->set_number('0860341')->is_valid_number, '北海道野付郡別海町中西別緑町');
ok($zip->set_number('0860342')->is_valid_number, '北海道野付郡別海町中西別朝日町');
ok($zip->set_number('0860343')->is_valid_number, '北海道野付郡別海町中西別光町');
ok($zip->set_number('0860344')->is_valid_number, '北海道野付郡別海町中西別本町');
ok($zip->set_number('0860345')->is_valid_number, '北海道野付郡別海町中西別');
ok($zip->set_number('0860346')->is_valid_number, '北海道野付郡別海町矢臼別(その他)');
ok($zip->set_number('0860521')->is_valid_number, '北海道野付郡別海町床丹(その他)');
ok($zip->set_number('0860522')->is_valid_number, '北海道野付郡別海町本別海');
ok($zip->set_number('0860523')->is_valid_number, '北海道野付郡別海町走古丹');
ok($zip->set_number('0860651')->is_valid_number, '北海道野付郡別海町中春別東町');
ok($zip->set_number('0860652')->is_valid_number, '北海道野付郡別海町中春別南町');
ok($zip->set_number('0860653')->is_valid_number, '北海道野付郡別海町中春別西町');
ok($zip->set_number('0860654')->is_valid_number, '北海道野付郡別海町中春別');
ok($zip->set_number('0860655')->is_valid_number, '北海道野付郡別海町床丹(1番地)');
ok($zip->set_number('0860656')->is_valid_number, '北海道野付郡別海町美原');
ok($zip->set_number('0860657')->is_valid_number, '北海道野付郡別海町豊原');
ok($zip->set_number('0861001')->is_valid_number, '北海道標津郡中標津町東1条南');
ok($zip->set_number('0861002')->is_valid_number, '北海道標津郡中標津町東2条南');
ok($zip->set_number('0861003')->is_valid_number, '北海道標津郡中標津町東3条南');
ok($zip->set_number('0861004')->is_valid_number, '北海道標津郡中標津町東4条南');
ok($zip->set_number('0861005')->is_valid_number, '北海道標津郡中標津町東5条南');
ok($zip->set_number('0861006')->is_valid_number, '北海道標津郡中標津町東6条南');
ok($zip->set_number('0861007')->is_valid_number, '北海道標津郡中標津町東7条南');
ok($zip->set_number('0861008')->is_valid_number, '北海道標津郡中標津町東8条南');
ok($zip->set_number('0861009')->is_valid_number, '北海道標津郡中標津町東9条南');
ok($zip->set_number('0861010')->is_valid_number, '北海道標津郡中標津町東10条南');
ok($zip->set_number('0861011')->is_valid_number, '北海道標津郡中標津町東11条南');
ok($zip->set_number('0861012')->is_valid_number, '北海道標津郡中標津町東12条南');
ok($zip->set_number('0861013')->is_valid_number, '北海道標津郡中標津町東13条南');
ok($zip->set_number('0861014')->is_valid_number, '北海道標津郡中標津町東14条南');
ok($zip->set_number('0861015')->is_valid_number, '北海道標津郡中標津町東15条南');
ok($zip->set_number('0861016')->is_valid_number, '北海道標津郡中標津町東16条南');
ok($zip->set_number('0861017')->is_valid_number, '北海道標津郡中標津町東17条南');
ok($zip->set_number('0861018')->is_valid_number, '北海道標津郡中標津町東18条南');
ok($zip->set_number('0861019')->is_valid_number, '北海道標津郡中標津町東19条南');
ok($zip->set_number('0861020')->is_valid_number, '北海道標津郡中標津町東20条南');
ok($zip->set_number('0861021')->is_valid_number, '北海道標津郡中標津町東21条南');
ok($zip->set_number('0861022')->is_valid_number, '北海道標津郡中標津町東22条南');
ok($zip->set_number('0861023')->is_valid_number, '北海道標津郡中標津町東23条南');
ok($zip->set_number('0861024')->is_valid_number, '北海道標津郡中標津町東24条南');
ok($zip->set_number('0861025')->is_valid_number, '北海道標津郡中標津町東25条南');
ok($zip->set_number('0861026')->is_valid_number, '北海道標津郡中標津町東26条南');
ok($zip->set_number('0861027')->is_valid_number, '北海道標津郡中標津町東27条南');
ok($zip->set_number('0861028')->is_valid_number, '北海道標津郡中標津町東28条南');
ok($zip->set_number('0861029')->is_valid_number, '北海道標津郡中標津町東29条南');
ok($zip->set_number('0861030')->is_valid_number, '北海道標津郡中標津町東30条南');
ok($zip->set_number('0861031')->is_valid_number, '北海道標津郡中標津町東31条南');
ok($zip->set_number('0861032')->is_valid_number, '北海道標津郡中標津町東32条南');
ok($zip->set_number('0861033')->is_valid_number, '北海道標津郡中標津町東33条南');
ok($zip->set_number('0861034')->is_valid_number, '北海道標津郡中標津町東34条南');
ok($zip->set_number('0861035')->is_valid_number, '北海道標津郡中標津町東35条南');
ok($zip->set_number('0861036')->is_valid_number, '北海道標津郡中標津町東36条南');
ok($zip->set_number('0861037')->is_valid_number, '北海道標津郡中標津町東37条南');
ok($zip->set_number('0861038')->is_valid_number, '北海道標津郡中標津町東38条南');
ok($zip->set_number('0861039')->is_valid_number, '北海道標津郡中標津町東39条南');
ok($zip->set_number('0861041')->is_valid_number, '北海道標津郡中標津町東1条北');
ok($zip->set_number('0861042')->is_valid_number, '北海道標津郡中標津町東2条北');
ok($zip->set_number('0861043')->is_valid_number, '北海道標津郡中標津町東3条北');
ok($zip->set_number('0861044')->is_valid_number, '北海道標津郡中標津町東4条北');
ok($zip->set_number('0861045')->is_valid_number, '北海道標津郡中標津町東5条北');
ok($zip->set_number('0861046')->is_valid_number, '北海道標津郡中標津町東6条北');
ok($zip->set_number('0861047')->is_valid_number, '北海道標津郡中標津町東7条北');
ok($zip->set_number('0861048')->is_valid_number, '北海道標津郡中標津町東8条北');
ok($zip->set_number('0861049')->is_valid_number, '北海道標津郡中標津町東9条北');
ok($zip->set_number('0861050')->is_valid_number, '北海道標津郡中標津町東10条北');
ok($zip->set_number('0861051')->is_valid_number, '北海道標津郡中標津町東11条北');
ok($zip->set_number('0861052')->is_valid_number, '北海道標津郡中標津町東12条北');
ok($zip->set_number('0861053')->is_valid_number, '北海道標津郡中標津町東13条北');
ok($zip->set_number('0861054')->is_valid_number, '北海道標津郡中標津町東14条北');
ok($zip->set_number('0861055')->is_valid_number, '北海道標津郡中標津町東15条北');
ok($zip->set_number('0861056')->is_valid_number, '北海道標津郡中標津町東16条北');
ok($zip->set_number('0861057')->is_valid_number, '北海道標津郡中標津町東17条北');
ok($zip->set_number('0861058')->is_valid_number, '北海道標津郡中標津町東18条北');
ok($zip->set_number('0861059')->is_valid_number, '北海道標津郡中標津町東19条北');
ok($zip->set_number('0861060')->is_valid_number, '北海道標津郡中標津町東20条北');
ok($zip->set_number('0861061')->is_valid_number, '北海道標津郡中標津町東21条北');
ok($zip->set_number('0861062')->is_valid_number, '北海道標津郡中標津町東22条北');
ok($zip->set_number('0861063')->is_valid_number, '北海道標津郡中標津町東23条北');
ok($zip->set_number('0861064')->is_valid_number, '北海道標津郡中標津町東24条北');
ok($zip->set_number('0861065')->is_valid_number, '北海道標津郡中標津町東25条北');
ok($zip->set_number('0861066')->is_valid_number, '北海道標津郡中標津町東26条北');
ok($zip->set_number('0861067')->is_valid_number, '北海道標津郡中標津町東27条北');
ok($zip->set_number('0861068')->is_valid_number, '北海道標津郡中標津町東28条北');
ok($zip->set_number('0861069')->is_valid_number, '北海道標津郡中標津町東29条北');
ok($zip->set_number('0861070')->is_valid_number, '北海道標津郡中標津町東30条北');
ok($zip->set_number('0861071')->is_valid_number, '北海道標津郡中標津町東31条北');
ok($zip->set_number('0861072')->is_valid_number, '北海道標津郡中標津町東32条北');
ok($zip->set_number('0861073')->is_valid_number, '北海道標津郡中標津町東33条北');
ok($zip->set_number('0861074')->is_valid_number, '北海道標津郡中標津町東34条北');
ok($zip->set_number('0861075')->is_valid_number, '北海道標津郡中標津町東35条北');
ok($zip->set_number('0861076')->is_valid_number, '北海道標津郡中標津町東36条北');
ok($zip->set_number('0861077')->is_valid_number, '北海道標津郡中標津町東37条北');
ok($zip->set_number('0861078')->is_valid_number, '北海道標津郡中標津町東38条北');
ok($zip->set_number('0861079')->is_valid_number, '北海道標津郡中標津町東39条北');
ok($zip->set_number('0861080')->is_valid_number, '北海道標津郡中標津町東40条南');
ok($zip->set_number('0861080')->is_valid_number, '北海道標津郡中標津町東40条北');
ok($zip->set_number('0861081')->is_valid_number, '北海道標津郡中標津町東41条南');
ok($zip->set_number('0861081')->is_valid_number, '北海道標津郡中標津町東41条北');
ok($zip->set_number('0861082')->is_valid_number, '北海道標津郡中標津町東42条南');
ok($zip->set_number('0861082')->is_valid_number, '北海道標津郡中標津町東42条北');
ok($zip->set_number('0861083')->is_valid_number, '北海道標津郡中標津町東中');
ok($zip->set_number('0861100')->is_valid_number, '北海道標津郡中標津町以下に掲載がない場合');
ok($zip->set_number('0861101')->is_valid_number, '北海道標津郡中標津町西1条南');
ok($zip->set_number('0861102')->is_valid_number, '北海道標津郡中標津町西2条南');
ok($zip->set_number('0861103')->is_valid_number, '北海道標津郡中標津町西3条南');
ok($zip->set_number('0861104')->is_valid_number, '北海道標津郡中標津町西4条南');
ok($zip->set_number('0861105')->is_valid_number, '北海道標津郡中標津町西5条南');
ok($zip->set_number('0861106')->is_valid_number, '北海道標津郡中標津町西6条南');
ok($zip->set_number('0861107')->is_valid_number, '北海道標津郡中標津町西7条南');
ok($zip->set_number('0861108')->is_valid_number, '北海道標津郡中標津町西8条南');
ok($zip->set_number('0861109')->is_valid_number, '北海道標津郡中標津町西9条南');
ok($zip->set_number('0861110')->is_valid_number, '北海道標津郡中標津町西10条南');
ok($zip->set_number('0861111')->is_valid_number, '北海道標津郡中標津町西11条南');
ok($zip->set_number('0861112')->is_valid_number, '北海道標津郡中標津町西12条南');
ok($zip->set_number('0861121')->is_valid_number, '北海道標津郡中標津町西1条北');
ok($zip->set_number('0861122')->is_valid_number, '北海道標津郡中標津町西2条北');
ok($zip->set_number('0861123')->is_valid_number, '北海道標津郡中標津町西3条北');
ok($zip->set_number('0861124')->is_valid_number, '北海道標津郡中標津町西4条北');
ok($zip->set_number('0861125')->is_valid_number, '北海道標津郡中標津町西5条北');
ok($zip->set_number('0861126')->is_valid_number, '北海道標津郡中標津町西6条北');
ok($zip->set_number('0861127')->is_valid_number, '北海道標津郡中標津町西7条北');
ok($zip->set_number('0861128')->is_valid_number, '北海道標津郡中標津町西8条北');
ok($zip->set_number('0861129')->is_valid_number, '北海道標津郡中標津町西9条北');
ok($zip->set_number('0861130')->is_valid_number, '北海道標津郡中標津町西10条北');
ok($zip->set_number('0861131')->is_valid_number, '北海道標津郡中標津町西11条北');
ok($zip->set_number('0861132')->is_valid_number, '北海道標津郡中標津町西12条北');
ok($zip->set_number('0861133')->is_valid_number, '北海道標津郡中標津町西13条北');
ok($zip->set_number('0861134')->is_valid_number, '北海道標津郡中標津町西14条北');
ok($zip->set_number('0861135')->is_valid_number, '北海道標津郡中標津町旭ケ丘');
ok($zip->set_number('0861136')->is_valid_number, '北海道標津郡中標津町協和');
ok($zip->set_number('0861137')->is_valid_number, '北海道標津郡中標津町俵橋');
ok($zip->set_number('0861139')->is_valid_number, '北海道標津郡中標津町豊岡');
ok($zip->set_number('0861141')->is_valid_number, '北海道標津郡中標津町大通北');
ok($zip->set_number('0861142')->is_valid_number, '北海道標津郡中標津町大通南');
ok($zip->set_number('0861143')->is_valid_number, '北海道標津郡中標津町当幌本通');
ok($zip->set_number('0861144')->is_valid_number, '北海道標津郡中標津町東当幌');
ok($zip->set_number('0861145')->is_valid_number, '北海道標津郡中標津町北中');
ok($zip->set_number('0861146')->is_valid_number, '北海道標津郡中標津町南町');
ok($zip->set_number('0861147')->is_valid_number, '北海道標津郡中標津町共立');
ok($zip->set_number('0861148')->is_valid_number, '北海道標津郡中標津町緑ケ丘');
ok($zip->set_number('0861150')->is_valid_number, '北海道標津郡中標津町南中');
ok($zip->set_number('0861151')->is_valid_number, '北海道標津郡中標津町川西');
ok($zip->set_number('0861152')->is_valid_number, '北海道標津郡中標津町北町');
ok($zip->set_number('0861153')->is_valid_number, '北海道標津郡中標津町桜ケ丘');
ok($zip->set_number('0861156')->is_valid_number, '北海道標津郡中標津町並美ケ丘');
ok($zip->set_number('0861157')->is_valid_number, '北海道標津郡中標津町西町');
ok($zip->set_number('0861159')->is_valid_number, '北海道標津郡中標津町青葉台');
ok($zip->set_number('0861160')->is_valid_number, '北海道標津郡中標津町りんどう町');
ok($zip->set_number('0861163')->is_valid_number, '北海道標津郡中標津町俵中');
ok($zip->set_number('0861164')->is_valid_number, '北海道標津郡中標津町丸山');
ok($zip->set_number('0861165')->is_valid_number, '北海道標津郡中標津町緑町北');
ok($zip->set_number('0861166')->is_valid_number, '北海道標津郡中標津町緑町南');
ok($zip->set_number('0861271')->is_valid_number, '北海道標津郡中標津町武佐');
ok($zip->set_number('0861272')->is_valid_number, '北海道標津郡中標津町開陽');
ok($zip->set_number('0861273')->is_valid_number, '北海道標津郡中標津町俣落(その他)');
ok($zip->set_number('0861451')->is_valid_number, '北海道標津郡標津町川北');
ok($zip->set_number('0861600')->is_valid_number, '北海道標津郡標津町以下に掲載がない場合');
ok($zip->set_number('0861601')->is_valid_number, '北海道標津郡標津町忠類');
ok($zip->set_number('0861602')->is_valid_number, '北海道標津郡標津町伊茶仁');
ok($zip->set_number('0861621')->is_valid_number, '北海道標津郡標津町茶志骨(パイロット)');
ok($zip->set_number('0861622')->is_valid_number, '北海道標津郡標津町茶志骨');
ok($zip->set_number('0861623')->is_valid_number, '北海道標津郡標津町茶志骨(東茶志骨)');
ok($zip->set_number('0861625')->is_valid_number, '北海道標津郡標津町茶志骨(住吉町)');
ok($zip->set_number('0861626')->is_valid_number, '北海道標津郡標津町茶志骨(東浜町)');
ok($zip->set_number('0861630')->is_valid_number, '北海道標津郡標津町北十条');
ok($zip->set_number('0861631')->is_valid_number, '北海道標津郡標津町北一条');
ok($zip->set_number('0861632')->is_valid_number, '北海道標津郡標津町北二条');
ok($zip->set_number('0861633')->is_valid_number, '北海道標津郡標津町北三条');
ok($zip->set_number('0861634')->is_valid_number, '北海道標津郡標津町北四条');
ok($zip->set_number('0861635')->is_valid_number, '北海道標津郡標津町北五条');
ok($zip->set_number('0861636')->is_valid_number, '北海道標津郡標津町北六条');
ok($zip->set_number('0861637')->is_valid_number, '北海道標津郡標津町北七条');
ok($zip->set_number('0861638')->is_valid_number, '北海道標津郡標津町北八条');
ok($zip->set_number('0861639')->is_valid_number, '北海道標津郡標津町北九条');
ok($zip->set_number('0861641')->is_valid_number, '北海道野付郡別海町尾岱沼');
ok($zip->set_number('0861642')->is_valid_number, '北海道野付郡別海町尾岱沼岬町');
ok($zip->set_number('0861643')->is_valid_number, '北海道野付郡別海町尾岱沼港町');
ok($zip->set_number('0861644')->is_valid_number, '北海道野付郡別海町尾岱沼潮見町');
ok($zip->set_number('0861645')->is_valid_number, '北海道野付郡別海町野付');
ok($zip->set_number('0861651')->is_valid_number, '北海道標津郡標津町南一条');
ok($zip->set_number('0861652')->is_valid_number, '北海道標津郡標津町南二条');
ok($zip->set_number('0861653')->is_valid_number, '北海道標津郡標津町南三条');
ok($zip->set_number('0861654')->is_valid_number, '北海道標津郡標津町南四条');
ok($zip->set_number('0861655')->is_valid_number, '北海道標津郡標津町南五条');
ok($zip->set_number('0861656')->is_valid_number, '北海道標津郡標津町南六条');
ok($zip->set_number('0861657')->is_valid_number, '北海道標津郡標津町南七条');
ok($zip->set_number('0861658')->is_valid_number, '北海道標津郡標津町南八条');
ok($zip->set_number('0861731')->is_valid_number, '北海道標津郡標津町古多糠');
ok($zip->set_number('0861732')->is_valid_number, '北海道標津郡標津町薫別');
ok($zip->set_number('0861733')->is_valid_number, '北海道標津郡標津町崎無異');
ok($zip->set_number('0861751')->is_valid_number, '北海道目梨郡羅臼町峯浜町');
ok($zip->set_number('0861752')->is_valid_number, '北海道目梨郡羅臼町幌萌町(その他)');
ok($zip->set_number('0861800')->is_valid_number, '北海道目梨郡羅臼町以下に掲載がない場合');
ok($zip->set_number('0861801')->is_valid_number, '北海道目梨郡羅臼町知床岬');
ok($zip->set_number('0861802')->is_valid_number, '北海道目梨郡羅臼町滝ノ下');
ok($zip->set_number('0861803')->is_valid_number, '北海道目梨郡羅臼町船泊');
ok($zip->set_number('0861804')->is_valid_number, '北海道目梨郡羅臼町化石浜');
ok($zip->set_number('0861805')->is_valid_number, '北海道目梨郡羅臼町崩浜');
ok($zip->set_number('0861806')->is_valid_number, '北海道目梨郡羅臼町相泊');
ok($zip->set_number('0861811')->is_valid_number, '北海道目梨郡羅臼町瀬石');
ok($zip->set_number('0861812')->is_valid_number, '北海道目梨郡羅臼町昆布浜');
ok($zip->set_number('0861813')->is_valid_number, '北海道目梨郡羅臼町北浜');
ok($zip->set_number('0861814')->is_valid_number, '北海道目梨郡羅臼町岬町');
ok($zip->set_number('0861815')->is_valid_number, '北海道目梨郡羅臼町海岸町');
ok($zip->set_number('0861816')->is_valid_number, '北海道目梨郡羅臼町共栄町');
ok($zip->set_number('0861821')->is_valid_number, '北海道目梨郡羅臼町緑町');
ok($zip->set_number('0861822')->is_valid_number, '北海道目梨郡羅臼町湯ノ沢町');
ok($zip->set_number('0861823')->is_valid_number, '北海道目梨郡羅臼町栄町');
ok($zip->set_number('0861831')->is_valid_number, '北海道目梨郡羅臼町富士見町');
ok($zip->set_number('0861832')->is_valid_number, '北海道目梨郡羅臼町船見町');
ok($zip->set_number('0861833')->is_valid_number, '北海道目梨郡羅臼町本町');
ok($zip->set_number('0861834')->is_valid_number, '北海道目梨郡羅臼町礼文町');
ok($zip->set_number('0861835')->is_valid_number, '北海道目梨郡羅臼町松法町');
ok($zip->set_number('0861836')->is_valid_number, '北海道目梨郡羅臼町知昭町');
ok($zip->set_number('0861841')->is_valid_number, '北海道目梨郡羅臼町八木浜町');
ok($zip->set_number('0861842')->is_valid_number, '北海道目梨郡羅臼町麻布町');
ok($zip->set_number('0861843')->is_valid_number, '北海道目梨郡羅臼町春日町');
ok($zip->set_number('0861844')->is_valid_number, '北海道目梨郡羅臼町幌萌町(40-1、623番地)');
ok($zip->set_number('0870000')->is_valid_number, '北海道根室市以下に掲載がない場合');
ok($zip->set_number('0870001')->is_valid_number, '北海道根室市北浜町');
ok($zip->set_number('0870002')->is_valid_number, '北海道根室市牧の内');
ok($zip->set_number('0870003')->is_valid_number, '北海道根室市明治町');
ok($zip->set_number('0870004')->is_valid_number, '北海道根室市光洋町');
ok($zip->set_number('0870005')->is_valid_number, '北海道根室市宝町');
ok($zip->set_number('0870006')->is_valid_number, '北海道根室市曙町');
ok($zip->set_number('0870007')->is_valid_number, '北海道根室市月見町');
ok($zip->set_number('0870008')->is_valid_number, '北海道根室市有磯町');
ok($zip->set_number('0870009')->is_valid_number, '北海道根室市弥栄町');
ok($zip->set_number('0870010')->is_valid_number, '北海道根室市栄町');
ok($zip->set_number('0870011')->is_valid_number, '北海道根室市弁天町');
ok($zip->set_number('0870012')->is_valid_number, '北海道根室市駒場町');
ok($zip->set_number('0870014')->is_valid_number, '北海道根室市朝日町');
ok($zip->set_number('0870015')->is_valid_number, '北海道根室市花咲町');
ok($zip->set_number('0870016')->is_valid_number, '北海道根室市松ケ枝町');
ok($zip->set_number('0870017')->is_valid_number, '北海道根室市鳴海町');
ok($zip->set_number('0870018')->is_valid_number, '北海道根室市千島町');
ok($zip->set_number('0870019')->is_valid_number, '北海道根室市汐見町');
ok($zip->set_number('0870021')->is_valid_number, '北海道根室市幸町');
ok($zip->set_number('0870022')->is_valid_number, '北海道根室市昭和町');
ok($zip->set_number('0870023')->is_valid_number, '北海道根室市桂木');
ok($zip->set_number('0870024')->is_valid_number, '北海道根室市宝林町');
ok($zip->set_number('0870025')->is_valid_number, '北海道根室市西浜町');
ok($zip->set_number('0870026')->is_valid_number, '北海道根室市敷島町');
ok($zip->set_number('0870027')->is_valid_number, '北海道根室市光和町');
ok($zip->set_number('0870028')->is_valid_number, '北海道根室市大正町');
ok($zip->set_number('0870031')->is_valid_number, '北海道根室市月岡町');
ok($zip->set_number('0870032')->is_valid_number, '北海道根室市花咲港');
ok($zip->set_number('0870033')->is_valid_number, '北海道根室市西和田');
ok($zip->set_number('0870034')->is_valid_number, '北海道根室市東和田');
ok($zip->set_number('0870035')->is_valid_number, '北海道根室市温根沼');
ok($zip->set_number('0870036')->is_valid_number, '北海道根室市幌茂尻');
ok($zip->set_number('0870037')->is_valid_number, '北海道根室市穂香');
ok($zip->set_number('0870041')->is_valid_number, '北海道根室市常盤町');
ok($zip->set_number('0870042')->is_valid_number, '北海道根室市清隆町');
ok($zip->set_number('0870043')->is_valid_number, '北海道根室市北斗町');
ok($zip->set_number('0870044')->is_valid_number, '北海道根室市松本町');
ok($zip->set_number('0870045')->is_valid_number, '北海道根室市花園町');
ok($zip->set_number('0870046')->is_valid_number, '北海道根室市岬町');
ok($zip->set_number('0870047')->is_valid_number, '北海道根室市定基町');
ok($zip->set_number('0870048')->is_valid_number, '北海道根室市平内町');
ok($zip->set_number('0870049')->is_valid_number, '北海道根室市弥生町');
ok($zip->set_number('0870051')->is_valid_number, '北海道根室市緑町');
ok($zip->set_number('0870052')->is_valid_number, '北海道根室市梅ケ枝町');
ok($zip->set_number('0870053')->is_valid_number, '北海道根室市本町');
ok($zip->set_number('0870054')->is_valid_number, '北海道根室市海岸町');
ok($zip->set_number('0870055')->is_valid_number, '北海道根室市琴平町');
ok($zip->set_number('0870161')->is_valid_number, '北海道根室市友知');
ok($zip->set_number('0870162')->is_valid_number, '北海道根室市双沖');
ok($zip->set_number('0870163')->is_valid_number, '北海道根室市歯舞');
ok($zip->set_number('0870164')->is_valid_number, '北海道根室市珸瑤瑁');
ok($zip->set_number('0870165')->is_valid_number, '北海道根室市納沙布');
ok($zip->set_number('0870166')->is_valid_number, '北海道根室市温根元');
ok($zip->set_number('0870167')->is_valid_number, '北海道根室市豊里');
ok($zip->set_number('0880101')->is_valid_number, '北海道釧路市音別町馬主来');
ok($zip->set_number('0880102')->is_valid_number, '北海道釧路市音別町中音別(光和)');
ok($zip->set_number('0880103')->is_valid_number, '北海道釧路市音別町中音別(北栄)');
ok($zip->set_number('0880104')->is_valid_number, '北海道釧路市音別町音別原野基線(二俣)');
ok($zip->set_number('0880105')->is_valid_number, '北海道釧路市音別町ムリ');
ok($zip->set_number('0880106')->is_valid_number, '北海道釧路市音別町ヌプキベツ');
ok($zip->set_number('0880107')->is_valid_number, '北海道釧路市音別町チヤンベツ');
ok($zip->set_number('0880108')->is_valid_number, '北海道釧路市音別町音別原野基線(二俣川向)');
ok($zip->set_number('0880109')->is_valid_number, '北海道釧路市音別町音別原野東');
ok($zip->set_number('0880111')->is_valid_number, '北海道釧路市音別町パシクル湖畔');
ok($zip->set_number('0880112')->is_valid_number, '北海道釧路市音別町中音別(チノミ台)');
ok($zip->set_number('0880113')->is_valid_number, '北海道釧路市音別町風連');
ok($zip->set_number('0880114')->is_valid_number, '北海道釧路市音別町海光');
ok($zip->set_number('0880115')->is_valid_number, '北海道釧路市音別町本町');
ok($zip->set_number('0880116')->is_valid_number, '北海道釧路市音別町中園');
ok($zip->set_number('0880117')->is_valid_number, '北海道釧路市音別町朝日');
ok($zip->set_number('0880118')->is_valid_number, '北海道釧路市音別町中音別(その他)');
ok($zip->set_number('0880121')->is_valid_number, '北海道釧路市音別町若草');
ok($zip->set_number('0880122')->is_valid_number, '北海道釧路市音別町あけぼの');
ok($zip->set_number('0880123')->is_valid_number, '北海道釧路市音別町川東');
ok($zip->set_number('0880124')->is_valid_number, '北海道釧路市音別町緑町');
ok($zip->set_number('0880125')->is_valid_number, '北海道釧路市音別町共栄');
ok($zip->set_number('0880126')->is_valid_number, '北海道釧路市音別町音別原野西(川西)');
ok($zip->set_number('0880131')->is_valid_number, '北海道釧路市音別町ノトロ');
ok($zip->set_number('0880132')->is_valid_number, '北海道釧路市音別町尺別(岐線)');
ok($zip->set_number('0880133')->is_valid_number, '北海道釧路市音別町尺別');
ok($zip->set_number('0880134')->is_valid_number, '北海道釧路市音別町キナシ別');
ok($zip->set_number('0880135')->is_valid_number, '北海道釧路市音別町直別');
ok($zip->set_number('0880181')->is_valid_number, '北海道十勝郡浦幌町直別');
ok($zip->set_number('0880300')->is_valid_number, '北海道白糠郡白糠町以下に掲載がない場合');
ok($zip->set_number('0880301')->is_valid_number, '北海道白糠郡白糠町東一条南');
ok($zip->set_number('0880302')->is_valid_number, '北海道白糠郡白糠町東二条南');
ok($zip->set_number('0880303')->is_valid_number, '北海道白糠郡白糠町東三条南');
ok($zip->set_number('0880304')->is_valid_number, '北海道白糠郡白糠町岬');
ok($zip->set_number('0880305')->is_valid_number, '北海道白糠郡白糠町刺牛');
ok($zip->set_number('0880311')->is_valid_number, '北海道白糠郡白糠町西一条南');
ok($zip->set_number('0880312')->is_valid_number, '北海道白糠郡白糠町西二条南');
ok($zip->set_number('0880321')->is_valid_number, '北海道白糠郡白糠町西一条北');
ok($zip->set_number('0880322')->is_valid_number, '北海道白糠郡白糠町西二条北');
ok($zip->set_number('0880323')->is_valid_number, '北海道白糠郡白糠町西四条北');
ok($zip->set_number('0880324')->is_valid_number, '北海道白糠郡白糠町西五条北');
ok($zip->set_number('0880325')->is_valid_number, '北海道白糠郡白糠町西三条北');
ok($zip->set_number('0880326')->is_valid_number, '北海道白糠郡白糠町西六条北');
ok($zip->set_number('0880331')->is_valid_number, '北海道白糠郡白糠町東一条北');
ok($zip->set_number('0880332')->is_valid_number, '北海道白糠郡白糠町東二条北');
ok($zip->set_number('0880333')->is_valid_number, '北海道白糠郡白糠町東三条北');
ok($zip->set_number('0880341')->is_valid_number, '北海道白糠郡白糠町大苗');
ok($zip->set_number('0880341')->is_valid_number, '北海道白糠郡白糠町下茶路');
ok($zip->set_number('0880341')->is_valid_number, '北海道白糠郡白糠町相互');
ok($zip->set_number('0880341')->is_valid_number, '北海道白糠郡白糠町西茶路');
ok($zip->set_number('0880341')->is_valid_number, '北海道白糠郡白糠町東茶路');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町御札部');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町御仁田');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町川西');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町高台');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町鍛高');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町茶路(共栄)');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町中茶路');
ok($zip->set_number('0880342')->is_valid_number, '北海道白糠郡白糠町松川');
ok($zip->set_number('0880343')->is_valid_number, '北海道白糠郡白糠町上茶路');
ok($zip->set_number('0880343')->is_valid_number, '北海道白糠郡白糠町新縫別');
ok($zip->set_number('0880343')->is_valid_number, '北海道白糠郡白糠町縫別');
ok($zip->set_number('0880343')->is_valid_number, '北海道白糠郡白糠町南大曲');
ok($zip->set_number('0880343')->is_valid_number, '北海道白糠郡白糠町南上茶路');
ok($zip->set_number('0880344')->is_valid_number, '北海道白糠郡白糠町左股');
ok($zip->set_number('0880344')->is_valid_number, '北海道白糠郡白糠町二股');
ok($zip->set_number('0880344')->is_valid_number, '北海道白糠郡白糠町右股');
ok($zip->set_number('0880351')->is_valid_number, '北海道白糠郡白糠町橋西');
ok($zip->set_number('0880351')->is_valid_number, '北海道白糠郡白糠町坂の丘');
ok($zip->set_number('0880351')->is_valid_number, '北海道白糠郡白糠町下和天別');
ok($zip->set_number('0880351')->is_valid_number, '北海道白糠郡白糠町和天別');
ok($zip->set_number('0880352')->is_valid_number, '北海道白糠郡白糠町川島');
ok($zip->set_number('0880352')->is_valid_number, '北海道白糠郡白糠町大秋');
ok($zip->set_number('0880352')->is_valid_number, '北海道白糠郡白糠町馬主来');
ok($zip->set_number('0880352')->is_valid_number, '北海道白糠郡白糠町緑');
ok($zip->set_number('0880353')->is_valid_number, '北海道白糠郡白糠町大沢');
ok($zip->set_number('0880353')->is_valid_number, '北海道白糠郡白糠町大平');
ok($zip->set_number('0880353')->is_valid_number, '北海道白糠郡白糠町河原');
ok($zip->set_number('0880353')->is_valid_number, '北海道白糠郡白糠町恋隠');
ok($zip->set_number('0880353')->is_valid_number, '北海道白糠郡白糠町中和天別');
ok($zip->set_number('0880353')->is_valid_number, '北海道白糠郡白糠町本郷');
ok($zip->set_number('0880560')->is_valid_number, '北海道白糠郡白糠町庶路宮下');
ok($zip->set_number('0880561')->is_valid_number, '北海道白糠郡白糠町大楽毛');
ok($zip->set_number('0880562')->is_valid_number, '北海道白糠郡白糠町コイトイ');
ok($zip->set_number('0880562')->is_valid_number, '北海道白糠郡白糠町恋問');
ok($zip->set_number('0880563')->is_valid_number, '北海道白糠郡白糠町庶路甲区');
ok($zip->set_number('0880564')->is_valid_number, '北海道白糠郡白糠町庶路(1区)');
ok($zip->set_number('0880565')->is_valid_number, '北海道白糠郡白糠町庶路(2区)');
ok($zip->set_number('0880566')->is_valid_number, '北海道白糠郡白糠町庶路(宮下)');
ok($zip->set_number('0880567')->is_valid_number, '北海道白糠郡白糠町庶路');
ok($zip->set_number('0880568')->is_valid_number, '北海道白糠郡白糠町庶路乙区');
ok($zip->set_number('0880569')->is_valid_number, '北海道白糠郡白糠町工業団地');
ok($zip->set_number('0880571')->is_valid_number, '北海道白糠郡白糠町西庶路西一条北');
ok($zip->set_number('0880571')->is_valid_number, '北海道白糠郡白糠町西庶路西二条北');
ok($zip->set_number('0880571')->is_valid_number, '北海道白糠郡白糠町西庶路西三条北');
ok($zip->set_number('0880572')->is_valid_number, '北海道白糠郡白糠町西庶路西一条南');
ok($zip->set_number('0880572')->is_valid_number, '北海道白糠郡白糠町西庶路西二条南');
ok($zip->set_number('0880572')->is_valid_number, '北海道白糠郡白糠町西庶路西三条南');
ok($zip->set_number('0880572')->is_valid_number, '北海道白糠郡白糠町西庶路西四条南');
ok($zip->set_number('0880572')->is_valid_number, '北海道白糠郡白糠町西庶路西五条南');
ok($zip->set_number('0880573')->is_valid_number, '北海道白糠郡白糠町西庶路東一条北');
ok($zip->set_number('0880573')->is_valid_number, '北海道白糠郡白糠町西庶路東二条北');
ok($zip->set_number('0880573')->is_valid_number, '北海道白糠郡白糠町西庶路東三条北');
ok($zip->set_number('0880574')->is_valid_number, '北海道白糠郡白糠町西庶路東一条南');
ok($zip->set_number('0880574')->is_valid_number, '北海道白糠郡白糠町西庶路東二条南');
ok($zip->set_number('0880574')->is_valid_number, '北海道白糠郡白糠町西庶路東三条南');
ok($zip->set_number('0880575')->is_valid_number, '北海道白糠郡白糠町西庶路学園通');
ok($zip->set_number('0880581')->is_valid_number, '北海道白糠郡白糠町乳呑');
ok($zip->set_number('0880582')->is_valid_number, '北海道白糠郡白糠町中庶路');
ok($zip->set_number('0880583')->is_valid_number, '北海道白糠郡白糠町上庶路');
ok($zip->set_number('0880584')->is_valid_number, '北海道白糠郡白糠町泊別');
ok($zip->set_number('0880585')->is_valid_number, '北海道白糠郡白糠町暁');
ok($zip->set_number('0880586')->is_valid_number, '北海道白糠郡白糠町庶路東');
ok($zip->set_number('0880587')->is_valid_number, '北海道白糠郡白糠町庶路西');
ok($zip->set_number('0880600')->is_valid_number, '北海道釧路郡釧路町以下に掲載がない場合');
ok($zip->set_number('0880601')->is_valid_number, '北海道釧路郡釧路町上別保原野');
ok($zip->set_number('0880602')->is_valid_number, '北海道釧路郡釧路町別保東');
ok($zip->set_number('0880603')->is_valid_number, '北海道釧路郡釧路町別保南');
ok($zip->set_number('0880604')->is_valid_number, '北海道釧路郡釧路町別保');
ok($zip->set_number('0880605')->is_valid_number, '北海道釧路郡釧路町別保原野');
ok($zip->set_number('0880606')->is_valid_number, '北海道釧路郡釧路町中央');
ok($zip->set_number('0880607')->is_valid_number, '北海道釧路郡釧路町床丹');
ok($zip->set_number('0880608')->is_valid_number, '北海道釧路郡釧路町釧望台');
ok($zip->set_number('0880609')->is_valid_number, '北海道釧路郡釧路町共和');
ok($zip->set_number('0880611')->is_valid_number, '北海道釧路郡釧路町豊美');
ok($zip->set_number('0880612')->is_valid_number, '北海道釧路郡釧路町雁来');
ok($zip->set_number('0880613')->is_valid_number, '北海道釧路郡釧路町若葉');
ok($zip->set_number('0880614')->is_valid_number, '北海道釧路郡釧路町国誉');
ok($zip->set_number('0880615')->is_valid_number, '北海道釧路郡釧路町睦');
ok($zip->set_number('0880616')->is_valid_number, '北海道釧路郡釧路町曙');
ok($zip->set_number('0880617')->is_valid_number, '北海道釧路郡釧路町北都');
ok($zip->set_number('0880618')->is_valid_number, '北海道釧路郡釧路町富原');
ok($zip->set_number('0880621')->is_valid_number, '北海道釧路郡釧路町桂木');
ok($zip->set_number('0880622')->is_valid_number, '北海道釧路郡釧路町木場');
ok($zip->set_number('0880623')->is_valid_number, '北海道釧路郡釧路町光和');
ok($zip->set_number('0880624')->is_valid_number, '北海道釧路郡釧路町新開');
ok($zip->set_number('0880625')->is_valid_number, '北海道釧路郡釧路町北見団地');
ok($zip->set_number('0880626')->is_valid_number, '北海道釧路郡釧路町桂');
ok($zip->set_number('0880627')->is_valid_number, '北海道釧路郡釧路町東陽西');
ok($zip->set_number('0880628')->is_valid_number, '北海道釧路郡釧路町東陽大通西');
ok($zip->set_number('0880771')->is_valid_number, '北海道厚岸郡厚岸町上尾幌');
ok($zip->set_number('0880831')->is_valid_number, '北海道釧路郡釧路町仙鳳趾村(仙鳳趾)');
ok($zip->set_number('0880832')->is_valid_number, '北海道釧路郡釧路町仙鳳趾村(知方学)');
ok($zip->set_number('0880833')->is_valid_number, '北海道釧路郡釧路町仙鳳趾村(老者舞)');
ok($zip->set_number('0880834')->is_valid_number, '北海道釧路郡釧路町仙鳳趾村(汐見)');
ok($zip->set_number('0880835')->is_valid_number, '北海道釧路郡釧路町仙鳳趾村(オタクパウシ)');
ok($zip->set_number('0880871')->is_valid_number, '北海道厚岸郡厚岸町尾幌');
ok($zip->set_number('0880872')->is_valid_number, '北海道厚岸郡厚岸町来別');
ok($zip->set_number('0880873')->is_valid_number, '北海道厚岸郡厚岸町乙幌');
ok($zip->set_number('0880874')->is_valid_number, '北海道厚岸郡厚岸町門静(4丁目55~114番地)');
ok($zip->set_number('0880875')->is_valid_number, '北海道厚岸郡厚岸町苫多');
ok($zip->set_number('0880876')->is_valid_number, '北海道厚岸郡厚岸町沖万別');
ok($zip->set_number('0880877')->is_valid_number, '北海道厚岸郡厚岸町敏内');
ok($zip->set_number('0880878')->is_valid_number, '北海道厚岸郡厚岸町ルークシュポール');
ok($zip->set_number('0881100')->is_valid_number, '北海道厚岸郡厚岸町以下に掲載がない場合');
ok($zip->set_number('0881101')->is_valid_number, '北海道厚岸郡厚岸町糸魚沢');
ok($zip->set_number('0881101')->is_valid_number, '北海道厚岸郡厚岸町神岩');
ok($zip->set_number('0881101')->is_valid_number, '北海道厚岸郡厚岸町チライカリベツ');
ok($zip->set_number('0881101')->is_valid_number, '北海道厚岸郡厚岸町別寒辺牛');
ok($zip->set_number('0881101')->is_valid_number, '北海道厚岸郡厚岸町ホロニタイ');
ok($zip->set_number('0881101')->is_valid_number, '北海道厚岸郡厚岸町若松');
ok($zip->set_number('0881102')->is_valid_number, '北海道厚岸郡厚岸町登喜岱');
ok($zip->set_number('0881103')->is_valid_number, '北海道厚岸郡厚岸町小島');
ok($zip->set_number('0881104')->is_valid_number, '北海道厚岸郡厚岸町大黒島');
ok($zip->set_number('0881105')->is_valid_number, '北海道厚岸郡厚岸町末広');
ok($zip->set_number('0881106')->is_valid_number, '北海道厚岸郡厚岸町東梅');
ok($zip->set_number('0881107')->is_valid_number, '北海道厚岸郡厚岸町床潭');
ok($zip->set_number('0881108')->is_valid_number, '北海道厚岸郡厚岸町筑紫恋');
ok($zip->set_number('0881111')->is_valid_number, '北海道厚岸郡厚岸町奔渡');
ok($zip->set_number('0881112')->is_valid_number, '北海道厚岸郡厚岸町有明');
ok($zip->set_number('0881113')->is_valid_number, '北海道厚岸郡厚岸町愛冠');
ok($zip->set_number('0881114')->is_valid_number, '北海道厚岸郡厚岸町湾月');
ok($zip->set_number('0881115')->is_valid_number, '北海道厚岸郡厚岸町梅香');
ok($zip->set_number('0881116')->is_valid_number, '北海道厚岸郡厚岸町松葉');
ok($zip->set_number('0881117')->is_valid_number, '北海道厚岸郡厚岸町御供');
ok($zip->set_number('0881118')->is_valid_number, '北海道厚岸郡厚岸町若竹');
ok($zip->set_number('0881118')->is_valid_number, '北海道厚岸郡厚岸町若竹町');
ok($zip->set_number('0881119')->is_valid_number, '北海道厚岸郡厚岸町住の江');
ok($zip->set_number('0881120')->is_valid_number, '北海道厚岸郡厚岸町山の手');
ok($zip->set_number('0881124')->is_valid_number, '北海道厚岸郡厚岸町宮園');
ok($zip->set_number('0881125')->is_valid_number, '北海道厚岸郡厚岸町白浜');
ok($zip->set_number('0881126')->is_valid_number, '北海道厚岸郡厚岸町門静(その他)');
ok($zip->set_number('0881128')->is_valid_number, '北海道厚岸郡厚岸町港町');
ok($zip->set_number('0881129')->is_valid_number, '北海道厚岸郡厚岸町光栄');
ok($zip->set_number('0881130')->is_valid_number, '北海道厚岸郡厚岸町太田南');
ok($zip->set_number('0881131')->is_valid_number, '北海道厚岸郡厚岸町太田');
ok($zip->set_number('0881132')->is_valid_number, '北海道厚岸郡厚岸町太田東');
ok($zip->set_number('0881133')->is_valid_number, '北海道厚岸郡厚岸町太田宏陽');
ok($zip->set_number('0881134')->is_valid_number, '北海道厚岸郡厚岸町太田西');
ok($zip->set_number('0881135')->is_valid_number, '北海道厚岸郡厚岸町太田北');
ok($zip->set_number('0881136')->is_valid_number, '北海道厚岸郡厚岸町大別');
ok($zip->set_number('0881137')->is_valid_number, '北海道厚岸郡厚岸町片無去');
ok($zip->set_number('0881138')->is_valid_number, '北海道厚岸郡厚岸町セタニウシ');
ok($zip->set_number('0881139')->is_valid_number, '北海道厚岸郡厚岸町サッテベツ');
ok($zip->set_number('0881140')->is_valid_number, '北海道厚岸郡厚岸町サンヌシ');
ok($zip->set_number('0881141')->is_valid_number, '北海道厚岸郡厚岸町太田1の通り');
ok($zip->set_number('0881142')->is_valid_number, '北海道厚岸郡厚岸町太田2の通り');
ok($zip->set_number('0881143')->is_valid_number, '北海道厚岸郡厚岸町太田3の通り');
ok($zip->set_number('0881144')->is_valid_number, '北海道厚岸郡厚岸町太田4の通り');
ok($zip->set_number('0881145')->is_valid_number, '北海道厚岸郡厚岸町太田5の通り');
ok($zip->set_number('0881146')->is_valid_number, '北海道厚岸郡厚岸町太田6の通り');
ok($zip->set_number('0881147')->is_valid_number, '北海道厚岸郡厚岸町太田7の通り');
ok($zip->set_number('0881148')->is_valid_number, '北海道厚岸郡厚岸町太田8の通り');
ok($zip->set_number('0881149')->is_valid_number, '北海道厚岸郡厚岸町太田9の通り');
ok($zip->set_number('0881151')->is_valid_number, '北海道厚岸郡厚岸町真栄');
ok($zip->set_number('0881301')->is_valid_number, '北海道厚岸郡浜中町一番沢');
ok($zip->set_number('0881302')->is_valid_number, '北海道厚岸郡浜中町二番沢');
ok($zip->set_number('0881303')->is_valid_number, '北海道厚岸郡浜中町三番沢');
ok($zip->set_number('0881304')->is_valid_number, '北海道厚岸郡浜中町四番沢');
ok($zip->set_number('0881306')->is_valid_number, '北海道厚岸郡浜中町六番沢');
ok($zip->set_number('0881360')->is_valid_number, '北海道厚岸郡浜中町散布村(北の沢)');
ok($zip->set_number('0881361')->is_valid_number, '北海道厚岸郡浜中町茶内緑');
ok($zip->set_number('0881362')->is_valid_number, '北海道厚岸郡浜中町茶内本町');
ok($zip->set_number('0881363')->is_valid_number, '北海道厚岸郡浜中町茶内栄');
ok($zip->set_number('0881364')->is_valid_number, '北海道厚岸郡浜中町茶内若葉');
ok($zip->set_number('0881365')->is_valid_number, '北海道厚岸郡浜中町茶内橋北東');
ok($zip->set_number('0881366')->is_valid_number, '北海道厚岸郡浜中町茶内橋北西');
ok($zip->set_number('0881367')->is_valid_number, '北海道厚岸郡浜中町茶内旭');
ok($zip->set_number('0881368')->is_valid_number, '北海道厚岸郡浜中町茶内基線');
ok($zip->set_number('0881368')->is_valid_number, '北海道厚岸郡浜中町茶内東1線');
ok($zip->set_number('0881368')->is_valid_number, '北海道厚岸郡浜中町茶内東2線');
ok($zip->set_number('0881369')->is_valid_number, '北海道厚岸郡浜中町茶内西');
ok($zip->set_number('0881370')->is_valid_number, '北海道厚岸郡浜中町西円朱別西');
ok($zip->set_number('0881371')->is_valid_number, '北海道厚岸郡浜中町円朱別西');
ok($zip->set_number('0881389')->is_valid_number, '北海道厚岸郡厚岸町トライベツ');
ok($zip->set_number('0881401')->is_valid_number, '北海道厚岸郡浜中町榊町');
ok($zip->set_number('0881402')->is_valid_number, '北海道厚岸郡浜中町後静');
ok($zip->set_number('0881402')->is_valid_number, '北海道厚岸郡浜中町横浜');
ok($zip->set_number('0881403')->is_valid_number, '北海道厚岸郡浜中町アザラップ');
ok($zip->set_number('0881403')->is_valid_number, '北海道厚岸郡浜中町幌戸');
ok($zip->set_number('0881404')->is_valid_number, '北海道厚岸郡浜中町ムギカラシナイ');
ok($zip->set_number('0881405')->is_valid_number, '北海道厚岸郡浜中町奔幌戸');
ok($zip->set_number('0881406')->is_valid_number, '北海道厚岸郡浜中町赤泊');
ok($zip->set_number('0881406')->is_valid_number, '北海道厚岸郡浜中町羨古丹');
ok($zip->set_number('0881407')->is_valid_number, '北海道厚岸郡浜中町榊町西');
ok($zip->set_number('0881408')->is_valid_number, '北海道厚岸郡浜中町大津屋沢');
ok($zip->set_number('0881409')->is_valid_number, '北海道厚岸郡浜中町走古潭');
ok($zip->set_number('0881412')->is_valid_number, '北海道厚岸郡浜中町後静村(熊牛原野)');
ok($zip->set_number('0881485')->is_valid_number, '北海道厚岸郡浜中町浜中');
ok($zip->set_number('0881486')->is_valid_number, '北海道厚岸郡浜中町熊牛');
ok($zip->set_number('0881487')->is_valid_number, '北海道厚岸郡浜中町茶内東3線');
ok($zip->set_number('0881487')->is_valid_number, '北海道厚岸郡浜中町茶内東4線');
ok($zip->set_number('0881487')->is_valid_number, '北海道厚岸郡浜中町茶内東5線');
ok($zip->set_number('0881487')->is_valid_number, '北海道厚岸郡浜中町茶内東6線');
ok($zip->set_number('0881500')->is_valid_number, '北海道厚岸郡浜中町以下に掲載がない場合');
ok($zip->set_number('0881511')->is_valid_number, '北海道厚岸郡浜中町霧多布東一条');
ok($zip->set_number('0881512')->is_valid_number, '北海道厚岸郡浜中町霧多布東二条');
ok($zip->set_number('0881513')->is_valid_number, '北海道厚岸郡浜中町霧多布東三条');
ok($zip->set_number('0881514')->is_valid_number, '北海道厚岸郡浜中町霧多布東四条');
ok($zip->set_number('0881522')->is_valid_number, '北海道厚岸郡浜中町湯沸');
ok($zip->set_number('0881524')->is_valid_number, '北海道厚岸郡浜中町暮帰別東');
ok($zip->set_number('0881525')->is_valid_number, '北海道厚岸郡浜中町暮帰別西');
ok($zip->set_number('0881526')->is_valid_number, '北海道厚岸郡浜中町新川');
ok($zip->set_number('0881527')->is_valid_number, '北海道厚岸郡浜中町新川東');
ok($zip->set_number('0881528')->is_valid_number, '北海道厚岸郡浜中町新川西');
ok($zip->set_number('0881531')->is_valid_number, '北海道厚岸郡浜中町仲の浜');
ok($zip->set_number('0881532')->is_valid_number, '北海道厚岸郡浜中町琵琶瀬');
ok($zip->set_number('0881534')->is_valid_number, '北海道厚岸郡浜中町渡散布');
ok($zip->set_number('0881535')->is_valid_number, '北海道厚岸郡浜中町養老散布');
ok($zip->set_number('0881536')->is_valid_number, '北海道厚岸郡浜中町火散布');
ok($zip->set_number('0881537')->is_valid_number, '北海道厚岸郡浜中町丸山散布');
ok($zip->set_number('0881538')->is_valid_number, '北海道厚岸郡浜中町藻散布');
ok($zip->set_number('0881551')->is_valid_number, '北海道厚岸郡浜中町霧多布西一条');
ok($zip->set_number('0881552')->is_valid_number, '北海道厚岸郡浜中町霧多布西二条');
ok($zip->set_number('0881553')->is_valid_number, '北海道厚岸郡浜中町霧多布西三条');
ok($zip->set_number('0881554')->is_valid_number, '北海道厚岸郡浜中町霧多布西四条');
ok($zip->set_number('0881561')->is_valid_number, '北海道厚岸郡浜中町霧多布湿原');
ok($zip->set_number('0881571')->is_valid_number, '北海道厚岸郡浜中町道有林');
ok($zip->set_number('0881641')->is_valid_number, '北海道厚岸郡浜中町姉別基線');
ok($zip->set_number('0881643')->is_valid_number, '北海道厚岸郡浜中町貰人');
ok($zip->set_number('0881644')->is_valid_number, '北海道厚岸郡浜中町恵茶人');
ok($zip->set_number('0881645')->is_valid_number, '北海道厚岸郡浜中町仙鳳趾');
ok($zip->set_number('0881646')->is_valid_number, '北海道厚岸郡浜中町姉別(丁目)');
ok($zip->set_number('0881647')->is_valid_number, '北海道厚岸郡浜中町姉別南');
ok($zip->set_number('0881648')->is_valid_number, '北海道厚岸郡浜中町姉別北');
ok($zip->set_number('0881649')->is_valid_number, '北海道厚岸郡浜中町姉別緑栄');
ok($zip->set_number('0881781')->is_valid_number, '北海道根室市落石西');
ok($zip->set_number('0881782')->is_valid_number, '北海道根室市落石東');
ok($zip->set_number('0881783')->is_valid_number, '北海道根室市浜松');
ok($zip->set_number('0881784')->is_valid_number, '北海道根室市昆布盛');
ok($zip->set_number('0881785')->is_valid_number, '北海道根室市長節');
ok($zip->set_number('0882140')->is_valid_number, '北海道釧路郡釧路町細岡');
ok($zip->set_number('0882141')->is_valid_number, '北海道釧路郡釧路町達古武');
ok($zip->set_number('0882142')->is_valid_number, '北海道釧路郡釧路町遠野');
ok($zip->set_number('0882143')->is_valid_number, '北海道釧路郡釧路町河畔');
ok($zip->set_number('0882144')->is_valid_number, '北海道釧路郡釧路町鳥里');
ok($zip->set_number('0882145')->is_valid_number, '北海道釧路郡釧路町遠矢');
ok($zip->set_number('0882146')->is_valid_number, '北海道釧路郡釧路町鳥通西');
ok($zip->set_number('0882147')->is_valid_number, '北海道釧路郡釧路町鳥通東');
ok($zip->set_number('0882148')->is_valid_number, '北海道釧路郡釧路町鳥通');
ok($zip->set_number('0882151')->is_valid_number, '北海道釧路郡釧路町よし野');
ok($zip->set_number('0882152')->is_valid_number, '北海道釧路郡釧路町南陽台');
ok($zip->set_number('0882153')->is_valid_number, '北海道釧路郡釧路町緑');
ok($zip->set_number('0882154')->is_valid_number, '北海道釧路郡釧路町柏東');
ok($zip->set_number('0882155')->is_valid_number, '北海道釧路郡釧路町柏西');
ok($zip->set_number('0882156')->is_valid_number, '北海道釧路郡釧路町遠矢南');
ok($zip->set_number('0882157')->is_valid_number, '北海道釧路郡釧路町わらび');
ok($zip->set_number('0882261')->is_valid_number, '北海道川上郡標茶町塘路(その他)');
ok($zip->set_number('0882262')->is_valid_number, '北海道川上郡標茶町ウライヤ');
ok($zip->set_number('0882263')->is_valid_number, '北海道川上郡標茶町沼ノ上');
ok($zip->set_number('0882264')->is_valid_number, '北海道川上郡標茶町塘路原野');
ok($zip->set_number('0882265')->is_valid_number, '北海道川上郡標茶町シラルトロ');
ok($zip->set_number('0882265')->is_valid_number, '北海道川上郡標茶町塘路(32番地)');
ok($zip->set_number('0882266')->is_valid_number, '北海道川上郡標茶町茅沼');
ok($zip->set_number('0882266')->is_valid_number, '北海道川上郡標茶町コツタロ原野');
ok($zip->set_number('0882271')->is_valid_number, '北海道川上郡標茶町阿歴内');
ok($zip->set_number('0882272')->is_valid_number, '北海道川上郡標茶町阿歴内原野');
ok($zip->set_number('0882273')->is_valid_number, '北海道川上郡標茶町西和');
ok($zip->set_number('0882274')->is_valid_number, '北海道川上郡標茶町東阿歴内');
ok($zip->set_number('0882275')->is_valid_number, '北海道川上郡標茶町北片無去');
ok($zip->set_number('0882300')->is_valid_number, '北海道川上郡標茶町以下に掲載がない場合');
ok($zip->set_number('0882301')->is_valid_number, '北海道川上郡標茶町旭');
ok($zip->set_number('0882302')->is_valid_number, '北海道川上郡標茶町富士');
ok($zip->set_number('0882303')->is_valid_number, '北海道川上郡標茶町桜');
ok($zip->set_number('0882304')->is_valid_number, '北海道川上郡標茶町平和');
ok($zip->set_number('0882305')->is_valid_number, '北海道川上郡標茶町麻生');
ok($zip->set_number('0882311')->is_valid_number, '北海道川上郡標茶町開運');
ok($zip->set_number('0882312')->is_valid_number, '北海道川上郡標茶町川上');
ok($zip->set_number('0882313')->is_valid_number, '北海道川上郡標茶町常盤');
ok($zip->set_number('0882314')->is_valid_number, '北海道川上郡標茶町標茶');
ok($zip->set_number('0882321')->is_valid_number, '北海道川上郡標茶町上チャンベツ');
ok($zip->set_number('0882322')->is_valid_number, '北海道川上郡標茶町中チャンベツ');
ok($zip->set_number('0882323')->is_valid_number, '北海道川上郡標茶町下チャンベツ');
ok($zip->set_number('0882324')->is_valid_number, '北海道川上郡標茶町雷別');
ok($zip->set_number('0882331')->is_valid_number, '北海道川上郡標茶町オソツベツ');
ok($zip->set_number('0882331')->is_valid_number, '北海道川上郡標茶町下オソツベツ');
ok($zip->set_number('0882332')->is_valid_number, '北海道川上郡標茶町中オソツベツ');
ok($zip->set_number('0882333')->is_valid_number, '北海道川上郡標茶町上オソツベツ');
ok($zip->set_number('0882334')->is_valid_number, '北海道川上郡標茶町厚生');
ok($zip->set_number('0882335')->is_valid_number, '北海道川上郡標茶町五十石');
ok($zip->set_number('0882336')->is_valid_number, '北海道川上郡標茶町ルルラン');
ok($zip->set_number('0882337')->is_valid_number, '北海道川上郡標茶町北標茶');
ok($zip->set_number('0882337')->is_valid_number, '北海道川上郡標茶町栄(その他)');
ok($zip->set_number('0882338')->is_valid_number, '北海道川上郡標茶町南標茶');
ok($zip->set_number('0882339')->is_valid_number, '北海道川上郡標茶町上多和');
ok($zip->set_number('0882339')->is_valid_number, '北海道川上郡標茶町多和(その他)');
ok($zip->set_number('0882380')->is_valid_number, '北海道川上郡標茶町クチョロ原野');
ok($zip->set_number('0882381')->is_valid_number, '北海道川上郡標茶町中久著呂市街');
ok($zip->set_number('0882382')->is_valid_number, '北海道川上郡標茶町中久著呂');
ok($zip->set_number('0882388')->is_valid_number, '北海道川上郡標茶町コッタロ');
ok($zip->set_number('0882389')->is_valid_number, '北海道川上郡標茶町ヌマオロ原野');
ok($zip->set_number('0882461')->is_valid_number, '北海道川上郡標茶町虹別市街');
ok($zip->set_number('0882462')->is_valid_number, '北海道川上郡標茶町虹別');
ok($zip->set_number('0882463')->is_valid_number, '北海道川上郡標茶町虹別(上虹)');
ok($zip->set_number('0882464')->is_valid_number, '北海道川上郡標茶町虹別(中虹)');
ok($zip->set_number('0882465')->is_valid_number, '北海道川上郡標茶町虹別(萩野)');
ok($zip->set_number('0882561')->is_valid_number, '北海道野付郡別海町西春別駅前柏町');
ok($zip->set_number('0882562')->is_valid_number, '北海道野付郡別海町西春別駅前栄町');
ok($zip->set_number('0882563')->is_valid_number, '北海道野付郡別海町西春別駅前錦町');
ok($zip->set_number('0882564')->is_valid_number, '北海道野付郡別海町西春別駅前西町');
ok($zip->set_number('0882565')->is_valid_number, '北海道野付郡別海町西春別駅前寿町');
ok($zip->set_number('0882566')->is_valid_number, '北海道野付郡別海町西春別駅前曙町');
ok($zip->set_number('0882571')->is_valid_number, '北海道野付郡別海町西春別幸町');
ok($zip->set_number('0882572')->is_valid_number, '北海道野付郡別海町西春別清川町');
ok($zip->set_number('0882573')->is_valid_number, '北海道野付郡別海町西春別本久町');
ok($zip->set_number('0882574')->is_valid_number, '北海道野付郡別海町西春別昭栄町');
ok($zip->set_number('0882575')->is_valid_number, '北海道野付郡別海町西春別宮園町');
ok($zip->set_number('0882576')->is_valid_number, '北海道野付郡別海町西春別');
ok($zip->set_number('0882577')->is_valid_number, '北海道野付郡別海町矢臼別(40の1番地、41の2番地)');
ok($zip->set_number('0882578')->is_valid_number, '北海道野付郡別海町泉川');
ok($zip->set_number('0882601')->is_valid_number, '北海道野付郡別海町大成');
ok($zip->set_number('0882602')->is_valid_number, '北海道野付郡別海町本別');
ok($zip->set_number('0882681')->is_valid_number, '北海道標津郡中標津町当幌');
ok($zip->set_number('0882682')->is_valid_number, '北海道標津郡中標津町計根別');
ok($zip->set_number('0882683')->is_valid_number, '北海道標津郡中標津町上標津');
ok($zip->set_number('0882684')->is_valid_number, '北海道標津郡中標津町養老牛');
ok($zip->set_number('0882685')->is_valid_number, '北海道標津郡中標津町西竹');
ok($zip->set_number('0882686')->is_valid_number, '北海道標津郡中標津町俣落(1629-1、1653-3、1684-5、1886-2、1893、');
ok($zip->set_number('0882686')->is_valid_number, '北海道標津郡中標津町1896-2、1896-3、1906-8、1932-2、1936、');
ok($zip->set_number('0882686')->is_valid_number, '北海道標津郡中標津町1936-2、1951-2、1956-2、1967-2、1980-2、');
ok($zip->set_number('0882686')->is_valid_number, '北海道標津郡中標津町1997-3、2000-2、2000-8、2003、2015-4、');
ok($zip->set_number('0882686')->is_valid_number, '北海道標津郡中標津町2023-2、2038-2、2253-2、2253-5、2253-21、');
ok($zip->set_number('0882686')->is_valid_number, '北海道標津郡中標津町2253-24、2253-35、2253-63)');
ok($zip->set_number('0882721')->is_valid_number, '北海道野付郡別海町上春別緑町');
ok($zip->set_number('0882722')->is_valid_number, '北海道野付郡別海町上春別旭町');
ok($zip->set_number('0882723')->is_valid_number, '北海道野付郡別海町上春別南町');
ok($zip->set_number('0882724')->is_valid_number, '北海道野付郡別海町上春別栄町');
ok($zip->set_number('0882725')->is_valid_number, '北海道野付郡別海町上春別');
ok($zip->set_number('0883141')->is_valid_number, '北海道川上郡標茶町多和(120番地)');
ok($zip->set_number('0883142')->is_valid_number, '北海道川上郡標茶町上磯分内');
ok($zip->set_number('0883143')->is_valid_number, '北海道川上郡標茶町磯分内美幌');
ok($zip->set_number('0883144')->is_valid_number, '北海道川上郡標茶町中多和');
ok($zip->set_number('0883145')->is_valid_number, '北海道川上郡標茶町熊牛原野');
ok($zip->set_number('0883146')->is_valid_number, '北海道川上郡標茶町磯分内下');
ok($zip->set_number('0883147')->is_valid_number, '北海道川上郡標茶町磯分内市街');
ok($zip->set_number('0883148')->is_valid_number, '北海道川上郡標茶町磯分内福島');
ok($zip->set_number('0883149')->is_valid_number, '北海道川上郡標茶町磯分内乙西');
ok($zip->set_number('0883151')->is_valid_number, '北海道川上郡標茶町磯分内上');
ok($zip->set_number('0883152')->is_valid_number, '北海道川上郡標茶町磯分内協盛');
ok($zip->set_number('0883153')->is_valid_number, '北海道川上郡標茶町磯分内小林');
ok($zip->set_number('0883154')->is_valid_number, '北海道川上郡標茶町栄(145、169番地)');
ok($zip->set_number('0883155')->is_valid_number, '北海道川上郡標茶町磯分内平泉');
ok($zip->set_number('0883156')->is_valid_number, '北海道川上郡標茶町磯分内平和');
ok($zip->set_number('0883157')->is_valid_number, '北海道川上郡標茶町磯分内憩');
ok($zip->set_number('0883200')->is_valid_number, '北海道川上郡弟子屈町以下に掲載がない場合');
ok($zip->set_number('0883201')->is_valid_number, '北海道川上郡弟子屈町摩周');
ok($zip->set_number('0883202')->is_valid_number, '北海道川上郡弟子屈町鈴蘭');
ok($zip->set_number('0883203')->is_valid_number, '北海道川上郡弟子屈町湯の島');
ok($zip->set_number('0883204')->is_valid_number, '北海道川上郡弟子屈町朝日');
ok($zip->set_number('0883211')->is_valid_number, '北海道川上郡弟子屈町中央');
ok($zip->set_number('0883212')->is_valid_number, '北海道川上郡弟子屈町泉');
ok($zip->set_number('0883213')->is_valid_number, '北海道川上郡弟子屈町桜丘');
ok($zip->set_number('0883214')->is_valid_number, '北海道川上郡弟子屈町高栄');
ok($zip->set_number('0883215')->is_valid_number, '北海道川上郡弟子屈町美里');
ok($zip->set_number('0883221')->is_valid_number, '北海道川上郡弟子屈町鐺別');
ok($zip->set_number('0883221')->is_valid_number, '北海道川上郡弟子屈町鐺別原野');
ok($zip->set_number('0883222')->is_valid_number, '北海道川上郡弟子屈町弟子屈原野');
ok($zip->set_number('0883223')->is_valid_number, '北海道川上郡弟子屈町仁多');
ok($zip->set_number('0883224')->is_valid_number, '北海道川上郡弟子屈町平和');
ok($zip->set_number('0883225')->is_valid_number, '北海道川上郡弟子屈町最栄利別');
ok($zip->set_number('0883226')->is_valid_number, '北海道川上郡弟子屈町奥オソベツ');
ok($zip->set_number('0883227')->is_valid_number, '北海道川上郡弟子屈町重内');
ok($zip->set_number('0883228')->is_valid_number, '北海道川上郡弟子屈町奥春別');
ok($zip->set_number('0883271')->is_valid_number, '北海道川上郡弟子屈町南弟子屈');
ok($zip->set_number('0883331')->is_valid_number, '北海道川上郡弟子屈町美留和');
ok($zip->set_number('0883331')->is_valid_number, '北海道川上郡弟子屈町美留和原野');
ok($zip->set_number('0883332')->is_valid_number, '北海道川上郡弟子屈町札友内');
ok($zip->set_number('0883332')->is_valid_number, '北海道川上郡弟子屈町札友内原野');
ok($zip->set_number('0883341')->is_valid_number, '北海道川上郡弟子屈町屈斜路');
ok($zip->set_number('0883341')->is_valid_number, '北海道川上郡弟子屈町屈斜路原野');
ok($zip->set_number('0883351')->is_valid_number, '北海道川上郡弟子屈町池の湯');
ok($zip->set_number('0883351')->is_valid_number, '北海道川上郡弟子屈町屈斜路市街地');
ok($zip->set_number('0883351')->is_valid_number, '北海道川上郡弟子屈町古丹');
ok($zip->set_number('0883351')->is_valid_number, '北海道川上郡弟子屈町砂湯');
ok($zip->set_number('0883461')->is_valid_number, '北海道川上郡弟子屈町跡佐登');
ok($zip->set_number('0883461')->is_valid_number, '北海道川上郡弟子屈町跡佐登原野');
ok($zip->set_number('0883462')->is_valid_number, '北海道川上郡弟子屈町川湯駅前');
ok($zip->set_number('0883463')->is_valid_number, '北海道川上郡弟子屈町アトサヌプリ原野');
ok($zip->set_number('0883464')->is_valid_number, '北海道川上郡弟子屈町サワンチサップ');
ok($zip->set_number('0883465')->is_valid_number, '北海道川上郡弟子屈町川湯温泉');
ok($zip->set_number('0890100')->is_valid_number, '北海道上川郡清水町以下に掲載がない場合');
ok($zip->set_number('0890101')->is_valid_number, '北海道上川郡清水町人舞');
ok($zip->set_number('0890102')->is_valid_number, '北海道上川郡清水町下佐幌');
ok($zip->set_number('0890103')->is_valid_number, '北海道上川郡清水町清水');
ok($zip->set_number('0890104')->is_valid_number, '北海道上川郡清水町南三条西');
ok($zip->set_number('0890105')->is_valid_number, '北海道上川郡清水町南四条西');
ok($zip->set_number('0890106')->is_valid_number, '北海道上川郡清水町南五条西');
ok($zip->set_number('0890107')->is_valid_number, '北海道上川郡清水町南六条西');
ok($zip->set_number('0890111')->is_valid_number, '北海道上川郡清水町南三条');
ok($zip->set_number('0890112')->is_valid_number, '北海道上川郡清水町南四条');
ok($zip->set_number('0890113')->is_valid_number, '北海道上川郡清水町南五条');
ok($zip->set_number('0890114')->is_valid_number, '北海道上川郡清水町南六条');
ok($zip->set_number('0890115')->is_valid_number, '北海道上川郡清水町南七条');
ok($zip->set_number('0890116')->is_valid_number, '北海道上川郡清水町南八条');
ok($zip->set_number('0890117')->is_valid_number, '北海道上川郡清水町南九条');
ok($zip->set_number('0890118')->is_valid_number, '北海道上川郡清水町南十条');
ok($zip->set_number('0890121')->is_valid_number, '北海道上川郡清水町北四条西');
ok($zip->set_number('0890122')->is_valid_number, '北海道上川郡清水町北三条西');
ok($zip->set_number('0890123')->is_valid_number, '北海道上川郡清水町北二条西');
ok($zip->set_number('0890124')->is_valid_number, '北海道上川郡清水町北一条西');
ok($zip->set_number('0890125')->is_valid_number, '北海道上川郡清水町本通西');
ok($zip->set_number('0890126')->is_valid_number, '北海道上川郡清水町南一条西');
ok($zip->set_number('0890127')->is_valid_number, '北海道上川郡清水町南二条西');
ok($zip->set_number('0890131')->is_valid_number, '北海道上川郡清水町北五条');
ok($zip->set_number('0890132')->is_valid_number, '北海道上川郡清水町北四条');
ok($zip->set_number('0890133')->is_valid_number, '北海道上川郡清水町北三条');
ok($zip->set_number('0890134')->is_valid_number, '北海道上川郡清水町北二条');
ok($zip->set_number('0890135')->is_valid_number, '北海道上川郡清水町北一条');
ok($zip->set_number('0890136')->is_valid_number, '北海道上川郡清水町本通');
ok($zip->set_number('0890137')->is_valid_number, '北海道上川郡清水町南一条');
ok($zip->set_number('0890138')->is_valid_number, '北海道上川郡清水町南二条');
ok($zip->set_number('0890241')->is_valid_number, '北海道上川郡清水町熊牛');
ok($zip->set_number('0890242')->is_valid_number, '北海道上川郡清水町美蔓');
ok($zip->set_number('0890243')->is_valid_number, '北海道上川郡清水町上然別');
ok($zip->set_number('0890351')->is_valid_number, '北海道上川郡清水町御影西一条');
ok($zip->set_number('0890352')->is_valid_number, '北海道上川郡清水町御影西二条');
ok($zip->set_number('0890353')->is_valid_number, '北海道上川郡清水町御影西三条');
ok($zip->set_number('0890354')->is_valid_number, '北海道上川郡清水町御影本通');
ok($zip->set_number('0890355')->is_valid_number, '北海道上川郡清水町旭山');
ok($zip->set_number('0890356')->is_valid_number, '北海道上川郡清水町羽帯');
ok($zip->set_number('0890357')->is_valid_number, '北海道上川郡清水町御影');
ok($zip->set_number('0890361')->is_valid_number, '北海道上川郡清水町御影東一条南');
ok($zip->set_number('0890362')->is_valid_number, '北海道上川郡清水町御影東二条南');
ok($zip->set_number('0890363')->is_valid_number, '北海道上川郡清水町御影東三条南');
ok($zip->set_number('0890371')->is_valid_number, '北海道上川郡清水町御影東一条');
ok($zip->set_number('0890372')->is_valid_number, '北海道上川郡清水町御影東二条');
ok($zip->set_number('0890373')->is_valid_number, '北海道上川郡清水町御影東三条');
ok($zip->set_number('0890374')->is_valid_number, '北海道上川郡清水町御影東四条');
ok($zip->set_number('0890375')->is_valid_number, '北海道上川郡清水町御影東五条');
ok($zip->set_number('0890376')->is_valid_number, '北海道上川郡清水町御影東六条');
ok($zip->set_number('0890377')->is_valid_number, '北海道上川郡清水町御影東七条');
ok($zip->set_number('0890378')->is_valid_number, '北海道上川郡清水町御影東八条');
ok($zip->set_number('0890531')->is_valid_number, '北海道中川郡幕別町札内暁町');
ok($zip->set_number('0890532')->is_valid_number, '北海道中川郡幕別町札内豊町');
ok($zip->set_number('0890533')->is_valid_number, '北海道中川郡幕別町札内新北町');
ok($zip->set_number('0890534')->is_valid_number, '北海道中川郡幕別町札内北町');
ok($zip->set_number('0890535')->is_valid_number, '北海道中川郡幕別町札内桜町');
ok($zip->set_number('0890536')->is_valid_number, '北海道中川郡幕別町札内西町');
ok($zip->set_number('0890537')->is_valid_number, '北海道中川郡幕別町札内北栄町');
ok($zip->set_number('0890538')->is_valid_number, '北海道中川郡幕別町札内共栄町');
ok($zip->set_number('0890541')->is_valid_number, '北海道中川郡幕別町札内青葉町');
ok($zip->set_number('0890542')->is_valid_number, '北海道中川郡幕別町札内春日町');
ok($zip->set_number('0890543')->is_valid_number, '北海道中川郡幕別町札内中央町');
ok($zip->set_number('0890544')->is_valid_number, '北海道中川郡幕別町札内若草町');
ok($zip->set_number('0890545')->is_valid_number, '北海道中川郡幕別町札内桂町');
ok($zip->set_number('0890546')->is_valid_number, '北海道中川郡幕別町札内堤町');
ok($zip->set_number('0890551')->is_valid_number, '北海道中川郡幕別町札内泉町');
ok($zip->set_number('0890552')->is_valid_number, '北海道中川郡幕別町札内あかしや町');
ok($zip->set_number('0890553')->is_valid_number, '北海道中川郡幕別町札内文京町');
ok($zip->set_number('0890554')->is_valid_number, '北海道中川郡幕別町札内みずほ町');
ok($zip->set_number('0890561')->is_valid_number, '北海道中川郡幕別町札内稔町');
ok($zip->set_number('0890562')->is_valid_number, '北海道中川郡幕別町札内東町');
ok($zip->set_number('0890563')->is_valid_number, '北海道中川郡幕別町千住');
ok($zip->set_number('0890564')->is_valid_number, '北海道中川郡幕別町稲志別');
ok($zip->set_number('0890565')->is_valid_number, '北海道中川郡幕別町新生');
ok($zip->set_number('0890566')->is_valid_number, '北海道中川郡幕別町昭和');
ok($zip->set_number('0890567')->is_valid_number, '北海道中川郡幕別町明倫(78、208番地)');
ok($zip->set_number('0890571')->is_valid_number, '北海道中川郡幕別町依田');
ok($zip->set_number('0890572')->is_valid_number, '北海道中川郡幕別町西和');
ok($zip->set_number('0890573')->is_valid_number, '北海道中川郡幕別町途別');
ok($zip->set_number('0890574')->is_valid_number, '北海道中川郡幕別町日新');
ok($zip->set_number('0890575')->is_valid_number, '北海道中川郡幕別町上稲志別');
ok($zip->set_number('0890576')->is_valid_number, '北海道中川郡幕別町古舞');
ok($zip->set_number('0890577')->is_valid_number, '北海道中川郡幕別町栄');
ok($zip->set_number('0890578')->is_valid_number, '北海道中川郡幕別町中稲志別');
ok($zip->set_number('0890600')->is_valid_number, '北海道中川郡幕別町以下に掲載がない場合');
ok($zip->set_number('0890601')->is_valid_number, '北海道中川郡幕別町幸町');
ok($zip->set_number('0890602')->is_valid_number, '北海道中川郡幕別町旭町');
ok($zip->set_number('0890603')->is_valid_number, '北海道中川郡幕別町本町');
ok($zip->set_number('0890604')->is_valid_number, '北海道中川郡幕別町錦町');
ok($zip->set_number('0890605')->is_valid_number, '北海道中川郡幕別町寿町');
ok($zip->set_number('0890611')->is_valid_number, '北海道中川郡幕別町新町');
ok($zip->set_number('0890612')->is_valid_number, '北海道中川郡幕別町明野');
ok($zip->set_number('0890613')->is_valid_number, '北海道中川郡幕別町新川');
ok($zip->set_number('0890614')->is_valid_number, '北海道中川郡幕別町緑町');
ok($zip->set_number('0890615')->is_valid_number, '北海道中川郡幕別町南町');
ok($zip->set_number('0890616')->is_valid_number, '北海道中川郡幕別町宝町');
ok($zip->set_number('0890621')->is_valid_number, '北海道中川郡幕別町相川');
ok($zip->set_number('0890622')->is_valid_number, '北海道中川郡幕別町大豊');
ok($zip->set_number('0890623')->is_valid_number, '北海道中川郡幕別町南勢');
ok($zip->set_number('0890624')->is_valid_number, '北海道中川郡幕別町軍岡');
ok($zip->set_number('0890625')->is_valid_number, '北海道中川郡幕別町猿別');
ok($zip->set_number('0890626')->is_valid_number, '北海道中川郡幕別町西猿別');
ok($zip->set_number('0890627')->is_valid_number, '北海道中川郡幕別町新和(その他)');
ok($zip->set_number('0890628')->is_valid_number, '北海道中川郡幕別町豊岡');
ok($zip->set_number('0890781')->is_valid_number, '北海道中川郡幕別町五位');
ok($zip->set_number('0890782')->is_valid_number, '北海道中川郡幕別町中里');
ok($zip->set_number('0890783')->is_valid_number, '北海道中川郡幕別町駒畠');
ok($zip->set_number('0890784')->is_valid_number, '北海道中川郡幕別町弘和');
ok($zip->set_number('0890785')->is_valid_number, '北海道中川郡幕別町美川');
ok($zip->set_number('0890786')->is_valid_number, '北海道中川郡幕別町糠内');
ok($zip->set_number('0890787')->is_valid_number, '北海道中川郡幕別町明倫(その他)');
ok($zip->set_number('0890788')->is_valid_number, '北海道中川郡幕別町新和(新田牧場)');
ok($zip->set_number('0891181')->is_valid_number, '北海道帯広市愛国町');
ok($zip->set_number('0891182')->is_valid_number, '北海道帯広市川西町');
ok($zip->set_number('0891183')->is_valid_number, '北海道帯広市豊西町');
ok($zip->set_number('0891184')->is_valid_number, '北海道帯広市別府町');
ok($zip->set_number('0891241')->is_valid_number, '北海道帯広市大正本町');
ok($zip->set_number('0891242')->is_valid_number, '北海道帯広市大正町');
ok($zip->set_number('0891243')->is_valid_number, '北海道帯広市桜木町');
ok($zip->set_number('0891244')->is_valid_number, '北海道帯広市以平町');
ok($zip->set_number('0891245')->is_valid_number, '北海道帯広市泉町');
ok($zip->set_number('0891246')->is_valid_number, '北海道帯広市幸福町');
ok($zip->set_number('0891247')->is_valid_number, '北海道帯広市昭和町');
ok($zip->set_number('0891251')->is_valid_number, '北海道帯広市富士町(その他)');
ok($zip->set_number('0891252')->is_valid_number, '北海道帯広市中島町');
ok($zip->set_number('0891300')->is_valid_number, '北海道河西郡中札内村以下に掲載がない場合');
ok($zip->set_number('0891310')->is_valid_number, '北海道河西郡中札内村大通北');
ok($zip->set_number('0891311')->is_valid_number, '北海道河西郡中札内村西一条北');
ok($zip->set_number('0891312')->is_valid_number, '北海道河西郡中札内村西二条北');
ok($zip->set_number('0891313')->is_valid_number, '北海道河西郡中札内村中札内西');
ok($zip->set_number('0891321')->is_valid_number, '北海道河西郡中札内村東一条北');
ok($zip->set_number('0891322')->is_valid_number, '北海道河西郡中札内村東二条北');
ok($zip->set_number('0891323')->is_valid_number, '北海道河西郡中札内村東三条北');
ok($zip->set_number('0891324')->is_valid_number, '北海道河西郡中札内村東四条北');
ok($zip->set_number('0891325')->is_valid_number, '北海道河西郡中札内村中札内基線');
ok($zip->set_number('0891330')->is_valid_number, '北海道河西郡中札内村大通南');
ok($zip->set_number('0891331')->is_valid_number, '北海道河西郡中札内村西一条南');
ok($zip->set_number('0891332')->is_valid_number, '北海道河西郡中札内村西二条南');
ok($zip->set_number('0891341')->is_valid_number, '北海道河西郡中札内村東一条南');
ok($zip->set_number('0891342')->is_valid_number, '北海道河西郡中札内村東二条南');
ok($zip->set_number('0891343')->is_valid_number, '北海道河西郡中札内村東三条南');
ok($zip->set_number('0891344')->is_valid_number, '北海道河西郡中札内村東四条南');
ok($zip->set_number('0891345')->is_valid_number, '北海道河西郡中札内村東五条南');
ok($zip->set_number('0891351')->is_valid_number, '北海道河西郡中札内村東戸蔦');
ok($zip->set_number('0891352')->is_valid_number, '北海道河西郡中札内村中戸蔦');
ok($zip->set_number('0891353')->is_valid_number, '北海道河西郡中札内村西戸蔦');
ok($zip->set_number('0891354')->is_valid_number, '北海道河西郡中札内村新札内');
ok($zip->set_number('0891355')->is_valid_number, '北海道河西郡中札内村新札内南');
ok($zip->set_number('0891356')->is_valid_number, '北海道河西郡中札内村西札内');
ok($zip->set_number('0891361')->is_valid_number, '北海道河西郡中札内村元大正');
ok($zip->set_number('0891362')->is_valid_number, '北海道河西郡中札内村新生');
ok($zip->set_number('0891363')->is_valid_number, '北海道河西郡中札内村興和');
ok($zip->set_number('0891364')->is_valid_number, '北海道河西郡中札内村共栄');
ok($zip->set_number('0891365')->is_valid_number, '北海道河西郡中札内村協和');
ok($zip->set_number('0891366')->is_valid_number, '北海道河西郡中札内村栄');
ok($zip->set_number('0891367')->is_valid_number, '北海道河西郡中札内村常盤基線');
ok($zip->set_number('0891368')->is_valid_number, '北海道河西郡中札内村南常盤');
ok($zip->set_number('0891371')->is_valid_number, '北海道河西郡中札内村上札内');
ok($zip->set_number('0891372')->is_valid_number, '北海道河西郡中札内村元札内');
ok($zip->set_number('0891373')->is_valid_number, '北海道河西郡中札内村元更別');
ok($zip->set_number('0891374')->is_valid_number, '北海道河西郡中札内村南札内');
ok($zip->set_number('0891500')->is_valid_number, '北海道河西郡更別村以下に掲載がない場合');
ok($zip->set_number('0891501')->is_valid_number, '北海道河西郡更別村新栄町');
ok($zip->set_number('0891502')->is_valid_number, '北海道河西郡更別村花園町');
ok($zip->set_number('0891511')->is_valid_number, '北海道河西郡更別村柏町');
ok($zip->set_number('0891512')->is_valid_number, '北海道河西郡更別村中央町');
ok($zip->set_number('0891513')->is_valid_number, '北海道河西郡更別村本町');
ok($zip->set_number('0891521')->is_valid_number, '北海道河西郡更別村錦町');
ok($zip->set_number('0891522')->is_valid_number, '北海道河西郡更別村若葉町');
ok($zip->set_number('0891531')->is_valid_number, '北海道河西郡更別村曙町');
ok($zip->set_number('0891532')->is_valid_number, '北海道河西郡更別村緑町');
ok($zip->set_number('0891541')->is_valid_number, '北海道河西郡更別村更南');
ok($zip->set_number('0891542')->is_valid_number, '北海道河西郡更別村更別(区)');
ok($zip->set_number('0891543')->is_valid_number, '北海道河西郡更別村昭和区');
ok($zip->set_number('0891551')->is_valid_number, '北海道河西郡更別村旭区');
ok($zip->set_number('0891552')->is_valid_number, '北海道河西郡更別村勢雄');
ok($zip->set_number('0891553')->is_valid_number, '北海道河西郡更別村平和区');
ok($zip->set_number('0891561')->is_valid_number, '北海道河西郡更別村北更別区');
ok($zip->set_number('0891562')->is_valid_number, '北海道河西郡更別村更別(東区)');
ok($zip->set_number('0891563')->is_valid_number, '北海道河西郡更別村南更別区');
ok($zip->set_number('0891571')->is_valid_number, '北海道河西郡更別村香川区');
ok($zip->set_number('0891572')->is_valid_number, '北海道河西郡更別村更生区');
ok($zip->set_number('0891573')->is_valid_number, '北海道河西郡更別村弘和');
ok($zip->set_number('0891573')->is_valid_number, '北海道河西郡更別村東栄');
ok($zip->set_number('0891581')->is_valid_number, '北海道河西郡更別村上更別(南区)');
ok($zip->set_number('0891582')->is_valid_number, '北海道河西郡更別村協和区');
ok($zip->set_number('0891583')->is_valid_number, '北海道河西郡更別村上更別(1区)');
ok($zip->set_number('0891701')->is_valid_number, '北海道中川郡幕別町忠類白銀町');
ok($zip->set_number('0891703')->is_valid_number, '北海道中川郡幕別町忠類栄町');
ok($zip->set_number('0891705')->is_valid_number, '北海道中川郡幕別町忠類本町');
ok($zip->set_number('0891707')->is_valid_number, '北海道中川郡幕別町忠類錦町');
ok($zip->set_number('0891709')->is_valid_number, '北海道中川郡幕別町忠類幸町');
ok($zip->set_number('0891711')->is_valid_number, '北海道中川郡幕別町忠類東宝');
ok($zip->set_number('0891714')->is_valid_number, '北海道中川郡幕別町忠類新生');
ok($zip->set_number('0891715')->is_valid_number, '北海道中川郡幕別町忠類幌内');
ok($zip->set_number('0891716')->is_valid_number, '北海道中川郡幕別町忠類元忠類');
ok($zip->set_number('0891717')->is_valid_number, '北海道中川郡幕別町忠類朝日');
ok($zip->set_number('0891721')->is_valid_number, '北海道中川郡幕別町忠類西当');
ok($zip->set_number('0891724')->is_valid_number, '北海道中川郡幕別町忠類明和');
ok($zip->set_number('0891725')->is_valid_number, '北海道中川郡幕別町忠類中当');
ok($zip->set_number('0891726')->is_valid_number, '北海道中川郡幕別町忠類古里');
ok($zip->set_number('0891727')->is_valid_number, '北海道中川郡幕別町忠類共栄');
ok($zip->set_number('0891728')->is_valid_number, '北海道中川郡幕別町忠類協徳');
ok($zip->set_number('0891729')->is_valid_number, '北海道中川郡幕別町忠類日和');
ok($zip->set_number('0891731')->is_valid_number, '北海道中川郡幕別町忠類公親');
ok($zip->set_number('0891871')->is_valid_number, '北海道中川郡幕別町忠類晩成');
ok($zip->set_number('0891881')->is_valid_number, '北海道広尾郡大樹町生花');
ok($zip->set_number('0891882')->is_valid_number, '北海道広尾郡大樹町晩成');
ok($zip->set_number('0892100')->is_valid_number, '北海道広尾郡大樹町以下に掲載がない場合');
ok($zip->set_number('0892101')->is_valid_number, '北海道広尾郡大樹町東和');
ok($zip->set_number('0892102')->is_valid_number, '北海道広尾郡大樹町大和');
ok($zip->set_number('0892103')->is_valid_number, '北海道広尾郡大樹町上大樹');
ok($zip->set_number('0892104')->is_valid_number, '北海道広尾郡大樹町中大樹');
ok($zip->set_number('0892105')->is_valid_number, '北海道広尾郡大樹町大樹');
ok($zip->set_number('0892106')->is_valid_number, '北海道広尾郡大樹町下大樹');
ok($zip->set_number('0892107')->is_valid_number, '北海道広尾郡大樹町松山');
ok($zip->set_number('0892111')->is_valid_number, '北海道広尾郡大樹町上萠和');
ok($zip->set_number('0892112')->is_valid_number, '北海道広尾郡大樹町萠和');
ok($zip->set_number('0892113')->is_valid_number, '北海道広尾郡大樹町芽武');
ok($zip->set_number('0892114')->is_valid_number, '北海道広尾郡大樹町下芽武');
ok($zip->set_number('0892115')->is_valid_number, '北海道広尾郡大樹町美成');
ok($zip->set_number('0892116')->is_valid_number, '北海道広尾郡大樹町浜大樹');
ok($zip->set_number('0892117')->is_valid_number, '北海道広尾郡大樹町更生');
ok($zip->set_number('0892121')->is_valid_number, '北海道広尾郡大樹町旭浜');
ok($zip->set_number('0892122')->is_valid_number, '北海道広尾郡大樹町中島');
ok($zip->set_number('0892123')->is_valid_number, '北海道広尾郡大樹町上中島');
ok($zip->set_number('0892124')->is_valid_number, '北海道広尾郡大樹町日方');
ok($zip->set_number('0892125')->is_valid_number, '北海道広尾郡大樹町石坂');
ok($zip->set_number('0892126')->is_valid_number, '北海道広尾郡大樹町開進');
ok($zip->set_number('0892127')->is_valid_number, '北海道広尾郡大樹町振別');
ok($zip->set_number('0892131')->is_valid_number, '北海道広尾郡大樹町松山町');
ok($zip->set_number('0892132')->is_valid_number, '北海道広尾郡大樹町双葉町');
ok($zip->set_number('0892133')->is_valid_number, '北海道広尾郡大樹町仲通');
ok($zip->set_number('0892134')->is_valid_number, '北海道広尾郡大樹町東本通');
ok($zip->set_number('0892135')->is_valid_number, '北海道広尾郡大樹町南通');
ok($zip->set_number('0892136')->is_valid_number, '北海道広尾郡大樹町新通');
ok($zip->set_number('0892137')->is_valid_number, '北海道広尾郡大樹町北通');
ok($zip->set_number('0892138')->is_valid_number, '北海道広尾郡大樹町柏木町');
ok($zip->set_number('0892140')->is_valid_number, '北海道広尾郡大樹町栄通');
ok($zip->set_number('0892141')->is_valid_number, '北海道広尾郡大樹町一条通');
ok($zip->set_number('0892142')->is_valid_number, '北海道広尾郡大樹町二条通');
ok($zip->set_number('0892143')->is_valid_number, '北海道広尾郡大樹町三条通');
ok($zip->set_number('0892145')->is_valid_number, '北海道広尾郡大樹町暁町');
ok($zip->set_number('0892146')->is_valid_number, '北海道広尾郡大樹町寿通');
ok($zip->set_number('0892147')->is_valid_number, '北海道広尾郡大樹町鏡町');
ok($zip->set_number('0892148')->is_valid_number, '北海道広尾郡大樹町麻友');
ok($zip->set_number('0892151')->is_valid_number, '北海道広尾郡大樹町高校通');
ok($zip->set_number('0892152')->is_valid_number, '北海道広尾郡大樹町西本通');
ok($zip->set_number('0892153')->is_valid_number, '北海道広尾郡大樹町南町');
ok($zip->set_number('0892154')->is_valid_number, '北海道広尾郡大樹町幸町');
ok($zip->set_number('0892155')->is_valid_number, '北海道広尾郡大樹町緑町');
ok($zip->set_number('0892156')->is_valid_number, '北海道広尾郡大樹町緑苑');
ok($zip->set_number('0892261')->is_valid_number, '北海道広尾郡大樹町尾田');
ok($zip->set_number('0892261')->is_valid_number, '北海道広尾郡大樹町拓北');
ok($zip->set_number('0892261')->is_valid_number, '北海道広尾郡大樹町豊里');
ok($zip->set_number('0892262')->is_valid_number, '北海道広尾郡大樹町相川');
ok($zip->set_number('0892263')->is_valid_number, '北海道広尾郡大樹町拓進');
ok($zip->set_number('0892271')->is_valid_number, '北海道広尾郡大樹町光地園');
ok($zip->set_number('0892272')->is_valid_number, '北海道広尾郡大樹町幸徳');
ok($zip->set_number('0892272')->is_valid_number, '北海道広尾郡大樹町住吉');
ok($zip->set_number('0892273')->is_valid_number, '北海道広尾郡大樹町大光');
ok($zip->set_number('0892273')->is_valid_number, '北海道広尾郡大樹町大全');
ok($zip->set_number('0892445')->is_valid_number, '北海道広尾郡広尾町カシュウンナイ');
ok($zip->set_number('0892446')->is_valid_number, '北海道広尾郡広尾町紋別');
ok($zip->set_number('0892447')->is_valid_number, '北海道広尾郡広尾町上豊似');
ok($zip->set_number('0892447')->is_valid_number, '北海道広尾郡広尾町下トヨイ');
ok($zip->set_number('0892447')->is_valid_number, '北海道広尾郡広尾町下豊似');
ok($zip->set_number('0892447')->is_valid_number, '北海道広尾郡広尾町トヨイベツ');
ok($zip->set_number('0892448')->is_valid_number, '北海道広尾郡広尾町上トヨイ');
ok($zip->set_number('0892455')->is_valid_number, '北海道広尾郡広尾町豊似');
ok($zip->set_number('0892561')->is_valid_number, '北海道広尾郡広尾町野塚');
ok($zip->set_number('0892562')->is_valid_number, '北海道広尾郡広尾町野塚西通');
ok($zip->set_number('0892563')->is_valid_number, '北海道広尾郡広尾町野塚東通');
ok($zip->set_number('0892564')->is_valid_number, '北海道広尾郡広尾町野塚本通');
ok($zip->set_number('0892600')->is_valid_number, '北海道広尾郡広尾町以下に掲載がない場合');
ok($zip->set_number('0892601')->is_valid_number, '北海道広尾郡広尾町東一条');
ok($zip->set_number('0892602')->is_valid_number, '北海道広尾郡広尾町東二条');
ok($zip->set_number('0892603')->is_valid_number, '北海道広尾郡広尾町東三条');
ok($zip->set_number('0892604')->is_valid_number, '北海道広尾郡広尾町会所通');
ok($zip->set_number('0892605')->is_valid_number, '北海道広尾郡広尾町会所前');
ok($zip->set_number('0892611')->is_valid_number, '北海道広尾郡広尾町西一条');
ok($zip->set_number('0892612')->is_valid_number, '北海道広尾郡広尾町西二条');
ok($zip->set_number('0892613')->is_valid_number, '北海道広尾郡広尾町西三条');
ok($zip->set_number('0892614')->is_valid_number, '北海道広尾郡広尾町西四条');
ok($zip->set_number('0892615')->is_valid_number, '北海道広尾郡広尾町本通');
ok($zip->set_number('0892616')->is_valid_number, '北海道広尾郡広尾町陣屋');
ok($zip->set_number('0892621')->is_valid_number, '北海道広尾郡広尾町公園通北');
ok($zip->set_number('0892622')->is_valid_number, '北海道広尾郡広尾町公園通南');
ok($zip->set_number('0892623')->is_valid_number, '北海道広尾郡広尾町並木通西');
ok($zip->set_number('0892624')->is_valid_number, '北海道広尾郡広尾町並木通東');
ok($zip->set_number('0892625')->is_valid_number, '北海道広尾郡広尾町錦通北');
ok($zip->set_number('0892626')->is_valid_number, '北海道広尾郡広尾町錦通南');
ok($zip->set_number('0892627')->is_valid_number, '北海道広尾郡広尾町丸山通北');
ok($zip->set_number('0892628')->is_valid_number, '北海道広尾郡広尾町丸山通南');
ok($zip->set_number('0892631')->is_valid_number, '北海道広尾郡広尾町白樺通北');
ok($zip->set_number('0892632')->is_valid_number, '北海道広尾郡広尾町白樺通南');
ok($zip->set_number('0892633')->is_valid_number, '北海道広尾郡広尾町美幌');
ok($zip->set_number('0892634')->is_valid_number, '北海道広尾郡広尾町フンベ');
ok($zip->set_number('0892635')->is_valid_number, '北海道広尾郡広尾町紅葉通北');
ok($zip->set_number('0892636')->is_valid_number, '北海道広尾郡広尾町紅葉通南');
ok($zip->set_number('0892637')->is_valid_number, '北海道広尾郡広尾町茂寄');
ok($zip->set_number('0892638')->is_valid_number, '北海道広尾郡広尾町茂寄南');
ok($zip->set_number('0892771')->is_valid_number, '北海道広尾郡広尾町音調津');
ok($zip->set_number('0892772')->is_valid_number, '北海道広尾郡広尾町音調津区画外');
ok($zip->set_number('0892773')->is_valid_number, '北海道広尾郡広尾町モエケシ');
ok($zip->set_number('0892774')->is_valid_number, '北海道広尾郡広尾町ルベシベツ');
ok($zip->set_number('0892775')->is_valid_number, '北海道広尾郡広尾町タニイソ');
ok($zip->set_number('0892776')->is_valid_number, '北海道広尾郡広尾町ビタタヌンケ');
ok($zip->set_number('0893151')->is_valid_number, '北海道中川郡池田町大森');
ok($zip->set_number('0893152')->is_valid_number, '北海道中川郡池田町高島');
ok($zip->set_number('0893153')->is_valid_number, '北海道中川郡池田町近牛');
ok($zip->set_number('0893154')->is_valid_number, '北海道中川郡池田町信取');
ok($zip->set_number('0893155')->is_valid_number, '北海道中川郡池田町美加登');
ok($zip->set_number('0893156')->is_valid_number, '北海道中川郡池田町常盤');
ok($zip->set_number('0893281')->is_valid_number, '北海道中川郡本別町勇足元町');
ok($zip->set_number('0893282')->is_valid_number, '北海道中川郡本別町勇足');
ok($zip->set_number('0893283')->is_valid_number, '北海道中川郡本別町押帯');
ok($zip->set_number('0893284')->is_valid_number, '北海道中川郡本別町美蘭別');
ok($zip->set_number('0893300')->is_valid_number, '北海道中川郡本別町以下に掲載がない場合');
ok($zip->set_number('0893301')->is_valid_number, '北海道中川郡本別町東本別');
ok($zip->set_number('0893302')->is_valid_number, '北海道中川郡本別町東町');
ok($zip->set_number('0893303')->is_valid_number, '北海道中川郡本別町向陽町');
ok($zip->set_number('0893304')->is_valid_number, '北海道中川郡本別町坂下町');
ok($zip->set_number('0893305')->is_valid_number, '北海道中川郡本別町共栄');
ok($zip->set_number('0893306')->is_valid_number, '北海道中川郡本別町チエトイ');
ok($zip->set_number('0893307')->is_valid_number, '北海道中川郡本別町負箙');
ok($zip->set_number('0893308')->is_valid_number, '北海道中川郡本別町弥生町');
ok($zip->set_number('0893311')->is_valid_number, '北海道中川郡本別町柏木町');
ok($zip->set_number('0893312')->is_valid_number, '北海道中川郡本別町緑町');
ok($zip->set_number('0893313')->is_valid_number, '北海道中川郡本別町柳町');
ok($zip->set_number('0893314')->is_valid_number, '北海道中川郡本別町南');
ok($zip->set_number('0893321')->is_valid_number, '北海道中川郡本別町上本別(フラツナイ)');
ok($zip->set_number('0893322')->is_valid_number, '北海道中川郡本別町栄町');
ok($zip->set_number('0893323')->is_valid_number, '北海道中川郡本別町美里別(東下)');
ok($zip->set_number('0893324')->is_valid_number, '北海道中川郡本別町新町');
ok($zip->set_number('0893325')->is_valid_number, '北海道中川郡本別町西美里別(その他)');
ok($zip->set_number('0893326')->is_valid_number, '北海道中川郡本別町美里別(高東)');
ok($zip->set_number('0893327')->is_valid_number, '北海道中川郡本別町追名牛(その他)');
ok($zip->set_number('0893331')->is_valid_number, '北海道中川郡本別町錦町');
ok($zip->set_number('0893332')->is_valid_number, '北海道中川郡本別町朝日町');
ok($zip->set_number('0893333')->is_valid_number, '北海道中川郡本別町山手町');
ok($zip->set_number('0893334')->is_valid_number, '北海道中川郡本別町北');
ok($zip->set_number('0893334')->is_valid_number, '北海道中川郡本別町清流町');
ok($zip->set_number('0893442')->is_valid_number, '北海道中川郡本別町美里別(拓農、東活込、東上、東中)');
ok($zip->set_number('0893443')->is_valid_number, '北海道中川郡本別町西美里別(113~791番地、西活込、西上、西中)');
ok($zip->set_number('0893571')->is_valid_number, '北海道十勝郡浦幌町恩根内');
ok($zip->set_number('0893572')->is_valid_number, '北海道十勝郡浦幌町川流布');
ok($zip->set_number('0893573')->is_valid_number, '北海道十勝郡浦幌町富川');
ok($zip->set_number('0893574')->is_valid_number, '北海道十勝郡浦幌町活平');
ok($zip->set_number('0893575')->is_valid_number, '北海道十勝郡浦幌町美園');
ok($zip->set_number('0893576')->is_valid_number, '北海道十勝郡浦幌町相川');
ok($zip->set_number('0893577')->is_valid_number, '北海道十勝郡浦幌町合流');
ok($zip->set_number('0893578')->is_valid_number, '北海道十勝郡浦幌町宝生');
ok($zip->set_number('0893585')->is_valid_number, '北海道十勝郡浦幌町川上');
ok($zip->set_number('0893586')->is_valid_number, '北海道十勝郡浦幌町栄穂');
ok($zip->set_number('0893587')->is_valid_number, '北海道十勝郡浦幌町貴老路');
ok($zip->set_number('0893661')->is_valid_number, '北海道中川郡本別町美栄');
ok($zip->set_number('0893662')->is_valid_number, '北海道中川郡本別町奥仙美里');
ok($zip->set_number('0893663')->is_valid_number, '北海道中川郡本別町仙美里');
ok($zip->set_number('0893664')->is_valid_number, '北海道中川郡本別町仙美里元町');
ok($zip->set_number('0893665')->is_valid_number, '北海道中川郡本別町清里');
ok($zip->set_number('0893666')->is_valid_number, '北海道中川郡本別町上仙美里');
ok($zip->set_number('0893671')->is_valid_number, '北海道中川郡本別町木札内');
ok($zip->set_number('0893672')->is_valid_number, '北海道中川郡本別町追名牛(67-4~113-7番地)');
ok($zip->set_number('0893673')->is_valid_number, '北海道中川郡本別町東仙美里');
ok($zip->set_number('0893674')->is_valid_number, '北海道中川郡本別町下仙美里');
ok($zip->set_number('0893675')->is_valid_number, '北海道中川郡本別町西仙美里');
ok($zip->set_number('0893676')->is_valid_number, '北海道中川郡本別町明美');
ok($zip->set_number('0893677')->is_valid_number, '北海道中川郡本別町美里別(246-7番地)');
ok($zip->set_number('0893700')->is_valid_number, '北海道足寄郡足寄町以下に掲載がない場合');
ok($zip->set_number('0893701')->is_valid_number, '北海道足寄郡足寄町北一条');
ok($zip->set_number('0893702')->is_valid_number, '北海道足寄郡足寄町北二条');
ok($zip->set_number('0893703')->is_valid_number, '北海道足寄郡足寄町北三条');
ok($zip->set_number('0893704')->is_valid_number, '北海道足寄郡足寄町北四条');
ok($zip->set_number('0893705')->is_valid_number, '北海道足寄郡足寄町北五条');
ok($zip->set_number('0893706')->is_valid_number, '北海道足寄郡足寄町北六条');
ok($zip->set_number('0893707')->is_valid_number, '北海道足寄郡足寄町下愛冠');
ok($zip->set_number('0893708')->is_valid_number, '北海道足寄郡足寄町愛冠');
ok($zip->set_number('0893711')->is_valid_number, '北海道足寄郡足寄町南一条');
ok($zip->set_number('0893712')->is_valid_number, '北海道足寄郡足寄町南二条');
ok($zip->set_number('0893713')->is_valid_number, '北海道足寄郡足寄町南三条');
ok($zip->set_number('0893714')->is_valid_number, '北海道足寄郡足寄町南四条');
ok($zip->set_number('0893715')->is_valid_number, '北海道足寄郡足寄町南五条');
ok($zip->set_number('0893716')->is_valid_number, '北海道足寄郡足寄町南六条');
ok($zip->set_number('0893717')->is_valid_number, '北海道足寄郡足寄町南七条');
ok($zip->set_number('0893718')->is_valid_number, '北海道足寄郡足寄町栄町');
ok($zip->set_number('0893721')->is_valid_number, '北海道足寄郡足寄町旭町');
ok($zip->set_number('0893722')->is_valid_number, '北海道足寄郡足寄町新町');
ok($zip->set_number('0893723')->is_valid_number, '北海道足寄郡足寄町中足寄');
ok($zip->set_number('0893724')->is_valid_number, '北海道足寄郡足寄町稲牛');
ok($zip->set_number('0893725')->is_valid_number, '北海道足寄郡足寄町平和');
ok($zip->set_number('0893726')->is_valid_number, '北海道足寄郡足寄町共栄町');
ok($zip->set_number('0893727')->is_valid_number, '北海道足寄郡足寄町郊南');
ok($zip->set_number('0893731')->is_valid_number, '北海道足寄郡足寄町中矢(7~288番地)');
ok($zip->set_number('0893732')->is_valid_number, '北海道足寄郡足寄町里見が丘');
ok($zip->set_number('0893733')->is_valid_number, '北海道足寄郡足寄町西町');
ok($zip->set_number('0893734')->is_valid_number, '北海道足寄郡足寄町常盤');
ok($zip->set_number('0893735')->is_valid_number, '北海道足寄郡足寄町美盛');
ok($zip->set_number('0893736')->is_valid_number, '北海道足寄郡足寄町鷲府');
ok($zip->set_number('0893737')->is_valid_number, '北海道足寄郡足寄町茂喜登牛(12~634番地)');
ok($zip->set_number('0893871')->is_valid_number, '北海道足寄郡足寄町芽登本町');
ok($zip->set_number('0893872')->is_valid_number, '北海道足寄郡足寄町芽登');
ok($zip->set_number('0893873')->is_valid_number, '北海道足寄郡足寄町中矢(426~782番地)');
ok($zip->set_number('0893874')->is_valid_number, '北海道足寄郡足寄町喜登牛');
ok($zip->set_number('0893875')->is_valid_number, '北海道足寄郡足寄町茂喜登牛(759~2786番地)');
ok($zip->set_number('0893961')->is_valid_number, '北海道足寄郡足寄町上足寄');
ok($zip->set_number('0893962')->is_valid_number, '北海道足寄郡足寄町上足寄本町');
ok($zip->set_number('0893963')->is_valid_number, '北海道足寄郡足寄町上螺湾');
ok($zip->set_number('0893964')->is_valid_number, '北海道足寄郡足寄町茂足寄');
ok($zip->set_number('0893965')->is_valid_number, '北海道足寄郡足寄町螺湾');
ok($zip->set_number('0893966')->is_valid_number, '北海道足寄郡足寄町螺湾本町');
ok($zip->set_number('0894141')->is_valid_number, '北海道足寄郡足寄町上利別本町');
ok($zip->set_number('0894142')->is_valid_number, '北海道足寄郡足寄町上利別');
ok($zip->set_number('0894143')->is_valid_number, '北海道足寄郡足寄町白糸');
ok($zip->set_number('0894144')->is_valid_number, '北海道足寄郡足寄町大誉地(10-1番地)');
ok($zip->set_number('0894251')->is_valid_number, '北海道足寄郡足寄町大誉地(その他)');
ok($zip->set_number('0894252')->is_valid_number, '北海道足寄郡足寄町大誉地本町');
ok($zip->set_number('0894261')->is_valid_number, '北海道足寄郡陸別町登良利');
ok($zip->set_number('0894262')->is_valid_number, '北海道足寄郡陸別町薫別');
ok($zip->set_number('0894300')->is_valid_number, '北海道足寄郡陸別町以下に掲載がない場合');
ok($zip->set_number('0894301')->is_valid_number, '北海道足寄郡陸別町ウエンベツ');
ok($zip->set_number('0894302')->is_valid_number, '北海道足寄郡陸別町若葉');
ok($zip->set_number('0894303')->is_valid_number, '北海道足寄郡陸別町下陸別');
ok($zip->set_number('0894304')->is_valid_number, '北海道足寄郡陸別町共和');
ok($zip->set_number('0894305')->is_valid_number, '北海道足寄郡陸別町中陸別');
ok($zip->set_number('0894306')->is_valid_number, '北海道足寄郡陸別町止若内');
ok($zip->set_number('0894307')->is_valid_number, '北海道足寄郡陸別町作集');
ok($zip->set_number('0894308')->is_valid_number, '北海道足寄郡陸別町上陸別');
ok($zip->set_number('0894311')->is_valid_number, '北海道足寄郡陸別町東一条二区');
ok($zip->set_number('0894312')->is_valid_number, '北海道足寄郡陸別町共栄第二');
ok($zip->set_number('0894313')->is_valid_number, '北海道足寄郡陸別町共栄第一');
ok($zip->set_number('0894314')->is_valid_number, '北海道足寄郡陸別町東一条一区');
ok($zip->set_number('0894315')->is_valid_number, '北海道足寄郡陸別町大通');
ok($zip->set_number('0894316')->is_valid_number, '北海道足寄郡陸別町栄町');
ok($zip->set_number('0894321')->is_valid_number, '北海道足寄郡陸別町恩根内');
ok($zip->set_number('0894322')->is_valid_number, '北海道足寄郡陸別町新町一区');
ok($zip->set_number('0894323')->is_valid_number, '北海道足寄郡陸別町新町二区');
ok($zip->set_number('0894324')->is_valid_number, '北海道足寄郡陸別町旭町');
ok($zip->set_number('0894325')->is_valid_number, '北海道足寄郡陸別町元町');
ok($zip->set_number('0894326')->is_valid_number, '北海道足寄郡陸別町緑町');
ok($zip->set_number('0894331')->is_valid_number, '北海道足寄郡陸別町川向');
ok($zip->set_number('0894332')->is_valid_number, '北海道足寄郡陸別町関');
ok($zip->set_number('0894333')->is_valid_number, '北海道足寄郡陸別町殖産');
ok($zip->set_number('0894334')->is_valid_number, '北海道足寄郡陸別町東斗満');
ok($zip->set_number('0894335')->is_valid_number, '北海道足寄郡陸別町中斗満');
ok($zip->set_number('0894336')->is_valid_number, '北海道足寄郡陸別町弥生');
ok($zip->set_number('0894337')->is_valid_number, '北海道足寄郡陸別町下斗満');
ok($zip->set_number('0894341')->is_valid_number, '北海道足寄郡陸別町苫務');
ok($zip->set_number('0894342')->is_valid_number, '北海道足寄郡陸別町上斗満');
ok($zip->set_number('0894343')->is_valid_number, '北海道足寄郡陸別町南斗満');
ok($zip->set_number('0894344')->is_valid_number, '北海道足寄郡陸別町西斗満');
ok($zip->set_number('0894345')->is_valid_number, '北海道足寄郡陸別町北斗満');
ok($zip->set_number('0894346')->is_valid_number, '北海道足寄郡陸別町ポントマム');
ok($zip->set_number('0894351')->is_valid_number, '北海道足寄郡陸別町勲祢別');
ok($zip->set_number('0894352')->is_valid_number, '北海道足寄郡陸別町分線');
ok($zip->set_number('0894353')->is_valid_number, '北海道足寄郡陸別町川上');
ok($zip->set_number('0894354')->is_valid_number, '北海道足寄郡陸別町日宗');
ok($zip->set_number('0894355')->is_valid_number, '北海道足寄郡陸別町小利別');
ok($zip->set_number('0894356')->is_valid_number, '北海道足寄郡陸別町林内');
ok($zip->set_number('0894357')->is_valid_number, '北海道足寄郡陸別町利上');
ok($zip->set_number('0895231')->is_valid_number, '北海道中川郡豊頃町豊頃佐々田町');
ok($zip->set_number('0895232')->is_valid_number, '北海道中川郡豊頃町豊頃旭町');
ok($zip->set_number('0895233')->is_valid_number, '北海道中川郡豊頃町豊頃南町');
ok($zip->set_number('0895234')->is_valid_number, '北海道中川郡豊頃町中央新町');
ok($zip->set_number('0895235')->is_valid_number, '北海道中川郡豊頃町中央若葉町');
ok($zip->set_number('0895241')->is_valid_number, '北海道中川郡豊頃町育素多');
ok($zip->set_number('0895242')->is_valid_number, '北海道中川郡豊頃町北栄');
ok($zip->set_number('0895243')->is_valid_number, '北海道中川郡豊頃町十弗宝町');
ok($zip->set_number('0895244')->is_valid_number, '北海道中川郡豊頃町十弗');
ok($zip->set_number('0895245')->is_valid_number, '北海道中川郡豊頃町礼文内');
ok($zip->set_number('0895246')->is_valid_number, '北海道中川郡豊頃町豊頃');
ok($zip->set_number('0895247')->is_valid_number, '北海道中川郡豊頃町幌岡');
ok($zip->set_number('0895300')->is_valid_number, '北海道中川郡豊頃町以下に掲載がない場合');
ok($zip->set_number('0895301')->is_valid_number, '北海道中川郡豊頃町統内');
ok($zip->set_number('0895302')->is_valid_number, '北海道中川郡豊頃町礼作別');
ok($zip->set_number('0895303')->is_valid_number, '北海道中川郡豊頃町農野牛');
ok($zip->set_number('0895304')->is_valid_number, '北海道中川郡豊頃町牛首別');
ok($zip->set_number('0895305')->is_valid_number, '北海道中川郡豊頃町背負');
ok($zip->set_number('0895306')->is_valid_number, '北海道中川郡豊頃町安骨');
ok($zip->set_number('0895307')->is_valid_number, '北海道中川郡豊頃町旅来');
ok($zip->set_number('0895308')->is_valid_number, '北海道中川郡豊頃町湧洞');
ok($zip->set_number('0895309')->is_valid_number, '北海道中川郡豊頃町二宮');
ok($zip->set_number('0895311')->is_valid_number, '北海道中川郡豊頃町茂岩新和町');
ok($zip->set_number('0895312')->is_valid_number, '北海道中川郡豊頃町茂岩本町');
ok($zip->set_number('0895313')->is_valid_number, '北海道中川郡豊頃町茂岩栄町');
ok($zip->set_number('0895314')->is_valid_number, '北海道中川郡豊頃町茂岩末広町');
ok($zip->set_number('0895315')->is_valid_number, '北海道中川郡豊頃町茂岩');
ok($zip->set_number('0895461')->is_valid_number, '北海道中川郡豊頃町大津元町');
ok($zip->set_number('0895462')->is_valid_number, '北海道中川郡豊頃町大津幸町');
ok($zip->set_number('0895463')->is_valid_number, '北海道中川郡豊頃町大津寿町');
ok($zip->set_number('0895464')->is_valid_number, '北海道中川郡豊頃町大津港町');
ok($zip->set_number('0895465')->is_valid_number, '北海道中川郡豊頃町大津');
ok($zip->set_number('0895466')->is_valid_number, '北海道中川郡豊頃町長節');
ok($zip->set_number('0895541')->is_valid_number, '北海道十勝郡浦幌町吉野');
ok($zip->set_number('0895542')->is_valid_number, '北海道十勝郡浦幌町共栄');
ok($zip->set_number('0895543')->is_valid_number, '北海道十勝郡浦幌町平和');
ok($zip->set_number('0895544')->is_valid_number, '北海道十勝郡浦幌町統太');
ok($zip->set_number('0895545')->is_valid_number, '北海道十勝郡浦幌町養老');
ok($zip->set_number('0895546')->is_valid_number, '北海道十勝郡浦幌町朝日');
ok($zip->set_number('0895547')->is_valid_number, '北海道十勝郡浦幌町生剛');
ok($zip->set_number('0895548')->is_valid_number, '北海道十勝郡浦幌町十勝太');
ok($zip->set_number('0895551')->is_valid_number, '北海道十勝郡浦幌町愛牛');
ok($zip->set_number('0895552')->is_valid_number, '北海道十勝郡浦幌町豊北');
ok($zip->set_number('0895553')->is_valid_number, '北海道十勝郡浦幌町打内');
ok($zip->set_number('0895554')->is_valid_number, '北海道十勝郡浦幌町大平');
ok($zip->set_number('0895555')->is_valid_number, '北海道十勝郡浦幌町トイトッキ');
ok($zip->set_number('0895556')->is_valid_number, '北海道十勝郡浦幌町鼈奴');
ok($zip->set_number('0895557')->is_valid_number, '北海道十勝郡浦幌町ヌタベット');
ok($zip->set_number('0895558')->is_valid_number, '北海道十勝郡浦幌町昆布刈石(30番地)');
ok($zip->set_number('0895600')->is_valid_number, '北海道十勝郡浦幌町以下に掲載がない場合');
ok($zip->set_number('0895601')->is_valid_number, '北海道十勝郡浦幌町宝町');
ok($zip->set_number('0895602')->is_valid_number, '北海道十勝郡浦幌町末広町');
ok($zip->set_number('0895603')->is_valid_number, '北海道十勝郡浦幌町本町');
ok($zip->set_number('0895604')->is_valid_number, '北海道十勝郡浦幌町栄町');
ok($zip->set_number('0895605')->is_valid_number, '北海道十勝郡浦幌町緑町');
ok($zip->set_number('0895606')->is_valid_number, '北海道十勝郡浦幌町住吉町');
ok($zip->set_number('0895607')->is_valid_number, '北海道十勝郡浦幌町材木町');
ok($zip->set_number('0895608')->is_valid_number, '北海道十勝郡浦幌町西町');
ok($zip->set_number('0895611')->is_valid_number, '北海道十勝郡浦幌町寿町');
ok($zip->set_number('0895612')->is_valid_number, '北海道十勝郡浦幌町東山町');
ok($zip->set_number('0895613')->is_valid_number, '北海道十勝郡浦幌町幸町');
ok($zip->set_number('0895614')->is_valid_number, '北海道十勝郡浦幌町桜町');
ok($zip->set_number('0895615')->is_valid_number, '北海道十勝郡浦幌町新町');
ok($zip->set_number('0895617')->is_valid_number, '北海道十勝郡浦幌町光南');
ok($zip->set_number('0895617')->is_valid_number, '北海道十勝郡浦幌町南町');
ok($zip->set_number('0895621')->is_valid_number, '北海道十勝郡浦幌町北町');
ok($zip->set_number('0895622')->is_valid_number, '北海道十勝郡浦幌町北栄');
ok($zip->set_number('0895631')->is_valid_number, '北海道十勝郡浦幌町瀬多来');
ok($zip->set_number('0895632')->is_valid_number, '北海道十勝郡浦幌町留真');
ok($zip->set_number('0895633')->is_valid_number, '北海道十勝郡浦幌町常豊');
ok($zip->set_number('0895633')->is_valid_number, '北海道十勝郡浦幌町常室');
ok($zip->set_number('0895633')->is_valid_number, '北海道十勝郡浦幌町福山');
ok($zip->set_number('0895633')->is_valid_number, '北海道十勝郡浦幌町円山');
ok($zip->set_number('0895634')->is_valid_number, '北海道十勝郡浦幌町帯富');
ok($zip->set_number('0895634')->is_valid_number, '北海道十勝郡浦幌町時和');
ok($zip->set_number('0895635')->is_valid_number, '北海道十勝郡浦幌町静内');
ok($zip->set_number('0895636')->is_valid_number, '北海道十勝郡浦幌町千歳町');
ok($zip->set_number('0895636')->is_valid_number, '北海道十勝郡浦幌町万年');
ok($zip->set_number('0895637')->is_valid_number, '北海道十勝郡浦幌町稲穂');
ok($zip->set_number('0895638')->is_valid_number, '北海道十勝郡浦幌町幾栄');
ok($zip->set_number('0895638')->is_valid_number, '北海道十勝郡浦幌町幾千世');
ok($zip->set_number('0895865')->is_valid_number, '北海道十勝郡浦幌町厚内(全域)');
ok($zip->set_number('0895866')->is_valid_number, '北海道十勝郡浦幌町上厚内');
ok($zip->set_number('0895867')->is_valid_number, '北海道十勝郡浦幌町オコッペ');
ok($zip->set_number('0895868')->is_valid_number, '北海道十勝郡浦幌町昆布刈石(3番地)');
ok($zip->set_number('0895869')->is_valid_number, '北海道十勝郡浦幌町チプネオコッペ');
ok($zip->set_number('0900000')->is_valid_number, '北海道北見市以下に掲載がない場合');
ok($zip->set_number('0900001')->is_valid_number, '北海道北見市小泉');
ok($zip->set_number('0900002')->is_valid_number, '北海道北見市昭和');
ok($zip->set_number('0900003')->is_valid_number, '北海道北見市仁頃町');
ok($zip->set_number('0900004')->is_valid_number, '北海道北見市北陽');
ok($zip->set_number('0900005')->is_valid_number, '北海道北見市大和');
ok($zip->set_number('0900006')->is_valid_number, '北海道北見市上仁頃');
ok($zip->set_number('0900007')->is_valid_number, '北海道北見市美里');
ok($zip->set_number('0900008')->is_valid_number, '北海道北見市大正');
ok($zip->set_number('0900011')->is_valid_number, '北海道北見市曙町');
ok($zip->set_number('0900012')->is_valid_number, '北海道北見市並木町');
ok($zip->set_number('0900013')->is_valid_number, '北海道北見市柏陽町');
ok($zip->set_number('0900014')->is_valid_number, '北海道北見市文京町');
ok($zip->set_number('0900015')->is_valid_number, '北海道北見市公園町');
ok($zip->set_number('0900016')->is_valid_number, '北海道北見市大町');
ok($zip->set_number('0900017')->is_valid_number, '北海道北見市高砂町');
ok($zip->set_number('0900018')->is_valid_number, '北海道北見市青葉町');
ok($zip->set_number('0900019')->is_valid_number, '北海道北見市三楽町');
ok($zip->set_number('0900020')->is_valid_number, '北海道北見市大通東');
ok($zip->set_number('0900021')->is_valid_number, '北海道北見市北一条東');
ok($zip->set_number('0900022')->is_valid_number, '北海道北見市北二条東');
ok($zip->set_number('0900023')->is_valid_number, '北海道北見市北三条東');
ok($zip->set_number('0900024')->is_valid_number, '北海道北見市北四条東');
ok($zip->set_number('0900025')->is_valid_number, '北海道北見市北五条東');
ok($zip->set_number('0900026')->is_valid_number, '北海道北見市北六条東');
ok($zip->set_number('0900027')->is_valid_number, '北海道北見市北七条東');
ok($zip->set_number('0900028')->is_valid_number, '北海道北見市北八条東');
ok($zip->set_number('0900029')->is_valid_number, '北海道北見市北九条東');
ok($zip->set_number('0900030')->is_valid_number, '北海道北見市北十条東');
ok($zip->set_number('0900031')->is_valid_number, '北海道北見市北十一条東');
ok($zip->set_number('0900032')->is_valid_number, '北海道北見市三住町');
ok($zip->set_number('0900033')->is_valid_number, '北海道北見市番場町');
ok($zip->set_number('0900034')->is_valid_number, '北海道北見市中央町');
ok($zip->set_number('0900035')->is_valid_number, '北海道北見市北斗町');
ok($zip->set_number('0900036')->is_valid_number, '北海道北見市幸町');
ok($zip->set_number('0900037')->is_valid_number, '北海道北見市山下町');
ok($zip->set_number('0900040')->is_valid_number, '北海道北見市大通西');
ok($zip->set_number('0900041')->is_valid_number, '北海道北見市北一条西');
ok($zip->set_number('0900042')->is_valid_number, '北海道北見市北二条西');
ok($zip->set_number('0900043')->is_valid_number, '北海道北見市北三条西');
ok($zip->set_number('0900044')->is_valid_number, '北海道北見市北四条西');
ok($zip->set_number('0900045')->is_valid_number, '北海道北見市北五条西');
ok($zip->set_number('0900046')->is_valid_number, '北海道北見市北六条西');
ok($zip->set_number('0900047')->is_valid_number, '北海道北見市北七条西');
ok($zip->set_number('0900048')->is_valid_number, '北海道北見市北八条西');
ok($zip->set_number('0900051')->is_valid_number, '北海道北見市高栄東町');
ok($zip->set_number('0900052')->is_valid_number, '北海道北見市北進町');
ok($zip->set_number('0900053')->is_valid_number, '北海道北見市桂町');
ok($zip->set_number('0900054')->is_valid_number, '北海道北見市双葉町');
ok($zip->set_number('0900055')->is_valid_number, '北海道北見市緑町');
ok($zip->set_number('0900056')->is_valid_number, '北海道北見市卸町');
ok($zip->set_number('0900057')->is_valid_number, '北海道北見市若葉');
ok($zip->set_number('0900058')->is_valid_number, '北海道北見市高栄西町');
ok($zip->set_number('0900061')->is_valid_number, '北海道北見市東陵町');
ok($zip->set_number('0900063')->is_valid_number, '北海道北見市清見町');
ok($zip->set_number('0900064')->is_valid_number, '北海道北見市美芳町');
ok($zip->set_number('0900065')->is_valid_number, '北海道北見市寿町');
ok($zip->set_number('0900066')->is_valid_number, '北海道北見市花月町');
ok($zip->set_number('0900067')->is_valid_number, '北海道北見市緑ケ丘');
ok($zip->set_number('0900068')->is_valid_number, '北海道北見市美山町南');
ok($zip->set_number('0900069')->is_valid_number, '北海道北見市美山町東');
ok($zip->set_number('0900070')->is_valid_number, '北海道北見市美山町西');
ok($zip->set_number('0900801')->is_valid_number, '北海道北見市春光町');
ok($zip->set_number('0900802')->is_valid_number, '北海道北見市田端町');
ok($zip->set_number('0900803')->is_valid_number, '北海道北見市朝日町');
ok($zip->set_number('0900804')->is_valid_number, '北海道北見市桜町');
ok($zip->set_number('0900805')->is_valid_number, '北海道北見市清月町');
ok($zip->set_number('0900806')->is_valid_number, '北海道北見市南町');
ok($zip->set_number('0900807')->is_valid_number, '北海道北見市川東');
ok($zip->set_number('0900808')->is_valid_number, '北海道北見市若松');
ok($zip->set_number('0900810')->is_valid_number, '北海道北見市ひかり野');
ok($zip->set_number('0900811')->is_valid_number, '北海道北見市泉町');
ok($zip->set_number('0900812')->is_valid_number, '北海道北見市南仲町');
ok($zip->set_number('0900813')->is_valid_number, '北海道北見市中ノ島町');
ok($zip->set_number('0900814')->is_valid_number, '北海道北見市光葉町');
ok($zip->set_number('0900815')->is_valid_number, '北海道北見市新生町');
ok($zip->set_number('0900816')->is_valid_number, '北海道北見市花園町');
ok($zip->set_number('0900817')->is_valid_number, '北海道北見市常盤町');
ok($zip->set_number('0900818')->is_valid_number, '北海道北見市本町');
ok($zip->set_number('0900821')->is_valid_number, '北海道北見市川沿町');
ok($zip->set_number('0900822')->is_valid_number, '北海道北見市北央町');
ok($zip->set_number('0900823')->is_valid_number, '北海道北見市広明町');
ok($zip->set_number('0900824')->is_valid_number, '北海道北見市北光');
ok($zip->set_number('0900825')->is_valid_number, '北海道北見市無加川町');
ok($zip->set_number('0900826')->is_valid_number, '北海道北見市末広町');
ok($zip->set_number('0900827')->is_valid_number, '北海道北見市錦町');
ok($zip->set_number('0900831')->is_valid_number, '北海道北見市西富町');
ok($zip->set_number('0900832')->is_valid_number, '北海道北見市栄町');
ok($zip->set_number('0900833')->is_valid_number, '北海道北見市とん田東町');
ok($zip->set_number('0900834')->is_valid_number, '北海道北見市とん田西町');
ok($zip->set_number('0900835')->is_valid_number, '北海道北見市光西町');
ok($zip->set_number('0900836')->is_valid_number, '北海道北見市東三輪');
ok($zip->set_number('0900837')->is_valid_number, '北海道北見市中央三輪');
ok($zip->set_number('0900838')->is_valid_number, '北海道北見市西三輪');
ok($zip->set_number('0910001')->is_valid_number, '北海道北見市留辺蘂町元町');
ok($zip->set_number('0910002')->is_valid_number, '北海道北見市留辺蘂町東町');
ok($zip->set_number('0910003')->is_valid_number, '北海道北見市留辺蘂町仲町');
ok($zip->set_number('0910004')->is_valid_number, '北海道北見市留辺蘂町上町');
ok($zip->set_number('0910007')->is_valid_number, '北海道北見市留辺蘂町富岡');
ok($zip->set_number('0910008')->is_valid_number, '北海道北見市留辺蘂町宮下町');
ok($zip->set_number('0910011')->is_valid_number, '北海道北見市留辺蘂町泉');
ok($zip->set_number('0910016')->is_valid_number, '北海道北見市留辺蘂町丸山');
ok($zip->set_number('0910017')->is_valid_number, '北海道北見市留辺蘂町瑞穂');
ok($zip->set_number('0910018')->is_valid_number, '北海道北見市留辺蘂町花園');
ok($zip->set_number('0910021')->is_valid_number, '北海道北見市留辺蘂町金華');
ok($zip->set_number('0910022')->is_valid_number, '北海道北見市留辺蘂町旭東');
ok($zip->set_number('0910023')->is_valid_number, '北海道北見市留辺蘂町旭中央');
ok($zip->set_number('0910024')->is_valid_number, '北海道北見市留辺蘂町旭南');
ok($zip->set_number('0910025')->is_valid_number, '北海道北見市留辺蘂町旭北');
ok($zip->set_number('0910026')->is_valid_number, '北海道北見市留辺蘂町旭公園');
ok($zip->set_number('0910027')->is_valid_number, '北海道北見市留辺蘂町旭西');
ok($zip->set_number('0910028')->is_valid_number, '北海道北見市留辺蘂町旭3区');
ok($zip->set_number('0910029')->is_valid_number, '北海道北見市留辺蘂町旭1区');
ok($zip->set_number('0910031')->is_valid_number, '北海道北見市留辺蘂町大富');
ok($zip->set_number('0910032')->is_valid_number, '北海道北見市留辺蘂町豊金');
ok($zip->set_number('0910033')->is_valid_number, '北海道北見市留辺蘂町栄町');
ok($zip->set_number('0910151')->is_valid_number, '北海道北見市留辺蘂町昭栄');
ok($zip->set_number('0910153')->is_valid_number, '北海道北見市留辺蘂町松山');
ok($zip->set_number('0910154')->is_valid_number, '北海道北見市留辺蘂町平里');
ok($zip->set_number('0910155')->is_valid_number, '北海道北見市留辺蘂町大和');
ok($zip->set_number('0910156')->is_valid_number, '北海道北見市留辺蘂町川北');
ok($zip->set_number('0910157')->is_valid_number, '北海道北見市留辺蘂町花丘');
ok($zip->set_number('0910161')->is_valid_number, '北海道北見市留辺蘂町厚和');
ok($zip->set_number('0910162')->is_valid_number, '北海道北見市留辺蘂町富士見');
ok($zip->set_number('0910163')->is_valid_number, '北海道北見市留辺蘂町滝の湯');
ok($zip->set_number('0910170')->is_valid_number, '北海道北見市留辺蘂町温根湯温泉');
ok($zip->set_number('0910471')->is_valid_number, '北海道常呂郡佐呂間町大成');
ok($zip->set_number('0910472')->is_valid_number, '北海道常呂郡佐呂間町栄');
ok($zip->set_number('0910473')->is_valid_number, '北海道常呂郡佐呂間町共立');
ok($zip->set_number('0910551')->is_valid_number, '北海道常呂郡佐呂間町若佐');
ok($zip->set_number('0910552')->is_valid_number, '北海道常呂郡佐呂間町富丘');
ok($zip->set_number('0910553')->is_valid_number, '北海道常呂郡佐呂間町朝日');
ok($zip->set_number('0910554')->is_valid_number, '北海道常呂郡佐呂間町武士');
ok($zip->set_number('0910555')->is_valid_number, '北海道常呂郡佐呂間町中園');
ok($zip->set_number('0910556')->is_valid_number, '北海道常呂郡佐呂間町啓生');
ok($zip->set_number('0910557')->is_valid_number, '北海道常呂郡佐呂間町川西');
ok($zip->set_number('0910558')->is_valid_number, '北海道常呂郡佐呂間町栃木');
ok($zip->set_number('0920000')->is_valid_number, '北海道網走郡美幌町以下に掲載がない場合');
ok($zip->set_number('0920001')->is_valid_number, '北海道網走郡美幌町高野');
ok($zip->set_number('0920002')->is_valid_number, '北海道網走郡美幌町美禽');
ok($zip->set_number('0920003')->is_valid_number, '北海道網走郡美幌町鳥里');
ok($zip->set_number('0920004')->is_valid_number, '北海道網走郡美幌町仲町');
ok($zip->set_number('0920005')->is_valid_number, '北海道網走郡美幌町野崎(その他)');
ok($zip->set_number('0920006')->is_valid_number, '北海道網走郡美幌町昭野');
ok($zip->set_number('0920007')->is_valid_number, '北海道網走郡美幌町豊岡');
ok($zip->set_number('0920011')->is_valid_number, '北海道網走郡美幌町東町');
ok($zip->set_number('0920012')->is_valid_number, '北海道網走郡美幌町栄町');
ok($zip->set_number('0920013')->is_valid_number, '北海道網走郡美幌町美芳');
ok($zip->set_number('0920014')->is_valid_number, '北海道網走郡美幌町美里');
ok($zip->set_number('0920015')->is_valid_number, '北海道網走郡美幌町新町');
ok($zip->set_number('0920016')->is_valid_number, '北海道網走郡美幌町瑞治');
ok($zip->set_number('0920017')->is_valid_number, '北海道網走郡美幌町報徳');
ok($zip->set_number('0920018')->is_valid_number, '北海道網走郡美幌町田中');
ok($zip->set_number('0920021')->is_valid_number, '北海道網走郡美幌町日並');
ok($zip->set_number('0920022')->is_valid_number, '北海道網走郡美幌町古梅');
ok($zip->set_number('0920023')->is_valid_number, '北海道網走郡美幌町豊富');
ok($zip->set_number('0920024')->is_valid_number, '北海道網走郡美幌町福住');
ok($zip->set_number('0920025')->is_valid_number, '北海道網走郡美幌町駒生(その他)');
ok($zip->set_number('0920026')->is_valid_number, '北海道網走郡美幌町都橋');
ok($zip->set_number('0920027')->is_valid_number, '北海道網走郡美幌町稲美');
ok($zip->set_number('0920030')->is_valid_number, '北海道網走郡美幌町美富(その他)');
ok($zip->set_number('0920031')->is_valid_number, '北海道網走郡美幌町大通南');
ok($zip->set_number('0920032')->is_valid_number, '北海道網走郡美幌町西一条南');
ok($zip->set_number('0920033')->is_valid_number, '北海道網走郡美幌町西二条南');
ok($zip->set_number('0920041')->is_valid_number, '北海道網走郡美幌町東一条南');
ok($zip->set_number('0920042')->is_valid_number, '北海道網走郡美幌町東二条南');
ok($zip->set_number('0920043')->is_valid_number, '北海道網走郡美幌町東三条南');
ok($zip->set_number('0920044')->is_valid_number, '北海道網走郡美幌町東四条南');
ok($zip->set_number('0920050')->is_valid_number, '北海道網走郡美幌町大通北');
ok($zip->set_number('0920051')->is_valid_number, '北海道網走郡美幌町東一条北');
ok($zip->set_number('0920052')->is_valid_number, '北海道網走郡美幌町東二条北');
ok($zip->set_number('0920053')->is_valid_number, '北海道網走郡美幌町東三条北');
ok($zip->set_number('0920061')->is_valid_number, '北海道網走郡美幌町西一条北');
ok($zip->set_number('0920062')->is_valid_number, '北海道網走郡美幌町西二条北');
ok($zip->set_number('0920063')->is_valid_number, '北海道網走郡美幌町元町');
ok($zip->set_number('0920064')->is_valid_number, '北海道網走郡美幌町青葉');
ok($zip->set_number('0920065')->is_valid_number, '北海道網走郡美幌町青山南');
ok($zip->set_number('0920066')->is_valid_number, '北海道網走郡美幌町青山北');
ok($zip->set_number('0920067')->is_valid_number, '北海道網走郡美幌町三橋南');
ok($zip->set_number('0920068')->is_valid_number, '北海道網走郡美幌町三橋町');
ok($zip->set_number('0920069')->is_valid_number, '北海道網走郡美幌町日の出');
ok($zip->set_number('0920171')->is_valid_number, '北海道網走郡美幌町美富(127~151、183~579番地)');
ok($zip->set_number('0920173')->is_valid_number, '北海道網走郡美幌町美和');
ok($zip->set_number('0920174')->is_valid_number, '北海道網走郡美幌町栄森');
ok($zip->set_number('0920175')->is_valid_number, '北海道網走郡美幌町駒生(268番地)');
ok($zip->set_number('0920176')->is_valid_number, '北海道網走郡美幌町野崎(103、122番地)');
ok($zip->set_number('0920181')->is_valid_number, '北海道網走郡美幌町上町');
ok($zip->set_number('0920183')->is_valid_number, '北海道網走郡美幌町豊幌');
ok($zip->set_number('0920184')->is_valid_number, '北海道網走郡美幌町登栄');
ok($zip->set_number('0920200')->is_valid_number, '北海道網走郡津別町以下に掲載がない場合');
ok($zip->set_number('0920201')->is_valid_number, '北海道網走郡津別町最上');
ok($zip->set_number('0920203')->is_valid_number, '北海道網走郡津別町達美');
ok($zip->set_number('0920205')->is_valid_number, '北海道網走郡津別町岩富');
ok($zip->set_number('0920206')->is_valid_number, '北海道網走郡津別町活汲');
ok($zip->set_number('0920207')->is_valid_number, '北海道網走郡津別町東岡');
ok($zip->set_number('0920211')->is_valid_number, '北海道網走郡津別町西三条');
ok($zip->set_number('0920212')->is_valid_number, '北海道網走郡津別町緑町');
ok($zip->set_number('0920213')->is_valid_number, '北海道網走郡津別町西四条');
ok($zip->set_number('0920214')->is_valid_number, '北海道網走郡津別町西二条');
ok($zip->set_number('0920215')->is_valid_number, '北海道網走郡津別町一条通');
ok($zip->set_number('0920216')->is_valid_number, '北海道網走郡津別町東二条');
ok($zip->set_number('0920217')->is_valid_number, '北海道網走郡津別町東三条');
ok($zip->set_number('0920218')->is_valid_number, '北海道網走郡津別町東四条');
ok($zip->set_number('0920221')->is_valid_number, '北海道網走郡津別町高台');
ok($zip->set_number('0920222')->is_valid_number, '北海道網走郡津別町上里');
ok($zip->set_number('0920223')->is_valid_number, '北海道網走郡津別町美都');
ok($zip->set_number('0920224')->is_valid_number, '北海道網走郡津別町豊永');
ok($zip->set_number('0920225')->is_valid_number, '北海道網走郡津別町共和');
ok($zip->set_number('0920231')->is_valid_number, '北海道網走郡津別町大通');
ok($zip->set_number('0920232')->is_valid_number, '北海道網走郡津別町新町');
ok($zip->set_number('0920233')->is_valid_number, '北海道網走郡津別町柏町');
ok($zip->set_number('0920234')->is_valid_number, '北海道網走郡津別町旭町');
ok($zip->set_number('0920235')->is_valid_number, '北海道網走郡津別町幸町');
ok($zip->set_number('0920236')->is_valid_number, '北海道網走郡津別町本町');
ok($zip->set_number('0920351')->is_valid_number, '北海道網走郡津別町本岐');
ok($zip->set_number('0920352')->is_valid_number, '北海道網走郡津別町木樋');
ok($zip->set_number('0920353')->is_valid_number, '北海道網走郡津別町二又');
ok($zip->set_number('0920354')->is_valid_number, '北海道網走郡津別町双葉');
ok($zip->set_number('0920355')->is_valid_number, '北海道網走郡津別町恩根');
ok($zip->set_number('0920356')->is_valid_number, '北海道網走郡津別町栄');
ok($zip->set_number('0920357')->is_valid_number, '北海道網走郡津別町大昭');
ok($zip->set_number('0920358')->is_valid_number, '北海道網走郡津別町沼沢');
ok($zip->set_number('0920361')->is_valid_number, '北海道網走郡津別町相生');
ok($zip->set_number('0920362')->is_valid_number, '北海道網走郡津別町布川');
ok($zip->set_number('0930000')->is_valid_number, '北海道網走市以下に掲載がない場合');
ok($zip->set_number('0930001')->is_valid_number, '北海道網走市南一条東');
ok($zip->set_number('0930002')->is_valid_number, '北海道網走市南二条東');
ok($zip->set_number('0930003')->is_valid_number, '北海道網走市南三条東');
ok($zip->set_number('0930004')->is_valid_number, '北海道網走市南四条東');
ok($zip->set_number('0930005')->is_valid_number, '北海道網走市南五条東');
ok($zip->set_number('0930006')->is_valid_number, '北海道網走市南六条東');
ok($zip->set_number('0930007')->is_valid_number, '北海道網走市南七条東');
ok($zip->set_number('0930008')->is_valid_number, '北海道網走市南八条東');
ok($zip->set_number('0930009')->is_valid_number, '北海道網走市南九条東');
ok($zip->set_number('0930010')->is_valid_number, '北海道網走市南十条東');
ok($zip->set_number('0930011')->is_valid_number, '北海道網走市南一条西');
ok($zip->set_number('0930012')->is_valid_number, '北海道網走市南二条西');
ok($zip->set_number('0930013')->is_valid_number, '北海道網走市南三条西');
ok($zip->set_number('0930014')->is_valid_number, '北海道網走市南四条西');
ok($zip->set_number('0930015')->is_valid_number, '北海道網走市南五条西');
ok($zip->set_number('0930016')->is_valid_number, '北海道網走市南六条西');
ok($zip->set_number('0930017')->is_valid_number, '北海道網走市南七条西');
ok($zip->set_number('0930018')->is_valid_number, '北海道網走市南八条西');
ok($zip->set_number('0930019')->is_valid_number, '北海道網走市南九条西');
ok($zip->set_number('0930020')->is_valid_number, '北海道網走市南十条西');
ok($zip->set_number('0930021')->is_valid_number, '北海道網走市南十一条西');
ok($zip->set_number('0930022')->is_valid_number, '北海道網走市南十二条西');
ok($zip->set_number('0930023')->is_valid_number, '北海道網走市南十三条西');
ok($zip->set_number('0930024')->is_valid_number, '北海道網走市南十四条西');
ok($zip->set_number('0930031')->is_valid_number, '北海道網走市台町');
ok($zip->set_number('0930032')->is_valid_number, '北海道網走市港町');
ok($zip->set_number('0930033')->is_valid_number, '北海道網走市駒場北');
ok($zip->set_number('0930034')->is_valid_number, '北海道網走市つくしケ丘');
ok($zip->set_number('0930035')->is_valid_number, '北海道網走市駒場南');
ok($zip->set_number('0930041')->is_valid_number, '北海道網走市桂町');
ok($zip->set_number('0930042')->is_valid_number, '北海道網走市潮見');
ok($zip->set_number('0930043')->is_valid_number, '北海道網走市錦町');
ok($zip->set_number('0930044')->is_valid_number, '北海道網走市天都山');
ok($zip->set_number('0930045')->is_valid_number, '北海道網走市大曲');
ok($zip->set_number('0930046')->is_valid_number, '北海道網走市新町');
ok($zip->set_number('0930051')->is_valid_number, '北海道網走市北一条東');
ok($zip->set_number('0930052')->is_valid_number, '北海道網走市北二条東');
ok($zip->set_number('0930053')->is_valid_number, '北海道網走市北三条東');
ok($zip->set_number('0930054')->is_valid_number, '北海道網走市北四条東');
ok($zip->set_number('0930055')->is_valid_number, '北海道網走市北五条東');
ok($zip->set_number('0930056')->is_valid_number, '北海道網走市北六条東');
ok($zip->set_number('0930057')->is_valid_number, '北海道網走市北七条東');
ok($zip->set_number('0930058')->is_valid_number, '北海道網走市北八条東');
ok($zip->set_number('0930059')->is_valid_number, '北海道網走市北九条東');
ok($zip->set_number('0930060')->is_valid_number, '北海道網走市北十条東');
ok($zip->set_number('0930061')->is_valid_number, '北海道網走市北十一条東');
ok($zip->set_number('0930062')->is_valid_number, '北海道網走市北十二条東');
ok($zip->set_number('0930071')->is_valid_number, '北海道網走市北一条西');
ok($zip->set_number('0930072')->is_valid_number, '北海道網走市北二条西');
ok($zip->set_number('0930073')->is_valid_number, '北海道網走市北三条西');
ok($zip->set_number('0930074')->is_valid_number, '北海道網走市北四条西');
ok($zip->set_number('0930075')->is_valid_number, '北海道網走市北五条西');
ok($zip->set_number('0930076')->is_valid_number, '北海道網走市北六条西');
ok($zip->set_number('0930077')->is_valid_number, '北海道網走市北七条西');
ok($zip->set_number('0930078')->is_valid_number, '北海道網走市北八条西');
ok($zip->set_number('0930079')->is_valid_number, '北海道網走市北九条西');
ok($zip->set_number('0930080')->is_valid_number, '北海道網走市北十条西');
ok($zip->set_number('0930081')->is_valid_number, '北海道網走市北十一条西');
ok($zip->set_number('0930082')->is_valid_number, '北海道網走市北十二条西');
ok($zip->set_number('0930083')->is_valid_number, '北海道網走市海岸町');
ok($zip->set_number('0930084')->is_valid_number, '北海道網走市向陽ケ丘');
ok($zip->set_number('0930085')->is_valid_number, '北海道網走市明治');
ok($zip->set_number('0930086')->is_valid_number, '北海道網走市二ツ岩');
ok($zip->set_number('0930087')->is_valid_number, '北海道網走市美岬');
ok($zip->set_number('0930088')->is_valid_number, '北海道網走市三眺');
ok($zip->set_number('0930089')->is_valid_number, '北海道網走市緑町');
ok($zip->set_number('0930090')->is_valid_number, '北海道網走市文化');
ok($zip->set_number('0930131')->is_valid_number, '北海道網走市能取港町');
ok($zip->set_number('0930132')->is_valid_number, '北海道網走市二見ケ岡');
ok($zip->set_number('0930133')->is_valid_number, '北海道網走市嘉多山');
ok($zip->set_number('0930134')->is_valid_number, '北海道網走市越歳');
ok($zip->set_number('0930135')->is_valid_number, '北海道網走市卯原内');
ok($zip->set_number('0930136')->is_valid_number, '北海道網走市平和');
ok($zip->set_number('0930202')->is_valid_number, '北海道北見市常呂町東浜');
ok($zip->set_number('0930210')->is_valid_number, '北海道北見市常呂町常呂');
ok($zip->set_number('0930213')->is_valid_number, '北海道北見市常呂町土佐');
ok($zip->set_number('0930214')->is_valid_number, '北海道北見市常呂町共立');
ok($zip->set_number('0930215')->is_valid_number, '北海道北見市常呂町岐阜');
ok($zip->set_number('0930216')->is_valid_number, '北海道北見市常呂町栄浦');
ok($zip->set_number('0930241')->is_valid_number, '北海道網走市能取');
ok($zip->set_number('0930331')->is_valid_number, '北海道北見市常呂町豊川');
ok($zip->set_number('0930332')->is_valid_number, '北海道北見市常呂町富丘');
ok($zip->set_number('0930333')->is_valid_number, '北海道北見市常呂町福山');
ok($zip->set_number('0930334')->is_valid_number, '北海道北見市常呂町日吉');
ok($zip->set_number('0930335')->is_valid_number, '北海道北見市常呂町吉野');
ok($zip->set_number('0930336')->is_valid_number, '北海道北見市常呂町登');
ok($zip->set_number('0930421')->is_valid_number, '北海道常呂郡佐呂間町浪速');
ok($zip->set_number('0930422')->is_valid_number, '北海道常呂郡佐呂間町幌岩');
ok($zip->set_number('0930423')->is_valid_number, '北海道常呂郡佐呂間町浜佐呂間');
ok($zip->set_number('0930424')->is_valid_number, '北海道常呂郡佐呂間町仁倉');
ok($zip->set_number('0930500')->is_valid_number, '北海道常呂郡佐呂間町以下に掲載がない場合');
ok($zip->set_number('0930501')->is_valid_number, '北海道常呂郡佐呂間町宮前町');
ok($zip->set_number('0930502')->is_valid_number, '北海道常呂郡佐呂間町永代町');
ok($zip->set_number('0930503')->is_valid_number, '北海道常呂郡佐呂間町幸町');
ok($zip->set_number('0930504')->is_valid_number, '北海道常呂郡佐呂間町西富');
ok($zip->set_number('0930505')->is_valid_number, '北海道常呂郡佐呂間町北');
ok($zip->set_number('0930506')->is_valid_number, '北海道常呂郡佐呂間町富武士');
ok($zip->set_number('0930507')->is_valid_number, '北海道常呂郡佐呂間町東');
ok($zip->set_number('0930508')->is_valid_number, '北海道常呂郡佐呂間町知来');
ok($zip->set_number('0930532')->is_valid_number, '北海道常呂郡佐呂間町若里');
ok($zip->set_number('0930651')->is_valid_number, '北海道紋別郡湧別町計呂地');
ok($zip->set_number('0930652')->is_valid_number, '北海道紋別郡湧別町志撫子');
ok($zip->set_number('0930731')->is_valid_number, '北海道紋別郡湧別町芭露');
ok($zip->set_number('0930732')->is_valid_number, '北海道紋別郡湧別町上芭露');
ok($zip->set_number('0930733')->is_valid_number, '北海道紋別郡湧別町西芭露');
ok($zip->set_number('0930734')->is_valid_number, '北海道紋別郡湧別町東芭露');
ok($zip->set_number('0930735')->is_valid_number, '北海道紋別郡湧別町福島(536番地)');
ok($zip->set_number('0940000')->is_valid_number, '北海道紋別市以下に掲載がない場合');
ok($zip->set_number('0940001')->is_valid_number, '北海道紋別市北浜町');
ok($zip->set_number('0940002')->is_valid_number, '北海道紋別市真砂町');
ok($zip->set_number('0940003')->is_valid_number, '北海道紋別市弁天町');
ok($zip->set_number('0940004')->is_valid_number, '北海道紋別市本町');
ok($zip->set_number('0940005')->is_valid_number, '北海道紋別市幸町');
ok($zip->set_number('0940006')->is_valid_number, '北海道紋別市潮見町');
ok($zip->set_number('0940007')->is_valid_number, '北海道紋別市落石町');
ok($zip->set_number('0940011')->is_valid_number, '北海道紋別市港町');
ok($zip->set_number('0940012')->is_valid_number, '北海道紋別市新港町');
ok($zip->set_number('0940013')->is_valid_number, '北海道紋別市南が丘町');
ok($zip->set_number('0940014')->is_valid_number, '北海道紋別市緑町');
ok($zip->set_number('0940015')->is_valid_number, '北海道紋別市花園町');
ok($zip->set_number('0940021')->is_valid_number, '北海道紋別市大山町');
ok($zip->set_number('0940022')->is_valid_number, '北海道紋別市新生');
ok($zip->set_number('0940023')->is_valid_number, '北海道紋別市元紋別');
ok($zip->set_number('0940024')->is_valid_number, '北海道紋別市藻別');
ok($zip->set_number('0940025')->is_valid_number, '北海道紋別市上藻別');
ok($zip->set_number('0940026')->is_valid_number, '北海道紋別市鴻之舞');
ok($zip->set_number('0940027')->is_valid_number, '北海道紋別市上鴻之舞');
ok($zip->set_number('0940031')->is_valid_number, '北海道紋別市海洋公園');
ok($zip->set_number('0950000')->is_valid_number, '北海道士別市以下に掲載がない場合');
ok($zip->set_number('0950001')->is_valid_number, '北海道士別市東一条北');
ok($zip->set_number('0950002')->is_valid_number, '北海道士別市東二条北');
ok($zip->set_number('0950003')->is_valid_number, '北海道士別市東三条北');
ok($zip->set_number('0950004')->is_valid_number, '北海道士別市東四条北');
ok($zip->set_number('0950005')->is_valid_number, '北海道士別市東五条北');
ok($zip->set_number('0950006')->is_valid_number, '北海道士別市東六条北');
ok($zip->set_number('0950007')->is_valid_number, '北海道士別市東七条北');
ok($zip->set_number('0950008')->is_valid_number, '北海道士別市東八条北');
ok($zip->set_number('0950011')->is_valid_number, '北海道士別市東一条');
ok($zip->set_number('0950012')->is_valid_number, '北海道士別市東二条');
ok($zip->set_number('0950013')->is_valid_number, '北海道士別市東三条');
ok($zip->set_number('0950014')->is_valid_number, '北海道士別市東四条');
ok($zip->set_number('0950015')->is_valid_number, '北海道士別市東五条');
ok($zip->set_number('0950016')->is_valid_number, '北海道士別市東六条');
ok($zip->set_number('0950017')->is_valid_number, '北海道士別市東七条');
ok($zip->set_number('0950018')->is_valid_number, '北海道士別市東八条');
ok($zip->set_number('0950019')->is_valid_number, '北海道士別市大通東');
ok($zip->set_number('0950021')->is_valid_number, '北海道士別市西一条');
ok($zip->set_number('0950022')->is_valid_number, '北海道士別市西二条');
ok($zip->set_number('0950023')->is_valid_number, '北海道士別市西三条');
ok($zip->set_number('0950024')->is_valid_number, '北海道士別市西四条');
ok($zip->set_number('0950025')->is_valid_number, '北海道士別市西五条');
ok($zip->set_number('0950029')->is_valid_number, '北海道士別市大通西');
ok($zip->set_number('0950031')->is_valid_number, '北海道士別市西一条北');
ok($zip->set_number('0950032')->is_valid_number, '北海道士別市西二条北');
ok($zip->set_number('0950033')->is_valid_number, '北海道士別市西三条北');
ok($zip->set_number('0950034')->is_valid_number, '北海道士別市西四条北');
ok($zip->set_number('0950035')->is_valid_number, '北海道士別市西五条北');
ok($zip->set_number('0950039')->is_valid_number, '北海道士別市大通北');
ok($zip->set_number('0950041')->is_valid_number, '北海道士別市東九条');
ok($zip->set_number('0950042')->is_valid_number, '北海道士別市東十条');
ok($zip->set_number('0950043')->is_valid_number, '北海道士別市九十九町');
ok($zip->set_number('0950044')->is_valid_number, '北海道士別市東山町');
ok($zip->set_number('0950045')->is_valid_number, '北海道士別市東丘');
ok($zip->set_number('0950046')->is_valid_number, '北海道士別市南町東');
ok($zip->set_number('0950047')->is_valid_number, '北海道士別市南町西');
ok($zip->set_number('0950048')->is_valid_number, '北海道士別市東十一条');
ok($zip->set_number('0950051')->is_valid_number, '北海道士別市北町');
ok($zip->set_number('0950052')->is_valid_number, '北海道士別市学田');
ok($zip->set_number('0950053')->is_valid_number, '北海道士別市新学田');
ok($zip->set_number('0950054')->is_valid_number, '北海道士別市不動町');
ok($zip->set_number('0950055')->is_valid_number, '北海道士別市南士別町');
ok($zip->set_number('0950056')->is_valid_number, '北海道士別市西士別町');
ok($zip->set_number('0950061')->is_valid_number, '北海道士別市下士別町');
ok($zip->set_number('0950062')->is_valid_number, '北海道士別市武徳町');
ok($zip->set_number('0950063')->is_valid_number, '北海道士別市中士別町');
ok($zip->set_number('0950064')->is_valid_number, '北海道士別市川西町');
ok($zip->set_number('0950181')->is_valid_number, '北海道士別市温根別町');
ok($zip->set_number('0950182')->is_valid_number, '北海道士別市温根別町伊文');
ok($zip->set_number('0950183')->is_valid_number, '北海道士別市温根別町北静川');
ok($zip->set_number('0950371')->is_valid_number, '北海道士別市上士別町');
ok($zip->set_number('0950401')->is_valid_number, '北海道士別市朝日町中央');
ok($zip->set_number('0950402')->is_valid_number, '北海道士別市朝日町登和里');
ok($zip->set_number('0950403')->is_valid_number, '北海道士別市朝日町岩尾内');
ok($zip->set_number('0950404')->is_valid_number, '北海道士別市朝日町茂志利');
ok($zip->set_number('0950405')->is_valid_number, '北海道士別市朝日町三栄');
ok($zip->set_number('0950406')->is_valid_number, '北海道士別市朝日町南朝日');
ok($zip->set_number('0960000')->is_valid_number, '北海道名寄市以下に掲載がない場合');
ok($zip->set_number('0960001')->is_valid_number, '北海道名寄市東一条南');
ok($zip->set_number('0960002')->is_valid_number, '北海道名寄市東二条南');
ok($zip->set_number('0960003')->is_valid_number, '北海道名寄市東三条南');
ok($zip->set_number('0960004')->is_valid_number, '北海道名寄市東四条南');
ok($zip->set_number('0960005')->is_valid_number, '北海道名寄市東五条南');
ok($zip->set_number('0960006')->is_valid_number, '北海道名寄市東六条南');
ok($zip->set_number('0960007')->is_valid_number, '北海道名寄市東七条南');
ok($zip->set_number('0960008')->is_valid_number, '北海道名寄市東八条南');
ok($zip->set_number('0960009')->is_valid_number, '北海道名寄市東九条南');
ok($zip->set_number('0960010')->is_valid_number, '北海道名寄市大通南');
ok($zip->set_number('0960011')->is_valid_number, '北海道名寄市西一条南');
ok($zip->set_number('0960012')->is_valid_number, '北海道名寄市西二条南');
ok($zip->set_number('0960013')->is_valid_number, '北海道名寄市西三条南');
ok($zip->set_number('0960014')->is_valid_number, '北海道名寄市西四条南');
ok($zip->set_number('0960015')->is_valid_number, '北海道名寄市西五条南');
ok($zip->set_number('0960016')->is_valid_number, '北海道名寄市西六条南');
ok($zip->set_number('0960017')->is_valid_number, '北海道名寄市西七条南');
ok($zip->set_number('0960018')->is_valid_number, '北海道名寄市西八条南');
ok($zip->set_number('0960019')->is_valid_number, '北海道名寄市西九条南');
ok($zip->set_number('0960020')->is_valid_number, '北海道名寄市西十条南');
ok($zip->set_number('0960021')->is_valid_number, '北海道名寄市西十一条南');
ok($zip->set_number('0960022')->is_valid_number, '北海道名寄市西十二条南');
ok($zip->set_number('0960023')->is_valid_number, '北海道名寄市西十三条南');
ok($zip->set_number('0960024')->is_valid_number, '北海道名寄市西十四条南');
ok($zip->set_number('0960025')->is_valid_number, '北海道名寄市西十五条南');
ok($zip->set_number('0960030')->is_valid_number, '北海道名寄市大通北');
ok($zip->set_number('0960031')->is_valid_number, '北海道名寄市西一条北');
ok($zip->set_number('0960032')->is_valid_number, '北海道名寄市西二条北');
ok($zip->set_number('0960033')->is_valid_number, '北海道名寄市西三条北');
ok($zip->set_number('0960034')->is_valid_number, '北海道名寄市西四条北');
ok($zip->set_number('0960035')->is_valid_number, '北海道名寄市西五条北');
ok($zip->set_number('0960036')->is_valid_number, '北海道名寄市西六条北');
ok($zip->set_number('0960037')->is_valid_number, '北海道名寄市西七条北');
ok($zip->set_number('0960038')->is_valid_number, '北海道名寄市西八条北');
ok($zip->set_number('0960039')->is_valid_number, '北海道名寄市西九条北');
ok($zip->set_number('0960040')->is_valid_number, '北海道名寄市西十条北');
ok($zip->set_number('0960041')->is_valid_number, '北海道名寄市西十一条北');
ok($zip->set_number('0960042')->is_valid_number, '北海道名寄市西十二条北');
ok($zip->set_number('0960043')->is_valid_number, '北海道名寄市西十三条北');
ok($zip->set_number('0960051')->is_valid_number, '北海道名寄市東一条北');
ok($zip->set_number('0960052')->is_valid_number, '北海道名寄市東二条北');
ok($zip->set_number('0960053')->is_valid_number, '北海道名寄市東三条北');
ok($zip->set_number('0960054')->is_valid_number, '北海道名寄市東四条北');
ok($zip->set_number('0960055')->is_valid_number, '北海道名寄市東五条北');
ok($zip->set_number('0960056')->is_valid_number, '北海道名寄市東六条北');
ok($zip->set_number('0960061')->is_valid_number, '北海道名寄市朝日');
ok($zip->set_number('0960062')->is_valid_number, '北海道名寄市日彰');
ok($zip->set_number('0960063')->is_valid_number, '北海道名寄市緑丘');
ok($zip->set_number('0960064')->is_valid_number, '北海道名寄市旭東');
ok($zip->set_number('0960065')->is_valid_number, '北海道名寄市大橋');
ok($zip->set_number('0960066')->is_valid_number, '北海道名寄市日進');
ok($zip->set_number('0960071')->is_valid_number, '北海道名寄市徳田');
ok($zip->set_number('0960072')->is_valid_number, '北海道名寄市豊栄');
ok($zip->set_number('0960073')->is_valid_number, '北海道名寄市共和');
ok($zip->set_number('0960074')->is_valid_number, '北海道名寄市弥生');
ok($zip->set_number('0960075')->is_valid_number, '北海道名寄市曙');
ok($zip->set_number('0960076')->is_valid_number, '北海道名寄市砺波');
ok($zip->set_number('0960077')->is_valid_number, '北海道名寄市瑞穂');
ok($zip->set_number('0960078')->is_valid_number, '北海道名寄市内淵');
ok($zip->set_number('0970000')->is_valid_number, '北海道稚内市以下に掲載がない場合');
ok($zip->set_number('0970001')->is_valid_number, '北海道稚内市末広');
ok($zip->set_number('0970002')->is_valid_number, '北海道稚内市潮見');
ok($zip->set_number('0970003')->is_valid_number, '北海道稚内市こまどり');
ok($zip->set_number('0970004')->is_valid_number, '北海道稚内市緑');
ok($zip->set_number('0970005')->is_valid_number, '北海道稚内市大黒');
ok($zip->set_number('0970006')->is_valid_number, '北海道稚内市新港町');
ok($zip->set_number('0970007')->is_valid_number, '北海道稚内市新末広');
ok($zip->set_number('0970011')->is_valid_number, '北海道稚内市はまなす');
ok($zip->set_number('0970012')->is_valid_number, '北海道稚内市富岡');
ok($zip->set_number('0970013')->is_valid_number, '北海道稚内市若葉台');
ok($zip->set_number('0970014')->is_valid_number, '北海道稚内市新光町');
ok($zip->set_number('0970015')->is_valid_number, '北海道稚内市朝日');
ok($zip->set_number('0970016')->is_valid_number, '北海道稚内市萩見');
ok($zip->set_number('0970017')->is_valid_number, '北海道稚内市栄');
ok($zip->set_number('0970021')->is_valid_number, '北海道稚内市港');
ok($zip->set_number('0970022')->is_valid_number, '北海道稚内市中央');
ok($zip->set_number('0970023')->is_valid_number, '北海道稚内市開運');
ok($zip->set_number('0970024')->is_valid_number, '北海道稚内市宝来');
ok($zip->set_number('0970025')->is_valid_number, '北海道稚内市恵比須');
ok($zip->set_number('0970026')->is_valid_number, '北海道稚内市ノシャップ');
ok($zip->set_number('0970027')->is_valid_number, '北海道稚内市富士見');
ok($zip->set_number('0970035')->is_valid_number, '北海道稚内市抜海村(バッカイ)');
ok($zip->set_number('0970036')->is_valid_number, '北海道稚内市抜海村(クトネベツ)');
ok($zip->set_number('0970037')->is_valid_number, '北海道稚内市西浜');
ok($zip->set_number('0970100')->is_valid_number, '北海道利尻郡利尻富士町以下に掲載がない場合');
ok($zip->set_number('0970101')->is_valid_number, '北海道利尻郡利尻富士町鴛泊');
ok($zip->set_number('0970211')->is_valid_number, '北海道利尻郡利尻富士町鬼脇');
ok($zip->set_number('0970311')->is_valid_number, '北海道利尻郡利尻町仙法志');
ok($zip->set_number('0970400')->is_valid_number, '北海道利尻郡利尻町以下に掲載がない場合');
ok($zip->set_number('0970401')->is_valid_number, '北海道利尻郡利尻町沓形');
ok($zip->set_number('0971111')->is_valid_number, '北海道礼文郡礼文町船泊村(その他)');
ok($zip->set_number('0971200')->is_valid_number, '北海道礼文郡礼文町以下に掲載がない場合');
ok($zip->set_number('0971201')->is_valid_number, '北海道礼文郡礼文町香深村');
ok($zip->set_number('0971202')->is_valid_number, '北海道礼文郡礼文町船泊村(ウヱンナイ)');
ok($zip->set_number('0980100')->is_valid_number, '北海道上川郡和寒町以下に掲載がない場合');
ok($zip->set_number('0980101')->is_valid_number, '北海道上川郡和寒町日ノ出');
ok($zip->set_number('0980102')->is_valid_number, '北海道上川郡和寒町大成');
ok($zip->set_number('0980103')->is_valid_number, '北海道上川郡和寒町北原');
ok($zip->set_number('0980104')->is_valid_number, '北海道上川郡和寒町松岡');
ok($zip->set_number('0980111')->is_valid_number, '北海道上川郡和寒町三笠');
ok($zip->set_number('0980112')->is_valid_number, '北海道上川郡和寒町三和');
ok($zip->set_number('0980113')->is_valid_number, '北海道上川郡和寒町菊野');
ok($zip->set_number('0980114')->is_valid_number, '北海道上川郡和寒町西和');
ok($zip->set_number('0980115')->is_valid_number, '北海道上川郡和寒町福原');
ok($zip->set_number('0980121')->is_valid_number, '北海道上川郡和寒町川西');
ok($zip->set_number('0980122')->is_valid_number, '北海道上川郡和寒町中和');
ok($zip->set_number('0980123')->is_valid_number, '北海道上川郡和寒町東丘');
ok($zip->set_number('0980124')->is_valid_number, '北海道上川郡和寒町南丘');
ok($zip->set_number('0980125')->is_valid_number, '北海道上川郡和寒町塩狩');
ok($zip->set_number('0980126')->is_valid_number, '北海道上川郡和寒町朝日');
ok($zip->set_number('0980131')->is_valid_number, '北海道上川郡和寒町南町');
ok($zip->set_number('0980132')->is_valid_number, '北海道上川郡和寒町西町');
ok($zip->set_number('0980133')->is_valid_number, '北海道上川郡和寒町北町');
ok($zip->set_number('0980134')->is_valid_number, '北海道上川郡和寒町東町');
ok($zip->set_number('0980135')->is_valid_number, '北海道上川郡和寒町東和');
ok($zip->set_number('0980300')->is_valid_number, '北海道上川郡剣淵町以下に掲載がない場合');
ok($zip->set_number('0980331')->is_valid_number, '北海道上川郡剣淵町西町');
ok($zip->set_number('0980332')->is_valid_number, '北海道上川郡剣淵町緑町');
ok($zip->set_number('0980333')->is_valid_number, '北海道上川郡剣淵町元町');
ok($zip->set_number('0980334')->is_valid_number, '北海道上川郡剣淵町屯田町');
ok($zip->set_number('0980335')->is_valid_number, '北海道上川郡剣淵町南桜町');
ok($zip->set_number('0980336')->is_valid_number, '北海道上川郡剣淵町旭町');
ok($zip->set_number('0980337')->is_valid_number, '北海道上川郡剣淵町西岡町');
ok($zip->set_number('0980338')->is_valid_number, '北海道上川郡剣淵町仲町');
ok($zip->set_number('0980339')->is_valid_number, '北海道上川郡剣淵町西原町');
ok($zip->set_number('0980341')->is_valid_number, '北海道上川郡剣淵町東町');
ok($zip->set_number('0980342')->is_valid_number, '北海道上川郡剣淵町藤本町');
ok($zip->set_number('0980475')->is_valid_number, '北海道士別市多寄町');
ok($zip->set_number('0980501')->is_valid_number, '北海道名寄市風連町豊里');
ok($zip->set_number('0980502')->is_valid_number, '北海道名寄市風連町北栄町');
ok($zip->set_number('0980503')->is_valid_number, '北海道名寄市風連町大町');
ok($zip->set_number('0980504')->is_valid_number, '北海道名寄市風連町本町');
ok($zip->set_number('0980505')->is_valid_number, '北海道名寄市風連町南町');
ok($zip->set_number('0980506')->is_valid_number, '北海道名寄市風連町仲町');
ok($zip->set_number('0980507')->is_valid_number, '北海道名寄市風連町西町');
ok($zip->set_number('0980508')->is_valid_number, '北海道名寄市風連町瑞生');
ok($zip->set_number('0980509')->is_valid_number, '北海道名寄市風連町西風連');
ok($zip->set_number('0980511')->is_valid_number, '北海道名寄市風連町新生町');
ok($zip->set_number('0980512')->is_valid_number, '北海道名寄市風連町東風連');
ok($zip->set_number('0980513')->is_valid_number, '北海道名寄市風連町池の上');
ok($zip->set_number('0980514')->is_valid_number, '北海道名寄市風連町旭');
ok($zip->set_number('0980515')->is_valid_number, '北海道名寄市風連町中央');
ok($zip->set_number('0980516')->is_valid_number, '北海道名寄市風連町緑町');
ok($zip->set_number('0980631')->is_valid_number, '北海道名寄市風連町日進');
ok($zip->set_number('0980632')->is_valid_number, '北海道名寄市風連町東生');
ok($zip->set_number('0981200')->is_valid_number, '北海道上川郡下川町以下に掲載がない場合');
ok($zip->set_number('0981201')->is_valid_number, '北海道上川郡下川町旭町');
ok($zip->set_number('0981202')->is_valid_number, '北海道上川郡下川町緑町');
ok($zip->set_number('0981203')->is_valid_number, '北海道上川郡下川町共栄町');
ok($zip->set_number('0981204')->is_valid_number, '北海道上川郡下川町南町');
ok($zip->set_number('0981205')->is_valid_number, '北海道上川郡下川町西町');
ok($zip->set_number('0981206')->is_valid_number, '北海道上川郡下川町幸町');
ok($zip->set_number('0981207')->is_valid_number, '北海道上川郡下川町錦町');
ok($zip->set_number('0981211')->is_valid_number, '北海道上川郡下川町珊瑠');
ok($zip->set_number('0981212')->is_valid_number, '北海道上川郡下川町北町');
ok($zip->set_number('0981213')->is_valid_number, '北海道上川郡下川町三の橋');
ok($zip->set_number('0981214')->is_valid_number, '北海道上川郡下川町渓和');
ok($zip->set_number('0981215')->is_valid_number, '北海道上川郡下川町班渓');
ok($zip->set_number('0981216')->is_valid_number, '北海道上川郡下川町上名寄');
ok($zip->set_number('0981331')->is_valid_number, '北海道上川郡下川町一の橋');
ok($zip->set_number('0981332')->is_valid_number, '北海道上川郡下川町二の橋');
ok($zip->set_number('0981421')->is_valid_number, '北海道紋別郡西興部村上興部');
ok($zip->set_number('0981422')->is_valid_number, '北海道紋別郡西興部村東興');
ok($zip->set_number('0981423')->is_valid_number, '北海道紋別郡西興部村札滑');
ok($zip->set_number('0981424')->is_valid_number, '北海道紋別郡西興部村奥興部');
ok($zip->set_number('0981500')->is_valid_number, '北海道紋別郡西興部村以下に掲載がない場合');
ok($zip->set_number('0981501')->is_valid_number, '北海道紋別郡西興部村西興部');
ok($zip->set_number('0981502')->is_valid_number, '北海道紋別郡西興部村六興');
ok($zip->set_number('0981503')->is_valid_number, '北海道紋別郡西興部村中興部');
ok($zip->set_number('0981504')->is_valid_number, '北海道紋別郡西興部村忍路子');
ok($zip->set_number('0981505')->is_valid_number, '北海道紋別郡西興部村上藻');
ok($zip->set_number('0981506')->is_valid_number, '北海道紋別郡西興部村中藻');
ok($zip->set_number('0981600')->is_valid_number, '北海道紋別郡興部町以下に掲載がない場合');
ok($zip->set_number('0981601')->is_valid_number, '北海道紋別郡興部町興部(元町)');
ok($zip->set_number('0981602')->is_valid_number, '北海道紋別郡興部町興部(浜町)');
ok($zip->set_number('0981603')->is_valid_number, '北海道紋別郡興部町興部(東町)');
ok($zip->set_number('0981604')->is_valid_number, '北海道紋別郡興部町興部(春日町)');
ok($zip->set_number('0981605')->is_valid_number, '北海道紋別郡興部町興部(緑ケ丘)');
ok($zip->set_number('0981606')->is_valid_number, '北海道紋別郡興部町興部(栄町)');
ok($zip->set_number('0981607')->is_valid_number, '北海道紋別郡興部町興部(旭町)');
ok($zip->set_number('0981611')->is_valid_number, '北海道紋別郡興部町興部(泉町)');
ok($zip->set_number('0981612')->is_valid_number, '北海道紋別郡興部町興部(新泉町)');
ok($zip->set_number('0981613')->is_valid_number, '北海道紋別郡興部町興部(新町)');
ok($zip->set_number('0981614')->is_valid_number, '北海道紋別郡興部町興部(幸町)');
ok($zip->set_number('0981615')->is_valid_number, '北海道紋別郡興部町興部(仲町)');
ok($zip->set_number('0981616')->is_valid_number, '北海道紋別郡興部町興部(本町)');
ok($zip->set_number('0981621')->is_valid_number, '北海道紋別郡興部町秋里');
ok($zip->set_number('0981622')->is_valid_number, '北海道紋別郡興部町北興');
ok($zip->set_number('0981623')->is_valid_number, '北海道紋別郡興部町興部(宮下町)');
ok($zip->set_number('0981624')->is_valid_number, '北海道紋別郡興部町宇津');
ok($zip->set_number('0981700')->is_valid_number, '北海道紋別郡雄武町以下に掲載がない場合');
ok($zip->set_number('0981701')->is_valid_number, '北海道紋別郡雄武町北雄武');
ok($zip->set_number('0981702')->is_valid_number, '北海道紋別郡雄武町雄武');
ok($zip->set_number('0981703')->is_valid_number, '北海道紋別郡雄武町沢木');
ok($zip->set_number('0981704')->is_valid_number, '北海道紋別郡雄武町上沢木');
ok($zip->set_number('0981705')->is_valid_number, '北海道紋別郡雄武町南雄武');
ok($zip->set_number('0981706')->is_valid_number, '北海道紋別郡雄武町中雄武');
ok($zip->set_number('0981707')->is_valid_number, '北海道紋別郡雄武町上雄武');
ok($zip->set_number('0981708')->is_valid_number, '北海道紋別郡雄武町上幌内');
ok($zip->set_number('0981821')->is_valid_number, '北海道紋別郡雄武町北幌内');
ok($zip->set_number('0981821')->is_valid_number, '北海道紋別郡雄武町中幌内');
ok($zip->set_number('0981821')->is_valid_number, '北海道紋別郡雄武町幌内');
ok($zip->set_number('0981941')->is_valid_number, '北海道紋別郡興部町沙留');
ok($zip->set_number('0981942')->is_valid_number, '北海道紋別郡興部町富丘');
ok($zip->set_number('0981943')->is_valid_number, '北海道紋別郡興部町住吉');
ok($zip->set_number('0981944')->is_valid_number, '北海道紋別郡興部町豊野');
ok($zip->set_number('0982181')->is_valid_number, '北海道名寄市智恵文');
ok($zip->set_number('0982200')->is_valid_number, '北海道中川郡美深町以下に掲載がない場合');
ok($zip->set_number('0982201')->is_valid_number, '北海道中川郡美深町泉');
ok($zip->set_number('0982202')->is_valid_number, '北海道中川郡美深町玉川');
ok($zip->set_number('0982203')->is_valid_number, '北海道中川郡美深町六郷');
ok($zip->set_number('0982204')->is_valid_number, '北海道中川郡美深町川西');
ok($zip->set_number('0982205')->is_valid_number, '北海道中川郡美深町美深');
ok($zip->set_number('0982206')->is_valid_number, '北海道中川郡美深町菊丘');
ok($zip->set_number('0982207')->is_valid_number, '北海道中川郡美深町辺渓');
ok($zip->set_number('0982208')->is_valid_number, '北海道中川郡美深町仁宇布');
ok($zip->set_number('0982211')->is_valid_number, '北海道中川郡美深町富岡');
ok($zip->set_number('0982212')->is_valid_number, '北海道中川郡美深町班渓');
ok($zip->set_number('0982213')->is_valid_number, '北海道中川郡美深町吉野');
ok($zip->set_number('0982214')->is_valid_number, '北海道中川郡美深町敷島');
ok($zip->set_number('0982220')->is_valid_number, '北海道中川郡美深町大通北');
ok($zip->set_number('0982221')->is_valid_number, '北海道中川郡美深町東一条北');
ok($zip->set_number('0982222')->is_valid_number, '北海道中川郡美深町東二条北');
ok($zip->set_number('0982223')->is_valid_number, '北海道中川郡美深町東三条北');
ok($zip->set_number('0982224')->is_valid_number, '北海道中川郡美深町東四条北');
ok($zip->set_number('0982225')->is_valid_number, '北海道中川郡美深町東五条北');
ok($zip->set_number('0982226')->is_valid_number, '北海道中川郡美深町東六条北');
ok($zip->set_number('0982227')->is_valid_number, '北海道中川郡美深町北町');
ok($zip->set_number('0982230')->is_valid_number, '北海道中川郡美深町大通南');
ok($zip->set_number('0982231')->is_valid_number, '北海道中川郡美深町東一条南');
ok($zip->set_number('0982232')->is_valid_number, '北海道中川郡美深町東二条南');
ok($zip->set_number('0982233')->is_valid_number, '北海道中川郡美深町東三条南');
ok($zip->set_number('0982234')->is_valid_number, '北海道中川郡美深町東四条南');
ok($zip->set_number('0982235')->is_valid_number, '北海道中川郡美深町南町');
ok($zip->set_number('0982236')->is_valid_number, '北海道中川郡美深町東六条南');
ok($zip->set_number('0982237')->is_valid_number, '北海道中川郡美深町若松町');
ok($zip->set_number('0982238')->is_valid_number, '北海道中川郡美深町開運町');
ok($zip->set_number('0982241')->is_valid_number, '北海道中川郡美深町西一条南');
ok($zip->set_number('0982242')->is_valid_number, '北海道中川郡美深町西二条南');
ok($zip->set_number('0982243')->is_valid_number, '北海道中川郡美深町西三条南');
ok($zip->set_number('0982251')->is_valid_number, '北海道中川郡美深町西一条北');
ok($zip->set_number('0982252')->is_valid_number, '北海道中川郡美深町西町');
ok($zip->set_number('0982253')->is_valid_number, '北海道中川郡美深町西三条北');
ok($zip->set_number('0982361')->is_valid_number, '北海道中川郡美深町恩根内');
ok($zip->set_number('0982362')->is_valid_number, '北海道中川郡美深町大手');
ok($zip->set_number('0982363')->is_valid_number, '北海道中川郡美深町小車');
ok($zip->set_number('0982364')->is_valid_number, '北海道中川郡美深町報徳');
ok($zip->set_number('0982365')->is_valid_number, '北海道中川郡美深町西里');
ok($zip->set_number('0982366')->is_valid_number, '北海道中川郡美深町紋穂内');
ok($zip->set_number('0982367')->is_valid_number, '北海道中川郡美深町楠');
ok($zip->set_number('0982368')->is_valid_number, '北海道中川郡美深町清水');
ok($zip->set_number('0982500')->is_valid_number, '北海道中川郡音威子府村以下に掲載がない場合');
ok($zip->set_number('0982501')->is_valid_number, '北海道中川郡音威子府村音威子府');
ok($zip->set_number('0982502')->is_valid_number, '北海道中川郡音威子府村咲来');
ok($zip->set_number('0982621')->is_valid_number, '北海道中川郡中川町共和');
ok($zip->set_number('0982622')->is_valid_number, '北海道中川郡中川町佐久');
ok($zip->set_number('0982623')->is_valid_number, '北海道中川郡中川町富和');
ok($zip->set_number('0982624')->is_valid_number, '北海道中川郡中川町豊里');
ok($zip->set_number('0982625')->is_valid_number, '北海道中川郡中川町安川');
ok($zip->set_number('0982626')->is_valid_number, '北海道中川郡中川町安川(3)');
ok($zip->set_number('0982800')->is_valid_number, '北海道中川郡中川町以下に掲載がない場合');
ok($zip->set_number('0982801')->is_valid_number, '北海道中川郡中川町歌内');
ok($zip->set_number('0982802')->is_valid_number, '北海道中川郡中川町中川');
ok($zip->set_number('0982803')->is_valid_number, '北海道中川郡中川町琴平');
ok($zip->set_number('0982804')->is_valid_number, '北海道中川郡中川町大富');
ok($zip->set_number('0982805')->is_valid_number, '北海道中川郡中川町誉');
ok($zip->set_number('0982806')->is_valid_number, '北海道中川郡中川町国府');
ok($zip->set_number('0982941')->is_valid_number, '北海道天塩郡幌延町上問寒');
ok($zip->set_number('0982942')->is_valid_number, '北海道天塩郡幌延町中問寒');
ok($zip->set_number('0982943')->is_valid_number, '北海道天塩郡幌延町問寒別');
ok($zip->set_number('0983131')->is_valid_number, '北海道天塩郡天塩町タツネウシ');
ok($zip->set_number('0983132')->is_valid_number, '北海道天塩郡天塩町東雄信内');
ok($zip->set_number('0983133')->is_valid_number, '北海道天塩郡天塩町オヌプナイ');
ok($zip->set_number('0983133')->is_valid_number, '北海道天塩郡天塩町雄信内');
ok($zip->set_number('0983134')->is_valid_number, '北海道天塩郡天塩町円山');
ok($zip->set_number('0983135')->is_valid_number, '北海道天塩郡天塩町東産士');
ok($zip->set_number('0983136')->is_valid_number, '北海道天塩郡天塩町下コクネップ');
ok($zip->set_number('0983141')->is_valid_number, '北海道天塩郡天塩町西雄信内');
ok($zip->set_number('0983142')->is_valid_number, '北海道天塩郡天塩町新成');
ok($zip->set_number('0983143')->is_valid_number, '北海道天塩郡天塩町泉源');
ok($zip->set_number('0983144')->is_valid_number, '北海道天塩郡天塩町男能富');
ok($zip->set_number('0983200')->is_valid_number, '北海道天塩郡幌延町以下に掲載がない場合');
ok($zip->set_number('0983201')->is_valid_number, '北海道天塩郡幌延町一条北');
ok($zip->set_number('0983202')->is_valid_number, '北海道天塩郡幌延町二条北');
ok($zip->set_number('0983203')->is_valid_number, '北海道天塩郡幌延町三条北');
ok($zip->set_number('0983204')->is_valid_number, '北海道天塩郡幌延町四条北');
ok($zip->set_number('0983205')->is_valid_number, '北海道天塩郡幌延町五条北');
ok($zip->set_number('0983206')->is_valid_number, '北海道天塩郡幌延町六条北');
ok($zip->set_number('0983207')->is_valid_number, '北海道天塩郡幌延町宮園町');
ok($zip->set_number('0983211')->is_valid_number, '北海道天塩郡幌延町一条南');
ok($zip->set_number('0983212')->is_valid_number, '北海道天塩郡幌延町二条南');
ok($zip->set_number('0983213')->is_valid_number, '北海道天塩郡幌延町三条南');
ok($zip->set_number('0983214')->is_valid_number, '北海道天塩郡幌延町四条南');
ok($zip->set_number('0983215')->is_valid_number, '北海道天塩郡幌延町五条南');
ok($zip->set_number('0983216')->is_valid_number, '北海道天塩郡幌延町六条南');
ok($zip->set_number('0983217')->is_valid_number, '北海道天塩郡幌延町元町');
ok($zip->set_number('0983221')->is_valid_number, '北海道天塩郡幌延町栄町');
ok($zip->set_number('0983222')->is_valid_number, '北海道天塩郡幌延町東町');
ok($zip->set_number('0983223')->is_valid_number, '北海道天塩郡幌延町幌延');
ok($zip->set_number('0983224')->is_valid_number, '北海道天塩郡幌延町北進');
ok($zip->set_number('0983225')->is_valid_number, '北海道天塩郡幌延町上幌延');
ok($zip->set_number('0983226')->is_valid_number, '北海道天塩郡幌延町開進');
ok($zip->set_number('0983227')->is_valid_number, '北海道天塩郡幌延町浜里');
ok($zip->set_number('0983228')->is_valid_number, '北海道天塩郡幌延町下沼');
ok($zip->set_number('0983251')->is_valid_number, '北海道天塩郡幌延町雄興');
ok($zip->set_number('0983300')->is_valid_number, '北海道天塩郡天塩町以下に掲載がない場合');
ok($zip->set_number('0983301')->is_valid_number, '北海道天塩郡天塩町山手通');
ok($zip->set_number('0983302')->is_valid_number, '北海道天塩郡天塩町山手裏通');
ok($zip->set_number('0983303')->is_valid_number, '北海道天塩郡天塩町新栄通');
ok($zip->set_number('0983304')->is_valid_number, '北海道天塩郡天塩町新地通');
ok($zip->set_number('0983305')->is_valid_number, '北海道天塩郡天塩町新開通');
ok($zip->set_number('0983306')->is_valid_number, '北海道天塩郡天塩町海岸通');
ok($zip->set_number('0983311')->is_valid_number, '北海道天塩郡天塩町産士');
ok($zip->set_number('0983312')->is_valid_number, '北海道天塩郡天塩町川口');
ok($zip->set_number('0983313')->is_valid_number, '北海道天塩郡天塩町作返');
ok($zip->set_number('0983314')->is_valid_number, '北海道天塩郡天塩町更岸');
ok($zip->set_number('0983315')->is_valid_number, '北海道天塩郡天塩町天塩');
ok($zip->set_number('0983316')->is_valid_number, '北海道天塩郡天塩町振老');
ok($zip->set_number('0983361')->is_valid_number, '北海道天塩郡遠別町北里(15号の沢)');
ok($zip->set_number('0983500')->is_valid_number, '北海道天塩郡遠別町以下に掲載がない場合');
ok($zip->set_number('0983501')->is_valid_number, '北海道天塩郡遠別町北里(その他)');
ok($zip->set_number('0983502')->is_valid_number, '北海道天塩郡遠別町清川');
ok($zip->set_number('0983503')->is_valid_number, '北海道天塩郡遠別町啓明');
ok($zip->set_number('0983504')->is_valid_number, '北海道天塩郡遠別町丸松');
ok($zip->set_number('0983511')->is_valid_number, '北海道天塩郡遠別町久光');
ok($zip->set_number('0983512')->is_valid_number, '北海道天塩郡遠別町中央');
ok($zip->set_number('0983521')->is_valid_number, '北海道天塩郡遠別町共栄');
ok($zip->set_number('0983522')->is_valid_number, '北海道天塩郡遠別町大成');
ok($zip->set_number('0983523')->is_valid_number, '北海道天塩郡遠別町東野');
ok($zip->set_number('0983531')->is_valid_number, '北海道天塩郡遠別町旭');
ok($zip->set_number('0983532')->is_valid_number, '北海道天塩郡遠別町歌越');
ok($zip->set_number('0983533')->is_valid_number, '北海道天塩郡遠別町金浦');
ok($zip->set_number('0983534')->is_valid_number, '北海道天塩郡遠別町富士見');
ok($zip->set_number('0983541')->is_valid_number, '北海道天塩郡遠別町北浜');
ok($zip->set_number('0983542')->is_valid_number, '北海道天塩郡遠別町幸和');
ok($zip->set_number('0983543')->is_valid_number, '北海道天塩郡遠別町本町');
ok($zip->set_number('0984100')->is_valid_number, '北海道天塩郡豊富町以下に掲載がない場合');
ok($zip->set_number('0984101')->is_valid_number, '北海道天塩郡豊富町福永');
ok($zip->set_number('0984102')->is_valid_number, '北海道天塩郡豊富町目梨別');
ok($zip->set_number('0984103')->is_valid_number, '北海道天塩郡豊富町有明');
ok($zip->set_number('0984104')->is_valid_number, '北海道天塩郡豊富町修徳');
ok($zip->set_number('0984105')->is_valid_number, '北海道天塩郡豊富町幌加');
ok($zip->set_number('0984106')->is_valid_number, '北海道天塩郡豊富町豊徳');
ok($zip->set_number('0984107')->is_valid_number, '北海道天塩郡豊富町稚咲内');
ok($zip->set_number('0984110')->is_valid_number, '北海道天塩郡豊富町大通り');
ok($zip->set_number('0984111')->is_valid_number, '北海道天塩郡豊富町西一条');
ok($zip->set_number('0984112')->is_valid_number, '北海道天塩郡豊富町西二条');
ok($zip->set_number('0984113')->is_valid_number, '北海道天塩郡豊富町西三条');
ok($zip->set_number('0984114')->is_valid_number, '北海道天塩郡豊富町西四条');
ok($zip->set_number('0984115')->is_valid_number, '北海道天塩郡豊富町西五条');
ok($zip->set_number('0984116')->is_valid_number, '北海道天塩郡豊富町西豊富');
ok($zip->set_number('0984117')->is_valid_number, '北海道天塩郡豊富町落合(その他)');
ok($zip->set_number('0984121')->is_valid_number, '北海道天塩郡豊富町東一条');
ok($zip->set_number('0984122')->is_valid_number, '北海道天塩郡豊富町東二条');
ok($zip->set_number('0984123')->is_valid_number, '北海道天塩郡豊富町東三条');
ok($zip->set_number('0984124')->is_valid_number, '北海道天塩郡豊富町東四条');
ok($zip->set_number('0984125')->is_valid_number, '北海道天塩郡豊富町東五条');
ok($zip->set_number('0984126')->is_valid_number, '北海道天塩郡豊富町東六条');
ok($zip->set_number('0984131')->is_valid_number, '北海道天塩郡豊富町東豊富');
ok($zip->set_number('0984132')->is_valid_number, '北海道天塩郡豊富町温泉');
ok($zip->set_number('0984133')->is_valid_number, '北海道天塩郡豊富町本流');
ok($zip->set_number('0984134')->is_valid_number, '北海道天塩郡豊富町豊幌');
ok($zip->set_number('0984135')->is_valid_number, '北海道天塩郡豊富町豊川');
ok($zip->set_number('0984136')->is_valid_number, '北海道天塩郡豊富町新生');
ok($zip->set_number('0984137')->is_valid_number, '北海道天塩郡豊富町徳満');
ok($zip->set_number('0984138')->is_valid_number, '北海道天塩郡豊富町駅前通');
ok($zip->set_number('0984139')->is_valid_number, '北海道天塩郡豊富町仲通り');
ok($zip->set_number('0984140')->is_valid_number, '北海道天塩郡豊富町停車場通');
ok($zip->set_number('0984141')->is_valid_number, '北海道天塩郡豊富町三条通り');
ok($zip->set_number('0984451')->is_valid_number, '北海道天塩郡豊富町兜沼');
ok($zip->set_number('0984455')->is_valid_number, '北海道天塩郡豊富町芦川');
ok($zip->set_number('0984456')->is_valid_number, '北海道天塩郡豊富町開源');
ok($zip->set_number('0984457')->is_valid_number, '北海道天塩郡豊富町沼向');
ok($zip->set_number('0984461')->is_valid_number, '北海道天塩郡豊富町瑞穂東');
ok($zip->set_number('0984462')->is_valid_number, '北海道天塩郡豊富町阿沙流');
ok($zip->set_number('0984463')->is_valid_number, '北海道天塩郡豊富町瑞穂南');
ok($zip->set_number('0984464')->is_valid_number, '北海道天塩郡豊富町豊栄');
ok($zip->set_number('0984465')->is_valid_number, '北海道天塩郡豊富町豊田');
ok($zip->set_number('0984466')->is_valid_number, '北海道天塩郡豊富町清明');
ok($zip->set_number('0984467')->is_valid_number, '北海道天塩郡豊富町豊里');
ok($zip->set_number('0984468')->is_valid_number, '北海道天塩郡豊富町落合(4468番地)');
ok($zip->set_number('0984581')->is_valid_number, '北海道稚内市抜海村(上勇知、下勇知、夕来、オネトマナイ)');
ok($zip->set_number('0984582')->is_valid_number, '北海道稚内市声問村(更喜苫内)');
ok($zip->set_number('0985101')->is_valid_number, '北海道枝幸郡中頓別町岩手');
ok($zip->set_number('0985102')->is_valid_number, '北海道枝幸郡中頓別町小頓別');
ok($zip->set_number('0985103')->is_valid_number, '北海道枝幸郡中頓別町秋田');
ok($zip->set_number('0985111')->is_valid_number, '北海道枝幸郡中頓別町上頓別');
ok($zip->set_number('0985112')->is_valid_number, '北海道枝幸郡中頓別町豊平');
ok($zip->set_number('0985113')->is_valid_number, '北海道枝幸郡中頓別町敏音知');
ok($zip->set_number('0985201')->is_valid_number, '北海道枝幸郡枝幸町歌登パンケナイ');
ok($zip->set_number('0985202')->is_valid_number, '北海道枝幸郡枝幸町歌登東歌登');
ok($zip->set_number('0985203')->is_valid_number, '北海道枝幸郡枝幸町歌登辺毛内');
ok($zip->set_number('0985204')->is_valid_number, '北海道枝幸郡枝幸町歌登南町');
ok($zip->set_number('0985205')->is_valid_number, '北海道枝幸郡枝幸町歌登桧垣町');
ok($zip->set_number('0985206')->is_valid_number, '北海道枝幸郡枝幸町歌登西町');
ok($zip->set_number('0985207')->is_valid_number, '北海道枝幸郡枝幸町歌登東町');
ok($zip->set_number('0985211')->is_valid_number, '北海道枝幸郡枝幸町歌登西歌登');
ok($zip->set_number('0985212')->is_valid_number, '北海道枝幸郡枝幸町歌登中央');
ok($zip->set_number('0985213')->is_valid_number, '北海道枝幸郡枝幸町歌登本幌別');
ok($zip->set_number('0985221')->is_valid_number, '北海道枝幸郡枝幸町歌登毛登別');
ok($zip->set_number('0985441')->is_valid_number, '北海道枝幸郡枝幸町歌登志美宇丹');
ok($zip->set_number('0985442')->is_valid_number, '北海道枝幸郡枝幸町歌登豊沃');
ok($zip->set_number('0985443')->is_valid_number, '北海道枝幸郡枝幸町歌登上徳志別');
ok($zip->set_number('0985444')->is_valid_number, '北海道枝幸郡枝幸町歌登大奮');
ok($zip->set_number('0985445')->is_valid_number, '北海道枝幸郡枝幸町歌登大曲');
ok($zip->set_number('0985500')->is_valid_number, '北海道枝幸郡中頓別町以下に掲載がない場合');
ok($zip->set_number('0985551')->is_valid_number, '北海道枝幸郡中頓別町中頓別');
ok($zip->set_number('0985552')->is_valid_number, '北海道枝幸郡中頓別町寿');
ok($zip->set_number('0985553')->is_valid_number, '北海道枝幸郡中頓別町弥生');
ok($zip->set_number('0985554')->is_valid_number, '北海道枝幸郡中頓別町旭台');
ok($zip->set_number('0985555')->is_valid_number, '北海道枝幸郡中頓別町豊泉');
ok($zip->set_number('0985561')->is_valid_number, '北海道枝幸郡中頓別町兵安');
ok($zip->set_number('0985562')->is_valid_number, '北海道枝幸郡中頓別町神崎');
ok($zip->set_number('0985563')->is_valid_number, '北海道枝幸郡中頓別町藤井');
ok($zip->set_number('0985564')->is_valid_number, '北海道枝幸郡中頓別町上駒');
ok($zip->set_number('0985565')->is_valid_number, '北海道枝幸郡中頓別町松音知');
ok($zip->set_number('0985700')->is_valid_number, '北海道枝幸郡浜頓別町以下に掲載がない場合');
ok($zip->set_number('0985701')->is_valid_number, '北海道枝幸郡浜頓別町栄和');
ok($zip->set_number('0985701')->is_valid_number, '北海道枝幸郡浜頓別町頓別');
ok($zip->set_number('0985702')->is_valid_number, '北海道枝幸郡浜頓別町豊牛');
ok($zip->set_number('0985702')->is_valid_number, '北海道枝幸郡浜頓別町豊寒別');
ok($zip->set_number('0985703')->is_valid_number, '北海道枝幸郡浜頓別町斜内');
ok($zip->set_number('0985703')->is_valid_number, '北海道枝幸郡浜頓別町豊浜');
ok($zip->set_number('0985704')->is_valid_number, '北海道枝幸郡浜頓別町中央北');
ok($zip->set_number('0985705')->is_valid_number, '北海道枝幸郡浜頓別町中央南');
ok($zip->set_number('0985711')->is_valid_number, '北海道枝幸郡浜頓別町北1条');
ok($zip->set_number('0985712')->is_valid_number, '北海道枝幸郡浜頓別町北2条');
ok($zip->set_number('0985713')->is_valid_number, '北海道枝幸郡浜頓別町北3条');
ok($zip->set_number('0985714')->is_valid_number, '北海道枝幸郡浜頓別町北4条');
ok($zip->set_number('0985717')->is_valid_number, '北海道枝幸郡浜頓別町浜頓別');
ok($zip->set_number('0985721')->is_valid_number, '北海道枝幸郡浜頓別町南1条');
ok($zip->set_number('0985722')->is_valid_number, '北海道枝幸郡浜頓別町南2条');
ok($zip->set_number('0985723')->is_valid_number, '北海道枝幸郡浜頓別町南3条');
ok($zip->set_number('0985725')->is_valid_number, '北海道枝幸郡浜頓別町大通');
ok($zip->set_number('0985734')->is_valid_number, '北海道枝幸郡浜頓別町日の出');
ok($zip->set_number('0985738')->is_valid_number, '北海道枝幸郡浜頓別町緑ケ丘');
ok($zip->set_number('0985739')->is_valid_number, '北海道枝幸郡浜頓別町クッチャロ湖畔');
ok($zip->set_number('0985741')->is_valid_number, '北海道枝幸郡浜頓別町旭ケ丘');
ok($zip->set_number('0985742')->is_valid_number, '北海道枝幸郡浜頓別町戸出');
ok($zip->set_number('0985743')->is_valid_number, '北海道枝幸郡浜頓別町楓');
ok($zip->set_number('0985744')->is_valid_number, '北海道枝幸郡浜頓別町宇曽丹');
ok($zip->set_number('0985745')->is_valid_number, '北海道枝幸郡浜頓別町常盤');
ok($zip->set_number('0985751')->is_valid_number, '北海道枝幸郡浜頓別町金ヶ丘');
ok($zip->set_number('0985752')->is_valid_number, '北海道枝幸郡浜頓別町下頓別');
ok($zip->set_number('0985753')->is_valid_number, '北海道枝幸郡浜頓別町高砂');
ok($zip->set_number('0985754')->is_valid_number, '北海道枝幸郡浜頓別町宇津内');
ok($zip->set_number('0985755')->is_valid_number, '北海道枝幸郡浜頓別町茂宇津内');
ok($zip->set_number('0985761')->is_valid_number, '北海道枝幸郡浜頓別町智福');
ok($zip->set_number('0985761')->is_valid_number, '北海道枝幸郡浜頓別町山軽');
ok($zip->set_number('0985762')->is_valid_number, '北海道枝幸郡浜頓別町ポン仁達内');
ok($zip->set_number('0985763')->is_valid_number, '北海道枝幸郡浜頓別町仁達内');
ok($zip->set_number('0985764')->is_valid_number, '北海道枝幸郡浜頓別町安別');
ok($zip->set_number('0985765')->is_valid_number, '北海道枝幸郡浜頓別町共和');
ok($zip->set_number('0985800')->is_valid_number, '北海道枝幸郡枝幸町以下に掲載がない場合');
ok($zip->set_number('0985801')->is_valid_number, '北海道枝幸郡枝幸町徳志別');
ok($zip->set_number('0985802')->is_valid_number, '北海道枝幸郡枝幸町岡島');
ok($zip->set_number('0985803')->is_valid_number, '北海道枝幸郡枝幸町下幌別');
ok($zip->set_number('0985804')->is_valid_number, '北海道枝幸郡枝幸町南浜町');
ok($zip->set_number('0985805')->is_valid_number, '北海道枝幸郡枝幸町幸町');
ok($zip->set_number('0985806')->is_valid_number, '北海道枝幸郡枝幸町梅ケ枝町');
ok($zip->set_number('0985807')->is_valid_number, '北海道枝幸郡枝幸町本町');
ok($zip->set_number('0985808')->is_valid_number, '北海道枝幸郡枝幸町新港町');
ok($zip->set_number('0985814')->is_valid_number, '北海道枝幸郡枝幸町岬町');
ok($zip->set_number('0985815')->is_valid_number, '北海道枝幸郡枝幸町問牧');
ok($zip->set_number('0985816')->is_valid_number, '北海道枝幸郡枝幸町目梨泊');
ok($zip->set_number('0985821')->is_valid_number, '北海道枝幸郡枝幸町栄町');
ok($zip->set_number('0985822')->is_valid_number, '北海道枝幸郡枝幸町北幸町');
ok($zip->set_number('0985823')->is_valid_number, '北海道枝幸郡枝幸町三笠町');
ok($zip->set_number('0985824')->is_valid_number, '北海道枝幸郡枝幸町北栄町');
ok($zip->set_number('0985825')->is_valid_number, '北海道枝幸郡枝幸町新栄町');
ok($zip->set_number('0985826')->is_valid_number, '北海道枝幸郡枝幸町北浜町');
ok($zip->set_number('0985827')->is_valid_number, '北海道枝幸郡枝幸町宇遠内');
ok($zip->set_number('0985951')->is_valid_number, '北海道枝幸郡枝幸町山臼');
ok($zip->set_number('0985952')->is_valid_number, '北海道枝幸郡枝幸町乙忠部');
ok($zip->set_number('0985953')->is_valid_number, '北海道枝幸郡枝幸町風烈布');
ok($zip->set_number('0985954')->is_valid_number, '北海道枝幸郡枝幸町上音標');
ok($zip->set_number('0985955')->is_valid_number, '北海道枝幸郡枝幸町音標');
ok($zip->set_number('0986101')->is_valid_number, '北海道宗谷郡猿払村浅茅野');
ok($zip->set_number('0986102')->is_valid_number, '北海道宗谷郡猿払村浅茅野台地');
ok($zip->set_number('0986103')->is_valid_number, '北海道宗谷郡猿払村狩別');
ok($zip->set_number('0986104')->is_valid_number, '北海道宗谷郡猿払村猿払');
ok($zip->set_number('0986105')->is_valid_number, '北海道宗谷郡猿払村浜猿払');
ok($zip->set_number('0986106')->is_valid_number, '北海道宗谷郡猿払村上猿払');
ok($zip->set_number('0986200')->is_valid_number, '北海道宗谷郡猿払村以下に掲載がない場合');
ok($zip->set_number('0986222')->is_valid_number, '北海道宗谷郡猿払村浜鬼志別');
ok($zip->set_number('0986225')->is_valid_number, '北海道宗谷郡猿払村芦野');
ok($zip->set_number('0986226')->is_valid_number, '北海道宗谷郡猿払村豊里');
ok($zip->set_number('0986228')->is_valid_number, '北海道宗谷郡猿払村小石');
ok($zip->set_number('0986231')->is_valid_number, '北海道宗谷郡猿払村鬼志別東町');
ok($zip->set_number('0986232')->is_valid_number, '北海道宗谷郡猿払村鬼志別西町');
ok($zip->set_number('0986233')->is_valid_number, '北海道宗谷郡猿払村鬼志別南町');
ok($zip->set_number('0986234')->is_valid_number, '北海道宗谷郡猿払村鬼志別北町');
ok($zip->set_number('0986341')->is_valid_number, '北海道宗谷郡猿払村知来別');
ok($zip->set_number('0986384')->is_valid_number, '北海道稚内市宗谷村(峰岡)');
ok($zip->set_number('0986385')->is_valid_number, '北海道稚内市宗谷村(東浦)');
ok($zip->set_number('0986561')->is_valid_number, '北海道稚内市声問村(樺岡)');
ok($zip->set_number('0986562')->is_valid_number, '北海道稚内市声問村(上声問)');
ok($zip->set_number('0986563')->is_valid_number, '北海道稚内市声問村(沼川)');
ok($zip->set_number('0986564')->is_valid_number, '北海道稚内市声問村(川西)');
ok($zip->set_number('0986565')->is_valid_number, '北海道稚内市声問村(曙)');
ok($zip->set_number('0986571')->is_valid_number, '北海道稚内市声問村(曲渕)');
ok($zip->set_number('0986572')->is_valid_number, '北海道稚内市声問村(開進)');
ok($zip->set_number('0986573')->is_valid_number, '北海道稚内市声問村(下豊別)');
ok($zip->set_number('0986574')->is_valid_number, '北海道稚内市声問村(上豊別)');
ok($zip->set_number('0986575')->is_valid_number, '北海道稚内市声問村(天興)');
ok($zip->set_number('0986576')->is_valid_number, '北海道稚内市声問村(川南)');
ok($zip->set_number('0986642')->is_valid_number, '北海道稚内市声問(1~5丁目)');
ok($zip->set_number('0986642')->is_valid_number, '北海道稚内市声問村(声問)');
ok($zip->set_number('0986643')->is_valid_number, '北海道稚内市声問村(メクマ)');
ok($zip->set_number('0986644')->is_valid_number, '北海道稚内市宗谷村(増幌)');
ok($zip->set_number('0986645')->is_valid_number, '北海道稚内市声問村(恵北)');
ok($zip->set_number('0986751')->is_valid_number, '北海道稚内市宗谷村(豊岩)');
ok($zip->set_number('0986754')->is_valid_number, '北海道稚内市宗谷村(清浜)');
ok($zip->set_number('0986755')->is_valid_number, '北海道稚内市宗谷村(宗谷)');
ok($zip->set_number('0986756')->is_valid_number, '北海道稚内市宗谷村(富磯)');
ok($zip->set_number('0986757')->is_valid_number, '北海道稚内市宗谷村(増幌浜)');
ok($zip->set_number('0986758')->is_valid_number, '北海道稚内市宗谷岬');
ok($zip->set_number('0990101')->is_valid_number, '北海道紋別郡遠軽町下白滝');
ok($zip->set_number('0990102')->is_valid_number, '北海道紋別郡遠軽町旧白滝');
ok($zip->set_number('0990111')->is_valid_number, '北海道紋別郡遠軽町白滝');
ok($zip->set_number('0990121')->is_valid_number, '北海道紋別郡遠軽町白滝北支湧別');
ok($zip->set_number('0990122')->is_valid_number, '北海道紋別郡遠軽町白滝支湧別');
ok($zip->set_number('0990123')->is_valid_number, '北海道紋別郡遠軽町白滝上支湧別');
ok($zip->set_number('0990124')->is_valid_number, '北海道紋別郡遠軽町東白滝');
ok($zip->set_number('0990125')->is_valid_number, '北海道紋別郡遠軽町白滝天狗平');
ok($zip->set_number('0990126')->is_valid_number, '北海道紋別郡遠軽町奥白滝');
ok($zip->set_number('0990127')->is_valid_number, '北海道紋別郡遠軽町上白滝');
ok($zip->set_number('0990201')->is_valid_number, '北海道紋別郡遠軽町丸瀬布新町');
ok($zip->set_number('0990202')->is_valid_number, '北海道紋別郡遠軽町丸瀬布天神町');
ok($zip->set_number('0990203')->is_valid_number, '北海道紋別郡遠軽町丸瀬布中町');
ok($zip->set_number('0990204')->is_valid_number, '北海道紋別郡遠軽町丸瀬布西町');
ok($zip->set_number('0990205')->is_valid_number, '北海道紋別郡遠軽町丸瀬布東町');
ok($zip->set_number('0990206')->is_valid_number, '北海道紋別郡遠軽町丸瀬布水谷町');
ok($zip->set_number('0990207')->is_valid_number, '北海道紋別郡遠軽町丸瀬布元町');
ok($zip->set_number('0990211')->is_valid_number, '北海道紋別郡遠軽町丸瀬布金山');
ok($zip->set_number('0990212')->is_valid_number, '北海道紋別郡遠軽町丸瀬布上丸');
ok($zip->set_number('0990213')->is_valid_number, '北海道紋別郡遠軽町丸瀬布上武利');
ok($zip->set_number('0990214')->is_valid_number, '北海道紋別郡遠軽町丸瀬布大平');
ok($zip->set_number('0990215')->is_valid_number, '北海道紋別郡遠軽町丸瀬布南丸');
ok($zip->set_number('0990216')->is_valid_number, '北海道紋別郡遠軽町丸瀬布武利');
ok($zip->set_number('0990341')->is_valid_number, '北海道紋別郡遠軽町瀬戸瀬東町');
ok($zip->set_number('0990342')->is_valid_number, '北海道紋別郡遠軽町瀬戸瀬西町');
ok($zip->set_number('0990343')->is_valid_number, '北海道紋別郡遠軽町栄野');
ok($zip->set_number('0990344')->is_valid_number, '北海道紋別郡遠軽町野上');
ok($zip->set_number('0990345')->is_valid_number, '北海道紋別郡遠軽町湯の里');
ok($zip->set_number('0990346')->is_valid_number, '北海道紋別郡遠軽町若咲内');
ok($zip->set_number('0990347')->is_valid_number, '北海道紋別郡遠軽町柏');
ok($zip->set_number('0990400')->is_valid_number, '北海道紋別郡遠軽町以下に掲載がない場合');
ok($zip->set_number('0990401')->is_valid_number, '北海道紋別郡遠軽町学田');
ok($zip->set_number('0990402')->is_valid_number, '北海道紋別郡遠軽町二条通北');
ok($zip->set_number('0990403')->is_valid_number, '北海道紋別郡遠軽町一条通北');
ok($zip->set_number('0990404')->is_valid_number, '北海道紋別郡遠軽町大通北');
ok($zip->set_number('0990405')->is_valid_number, '北海道紋別郡遠軽町岩見通北');
ok($zip->set_number('0990406')->is_valid_number, '北海道紋別郡遠軽町宮前町');
ok($zip->set_number('0990407')->is_valid_number, '北海道紋別郡遠軽町丸大');
ok($zip->set_number('0990408')->is_valid_number, '北海道紋別郡遠軽町留岡');
ok($zip->set_number('0990410')->is_valid_number, '北海道紋別郡遠軽町東町');
ok($zip->set_number('0990411')->is_valid_number, '北海道紋別郡遠軽町向遠軽');
ok($zip->set_number('0990412')->is_valid_number, '北海道紋別郡遠軽町豊里');
ok($zip->set_number('0990413')->is_valid_number, '北海道紋別郡遠軽町寿町');
ok($zip->set_number('0990414')->is_valid_number, '北海道紋別郡遠軽町南町');
ok($zip->set_number('0990415')->is_valid_number, '北海道紋別郡遠軽町岩見通南');
ok($zip->set_number('0990416')->is_valid_number, '北海道紋別郡遠軽町大通南');
ok($zip->set_number('0990417')->is_valid_number, '北海道紋別郡遠軽町一条通南');
ok($zip->set_number('0990418')->is_valid_number, '北海道紋別郡遠軽町二条通南');
ok($zip->set_number('0990421')->is_valid_number, '北海道紋別郡遠軽町福路');
ok($zip->set_number('0990422')->is_valid_number, '北海道紋別郡遠軽町清川');
ok($zip->set_number('0990423')->is_valid_number, '北海道紋別郡遠軽町若松');
ok($zip->set_number('0990424')->is_valid_number, '北海道紋別郡遠軽町美山');
ok($zip->set_number('0990425')->is_valid_number, '北海道紋別郡遠軽町千代田');
ok($zip->set_number('0990426')->is_valid_number, '北海道紋別郡遠軽町社名淵');
ok($zip->set_number('0990427')->is_valid_number, '北海道紋別郡遠軽町見晴');
ok($zip->set_number('0990428')->is_valid_number, '北海道紋別郡遠軽町西町');
ok($zip->set_number('0990621')->is_valid_number, '北海道紋別郡遠軽町生田原水穂');
ok($zip->set_number('0990622')->is_valid_number, '北海道紋別郡遠軽町生田原安国');
ok($zip->set_number('0990623')->is_valid_number, '北海道紋別郡遠軽町生田原旭野');
ok($zip->set_number('0990624')->is_valid_number, '北海道紋別郡遠軽町生田原豊原');
ok($zip->set_number('0990701')->is_valid_number, '北海道紋別郡遠軽町生田原');
ok($zip->set_number('0990702')->is_valid_number, '北海道紋別郡遠軽町生田原伊吹');
ok($zip->set_number('0990703')->is_valid_number, '北海道紋別郡遠軽町生田原八重');
ok($zip->set_number('0990704')->is_valid_number, '北海道紋別郡遠軽町生田原岩戸');
ok($zip->set_number('0990705')->is_valid_number, '北海道紋別郡遠軽町生田原清里');
ok($zip->set_number('0990871')->is_valid_number, '北海道北見市相内町');
ok($zip->set_number('0990872')->is_valid_number, '北海道北見市豊田');
ok($zip->set_number('0990873')->is_valid_number, '北海道北見市西相内');
ok($zip->set_number('0990874')->is_valid_number, '北海道北見市住吉');
ok($zip->set_number('0990875')->is_valid_number, '北海道北見市本沢');
ok($zip->set_number('0990876')->is_valid_number, '北海道北見市富里');
ok($zip->set_number('0990877')->is_valid_number, '北海道北見市柏木');
ok($zip->set_number('0990878')->is_valid_number, '北海道北見市東相内町');
ok($zip->set_number('0990879')->is_valid_number, '北海道北見市美園');
ok($zip->set_number('0991100')->is_valid_number, '北海道常呂郡置戸町以下に掲載がない場合');
ok($zip->set_number('0991101')->is_valid_number, '北海道常呂郡置戸町北光');
ok($zip->set_number('0991102')->is_valid_number, '北海道常呂郡置戸町緑');
ok($zip->set_number('0991103')->is_valid_number, '北海道常呂郡置戸町栄二');
ok($zip->set_number('0991104')->is_valid_number, '北海道常呂郡置戸町栄一');
ok($zip->set_number('0991105')->is_valid_number, '北海道常呂郡置戸町洗心');
ok($zip->set_number('0991106')->is_valid_number, '北海道常呂郡置戸町新和');
ok($zip->set_number('0991112')->is_valid_number, '北海道常呂郡置戸町若松');
ok($zip->set_number('0991113')->is_valid_number, '北海道常呂郡置戸町新光');
ok($zip->set_number('0991114')->is_valid_number, '北海道常呂郡置戸町協生');
ok($zip->set_number('0991115')->is_valid_number, '北海道常呂郡置戸町宮下');
ok($zip->set_number('0991116')->is_valid_number, '北海道常呂郡置戸町朝日');
ok($zip->set_number('0991117')->is_valid_number, '北海道常呂郡置戸町宮坂');
ok($zip->set_number('0991118')->is_valid_number, '北海道常呂郡置戸町若木');
ok($zip->set_number('0991121')->is_valid_number, '北海道常呂郡置戸町北農');
ok($zip->set_number('0991122')->is_valid_number, '北海道常呂郡置戸町林友');
ok($zip->set_number('0991123')->is_valid_number, '北海道常呂郡置戸町拓殖');
ok($zip->set_number('0991124')->is_valid_number, '北海道常呂郡置戸町拓実');
ok($zip->set_number('0991131')->is_valid_number, '北海道常呂郡置戸町中央');
ok($zip->set_number('0991132')->is_valid_number, '北海道常呂郡置戸町協和');
ok($zip->set_number('0991133')->is_valid_number, '北海道常呂郡置戸町更盛');
ok($zip->set_number('0991134')->is_valid_number, '北海道常呂郡置戸町十全');
ok($zip->set_number('0991135')->is_valid_number, '北海道常呂郡置戸町国栄');
ok($zip->set_number('0991136')->is_valid_number, '北海道常呂郡置戸町日進');
ok($zip->set_number('0991137')->is_valid_number, '北海道常呂郡置戸町大美');
ok($zip->set_number('0991138')->is_valid_number, '北海道常呂郡置戸町中里');
ok($zip->set_number('0991251')->is_valid_number, '北海道常呂郡置戸町安住');
ok($zip->set_number('0991252')->is_valid_number, '北海道常呂郡置戸町勝山');
ok($zip->set_number('0991253')->is_valid_number, '北海道常呂郡置戸町春日');
ok($zip->set_number('0991254')->is_valid_number, '北海道常呂郡置戸町常元');
ok($zip->set_number('0991361')->is_valid_number, '北海道常呂郡置戸町境野');
ok($zip->set_number('0991362')->is_valid_number, '北海道常呂郡置戸町雄勝');
ok($zip->set_number('0991363')->is_valid_number, '北海道常呂郡置戸町幸岡');
ok($zip->set_number('0991364')->is_valid_number, '北海道常呂郡置戸町秋田');
ok($zip->set_number('0991365')->is_valid_number, '北海道常呂郡置戸町豊住');
ok($zip->set_number('0991366')->is_valid_number, '北海道常呂郡置戸町川南');
ok($zip->set_number('0991367')->is_valid_number, '北海道常呂郡置戸町常盤');
ok($zip->set_number('0991400')->is_valid_number, '北海道常呂郡訓子府町以下に掲載がない場合');
ok($zip->set_number('0991401')->is_valid_number, '北海道常呂郡訓子府町日出');
ok($zip->set_number('0991402')->is_valid_number, '北海道常呂郡訓子府町穂波');
ok($zip->set_number('0991403')->is_valid_number, '北海道常呂郡訓子府町東幸町');
ok($zip->set_number('0991404')->is_valid_number, '北海道常呂郡訓子府町柏丘');
ok($zip->set_number('0991405')->is_valid_number, '北海道常呂郡訓子府町高園');
ok($zip->set_number('0991406')->is_valid_number, '北海道常呂郡訓子府町弥生');
ok($zip->set_number('0991407')->is_valid_number, '北海道常呂郡訓子府町福野');
ok($zip->set_number('0991411')->is_valid_number, '北海道常呂郡訓子府町大谷');
ok($zip->set_number('0991412')->is_valid_number, '北海道常呂郡訓子府町緑丘');
ok($zip->set_number('0991413')->is_valid_number, '北海道常呂郡訓子府町協成');
ok($zip->set_number('0991414')->is_valid_number, '北海道常呂郡訓子府町開盛');
ok($zip->set_number('0991415')->is_valid_number, '北海道常呂郡訓子府町美園');
ok($zip->set_number('0991416')->is_valid_number, '北海道常呂郡訓子府町常盤');
ok($zip->set_number('0991417')->is_valid_number, '北海道常呂郡訓子府町末広町');
ok($zip->set_number('0991418')->is_valid_number, '北海道常呂郡訓子府町実郷');
ok($zip->set_number('0991421')->is_valid_number, '北海道常呂郡訓子府町駒里');
ok($zip->set_number('0991422')->is_valid_number, '北海道常呂郡訓子府町北栄');
ok($zip->set_number('0991423')->is_valid_number, '北海道常呂郡訓子府町西幸町');
ok($zip->set_number('0991424')->is_valid_number, '北海道常呂郡訓子府町西富');
ok($zip->set_number('0991425')->is_valid_number, '北海道常呂郡訓子府町若葉町');
ok($zip->set_number('0991426')->is_valid_number, '北海道常呂郡訓子府町清住');
ok($zip->set_number('0991427')->is_valid_number, '北海道常呂郡訓子府町豊坂');
ok($zip->set_number('0991431')->is_valid_number, '北海道常呂郡訓子府町東町');
ok($zip->set_number('0991432')->is_valid_number, '北海道常呂郡訓子府町旭町');
ok($zip->set_number('0991433')->is_valid_number, '北海道常呂郡訓子府町仲町');
ok($zip->set_number('0991434')->is_valid_number, '北海道常呂郡訓子府町栄町');
ok($zip->set_number('0991435')->is_valid_number, '北海道常呂郡訓子府町若富町');
ok($zip->set_number('0991436')->is_valid_number, '北海道常呂郡訓子府町大町');
ok($zip->set_number('0991437')->is_valid_number, '北海道常呂郡訓子府町元町');
ok($zip->set_number('0991581')->is_valid_number, '北海道北見市南丘');
ok($zip->set_number('0991582')->is_valid_number, '北海道北見市開成');
ok($zip->set_number('0991583')->is_valid_number, '北海道北見市北上');
ok($zip->set_number('0991584')->is_valid_number, '北海道北見市常川');
ok($zip->set_number('0991585')->is_valid_number, '北海道北見市上ところ');
ok($zip->set_number('0991586')->is_valid_number, '北海道北見市広郷');
ok($zip->set_number('0991587')->is_valid_number, '北海道北見市豊地');
ok($zip->set_number('0992101')->is_valid_number, '北海道北見市端野町一区');
ok($zip->set_number('0992102')->is_valid_number, '北海道北見市端野町二区');
ok($zip->set_number('0992103')->is_valid_number, '北海道北見市端野町三区');
ok($zip->set_number('0992104')->is_valid_number, '北海道北見市端野町端野');
ok($zip->set_number('0992105')->is_valid_number, '北海道北見市端野町忠志');
ok($zip->set_number('0992106')->is_valid_number, '北海道北見市端野町協和');
ok($zip->set_number('0992107')->is_valid_number, '北海道北見市端野町川向');
ok($zip->set_number('0992111')->is_valid_number, '北海道北見市端野町北登');
ok($zip->set_number('0992112')->is_valid_number, '北海道北見市端野町豊実');
ok($zip->set_number('0992231')->is_valid_number, '北海道北見市端野町緋牛内');
ok($zip->set_number('0992300')->is_valid_number, '北海道網走郡大空町以下に掲載がない場合');
ok($zip->set_number('0992301')->is_valid_number, '北海道網走郡大空町女満別本郷');
ok($zip->set_number('0992302')->is_valid_number, '北海道網走郡大空町女満別住吉');
ok($zip->set_number('0992303')->is_valid_number, '北海道網走郡大空町女満別豊里');
ok($zip->set_number('0992304')->is_valid_number, '北海道網走郡大空町女満別公園');
ok($zip->set_number('0992305')->is_valid_number, '北海道網走郡大空町女満別東陽');
ok($zip->set_number('0992306')->is_valid_number, '北海道網走郡大空町女満別湖畔');
ok($zip->set_number('0992310')->is_valid_number, '北海道網走郡大空町女満別本通');
ok($zip->set_number('0992311')->is_valid_number, '北海道網走郡大空町女満別東一条');
ok($zip->set_number('0992312')->is_valid_number, '北海道網走郡大空町女満別東二条');
ok($zip->set_number('0992321')->is_valid_number, '北海道網走郡大空町女満別西一条');
ok($zip->set_number('0992322')->is_valid_number, '北海道網走郡大空町女満別西二条');
ok($zip->set_number('0992323')->is_valid_number, '北海道網走郡大空町女満別西三条');
ok($zip->set_number('0992324')->is_valid_number, '北海道網走郡大空町女満別西四条');
ok($zip->set_number('0992325')->is_valid_number, '北海道網走郡大空町女満別西五条');
ok($zip->set_number('0992326')->is_valid_number, '北海道網走郡大空町女満別西六条');
ok($zip->set_number('0992327')->is_valid_number, '北海道網走郡大空町女満別西七条');
ok($zip->set_number('0992351')->is_valid_number, '北海道網走郡大空町女満別公園通');
ok($zip->set_number('0992354')->is_valid_number, '北海道網走郡大空町女満別眺湖台');
ok($zip->set_number('0992355')->is_valid_number, '北海道網走郡大空町女満別夕陽台');
ok($zip->set_number('0992356')->is_valid_number, '北海道網走郡大空町女満別昭和');
ok($zip->set_number('0992361')->is_valid_number, '北海道網走郡大空町女満別湖南');
ok($zip->set_number('0992362')->is_valid_number, '北海道網走郡大空町女満別朝日');
ok($zip->set_number('0992371')->is_valid_number, '北海道網走郡大空町女満別中央');
ok($zip->set_number('0992372')->is_valid_number, '北海道網走郡大空町女満別大東');
ok($zip->set_number('0992373')->is_valid_number, '北海道網走郡大空町女満別巴沢');
ok($zip->set_number('0992381')->is_valid_number, '北海道網走郡大空町女満別大成');
ok($zip->set_number('0992382')->is_valid_number, '北海道網走郡大空町女満別開陽');
ok($zip->set_number('0992383')->is_valid_number, '北海道網走郡大空町女満別日進');
ok($zip->set_number('0992421')->is_valid_number, '北海道網走市呼人');
ok($zip->set_number('0992422')->is_valid_number, '北海道網走市八坂');
ok($zip->set_number('0992423')->is_valid_number, '北海道網走市東網走');
ok($zip->set_number('0992424')->is_valid_number, '北海道網走市中園');
ok($zip->set_number('0993111')->is_valid_number, '北海道網走市藻琴');
ok($zip->set_number('0993112')->is_valid_number, '北海道網走市北浜');
ok($zip->set_number('0993113')->is_valid_number, '北海道網走市実豊');
ok($zip->set_number('0993114')->is_valid_number, '北海道網走市丸万');
ok($zip->set_number('0993115')->is_valid_number, '北海道網走市稲富');
ok($zip->set_number('0993116')->is_valid_number, '北海道網走市山里');
ok($zip->set_number('0993117')->is_valid_number, '北海道網走市昭和');
ok($zip->set_number('0993118')->is_valid_number, '北海道網走市豊郷');
ok($zip->set_number('0993119')->is_valid_number, '北海道網走市鱒浦');
ok($zip->set_number('0993201')->is_valid_number, '北海道網走郡大空町東藻琴(西区)');
ok($zip->set_number('0993202')->is_valid_number, '北海道網走郡大空町東藻琴西倉');
ok($zip->set_number('0993211')->is_valid_number, '北海道網走郡大空町東藻琴(北1区)');
ok($zip->set_number('0993212')->is_valid_number, '北海道網走郡大空町東藻琴(北2区)');
ok($zip->set_number('0993213')->is_valid_number, '北海道網走郡大空町東藻琴(中央区)');
ok($zip->set_number('0993214')->is_valid_number, '北海道網走郡大空町東藻琴(南区)');
ok($zip->set_number('0993221')->is_valid_number, '北海道網走郡大空町東藻琴大進');
ok($zip->set_number('0993222')->is_valid_number, '北海道網走郡大空町東藻琴新富');
ok($zip->set_number('0993223')->is_valid_number, '北海道網走郡大空町東藻琴(東区)');
ok($zip->set_number('0993224')->is_valid_number, '北海道網走郡大空町東藻琴明生');
ok($zip->set_number('0993225')->is_valid_number, '北海道網走郡大空町東藻琴(旭台)');
ok($zip->set_number('0993231')->is_valid_number, '北海道網走郡大空町東藻琴千草');
ok($zip->set_number('0993232')->is_valid_number, '北海道網走郡大空町東藻琴末広');
ok($zip->set_number('0993233')->is_valid_number, '北海道網走郡大空町東藻琴(上東)');
ok($zip->set_number('0993234')->is_valid_number, '北海道網走郡大空町東藻琴福富');
ok($zip->set_number('0993243')->is_valid_number, '北海道網走郡大空町東藻琴山園');
ok($zip->set_number('0993244')->is_valid_number, '北海道網走郡大空町東藻琴(その他)');
ok($zip->set_number('0993451')->is_valid_number, '北海道斜里郡小清水町倉栄');
ok($zip->set_number('0993452')->is_valid_number, '北海道斜里郡小清水町浜小清水');
ok($zip->set_number('0993453')->is_valid_number, '北海道斜里郡小清水町北斗');
ok($zip->set_number('0993454')->is_valid_number, '北海道斜里郡小清水町止別');
ok($zip->set_number('0993501')->is_valid_number, '北海道網走市音根内');
ok($zip->set_number('0993502')->is_valid_number, '北海道網走市浦士別');
ok($zip->set_number('0993503')->is_valid_number, '北海道網走市栄');
ok($zip->set_number('0993504')->is_valid_number, '北海道網走市清浦');
ok($zip->set_number('0993600')->is_valid_number, '北海道斜里郡小清水町以下に掲載がない場合');
ok($zip->set_number('0993601')->is_valid_number, '北海道斜里郡小清水町萱野');
ok($zip->set_number('0993602')->is_valid_number, '北海道斜里郡小清水町東野');
ok($zip->set_number('0993603')->is_valid_number, '北海道斜里郡小清水町泉');
ok($zip->set_number('0993604')->is_valid_number, '北海道斜里郡小清水町水上');
ok($zip->set_number('0993605')->is_valid_number, '北海道斜里郡小清水町もこと山');
ok($zip->set_number('0993611')->is_valid_number, '北海道斜里郡小清水町上徳');
ok($zip->set_number('0993612')->is_valid_number, '北海道斜里郡小清水町共和');
ok($zip->set_number('0993613')->is_valid_number, '北海道斜里郡小清水町神浦');
ok($zip->set_number('0993614')->is_valid_number, '北海道斜里郡小清水町美和');
ok($zip->set_number('0993615')->is_valid_number, '北海道斜里郡小清水町中里');
ok($zip->set_number('0993616')->is_valid_number, '北海道斜里郡小清水町旭');
ok($zip->set_number('0993641')->is_valid_number, '北海道斜里郡小清水町元町');
ok($zip->set_number('0993642')->is_valid_number, '北海道斜里郡小清水町南町');
ok($zip->set_number('0994100')->is_valid_number, '北海道斜里郡斜里町以下に掲載がない場合');
ok($zip->set_number('0994111')->is_valid_number, '北海道斜里郡斜里町前浜町');
ok($zip->set_number('0994112')->is_valid_number, '北海道斜里郡斜里町港町');
ok($zip->set_number('0994113')->is_valid_number, '北海道斜里郡斜里町本町');
ok($zip->set_number('0994114')->is_valid_number, '北海道斜里郡斜里町朝日町');
ok($zip->set_number('0994115')->is_valid_number, '北海道斜里郡斜里町光陽町');
ok($zip->set_number('0994116')->is_valid_number, '北海道斜里郡斜里町文光町');
ok($zip->set_number('0994117')->is_valid_number, '北海道斜里郡斜里町青葉町');
ok($zip->set_number('0994118')->is_valid_number, '北海道斜里郡斜里町新光町');
ok($zip->set_number('0994121')->is_valid_number, '北海道斜里郡斜里町日の出');
ok($zip->set_number('0994122')->is_valid_number, '北海道斜里郡斜里町峰浜');
ok($zip->set_number('0994123')->is_valid_number, '北海道斜里郡斜里町朱円東');
ok($zip->set_number('0994124')->is_valid_number, '北海道斜里郡斜里町朱円');
ok($zip->set_number('0994125')->is_valid_number, '北海道斜里郡斜里町朱円西');
ok($zip->set_number('0994126')->is_valid_number, '北海道斜里郡斜里町以久科北');
ok($zip->set_number('0994127')->is_valid_number, '北海道斜里郡斜里町以久科南');
ok($zip->set_number('0994131')->is_valid_number, '北海道斜里郡斜里町越川');
ok($zip->set_number('0994132')->is_valid_number, '北海道斜里郡斜里町富士');
ok($zip->set_number('0994133')->is_valid_number, '北海道斜里郡斜里町三井');
ok($zip->set_number('0994134')->is_valid_number, '北海道斜里郡斜里町豊里');
ok($zip->set_number('0994135')->is_valid_number, '北海道斜里郡斜里町来運');
ok($zip->set_number('0994141')->is_valid_number, '北海道斜里郡斜里町豊倉');
ok($zip->set_number('0994142')->is_valid_number, '北海道斜里郡斜里町中斜里');
ok($zip->set_number('0994143')->is_valid_number, '北海道斜里郡斜里町川上');
ok($zip->set_number('0994144')->is_valid_number, '北海道斜里郡斜里町大栄');
ok($zip->set_number('0994145')->is_valid_number, '北海道斜里郡斜里町美咲');
ok($zip->set_number('0994146')->is_valid_number, '北海道斜里郡斜里町港西町');
ok($zip->set_number('0994147')->is_valid_number, '北海道斜里郡斜里町西町');
ok($zip->set_number('0994351')->is_valid_number, '北海道斜里郡斜里町ウトロ香川');
ok($zip->set_number('0994352')->is_valid_number, '北海道斜里郡斜里町ウトロ高原');
ok($zip->set_number('0994353')->is_valid_number, '北海道斜里郡斜里町ウトロ中島');
ok($zip->set_number('0994354')->is_valid_number, '北海道斜里郡斜里町ウトロ西');
ok($zip->set_number('0994355')->is_valid_number, '北海道斜里郡斜里町ウトロ東');
ok($zip->set_number('0994356')->is_valid_number, '北海道斜里郡斜里町岩尾別');
ok($zip->set_number('0994357')->is_valid_number, '北海道斜里郡斜里町真鯉');
ok($zip->set_number('0994400')->is_valid_number, '北海道斜里郡清里町以下に掲載がない場合');
ok($zip->set_number('0994401')->is_valid_number, '北海道斜里郡清里町上斜里');
ok($zip->set_number('0994402')->is_valid_number, '北海道斜里郡清里町下江鳶');
ok($zip->set_number('0994403')->is_valid_number, '北海道斜里郡清里町向陽');
ok($zip->set_number('0994404')->is_valid_number, '北海道斜里郡清里町江南');
ok($zip->set_number('0994405')->is_valid_number, '北海道斜里郡清里町羽衣町');
ok($zip->set_number('0994406')->is_valid_number, '北海道斜里郡清里町水元町');
ok($zip->set_number('0994407')->is_valid_number, '北海道斜里郡清里町新町');
ok($zip->set_number('0994521')->is_valid_number, '北海道斜里郡清里町札弦町');
ok($zip->set_number('0994522')->is_valid_number, '北海道斜里郡清里町神威');
ok($zip->set_number('0994523')->is_valid_number, '北海道斜里郡清里町川向');
ok($zip->set_number('0994524')->is_valid_number, '北海道斜里郡清里町青葉');
ok($zip->set_number('0994525')->is_valid_number, '北海道斜里郡清里町緑町');
ok($zip->set_number('0994526')->is_valid_number, '北海道斜里郡清里町清泉');
ok($zip->set_number('0995171')->is_valid_number, '北海道紋別市渚滑町');
ok($zip->set_number('0995172')->is_valid_number, '北海道紋別市渚滑町元新');
ok($zip->set_number('0995173')->is_valid_number, '北海道紋別市渚滑町元西');
ok($zip->set_number('0995174')->is_valid_number, '北海道紋別市渚滑町宇津々');
ok($zip->set_number('0995175')->is_valid_number, '北海道紋別市渚滑町川向');
ok($zip->set_number('0995351')->is_valid_number, '北海道紋別市上渚滑町下渚滑');
ok($zip->set_number('0995352')->is_valid_number, '北海道紋別市上渚滑町中渚滑');
ok($zip->set_number('0995353')->is_valid_number, '北海道紋別市上渚滑町上東');
ok($zip->set_number('0995354')->is_valid_number, '北海道紋別市上渚滑町');
ok($zip->set_number('0995355')->is_valid_number, '北海道紋別市上渚滑町更生');
ok($zip->set_number('0995361')->is_valid_number, '北海道紋別市上渚滑町和訓辺');
ok($zip->set_number('0995362')->is_valid_number, '北海道紋別市上渚滑町奥東');
ok($zip->set_number('0995363')->is_valid_number, '北海道紋別市上渚滑町下立牛');
ok($zip->set_number('0995364')->is_valid_number, '北海道紋別市上渚滑町上古丹');
ok($zip->set_number('0995365')->is_valid_number, '北海道紋別市上渚滑町中立牛');
ok($zip->set_number('0995541')->is_valid_number, '北海道紋別郡滝上町濁川中央');
ok($zip->set_number('0995542')->is_valid_number, '北海道紋別郡滝上町濁川みどり町');
ok($zip->set_number('0995543')->is_valid_number, '北海道紋別郡滝上町新町');
ok($zip->set_number('0995544')->is_valid_number, '北海道紋別郡滝上町雄鎮内');
ok($zip->set_number('0995551')->is_valid_number, '北海道紋別郡滝上町大正');
ok($zip->set_number('0995552')->is_valid_number, '北海道紋別郡滝上町滝下');
ok($zip->set_number('0995553')->is_valid_number, '北海道紋別郡滝上町雄柏');
ok($zip->set_number('0995600')->is_valid_number, '北海道紋別郡滝上町以下に掲載がない場合');
ok($zip->set_number('0995601')->is_valid_number, '北海道紋別郡滝上町あけぼの町');
ok($zip->set_number('0995602')->is_valid_number, '北海道紋別郡滝上町旭町');
ok($zip->set_number('0995603')->is_valid_number, '北海道紋別郡滝上町滝美町');
ok($zip->set_number('0995604')->is_valid_number, '北海道紋別郡滝上町元町');
ok($zip->set_number('0995605')->is_valid_number, '北海道紋別郡滝上町栄町');
ok($zip->set_number('0995606')->is_valid_number, '北海道紋別郡滝上町幸町');
ok($zip->set_number('0995611')->is_valid_number, '北海道紋別郡滝上町第1区');
ok($zip->set_number('0995612')->is_valid_number, '北海道紋別郡滝上町白鳥');
ok($zip->set_number('0995612')->is_valid_number, '北海道紋別郡滝上町第2区');
ok($zip->set_number('0995613')->is_valid_number, '北海道紋別郡滝上町第3区');
ok($zip->set_number('0995613')->is_valid_number, '北海道紋別郡滝上町第4区');
ok($zip->set_number('0995613')->is_valid_number, '北海道紋別郡滝上町第5区');
ok($zip->set_number('0995613')->is_valid_number, '北海道紋別郡滝上町滝西');
ok($zip->set_number('0995614')->is_valid_number, '北海道紋別郡滝上町札久留');
ok($zip->set_number('0996131')->is_valid_number, '北海道紋別市一本松');
ok($zip->set_number('0996131')->is_valid_number, '北海道紋別市八十士');
ok($zip->set_number('0996132')->is_valid_number, '北海道紋別市小向');
ok($zip->set_number('0996133')->is_valid_number, '北海道紋別市弘道');
ok($zip->set_number('0996241')->is_valid_number, '北海道紋別市沼の上');
ok($zip->set_number('0996242')->is_valid_number, '北海道紋別市志文');
ok($zip->set_number('0996271')->is_valid_number, '北海道紋別郡湧別町信部内');
ok($zip->set_number('0996272')->is_valid_number, '北海道紋別郡湧別町緑蔭');
ok($zip->set_number('0996321')->is_valid_number, '北海道紋別郡湧別町旭');
ok($zip->set_number('0996322')->is_valid_number, '北海道紋別郡湧別町北兵村三区');
ok($zip->set_number('0996323')->is_valid_number, '北海道紋別郡湧別町北兵村二区');
ok($zip->set_number('0996325')->is_valid_number, '北海道紋別郡湧別町北兵村一区');
ok($zip->set_number('0996326')->is_valid_number, '北海道紋別郡湧別町中湧別北町');
ok($zip->set_number('0996327')->is_valid_number, '北海道紋別郡湧別町中湧別東町');
ok($zip->set_number('0996328')->is_valid_number, '北海道紋別郡湧別町中湧別南町');
ok($zip->set_number('0996329')->is_valid_number, '北海道紋別郡湧別町中湧別中町');
ok($zip->set_number('0996400')->is_valid_number, '北海道紋別郡湧別町以下に掲載がない場合');
ok($zip->set_number('0996401')->is_valid_number, '北海道紋別郡湧別町港町');
ok($zip->set_number('0996402')->is_valid_number, '北海道紋別郡湧別町曙町');
ok($zip->set_number('0996403')->is_valid_number, '北海道紋別郡湧別町緑町');
ok($zip->set_number('0996404')->is_valid_number, '北海道紋別郡湧別町栄町');
ok($zip->set_number('0996411')->is_valid_number, '北海道紋別郡湧別町東');
ok($zip->set_number('0996412')->is_valid_number, '北海道紋別郡湧別町登栄床');
ok($zip->set_number('0996413')->is_valid_number, '北海道紋別郡湧別町福島(その他)');
ok($zip->set_number('0996414')->is_valid_number, '北海道紋別郡湧別町錦町');
ok($zip->set_number('0996415')->is_valid_number, '北海道紋別郡湧別町川西');
ok($zip->set_number('0996501')->is_valid_number, '北海道紋別郡湧別町上湧別屯田市街地');
ok($zip->set_number('0996503')->is_valid_number, '北海道紋別郡湧別町開盛');
ok($zip->set_number('0996504')->is_valid_number, '北海道紋別郡湧別町上富美');
ok($zip->set_number('0996505')->is_valid_number, '北海道紋別郡湧別町富美');
ok($zip->set_number('0996506')->is_valid_number, '北海道紋別郡湧別町札富美');
ok($zip->set_number('0996507')->is_valid_number, '北海道紋別郡湧別町南兵村三区');
ok($zip->set_number('0996508')->is_valid_number, '北海道紋別郡湧別町南兵村二区');
ok($zip->set_number('0996509')->is_valid_number, '北海道紋別郡湧別町南兵村一区');
ok($zip->set_number('1000000')->is_valid_number, '東京都千代田区以下に掲載がない場合');
ok($zip->set_number('1000001')->is_valid_number, '東京都千代田区千代田');
ok($zip->set_number('1000002')->is_valid_number, '東京都千代田区皇居外苑');
ok($zip->set_number('1000003')->is_valid_number, '東京都千代田区一ツ橋(1丁目)');
ok($zip->set_number('1000004')->is_valid_number, '東京都千代田区大手町(次のビルを除く)');
ok($zip->set_number('1000005')->is_valid_number, '東京都千代田区丸の内(次のビルを除く)');
ok($zip->set_number('1000006')->is_valid_number, '東京都千代田区有楽町');
ok($zip->set_number('1000011')->is_valid_number, '東京都千代田区内幸町');
ok($zip->set_number('1000012')->is_valid_number, '東京都千代田区日比谷公園');
ok($zip->set_number('1000013')->is_valid_number, '東京都千代田区霞が関(次のビルを除く)');
ok($zip->set_number('1000014')->is_valid_number, '東京都千代田区永田町(次のビルを除く)');
ok($zip->set_number('1000100')->is_valid_number, '東京都大島町以下に掲載がない場合');
ok($zip->set_number('1000101')->is_valid_number, '東京都大島町元町');
ok($zip->set_number('1000102')->is_valid_number, '東京都大島町岡田');
ok($zip->set_number('1000103')->is_valid_number, '東京都大島町泉津');
ok($zip->set_number('1000104')->is_valid_number, '東京都大島町野増');
ok($zip->set_number('1000211')->is_valid_number, '東京都大島町差木地');
ok($zip->set_number('1000212')->is_valid_number, '東京都大島町波浮港');
ok($zip->set_number('1000301')->is_valid_number, '東京都利島村利島村一円');
ok($zip->set_number('1000400')->is_valid_number, '東京都新島村以下に掲載がない場合');
ok($zip->set_number('1000401')->is_valid_number, '東京都新島村若郷');
ok($zip->set_number('1000402')->is_valid_number, '東京都新島村本村');
ok($zip->set_number('1000511')->is_valid_number, '東京都新島村式根島');
ok($zip->set_number('1000601')->is_valid_number, '東京都神津島村神津島村一円');
ok($zip->set_number('1001100')->is_valid_number, '東京都三宅島三宅村以下に掲載がない場合');
ok($zip->set_number('1001101')->is_valid_number, '東京都三宅島三宅村神着');
ok($zip->set_number('1001102')->is_valid_number, '東京都三宅島三宅村伊豆');
ok($zip->set_number('1001103')->is_valid_number, '東京都三宅島三宅村伊ケ谷');
ok($zip->set_number('1001211')->is_valid_number, '東京都三宅島三宅村坪田');
ok($zip->set_number('1001212')->is_valid_number, '東京都三宅島三宅村阿古');
ok($zip->set_number('1001213')->is_valid_number, '東京都三宅島三宅村雄山');
ok($zip->set_number('1001301')->is_valid_number, '東京都御蔵島村御蔵島村一円');
ok($zip->set_number('1001400')->is_valid_number, '東京都八丈島八丈町以下に掲載がない場合');
ok($zip->set_number('1001401')->is_valid_number, '東京都八丈島八丈町大賀郷');
ok($zip->set_number('1001511')->is_valid_number, '東京都八丈島八丈町三根');
ok($zip->set_number('1001621')->is_valid_number, '東京都八丈島八丈町樫立');
ok($zip->set_number('1001622')->is_valid_number, '東京都八丈島八丈町末吉');
ok($zip->set_number('1001623')->is_valid_number, '東京都八丈島八丈町中之郷');
ok($zip->set_number('1001701')->is_valid_number, '東京都青ヶ島村青ヶ島村一円');
ok($zip->set_number('1002100')->is_valid_number, '東京都小笠原村以下に掲載がない場合');
ok($zip->set_number('1002101')->is_valid_number, '東京都小笠原村父島');
ok($zip->set_number('1002211')->is_valid_number, '東京都小笠原村母島');
ok($zip->set_number('1006001')->is_valid_number, '東京都千代田区霞が関霞が関ビル(1階)');
ok($zip->set_number('1006002')->is_valid_number, '東京都千代田区霞が関霞が関ビル(2階)');
ok($zip->set_number('1006003')->is_valid_number, '東京都千代田区霞が関霞が関ビル(3階)');
ok($zip->set_number('1006004')->is_valid_number, '東京都千代田区霞が関霞が関ビル(4階)');
ok($zip->set_number('1006005')->is_valid_number, '東京都千代田区霞が関霞が関ビル(5階)');
ok($zip->set_number('1006006')->is_valid_number, '東京都千代田区霞が関霞が関ビル(6階)');
ok($zip->set_number('1006007')->is_valid_number, '東京都千代田区霞が関霞が関ビル(7階)');
ok($zip->set_number('1006008')->is_valid_number, '東京都千代田区霞が関霞が関ビル(8階)');
ok($zip->set_number('1006009')->is_valid_number, '東京都千代田区霞が関霞が関ビル(9階)');
ok($zip->set_number('1006010')->is_valid_number, '東京都千代田区霞が関霞が関ビル(10階)');
ok($zip->set_number('1006011')->is_valid_number, '東京都千代田区霞が関霞が関ビル(11階)');
ok($zip->set_number('1006012')->is_valid_number, '東京都千代田区霞が関霞が関ビル(12階)');
ok($zip->set_number('1006013')->is_valid_number, '東京都千代田区霞が関霞が関ビル(13階)');
ok($zip->set_number('1006014')->is_valid_number, '東京都千代田区霞が関霞が関ビル(14階)');
ok($zip->set_number('1006015')->is_valid_number, '東京都千代田区霞が関霞が関ビル(15階)');
ok($zip->set_number('1006016')->is_valid_number, '東京都千代田区霞が関霞が関ビル(16階)');
ok($zip->set_number('1006017')->is_valid_number, '東京都千代田区霞が関霞が関ビル(17階)');
ok($zip->set_number('1006018')->is_valid_number, '東京都千代田区霞が関霞が関ビル(18階)');
ok($zip->set_number('1006019')->is_valid_number, '東京都千代田区霞が関霞が関ビル(19階)');
ok($zip->set_number('1006020')->is_valid_number, '東京都千代田区霞が関霞が関ビル(20階)');
ok($zip->set_number('1006021')->is_valid_number, '東京都千代田区霞が関霞が関ビル(21階)');
ok($zip->set_number('1006022')->is_valid_number, '東京都千代田区霞が関霞が関ビル(22階)');
ok($zip->set_number('1006023')->is_valid_number, '東京都千代田区霞が関霞が関ビル(23階)');
ok($zip->set_number('1006024')->is_valid_number, '東京都千代田区霞が関霞が関ビル(24階)');
ok($zip->set_number('1006025')->is_valid_number, '東京都千代田区霞が関霞が関ビル(25階)');
ok($zip->set_number('1006026')->is_valid_number, '東京都千代田区霞が関霞が関ビル(26階)');
ok($zip->set_number('1006027')->is_valid_number, '東京都千代田区霞が関霞が関ビル(27階)');
ok($zip->set_number('1006028')->is_valid_number, '東京都千代田区霞が関霞が関ビル(28階)');
ok($zip->set_number('1006029')->is_valid_number, '東京都千代田区霞が関霞が関ビル(29階)');
ok($zip->set_number('1006030')->is_valid_number, '東京都千代田区霞が関霞が関ビル(30階)');
ok($zip->set_number('1006031')->is_valid_number, '東京都千代田区霞が関霞が関ビル(31階)');
ok($zip->set_number('1006032')->is_valid_number, '東京都千代田区霞が関霞が関ビル(32階)');
ok($zip->set_number('1006033')->is_valid_number, '東京都千代田区霞が関霞が関ビル(33階)');
ok($zip->set_number('1006034')->is_valid_number, '東京都千代田区霞が関霞が関ビル(34階)');
ok($zip->set_number('1006035')->is_valid_number, '東京都千代田区霞が関霞が関ビル(35階)');
ok($zip->set_number('1006036')->is_valid_number, '東京都千代田区霞が関霞が関ビル(36階)');
ok($zip->set_number('1006090')->is_valid_number, '東京都千代田区霞が関霞が関ビル(地階・階層不明)');
ok($zip->set_number('1006101')->is_valid_number, '東京都千代田区永田町山王パークタワー(1階)');
ok($zip->set_number('1006102')->is_valid_number, '東京都千代田区永田町山王パークタワー(2階)');
ok($zip->set_number('1006103')->is_valid_number, '東京都千代田区永田町山王パークタワー(3階)');
ok($zip->set_number('1006104')->is_valid_number, '東京都千代田区永田町山王パークタワー(4階)');
ok($zip->set_number('1006105')->is_valid_number, '東京都千代田区永田町山王パークタワー(5階)');
ok($zip->set_number('1006106')->is_valid_number, '東京都千代田区永田町山王パークタワー(6階)');
ok($zip->set_number('1006107')->is_valid_number, '東京都千代田区永田町山王パークタワー(7階)');
ok($zip->set_number('1006108')->is_valid_number, '東京都千代田区永田町山王パークタワー(8階)');
ok($zip->set_number('1006109')->is_valid_number, '東京都千代田区永田町山王パークタワー(9階)');
ok($zip->set_number('1006110')->is_valid_number, '東京都千代田区永田町山王パークタワー(10階)');
ok($zip->set_number('1006111')->is_valid_number, '東京都千代田区永田町山王パークタワー(11階)');
ok($zip->set_number('1006112')->is_valid_number, '東京都千代田区永田町山王パークタワー(12階)');
ok($zip->set_number('1006113')->is_valid_number, '東京都千代田区永田町山王パークタワー(13階)');
ok($zip->set_number('1006114')->is_valid_number, '東京都千代田区永田町山王パークタワー(14階)');
ok($zip->set_number('1006115')->is_valid_number, '東京都千代田区永田町山王パークタワー(15階)');
ok($zip->set_number('1006116')->is_valid_number, '東京都千代田区永田町山王パークタワー(16階)');
ok($zip->set_number('1006117')->is_valid_number, '東京都千代田区永田町山王パークタワー(17階)');
ok($zip->set_number('1006118')->is_valid_number, '東京都千代田区永田町山王パークタワー(18階)');
ok($zip->set_number('1006119')->is_valid_number, '東京都千代田区永田町山王パークタワー(19階)');
ok($zip->set_number('1006120')->is_valid_number, '東京都千代田区永田町山王パークタワー(20階)');
ok($zip->set_number('1006121')->is_valid_number, '東京都千代田区永田町山王パークタワー(21階)');
ok($zip->set_number('1006122')->is_valid_number, '東京都千代田区永田町山王パークタワー(22階)');
ok($zip->set_number('1006123')->is_valid_number, '東京都千代田区永田町山王パークタワー(23階)');
ok($zip->set_number('1006124')->is_valid_number, '東京都千代田区永田町山王パークタワー(24階)');
ok($zip->set_number('1006125')->is_valid_number, '東京都千代田区永田町山王パークタワー(25階)');
ok($zip->set_number('1006126')->is_valid_number, '東京都千代田区永田町山王パークタワー(26階)');
ok($zip->set_number('1006127')->is_valid_number, '東京都千代田区永田町山王パークタワー(27階)');
ok($zip->set_number('1006128')->is_valid_number, '東京都千代田区永田町山王パークタワー(28階)');
ok($zip->set_number('1006129')->is_valid_number, '東京都千代田区永田町山王パークタワー(29階)');
ok($zip->set_number('1006130')->is_valid_number, '東京都千代田区永田町山王パークタワー(30階)');
ok($zip->set_number('1006131')->is_valid_number, '東京都千代田区永田町山王パークタワー(31階)');
ok($zip->set_number('1006132')->is_valid_number, '東京都千代田区永田町山王パークタワー(32階)');
ok($zip->set_number('1006133')->is_valid_number, '東京都千代田区永田町山王パークタワー(33階)');
ok($zip->set_number('1006134')->is_valid_number, '東京都千代田区永田町山王パークタワー(34階)');
ok($zip->set_number('1006135')->is_valid_number, '東京都千代田区永田町山王パークタワー(35階)');
ok($zip->set_number('1006136')->is_valid_number, '東京都千代田区永田町山王パークタワー(36階)');
ok($zip->set_number('1006137')->is_valid_number, '東京都千代田区永田町山王パークタワー(37階)');
ok($zip->set_number('1006138')->is_valid_number, '東京都千代田区永田町山王パークタワー(38階)');
ok($zip->set_number('1006139')->is_valid_number, '東京都千代田区永田町山王パークタワー(39階)');
ok($zip->set_number('1006140')->is_valid_number, '東京都千代田区永田町山王パークタワー(40階)');
ok($zip->set_number('1006141')->is_valid_number, '東京都千代田区永田町山王パークタワー(41階)');
ok($zip->set_number('1006142')->is_valid_number, '東京都千代田区永田町山王パークタワー(42階)');
ok($zip->set_number('1006143')->is_valid_number, '東京都千代田区永田町山王パークタワー(43階)');
ok($zip->set_number('1006144')->is_valid_number, '東京都千代田区永田町山王パークタワー(44階)');
ok($zip->set_number('1006190')->is_valid_number, '東京都千代田区永田町山王パークタワー(地階・階層不明)');
ok($zip->set_number('1006201')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(1階)');
ok($zip->set_number('1006202')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(2階)');
ok($zip->set_number('1006203')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(3階)');
ok($zip->set_number('1006204')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(4階)');
ok($zip->set_number('1006205')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(5階)');
ok($zip->set_number('1006206')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(6階)');
ok($zip->set_number('1006207')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(7階)');
ok($zip->set_number('1006208')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(8階)');
ok($zip->set_number('1006209')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(9階)');
ok($zip->set_number('1006210')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(10階)');
ok($zip->set_number('1006211')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(11階)');
ok($zip->set_number('1006212')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(12階)');
ok($zip->set_number('1006213')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(13階)');
ok($zip->set_number('1006214')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(14階)');
ok($zip->set_number('1006215')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(15階)');
ok($zip->set_number('1006216')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(16階)');
ok($zip->set_number('1006217')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(17階)');
ok($zip->set_number('1006218')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(18階)');
ok($zip->set_number('1006219')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(19階)');
ok($zip->set_number('1006220')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(20階)');
ok($zip->set_number('1006221')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(21階)');
ok($zip->set_number('1006222')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(22階)');
ok($zip->set_number('1006223')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(23階)');
ok($zip->set_number('1006224')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(24階)');
ok($zip->set_number('1006225')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(25階)');
ok($zip->set_number('1006226')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(26階)');
ok($zip->set_number('1006227')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(27階)');
ok($zip->set_number('1006228')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(28階)');
ok($zip->set_number('1006229')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(29階)');
ok($zip->set_number('1006230')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(30階)');
ok($zip->set_number('1006231')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(31階)');
ok($zip->set_number('1006290')->is_valid_number, '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内(地階・階層不明)');
ok($zip->set_number('1006301')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(1階)');
ok($zip->set_number('1006302')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(2階)');
ok($zip->set_number('1006303')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(3階)');
ok($zip->set_number('1006304')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(4階)');
ok($zip->set_number('1006305')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(5階)');
ok($zip->set_number('1006306')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(6階)');
ok($zip->set_number('1006307')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(7階)');
ok($zip->set_number('1006308')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(8階)');
ok($zip->set_number('1006309')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(9階)');
ok($zip->set_number('1006310')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(10階)');
ok($zip->set_number('1006311')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(11階)');
ok($zip->set_number('1006312')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(12階)');
ok($zip->set_number('1006313')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(13階)');
ok($zip->set_number('1006314')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(14階)');
ok($zip->set_number('1006315')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(15階)');
ok($zip->set_number('1006316')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(16階)');
ok($zip->set_number('1006317')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(17階)');
ok($zip->set_number('1006318')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(18階)');
ok($zip->set_number('1006319')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(19階)');
ok($zip->set_number('1006320')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(20階)');
ok($zip->set_number('1006321')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(21階)');
ok($zip->set_number('1006322')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(22階)');
ok($zip->set_number('1006323')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(23階)');
ok($zip->set_number('1006324')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(24階)');
ok($zip->set_number('1006325')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(25階)');
ok($zip->set_number('1006326')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(26階)');
ok($zip->set_number('1006327')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(27階)');
ok($zip->set_number('1006328')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(28階)');
ok($zip->set_number('1006329')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(29階)');
ok($zip->set_number('1006330')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(30階)');
ok($zip->set_number('1006331')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(31階)');
ok($zip->set_number('1006332')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(32階)');
ok($zip->set_number('1006333')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(33階)');
ok($zip->set_number('1006334')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(34階)');
ok($zip->set_number('1006335')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(35階)');
ok($zip->set_number('1006336')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(36階)');
ok($zip->set_number('1006337')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(37階)');
ok($zip->set_number('1006390')->is_valid_number, '東京都千代田区丸の内丸の内ビルディング(地階・階層不明)');
ok($zip->set_number('1006401')->is_valid_number, '東京都千代田区丸の内東京ビルディング(1階)');
ok($zip->set_number('1006402')->is_valid_number, '東京都千代田区丸の内東京ビルディング(2階)');
ok($zip->set_number('1006403')->is_valid_number, '東京都千代田区丸の内東京ビルディング(3階)');
ok($zip->set_number('1006404')->is_valid_number, '東京都千代田区丸の内東京ビルディング(4階)');
ok($zip->set_number('1006405')->is_valid_number, '東京都千代田区丸の内東京ビルディング(5階)');
ok($zip->set_number('1006406')->is_valid_number, '東京都千代田区丸の内東京ビルディング(6階)');
ok($zip->set_number('1006407')->is_valid_number, '東京都千代田区丸の内東京ビルディング(7階)');
ok($zip->set_number('1006408')->is_valid_number, '東京都千代田区丸の内東京ビルディング(8階)');
ok($zip->set_number('1006409')->is_valid_number, '東京都千代田区丸の内東京ビルディング(9階)');
ok($zip->set_number('1006410')->is_valid_number, '東京都千代田区丸の内東京ビルディング(10階)');
ok($zip->set_number('1006411')->is_valid_number, '東京都千代田区丸の内東京ビルディング(11階)');
ok($zip->set_number('1006412')->is_valid_number, '東京都千代田区丸の内東京ビルディング(12階)');
ok($zip->set_number('1006413')->is_valid_number, '東京都千代田区丸の内東京ビルディング(13階)');
ok($zip->set_number('1006414')->is_valid_number, '東京都千代田区丸の内東京ビルディング(14階)');
ok($zip->set_number('1006415')->is_valid_number, '東京都千代田区丸の内東京ビルディング(15階)');
ok($zip->set_number('1006416')->is_valid_number, '東京都千代田区丸の内東京ビルディング(16階)');
ok($zip->set_number('1006417')->is_valid_number, '東京都千代田区丸の内東京ビルディング(17階)');
ok($zip->set_number('1006418')->is_valid_number, '東京都千代田区丸の内東京ビルディング(18階)');
ok($zip->set_number('1006419')->is_valid_number, '東京都千代田区丸の内東京ビルディング(19階)');
ok($zip->set_number('1006420')->is_valid_number, '東京都千代田区丸の内東京ビルディング(20階)');
ok($zip->set_number('1006421')->is_valid_number, '東京都千代田区丸の内東京ビルディング(21階)');
ok($zip->set_number('1006422')->is_valid_number, '東京都千代田区丸の内東京ビルディング(22階)');
ok($zip->set_number('1006423')->is_valid_number, '東京都千代田区丸の内東京ビルディング(23階)');
ok($zip->set_number('1006424')->is_valid_number, '東京都千代田区丸の内東京ビルディング(24階)');
ok($zip->set_number('1006425')->is_valid_number, '東京都千代田区丸の内東京ビルディング(25階)');
ok($zip->set_number('1006426')->is_valid_number, '東京都千代田区丸の内東京ビルディング(26階)');
ok($zip->set_number('1006427')->is_valid_number, '東京都千代田区丸の内東京ビルディング(27階)');
ok($zip->set_number('1006428')->is_valid_number, '東京都千代田区丸の内東京ビルディング(28階)');
ok($zip->set_number('1006429')->is_valid_number, '東京都千代田区丸の内東京ビルディング(29階)');
ok($zip->set_number('1006430')->is_valid_number, '東京都千代田区丸の内東京ビルディング(30階)');
ok($zip->set_number('1006431')->is_valid_number, '東京都千代田区丸の内東京ビルディング(31階)');
ok($zip->set_number('1006432')->is_valid_number, '東京都千代田区丸の内東京ビルディング(32階)');
ok($zip->set_number('1006433')->is_valid_number, '東京都千代田区丸の内東京ビルディング(33階)');
ok($zip->set_number('1006490')->is_valid_number, '東京都千代田区丸の内東京ビルディング(地階・階層不明)');
ok($zip->set_number('1006501')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(1階)');
ok($zip->set_number('1006502')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(2階)');
ok($zip->set_number('1006503')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(3階)');
ok($zip->set_number('1006504')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(4階)');
ok($zip->set_number('1006505')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(5階)');
ok($zip->set_number('1006506')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(6階)');
ok($zip->set_number('1006507')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(7階)');
ok($zip->set_number('1006508')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(8階)');
ok($zip->set_number('1006509')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(9階)');
ok($zip->set_number('1006510')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(10階)');
ok($zip->set_number('1006511')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(11階)');
ok($zip->set_number('1006512')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(12階)');
ok($zip->set_number('1006513')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(13階)');
ok($zip->set_number('1006514')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(14階)');
ok($zip->set_number('1006515')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(15階)');
ok($zip->set_number('1006516')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(16階)');
ok($zip->set_number('1006517')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(17階)');
ok($zip->set_number('1006518')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(18階)');
ok($zip->set_number('1006519')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(19階)');
ok($zip->set_number('1006520')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(20階)');
ok($zip->set_number('1006521')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(21階)');
ok($zip->set_number('1006522')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(22階)');
ok($zip->set_number('1006523')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(23階)');
ok($zip->set_number('1006524')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(24階)');
ok($zip->set_number('1006525')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(25階)');
ok($zip->set_number('1006526')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(26階)');
ok($zip->set_number('1006527')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(27階)');
ok($zip->set_number('1006528')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(28階)');
ok($zip->set_number('1006529')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(29階)');
ok($zip->set_number('1006530')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(30階)');
ok($zip->set_number('1006531')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(31階)');
ok($zip->set_number('1006532')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(32階)');
ok($zip->set_number('1006533')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(33階)');
ok($zip->set_number('1006534')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(34階)');
ok($zip->set_number('1006535')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(35階)');
ok($zip->set_number('1006536')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(36階)');
ok($zip->set_number('1006537')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(37階)');
ok($zip->set_number('1006538')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(38階)');
ok($zip->set_number('1006590')->is_valid_number, '東京都千代田区丸の内新丸の内ビルディング(地階・階層不明)');
ok($zip->set_number('1006601')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(1階)');
ok($zip->set_number('1006602')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(2階)');
ok($zip->set_number('1006603')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(3階)');
ok($zip->set_number('1006604')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(4階)');
ok($zip->set_number('1006605')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(5階)');
ok($zip->set_number('1006606')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(6階)');
ok($zip->set_number('1006607')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(7階)');
ok($zip->set_number('1006608')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(8階)');
ok($zip->set_number('1006609')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(9階)');
ok($zip->set_number('1006610')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(10階)');
ok($zip->set_number('1006611')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(11階)');
ok($zip->set_number('1006612')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(12階)');
ok($zip->set_number('1006613')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(13階)');
ok($zip->set_number('1006614')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(14階)');
ok($zip->set_number('1006615')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(15階)');
ok($zip->set_number('1006616')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(16階)');
ok($zip->set_number('1006617')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(17階)');
ok($zip->set_number('1006618')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(18階)');
ok($zip->set_number('1006619')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(19階)');
ok($zip->set_number('1006620')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(20階)');
ok($zip->set_number('1006621')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(21階)');
ok($zip->set_number('1006622')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(22階)');
ok($zip->set_number('1006623')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(23階)');
ok($zip->set_number('1006624')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(24階)');
ok($zip->set_number('1006625')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(25階)');
ok($zip->set_number('1006626')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(26階)');
ok($zip->set_number('1006627')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(27階)');
ok($zip->set_number('1006628')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(28階)');
ok($zip->set_number('1006629')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(29階)');
ok($zip->set_number('1006630')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(30階)');
ok($zip->set_number('1006631')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(31階)');
ok($zip->set_number('1006632')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(32階)');
ok($zip->set_number('1006633')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(33階)');
ok($zip->set_number('1006634')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(34階)');
ok($zip->set_number('1006635')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(35階)');
ok($zip->set_number('1006636')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(36階)');
ok($zip->set_number('1006637')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(37階)');
ok($zip->set_number('1006638')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(38階)');
ok($zip->set_number('1006639')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(39階)');
ok($zip->set_number('1006640')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(40階)');
ok($zip->set_number('1006641')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(41階)');
ok($zip->set_number('1006642')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(42階)');
ok($zip->set_number('1006690')->is_valid_number, '東京都千代田区丸の内グラントウキョウサウスタワー(地階・階層不明)');
ok($zip->set_number('1006701')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(1階)');
ok($zip->set_number('1006702')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(2階)');
ok($zip->set_number('1006703')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(3階)');
ok($zip->set_number('1006704')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(4階)');
ok($zip->set_number('1006705')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(5階)');
ok($zip->set_number('1006706')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(6階)');
ok($zip->set_number('1006707')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(7階)');
ok($zip->set_number('1006708')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(8階)');
ok($zip->set_number('1006709')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(9階)');
ok($zip->set_number('1006710')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(10階)');
ok($zip->set_number('1006711')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(11階)');
ok($zip->set_number('1006712')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(12階)');
ok($zip->set_number('1006713')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(13階)');
ok($zip->set_number('1006714')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(14階)');
ok($zip->set_number('1006715')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(15階)');
ok($zip->set_number('1006716')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(16階)');
ok($zip->set_number('1006717')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(17階)');
ok($zip->set_number('1006718')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(18階)');
ok($zip->set_number('1006719')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(19階)');
ok($zip->set_number('1006720')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(20階)');
ok($zip->set_number('1006721')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(21階)');
ok($zip->set_number('1006722')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(22階)');
ok($zip->set_number('1006723')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(23階)');
ok($zip->set_number('1006724')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(24階)');
ok($zip->set_number('1006725')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(25階)');
ok($zip->set_number('1006726')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(26階)');
ok($zip->set_number('1006727')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(27階)');
ok($zip->set_number('1006728')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(28階)');
ok($zip->set_number('1006729')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(29階)');
ok($zip->set_number('1006730')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(30階)');
ok($zip->set_number('1006731')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(31階)');
ok($zip->set_number('1006732')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(32階)');
ok($zip->set_number('1006733')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(33階)');
ok($zip->set_number('1006734')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(34階)');
ok($zip->set_number('1006735')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(35階)');
ok($zip->set_number('1006736')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(36階)');
ok($zip->set_number('1006737')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(37階)');
ok($zip->set_number('1006738')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(38階)');
ok($zip->set_number('1006739')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(39階)');
ok($zip->set_number('1006740')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(40階)');
ok($zip->set_number('1006741')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(41階)');
ok($zip->set_number('1006742')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(42階)');
ok($zip->set_number('1006743')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(43階)');
ok($zip->set_number('1006790')->is_valid_number, '東京都千代田区丸の内グラントウキョウノースタワー(地階・階層不明)');
ok($zip->set_number('1006801')->is_valid_number, '東京都千代田区大手町JAビル(1階)');
ok($zip->set_number('1006802')->is_valid_number, '東京都千代田区大手町JAビル(2階)');
ok($zip->set_number('1006803')->is_valid_number, '東京都千代田区大手町JAビル(3階)');
ok($zip->set_number('1006804')->is_valid_number, '東京都千代田区大手町JAビル(4階)');
ok($zip->set_number('1006805')->is_valid_number, '東京都千代田区大手町JAビル(5階)');
ok($zip->set_number('1006806')->is_valid_number, '東京都千代田区大手町JAビル(6階)');
ok($zip->set_number('1006807')->is_valid_number, '東京都千代田区大手町JAビル(7階)');
ok($zip->set_number('1006808')->is_valid_number, '東京都千代田区大手町JAビル(8階)');
ok($zip->set_number('1006809')->is_valid_number, '東京都千代田区大手町JAビル(9階)');
ok($zip->set_number('1006810')->is_valid_number, '東京都千代田区大手町JAビル(10階)');
ok($zip->set_number('1006811')->is_valid_number, '東京都千代田区大手町JAビル(11階)');
ok($zip->set_number('1006812')->is_valid_number, '東京都千代田区大手町JAビル(12階)');
ok($zip->set_number('1006813')->is_valid_number, '東京都千代田区大手町JAビル(13階)');
ok($zip->set_number('1006814')->is_valid_number, '東京都千代田区大手町JAビル(14階)');
ok($zip->set_number('1006815')->is_valid_number, '東京都千代田区大手町JAビル(15階)');
ok($zip->set_number('1006816')->is_valid_number, '東京都千代田区大手町JAビル(16階)');
ok($zip->set_number('1006817')->is_valid_number, '東京都千代田区大手町JAビル(17階)');
ok($zip->set_number('1006818')->is_valid_number, '東京都千代田区大手町JAビル(18階)');
ok($zip->set_number('1006819')->is_valid_number, '東京都千代田区大手町JAビル(19階)');
ok($zip->set_number('1006820')->is_valid_number, '東京都千代田区大手町JAビル(20階)');
ok($zip->set_number('1006821')->is_valid_number, '東京都千代田区大手町JAビル(21階)');
ok($zip->set_number('1006822')->is_valid_number, '東京都千代田区大手町JAビル(22階)');
ok($zip->set_number('1006823')->is_valid_number, '東京都千代田区大手町JAビル(23階)');
ok($zip->set_number('1006824')->is_valid_number, '東京都千代田区大手町JAビル(24階)');
ok($zip->set_number('1006825')->is_valid_number, '東京都千代田区大手町JAビル(25階)');
ok($zip->set_number('1006826')->is_valid_number, '東京都千代田区大手町JAビル(26階)');
ok($zip->set_number('1006827')->is_valid_number, '東京都千代田区大手町JAビル(27階)');
ok($zip->set_number('1006828')->is_valid_number, '東京都千代田区大手町JAビル(28階)');
ok($zip->set_number('1006829')->is_valid_number, '東京都千代田区大手町JAビル(29階)');
ok($zip->set_number('1006830')->is_valid_number, '東京都千代田区大手町JAビル(30階)');
ok($zip->set_number('1006831')->is_valid_number, '東京都千代田区大手町JAビル(31階)');
ok($zip->set_number('1006832')->is_valid_number, '東京都千代田区大手町JAビル(32階)');
ok($zip->set_number('1006833')->is_valid_number, '東京都千代田区大手町JAビル(33階)');
ok($zip->set_number('1006834')->is_valid_number, '東京都千代田区大手町JAビル(34階)');
ok($zip->set_number('1006835')->is_valid_number, '東京都千代田区大手町JAビル(35階)');
ok($zip->set_number('1006836')->is_valid_number, '東京都千代田区大手町JAビル(36階)');
ok($zip->set_number('1006837')->is_valid_number, '東京都千代田区大手町JAビル(37階)');
ok($zip->set_number('1006890')->is_valid_number, '東京都千代田区大手町JAビル(地階・階層不明)');
ok($zip->set_number('1006901')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(1階)');
ok($zip->set_number('1006902')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(2階)');
ok($zip->set_number('1006903')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(3階)');
ok($zip->set_number('1006904')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(4階)');
ok($zip->set_number('1006905')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(5階)');
ok($zip->set_number('1006906')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(6階)');
ok($zip->set_number('1006907')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(7階)');
ok($zip->set_number('1006908')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(8階)');
ok($zip->set_number('1006909')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(9階)');
ok($zip->set_number('1006910')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(10階)');
ok($zip->set_number('1006911')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(11階)');
ok($zip->set_number('1006912')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(12階)');
ok($zip->set_number('1006913')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(13階)');
ok($zip->set_number('1006914')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(14階)');
ok($zip->set_number('1006915')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(15階)');
ok($zip->set_number('1006916')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(16階)');
ok($zip->set_number('1006917')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(17階)');
ok($zip->set_number('1006918')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(18階)');
ok($zip->set_number('1006919')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(19階)');
ok($zip->set_number('1006920')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(20階)');
ok($zip->set_number('1006921')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(21階)');
ok($zip->set_number('1006922')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(22階)');
ok($zip->set_number('1006923')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(23階)');
ok($zip->set_number('1006924')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(24階)');
ok($zip->set_number('1006925')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(25階)');
ok($zip->set_number('1006926')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(26階)');
ok($zip->set_number('1006927')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(27階)');
ok($zip->set_number('1006928')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(28階)');
ok($zip->set_number('1006929')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(29階)');
ok($zip->set_number('1006930')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(30階)');
ok($zip->set_number('1006931')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(31階)');
ok($zip->set_number('1006932')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(32階)');
ok($zip->set_number('1006933')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(33階)');
ok($zip->set_number('1006934')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(34階)');
ok($zip->set_number('1006990')->is_valid_number, '東京都千代田区丸の内丸の内パークビルディング(地階・階層不明)');
ok($zip->set_number('1007001')->is_valid_number, '東京都千代田区丸の内JPタワー(1階)');
ok($zip->set_number('1007002')->is_valid_number, '東京都千代田区丸の内JPタワー(2階)');
ok($zip->set_number('1007003')->is_valid_number, '東京都千代田区丸の内JPタワー(3階)');
ok($zip->set_number('1007004')->is_valid_number, '東京都千代田区丸の内JPタワー(4階)');
ok($zip->set_number('1007005')->is_valid_number, '東京都千代田区丸の内JPタワー(5階)');
ok($zip->set_number('1007006')->is_valid_number, '東京都千代田区丸の内JPタワー(6階)');
ok($zip->set_number('1007007')->is_valid_number, '東京都千代田区丸の内JPタワー(7階)');
ok($zip->set_number('1007008')->is_valid_number, '東京都千代田区丸の内JPタワー(8階)');
ok($zip->set_number('1007009')->is_valid_number, '東京都千代田区丸の内JPタワー(9階)');
ok($zip->set_number('1007010')->is_valid_number, '東京都千代田区丸の内JPタワー(10階)');
ok($zip->set_number('1007011')->is_valid_number, '東京都千代田区丸の内JPタワー(11階)');
ok($zip->set_number('1007012')->is_valid_number, '東京都千代田区丸の内JPタワー(12階)');
ok($zip->set_number('1007013')->is_valid_number, '東京都千代田区丸の内JPタワー(13階)');
ok($zip->set_number('1007014')->is_valid_number, '東京都千代田区丸の内JPタワー(14階)');
ok($zip->set_number('1007015')->is_valid_number, '東京都千代田区丸の内JPタワー(15階)');
ok($zip->set_number('1007016')->is_valid_number, '東京都千代田区丸の内JPタワー(16階)');
ok($zip->set_number('1007017')->is_valid_number, '東京都千代田区丸の内JPタワー(17階)');
ok($zip->set_number('1007018')->is_valid_number, '東京都千代田区丸の内JPタワー(18階)');
ok($zip->set_number('1007019')->is_valid_number, '東京都千代田区丸の内JPタワー(19階)');
ok($zip->set_number('1007020')->is_valid_number, '東京都千代田区丸の内JPタワー(20階)');
ok($zip->set_number('1007021')->is_valid_number, '東京都千代田区丸の内JPタワー(21階)');
ok($zip->set_number('1007022')->is_valid_number, '東京都千代田区丸の内JPタワー(22階)');
ok($zip->set_number('1007023')->is_valid_number, '東京都千代田区丸の内JPタワー(23階)');
ok($zip->set_number('1007024')->is_valid_number, '東京都千代田区丸の内JPタワー(24階)');
ok($zip->set_number('1007025')->is_valid_number, '東京都千代田区丸の内JPタワー(25階)');
ok($zip->set_number('1007026')->is_valid_number, '東京都千代田区丸の内JPタワー(26階)');
ok($zip->set_number('1007027')->is_valid_number, '東京都千代田区丸の内JPタワー(27階)');
ok($zip->set_number('1007028')->is_valid_number, '東京都千代田区丸の内JPタワー(28階)');
ok($zip->set_number('1007029')->is_valid_number, '東京都千代田区丸の内JPタワー(29階)');
ok($zip->set_number('1007030')->is_valid_number, '東京都千代田区丸の内JPタワー(30階)');
ok($zip->set_number('1007031')->is_valid_number, '東京都千代田区丸の内JPタワー(31階)');
ok($zip->set_number('1007032')->is_valid_number, '東京都千代田区丸の内JPタワー(32階)');
ok($zip->set_number('1007033')->is_valid_number, '東京都千代田区丸の内JPタワー(33階)');
ok($zip->set_number('1007034')->is_valid_number, '東京都千代田区丸の内JPタワー(34階)');
ok($zip->set_number('1007035')->is_valid_number, '東京都千代田区丸の内JPタワー(35階)');
ok($zip->set_number('1007036')->is_valid_number, '東京都千代田区丸の内JPタワー(36階)');
ok($zip->set_number('1007037')->is_valid_number, '東京都千代田区丸の内JPタワー(37階)');
ok($zip->set_number('1007038')->is_valid_number, '東京都千代田区丸の内JPタワー(38階)');
ok($zip->set_number('1007090')->is_valid_number, '東京都千代田区丸の内JPタワー(地階・階層不明)');
ok($zip->set_number('1010003')->is_valid_number, '東京都千代田区一ツ橋(2丁目)');
ok($zip->set_number('1010021')->is_valid_number, '東京都千代田区外神田');
ok($zip->set_number('1010022')->is_valid_number, '東京都千代田区神田練塀町');
ok($zip->set_number('1010023')->is_valid_number, '東京都千代田区神田松永町');
ok($zip->set_number('1010024')->is_valid_number, '東京都千代田区神田和泉町');
ok($zip->set_number('1010025')->is_valid_number, '東京都千代田区神田佐久間町');
ok($zip->set_number('1010026')->is_valid_number, '東京都千代田区神田佐久間河岸');
ok($zip->set_number('1010027')->is_valid_number, '東京都千代田区神田平河町');
ok($zip->set_number('1010028')->is_valid_number, '東京都千代田区神田花岡町');
ok($zip->set_number('1010029')->is_valid_number, '東京都千代田区神田相生町');
ok($zip->set_number('1010031')->is_valid_number, '東京都千代田区東神田');
ok($zip->set_number('1010032')->is_valid_number, '東京都千代田区岩本町');
ok($zip->set_number('1010033')->is_valid_number, '東京都千代田区神田岩本町');
ok($zip->set_number('1010034')->is_valid_number, '東京都千代田区神田東紺屋町');
ok($zip->set_number('1010035')->is_valid_number, '東京都千代田区神田紺屋町');
ok($zip->set_number('1010036')->is_valid_number, '東京都千代田区神田北乗物町');
ok($zip->set_number('1010037')->is_valid_number, '東京都千代田区神田西福田町');
ok($zip->set_number('1010038')->is_valid_number, '東京都千代田区神田美倉町');
ok($zip->set_number('1010041')->is_valid_number, '東京都千代田区神田須田町');
ok($zip->set_number('1010042')->is_valid_number, '東京都千代田区神田東松下町');
ok($zip->set_number('1010043')->is_valid_number, '東京都千代田区神田富山町');
ok($zip->set_number('1010044')->is_valid_number, '東京都千代田区鍛冶町');
ok($zip->set_number('1010045')->is_valid_number, '東京都千代田区神田鍛冶町');
ok($zip->set_number('1010046')->is_valid_number, '東京都千代田区神田多町');
ok($zip->set_number('1010047')->is_valid_number, '東京都千代田区内神田');
ok($zip->set_number('1010048')->is_valid_number, '東京都千代田区神田司町');
ok($zip->set_number('1010051')->is_valid_number, '東京都千代田区神田神保町');
ok($zip->set_number('1010052')->is_valid_number, '東京都千代田区神田小川町');
ok($zip->set_number('1010053')->is_valid_number, '東京都千代田区神田美土代町');
ok($zip->set_number('1010054')->is_valid_number, '東京都千代田区神田錦町');
ok($zip->set_number('1010061')->is_valid_number, '東京都千代田区神田三崎町');
ok($zip->set_number('1010062')->is_valid_number, '東京都千代田区神田駿河台');
ok($zip->set_number('1010063')->is_valid_number, '東京都千代田区神田淡路町');
ok($zip->set_number('1010064')->is_valid_number, '東京都千代田区神田猿楽町');
ok($zip->set_number('1010065')->is_valid_number, '東京都千代田区西神田');
ok($zip->set_number('1020071')->is_valid_number, '東京都千代田区富士見');
ok($zip->set_number('1020072')->is_valid_number, '東京都千代田区飯田橋');
ok($zip->set_number('1020073')->is_valid_number, '東京都千代田区九段北');
ok($zip->set_number('1020074')->is_valid_number, '東京都千代田区九段南');
ok($zip->set_number('1020075')->is_valid_number, '東京都千代田区三番町');
ok($zip->set_number('1020076')->is_valid_number, '東京都千代田区五番町');
ok($zip->set_number('1020081')->is_valid_number, '東京都千代田区四番町');
ok($zip->set_number('1020082')->is_valid_number, '東京都千代田区一番町');
ok($zip->set_number('1020083')->is_valid_number, '東京都千代田区麹町');
ok($zip->set_number('1020084')->is_valid_number, '東京都千代田区二番町');
ok($zip->set_number('1020085')->is_valid_number, '東京都千代田区六番町');
ok($zip->set_number('1020091')->is_valid_number, '東京都千代田区北の丸公園');
ok($zip->set_number('1020092')->is_valid_number, '東京都千代田区隼町');
ok($zip->set_number('1020093')->is_valid_number, '東京都千代田区平河町');
ok($zip->set_number('1020094')->is_valid_number, '東京都千代田区紀尾井町');
ok($zip->set_number('1030000')->is_valid_number, '東京都中央区以下に掲載がない場合');
ok($zip->set_number('1030001')->is_valid_number, '東京都中央区日本橋小伝馬町');
ok($zip->set_number('1030002')->is_valid_number, '東京都中央区日本橋馬喰町');
ok($zip->set_number('1030003')->is_valid_number, '東京都中央区日本橋横山町');
ok($zip->set_number('1030004')->is_valid_number, '東京都中央区東日本橋');
ok($zip->set_number('1030005')->is_valid_number, '東京都中央区日本橋久松町');
ok($zip->set_number('1030006')->is_valid_number, '東京都中央区日本橋富沢町');
ok($zip->set_number('1030007')->is_valid_number, '東京都中央区日本橋浜町');
ok($zip->set_number('1030008')->is_valid_number, '東京都中央区日本橋中洲');
ok($zip->set_number('1030011')->is_valid_number, '東京都中央区日本橋大伝馬町');
ok($zip->set_number('1030012')->is_valid_number, '東京都中央区日本橋堀留町');
ok($zip->set_number('1030013')->is_valid_number, '東京都中央区日本橋人形町');
ok($zip->set_number('1030014')->is_valid_number, '東京都中央区日本橋蛎殻町');
ok($zip->set_number('1030015')->is_valid_number, '東京都中央区日本橋箱崎町');
ok($zip->set_number('1030016')->is_valid_number, '東京都中央区日本橋小網町');
ok($zip->set_number('1030021')->is_valid_number, '東京都中央区日本橋本石町');
ok($zip->set_number('1030022')->is_valid_number, '東京都中央区日本橋室町');
ok($zip->set_number('1030023')->is_valid_number, '東京都中央区日本橋本町');
ok($zip->set_number('1030024')->is_valid_number, '東京都中央区日本橋小舟町');
ok($zip->set_number('1030025')->is_valid_number, '東京都中央区日本橋茅場町');
ok($zip->set_number('1030026')->is_valid_number, '東京都中央区日本橋兜町');
ok($zip->set_number('1030027')->is_valid_number, '東京都中央区日本橋(次のビルを除く)');
ok($zip->set_number('1030028')->is_valid_number, '東京都中央区八重洲(1丁目)');
ok($zip->set_number('1036001')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(1階)');
ok($zip->set_number('1036002')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(2階)');
ok($zip->set_number('1036003')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(3階)');
ok($zip->set_number('1036004')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(4階)');
ok($zip->set_number('1036005')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(5階)');
ok($zip->set_number('1036006')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(6階)');
ok($zip->set_number('1036007')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(7階)');
ok($zip->set_number('1036008')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(8階)');
ok($zip->set_number('1036009')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(9階)');
ok($zip->set_number('1036010')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(10階)');
ok($zip->set_number('1036011')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(11階)');
ok($zip->set_number('1036012')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(12階)');
ok($zip->set_number('1036013')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(13階)');
ok($zip->set_number('1036014')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(14階)');
ok($zip->set_number('1036015')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(15階)');
ok($zip->set_number('1036016')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(16階)');
ok($zip->set_number('1036017')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(17階)');
ok($zip->set_number('1036018')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(18階)');
ok($zip->set_number('1036019')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(19階)');
ok($zip->set_number('1036020')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(20階)');
ok($zip->set_number('1036021')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(21階)');
ok($zip->set_number('1036022')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(22階)');
ok($zip->set_number('1036023')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(23階)');
ok($zip->set_number('1036024')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(24階)');
ok($zip->set_number('1036025')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(25階)');
ok($zip->set_number('1036026')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(26階)');
ok($zip->set_number('1036027')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(27階)');
ok($zip->set_number('1036028')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(28階)');
ok($zip->set_number('1036029')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(29階)');
ok($zip->set_number('1036030')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(30階)');
ok($zip->set_number('1036031')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(31階)');
ok($zip->set_number('1036032')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(32階)');
ok($zip->set_number('1036033')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(33階)');
ok($zip->set_number('1036034')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(34階)');
ok($zip->set_number('1036035')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(35階)');
ok($zip->set_number('1036090')->is_valid_number, '東京都中央区日本橋東京日本橋タワー(地階・階層不明)');
ok($zip->set_number('1036101')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(1階)');
ok($zip->set_number('1036102')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(2階)');
ok($zip->set_number('1036103')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(3階)');
ok($zip->set_number('1036104')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(4階)');
ok($zip->set_number('1036105')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(5階)');
ok($zip->set_number('1036106')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(6階)');
ok($zip->set_number('1036107')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(7階)');
ok($zip->set_number('1036108')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(8階)');
ok($zip->set_number('1036109')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(9階)');
ok($zip->set_number('1036110')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(10階)');
ok($zip->set_number('1036111')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(11階)');
ok($zip->set_number('1036112')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(12階)');
ok($zip->set_number('1036113')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(13階)');
ok($zip->set_number('1036114')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(14階)');
ok($zip->set_number('1036115')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(15階)');
ok($zip->set_number('1036116')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(16階)');
ok($zip->set_number('1036117')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(17階)');
ok($zip->set_number('1036118')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(18階)');
ok($zip->set_number('1036119')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(19階)');
ok($zip->set_number('1036120')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(20階)');
ok($zip->set_number('1036121')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(21階)');
ok($zip->set_number('1036122')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(22階)');
ok($zip->set_number('1036123')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(23階)');
ok($zip->set_number('1036124')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(24階)');
ok($zip->set_number('1036125')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(25階)');
ok($zip->set_number('1036126')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(26階)');
ok($zip->set_number('1036127')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(27階)');
ok($zip->set_number('1036128')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(28階)');
ok($zip->set_number('1036129')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(29階)');
ok($zip->set_number('1036130')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(30階)');
ok($zip->set_number('1036131')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(31階)');
ok($zip->set_number('1036132')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(32階)');
ok($zip->set_number('1036190')->is_valid_number, '東京都中央区日本橋日本橋高島屋三井ビルディング(地階・階層不明)');
ok($zip->set_number('1040028')->is_valid_number, '東京都中央区八重洲(2丁目)');
ok($zip->set_number('1040031')->is_valid_number, '東京都中央区京橋');
ok($zip->set_number('1040032')->is_valid_number, '東京都中央区八丁堀');
ok($zip->set_number('1040033')->is_valid_number, '東京都中央区新川');
ok($zip->set_number('1040041')->is_valid_number, '東京都中央区新富');
ok($zip->set_number('1040042')->is_valid_number, '東京都中央区入船');
ok($zip->set_number('1040043')->is_valid_number, '東京都中央区湊');
ok($zip->set_number('1040044')->is_valid_number, '東京都中央区明石町');
ok($zip->set_number('1040045')->is_valid_number, '東京都中央区築地');
ok($zip->set_number('1040046')->is_valid_number, '東京都中央区浜離宮庭園');
ok($zip->set_number('1040051')->is_valid_number, '東京都中央区佃');
ok($zip->set_number('1040052')->is_valid_number, '東京都中央区月島');
ok($zip->set_number('1040053')->is_valid_number, '東京都中央区晴海(次のビルを除く)');
ok($zip->set_number('1040054')->is_valid_number, '東京都中央区勝どき');
ok($zip->set_number('1040055')->is_valid_number, '東京都中央区豊海町');
ok($zip->set_number('1040061')->is_valid_number, '東京都中央区銀座');
ok($zip->set_number('1046001')->is_valid_number, '東京都中央区晴海オフィスタワーX(1階)');
ok($zip->set_number('1046002')->is_valid_number, '東京都中央区晴海オフィスタワーX(2階)');
ok($zip->set_number('1046003')->is_valid_number, '東京都中央区晴海オフィスタワーX(3階)');
ok($zip->set_number('1046004')->is_valid_number, '東京都中央区晴海オフィスタワーX(4階)');
ok($zip->set_number('1046005')->is_valid_number, '東京都中央区晴海オフィスタワーX(5階)');
ok($zip->set_number('1046006')->is_valid_number, '東京都中央区晴海オフィスタワーX(6階)');
ok($zip->set_number('1046007')->is_valid_number, '東京都中央区晴海オフィスタワーX(7階)');
ok($zip->set_number('1046008')->is_valid_number, '東京都中央区晴海オフィスタワーX(8階)');
ok($zip->set_number('1046009')->is_valid_number, '東京都中央区晴海オフィスタワーX(9階)');
ok($zip->set_number('1046010')->is_valid_number, '東京都中央区晴海オフィスタワーX(10階)');
ok($zip->set_number('1046011')->is_valid_number, '東京都中央区晴海オフィスタワーX(11階)');
ok($zip->set_number('1046012')->is_valid_number, '東京都中央区晴海オフィスタワーX(12階)');
ok($zip->set_number('1046013')->is_valid_number, '東京都中央区晴海オフィスタワーX(13階)');
ok($zip->set_number('1046014')->is_valid_number, '東京都中央区晴海オフィスタワーX(14階)');
ok($zip->set_number('1046015')->is_valid_number, '東京都中央区晴海オフィスタワーX(15階)');
ok($zip->set_number('1046016')->is_valid_number, '東京都中央区晴海オフィスタワーX(16階)');
ok($zip->set_number('1046017')->is_valid_number, '東京都中央区晴海オフィスタワーX(17階)');
ok($zip->set_number('1046018')->is_valid_number, '東京都中央区晴海オフィスタワーX(18階)');
ok($zip->set_number('1046019')->is_valid_number, '東京都中央区晴海オフィスタワーX(19階)');
ok($zip->set_number('1046020')->is_valid_number, '東京都中央区晴海オフィスタワーX(20階)');
ok($zip->set_number('1046021')->is_valid_number, '東京都中央区晴海オフィスタワーX(21階)');
ok($zip->set_number('1046022')->is_valid_number, '東京都中央区晴海オフィスタワーX(22階)');
ok($zip->set_number('1046023')->is_valid_number, '東京都中央区晴海オフィスタワーX(23階)');
ok($zip->set_number('1046024')->is_valid_number, '東京都中央区晴海オフィスタワーX(24階)');
ok($zip->set_number('1046025')->is_valid_number, '東京都中央区晴海オフィスタワーX(25階)');
ok($zip->set_number('1046026')->is_valid_number, '東京都中央区晴海オフィスタワーX(26階)');
ok($zip->set_number('1046027')->is_valid_number, '東京都中央区晴海オフィスタワーX(27階)');
ok($zip->set_number('1046028')->is_valid_number, '東京都中央区晴海オフィスタワーX(28階)');
ok($zip->set_number('1046029')->is_valid_number, '東京都中央区晴海オフィスタワーX(29階)');
ok($zip->set_number('1046030')->is_valid_number, '東京都中央区晴海オフィスタワーX(30階)');
ok($zip->set_number('1046031')->is_valid_number, '東京都中央区晴海オフィスタワーX(31階)');
ok($zip->set_number('1046032')->is_valid_number, '東京都中央区晴海オフィスタワーX(32階)');
ok($zip->set_number('1046033')->is_valid_number, '東京都中央区晴海オフィスタワーX(33階)');
ok($zip->set_number('1046034')->is_valid_number, '東京都中央区晴海オフィスタワーX(34階)');
ok($zip->set_number('1046035')->is_valid_number, '東京都中央区晴海オフィスタワーX(35階)');
ok($zip->set_number('1046036')->is_valid_number, '東京都中央区晴海オフィスタワーX(36階)');
ok($zip->set_number('1046037')->is_valid_number, '東京都中央区晴海オフィスタワーX(37階)');
ok($zip->set_number('1046038')->is_valid_number, '東京都中央区晴海オフィスタワーX(38階)');
ok($zip->set_number('1046039')->is_valid_number, '東京都中央区晴海オフィスタワーX(39階)');
ok($zip->set_number('1046040')->is_valid_number, '東京都中央区晴海オフィスタワーX(40階)');
ok($zip->set_number('1046041')->is_valid_number, '東京都中央区晴海オフィスタワーX(41階)');
ok($zip->set_number('1046042')->is_valid_number, '東京都中央区晴海オフィスタワーX(42階)');
ok($zip->set_number('1046043')->is_valid_number, '東京都中央区晴海オフィスタワーX(43階)');
ok($zip->set_number('1046044')->is_valid_number, '東京都中央区晴海オフィスタワーX(44階)');
ok($zip->set_number('1046090')->is_valid_number, '東京都中央区晴海オフィスタワーX(地階・階層不明)');
ok($zip->set_number('1046101')->is_valid_number, '東京都中央区晴海オフィスタワーY(1階)');
ok($zip->set_number('1046102')->is_valid_number, '東京都中央区晴海オフィスタワーY(2階)');
ok($zip->set_number('1046103')->is_valid_number, '東京都中央区晴海オフィスタワーY(3階)');
ok($zip->set_number('1046104')->is_valid_number, '東京都中央区晴海オフィスタワーY(4階)');
ok($zip->set_number('1046105')->is_valid_number, '東京都中央区晴海オフィスタワーY(5階)');
ok($zip->set_number('1046106')->is_valid_number, '東京都中央区晴海オフィスタワーY(6階)');
ok($zip->set_number('1046107')->is_valid_number, '東京都中央区晴海オフィスタワーY(7階)');
ok($zip->set_number('1046108')->is_valid_number, '東京都中央区晴海オフィスタワーY(8階)');
ok($zip->set_number('1046109')->is_valid_number, '東京都中央区晴海オフィスタワーY(9階)');
ok($zip->set_number('1046110')->is_valid_number, '東京都中央区晴海オフィスタワーY(10階)');
ok($zip->set_number('1046111')->is_valid_number, '東京都中央区晴海オフィスタワーY(11階)');
ok($zip->set_number('1046112')->is_valid_number, '東京都中央区晴海オフィスタワーY(12階)');
ok($zip->set_number('1046113')->is_valid_number, '東京都中央区晴海オフィスタワーY(13階)');
ok($zip->set_number('1046114')->is_valid_number, '東京都中央区晴海オフィスタワーY(14階)');
ok($zip->set_number('1046115')->is_valid_number, '東京都中央区晴海オフィスタワーY(15階)');
ok($zip->set_number('1046116')->is_valid_number, '東京都中央区晴海オフィスタワーY(16階)');
ok($zip->set_number('1046117')->is_valid_number, '東京都中央区晴海オフィスタワーY(17階)');
ok($zip->set_number('1046118')->is_valid_number, '東京都中央区晴海オフィスタワーY(18階)');
ok($zip->set_number('1046119')->is_valid_number, '東京都中央区晴海オフィスタワーY(19階)');
ok($zip->set_number('1046120')->is_valid_number, '東京都中央区晴海オフィスタワーY(20階)');
ok($zip->set_number('1046121')->is_valid_number, '東京都中央区晴海オフィスタワーY(21階)');
ok($zip->set_number('1046122')->is_valid_number, '東京都中央区晴海オフィスタワーY(22階)');
ok($zip->set_number('1046123')->is_valid_number, '東京都中央区晴海オフィスタワーY(23階)');
ok($zip->set_number('1046124')->is_valid_number, '東京都中央区晴海オフィスタワーY(24階)');
ok($zip->set_number('1046125')->is_valid_number, '東京都中央区晴海オフィスタワーY(25階)');
ok($zip->set_number('1046126')->is_valid_number, '東京都中央区晴海オフィスタワーY(26階)');
ok($zip->set_number('1046127')->is_valid_number, '東京都中央区晴海オフィスタワーY(27階)');
ok($zip->set_number('1046128')->is_valid_number, '東京都中央区晴海オフィスタワーY(28階)');
ok($zip->set_number('1046129')->is_valid_number, '東京都中央区晴海オフィスタワーY(29階)');
ok($zip->set_number('1046130')->is_valid_number, '東京都中央区晴海オフィスタワーY(30階)');
ok($zip->set_number('1046131')->is_valid_number, '東京都中央区晴海オフィスタワーY(31階)');
ok($zip->set_number('1046132')->is_valid_number, '東京都中央区晴海オフィスタワーY(32階)');
ok($zip->set_number('1046133')->is_valid_number, '東京都中央区晴海オフィスタワーY(33階)');
ok($zip->set_number('1046134')->is_valid_number, '東京都中央区晴海オフィスタワーY(34階)');
ok($zip->set_number('1046135')->is_valid_number, '東京都中央区晴海オフィスタワーY(35階)');
ok($zip->set_number('1046136')->is_valid_number, '東京都中央区晴海オフィスタワーY(36階)');
ok($zip->set_number('1046137')->is_valid_number, '東京都中央区晴海オフィスタワーY(37階)');
ok($zip->set_number('1046138')->is_valid_number, '東京都中央区晴海オフィスタワーY(38階)');
ok($zip->set_number('1046139')->is_valid_number, '東京都中央区晴海オフィスタワーY(39階)');
ok($zip->set_number('1046190')->is_valid_number, '東京都中央区晴海オフィスタワーY(地階・階層不明)');
ok($zip->set_number('1046201')->is_valid_number, '東京都中央区晴海オフィスタワーZ(1階)');
ok($zip->set_number('1046202')->is_valid_number, '東京都中央区晴海オフィスタワーZ(2階)');
ok($zip->set_number('1046203')->is_valid_number, '東京都中央区晴海オフィスタワーZ(3階)');
ok($zip->set_number('1046204')->is_valid_number, '東京都中央区晴海オフィスタワーZ(4階)');
ok($zip->set_number('1046205')->is_valid_number, '東京都中央区晴海オフィスタワーZ(5階)');
ok($zip->set_number('1046206')->is_valid_number, '東京都中央区晴海オフィスタワーZ(6階)');
ok($zip->set_number('1046207')->is_valid_number, '東京都中央区晴海オフィスタワーZ(7階)');
ok($zip->set_number('1046208')->is_valid_number, '東京都中央区晴海オフィスタワーZ(8階)');
ok($zip->set_number('1046209')->is_valid_number, '東京都中央区晴海オフィスタワーZ(9階)');
ok($zip->set_number('1046210')->is_valid_number, '東京都中央区晴海オフィスタワーZ(10階)');
ok($zip->set_number('1046211')->is_valid_number, '東京都中央区晴海オフィスタワーZ(11階)');
ok($zip->set_number('1046212')->is_valid_number, '東京都中央区晴海オフィスタワーZ(12階)');
ok($zip->set_number('1046213')->is_valid_number, '東京都中央区晴海オフィスタワーZ(13階)');
ok($zip->set_number('1046214')->is_valid_number, '東京都中央区晴海オフィスタワーZ(14階)');
ok($zip->set_number('1046215')->is_valid_number, '東京都中央区晴海オフィスタワーZ(15階)');
ok($zip->set_number('1046216')->is_valid_number, '東京都中央区晴海オフィスタワーZ(16階)');
ok($zip->set_number('1046217')->is_valid_number, '東京都中央区晴海オフィスタワーZ(17階)');
ok($zip->set_number('1046218')->is_valid_number, '東京都中央区晴海オフィスタワーZ(18階)');
ok($zip->set_number('1046219')->is_valid_number, '東京都中央区晴海オフィスタワーZ(19階)');
ok($zip->set_number('1046220')->is_valid_number, '東京都中央区晴海オフィスタワーZ(20階)');
ok($zip->set_number('1046221')->is_valid_number, '東京都中央区晴海オフィスタワーZ(21階)');
ok($zip->set_number('1046222')->is_valid_number, '東京都中央区晴海オフィスタワーZ(22階)');
ok($zip->set_number('1046223')->is_valid_number, '東京都中央区晴海オフィスタワーZ(23階)');
ok($zip->set_number('1046224')->is_valid_number, '東京都中央区晴海オフィスタワーZ(24階)');
ok($zip->set_number('1046225')->is_valid_number, '東京都中央区晴海オフィスタワーZ(25階)');
ok($zip->set_number('1046226')->is_valid_number, '東京都中央区晴海オフィスタワーZ(26階)');
ok($zip->set_number('1046227')->is_valid_number, '東京都中央区晴海オフィスタワーZ(27階)');
ok($zip->set_number('1046228')->is_valid_number, '東京都中央区晴海オフィスタワーZ(28階)');
ok($zip->set_number('1046229')->is_valid_number, '東京都中央区晴海オフィスタワーZ(29階)');
ok($zip->set_number('1046230')->is_valid_number, '東京都中央区晴海オフィスタワーZ(30階)');
ok($zip->set_number('1046231')->is_valid_number, '東京都中央区晴海オフィスタワーZ(31階)');
ok($zip->set_number('1046232')->is_valid_number, '東京都中央区晴海オフィスタワーZ(32階)');
ok($zip->set_number('1046233')->is_valid_number, '東京都中央区晴海オフィスタワーZ(33階)');
ok($zip->set_number('1046290')->is_valid_number, '東京都中央区晴海オフィスタワーZ(地階・階層不明)');
ok($zip->set_number('1050000')->is_valid_number, '東京都港区以下に掲載がない場合');
ok($zip->set_number('1050001')->is_valid_number, '東京都港区虎ノ門(次のビルを除く)');
ok($zip->set_number('1050002')->is_valid_number, '東京都港区愛宕(次のビルを除く)');
ok($zip->set_number('1050003')->is_valid_number, '東京都港区西新橋');
ok($zip->set_number('1050004')->is_valid_number, '東京都港区新橋');
ok($zip->set_number('1050011')->is_valid_number, '東京都港区芝公園');
ok($zip->set_number('1050012')->is_valid_number, '東京都港区芝大門');
ok($zip->set_number('1050013')->is_valid_number, '東京都港区浜松町(次のビルを除く)');
ok($zip->set_number('1050014')->is_valid_number, '東京都港区芝(1~3丁目)');
ok($zip->set_number('1050021')->is_valid_number, '東京都港区東新橋(次のビルを除く)');
ok($zip->set_number('1050022')->is_valid_number, '東京都港区海岸(1、2丁目)');
ok($zip->set_number('1050023')->is_valid_number, '東京都港区芝浦(1丁目)');
ok($zip->set_number('1055101')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(1階)');
ok($zip->set_number('1055102')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(2階)');
ok($zip->set_number('1055103')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(3階)');
ok($zip->set_number('1055104')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(4階)');
ok($zip->set_number('1055105')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(5階)');
ok($zip->set_number('1055106')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(6階)');
ok($zip->set_number('1055107')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(7階)');
ok($zip->set_number('1055108')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(8階)');
ok($zip->set_number('1055109')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(9階)');
ok($zip->set_number('1055110')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(10階)');
ok($zip->set_number('1055111')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(11階)');
ok($zip->set_number('1055112')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(12階)');
ok($zip->set_number('1055113')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(13階)');
ok($zip->set_number('1055114')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(14階)');
ok($zip->set_number('1055115')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(15階)');
ok($zip->set_number('1055116')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(16階)');
ok($zip->set_number('1055117')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(17階)');
ok($zip->set_number('1055118')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(18階)');
ok($zip->set_number('1055119')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(19階)');
ok($zip->set_number('1055120')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(20階)');
ok($zip->set_number('1055121')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(21階)');
ok($zip->set_number('1055122')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(22階)');
ok($zip->set_number('1055123')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(23階)');
ok($zip->set_number('1055124')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(24階)');
ok($zip->set_number('1055125')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(25階)');
ok($zip->set_number('1055126')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(26階)');
ok($zip->set_number('1055127')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(27階)');
ok($zip->set_number('1055128')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(28階)');
ok($zip->set_number('1055129')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(29階)');
ok($zip->set_number('1055130')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(30階)');
ok($zip->set_number('1055131')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(31階)');
ok($zip->set_number('1055132')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(32階)');
ok($zip->set_number('1055133')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(33階)');
ok($zip->set_number('1055134')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(34階)');
ok($zip->set_number('1055135')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(35階)');
ok($zip->set_number('1055136')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(36階)');
ok($zip->set_number('1055137')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(37階)');
ok($zip->set_number('1055138')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(38階)');
ok($zip->set_number('1055190')->is_valid_number, '東京都港区浜松町世界貿易センタービルディング南館(地階・階層不明)');
ok($zip->set_number('1055501')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(1階)');
ok($zip->set_number('1055502')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(2階)');
ok($zip->set_number('1055503')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(3階)');
ok($zip->set_number('1055504')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(4階)');
ok($zip->set_number('1055505')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(5階)');
ok($zip->set_number('1055506')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(6階)');
ok($zip->set_number('1055507')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(7階)');
ok($zip->set_number('1055508')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(8階)');
ok($zip->set_number('1055509')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(9階)');
ok($zip->set_number('1055510')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(10階)');
ok($zip->set_number('1055515')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(15階)');
ok($zip->set_number('1055516')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(16階)');
ok($zip->set_number('1055517')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(17階)');
ok($zip->set_number('1055518')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(18階)');
ok($zip->set_number('1055519')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(19階)');
ok($zip->set_number('1055520')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(20階)');
ok($zip->set_number('1055521')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(21階)');
ok($zip->set_number('1055522')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(22階)');
ok($zip->set_number('1055523')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(23階)');
ok($zip->set_number('1055524')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(24階)');
ok($zip->set_number('1055525')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(25階)');
ok($zip->set_number('1055526')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(26階)');
ok($zip->set_number('1055527')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(27階)');
ok($zip->set_number('1055528')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(28階)');
ok($zip->set_number('1055529')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(29階)');
ok($zip->set_number('1055530')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(30階)');
ok($zip->set_number('1055531')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(31階)');
ok($zip->set_number('1055532')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(32階)');
ok($zip->set_number('1055533')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(33階)');
ok($zip->set_number('1055534')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(34階)');
ok($zip->set_number('1055535')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(35階)');
ok($zip->set_number('1055536')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(36階)');
ok($zip->set_number('1055537')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(37階)');
ok($zip->set_number('1055538')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(38階)');
ok($zip->set_number('1055539')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(39階)');
ok($zip->set_number('1055540')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(40階)');
ok($zip->set_number('1055541')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(41階)');
ok($zip->set_number('1055542')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(42階)');
ok($zip->set_number('1055543')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(43階)');
ok($zip->set_number('1055544')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(44階)');
ok($zip->set_number('1055545')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(45階)');
ok($zip->set_number('1055546')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(46階)');
ok($zip->set_number('1055547')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(47階)');
ok($zip->set_number('1055548')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(48階)');
ok($zip->set_number('1055549')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(49階)');
ok($zip->set_number('1055590')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズステーションタワー(地階・階層不明)');
ok($zip->set_number('1056001')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(1階)');
ok($zip->set_number('1056002')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(2階)');
ok($zip->set_number('1056003')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(3階)');
ok($zip->set_number('1056004')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(4階)');
ok($zip->set_number('1056005')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(5階)');
ok($zip->set_number('1056006')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(6階)');
ok($zip->set_number('1056007')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(7階)');
ok($zip->set_number('1056008')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(8階)');
ok($zip->set_number('1056009')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(9階)');
ok($zip->set_number('1056010')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(10階)');
ok($zip->set_number('1056011')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(11階)');
ok($zip->set_number('1056012')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(12階)');
ok($zip->set_number('1056013')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(13階)');
ok($zip->set_number('1056014')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(14階)');
ok($zip->set_number('1056015')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(15階)');
ok($zip->set_number('1056016')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(16階)');
ok($zip->set_number('1056017')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(17階)');
ok($zip->set_number('1056018')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(18階)');
ok($zip->set_number('1056019')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(19階)');
ok($zip->set_number('1056020')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(20階)');
ok($zip->set_number('1056021')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(21階)');
ok($zip->set_number('1056022')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(22階)');
ok($zip->set_number('1056023')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(23階)');
ok($zip->set_number('1056024')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(24階)');
ok($zip->set_number('1056025')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(25階)');
ok($zip->set_number('1056026')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(26階)');
ok($zip->set_number('1056027')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(27階)');
ok($zip->set_number('1056028')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(28階)');
ok($zip->set_number('1056029')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(29階)');
ok($zip->set_number('1056030')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(30階)');
ok($zip->set_number('1056031')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(31階)');
ok($zip->set_number('1056032')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(32階)');
ok($zip->set_number('1056033')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(33階)');
ok($zip->set_number('1056034')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(34階)');
ok($zip->set_number('1056035')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(35階)');
ok($zip->set_number('1056036')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(36階)');
ok($zip->set_number('1056037')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(37階)');
ok($zip->set_number('1056090')->is_valid_number, '東京都港区虎ノ門城山トラストタワー(地階・階層不明)');
ok($zip->set_number('1056201')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(1階)');
ok($zip->set_number('1056202')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(2階)');
ok($zip->set_number('1056203')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(3階)');
ok($zip->set_number('1056204')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(4階)');
ok($zip->set_number('1056205')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(5階)');
ok($zip->set_number('1056206')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(6階)');
ok($zip->set_number('1056207')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(7階)');
ok($zip->set_number('1056208')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(8階)');
ok($zip->set_number('1056209')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(9階)');
ok($zip->set_number('1056210')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(10階)');
ok($zip->set_number('1056211')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(11階)');
ok($zip->set_number('1056212')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(12階)');
ok($zip->set_number('1056213')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(13階)');
ok($zip->set_number('1056214')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(14階)');
ok($zip->set_number('1056215')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(15階)');
ok($zip->set_number('1056216')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(16階)');
ok($zip->set_number('1056217')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(17階)');
ok($zip->set_number('1056218')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(18階)');
ok($zip->set_number('1056219')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(19階)');
ok($zip->set_number('1056220')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(20階)');
ok($zip->set_number('1056221')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(21階)');
ok($zip->set_number('1056222')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(22階)');
ok($zip->set_number('1056223')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(23階)');
ok($zip->set_number('1056224')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(24階)');
ok($zip->set_number('1056225')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(25階)');
ok($zip->set_number('1056226')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(26階)');
ok($zip->set_number('1056227')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(27階)');
ok($zip->set_number('1056228')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(28階)');
ok($zip->set_number('1056229')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(29階)');
ok($zip->set_number('1056230')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(30階)');
ok($zip->set_number('1056231')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(31階)');
ok($zip->set_number('1056232')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(32階)');
ok($zip->set_number('1056233')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(33階)');
ok($zip->set_number('1056234')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(34階)');
ok($zip->set_number('1056235')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(35階)');
ok($zip->set_number('1056236')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(36階)');
ok($zip->set_number('1056237')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(37階)');
ok($zip->set_number('1056238')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(38階)');
ok($zip->set_number('1056239')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(39階)');
ok($zip->set_number('1056240')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(40階)');
ok($zip->set_number('1056241')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(41階)');
ok($zip->set_number('1056242')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(42階)');
ok($zip->set_number('1056290')->is_valid_number, '東京都港区愛宕愛宕グリーンヒルズMORIタワー(地階・階層不明)');
ok($zip->set_number('1056301')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(1階)');
ok($zip->set_number('1056302')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(2階)');
ok($zip->set_number('1056303')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(3階)');
ok($zip->set_number('1056304')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(4階)');
ok($zip->set_number('1056305')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(5階)');
ok($zip->set_number('1056306')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(6階)');
ok($zip->set_number('1056307')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(7階)');
ok($zip->set_number('1056308')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(8階)');
ok($zip->set_number('1056309')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(9階)');
ok($zip->set_number('1056310')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(10階)');
ok($zip->set_number('1056311')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(11階)');
ok($zip->set_number('1056312')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(12階)');
ok($zip->set_number('1056313')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(13階)');
ok($zip->set_number('1056314')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(14階)');
ok($zip->set_number('1056315')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(15階)');
ok($zip->set_number('1056316')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(16階)');
ok($zip->set_number('1056317')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(17階)');
ok($zip->set_number('1056318')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(18階)');
ok($zip->set_number('1056319')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(19階)');
ok($zip->set_number('1056320')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(20階)');
ok($zip->set_number('1056321')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(21階)');
ok($zip->set_number('1056322')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(22階)');
ok($zip->set_number('1056323')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(23階)');
ok($zip->set_number('1056324')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(24階)');
ok($zip->set_number('1056325')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(25階)');
ok($zip->set_number('1056326')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(26階)');
ok($zip->set_number('1056327')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(27階)');
ok($zip->set_number('1056328')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(28階)');
ok($zip->set_number('1056329')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(29階)');
ok($zip->set_number('1056330')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(30階)');
ok($zip->set_number('1056331')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(31階)');
ok($zip->set_number('1056332')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(32階)');
ok($zip->set_number('1056333')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(33階)');
ok($zip->set_number('1056334')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(34階)');
ok($zip->set_number('1056335')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(35階)');
ok($zip->set_number('1056336')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(36階)');
ok($zip->set_number('1056390')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズ森タワー(地階・階層不明)');
ok($zip->set_number('1056401')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(1階)');
ok($zip->set_number('1056402')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(2階)');
ok($zip->set_number('1056403')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(3階)');
ok($zip->set_number('1056404')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(4階)');
ok($zip->set_number('1056405')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(5階)');
ok($zip->set_number('1056406')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(6階)');
ok($zip->set_number('1056407')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(7階)');
ok($zip->set_number('1056408')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(8階)');
ok($zip->set_number('1056409')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(9階)');
ok($zip->set_number('1056410')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(10階)');
ok($zip->set_number('1056411')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(11階)');
ok($zip->set_number('1056412')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(12階)');
ok($zip->set_number('1056413')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(13階)');
ok($zip->set_number('1056414')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(14階)');
ok($zip->set_number('1056415')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(15階)');
ok($zip->set_number('1056416')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(16階)');
ok($zip->set_number('1056417')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(17階)');
ok($zip->set_number('1056418')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(18階)');
ok($zip->set_number('1056419')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(19階)');
ok($zip->set_number('1056420')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(20階)');
ok($zip->set_number('1056421')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(21階)');
ok($zip->set_number('1056422')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(22階)');
ok($zip->set_number('1056423')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(23階)');
ok($zip->set_number('1056424')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(24階)');
ok($zip->set_number('1056425')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(25階)');
ok($zip->set_number('1056426')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(26階)');
ok($zip->set_number('1056427')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(27階)');
ok($zip->set_number('1056428')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(28階)');
ok($zip->set_number('1056429')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(29階)');
ok($zip->set_number('1056430')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(30階)');
ok($zip->set_number('1056431')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(31階)');
ok($zip->set_number('1056432')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(32階)');
ok($zip->set_number('1056433')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(33階)');
ok($zip->set_number('1056434')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(34階)');
ok($zip->set_number('1056435')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(35階)');
ok($zip->set_number('1056436')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(36階)');
ok($zip->set_number('1056490')->is_valid_number, '東京都港区虎ノ門虎ノ門ヒルズビジネスタワー(地階・階層不明)');
ok($zip->set_number('1056901')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(1階)');
ok($zip->set_number('1056902')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(2階)');
ok($zip->set_number('1056903')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(3階)');
ok($zip->set_number('1056904')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(4階)');
ok($zip->set_number('1056905')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(5階)');
ok($zip->set_number('1056906')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(6階)');
ok($zip->set_number('1056907')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(7階)');
ok($zip->set_number('1056908')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(8階)');
ok($zip->set_number('1056909')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(9階)');
ok($zip->set_number('1056910')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(10階)');
ok($zip->set_number('1056911')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(11階)');
ok($zip->set_number('1056912')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(12階)');
ok($zip->set_number('1056913')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(13階)');
ok($zip->set_number('1056914')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(14階)');
ok($zip->set_number('1056915')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(15階)');
ok($zip->set_number('1056916')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(16階)');
ok($zip->set_number('1056917')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(17階)');
ok($zip->set_number('1056918')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(18階)');
ok($zip->set_number('1056919')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(19階)');
ok($zip->set_number('1056920')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(20階)');
ok($zip->set_number('1056921')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(21階)');
ok($zip->set_number('1056922')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(22階)');
ok($zip->set_number('1056923')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(23階)');
ok($zip->set_number('1056924')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(24階)');
ok($zip->set_number('1056925')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(25階)');
ok($zip->set_number('1056926')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(26階)');
ok($zip->set_number('1056927')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(27階)');
ok($zip->set_number('1056928')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(28階)');
ok($zip->set_number('1056929')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(29階)');
ok($zip->set_number('1056930')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(30階)');
ok($zip->set_number('1056990')->is_valid_number, '東京都港区虎ノ門神谷町トラストタワー(地階・階層不明)');
ok($zip->set_number('1057001')->is_valid_number, '東京都港区東新橋電通本社ビル(1階)');
ok($zip->set_number('1057002')->is_valid_number, '東京都港区東新橋電通本社ビル(2階)');
ok($zip->set_number('1057003')->is_valid_number, '東京都港区東新橋電通本社ビル(3階)');
ok($zip->set_number('1057004')->is_valid_number, '東京都港区東新橋電通本社ビル(4階)');
ok($zip->set_number('1057005')->is_valid_number, '東京都港区東新橋電通本社ビル(5階)');
ok($zip->set_number('1057006')->is_valid_number, '東京都港区東新橋電通本社ビル(6階)');
ok($zip->set_number('1057007')->is_valid_number, '東京都港区東新橋電通本社ビル(7階)');
ok($zip->set_number('1057008')->is_valid_number, '東京都港区東新橋電通本社ビル(8階)');
ok($zip->set_number('1057009')->is_valid_number, '東京都港区東新橋電通本社ビル(9階)');
ok($zip->set_number('1057010')->is_valid_number, '東京都港区東新橋電通本社ビル(10階)');
ok($zip->set_number('1057011')->is_valid_number, '東京都港区東新橋電通本社ビル(11階)');
ok($zip->set_number('1057012')->is_valid_number, '東京都港区東新橋電通本社ビル(12階)');
ok($zip->set_number('1057013')->is_valid_number, '東京都港区東新橋電通本社ビル(13階)');
ok($zip->set_number('1057014')->is_valid_number, '東京都港区東新橋電通本社ビル(14階)');
ok($zip->set_number('1057015')->is_valid_number, '東京都港区東新橋電通本社ビル(15階)');
ok($zip->set_number('1057016')->is_valid_number, '東京都港区東新橋電通本社ビル(16階)');
ok($zip->set_number('1057017')->is_valid_number, '東京都港区東新橋電通本社ビル(17階)');
ok($zip->set_number('1057018')->is_valid_number, '東京都港区東新橋電通本社ビル(18階)');
ok($zip->set_number('1057019')->is_valid_number, '東京都港区東新橋電通本社ビル(19階)');
ok($zip->set_number('1057020')->is_valid_number, '東京都港区東新橋電通本社ビル(20階)');
ok($zip->set_number('1057021')->is_valid_number, '東京都港区東新橋電通本社ビル(21階)');
ok($zip->set_number('1057022')->is_valid_number, '東京都港区東新橋電通本社ビル(22階)');
ok($zip->set_number('1057023')->is_valid_number, '東京都港区東新橋電通本社ビル(23階)');
ok($zip->set_number('1057024')->is_valid_number, '東京都港区東新橋電通本社ビル(24階)');
ok($zip->set_number('1057025')->is_valid_number, '東京都港区東新橋電通本社ビル(25階)');
ok($zip->set_number('1057026')->is_valid_number, '東京都港区東新橋電通本社ビル(26階)');
ok($zip->set_number('1057027')->is_valid_number, '東京都港区東新橋電通本社ビル(27階)');
ok($zip->set_number('1057028')->is_valid_number, '東京都港区東新橋電通本社ビル(28階)');
ok($zip->set_number('1057029')->is_valid_number, '東京都港区東新橋電通本社ビル(29階)');
ok($zip->set_number('1057030')->is_valid_number, '東京都港区東新橋電通本社ビル(30階)');
ok($zip->set_number('1057031')->is_valid_number, '東京都港区東新橋電通本社ビル(31階)');
ok($zip->set_number('1057032')->is_valid_number, '東京都港区東新橋電通本社ビル(32階)');
ok($zip->set_number('1057033')->is_valid_number, '東京都港区東新橋電通本社ビル(33階)');
ok($zip->set_number('1057034')->is_valid_number, '東京都港区東新橋電通本社ビル(34階)');
ok($zip->set_number('1057035')->is_valid_number, '東京都港区東新橋電通本社ビル(35階)');
ok($zip->set_number('1057036')->is_valid_number, '東京都港区東新橋電通本社ビル(36階)');
ok($zip->set_number('1057037')->is_valid_number, '東京都港区東新橋電通本社ビル(37階)');
ok($zip->set_number('1057038')->is_valid_number, '東京都港区東新橋電通本社ビル(38階)');
ok($zip->set_number('1057039')->is_valid_number, '東京都港区東新橋電通本社ビル(39階)');
ok($zip->set_number('1057040')->is_valid_number, '東京都港区東新橋電通本社ビル(40階)');
ok($zip->set_number('1057041')->is_valid_number, '東京都港区東新橋電通本社ビル(41階)');
ok($zip->set_number('1057042')->is_valid_number, '東京都港区東新橋電通本社ビル(42階)');
ok($zip->set_number('1057043')->is_valid_number, '東京都港区東新橋電通本社ビル(43階)');
ok($zip->set_number('1057044')->is_valid_number, '東京都港区東新橋電通本社ビル(44階)');
ok($zip->set_number('1057045')->is_valid_number, '東京都港区東新橋電通本社ビル(45階)');
ok($zip->set_number('1057046')->is_valid_number, '東京都港区東新橋電通本社ビル(46階)');
ok($zip->set_number('1057047')->is_valid_number, '東京都港区東新橋電通本社ビル(47階)');
ok($zip->set_number('1057090')->is_valid_number, '東京都港区東新橋電通本社ビル(地階・階層不明)');
ok($zip->set_number('1057101')->is_valid_number, '東京都港区東新橋汐留シティセンター(1階)');
ok($zip->set_number('1057102')->is_valid_number, '東京都港区東新橋汐留シティセンター(2階)');
ok($zip->set_number('1057103')->is_valid_number, '東京都港区東新橋汐留シティセンター(3階)');
ok($zip->set_number('1057104')->is_valid_number, '東京都港区東新橋汐留シティセンター(4階)');
ok($zip->set_number('1057105')->is_valid_number, '東京都港区東新橋汐留シティセンター(5階)');
ok($zip->set_number('1057106')->is_valid_number, '東京都港区東新橋汐留シティセンター(6階)');
ok($zip->set_number('1057107')->is_valid_number, '東京都港区東新橋汐留シティセンター(7階)');
ok($zip->set_number('1057108')->is_valid_number, '東京都港区東新橋汐留シティセンター(8階)');
ok($zip->set_number('1057109')->is_valid_number, '東京都港区東新橋汐留シティセンター(9階)');
ok($zip->set_number('1057110')->is_valid_number, '東京都港区東新橋汐留シティセンター(10階)');
ok($zip->set_number('1057111')->is_valid_number, '東京都港区東新橋汐留シティセンター(11階)');
ok($zip->set_number('1057112')->is_valid_number, '東京都港区東新橋汐留シティセンター(12階)');
ok($zip->set_number('1057113')->is_valid_number, '東京都港区東新橋汐留シティセンター(13階)');
ok($zip->set_number('1057114')->is_valid_number, '東京都港区東新橋汐留シティセンター(14階)');
ok($zip->set_number('1057115')->is_valid_number, '東京都港区東新橋汐留シティセンター(15階)');
ok($zip->set_number('1057116')->is_valid_number, '東京都港区東新橋汐留シティセンター(16階)');
ok($zip->set_number('1057117')->is_valid_number, '東京都港区東新橋汐留シティセンター(17階)');
ok($zip->set_number('1057118')->is_valid_number, '東京都港区東新橋汐留シティセンター(18階)');
ok($zip->set_number('1057119')->is_valid_number, '東京都港区東新橋汐留シティセンター(19階)');
ok($zip->set_number('1057120')->is_valid_number, '東京都港区東新橋汐留シティセンター(20階)');
ok($zip->set_number('1057121')->is_valid_number, '東京都港区東新橋汐留シティセンター(21階)');
ok($zip->set_number('1057122')->is_valid_number, '東京都港区東新橋汐留シティセンター(22階)');
ok($zip->set_number('1057123')->is_valid_number, '東京都港区東新橋汐留シティセンター(23階)');
ok($zip->set_number('1057124')->is_valid_number, '東京都港区東新橋汐留シティセンター(24階)');
ok($zip->set_number('1057125')->is_valid_number, '東京都港区東新橋汐留シティセンター(25階)');
ok($zip->set_number('1057126')->is_valid_number, '東京都港区東新橋汐留シティセンター(26階)');
ok($zip->set_number('1057127')->is_valid_number, '東京都港区東新橋汐留シティセンター(27階)');
ok($zip->set_number('1057128')->is_valid_number, '東京都港区東新橋汐留シティセンター(28階)');
ok($zip->set_number('1057129')->is_valid_number, '東京都港区東新橋汐留シティセンター(29階)');
ok($zip->set_number('1057130')->is_valid_number, '東京都港区東新橋汐留シティセンター(30階)');
ok($zip->set_number('1057131')->is_valid_number, '東京都港区東新橋汐留シティセンター(31階)');
ok($zip->set_number('1057132')->is_valid_number, '東京都港区東新橋汐留シティセンター(32階)');
ok($zip->set_number('1057133')->is_valid_number, '東京都港区東新橋汐留シティセンター(33階)');
ok($zip->set_number('1057134')->is_valid_number, '東京都港区東新橋汐留シティセンター(34階)');
ok($zip->set_number('1057135')->is_valid_number, '東京都港区東新橋汐留シティセンター(35階)');
ok($zip->set_number('1057136')->is_valid_number, '東京都港区東新橋汐留シティセンター(36階)');
ok($zip->set_number('1057137')->is_valid_number, '東京都港区東新橋汐留シティセンター(37階)');
ok($zip->set_number('1057138')->is_valid_number, '東京都港区東新橋汐留シティセンター(38階)');
ok($zip->set_number('1057139')->is_valid_number, '東京都港区東新橋汐留シティセンター(39階)');
ok($zip->set_number('1057140')->is_valid_number, '東京都港区東新橋汐留シティセンター(40階)');
ok($zip->set_number('1057141')->is_valid_number, '東京都港区東新橋汐留シティセンター(41階)');
ok($zip->set_number('1057142')->is_valid_number, '東京都港区東新橋汐留シティセンター(42階)');
ok($zip->set_number('1057143')->is_valid_number, '東京都港区東新橋汐留シティセンター(43階)');
ok($zip->set_number('1057190')->is_valid_number, '東京都港区東新橋汐留シティセンター(地階・階層不明)');
ok($zip->set_number('1057201')->is_valid_number, '東京都港区東新橋汐留メディアタワー(1階)');
ok($zip->set_number('1057202')->is_valid_number, '東京都港区東新橋汐留メディアタワー(2階)');
ok($zip->set_number('1057203')->is_valid_number, '東京都港区東新橋汐留メディアタワー(3階)');
ok($zip->set_number('1057204')->is_valid_number, '東京都港区東新橋汐留メディアタワー(4階)');
ok($zip->set_number('1057205')->is_valid_number, '東京都港区東新橋汐留メディアタワー(5階)');
ok($zip->set_number('1057206')->is_valid_number, '東京都港区東新橋汐留メディアタワー(6階)');
ok($zip->set_number('1057207')->is_valid_number, '東京都港区東新橋汐留メディアタワー(7階)');
ok($zip->set_number('1057208')->is_valid_number, '東京都港区東新橋汐留メディアタワー(8階)');
ok($zip->set_number('1057209')->is_valid_number, '東京都港区東新橋汐留メディアタワー(9階)');
ok($zip->set_number('1057210')->is_valid_number, '東京都港区東新橋汐留メディアタワー(10階)');
ok($zip->set_number('1057211')->is_valid_number, '東京都港区東新橋汐留メディアタワー(11階)');
ok($zip->set_number('1057212')->is_valid_number, '東京都港区東新橋汐留メディアタワー(12階)');
ok($zip->set_number('1057213')->is_valid_number, '東京都港区東新橋汐留メディアタワー(13階)');
ok($zip->set_number('1057214')->is_valid_number, '東京都港区東新橋汐留メディアタワー(14階)');
ok($zip->set_number('1057215')->is_valid_number, '東京都港区東新橋汐留メディアタワー(15階)');
ok($zip->set_number('1057216')->is_valid_number, '東京都港区東新橋汐留メディアタワー(16階)');
ok($zip->set_number('1057217')->is_valid_number, '東京都港区東新橋汐留メディアタワー(17階)');
ok($zip->set_number('1057218')->is_valid_number, '東京都港区東新橋汐留メディアタワー(18階)');
ok($zip->set_number('1057219')->is_valid_number, '東京都港区東新橋汐留メディアタワー(19階)');
ok($zip->set_number('1057220')->is_valid_number, '東京都港区東新橋汐留メディアタワー(20階)');
ok($zip->set_number('1057221')->is_valid_number, '東京都港区東新橋汐留メディアタワー(21階)');
ok($zip->set_number('1057222')->is_valid_number, '東京都港区東新橋汐留メディアタワー(22階)');
ok($zip->set_number('1057223')->is_valid_number, '東京都港区東新橋汐留メディアタワー(23階)');
ok($zip->set_number('1057224')->is_valid_number, '東京都港区東新橋汐留メディアタワー(24階)');
ok($zip->set_number('1057225')->is_valid_number, '東京都港区東新橋汐留メディアタワー(25階)');
ok($zip->set_number('1057226')->is_valid_number, '東京都港区東新橋汐留メディアタワー(26階)');
ok($zip->set_number('1057227')->is_valid_number, '東京都港区東新橋汐留メディアタワー(27階)');
ok($zip->set_number('1057228')->is_valid_number, '東京都港区東新橋汐留メディアタワー(28階)');
ok($zip->set_number('1057229')->is_valid_number, '東京都港区東新橋汐留メディアタワー(29階)');
ok($zip->set_number('1057230')->is_valid_number, '東京都港区東新橋汐留メディアタワー(30階)');
ok($zip->set_number('1057231')->is_valid_number, '東京都港区東新橋汐留メディアタワー(31階)');
ok($zip->set_number('1057232')->is_valid_number, '東京都港区東新橋汐留メディアタワー(32階)');
ok($zip->set_number('1057233')->is_valid_number, '東京都港区東新橋汐留メディアタワー(33階)');
ok($zip->set_number('1057234')->is_valid_number, '東京都港区東新橋汐留メディアタワー(34階)');
ok($zip->set_number('1057290')->is_valid_number, '東京都港区東新橋汐留メディアタワー(地階・階層不明)');
ok($zip->set_number('1057301')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(1階)');
ok($zip->set_number('1057302')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(2階)');
ok($zip->set_number('1057303')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(3階)');
ok($zip->set_number('1057304')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(4階)');
ok($zip->set_number('1057305')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(5階)');
ok($zip->set_number('1057306')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(6階)');
ok($zip->set_number('1057307')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(7階)');
ok($zip->set_number('1057308')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(8階)');
ok($zip->set_number('1057309')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(9階)');
ok($zip->set_number('1057310')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(10階)');
ok($zip->set_number('1057311')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(11階)');
ok($zip->set_number('1057312')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(12階)');
ok($zip->set_number('1057313')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(13階)');
ok($zip->set_number('1057314')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(14階)');
ok($zip->set_number('1057315')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(15階)');
ok($zip->set_number('1057316')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(16階)');
ok($zip->set_number('1057317')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(17階)');
ok($zip->set_number('1057318')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(18階)');
ok($zip->set_number('1057319')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(19階)');
ok($zip->set_number('1057320')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(20階)');
ok($zip->set_number('1057321')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(21階)');
ok($zip->set_number('1057322')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(22階)');
ok($zip->set_number('1057323')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(23階)');
ok($zip->set_number('1057324')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(24階)');
ok($zip->set_number('1057325')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(25階)');
ok($zip->set_number('1057326')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(26階)');
ok($zip->set_number('1057327')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(27階)');
ok($zip->set_number('1057328')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(28階)');
ok($zip->set_number('1057329')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(29階)');
ok($zip->set_number('1057330')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(30階)');
ok($zip->set_number('1057331')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(31階)');
ok($zip->set_number('1057332')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(32階)');
ok($zip->set_number('1057333')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(33階)');
ok($zip->set_number('1057334')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(34階)');
ok($zip->set_number('1057335')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(35階)');
ok($zip->set_number('1057336')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(36階)');
ok($zip->set_number('1057337')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(37階)');
ok($zip->set_number('1057390')->is_valid_number, '東京都港区東新橋東京汐留ビルディング(地階・階層不明)');
ok($zip->set_number('1057401')->is_valid_number, '東京都港区東新橋日本テレビタワー(1階)');
ok($zip->set_number('1057402')->is_valid_number, '東京都港区東新橋日本テレビタワー(2階)');
ok($zip->set_number('1057403')->is_valid_number, '東京都港区東新橋日本テレビタワー(3階)');
ok($zip->set_number('1057404')->is_valid_number, '東京都港区東新橋日本テレビタワー(4階)');
ok($zip->set_number('1057405')->is_valid_number, '東京都港区東新橋日本テレビタワー(5階)');
ok($zip->set_number('1057406')->is_valid_number, '東京都港区東新橋日本テレビタワー(6階)');
ok($zip->set_number('1057407')->is_valid_number, '東京都港区東新橋日本テレビタワー(7階)');
ok($zip->set_number('1057408')->is_valid_number, '東京都港区東新橋日本テレビタワー(8階)');
ok($zip->set_number('1057409')->is_valid_number, '東京都港区東新橋日本テレビタワー(9階)');
ok($zip->set_number('1057410')->is_valid_number, '東京都港区東新橋日本テレビタワー(10階)');
ok($zip->set_number('1057411')->is_valid_number, '東京都港区東新橋日本テレビタワー(11階)');
ok($zip->set_number('1057412')->is_valid_number, '東京都港区東新橋日本テレビタワー(12階)');
ok($zip->set_number('1057413')->is_valid_number, '東京都港区東新橋日本テレビタワー(13階)');
ok($zip->set_number('1057414')->is_valid_number, '東京都港区東新橋日本テレビタワー(14階)');
ok($zip->set_number('1057415')->is_valid_number, '東京都港区東新橋日本テレビタワー(15階)');
ok($zip->set_number('1057416')->is_valid_number, '東京都港区東新橋日本テレビタワー(16階)');
ok($zip->set_number('1057417')->is_valid_number, '東京都港区東新橋日本テレビタワー(17階)');
ok($zip->set_number('1057418')->is_valid_number, '東京都港区東新橋日本テレビタワー(18階)');
ok($zip->set_number('1057419')->is_valid_number, '東京都港区東新橋日本テレビタワー(19階)');
ok($zip->set_number('1057420')->is_valid_number, '東京都港区東新橋日本テレビタワー(20階)');
ok($zip->set_number('1057421')->is_valid_number, '東京都港区東新橋日本テレビタワー(21階)');
ok($zip->set_number('1057422')->is_valid_number, '東京都港区東新橋日本テレビタワー(22階)');
ok($zip->set_number('1057423')->is_valid_number, '東京都港区東新橋日本テレビタワー(23階)');
ok($zip->set_number('1057424')->is_valid_number, '東京都港区東新橋日本テレビタワー(24階)');
ok($zip->set_number('1057425')->is_valid_number, '東京都港区東新橋日本テレビタワー(25階)');
ok($zip->set_number('1057426')->is_valid_number, '東京都港区東新橋日本テレビタワー(26階)');
ok($zip->set_number('1057427')->is_valid_number, '東京都港区東新橋日本テレビタワー(27階)');
ok($zip->set_number('1057428')->is_valid_number, '東京都港区東新橋日本テレビタワー(28階)');
ok($zip->set_number('1057429')->is_valid_number, '東京都港区東新橋日本テレビタワー(29階)');
ok($zip->set_number('1057430')->is_valid_number, '東京都港区東新橋日本テレビタワー(30階)');
ok($zip->set_number('1057431')->is_valid_number, '東京都港区東新橋日本テレビタワー(31階)');
ok($zip->set_number('1057432')->is_valid_number, '東京都港区東新橋日本テレビタワー(32階)');
ok($zip->set_number('1057490')->is_valid_number, '東京都港区東新橋日本テレビタワー(地階・階層不明)');
ok($zip->set_number('1057501')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(1階)');
ok($zip->set_number('1057502')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(2階)');
ok($zip->set_number('1057503')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(3階)');
ok($zip->set_number('1057504')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(4階)');
ok($zip->set_number('1057505')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(5階)');
ok($zip->set_number('1057506')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(6階)');
ok($zip->set_number('1057507')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(7階)');
ok($zip->set_number('1057508')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(8階)');
ok($zip->set_number('1057509')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(9階)');
ok($zip->set_number('1057510')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(10階)');
ok($zip->set_number('1057511')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(11階)');
ok($zip->set_number('1057512')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(12階)');
ok($zip->set_number('1057513')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(13階)');
ok($zip->set_number('1057514')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(14階)');
ok($zip->set_number('1057515')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(15階)');
ok($zip->set_number('1057516')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(16階)');
ok($zip->set_number('1057517')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(17階)');
ok($zip->set_number('1057518')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(18階)');
ok($zip->set_number('1057519')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(19階)');
ok($zip->set_number('1057520')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(20階)');
ok($zip->set_number('1057521')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(21階)');
ok($zip->set_number('1057522')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(22階)');
ok($zip->set_number('1057523')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(23階)');
ok($zip->set_number('1057524')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(24階)');
ok($zip->set_number('1057525')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(25階)');
ok($zip->set_number('1057526')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(26階)');
ok($zip->set_number('1057527')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(27階)');
ok($zip->set_number('1057528')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(28階)');
ok($zip->set_number('1057529')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(29階)');
ok($zip->set_number('1057530')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(30階)');
ok($zip->set_number('1057531')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(31階)');
ok($zip->set_number('1057532')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(32階)');
ok($zip->set_number('1057533')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(33階)');
ok($zip->set_number('1057534')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(34階)');
ok($zip->set_number('1057535')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(35階)');
ok($zip->set_number('1057536')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(36階)');
ok($zip->set_number('1057537')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(37階)');
ok($zip->set_number('1057538')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(38階)');
ok($zip->set_number('1057539')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(39階)');
ok($zip->set_number('1057590')->is_valid_number, '東京都港区海岸東京ポートシティ竹芝オフィスタワー(地階・階層不明)');
ok($zip->set_number('1060031')->is_valid_number, '東京都港区西麻布');
ok($zip->set_number('1060032')->is_valid_number, '東京都港区六本木(次のビルを除く)');
ok($zip->set_number('1060041')->is_valid_number, '東京都港区麻布台');
ok($zip->set_number('1060042')->is_valid_number, '東京都港区麻布狸穴町');
ok($zip->set_number('1060043')->is_valid_number, '東京都港区麻布永坂町');
ok($zip->set_number('1060044')->is_valid_number, '東京都港区東麻布');
ok($zip->set_number('1060045')->is_valid_number, '東京都港区麻布十番');
ok($zip->set_number('1060046')->is_valid_number, '東京都港区元麻布');
ok($zip->set_number('1060047')->is_valid_number, '東京都港区南麻布');
ok($zip->set_number('1066001')->is_valid_number, '東京都港区六本木泉ガーデンタワー(1階)');
ok($zip->set_number('1066002')->is_valid_number, '東京都港区六本木泉ガーデンタワー(2階)');
ok($zip->set_number('1066003')->is_valid_number, '東京都港区六本木泉ガーデンタワー(3階)');
ok($zip->set_number('1066004')->is_valid_number, '東京都港区六本木泉ガーデンタワー(4階)');
ok($zip->set_number('1066005')->is_valid_number, '東京都港区六本木泉ガーデンタワー(5階)');
ok($zip->set_number('1066006')->is_valid_number, '東京都港区六本木泉ガーデンタワー(6階)');
ok($zip->set_number('1066007')->is_valid_number, '東京都港区六本木泉ガーデンタワー(7階)');
ok($zip->set_number('1066008')->is_valid_number, '東京都港区六本木泉ガーデンタワー(8階)');
ok($zip->set_number('1066009')->is_valid_number, '東京都港区六本木泉ガーデンタワー(9階)');
ok($zip->set_number('1066010')->is_valid_number, '東京都港区六本木泉ガーデンタワー(10階)');
ok($zip->set_number('1066011')->is_valid_number, '東京都港区六本木泉ガーデンタワー(11階)');
ok($zip->set_number('1066012')->is_valid_number, '東京都港区六本木泉ガーデンタワー(12階)');
ok($zip->set_number('1066013')->is_valid_number, '東京都港区六本木泉ガーデンタワー(13階)');
ok($zip->set_number('1066014')->is_valid_number, '東京都港区六本木泉ガーデンタワー(14階)');
ok($zip->set_number('1066015')->is_valid_number, '東京都港区六本木泉ガーデンタワー(15階)');
ok($zip->set_number('1066016')->is_valid_number, '東京都港区六本木泉ガーデンタワー(16階)');
ok($zip->set_number('1066017')->is_valid_number, '東京都港区六本木泉ガーデンタワー(17階)');
ok($zip->set_number('1066018')->is_valid_number, '東京都港区六本木泉ガーデンタワー(18階)');
ok($zip->set_number('1066019')->is_valid_number, '東京都港区六本木泉ガーデンタワー(19階)');
ok($zip->set_number('1066020')->is_valid_number, '東京都港区六本木泉ガーデンタワー(20階)');
ok($zip->set_number('1066021')->is_valid_number, '東京都港区六本木泉ガーデンタワー(21階)');
ok($zip->set_number('1066022')->is_valid_number, '東京都港区六本木泉ガーデンタワー(22階)');
ok($zip->set_number('1066023')->is_valid_number, '東京都港区六本木泉ガーデンタワー(23階)');
ok($zip->set_number('1066024')->is_valid_number, '東京都港区六本木泉ガーデンタワー(24階)');
ok($zip->set_number('1066025')->is_valid_number, '東京都港区六本木泉ガーデンタワー(25階)');
ok($zip->set_number('1066026')->is_valid_number, '東京都港区六本木泉ガーデンタワー(26階)');
ok($zip->set_number('1066027')->is_valid_number, '東京都港区六本木泉ガーデンタワー(27階)');
ok($zip->set_number('1066028')->is_valid_number, '東京都港区六本木泉ガーデンタワー(28階)');
ok($zip->set_number('1066029')->is_valid_number, '東京都港区六本木泉ガーデンタワー(29階)');
ok($zip->set_number('1066030')->is_valid_number, '東京都港区六本木泉ガーデンタワー(30階)');
ok($zip->set_number('1066031')->is_valid_number, '東京都港区六本木泉ガーデンタワー(31階)');
ok($zip->set_number('1066032')->is_valid_number, '東京都港区六本木泉ガーデンタワー(32階)');
ok($zip->set_number('1066033')->is_valid_number, '東京都港区六本木泉ガーデンタワー(33階)');
ok($zip->set_number('1066034')->is_valid_number, '東京都港区六本木泉ガーデンタワー(34階)');
ok($zip->set_number('1066035')->is_valid_number, '東京都港区六本木泉ガーデンタワー(35階)');
ok($zip->set_number('1066036')->is_valid_number, '東京都港区六本木泉ガーデンタワー(36階)');
ok($zip->set_number('1066037')->is_valid_number, '東京都港区六本木泉ガーデンタワー(37階)');
ok($zip->set_number('1066038')->is_valid_number, '東京都港区六本木泉ガーデンタワー(38階)');
ok($zip->set_number('1066039')->is_valid_number, '東京都港区六本木泉ガーデンタワー(39階)');
ok($zip->set_number('1066040')->is_valid_number, '東京都港区六本木泉ガーデンタワー(40階)');
ok($zip->set_number('1066041')->is_valid_number, '東京都港区六本木泉ガーデンタワー(41階)');
ok($zip->set_number('1066042')->is_valid_number, '東京都港区六本木泉ガーデンタワー(42階)');
ok($zip->set_number('1066043')->is_valid_number, '東京都港区六本木泉ガーデンタワー(43階)');
ok($zip->set_number('1066044')->is_valid_number, '東京都港区六本木泉ガーデンタワー(44階)');
ok($zip->set_number('1066045')->is_valid_number, '東京都港区六本木泉ガーデンタワー(45階)');
ok($zip->set_number('1066090')->is_valid_number, '東京都港区六本木泉ガーデンタワー(地階・階層不明)');
ok($zip->set_number('1066101')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(1階)');
ok($zip->set_number('1066102')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(2階)');
ok($zip->set_number('1066103')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(3階)');
ok($zip->set_number('1066104')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(4階)');
ok($zip->set_number('1066105')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(5階)');
ok($zip->set_number('1066106')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(6階)');
ok($zip->set_number('1066107')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(7階)');
ok($zip->set_number('1066108')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(8階)');
ok($zip->set_number('1066109')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(9階)');
ok($zip->set_number('1066110')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(10階)');
ok($zip->set_number('1066111')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(11階)');
ok($zip->set_number('1066112')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(12階)');
ok($zip->set_number('1066113')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(13階)');
ok($zip->set_number('1066114')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(14階)');
ok($zip->set_number('1066115')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(15階)');
ok($zip->set_number('1066116')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(16階)');
ok($zip->set_number('1066117')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(17階)');
ok($zip->set_number('1066118')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(18階)');
ok($zip->set_number('1066119')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(19階)');
ok($zip->set_number('1066120')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(20階)');
ok($zip->set_number('1066121')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(21階)');
ok($zip->set_number('1066122')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(22階)');
ok($zip->set_number('1066123')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(23階)');
ok($zip->set_number('1066124')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(24階)');
ok($zip->set_number('1066125')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(25階)');
ok($zip->set_number('1066126')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(26階)');
ok($zip->set_number('1066127')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(27階)');
ok($zip->set_number('1066128')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(28階)');
ok($zip->set_number('1066129')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(29階)');
ok($zip->set_number('1066130')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(30階)');
ok($zip->set_number('1066131')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(31階)');
ok($zip->set_number('1066132')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(32階)');
ok($zip->set_number('1066133')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(33階)');
ok($zip->set_number('1066134')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(34階)');
ok($zip->set_number('1066135')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(35階)');
ok($zip->set_number('1066136')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(36階)');
ok($zip->set_number('1066137')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(37階)');
ok($zip->set_number('1066138')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(38階)');
ok($zip->set_number('1066139')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(39階)');
ok($zip->set_number('1066140')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(40階)');
ok($zip->set_number('1066141')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(41階)');
ok($zip->set_number('1066142')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(42階)');
ok($zip->set_number('1066143')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(43階)');
ok($zip->set_number('1066144')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(44階)');
ok($zip->set_number('1066145')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(45階)');
ok($zip->set_number('1066146')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(46階)');
ok($zip->set_number('1066147')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(47階)');
ok($zip->set_number('1066148')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(48階)');
ok($zip->set_number('1066149')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(49階)');
ok($zip->set_number('1066150')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(50階)');
ok($zip->set_number('1066151')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(51階)');
ok($zip->set_number('1066152')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(52階)');
ok($zip->set_number('1066153')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(53階)');
ok($zip->set_number('1066154')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(54階)');
ok($zip->set_number('1066190')->is_valid_number, '東京都港区六本木六本木ヒルズ森タワー(地階・階層不明)');
ok($zip->set_number('1066201')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(1階)');
ok($zip->set_number('1066202')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(2階)');
ok($zip->set_number('1066203')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(3階)');
ok($zip->set_number('1066204')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(4階)');
ok($zip->set_number('1066205')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(5階)');
ok($zip->set_number('1066206')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(6階)');
ok($zip->set_number('1066207')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(7階)');
ok($zip->set_number('1066208')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(8階)');
ok($zip->set_number('1066209')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(9階)');
ok($zip->set_number('1066210')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(10階)');
ok($zip->set_number('1066211')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(11階)');
ok($zip->set_number('1066212')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(12階)');
ok($zip->set_number('1066213')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(13階)');
ok($zip->set_number('1066214')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(14階)');
ok($zip->set_number('1066215')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(15階)');
ok($zip->set_number('1066216')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(16階)');
ok($zip->set_number('1066217')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(17階)');
ok($zip->set_number('1066218')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(18階)');
ok($zip->set_number('1066219')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(19階)');
ok($zip->set_number('1066220')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(20階)');
ok($zip->set_number('1066221')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(21階)');
ok($zip->set_number('1066222')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(22階)');
ok($zip->set_number('1066223')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(23階)');
ok($zip->set_number('1066224')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(24階)');
ok($zip->set_number('1066225')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(25階)');
ok($zip->set_number('1066226')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(26階)');
ok($zip->set_number('1066227')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(27階)');
ok($zip->set_number('1066228')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(28階)');
ok($zip->set_number('1066229')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(29階)');
ok($zip->set_number('1066230')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(30階)');
ok($zip->set_number('1066231')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(31階)');
ok($zip->set_number('1066232')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(32階)');
ok($zip->set_number('1066233')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(33階)');
ok($zip->set_number('1066234')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(34階)');
ok($zip->set_number('1066235')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(35階)');
ok($zip->set_number('1066236')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(36階)');
ok($zip->set_number('1066237')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(37階)');
ok($zip->set_number('1066238')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(38階)');
ok($zip->set_number('1066239')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(39階)');
ok($zip->set_number('1066240')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(40階)');
ok($zip->set_number('1066241')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(41階)');
ok($zip->set_number('1066242')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(42階)');
ok($zip->set_number('1066243')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(43階)');
ok($zip->set_number('1066290')->is_valid_number, '東京都港区六本木住友不動産六本木グランドタワー(地階・階層不明)');
ok($zip->set_number('1070051')->is_valid_number, '東京都港区元赤坂');
ok($zip->set_number('1070052')->is_valid_number, '東京都港区赤坂(次のビルを除く)');
ok($zip->set_number('1070061')->is_valid_number, '東京都港区北青山');
ok($zip->set_number('1070062')->is_valid_number, '東京都港区南青山');
ok($zip->set_number('1076001')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(1階)');
ok($zip->set_number('1076002')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(2階)');
ok($zip->set_number('1076003')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(3階)');
ok($zip->set_number('1076004')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(4階)');
ok($zip->set_number('1076005')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(5階)');
ok($zip->set_number('1076006')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(6階)');
ok($zip->set_number('1076007')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(7階)');
ok($zip->set_number('1076008')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(8階)');
ok($zip->set_number('1076009')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(9階)');
ok($zip->set_number('1076010')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(10階)');
ok($zip->set_number('1076011')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(11階)');
ok($zip->set_number('1076012')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(12階)');
ok($zip->set_number('1076013')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(13階)');
ok($zip->set_number('1076014')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(14階)');
ok($zip->set_number('1076015')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(15階)');
ok($zip->set_number('1076016')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(16階)');
ok($zip->set_number('1076017')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(17階)');
ok($zip->set_number('1076018')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(18階)');
ok($zip->set_number('1076019')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(19階)');
ok($zip->set_number('1076020')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(20階)');
ok($zip->set_number('1076021')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(21階)');
ok($zip->set_number('1076022')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(22階)');
ok($zip->set_number('1076023')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(23階)');
ok($zip->set_number('1076024')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(24階)');
ok($zip->set_number('1076025')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(25階)');
ok($zip->set_number('1076026')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(26階)');
ok($zip->set_number('1076027')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(27階)');
ok($zip->set_number('1076028')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(28階)');
ok($zip->set_number('1076029')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(29階)');
ok($zip->set_number('1076030')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(30階)');
ok($zip->set_number('1076031')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(31階)');
ok($zip->set_number('1076032')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(32階)');
ok($zip->set_number('1076033')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(33階)');
ok($zip->set_number('1076034')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(34階)');
ok($zip->set_number('1076035')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(35階)');
ok($zip->set_number('1076036')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(36階)');
ok($zip->set_number('1076037')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(37階)');
ok($zip->set_number('1076090')->is_valid_number, '東京都港区赤坂赤坂アークヒルズ・アーク森ビル(地階・階層不明)');
ok($zip->set_number('1076101')->is_valid_number, '東京都港区赤坂赤坂パークビル(1階)');
ok($zip->set_number('1076102')->is_valid_number, '東京都港区赤坂赤坂パークビル(2階)');
ok($zip->set_number('1076103')->is_valid_number, '東京都港区赤坂赤坂パークビル(3階)');
ok($zip->set_number('1076104')->is_valid_number, '東京都港区赤坂赤坂パークビル(4階)');
ok($zip->set_number('1076105')->is_valid_number, '東京都港区赤坂赤坂パークビル(5階)');
ok($zip->set_number('1076106')->is_valid_number, '東京都港区赤坂赤坂パークビル(6階)');
ok($zip->set_number('1076107')->is_valid_number, '東京都港区赤坂赤坂パークビル(7階)');
ok($zip->set_number('1076108')->is_valid_number, '東京都港区赤坂赤坂パークビル(8階)');
ok($zip->set_number('1076109')->is_valid_number, '東京都港区赤坂赤坂パークビル(9階)');
ok($zip->set_number('1076110')->is_valid_number, '東京都港区赤坂赤坂パークビル(10階)');
ok($zip->set_number('1076111')->is_valid_number, '東京都港区赤坂赤坂パークビル(11階)');
ok($zip->set_number('1076112')->is_valid_number, '東京都港区赤坂赤坂パークビル(12階)');
ok($zip->set_number('1076113')->is_valid_number, '東京都港区赤坂赤坂パークビル(13階)');
ok($zip->set_number('1076114')->is_valid_number, '東京都港区赤坂赤坂パークビル(14階)');
ok($zip->set_number('1076115')->is_valid_number, '東京都港区赤坂赤坂パークビル(15階)');
ok($zip->set_number('1076116')->is_valid_number, '東京都港区赤坂赤坂パークビル(16階)');
ok($zip->set_number('1076117')->is_valid_number, '東京都港区赤坂赤坂パークビル(17階)');
ok($zip->set_number('1076118')->is_valid_number, '東京都港区赤坂赤坂パークビル(18階)');
ok($zip->set_number('1076119')->is_valid_number, '東京都港区赤坂赤坂パークビル(19階)');
ok($zip->set_number('1076120')->is_valid_number, '東京都港区赤坂赤坂パークビル(20階)');
ok($zip->set_number('1076121')->is_valid_number, '東京都港区赤坂赤坂パークビル(21階)');
ok($zip->set_number('1076122')->is_valid_number, '東京都港区赤坂赤坂パークビル(22階)');
ok($zip->set_number('1076123')->is_valid_number, '東京都港区赤坂赤坂パークビル(23階)');
ok($zip->set_number('1076124')->is_valid_number, '東京都港区赤坂赤坂パークビル(24階)');
ok($zip->set_number('1076125')->is_valid_number, '東京都港区赤坂赤坂パークビル(25階)');
ok($zip->set_number('1076126')->is_valid_number, '東京都港区赤坂赤坂パークビル(26階)');
ok($zip->set_number('1076127')->is_valid_number, '東京都港区赤坂赤坂パークビル(27階)');
ok($zip->set_number('1076128')->is_valid_number, '東京都港区赤坂赤坂パークビル(28階)');
ok($zip->set_number('1076129')->is_valid_number, '東京都港区赤坂赤坂パークビル(29階)');
ok($zip->set_number('1076130')->is_valid_number, '東京都港区赤坂赤坂パークビル(30階)');
ok($zip->set_number('1076190')->is_valid_number, '東京都港区赤坂赤坂パークビル(地階・階層不明)');
ok($zip->set_number('1076201')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(1階)');
ok($zip->set_number('1076202')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(2階)');
ok($zip->set_number('1076203')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(3階)');
ok($zip->set_number('1076204')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(4階)');
ok($zip->set_number('1076205')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(5階)');
ok($zip->set_number('1076206')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(6階)');
ok($zip->set_number('1076207')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(7階)');
ok($zip->set_number('1076208')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(8階)');
ok($zip->set_number('1076209')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(9階)');
ok($zip->set_number('1076210')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(10階)');
ok($zip->set_number('1076211')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(11階)');
ok($zip->set_number('1076212')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(12階)');
ok($zip->set_number('1076213')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(13階)');
ok($zip->set_number('1076214')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(14階)');
ok($zip->set_number('1076215')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(15階)');
ok($zip->set_number('1076216')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(16階)');
ok($zip->set_number('1076217')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(17階)');
ok($zip->set_number('1076218')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(18階)');
ok($zip->set_number('1076219')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(19階)');
ok($zip->set_number('1076220')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(20階)');
ok($zip->set_number('1076221')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(21階)');
ok($zip->set_number('1076222')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(22階)');
ok($zip->set_number('1076223')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(23階)');
ok($zip->set_number('1076224')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(24階)');
ok($zip->set_number('1076225')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(25階)');
ok($zip->set_number('1076226')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(26階)');
ok($zip->set_number('1076227')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(27階)');
ok($zip->set_number('1076228')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(28階)');
ok($zip->set_number('1076229')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(29階)');
ok($zip->set_number('1076230')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(30階)');
ok($zip->set_number('1076231')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(31階)');
ok($zip->set_number('1076232')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(32階)');
ok($zip->set_number('1076233')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(33階)');
ok($zip->set_number('1076234')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(34階)');
ok($zip->set_number('1076235')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(35階)');
ok($zip->set_number('1076236')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(36階)');
ok($zip->set_number('1076237')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(37階)');
ok($zip->set_number('1076238')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(38階)');
ok($zip->set_number('1076239')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(39階)');
ok($zip->set_number('1076240')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(40階)');
ok($zip->set_number('1076241')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(41階)');
ok($zip->set_number('1076242')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(42階)');
ok($zip->set_number('1076243')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(43階)');
ok($zip->set_number('1076244')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(44階)');
ok($zip->set_number('1076245')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(45階)');
ok($zip->set_number('1076290')->is_valid_number, '東京都港区赤坂ミッドタウン・タワー(地階・階層不明)');
ok($zip->set_number('1076301')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(1階)');
ok($zip->set_number('1076302')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(2階)');
ok($zip->set_number('1076303')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(3階)');
ok($zip->set_number('1076304')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(4階)');
ok($zip->set_number('1076305')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(5階)');
ok($zip->set_number('1076306')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(6階)');
ok($zip->set_number('1076307')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(7階)');
ok($zip->set_number('1076308')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(8階)');
ok($zip->set_number('1076309')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(9階)');
ok($zip->set_number('1076310')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(10階)');
ok($zip->set_number('1076311')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(11階)');
ok($zip->set_number('1076312')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(12階)');
ok($zip->set_number('1076313')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(13階)');
ok($zip->set_number('1076314')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(14階)');
ok($zip->set_number('1076315')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(15階)');
ok($zip->set_number('1076316')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(16階)');
ok($zip->set_number('1076317')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(17階)');
ok($zip->set_number('1076318')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(18階)');
ok($zip->set_number('1076319')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(19階)');
ok($zip->set_number('1076320')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(20階)');
ok($zip->set_number('1076321')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(21階)');
ok($zip->set_number('1076322')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(22階)');
ok($zip->set_number('1076323')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(23階)');
ok($zip->set_number('1076324')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(24階)');
ok($zip->set_number('1076325')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(25階)');
ok($zip->set_number('1076326')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(26階)');
ok($zip->set_number('1076327')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(27階)');
ok($zip->set_number('1076328')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(28階)');
ok($zip->set_number('1076329')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(29階)');
ok($zip->set_number('1076330')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(30階)');
ok($zip->set_number('1076331')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(31階)');
ok($zip->set_number('1076332')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(32階)');
ok($zip->set_number('1076333')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(33階)');
ok($zip->set_number('1076334')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(34階)');
ok($zip->set_number('1076335')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(35階)');
ok($zip->set_number('1076336')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(36階)');
ok($zip->set_number('1076337')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(37階)');
ok($zip->set_number('1076338')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(38階)');
ok($zip->set_number('1076339')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(39階)');
ok($zip->set_number('1076390')->is_valid_number, '東京都港区赤坂赤坂Bizタワー(地階・階層不明)');
ok($zip->set_number('1080014')->is_valid_number, '東京都港区芝(4、5丁目)');
ok($zip->set_number('1080022')->is_valid_number, '東京都港区海岸(3丁目)');
ok($zip->set_number('1080023')->is_valid_number, '東京都港区芝浦(2~4丁目)');
ok($zip->set_number('1080071')->is_valid_number, '東京都港区白金台');
ok($zip->set_number('1080072')->is_valid_number, '東京都港区白金');
ok($zip->set_number('1080073')->is_valid_number, '東京都港区三田(次のビルを除く)');
ok($zip->set_number('1080074')->is_valid_number, '東京都港区高輪');
ok($zip->set_number('1080075')->is_valid_number, '東京都港区港南(次のビルを除く)');
ok($zip->set_number('1086001')->is_valid_number, '東京都港区港南品川インターシティA棟(1階)');
ok($zip->set_number('1086002')->is_valid_number, '東京都港区港南品川インターシティA棟(2階)');
ok($zip->set_number('1086003')->is_valid_number, '東京都港区港南品川インターシティA棟(3階)');
ok($zip->set_number('1086004')->is_valid_number, '東京都港区港南品川インターシティA棟(4階)');
ok($zip->set_number('1086005')->is_valid_number, '東京都港区港南品川インターシティA棟(5階)');
ok($zip->set_number('1086006')->is_valid_number, '東京都港区港南品川インターシティA棟(6階)');
ok($zip->set_number('1086007')->is_valid_number, '東京都港区港南品川インターシティA棟(7階)');
ok($zip->set_number('1086008')->is_valid_number, '東京都港区港南品川インターシティA棟(8階)');
ok($zip->set_number('1086009')->is_valid_number, '東京都港区港南品川インターシティA棟(9階)');
ok($zip->set_number('1086010')->is_valid_number, '東京都港区港南品川インターシティA棟(10階)');
ok($zip->set_number('1086011')->is_valid_number, '東京都港区港南品川インターシティA棟(11階)');
ok($zip->set_number('1086012')->is_valid_number, '東京都港区港南品川インターシティA棟(12階)');
ok($zip->set_number('1086013')->is_valid_number, '東京都港区港南品川インターシティA棟(13階)');
ok($zip->set_number('1086014')->is_valid_number, '東京都港区港南品川インターシティA棟(14階)');
ok($zip->set_number('1086015')->is_valid_number, '東京都港区港南品川インターシティA棟(15階)');
ok($zip->set_number('1086016')->is_valid_number, '東京都港区港南品川インターシティA棟(16階)');
ok($zip->set_number('1086017')->is_valid_number, '東京都港区港南品川インターシティA棟(17階)');
ok($zip->set_number('1086018')->is_valid_number, '東京都港区港南品川インターシティA棟(18階)');
ok($zip->set_number('1086019')->is_valid_number, '東京都港区港南品川インターシティA棟(19階)');
ok($zip->set_number('1086020')->is_valid_number, '東京都港区港南品川インターシティA棟(20階)');
ok($zip->set_number('1086021')->is_valid_number, '東京都港区港南品川インターシティA棟(21階)');
ok($zip->set_number('1086022')->is_valid_number, '東京都港区港南品川インターシティA棟(22階)');
ok($zip->set_number('1086023')->is_valid_number, '東京都港区港南品川インターシティA棟(23階)');
ok($zip->set_number('1086024')->is_valid_number, '東京都港区港南品川インターシティA棟(24階)');
ok($zip->set_number('1086025')->is_valid_number, '東京都港区港南品川インターシティA棟(25階)');
ok($zip->set_number('1086026')->is_valid_number, '東京都港区港南品川インターシティA棟(26階)');
ok($zip->set_number('1086027')->is_valid_number, '東京都港区港南品川インターシティA棟(27階)');
ok($zip->set_number('1086028')->is_valid_number, '東京都港区港南品川インターシティA棟(28階)');
ok($zip->set_number('1086029')->is_valid_number, '東京都港区港南品川インターシティA棟(29階)');
ok($zip->set_number('1086030')->is_valid_number, '東京都港区港南品川インターシティA棟(30階)');
ok($zip->set_number('1086031')->is_valid_number, '東京都港区港南品川インターシティA棟(31階)');
ok($zip->set_number('1086032')->is_valid_number, '東京都港区港南品川インターシティA棟(32階)');
ok($zip->set_number('1086090')->is_valid_number, '東京都港区港南品川インターシティA棟(地階・階層不明)');
ok($zip->set_number('1086101')->is_valid_number, '東京都港区港南品川インターシティB棟(1階)');
ok($zip->set_number('1086102')->is_valid_number, '東京都港区港南品川インターシティB棟(2階)');
ok($zip->set_number('1086103')->is_valid_number, '東京都港区港南品川インターシティB棟(3階)');
ok($zip->set_number('1086104')->is_valid_number, '東京都港区港南品川インターシティB棟(4階)');
ok($zip->set_number('1086105')->is_valid_number, '東京都港区港南品川インターシティB棟(5階)');
ok($zip->set_number('1086106')->is_valid_number, '東京都港区港南品川インターシティB棟(6階)');
ok($zip->set_number('1086107')->is_valid_number, '東京都港区港南品川インターシティB棟(7階)');
ok($zip->set_number('1086108')->is_valid_number, '東京都港区港南品川インターシティB棟(8階)');
ok($zip->set_number('1086109')->is_valid_number, '東京都港区港南品川インターシティB棟(9階)');
ok($zip->set_number('1086110')->is_valid_number, '東京都港区港南品川インターシティB棟(10階)');
ok($zip->set_number('1086111')->is_valid_number, '東京都港区港南品川インターシティB棟(11階)');
ok($zip->set_number('1086112')->is_valid_number, '東京都港区港南品川インターシティB棟(12階)');
ok($zip->set_number('1086113')->is_valid_number, '東京都港区港南品川インターシティB棟(13階)');
ok($zip->set_number('1086114')->is_valid_number, '東京都港区港南品川インターシティB棟(14階)');
ok($zip->set_number('1086115')->is_valid_number, '東京都港区港南品川インターシティB棟(15階)');
ok($zip->set_number('1086116')->is_valid_number, '東京都港区港南品川インターシティB棟(16階)');
ok($zip->set_number('1086117')->is_valid_number, '東京都港区港南品川インターシティB棟(17階)');
ok($zip->set_number('1086118')->is_valid_number, '東京都港区港南品川インターシティB棟(18階)');
ok($zip->set_number('1086119')->is_valid_number, '東京都港区港南品川インターシティB棟(19階)');
ok($zip->set_number('1086120')->is_valid_number, '東京都港区港南品川インターシティB棟(20階)');
ok($zip->set_number('1086121')->is_valid_number, '東京都港区港南品川インターシティB棟(21階)');
ok($zip->set_number('1086122')->is_valid_number, '東京都港区港南品川インターシティB棟(22階)');
ok($zip->set_number('1086123')->is_valid_number, '東京都港区港南品川インターシティB棟(23階)');
ok($zip->set_number('1086124')->is_valid_number, '東京都港区港南品川インターシティB棟(24階)');
ok($zip->set_number('1086125')->is_valid_number, '東京都港区港南品川インターシティB棟(25階)');
ok($zip->set_number('1086126')->is_valid_number, '東京都港区港南品川インターシティB棟(26階)');
ok($zip->set_number('1086127')->is_valid_number, '東京都港区港南品川インターシティB棟(27階)');
ok($zip->set_number('1086128')->is_valid_number, '東京都港区港南品川インターシティB棟(28階)');
ok($zip->set_number('1086129')->is_valid_number, '東京都港区港南品川インターシティB棟(29階)');
ok($zip->set_number('1086130')->is_valid_number, '東京都港区港南品川インターシティB棟(30階)');
ok($zip->set_number('1086131')->is_valid_number, '東京都港区港南品川インターシティB棟(31階)');
ok($zip->set_number('1086190')->is_valid_number, '東京都港区港南品川インターシティB棟(地階・階層不明)');
ok($zip->set_number('1086201')->is_valid_number, '東京都港区港南品川インターシティC棟(1階)');
ok($zip->set_number('1086202')->is_valid_number, '東京都港区港南品川インターシティC棟(2階)');
ok($zip->set_number('1086203')->is_valid_number, '東京都港区港南品川インターシティC棟(3階)');
ok($zip->set_number('1086204')->is_valid_number, '東京都港区港南品川インターシティC棟(4階)');
ok($zip->set_number('1086205')->is_valid_number, '東京都港区港南品川インターシティC棟(5階)');
ok($zip->set_number('1086206')->is_valid_number, '東京都港区港南品川インターシティC棟(6階)');
ok($zip->set_number('1086207')->is_valid_number, '東京都港区港南品川インターシティC棟(7階)');
ok($zip->set_number('1086208')->is_valid_number, '東京都港区港南品川インターシティC棟(8階)');
ok($zip->set_number('1086209')->is_valid_number, '東京都港区港南品川インターシティC棟(9階)');
ok($zip->set_number('1086210')->is_valid_number, '東京都港区港南品川インターシティC棟(10階)');
ok($zip->set_number('1086211')->is_valid_number, '東京都港区港南品川インターシティC棟(11階)');
ok($zip->set_number('1086212')->is_valid_number, '東京都港区港南品川インターシティC棟(12階)');
ok($zip->set_number('1086213')->is_valid_number, '東京都港区港南品川インターシティC棟(13階)');
ok($zip->set_number('1086214')->is_valid_number, '東京都港区港南品川インターシティC棟(14階)');
ok($zip->set_number('1086215')->is_valid_number, '東京都港区港南品川インターシティC棟(15階)');
ok($zip->set_number('1086216')->is_valid_number, '東京都港区港南品川インターシティC棟(16階)');
ok($zip->set_number('1086217')->is_valid_number, '東京都港区港南品川インターシティC棟(17階)');
ok($zip->set_number('1086218')->is_valid_number, '東京都港区港南品川インターシティC棟(18階)');
ok($zip->set_number('1086219')->is_valid_number, '東京都港区港南品川インターシティC棟(19階)');
ok($zip->set_number('1086220')->is_valid_number, '東京都港区港南品川インターシティC棟(20階)');
ok($zip->set_number('1086221')->is_valid_number, '東京都港区港南品川インターシティC棟(21階)');
ok($zip->set_number('1086222')->is_valid_number, '東京都港区港南品川インターシティC棟(22階)');
ok($zip->set_number('1086223')->is_valid_number, '東京都港区港南品川インターシティC棟(23階)');
ok($zip->set_number('1086224')->is_valid_number, '東京都港区港南品川インターシティC棟(24階)');
ok($zip->set_number('1086225')->is_valid_number, '東京都港区港南品川インターシティC棟(25階)');
ok($zip->set_number('1086226')->is_valid_number, '東京都港区港南品川インターシティC棟(26階)');
ok($zip->set_number('1086227')->is_valid_number, '東京都港区港南品川インターシティC棟(27階)');
ok($zip->set_number('1086228')->is_valid_number, '東京都港区港南品川インターシティC棟(28階)');
ok($zip->set_number('1086229')->is_valid_number, '東京都港区港南品川インターシティC棟(29階)');
ok($zip->set_number('1086230')->is_valid_number, '東京都港区港南品川インターシティC棟(30階)');
ok($zip->set_number('1086231')->is_valid_number, '東京都港区港南品川インターシティC棟(31階)');
ok($zip->set_number('1086290')->is_valid_number, '東京都港区港南品川インターシティC棟(地階・階層不明)');
ok($zip->set_number('1086301')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(1階)');
ok($zip->set_number('1086302')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(2階)');
ok($zip->set_number('1086303')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(3階)');
ok($zip->set_number('1086304')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(4階)');
ok($zip->set_number('1086305')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(5階)');
ok($zip->set_number('1086306')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(6階)');
ok($zip->set_number('1086307')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(7階)');
ok($zip->set_number('1086308')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(8階)');
ok($zip->set_number('1086309')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(9階)');
ok($zip->set_number('1086310')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(10階)');
ok($zip->set_number('1086311')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(11階)');
ok($zip->set_number('1086312')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(12階)');
ok($zip->set_number('1086313')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(13階)');
ok($zip->set_number('1086314')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(14階)');
ok($zip->set_number('1086315')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(15階)');
ok($zip->set_number('1086316')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(16階)');
ok($zip->set_number('1086317')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(17階)');
ok($zip->set_number('1086318')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(18階)');
ok($zip->set_number('1086319')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(19階)');
ok($zip->set_number('1086320')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(20階)');
ok($zip->set_number('1086321')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(21階)');
ok($zip->set_number('1086322')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(22階)');
ok($zip->set_number('1086323')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(23階)');
ok($zip->set_number('1086324')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(24階)');
ok($zip->set_number('1086325')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(25階)');
ok($zip->set_number('1086326')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(26階)');
ok($zip->set_number('1086327')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(27階)');
ok($zip->set_number('1086328')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(28階)');
ok($zip->set_number('1086329')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(29階)');
ok($zip->set_number('1086330')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(30階)');
ok($zip->set_number('1086390')->is_valid_number, '東京都港区三田住友不動産三田ツインビル西館(地階・階層不明)');
ok($zip->set_number('1100000')->is_valid_number, '東京都台東区以下に掲載がない場合');
ok($zip->set_number('1100001')->is_valid_number, '東京都台東区谷中');
ok($zip->set_number('1100002')->is_valid_number, '東京都台東区上野桜木');
ok($zip->set_number('1100003')->is_valid_number, '東京都台東区根岸');
ok($zip->set_number('1100004')->is_valid_number, '東京都台東区下谷');
ok($zip->set_number('1100005')->is_valid_number, '東京都台東区上野');
ok($zip->set_number('1100006')->is_valid_number, '東京都台東区秋葉原');
ok($zip->set_number('1100007')->is_valid_number, '東京都台東区上野公園');
ok($zip->set_number('1100008')->is_valid_number, '東京都台東区池之端');
ok($zip->set_number('1100011')->is_valid_number, '東京都台東区三ノ輪');
ok($zip->set_number('1100012')->is_valid_number, '東京都台東区竜泉');
ok($zip->set_number('1100013')->is_valid_number, '東京都台東区入谷');
ok($zip->set_number('1100014')->is_valid_number, '東京都台東区北上野');
ok($zip->set_number('1100015')->is_valid_number, '東京都台東区東上野');
ok($zip->set_number('1100016')->is_valid_number, '東京都台東区台東');
ok($zip->set_number('1110021')->is_valid_number, '東京都台東区日本堤');
ok($zip->set_number('1110022')->is_valid_number, '東京都台東区清川');
ok($zip->set_number('1110023')->is_valid_number, '東京都台東区橋場');
ok($zip->set_number('1110024')->is_valid_number, '東京都台東区今戸');
ok($zip->set_number('1110025')->is_valid_number, '東京都台東区東浅草');
ok($zip->set_number('1110031')->is_valid_number, '東京都台東区千束');
ok($zip->set_number('1110032')->is_valid_number, '東京都台東区浅草');
ok($zip->set_number('1110033')->is_valid_number, '東京都台東区花川戸');
ok($zip->set_number('1110034')->is_valid_number, '東京都台東区雷門');
ok($zip->set_number('1110035')->is_valid_number, '東京都台東区西浅草');
ok($zip->set_number('1110036')->is_valid_number, '東京都台東区松が谷');
ok($zip->set_number('1110041')->is_valid_number, '東京都台東区元浅草');
ok($zip->set_number('1110042')->is_valid_number, '東京都台東区寿');
ok($zip->set_number('1110043')->is_valid_number, '東京都台東区駒形');
ok($zip->set_number('1110051')->is_valid_number, '東京都台東区蔵前');
ok($zip->set_number('1110052')->is_valid_number, '東京都台東区柳橋');
ok($zip->set_number('1110053')->is_valid_number, '東京都台東区浅草橋');
ok($zip->set_number('1110054')->is_valid_number, '東京都台東区鳥越');
ok($zip->set_number('1110055')->is_valid_number, '東京都台東区三筋');
ok($zip->set_number('1110056')->is_valid_number, '東京都台東区小島');
ok($zip->set_number('1120000')->is_valid_number, '東京都文京区以下に掲載がない場合');
ok($zip->set_number('1120001')->is_valid_number, '東京都文京区白山(2~5丁目)');
ok($zip->set_number('1120002')->is_valid_number, '東京都文京区小石川');
ok($zip->set_number('1120003')->is_valid_number, '東京都文京区春日');
ok($zip->set_number('1120004')->is_valid_number, '東京都文京区後楽');
ok($zip->set_number('1120005')->is_valid_number, '東京都文京区水道');
ok($zip->set_number('1120006')->is_valid_number, '東京都文京区小日向');
ok($zip->set_number('1120011')->is_valid_number, '東京都文京区千石');
ok($zip->set_number('1120012')->is_valid_number, '東京都文京区大塚');
ok($zip->set_number('1120013')->is_valid_number, '東京都文京区音羽');
ok($zip->set_number('1120014')->is_valid_number, '東京都文京区関口');
ok($zip->set_number('1120015')->is_valid_number, '東京都文京区目白台');
ok($zip->set_number('1130001')->is_valid_number, '東京都文京区白山(1丁目)');
ok($zip->set_number('1130021')->is_valid_number, '東京都文京区本駒込');
ok($zip->set_number('1130022')->is_valid_number, '東京都文京区千駄木');
ok($zip->set_number('1130023')->is_valid_number, '東京都文京区向丘');
ok($zip->set_number('1130024')->is_valid_number, '東京都文京区西片');
ok($zip->set_number('1130031')->is_valid_number, '東京都文京区根津');
ok($zip->set_number('1130032')->is_valid_number, '東京都文京区弥生');
ok($zip->set_number('1130033')->is_valid_number, '東京都文京区本郷');
ok($zip->set_number('1130034')->is_valid_number, '東京都文京区湯島');
ok($zip->set_number('1140000')->is_valid_number, '東京都北区以下に掲載がない場合');
ok($zip->set_number('1140001')->is_valid_number, '東京都北区東十条');
ok($zip->set_number('1140002')->is_valid_number, '東京都北区王子');
ok($zip->set_number('1140003')->is_valid_number, '東京都北区豊島');
ok($zip->set_number('1140004')->is_valid_number, '東京都北区堀船');
ok($zip->set_number('1140005')->is_valid_number, '東京都北区栄町');
ok($zip->set_number('1140011')->is_valid_number, '東京都北区昭和町');
ok($zip->set_number('1140012')->is_valid_number, '東京都北区田端新町');
ok($zip->set_number('1140013')->is_valid_number, '東京都北区東田端');
ok($zip->set_number('1140014')->is_valid_number, '東京都北区田端');
ok($zip->set_number('1140015')->is_valid_number, '東京都北区中里');
ok($zip->set_number('1140016')->is_valid_number, '東京都北区上中里');
ok($zip->set_number('1140021')->is_valid_number, '東京都北区岸町');
ok($zip->set_number('1140022')->is_valid_number, '東京都北区王子本町');
ok($zip->set_number('1140023')->is_valid_number, '東京都北区滝野川');
ok($zip->set_number('1140024')->is_valid_number, '東京都北区西ケ原');
ok($zip->set_number('1140031')->is_valid_number, '東京都北区十条仲原');
ok($zip->set_number('1140032')->is_valid_number, '東京都北区中十条');
ok($zip->set_number('1140033')->is_valid_number, '東京都北区十条台');
ok($zip->set_number('1140034')->is_valid_number, '東京都北区上十条');
ok($zip->set_number('1150041')->is_valid_number, '東京都北区岩淵町');
ok($zip->set_number('1150042')->is_valid_number, '東京都北区志茂');
ok($zip->set_number('1150043')->is_valid_number, '東京都北区神谷');
ok($zip->set_number('1150044')->is_valid_number, '東京都北区赤羽南');
ok($zip->set_number('1150045')->is_valid_number, '東京都北区赤羽');
ok($zip->set_number('1150051')->is_valid_number, '東京都北区浮間');
ok($zip->set_number('1150052')->is_valid_number, '東京都北区赤羽北');
ok($zip->set_number('1150053')->is_valid_number, '東京都北区赤羽台');
ok($zip->set_number('1150054')->is_valid_number, '東京都北区桐ケ丘');
ok($zip->set_number('1150055')->is_valid_number, '東京都北区赤羽西');
ok($zip->set_number('1150056')->is_valid_number, '東京都北区西が丘');
ok($zip->set_number('1160000')->is_valid_number, '東京都荒川区以下に掲載がない場合');
ok($zip->set_number('1160001')->is_valid_number, '東京都荒川区町屋');
ok($zip->set_number('1160002')->is_valid_number, '東京都荒川区荒川');
ok($zip->set_number('1160003')->is_valid_number, '東京都荒川区南千住');
ok($zip->set_number('1160011')->is_valid_number, '東京都荒川区西尾久');
ok($zip->set_number('1160012')->is_valid_number, '東京都荒川区東尾久');
ok($zip->set_number('1160013')->is_valid_number, '東京都荒川区西日暮里');
ok($zip->set_number('1160014')->is_valid_number, '東京都荒川区東日暮里');
ok($zip->set_number('1200000')->is_valid_number, '東京都足立区以下に掲載がない場合');
ok($zip->set_number('1200001')->is_valid_number, '東京都足立区大谷田');
ok($zip->set_number('1200002')->is_valid_number, '東京都足立区中川');
ok($zip->set_number('1200003')->is_valid_number, '東京都足立区東和');
ok($zip->set_number('1200004')->is_valid_number, '東京都足立区東綾瀬');
ok($zip->set_number('1200005')->is_valid_number, '東京都足立区綾瀬');
ok($zip->set_number('1200006')->is_valid_number, '東京都足立区谷中');
ok($zip->set_number('1200011')->is_valid_number, '東京都足立区中央本町(1、2丁目)');
ok($zip->set_number('1200012')->is_valid_number, '東京都足立区青井(1~3丁目)');
ok($zip->set_number('1200013')->is_valid_number, '東京都足立区弘道');
ok($zip->set_number('1200014')->is_valid_number, '東京都足立区西綾瀬');
ok($zip->set_number('1200015')->is_valid_number, '東京都足立区足立');
ok($zip->set_number('1200021')->is_valid_number, '東京都足立区日ノ出町');
ok($zip->set_number('1200022')->is_valid_number, '東京都足立区柳原');
ok($zip->set_number('1200023')->is_valid_number, '東京都足立区千住曙町');
ok($zip->set_number('1200024')->is_valid_number, '東京都足立区千住関屋町');
ok($zip->set_number('1200025')->is_valid_number, '東京都足立区千住東');
ok($zip->set_number('1200026')->is_valid_number, '東京都足立区千住旭町');
ok($zip->set_number('1200031')->is_valid_number, '東京都足立区千住大川町');
ok($zip->set_number('1200032')->is_valid_number, '東京都足立区千住柳町');
ok($zip->set_number('1200033')->is_valid_number, '東京都足立区千住寿町');
ok($zip->set_number('1200034')->is_valid_number, '東京都足立区千住');
ok($zip->set_number('1200035')->is_valid_number, '東京都足立区千住中居町');
ok($zip->set_number('1200036')->is_valid_number, '東京都足立区千住仲町');
ok($zip->set_number('1200037')->is_valid_number, '東京都足立区千住河原町');
ok($zip->set_number('1200038')->is_valid_number, '東京都足立区千住橋戸町');
ok($zip->set_number('1200041')->is_valid_number, '東京都足立区千住元町');
ok($zip->set_number('1200042')->is_valid_number, '東京都足立区千住龍田町');
ok($zip->set_number('1200043')->is_valid_number, '東京都足立区千住宮元町');
ok($zip->set_number('1200044')->is_valid_number, '東京都足立区千住緑町');
ok($zip->set_number('1200045')->is_valid_number, '東京都足立区千住桜木');
ok($zip->set_number('1200046')->is_valid_number, '東京都足立区小台');
ok($zip->set_number('1200047')->is_valid_number, '東京都足立区宮城');
ok($zip->set_number('1210011')->is_valid_number, '東京都足立区中央本町(3~5丁目)');
ok($zip->set_number('1210012')->is_valid_number, '東京都足立区青井(4~6丁目)');
ok($zip->set_number('1210051')->is_valid_number, '東京都足立区神明');
ok($zip->set_number('1210052')->is_valid_number, '東京都足立区六木');
ok($zip->set_number('1210053')->is_valid_number, '東京都足立区佐野');
ok($zip->set_number('1210054')->is_valid_number, '東京都足立区辰沼');
ok($zip->set_number('1210055')->is_valid_number, '東京都足立区加平');
ok($zip->set_number('1210056')->is_valid_number, '東京都足立区北加平町');
ok($zip->set_number('1210057')->is_valid_number, '東京都足立区神明南');
ok($zip->set_number('1210061')->is_valid_number, '東京都足立区花畑');
ok($zip->set_number('1210062')->is_valid_number, '東京都足立区南花畑');
ok($zip->set_number('1210063')->is_valid_number, '東京都足立区東保木間');
ok($zip->set_number('1210064')->is_valid_number, '東京都足立区保木間');
ok($zip->set_number('1210071')->is_valid_number, '東京都足立区東六月町');
ok($zip->set_number('1210072')->is_valid_number, '東京都足立区保塚町');
ok($zip->set_number('1210073')->is_valid_number, '東京都足立区六町');
ok($zip->set_number('1210074')->is_valid_number, '東京都足立区西加平');
ok($zip->set_number('1210075')->is_valid_number, '東京都足立区一ツ家');
ok($zip->set_number('1210076')->is_valid_number, '東京都足立区平野');
ok($zip->set_number('1210801')->is_valid_number, '東京都足立区東伊興');
ok($zip->set_number('1210807')->is_valid_number, '東京都足立区伊興本町');
ok($zip->set_number('1210812')->is_valid_number, '東京都足立区西保木間');
ok($zip->set_number('1210813')->is_valid_number, '東京都足立区竹の塚');
ok($zip->set_number('1210814')->is_valid_number, '東京都足立区六月');
ok($zip->set_number('1210815')->is_valid_number, '東京都足立区島根');
ok($zip->set_number('1210816')->is_valid_number, '東京都足立区梅島');
ok($zip->set_number('1210822')->is_valid_number, '東京都足立区西竹の塚');
ok($zip->set_number('1210823')->is_valid_number, '東京都足立区伊興');
ok($zip->set_number('1210824')->is_valid_number, '東京都足立区西伊興');
ok($zip->set_number('1210825')->is_valid_number, '東京都足立区西伊興町');
ok($zip->set_number('1210831')->is_valid_number, '東京都足立区舎人');
ok($zip->set_number('1210832')->is_valid_number, '東京都足立区古千谷本町');
ok($zip->set_number('1210833')->is_valid_number, '東京都足立区古千谷');
ok($zip->set_number('1210834')->is_valid_number, '東京都足立区入谷町');
ok($zip->set_number('1210835')->is_valid_number, '東京都足立区舎人町');
ok($zip->set_number('1210836')->is_valid_number, '東京都足立区入谷');
ok($zip->set_number('1210837')->is_valid_number, '東京都足立区舎人公園');
ok($zip->set_number('1230841')->is_valid_number, '東京都足立区西新井');
ok($zip->set_number('1230842')->is_valid_number, '東京都足立区栗原');
ok($zip->set_number('1230843')->is_valid_number, '東京都足立区西新井栄町');
ok($zip->set_number('1230844')->is_valid_number, '東京都足立区興野');
ok($zip->set_number('1230845')->is_valid_number, '東京都足立区西新井本町');
ok($zip->set_number('1230851')->is_valid_number, '東京都足立区梅田');
ok($zip->set_number('1230852')->is_valid_number, '東京都足立区関原');
ok($zip->set_number('1230853')->is_valid_number, '東京都足立区本木');
ok($zip->set_number('1230854')->is_valid_number, '東京都足立区本木東町');
ok($zip->set_number('1230855')->is_valid_number, '東京都足立区本木南町');
ok($zip->set_number('1230856')->is_valid_number, '東京都足立区本木西町');
ok($zip->set_number('1230857')->is_valid_number, '東京都足立区本木北町');
ok($zip->set_number('1230861')->is_valid_number, '東京都足立区加賀');
ok($zip->set_number('1230862')->is_valid_number, '東京都足立区皿沼');
ok($zip->set_number('1230863')->is_valid_number, '東京都足立区谷在家');
ok($zip->set_number('1230864')->is_valid_number, '東京都足立区鹿浜');
ok($zip->set_number('1230865')->is_valid_number, '東京都足立区新田');
ok($zip->set_number('1230871')->is_valid_number, '東京都足立区椿');
ok($zip->set_number('1230872')->is_valid_number, '東京都足立区江北');
ok($zip->set_number('1230873')->is_valid_number, '東京都足立区扇');
ok($zip->set_number('1230874')->is_valid_number, '東京都足立区堀之内');
ok($zip->set_number('1240000')->is_valid_number, '東京都葛飾区以下に掲載がない場合');
ok($zip->set_number('1240001')->is_valid_number, '東京都葛飾区小菅');
ok($zip->set_number('1240002')->is_valid_number, '東京都葛飾区西亀有(1、2丁目)');
ok($zip->set_number('1240003')->is_valid_number, '東京都葛飾区お花茶屋');
ok($zip->set_number('1240004')->is_valid_number, '東京都葛飾区東堀切');
ok($zip->set_number('1240005')->is_valid_number, '東京都葛飾区宝町');
ok($zip->set_number('1240006')->is_valid_number, '東京都葛飾区堀切');
ok($zip->set_number('1240011')->is_valid_number, '東京都葛飾区四つ木');
ok($zip->set_number('1240012')->is_valid_number, '東京都葛飾区立石');
ok($zip->set_number('1240013')->is_valid_number, '東京都葛飾区東立石');
ok($zip->set_number('1240014')->is_valid_number, '東京都葛飾区東四つ木');
ok($zip->set_number('1240021')->is_valid_number, '東京都葛飾区細田');
ok($zip->set_number('1240022')->is_valid_number, '東京都葛飾区奥戸');
ok($zip->set_number('1240023')->is_valid_number, '東京都葛飾区東新小岩');
ok($zip->set_number('1240024')->is_valid_number, '東京都葛飾区新小岩');
ok($zip->set_number('1240025')->is_valid_number, '東京都葛飾区西新小岩');
ok($zip->set_number('1250002')->is_valid_number, '東京都葛飾区西亀有(3、4丁目)');
ok($zip->set_number('1250031')->is_valid_number, '東京都葛飾区西水元');
ok($zip->set_number('1250032')->is_valid_number, '東京都葛飾区水元');
ok($zip->set_number('1250033')->is_valid_number, '東京都葛飾区東水元');
ok($zip->set_number('1250034')->is_valid_number, '東京都葛飾区水元公園');
ok($zip->set_number('1250035')->is_valid_number, '東京都葛飾区南水元');
ok($zip->set_number('1250041')->is_valid_number, '東京都葛飾区東金町');
ok($zip->set_number('1250042')->is_valid_number, '東京都葛飾区金町');
ok($zip->set_number('1250043')->is_valid_number, '東京都葛飾区金町浄水場');
ok($zip->set_number('1250051')->is_valid_number, '東京都葛飾区新宿');
ok($zip->set_number('1250052')->is_valid_number, '東京都葛飾区柴又');
ok($zip->set_number('1250053')->is_valid_number, '東京都葛飾区鎌倉');
ok($zip->set_number('1250054')->is_valid_number, '東京都葛飾区高砂');
ok($zip->set_number('1250061')->is_valid_number, '東京都葛飾区亀有');
ok($zip->set_number('1250062')->is_valid_number, '東京都葛飾区青戸');
ok($zip->set_number('1250063')->is_valid_number, '東京都葛飾区白鳥');
ok($zip->set_number('1300000')->is_valid_number, '東京都墨田区以下に掲載がない場合');
ok($zip->set_number('1300001')->is_valid_number, '東京都墨田区吾妻橋');
ok($zip->set_number('1300002')->is_valid_number, '東京都墨田区業平');
ok($zip->set_number('1300003')->is_valid_number, '東京都墨田区横川');
ok($zip->set_number('1300004')->is_valid_number, '東京都墨田区本所');
ok($zip->set_number('1300005')->is_valid_number, '東京都墨田区東駒形');
ok($zip->set_number('1300011')->is_valid_number, '東京都墨田区石原');
ok($zip->set_number('1300012')->is_valid_number, '東京都墨田区太平');
ok($zip->set_number('1300013')->is_valid_number, '東京都墨田区錦糸');
ok($zip->set_number('1300014')->is_valid_number, '東京都墨田区亀沢');
ok($zip->set_number('1300015')->is_valid_number, '東京都墨田区横網');
ok($zip->set_number('1300021')->is_valid_number, '東京都墨田区緑');
ok($zip->set_number('1300022')->is_valid_number, '東京都墨田区江東橋');
ok($zip->set_number('1300023')->is_valid_number, '東京都墨田区立川');
ok($zip->set_number('1300024')->is_valid_number, '東京都墨田区菊川');
ok($zip->set_number('1300025')->is_valid_number, '東京都墨田区千歳');
ok($zip->set_number('1300026')->is_valid_number, '東京都墨田区両国');
ok($zip->set_number('1310031')->is_valid_number, '東京都墨田区墨田');
ok($zip->set_number('1310032')->is_valid_number, '東京都墨田区東向島');
ok($zip->set_number('1310033')->is_valid_number, '東京都墨田区向島');
ok($zip->set_number('1310034')->is_valid_number, '東京都墨田区堤通');
ok($zip->set_number('1310041')->is_valid_number, '東京都墨田区八広');
ok($zip->set_number('1310042')->is_valid_number, '東京都墨田区東墨田');
ok($zip->set_number('1310043')->is_valid_number, '東京都墨田区立花');
ok($zip->set_number('1310044')->is_valid_number, '東京都墨田区文花');
ok($zip->set_number('1310045')->is_valid_number, '東京都墨田区押上');
ok($zip->set_number('1310046')->is_valid_number, '東京都墨田区京島');
ok($zip->set_number('1320000')->is_valid_number, '東京都江戸川区以下に掲載がない場合');
ok($zip->set_number('1320001')->is_valid_number, '東京都江戸川区新堀');
ok($zip->set_number('1320002')->is_valid_number, '東京都江戸川区谷河内(1丁目)');
ok($zip->set_number('1320003')->is_valid_number, '東京都江戸川区春江町(1~3丁目)');
ok($zip->set_number('1320011')->is_valid_number, '東京都江戸川区瑞江');
ok($zip->set_number('1320013')->is_valid_number, '東京都江戸川区江戸川(1~3丁目、4丁目1~14番)');
ok($zip->set_number('1320014')->is_valid_number, '東京都江戸川区東瑞江');
ok($zip->set_number('1320015')->is_valid_number, '東京都江戸川区西瑞江(3丁目、4丁目3~9番)');
ok($zip->set_number('1320021')->is_valid_number, '東京都江戸川区中央');
ok($zip->set_number('1320022')->is_valid_number, '東京都江戸川区大杉');
ok($zip->set_number('1320023')->is_valid_number, '東京都江戸川区西一之江');
ok($zip->set_number('1320024')->is_valid_number, '東京都江戸川区一之江');
ok($zip->set_number('1320025')->is_valid_number, '東京都江戸川区松江');
ok($zip->set_number('1320031')->is_valid_number, '東京都江戸川区松島');
ok($zip->set_number('1320032')->is_valid_number, '東京都江戸川区西小松川町');
ok($zip->set_number('1320033')->is_valid_number, '東京都江戸川区東小松川');
ok($zip->set_number('1320034')->is_valid_number, '東京都江戸川区小松川');
ok($zip->set_number('1320035')->is_valid_number, '東京都江戸川区平井');
ok($zip->set_number('1330002')->is_valid_number, '東京都江戸川区谷河内(2丁目)');
ok($zip->set_number('1330041')->is_valid_number, '東京都江戸川区上一色');
ok($zip->set_number('1330042')->is_valid_number, '東京都江戸川区興宮町');
ok($zip->set_number('1330043')->is_valid_number, '東京都江戸川区松本');
ok($zip->set_number('1330044')->is_valid_number, '東京都江戸川区本一色');
ok($zip->set_number('1330051')->is_valid_number, '東京都江戸川区北小岩');
ok($zip->set_number('1330052')->is_valid_number, '東京都江戸川区東小岩');
ok($zip->set_number('1330053')->is_valid_number, '東京都江戸川区北篠崎');
ok($zip->set_number('1330054')->is_valid_number, '東京都江戸川区上篠崎');
ok($zip->set_number('1330055')->is_valid_number, '東京都江戸川区西篠崎');
ok($zip->set_number('1330056')->is_valid_number, '東京都江戸川区南小岩');
ok($zip->set_number('1330057')->is_valid_number, '東京都江戸川区西小岩');
ok($zip->set_number('1330061')->is_valid_number, '東京都江戸川区篠崎町');
ok($zip->set_number('1330062')->is_valid_number, '東京都江戸川区東篠崎町');
ok($zip->set_number('1330063')->is_valid_number, '東京都江戸川区東篠崎');
ok($zip->set_number('1330064')->is_valid_number, '東京都江戸川区下篠崎町');
ok($zip->set_number('1330065')->is_valid_number, '東京都江戸川区南篠崎町');
ok($zip->set_number('1330071')->is_valid_number, '東京都江戸川区東松本');
ok($zip->set_number('1330072')->is_valid_number, '東京都江戸川区鹿骨町');
ok($zip->set_number('1330073')->is_valid_number, '東京都江戸川区鹿骨');
ok($zip->set_number('1340003')->is_valid_number, '東京都江戸川区春江町(4、5丁目)');
ok($zip->set_number('1340013')->is_valid_number, '東京都江戸川区江戸川(その他)');
ok($zip->set_number('1340015')->is_valid_number, '東京都江戸川区西瑞江(4丁目1~2番・10~27番、5丁目)');
ok($zip->set_number('1340081')->is_valid_number, '東京都江戸川区北葛西');
ok($zip->set_number('1340082')->is_valid_number, '東京都江戸川区宇喜田町');
ok($zip->set_number('1340083')->is_valid_number, '東京都江戸川区中葛西');
ok($zip->set_number('1340084')->is_valid_number, '東京都江戸川区東葛西');
ok($zip->set_number('1340085')->is_valid_number, '東京都江戸川区南葛西');
ok($zip->set_number('1340086')->is_valid_number, '東京都江戸川区臨海町');
ok($zip->set_number('1340087')->is_valid_number, '東京都江戸川区清新町');
ok($zip->set_number('1340088')->is_valid_number, '東京都江戸川区西葛西');
ok($zip->set_number('1340091')->is_valid_number, '東京都江戸川区船堀');
ok($zip->set_number('1340092')->is_valid_number, '東京都江戸川区一之江町');
ok($zip->set_number('1340093')->is_valid_number, '東京都江戸川区二之江町');
ok($zip->set_number('1350000')->is_valid_number, '東京都江東区以下に掲載がない場合');
ok($zip->set_number('1350001')->is_valid_number, '東京都江東区毛利');
ok($zip->set_number('1350002')->is_valid_number, '東京都江東区住吉');
ok($zip->set_number('1350003')->is_valid_number, '東京都江東区猿江');
ok($zip->set_number('1350004')->is_valid_number, '東京都江東区森下');
ok($zip->set_number('1350005')->is_valid_number, '東京都江東区高橋');
ok($zip->set_number('1350006')->is_valid_number, '東京都江東区常盤');
ok($zip->set_number('1350007')->is_valid_number, '東京都江東区新大橋');
ok($zip->set_number('1350011')->is_valid_number, '東京都江東区扇橋');
ok($zip->set_number('1350012')->is_valid_number, '東京都江東区海辺');
ok($zip->set_number('1350013')->is_valid_number, '東京都江東区千田');
ok($zip->set_number('1350014')->is_valid_number, '東京都江東区石島');
ok($zip->set_number('1350015')->is_valid_number, '東京都江東区千石');
ok($zip->set_number('1350016')->is_valid_number, '東京都江東区東陽');
ok($zip->set_number('1350021')->is_valid_number, '東京都江東区白河');
ok($zip->set_number('1350022')->is_valid_number, '東京都江東区三好');
ok($zip->set_number('1350023')->is_valid_number, '東京都江東区平野');
ok($zip->set_number('1350024')->is_valid_number, '東京都江東区清澄');
ok($zip->set_number('1350031')->is_valid_number, '東京都江東区佐賀');
ok($zip->set_number('1350032')->is_valid_number, '東京都江東区福住');
ok($zip->set_number('1350033')->is_valid_number, '東京都江東区深川');
ok($zip->set_number('1350034')->is_valid_number, '東京都江東区永代');
ok($zip->set_number('1350041')->is_valid_number, '東京都江東区冬木');
ok($zip->set_number('1350042')->is_valid_number, '東京都江東区木場');
ok($zip->set_number('1350043')->is_valid_number, '東京都江東区塩浜');
ok($zip->set_number('1350044')->is_valid_number, '東京都江東区越中島');
ok($zip->set_number('1350045')->is_valid_number, '東京都江東区古石場');
ok($zip->set_number('1350046')->is_valid_number, '東京都江東区牡丹');
ok($zip->set_number('1350047')->is_valid_number, '東京都江東区富岡');
ok($zip->set_number('1350048')->is_valid_number, '東京都江東区門前仲町');
ok($zip->set_number('1350051')->is_valid_number, '東京都江東区枝川');
ok($zip->set_number('1350052')->is_valid_number, '東京都江東区潮見');
ok($zip->set_number('1350053')->is_valid_number, '東京都江東区辰巳');
ok($zip->set_number('1350061')->is_valid_number, '東京都江東区豊洲(次のビルを除く)');
ok($zip->set_number('1350062')->is_valid_number, '東京都江東区東雲');
ok($zip->set_number('1350063')->is_valid_number, '東京都江東区有明');
ok($zip->set_number('1350064')->is_valid_number, '東京都江東区青海');
ok($zip->set_number('1350065')->is_valid_number, '東京都江東区中央防波堤');
ok($zip->set_number('1350066')->is_valid_number, '東京都江東区海の森');
ok($zip->set_number('1350091')->is_valid_number, '東京都港区台場');
ok($zip->set_number('1350092')->is_valid_number, '東京都品川区東八潮');
ok($zip->set_number('1350093')->is_valid_number, '東京都大田区令和島');
ok($zip->set_number('1356001')->is_valid_number, '東京都江東区豊洲豊洲センタービル(1階)');
ok($zip->set_number('1356002')->is_valid_number, '東京都江東区豊洲豊洲センタービル(2階)');
ok($zip->set_number('1356003')->is_valid_number, '東京都江東区豊洲豊洲センタービル(3階)');
ok($zip->set_number('1356004')->is_valid_number, '東京都江東区豊洲豊洲センタービル(4階)');
ok($zip->set_number('1356005')->is_valid_number, '東京都江東区豊洲豊洲センタービル(5階)');
ok($zip->set_number('1356006')->is_valid_number, '東京都江東区豊洲豊洲センタービル(6階)');
ok($zip->set_number('1356007')->is_valid_number, '東京都江東区豊洲豊洲センタービル(7階)');
ok($zip->set_number('1356008')->is_valid_number, '東京都江東区豊洲豊洲センタービル(8階)');
ok($zip->set_number('1356009')->is_valid_number, '東京都江東区豊洲豊洲センタービル(9階)');
ok($zip->set_number('1356010')->is_valid_number, '東京都江東区豊洲豊洲センタービル(10階)');
ok($zip->set_number('1356011')->is_valid_number, '東京都江東区豊洲豊洲センタービル(11階)');
ok($zip->set_number('1356012')->is_valid_number, '東京都江東区豊洲豊洲センタービル(12階)');
ok($zip->set_number('1356013')->is_valid_number, '東京都江東区豊洲豊洲センタービル(13階)');
ok($zip->set_number('1356014')->is_valid_number, '東京都江東区豊洲豊洲センタービル(14階)');
ok($zip->set_number('1356015')->is_valid_number, '東京都江東区豊洲豊洲センタービル(15階)');
ok($zip->set_number('1356016')->is_valid_number, '東京都江東区豊洲豊洲センタービル(16階)');
ok($zip->set_number('1356017')->is_valid_number, '東京都江東区豊洲豊洲センタービル(17階)');
ok($zip->set_number('1356018')->is_valid_number, '東京都江東区豊洲豊洲センタービル(18階)');
ok($zip->set_number('1356019')->is_valid_number, '東京都江東区豊洲豊洲センタービル(19階)');
ok($zip->set_number('1356020')->is_valid_number, '東京都江東区豊洲豊洲センタービル(20階)');
ok($zip->set_number('1356021')->is_valid_number, '東京都江東区豊洲豊洲センタービル(21階)');
ok($zip->set_number('1356022')->is_valid_number, '東京都江東区豊洲豊洲センタービル(22階)');
ok($zip->set_number('1356023')->is_valid_number, '東京都江東区豊洲豊洲センタービル(23階)');
ok($zip->set_number('1356024')->is_valid_number, '東京都江東区豊洲豊洲センタービル(24階)');
ok($zip->set_number('1356025')->is_valid_number, '東京都江東区豊洲豊洲センタービル(25階)');
ok($zip->set_number('1356026')->is_valid_number, '東京都江東区豊洲豊洲センタービル(26階)');
ok($zip->set_number('1356027')->is_valid_number, '東京都江東区豊洲豊洲センタービル(27階)');
ok($zip->set_number('1356028')->is_valid_number, '東京都江東区豊洲豊洲センタービル(28階)');
ok($zip->set_number('1356029')->is_valid_number, '東京都江東区豊洲豊洲センタービル(29階)');
ok($zip->set_number('1356030')->is_valid_number, '東京都江東区豊洲豊洲センタービル(30階)');
ok($zip->set_number('1356031')->is_valid_number, '東京都江東区豊洲豊洲センタービル(31階)');
ok($zip->set_number('1356032')->is_valid_number, '東京都江東区豊洲豊洲センタービル(32階)');
ok($zip->set_number('1356033')->is_valid_number, '東京都江東区豊洲豊洲センタービル(33階)');
ok($zip->set_number('1356034')->is_valid_number, '東京都江東区豊洲豊洲センタービル(34階)');
ok($zip->set_number('1356035')->is_valid_number, '東京都江東区豊洲豊洲センタービル(35階)');
ok($zip->set_number('1356036')->is_valid_number, '東京都江東区豊洲豊洲センタービル(36階)');
ok($zip->set_number('1356037')->is_valid_number, '東京都江東区豊洲豊洲センタービル(37階)');
ok($zip->set_number('1356090')->is_valid_number, '東京都江東区豊洲豊洲センタービル(地階・階層不明)');
ok($zip->set_number('1360071')->is_valid_number, '東京都江東区亀戸');
ok($zip->set_number('1360072')->is_valid_number, '東京都江東区大島');
ok($zip->set_number('1360073')->is_valid_number, '東京都江東区北砂');
ok($zip->set_number('1360074')->is_valid_number, '東京都江東区東砂');
ok($zip->set_number('1360075')->is_valid_number, '東京都江東区新砂');
ok($zip->set_number('1360076')->is_valid_number, '東京都江東区南砂');
ok($zip->set_number('1360081')->is_valid_number, '東京都江東区夢の島');
ok($zip->set_number('1360082')->is_valid_number, '東京都江東区新木場');
ok($zip->set_number('1360083')->is_valid_number, '東京都江東区若洲');
ok($zip->set_number('1400000')->is_valid_number, '東京都品川区以下に掲載がない場合');
ok($zip->set_number('1400001')->is_valid_number, '東京都品川区北品川(1~4丁目)');
ok($zip->set_number('1400002')->is_valid_number, '東京都品川区東品川');
ok($zip->set_number('1400003')->is_valid_number, '東京都品川区八潮');
ok($zip->set_number('1400004')->is_valid_number, '東京都品川区南品川');
ok($zip->set_number('1400005')->is_valid_number, '東京都品川区広町');
ok($zip->set_number('1400011')->is_valid_number, '東京都品川区東大井');
ok($zip->set_number('1400012')->is_valid_number, '東京都品川区勝島');
ok($zip->set_number('1400013')->is_valid_number, '東京都品川区南大井');
ok($zip->set_number('1400014')->is_valid_number, '東京都品川区大井');
ok($zip->set_number('1400015')->is_valid_number, '東京都品川区西大井');
ok($zip->set_number('1410001')->is_valid_number, '東京都品川区北品川(5、6丁目)');
ok($zip->set_number('1410021')->is_valid_number, '東京都品川区上大崎');
ok($zip->set_number('1410022')->is_valid_number, '東京都品川区東五反田');
ok($zip->set_number('1410031')->is_valid_number, '東京都品川区西五反田');
ok($zip->set_number('1410032')->is_valid_number, '東京都品川区大崎(次のビルを除く)');
ok($zip->set_number('1410033')->is_valid_number, '東京都品川区西品川');
ok($zip->set_number('1416001')->is_valid_number, '東京都品川区大崎ThinkParkTower(1階)');
ok($zip->set_number('1416002')->is_valid_number, '東京都品川区大崎ThinkParkTower(2階)');
ok($zip->set_number('1416003')->is_valid_number, '東京都品川区大崎ThinkParkTower(3階)');
ok($zip->set_number('1416004')->is_valid_number, '東京都品川区大崎ThinkParkTower(4階)');
ok($zip->set_number('1416005')->is_valid_number, '東京都品川区大崎ThinkParkTower(5階)');
ok($zip->set_number('1416006')->is_valid_number, '東京都品川区大崎ThinkParkTower(6階)');
ok($zip->set_number('1416007')->is_valid_number, '東京都品川区大崎ThinkParkTower(7階)');
ok($zip->set_number('1416008')->is_valid_number, '東京都品川区大崎ThinkParkTower(8階)');
ok($zip->set_number('1416009')->is_valid_number, '東京都品川区大崎ThinkParkTower(9階)');
ok($zip->set_number('1416010')->is_valid_number, '東京都品川区大崎ThinkParkTower(10階)');
ok($zip->set_number('1416011')->is_valid_number, '東京都品川区大崎ThinkParkTower(11階)');
ok($zip->set_number('1416012')->is_valid_number, '東京都品川区大崎ThinkParkTower(12階)');
ok($zip->set_number('1416013')->is_valid_number, '東京都品川区大崎ThinkParkTower(13階)');
ok($zip->set_number('1416014')->is_valid_number, '東京都品川区大崎ThinkParkTower(14階)');
ok($zip->set_number('1416015')->is_valid_number, '東京都品川区大崎ThinkParkTower(15階)');
ok($zip->set_number('1416016')->is_valid_number, '東京都品川区大崎ThinkParkTower(16階)');
ok($zip->set_number('1416017')->is_valid_number, '東京都品川区大崎ThinkParkTower(17階)');
ok($zip->set_number('1416018')->is_valid_number, '東京都品川区大崎ThinkParkTower(18階)');
ok($zip->set_number('1416019')->is_valid_number, '東京都品川区大崎ThinkParkTower(19階)');
ok($zip->set_number('1416020')->is_valid_number, '東京都品川区大崎ThinkParkTower(20階)');
ok($zip->set_number('1416021')->is_valid_number, '東京都品川区大崎ThinkParkTower(21階)');
ok($zip->set_number('1416022')->is_valid_number, '東京都品川区大崎ThinkParkTower(22階)');
ok($zip->set_number('1416023')->is_valid_number, '東京都品川区大崎ThinkParkTower(23階)');
ok($zip->set_number('1416024')->is_valid_number, '東京都品川区大崎ThinkParkTower(24階)');
ok($zip->set_number('1416025')->is_valid_number, '東京都品川区大崎ThinkParkTower(25階)');
ok($zip->set_number('1416026')->is_valid_number, '東京都品川区大崎ThinkParkTower(26階)');
ok($zip->set_number('1416027')->is_valid_number, '東京都品川区大崎ThinkParkTower(27階)');
ok($zip->set_number('1416028')->is_valid_number, '東京都品川区大崎ThinkParkTower(28階)');
ok($zip->set_number('1416029')->is_valid_number, '東京都品川区大崎ThinkParkTower(29階)');
ok($zip->set_number('1416030')->is_valid_number, '東京都品川区大崎ThinkParkTower(30階)');
ok($zip->set_number('1416090')->is_valid_number, '東京都品川区大崎ThinkParkTower(地階・階層不明)');
ok($zip->set_number('1420041')->is_valid_number, '東京都品川区戸越');
ok($zip->set_number('1420042')->is_valid_number, '東京都品川区豊町');
ok($zip->set_number('1420043')->is_valid_number, '東京都品川区二葉');
ok($zip->set_number('1420051')->is_valid_number, '東京都品川区平塚');
ok($zip->set_number('1420052')->is_valid_number, '東京都品川区東中延');
ok($zip->set_number('1420053')->is_valid_number, '東京都品川区中延');
ok($zip->set_number('1420054')->is_valid_number, '東京都品川区西中延');
ok($zip->set_number('1420061')->is_valid_number, '東京都品川区小山台');
ok($zip->set_number('1420062')->is_valid_number, '東京都品川区小山');
ok($zip->set_number('1420063')->is_valid_number, '東京都品川区荏原');
ok($zip->set_number('1420064')->is_valid_number, '東京都品川区旗の台');
ok($zip->set_number('1430001')->is_valid_number, '東京都大田区東海');
ok($zip->set_number('1430002')->is_valid_number, '東京都大田区城南島');
ok($zip->set_number('1430003')->is_valid_number, '東京都大田区京浜島');
ok($zip->set_number('1430004')->is_valid_number, '東京都大田区昭和島');
ok($zip->set_number('1430005')->is_valid_number, '東京都大田区平和の森公園');
ok($zip->set_number('1430006')->is_valid_number, '東京都大田区平和島');
ok($zip->set_number('1430007')->is_valid_number, '東京都大田区ふるさとの浜辺公園');
ok($zip->set_number('1430011')->is_valid_number, '東京都大田区大森本町');
ok($zip->set_number('1430012')->is_valid_number, '東京都大田区大森東');
ok($zip->set_number('1430013')->is_valid_number, '東京都大田区大森南');
ok($zip->set_number('1430014')->is_valid_number, '東京都大田区大森中');
ok($zip->set_number('1430015')->is_valid_number, '東京都大田区大森西');
ok($zip->set_number('1430016')->is_valid_number, '東京都大田区大森北');
ok($zip->set_number('1430021')->is_valid_number, '東京都大田区北馬込');
ok($zip->set_number('1430022')->is_valid_number, '東京都大田区東馬込');
ok($zip->set_number('1430023')->is_valid_number, '東京都大田区山王');
ok($zip->set_number('1430024')->is_valid_number, '東京都大田区中央');
ok($zip->set_number('1430025')->is_valid_number, '東京都大田区南馬込');
ok($zip->set_number('1430026')->is_valid_number, '東京都大田区西馬込');
ok($zip->set_number('1430027')->is_valid_number, '東京都大田区中馬込');
ok($zip->set_number('1440000')->is_valid_number, '東京都大田区以下に掲載がない場合');
ok($zip->set_number('1440031')->is_valid_number, '東京都大田区東蒲田');
ok($zip->set_number('1440032')->is_valid_number, '東京都大田区北糀谷');
ok($zip->set_number('1440033')->is_valid_number, '東京都大田区東糀谷');
ok($zip->set_number('1440034')->is_valid_number, '東京都大田区西糀谷');
ok($zip->set_number('1440035')->is_valid_number, '東京都大田区南蒲田');
ok($zip->set_number('1440041')->is_valid_number, '東京都大田区羽田空港');
ok($zip->set_number('1440042')->is_valid_number, '東京都大田区羽田旭町');
ok($zip->set_number('1440043')->is_valid_number, '東京都大田区羽田');
ok($zip->set_number('1440044')->is_valid_number, '東京都大田区本羽田');
ok($zip->set_number('1440045')->is_valid_number, '東京都大田区南六郷');
ok($zip->set_number('1440046')->is_valid_number, '東京都大田区東六郷');
ok($zip->set_number('1440047')->is_valid_number, '東京都大田区萩中');
ok($zip->set_number('1440051')->is_valid_number, '東京都大田区西蒲田');
ok($zip->set_number('1440052')->is_valid_number, '東京都大田区蒲田');
ok($zip->set_number('1440053')->is_valid_number, '東京都大田区蒲田本町');
ok($zip->set_number('1440054')->is_valid_number, '東京都大田区新蒲田');
ok($zip->set_number('1440055')->is_valid_number, '東京都大田区仲六郷');
ok($zip->set_number('1440056')->is_valid_number, '東京都大田区西六郷');
ok($zip->set_number('1450061')->is_valid_number, '東京都大田区石川町');
ok($zip->set_number('1450062')->is_valid_number, '東京都大田区北千束');
ok($zip->set_number('1450063')->is_valid_number, '東京都大田区南千束');
ok($zip->set_number('1450064')->is_valid_number, '東京都大田区上池台');
ok($zip->set_number('1450065')->is_valid_number, '東京都大田区東雪谷');
ok($zip->set_number('1450066')->is_valid_number, '東京都大田区南雪谷');
ok($zip->set_number('1450067')->is_valid_number, '東京都大田区雪谷大塚町');
ok($zip->set_number('1450071')->is_valid_number, '東京都大田区田園調布');
ok($zip->set_number('1450072')->is_valid_number, '東京都大田区田園調布本町');
ok($zip->set_number('1450073')->is_valid_number, '東京都大田区北嶺町');
ok($zip->set_number('1450074')->is_valid_number, '東京都大田区東嶺町');
ok($zip->set_number('1450075')->is_valid_number, '東京都大田区西嶺町');
ok($zip->set_number('1450076')->is_valid_number, '東京都大田区田園調布南');
ok($zip->set_number('1460081')->is_valid_number, '東京都大田区仲池上');
ok($zip->set_number('1460082')->is_valid_number, '東京都大田区池上');
ok($zip->set_number('1460083')->is_valid_number, '東京都大田区千鳥');
ok($zip->set_number('1460084')->is_valid_number, '東京都大田区南久が原');
ok($zip->set_number('1460085')->is_valid_number, '東京都大田区久が原');
ok($zip->set_number('1460091')->is_valid_number, '東京都大田区鵜の木');
ok($zip->set_number('1460092')->is_valid_number, '東京都大田区下丸子');
ok($zip->set_number('1460093')->is_valid_number, '東京都大田区矢口');
ok($zip->set_number('1460094')->is_valid_number, '東京都大田区東矢口');
ok($zip->set_number('1460095')->is_valid_number, '東京都大田区多摩川');
ok($zip->set_number('1500000')->is_valid_number, '東京都渋谷区以下に掲載がない場合');
ok($zip->set_number('1500001')->is_valid_number, '東京都渋谷区神宮前');
ok($zip->set_number('1500002')->is_valid_number, '東京都渋谷区渋谷(次のビルを除く)');
ok($zip->set_number('1500011')->is_valid_number, '東京都渋谷区東');
ok($zip->set_number('1500012')->is_valid_number, '東京都渋谷区広尾');
ok($zip->set_number('1500013')->is_valid_number, '東京都渋谷区恵比寿(次のビルを除く)');
ok($zip->set_number('1500021')->is_valid_number, '東京都渋谷区恵比寿西');
ok($zip->set_number('1500022')->is_valid_number, '東京都渋谷区恵比寿南');
ok($zip->set_number('1500031')->is_valid_number, '東京都渋谷区桜丘町');
ok($zip->set_number('1500032')->is_valid_number, '東京都渋谷区鶯谷町');
ok($zip->set_number('1500033')->is_valid_number, '東京都渋谷区猿楽町');
ok($zip->set_number('1500034')->is_valid_number, '東京都渋谷区代官山町');
ok($zip->set_number('1500035')->is_valid_number, '東京都渋谷区鉢山町');
ok($zip->set_number('1500036')->is_valid_number, '東京都渋谷区南平台町');
ok($zip->set_number('1500041')->is_valid_number, '東京都渋谷区神南');
ok($zip->set_number('1500042')->is_valid_number, '東京都渋谷区宇田川町');
ok($zip->set_number('1500043')->is_valid_number, '東京都渋谷区道玄坂');
ok($zip->set_number('1500044')->is_valid_number, '東京都渋谷区円山町');
ok($zip->set_number('1500045')->is_valid_number, '東京都渋谷区神泉町');
ok($zip->set_number('1500046')->is_valid_number, '東京都渋谷区松濤');
ok($zip->set_number('1500047')->is_valid_number, '東京都渋谷区神山町');
ok($zip->set_number('1506001')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(1階)');
ok($zip->set_number('1506002')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(2階)');
ok($zip->set_number('1506003')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(3階)');
ok($zip->set_number('1506004')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(4階)');
ok($zip->set_number('1506005')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(5階)');
ok($zip->set_number('1506006')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(6階)');
ok($zip->set_number('1506007')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(7階)');
ok($zip->set_number('1506008')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(8階)');
ok($zip->set_number('1506009')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(9階)');
ok($zip->set_number('1506010')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(10階)');
ok($zip->set_number('1506011')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(11階)');
ok($zip->set_number('1506012')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(12階)');
ok($zip->set_number('1506013')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(13階)');
ok($zip->set_number('1506014')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(14階)');
ok($zip->set_number('1506015')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(15階)');
ok($zip->set_number('1506016')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(16階)');
ok($zip->set_number('1506017')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(17階)');
ok($zip->set_number('1506018')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(18階)');
ok($zip->set_number('1506019')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(19階)');
ok($zip->set_number('1506020')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(20階)');
ok($zip->set_number('1506021')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(21階)');
ok($zip->set_number('1506022')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(22階)');
ok($zip->set_number('1506023')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(23階)');
ok($zip->set_number('1506024')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(24階)');
ok($zip->set_number('1506025')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(25階)');
ok($zip->set_number('1506026')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(26階)');
ok($zip->set_number('1506027')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(27階)');
ok($zip->set_number('1506028')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(28階)');
ok($zip->set_number('1506029')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(29階)');
ok($zip->set_number('1506030')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(30階)');
ok($zip->set_number('1506031')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(31階)');
ok($zip->set_number('1506032')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(32階)');
ok($zip->set_number('1506033')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(33階)');
ok($zip->set_number('1506034')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(34階)');
ok($zip->set_number('1506035')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(35階)');
ok($zip->set_number('1506036')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(36階)');
ok($zip->set_number('1506037')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(37階)');
ok($zip->set_number('1506038')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(38階)');
ok($zip->set_number('1506039')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(39階)');
ok($zip->set_number('1506090')->is_valid_number, '東京都渋谷区恵比寿恵比寿ガーデンプレイス(地階・階層不明)');
ok($zip->set_number('1506101')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(1階)');
ok($zip->set_number('1506102')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(2階)');
ok($zip->set_number('1506103')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(3階)');
ok($zip->set_number('1506104')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(4階)');
ok($zip->set_number('1506105')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(5階)');
ok($zip->set_number('1506106')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(6階)');
ok($zip->set_number('1506107')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(7階)');
ok($zip->set_number('1506108')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(8階)');
ok($zip->set_number('1506109')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(9階)');
ok($zip->set_number('1506110')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(10階)');
ok($zip->set_number('1506111')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(11階)');
ok($zip->set_number('1506112')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(12階)');
ok($zip->set_number('1506113')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(13階)');
ok($zip->set_number('1506114')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(14階)');
ok($zip->set_number('1506115')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(15階)');
ok($zip->set_number('1506116')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(16階)');
ok($zip->set_number('1506117')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(17階)');
ok($zip->set_number('1506118')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(18階)');
ok($zip->set_number('1506119')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(19階)');
ok($zip->set_number('1506120')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(20階)');
ok($zip->set_number('1506121')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(21階)');
ok($zip->set_number('1506122')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(22階)');
ok($zip->set_number('1506123')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(23階)');
ok($zip->set_number('1506124')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(24階)');
ok($zip->set_number('1506125')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(25階)');
ok($zip->set_number('1506126')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(26階)');
ok($zip->set_number('1506127')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(27階)');
ok($zip->set_number('1506128')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(28階)');
ok($zip->set_number('1506129')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(29階)');
ok($zip->set_number('1506130')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(30階)');
ok($zip->set_number('1506131')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(31階)');
ok($zip->set_number('1506132')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(32階)');
ok($zip->set_number('1506133')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(33階)');
ok($zip->set_number('1506134')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(34階)');
ok($zip->set_number('1506135')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(35階)');
ok($zip->set_number('1506136')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(36階)');
ok($zip->set_number('1506137')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(37階)');
ok($zip->set_number('1506138')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(38階)');
ok($zip->set_number('1506139')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(39階)');
ok($zip->set_number('1506140')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(40階)');
ok($zip->set_number('1506141')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(41階)');
ok($zip->set_number('1506142')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(42階)');
ok($zip->set_number('1506143')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(43階)');
ok($zip->set_number('1506144')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(44階)');
ok($zip->set_number('1506145')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(45階)');
ok($zip->set_number('1506146')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(46階)');
ok($zip->set_number('1506147')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(47階)');
ok($zip->set_number('1506190')->is_valid_number, '東京都渋谷区渋谷渋谷スクランブルスクエア(地階・階層不明)');
ok($zip->set_number('1510051')->is_valid_number, '東京都渋谷区千駄ヶ谷');
ok($zip->set_number('1510052')->is_valid_number, '東京都渋谷区代々木神園町');
ok($zip->set_number('1510053')->is_valid_number, '東京都渋谷区代々木');
ok($zip->set_number('1510061')->is_valid_number, '東京都渋谷区初台');
ok($zip->set_number('1510062')->is_valid_number, '東京都渋谷区元代々木町');
ok($zip->set_number('1510063')->is_valid_number, '東京都渋谷区富ヶ谷');
ok($zip->set_number('1510064')->is_valid_number, '東京都渋谷区上原');
ok($zip->set_number('1510065')->is_valid_number, '東京都渋谷区大山町');
ok($zip->set_number('1510066')->is_valid_number, '東京都渋谷区西原');
ok($zip->set_number('1510071')->is_valid_number, '東京都渋谷区本町');
ok($zip->set_number('1510072')->is_valid_number, '東京都渋谷区幡ヶ谷');
ok($zip->set_number('1510073')->is_valid_number, '東京都渋谷区笹塚');
ok($zip->set_number('1520000')->is_valid_number, '東京都目黒区以下に掲載がない場合');
ok($zip->set_number('1520001')->is_valid_number, '東京都目黒区中央町');
ok($zip->set_number('1520002')->is_valid_number, '東京都目黒区目黒本町');
ok($zip->set_number('1520003')->is_valid_number, '東京都目黒区碑文谷');
ok($zip->set_number('1520004')->is_valid_number, '東京都目黒区鷹番');
ok($zip->set_number('1520011')->is_valid_number, '東京都目黒区原町');
ok($zip->set_number('1520012')->is_valid_number, '東京都目黒区洗足');
ok($zip->set_number('1520013')->is_valid_number, '東京都目黒区南');
ok($zip->set_number('1520021')->is_valid_number, '東京都目黒区東が丘');
ok($zip->set_number('1520022')->is_valid_number, '東京都目黒区柿の木坂');
ok($zip->set_number('1520023')->is_valid_number, '東京都目黒区八雲');
ok($zip->set_number('1520031')->is_valid_number, '東京都目黒区中根');
ok($zip->set_number('1520032')->is_valid_number, '東京都目黒区平町');
ok($zip->set_number('1520033')->is_valid_number, '東京都目黒区大岡山');
ok($zip->set_number('1520034')->is_valid_number, '東京都目黒区緑が丘');
ok($zip->set_number('1520035')->is_valid_number, '東京都目黒区自由が丘');
ok($zip->set_number('1530041')->is_valid_number, '東京都目黒区駒場');
ok($zip->set_number('1530042')->is_valid_number, '東京都目黒区青葉台');
ok($zip->set_number('1530043')->is_valid_number, '東京都目黒区東山');
ok($zip->set_number('1530044')->is_valid_number, '東京都目黒区大橋');
ok($zip->set_number('1530051')->is_valid_number, '東京都目黒区上目黒');
ok($zip->set_number('1530052')->is_valid_number, '東京都目黒区祐天寺');
ok($zip->set_number('1530053')->is_valid_number, '東京都目黒区五本木');
ok($zip->set_number('1530061')->is_valid_number, '東京都目黒区中目黒');
ok($zip->set_number('1530062')->is_valid_number, '東京都目黒区三田');
ok($zip->set_number('1530063')->is_valid_number, '東京都目黒区目黒');
ok($zip->set_number('1530064')->is_valid_number, '東京都目黒区下目黒');
ok($zip->set_number('1530065')->is_valid_number, '東京都目黒区中町');
ok($zip->set_number('1540000')->is_valid_number, '東京都世田谷区以下に掲載がない場合');
ok($zip->set_number('1540001')->is_valid_number, '東京都世田谷区池尻');
ok($zip->set_number('1540002')->is_valid_number, '東京都世田谷区下馬');
ok($zip->set_number('1540003')->is_valid_number, '東京都世田谷区野沢');
ok($zip->set_number('1540004')->is_valid_number, '東京都世田谷区太子堂');
ok($zip->set_number('1540005')->is_valid_number, '東京都世田谷区三宿');
ok($zip->set_number('1540011')->is_valid_number, '東京都世田谷区上馬');
ok($zip->set_number('1540012')->is_valid_number, '東京都世田谷区駒沢');
ok($zip->set_number('1540013')->is_valid_number, '東京都世田谷区駒沢公園');
ok($zip->set_number('1540014')->is_valid_number, '東京都世田谷区新町');
ok($zip->set_number('1540015')->is_valid_number, '東京都世田谷区桜新町');
ok($zip->set_number('1540016')->is_valid_number, '東京都世田谷区弦巻');
ok($zip->set_number('1540017')->is_valid_number, '東京都世田谷区世田谷');
ok($zip->set_number('1540021')->is_valid_number, '東京都世田谷区豪徳寺');
ok($zip->set_number('1540022')->is_valid_number, '東京都世田谷区梅丘');
ok($zip->set_number('1540023')->is_valid_number, '東京都世田谷区若林');
ok($zip->set_number('1540024')->is_valid_number, '東京都世田谷区三軒茶屋');
ok($zip->set_number('1550031')->is_valid_number, '東京都世田谷区北沢');
ok($zip->set_number('1550032')->is_valid_number, '東京都世田谷区代沢');
ok($zip->set_number('1550033')->is_valid_number, '東京都世田谷区代田');
ok($zip->set_number('1560041')->is_valid_number, '東京都世田谷区大原');
ok($zip->set_number('1560042')->is_valid_number, '東京都世田谷区羽根木');
ok($zip->set_number('1560043')->is_valid_number, '東京都世田谷区松原');
ok($zip->set_number('1560044')->is_valid_number, '東京都世田谷区赤堤');
ok($zip->set_number('1560045')->is_valid_number, '東京都世田谷区桜上水');
ok($zip->set_number('1560051')->is_valid_number, '東京都世田谷区宮坂');
ok($zip->set_number('1560052')->is_valid_number, '東京都世田谷区経堂');
ok($zip->set_number('1560053')->is_valid_number, '東京都世田谷区桜');
ok($zip->set_number('1560054')->is_valid_number, '東京都世田谷区桜丘');
ok($zip->set_number('1560055')->is_valid_number, '東京都世田谷区船橋');
ok($zip->set_number('1560056')->is_valid_number, '東京都世田谷区八幡山');
ok($zip->set_number('1560057')->is_valid_number, '東京都世田谷区上北沢');
ok($zip->set_number('1570061')->is_valid_number, '東京都世田谷区北烏山');
ok($zip->set_number('1570062')->is_valid_number, '東京都世田谷区南烏山');
ok($zip->set_number('1570063')->is_valid_number, '東京都世田谷区粕谷');
ok($zip->set_number('1570064')->is_valid_number, '東京都世田谷区給田');
ok($zip->set_number('1570065')->is_valid_number, '東京都世田谷区上祖師谷');
ok($zip->set_number('1570066')->is_valid_number, '東京都世田谷区成城');
ok($zip->set_number('1570067')->is_valid_number, '東京都世田谷区喜多見');
ok($zip->set_number('1570068')->is_valid_number, '東京都世田谷区宇奈根');
ok($zip->set_number('1570071')->is_valid_number, '東京都世田谷区千歳台');
ok($zip->set_number('1570072')->is_valid_number, '東京都世田谷区祖師谷');
ok($zip->set_number('1570073')->is_valid_number, '東京都世田谷区砧');
ok($zip->set_number('1570074')->is_valid_number, '東京都世田谷区大蔵');
ok($zip->set_number('1570075')->is_valid_number, '東京都世田谷区砧公園');
ok($zip->set_number('1570076')->is_valid_number, '東京都世田谷区岡本');
ok($zip->set_number('1570077')->is_valid_number, '東京都世田谷区鎌田');
ok($zip->set_number('1580081')->is_valid_number, '東京都世田谷区深沢');
ok($zip->set_number('1580082')->is_valid_number, '東京都世田谷区等々力');
ok($zip->set_number('1580083')->is_valid_number, '東京都世田谷区奥沢');
ok($zip->set_number('1580084')->is_valid_number, '東京都世田谷区東玉川');
ok($zip->set_number('1580085')->is_valid_number, '東京都世田谷区玉川田園調布');
ok($zip->set_number('1580086')->is_valid_number, '東京都世田谷区尾山台');
ok($zip->set_number('1580087')->is_valid_number, '東京都世田谷区玉堤');
ok($zip->set_number('1580091')->is_valid_number, '東京都世田谷区中町');
ok($zip->set_number('1580092')->is_valid_number, '東京都世田谷区野毛');
ok($zip->set_number('1580093')->is_valid_number, '東京都世田谷区上野毛');
ok($zip->set_number('1580094')->is_valid_number, '東京都世田谷区玉川');
ok($zip->set_number('1580095')->is_valid_number, '東京都世田谷区瀬田');
ok($zip->set_number('1580096')->is_valid_number, '東京都世田谷区玉川台');
ok($zip->set_number('1580097')->is_valid_number, '東京都世田谷区用賀');
ok($zip->set_number('1580098')->is_valid_number, '東京都世田谷区上用賀');
ok($zip->set_number('1600000')->is_valid_number, '東京都新宿区以下に掲載がない場合');
ok($zip->set_number('1600001')->is_valid_number, '東京都新宿区片町');
ok($zip->set_number('1600002')->is_valid_number, '東京都新宿区四谷坂町');
ok($zip->set_number('1600003')->is_valid_number, '東京都新宿区四谷本塩町');
ok($zip->set_number('1600004')->is_valid_number, '東京都新宿区四谷');
ok($zip->set_number('1600005')->is_valid_number, '東京都新宿区愛住町');
ok($zip->set_number('1600006')->is_valid_number, '東京都新宿区舟町');
ok($zip->set_number('1600007')->is_valid_number, '東京都新宿区荒木町');
ok($zip->set_number('1600008')->is_valid_number, '東京都新宿区四谷三栄町');
ok($zip->set_number('1600011')->is_valid_number, '東京都新宿区若葉');
ok($zip->set_number('1600012')->is_valid_number, '東京都新宿区南元町');
ok($zip->set_number('1600013')->is_valid_number, '東京都新宿区霞ケ丘町');
ok($zip->set_number('1600014')->is_valid_number, '東京都新宿区内藤町');
ok($zip->set_number('1600015')->is_valid_number, '東京都新宿区大京町');
ok($zip->set_number('1600016')->is_valid_number, '東京都新宿区信濃町');
ok($zip->set_number('1600017')->is_valid_number, '東京都新宿区左門町');
ok($zip->set_number('1600018')->is_valid_number, '東京都新宿区須賀町');
ok($zip->set_number('1600021')->is_valid_number, '東京都新宿区歌舞伎町');
ok($zip->set_number('1600022')->is_valid_number, '東京都新宿区新宿');
ok($zip->set_number('1600023')->is_valid_number, '東京都新宿区西新宿(次のビルを除く)');
ok($zip->set_number('1606101')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(1階)');
ok($zip->set_number('1606102')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(2階)');
ok($zip->set_number('1606103')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(3階)');
ok($zip->set_number('1606104')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(4階)');
ok($zip->set_number('1606105')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(5階)');
ok($zip->set_number('1606106')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(6階)');
ok($zip->set_number('1606107')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(7階)');
ok($zip->set_number('1606108')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(8階)');
ok($zip->set_number('1606109')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(9階)');
ok($zip->set_number('1606110')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(10階)');
ok($zip->set_number('1606111')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(11階)');
ok($zip->set_number('1606112')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(12階)');
ok($zip->set_number('1606113')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(13階)');
ok($zip->set_number('1606114')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(14階)');
ok($zip->set_number('1606115')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(15階)');
ok($zip->set_number('1606116')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(16階)');
ok($zip->set_number('1606117')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(17階)');
ok($zip->set_number('1606118')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(18階)');
ok($zip->set_number('1606119')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(19階)');
ok($zip->set_number('1606120')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(20階)');
ok($zip->set_number('1606121')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(21階)');
ok($zip->set_number('1606122')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(22階)');
ok($zip->set_number('1606123')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(23階)');
ok($zip->set_number('1606124')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(24階)');
ok($zip->set_number('1606125')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(25階)');
ok($zip->set_number('1606126')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(26階)');
ok($zip->set_number('1606127')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(27階)');
ok($zip->set_number('1606128')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(28階)');
ok($zip->set_number('1606129')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(29階)');
ok($zip->set_number('1606130')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(30階)');
ok($zip->set_number('1606131')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(31階)');
ok($zip->set_number('1606132')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(32階)');
ok($zip->set_number('1606133')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(33階)');
ok($zip->set_number('1606134')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(34階)');
ok($zip->set_number('1606135')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(35階)');
ok($zip->set_number('1606136')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(36階)');
ok($zip->set_number('1606137')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(37階)');
ok($zip->set_number('1606138')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(38階)');
ok($zip->set_number('1606139')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(39階)');
ok($zip->set_number('1606190')->is_valid_number, '東京都新宿区西新宿住友不動産新宿グランドタワー(地階・階層不明)');
ok($zip->set_number('1610031')->is_valid_number, '東京都新宿区西落合');
ok($zip->set_number('1610032')->is_valid_number, '東京都新宿区中落合');
ok($zip->set_number('1610033')->is_valid_number, '東京都新宿区下落合');
ok($zip->set_number('1610034')->is_valid_number, '東京都新宿区上落合');
ok($zip->set_number('1610035')->is_valid_number, '東京都新宿区中井');
ok($zip->set_number('1620041')->is_valid_number, '東京都新宿区早稲田鶴巻町');
ok($zip->set_number('1620042')->is_valid_number, '東京都新宿区早稲田町');
ok($zip->set_number('1620043')->is_valid_number, '東京都新宿区早稲田南町');
ok($zip->set_number('1620044')->is_valid_number, '東京都新宿区喜久井町');
ok($zip->set_number('1620045')->is_valid_number, '東京都新宿区馬場下町');
ok($zip->set_number('1620051')->is_valid_number, '東京都新宿区西早稲田(2丁目1番1~23号、2番)');
ok($zip->set_number('1620052')->is_valid_number, '東京都新宿区戸山(その他)');
ok($zip->set_number('1620053')->is_valid_number, '東京都新宿区原町');
ok($zip->set_number('1620054')->is_valid_number, '東京都新宿区河田町');
ok($zip->set_number('1620055')->is_valid_number, '東京都新宿区余丁町');
ok($zip->set_number('1620056')->is_valid_number, '東京都新宿区若松町');
ok($zip->set_number('1620061')->is_valid_number, '東京都新宿区市谷柳町');
ok($zip->set_number('1620062')->is_valid_number, '東京都新宿区市谷加賀町');
ok($zip->set_number('1620063')->is_valid_number, '東京都新宿区市谷薬王寺町');
ok($zip->set_number('1620064')->is_valid_number, '東京都新宿区市谷仲之町');
ok($zip->set_number('1620065')->is_valid_number, '東京都新宿区住吉町');
ok($zip->set_number('1620066')->is_valid_number, '東京都新宿区市谷台町');
ok($zip->set_number('1620067')->is_valid_number, '東京都新宿区富久町');
ok($zip->set_number('1620801')->is_valid_number, '東京都新宿区山吹町');
ok($zip->set_number('1620802')->is_valid_number, '東京都新宿区改代町');
ok($zip->set_number('1620803')->is_valid_number, '東京都新宿区赤城下町');
ok($zip->set_number('1620804')->is_valid_number, '東京都新宿区中里町');
ok($zip->set_number('1620805')->is_valid_number, '東京都新宿区矢来町');
ok($zip->set_number('1620806')->is_valid_number, '東京都新宿区榎町');
ok($zip->set_number('1620807')->is_valid_number, '東京都新宿区東榎町');
ok($zip->set_number('1620808')->is_valid_number, '東京都新宿区天神町');
ok($zip->set_number('1620811')->is_valid_number, '東京都新宿区水道町');
ok($zip->set_number('1620812')->is_valid_number, '東京都新宿区西五軒町');
ok($zip->set_number('1620813')->is_valid_number, '東京都新宿区東五軒町');
ok($zip->set_number('1620814')->is_valid_number, '東京都新宿区新小川町');
ok($zip->set_number('1620815')->is_valid_number, '東京都新宿区筑土八幡町');
ok($zip->set_number('1620816')->is_valid_number, '東京都新宿区白銀町');
ok($zip->set_number('1620817')->is_valid_number, '東京都新宿区赤城元町');
ok($zip->set_number('1620818')->is_valid_number, '東京都新宿区築地町');
ok($zip->set_number('1620821')->is_valid_number, '東京都新宿区津久戸町');
ok($zip->set_number('1620822')->is_valid_number, '東京都新宿区下宮比町');
ok($zip->set_number('1620823')->is_valid_number, '東京都新宿区神楽河岸');
ok($zip->set_number('1620824')->is_valid_number, '東京都新宿区揚場町');
ok($zip->set_number('1620825')->is_valid_number, '東京都新宿区神楽坂');
ok($zip->set_number('1620826')->is_valid_number, '東京都新宿区市谷船河原町');
ok($zip->set_number('1620827')->is_valid_number, '東京都新宿区若宮町');
ok($zip->set_number('1620828')->is_valid_number, '東京都新宿区袋町');
ok($zip->set_number('1620831')->is_valid_number, '東京都新宿区横寺町');
ok($zip->set_number('1620832')->is_valid_number, '東京都新宿区岩戸町');
ok($zip->set_number('1620833')->is_valid_number, '東京都新宿区箪笥町');
ok($zip->set_number('1620834')->is_valid_number, '東京都新宿区北町');
ok($zip->set_number('1620835')->is_valid_number, '東京都新宿区中町');
ok($zip->set_number('1620836')->is_valid_number, '東京都新宿区南町');
ok($zip->set_number('1620837')->is_valid_number, '東京都新宿区納戸町');
ok($zip->set_number('1620838')->is_valid_number, '東京都新宿区細工町');
ok($zip->set_number('1620841')->is_valid_number, '東京都新宿区払方町');
ok($zip->set_number('1620842')->is_valid_number, '東京都新宿区市谷砂土原町');
ok($zip->set_number('1620843')->is_valid_number, '東京都新宿区市谷田町');
ok($zip->set_number('1620844')->is_valid_number, '東京都新宿区市谷八幡町');
ok($zip->set_number('1620845')->is_valid_number, '東京都新宿区市谷本村町');
ok($zip->set_number('1620846')->is_valid_number, '東京都新宿区市谷左内町');
ok($zip->set_number('1620847')->is_valid_number, '東京都新宿区市谷長延寺町');
ok($zip->set_number('1620848')->is_valid_number, '東京都新宿区市谷鷹匠町');
ok($zip->set_number('1620851')->is_valid_number, '東京都新宿区弁天町');
ok($zip->set_number('1620852')->is_valid_number, '東京都新宿区南榎町');
ok($zip->set_number('1620853')->is_valid_number, '東京都新宿区北山伏町');
ok($zip->set_number('1620854')->is_valid_number, '東京都新宿区南山伏町');
ok($zip->set_number('1620855')->is_valid_number, '東京都新宿区二十騎町');
ok($zip->set_number('1620856')->is_valid_number, '東京都新宿区市谷甲良町');
ok($zip->set_number('1620857')->is_valid_number, '東京都新宿区市谷山伏町');
ok($zip->set_number('1630201')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(1階)');
ok($zip->set_number('1630202')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(2階)');
ok($zip->set_number('1630203')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(3階)');
ok($zip->set_number('1630204')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(4階)');
ok($zip->set_number('1630205')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(5階)');
ok($zip->set_number('1630206')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(6階)');
ok($zip->set_number('1630207')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(7階)');
ok($zip->set_number('1630208')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(8階)');
ok($zip->set_number('1630209')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(9階)');
ok($zip->set_number('1630210')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(10階)');
ok($zip->set_number('1630211')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(11階)');
ok($zip->set_number('1630212')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(12階)');
ok($zip->set_number('1630213')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(13階)');
ok($zip->set_number('1630214')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(14階)');
ok($zip->set_number('1630215')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(15階)');
ok($zip->set_number('1630216')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(16階)');
ok($zip->set_number('1630217')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(17階)');
ok($zip->set_number('1630218')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(18階)');
ok($zip->set_number('1630219')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(19階)');
ok($zip->set_number('1630220')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(20階)');
ok($zip->set_number('1630221')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(21階)');
ok($zip->set_number('1630222')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(22階)');
ok($zip->set_number('1630223')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(23階)');
ok($zip->set_number('1630224')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(24階)');
ok($zip->set_number('1630225')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(25階)');
ok($zip->set_number('1630226')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(26階)');
ok($zip->set_number('1630227')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(27階)');
ok($zip->set_number('1630228')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(28階)');
ok($zip->set_number('1630229')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(29階)');
ok($zip->set_number('1630230')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(30階)');
ok($zip->set_number('1630231')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(31階)');
ok($zip->set_number('1630232')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(32階)');
ok($zip->set_number('1630233')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(33階)');
ok($zip->set_number('1630234')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(34階)');
ok($zip->set_number('1630235')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(35階)');
ok($zip->set_number('1630236')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(36階)');
ok($zip->set_number('1630237')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(37階)');
ok($zip->set_number('1630238')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(38階)');
ok($zip->set_number('1630239')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(39階)');
ok($zip->set_number('1630240')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(40階)');
ok($zip->set_number('1630241')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(41階)');
ok($zip->set_number('1630242')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(42階)');
ok($zip->set_number('1630243')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(43階)');
ok($zip->set_number('1630244')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(44階)');
ok($zip->set_number('1630245')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(45階)');
ok($zip->set_number('1630246')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(46階)');
ok($zip->set_number('1630247')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(47階)');
ok($zip->set_number('1630248')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(48階)');
ok($zip->set_number('1630249')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(49階)');
ok($zip->set_number('1630250')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(50階)');
ok($zip->set_number('1630251')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(51階)');
ok($zip->set_number('1630252')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(52階)');
ok($zip->set_number('1630290')->is_valid_number, '東京都新宿区西新宿新宿住友ビル(地階・階層不明)');
ok($zip->set_number('1630401')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(1階)');
ok($zip->set_number('1630402')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(2階)');
ok($zip->set_number('1630403')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(3階)');
ok($zip->set_number('1630404')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(4階)');
ok($zip->set_number('1630405')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(5階)');
ok($zip->set_number('1630406')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(6階)');
ok($zip->set_number('1630407')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(7階)');
ok($zip->set_number('1630408')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(8階)');
ok($zip->set_number('1630409')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(9階)');
ok($zip->set_number('1630410')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(10階)');
ok($zip->set_number('1630411')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(11階)');
ok($zip->set_number('1630412')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(12階)');
ok($zip->set_number('1630413')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(13階)');
ok($zip->set_number('1630414')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(14階)');
ok($zip->set_number('1630415')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(15階)');
ok($zip->set_number('1630416')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(16階)');
ok($zip->set_number('1630417')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(17階)');
ok($zip->set_number('1630418')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(18階)');
ok($zip->set_number('1630419')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(19階)');
ok($zip->set_number('1630420')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(20階)');
ok($zip->set_number('1630421')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(21階)');
ok($zip->set_number('1630422')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(22階)');
ok($zip->set_number('1630423')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(23階)');
ok($zip->set_number('1630424')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(24階)');
ok($zip->set_number('1630425')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(25階)');
ok($zip->set_number('1630426')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(26階)');
ok($zip->set_number('1630427')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(27階)');
ok($zip->set_number('1630428')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(28階)');
ok($zip->set_number('1630429')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(29階)');
ok($zip->set_number('1630430')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(30階)');
ok($zip->set_number('1630431')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(31階)');
ok($zip->set_number('1630432')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(32階)');
ok($zip->set_number('1630433')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(33階)');
ok($zip->set_number('1630434')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(34階)');
ok($zip->set_number('1630435')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(35階)');
ok($zip->set_number('1630436')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(36階)');
ok($zip->set_number('1630437')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(37階)');
ok($zip->set_number('1630438')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(38階)');
ok($zip->set_number('1630439')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(39階)');
ok($zip->set_number('1630440')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(40階)');
ok($zip->set_number('1630441')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(41階)');
ok($zip->set_number('1630442')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(42階)');
ok($zip->set_number('1630443')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(43階)');
ok($zip->set_number('1630444')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(44階)');
ok($zip->set_number('1630445')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(45階)');
ok($zip->set_number('1630446')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(46階)');
ok($zip->set_number('1630447')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(47階)');
ok($zip->set_number('1630448')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(48階)');
ok($zip->set_number('1630449')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(49階)');
ok($zip->set_number('1630450')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(50階)');
ok($zip->set_number('1630451')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(51階)');
ok($zip->set_number('1630452')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(52階)');
ok($zip->set_number('1630453')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(53階)');
ok($zip->set_number('1630454')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(54階)');
ok($zip->set_number('1630455')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(55階)');
ok($zip->set_number('1630490')->is_valid_number, '東京都新宿区西新宿新宿三井ビル(地階・階層不明)');
ok($zip->set_number('1630501')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(1階)');
ok($zip->set_number('1630502')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(2階)');
ok($zip->set_number('1630503')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(3階)');
ok($zip->set_number('1630504')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(4階)');
ok($zip->set_number('1630505')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(5階)');
ok($zip->set_number('1630506')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(6階)');
ok($zip->set_number('1630507')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(7階)');
ok($zip->set_number('1630508')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(8階)');
ok($zip->set_number('1630509')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(9階)');
ok($zip->set_number('1630510')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(10階)');
ok($zip->set_number('1630511')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(11階)');
ok($zip->set_number('1630512')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(12階)');
ok($zip->set_number('1630513')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(13階)');
ok($zip->set_number('1630514')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(14階)');
ok($zip->set_number('1630515')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(15階)');
ok($zip->set_number('1630516')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(16階)');
ok($zip->set_number('1630517')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(17階)');
ok($zip->set_number('1630518')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(18階)');
ok($zip->set_number('1630519')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(19階)');
ok($zip->set_number('1630520')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(20階)');
ok($zip->set_number('1630521')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(21階)');
ok($zip->set_number('1630522')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(22階)');
ok($zip->set_number('1630523')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(23階)');
ok($zip->set_number('1630524')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(24階)');
ok($zip->set_number('1630525')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(25階)');
ok($zip->set_number('1630526')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(26階)');
ok($zip->set_number('1630527')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(27階)');
ok($zip->set_number('1630528')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(28階)');
ok($zip->set_number('1630529')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(29階)');
ok($zip->set_number('1630530')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(30階)');
ok($zip->set_number('1630531')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(31階)');
ok($zip->set_number('1630532')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(32階)');
ok($zip->set_number('1630533')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(33階)');
ok($zip->set_number('1630534')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(34階)');
ok($zip->set_number('1630535')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(35階)');
ok($zip->set_number('1630536')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(36階)');
ok($zip->set_number('1630537')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(37階)');
ok($zip->set_number('1630538')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(38階)');
ok($zip->set_number('1630539')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(39階)');
ok($zip->set_number('1630540')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(40階)');
ok($zip->set_number('1630541')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(41階)');
ok($zip->set_number('1630542')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(42階)');
ok($zip->set_number('1630543')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(43階)');
ok($zip->set_number('1630544')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(44階)');
ok($zip->set_number('1630545')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(45階)');
ok($zip->set_number('1630546')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(46階)');
ok($zip->set_number('1630547')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(47階)');
ok($zip->set_number('1630548')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(48階)');
ok($zip->set_number('1630549')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(49階)');
ok($zip->set_number('1630550')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(50階)');
ok($zip->set_number('1630590')->is_valid_number, '東京都新宿区西新宿新宿野村ビル(地階・階層不明)');
ok($zip->set_number('1630601')->is_valid_number, '東京都新宿区西新宿新宿センタービル(1階)');
ok($zip->set_number('1630602')->is_valid_number, '東京都新宿区西新宿新宿センタービル(2階)');
ok($zip->set_number('1630603')->is_valid_number, '東京都新宿区西新宿新宿センタービル(3階)');
ok($zip->set_number('1630604')->is_valid_number, '東京都新宿区西新宿新宿センタービル(4階)');
ok($zip->set_number('1630605')->is_valid_number, '東京都新宿区西新宿新宿センタービル(5階)');
ok($zip->set_number('1630606')->is_valid_number, '東京都新宿区西新宿新宿センタービル(6階)');
ok($zip->set_number('1630607')->is_valid_number, '東京都新宿区西新宿新宿センタービル(7階)');
ok($zip->set_number('1630608')->is_valid_number, '東京都新宿区西新宿新宿センタービル(8階)');
ok($zip->set_number('1630609')->is_valid_number, '東京都新宿区西新宿新宿センタービル(9階)');
ok($zip->set_number('1630610')->is_valid_number, '東京都新宿区西新宿新宿センタービル(10階)');
ok($zip->set_number('1630611')->is_valid_number, '東京都新宿区西新宿新宿センタービル(11階)');
ok($zip->set_number('1630612')->is_valid_number, '東京都新宿区西新宿新宿センタービル(12階)');
ok($zip->set_number('1630613')->is_valid_number, '東京都新宿区西新宿新宿センタービル(13階)');
ok($zip->set_number('1630614')->is_valid_number, '東京都新宿区西新宿新宿センタービル(14階)');
ok($zip->set_number('1630615')->is_valid_number, '東京都新宿区西新宿新宿センタービル(15階)');
ok($zip->set_number('1630616')->is_valid_number, '東京都新宿区西新宿新宿センタービル(16階)');
ok($zip->set_number('1630617')->is_valid_number, '東京都新宿区西新宿新宿センタービル(17階)');
ok($zip->set_number('1630618')->is_valid_number, '東京都新宿区西新宿新宿センタービル(18階)');
ok($zip->set_number('1630619')->is_valid_number, '東京都新宿区西新宿新宿センタービル(19階)');
ok($zip->set_number('1630620')->is_valid_number, '東京都新宿区西新宿新宿センタービル(20階)');
ok($zip->set_number('1630621')->is_valid_number, '東京都新宿区西新宿新宿センタービル(21階)');
ok($zip->set_number('1630622')->is_valid_number, '東京都新宿区西新宿新宿センタービル(22階)');
ok($zip->set_number('1630623')->is_valid_number, '東京都新宿区西新宿新宿センタービル(23階)');
ok($zip->set_number('1630624')->is_valid_number, '東京都新宿区西新宿新宿センタービル(24階)');
ok($zip->set_number('1630625')->is_valid_number, '東京都新宿区西新宿新宿センタービル(25階)');
ok($zip->set_number('1630626')->is_valid_number, '東京都新宿区西新宿新宿センタービル(26階)');
ok($zip->set_number('1630627')->is_valid_number, '東京都新宿区西新宿新宿センタービル(27階)');
ok($zip->set_number('1630628')->is_valid_number, '東京都新宿区西新宿新宿センタービル(28階)');
ok($zip->set_number('1630629')->is_valid_number, '東京都新宿区西新宿新宿センタービル(29階)');
ok($zip->set_number('1630630')->is_valid_number, '東京都新宿区西新宿新宿センタービル(30階)');
ok($zip->set_number('1630631')->is_valid_number, '東京都新宿区西新宿新宿センタービル(31階)');
ok($zip->set_number('1630632')->is_valid_number, '東京都新宿区西新宿新宿センタービル(32階)');
ok($zip->set_number('1630633')->is_valid_number, '東京都新宿区西新宿新宿センタービル(33階)');
ok($zip->set_number('1630634')->is_valid_number, '東京都新宿区西新宿新宿センタービル(34階)');
ok($zip->set_number('1630635')->is_valid_number, '東京都新宿区西新宿新宿センタービル(35階)');
ok($zip->set_number('1630636')->is_valid_number, '東京都新宿区西新宿新宿センタービル(36階)');
ok($zip->set_number('1630637')->is_valid_number, '東京都新宿区西新宿新宿センタービル(37階)');
ok($zip->set_number('1630638')->is_valid_number, '東京都新宿区西新宿新宿センタービル(38階)');
ok($zip->set_number('1630639')->is_valid_number, '東京都新宿区西新宿新宿センタービル(39階)');
ok($zip->set_number('1630640')->is_valid_number, '東京都新宿区西新宿新宿センタービル(40階)');
ok($zip->set_number('1630641')->is_valid_number, '東京都新宿区西新宿新宿センタービル(41階)');
ok($zip->set_number('1630642')->is_valid_number, '東京都新宿区西新宿新宿センタービル(42階)');
ok($zip->set_number('1630643')->is_valid_number, '東京都新宿区西新宿新宿センタービル(43階)');
ok($zip->set_number('1630644')->is_valid_number, '東京都新宿区西新宿新宿センタービル(44階)');
ok($zip->set_number('1630645')->is_valid_number, '東京都新宿区西新宿新宿センタービル(45階)');
ok($zip->set_number('1630646')->is_valid_number, '東京都新宿区西新宿新宿センタービル(46階)');
ok($zip->set_number('1630647')->is_valid_number, '東京都新宿区西新宿新宿センタービル(47階)');
ok($zip->set_number('1630648')->is_valid_number, '東京都新宿区西新宿新宿センタービル(48階)');
ok($zip->set_number('1630649')->is_valid_number, '東京都新宿区西新宿新宿センタービル(49階)');
ok($zip->set_number('1630650')->is_valid_number, '東京都新宿区西新宿新宿センタービル(50階)');
ok($zip->set_number('1630651')->is_valid_number, '東京都新宿区西新宿新宿センタービル(51階)');
ok($zip->set_number('1630652')->is_valid_number, '東京都新宿区西新宿新宿センタービル(52階)');
ok($zip->set_number('1630653')->is_valid_number, '東京都新宿区西新宿新宿センタービル(53階)');
ok($zip->set_number('1630654')->is_valid_number, '東京都新宿区西新宿新宿センタービル(54階)');
ok($zip->set_number('1630690')->is_valid_number, '東京都新宿区西新宿新宿センタービル(地階・階層不明)');
ok($zip->set_number('1630701')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(1階)');
ok($zip->set_number('1630702')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(2階)');
ok($zip->set_number('1630703')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(3階)');
ok($zip->set_number('1630704')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(4階)');
ok($zip->set_number('1630705')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(5階)');
ok($zip->set_number('1630706')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(6階)');
ok($zip->set_number('1630707')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(7階)');
ok($zip->set_number('1630708')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(8階)');
ok($zip->set_number('1630709')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(9階)');
ok($zip->set_number('1630710')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(10階)');
ok($zip->set_number('1630711')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(11階)');
ok($zip->set_number('1630712')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(12階)');
ok($zip->set_number('1630713')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(13階)');
ok($zip->set_number('1630714')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(14階)');
ok($zip->set_number('1630715')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(15階)');
ok($zip->set_number('1630716')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(16階)');
ok($zip->set_number('1630717')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(17階)');
ok($zip->set_number('1630718')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(18階)');
ok($zip->set_number('1630719')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(19階)');
ok($zip->set_number('1630720')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(20階)');
ok($zip->set_number('1630721')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(21階)');
ok($zip->set_number('1630722')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(22階)');
ok($zip->set_number('1630723')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(23階)');
ok($zip->set_number('1630724')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(24階)');
ok($zip->set_number('1630725')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(25階)');
ok($zip->set_number('1630726')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(26階)');
ok($zip->set_number('1630790')->is_valid_number, '東京都新宿区西新宿小田急第一生命ビル(地階・階層不明)');
ok($zip->set_number('1630801')->is_valid_number, '東京都新宿区西新宿新宿NSビル(1階)');
ok($zip->set_number('1630802')->is_valid_number, '東京都新宿区西新宿新宿NSビル(2階)');
ok($zip->set_number('1630803')->is_valid_number, '東京都新宿区西新宿新宿NSビル(3階)');
ok($zip->set_number('1630804')->is_valid_number, '東京都新宿区西新宿新宿NSビル(4階)');
ok($zip->set_number('1630805')->is_valid_number, '東京都新宿区西新宿新宿NSビル(5階)');
ok($zip->set_number('1630806')->is_valid_number, '東京都新宿区西新宿新宿NSビル(6階)');
ok($zip->set_number('1630807')->is_valid_number, '東京都新宿区西新宿新宿NSビル(7階)');
ok($zip->set_number('1630808')->is_valid_number, '東京都新宿区西新宿新宿NSビル(8階)');
ok($zip->set_number('1630809')->is_valid_number, '東京都新宿区西新宿新宿NSビル(9階)');
ok($zip->set_number('1630810')->is_valid_number, '東京都新宿区西新宿新宿NSビル(10階)');
ok($zip->set_number('1630811')->is_valid_number, '東京都新宿区西新宿新宿NSビル(11階)');
ok($zip->set_number('1630812')->is_valid_number, '東京都新宿区西新宿新宿NSビル(12階)');
ok($zip->set_number('1630813')->is_valid_number, '東京都新宿区西新宿新宿NSビル(13階)');
ok($zip->set_number('1630814')->is_valid_number, '東京都新宿区西新宿新宿NSビル(14階)');
ok($zip->set_number('1630815')->is_valid_number, '東京都新宿区西新宿新宿NSビル(15階)');
ok($zip->set_number('1630816')->is_valid_number, '東京都新宿区西新宿新宿NSビル(16階)');
ok($zip->set_number('1630817')->is_valid_number, '東京都新宿区西新宿新宿NSビル(17階)');
ok($zip->set_number('1630818')->is_valid_number, '東京都新宿区西新宿新宿NSビル(18階)');
ok($zip->set_number('1630819')->is_valid_number, '東京都新宿区西新宿新宿NSビル(19階)');
ok($zip->set_number('1630820')->is_valid_number, '東京都新宿区西新宿新宿NSビル(20階)');
ok($zip->set_number('1630821')->is_valid_number, '東京都新宿区西新宿新宿NSビル(21階)');
ok($zip->set_number('1630822')->is_valid_number, '東京都新宿区西新宿新宿NSビル(22階)');
ok($zip->set_number('1630823')->is_valid_number, '東京都新宿区西新宿新宿NSビル(23階)');
ok($zip->set_number('1630824')->is_valid_number, '東京都新宿区西新宿新宿NSビル(24階)');
ok($zip->set_number('1630825')->is_valid_number, '東京都新宿区西新宿新宿NSビル(25階)');
ok($zip->set_number('1630826')->is_valid_number, '東京都新宿区西新宿新宿NSビル(26階)');
ok($zip->set_number('1630827')->is_valid_number, '東京都新宿区西新宿新宿NSビル(27階)');
ok($zip->set_number('1630828')->is_valid_number, '東京都新宿区西新宿新宿NSビル(28階)');
ok($zip->set_number('1630829')->is_valid_number, '東京都新宿区西新宿新宿NSビル(29階)');
ok($zip->set_number('1630830')->is_valid_number, '東京都新宿区西新宿新宿NSビル(30階)');
ok($zip->set_number('1630890')->is_valid_number, '東京都新宿区西新宿新宿NSビル(地階・階層不明)');
ok($zip->set_number('1630901')->is_valid_number, '東京都新宿区西新宿新宿モノリス(1階)');
ok($zip->set_number('1630902')->is_valid_number, '東京都新宿区西新宿新宿モノリス(2階)');
ok($zip->set_number('1630903')->is_valid_number, '東京都新宿区西新宿新宿モノリス(3階)');
ok($zip->set_number('1630904')->is_valid_number, '東京都新宿区西新宿新宿モノリス(4階)');
ok($zip->set_number('1630905')->is_valid_number, '東京都新宿区西新宿新宿モノリス(5階)');
ok($zip->set_number('1630906')->is_valid_number, '東京都新宿区西新宿新宿モノリス(6階)');
ok($zip->set_number('1630907')->is_valid_number, '東京都新宿区西新宿新宿モノリス(7階)');
ok($zip->set_number('1630908')->is_valid_number, '東京都新宿区西新宿新宿モノリス(8階)');
ok($zip->set_number('1630909')->is_valid_number, '東京都新宿区西新宿新宿モノリス(9階)');
ok($zip->set_number('1630910')->is_valid_number, '東京都新宿区西新宿新宿モノリス(10階)');
ok($zip->set_number('1630911')->is_valid_number, '東京都新宿区西新宿新宿モノリス(11階)');
ok($zip->set_number('1630912')->is_valid_number, '東京都新宿区西新宿新宿モノリス(12階)');
ok($zip->set_number('1630913')->is_valid_number, '東京都新宿区西新宿新宿モノリス(13階)');
ok($zip->set_number('1630914')->is_valid_number, '東京都新宿区西新宿新宿モノリス(14階)');
ok($zip->set_number('1630915')->is_valid_number, '東京都新宿区西新宿新宿モノリス(15階)');
ok($zip->set_number('1630916')->is_valid_number, '東京都新宿区西新宿新宿モノリス(16階)');
ok($zip->set_number('1630917')->is_valid_number, '東京都新宿区西新宿新宿モノリス(17階)');
ok($zip->set_number('1630918')->is_valid_number, '東京都新宿区西新宿新宿モノリス(18階)');
ok($zip->set_number('1630919')->is_valid_number, '東京都新宿区西新宿新宿モノリス(19階)');
ok($zip->set_number('1630920')->is_valid_number, '東京都新宿区西新宿新宿モノリス(20階)');
ok($zip->set_number('1630921')->is_valid_number, '東京都新宿区西新宿新宿モノリス(21階)');
ok($zip->set_number('1630922')->is_valid_number, '東京都新宿区西新宿新宿モノリス(22階)');
ok($zip->set_number('1630923')->is_valid_number, '東京都新宿区西新宿新宿モノリス(23階)');
ok($zip->set_number('1630924')->is_valid_number, '東京都新宿区西新宿新宿モノリス(24階)');
ok($zip->set_number('1630925')->is_valid_number, '東京都新宿区西新宿新宿モノリス(25階)');
ok($zip->set_number('1630926')->is_valid_number, '東京都新宿区西新宿新宿モノリス(26階)');
ok($zip->set_number('1630927')->is_valid_number, '東京都新宿区西新宿新宿モノリス(27階)');
ok($zip->set_number('1630928')->is_valid_number, '東京都新宿区西新宿新宿モノリス(28階)');
ok($zip->set_number('1630929')->is_valid_number, '東京都新宿区西新宿新宿モノリス(29階)');
ok($zip->set_number('1630930')->is_valid_number, '東京都新宿区西新宿新宿モノリス(30階)');
ok($zip->set_number('1630990')->is_valid_number, '東京都新宿区西新宿新宿モノリス(地階・階層不明)');
ok($zip->set_number('1631001')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(1階)');
ok($zip->set_number('1631002')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(2階)');
ok($zip->set_number('1631003')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(3階)');
ok($zip->set_number('1631004')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(4階)');
ok($zip->set_number('1631005')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(5階)');
ok($zip->set_number('1631006')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(6階)');
ok($zip->set_number('1631007')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(7階)');
ok($zip->set_number('1631008')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(8階)');
ok($zip->set_number('1631009')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(9階)');
ok($zip->set_number('1631010')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(10階)');
ok($zip->set_number('1631011')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(11階)');
ok($zip->set_number('1631012')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(12階)');
ok($zip->set_number('1631013')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(13階)');
ok($zip->set_number('1631014')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(14階)');
ok($zip->set_number('1631015')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(15階)');
ok($zip->set_number('1631016')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(16階)');
ok($zip->set_number('1631017')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(17階)');
ok($zip->set_number('1631018')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(18階)');
ok($zip->set_number('1631019')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(19階)');
ok($zip->set_number('1631020')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(20階)');
ok($zip->set_number('1631021')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(21階)');
ok($zip->set_number('1631022')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(22階)');
ok($zip->set_number('1631023')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(23階)');
ok($zip->set_number('1631024')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(24階)');
ok($zip->set_number('1631025')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(25階)');
ok($zip->set_number('1631026')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(26階)');
ok($zip->set_number('1631027')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(27階)');
ok($zip->set_number('1631028')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(28階)');
ok($zip->set_number('1631029')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(29階)');
ok($zip->set_number('1631030')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(30階)');
ok($zip->set_number('1631031')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(31階)');
ok($zip->set_number('1631032')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(32階)');
ok($zip->set_number('1631033')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(33階)');
ok($zip->set_number('1631034')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(34階)');
ok($zip->set_number('1631035')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(35階)');
ok($zip->set_number('1631036')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(36階)');
ok($zip->set_number('1631037')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(37階)');
ok($zip->set_number('1631038')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(38階)');
ok($zip->set_number('1631039')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(39階)');
ok($zip->set_number('1631040')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(40階)');
ok($zip->set_number('1631041')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(41階)');
ok($zip->set_number('1631042')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(42階)');
ok($zip->set_number('1631043')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(43階)');
ok($zip->set_number('1631044')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(44階)');
ok($zip->set_number('1631045')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(45階)');
ok($zip->set_number('1631046')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(46階)');
ok($zip->set_number('1631047')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(47階)');
ok($zip->set_number('1631048')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(48階)');
ok($zip->set_number('1631049')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(49階)');
ok($zip->set_number('1631050')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(50階)');
ok($zip->set_number('1631051')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(51階)');
ok($zip->set_number('1631052')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(52階)');
ok($zip->set_number('1631090')->is_valid_number, '東京都新宿区西新宿新宿パークタワー(地階・階層不明)');
ok($zip->set_number('1631101')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(1階)');
ok($zip->set_number('1631102')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(2階)');
ok($zip->set_number('1631103')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(3階)');
ok($zip->set_number('1631104')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(4階)');
ok($zip->set_number('1631105')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(5階)');
ok($zip->set_number('1631106')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(6階)');
ok($zip->set_number('1631107')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(7階)');
ok($zip->set_number('1631108')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(8階)');
ok($zip->set_number('1631109')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(9階)');
ok($zip->set_number('1631110')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(10階)');
ok($zip->set_number('1631111')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(11階)');
ok($zip->set_number('1631112')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(12階)');
ok($zip->set_number('1631113')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(13階)');
ok($zip->set_number('1631114')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(14階)');
ok($zip->set_number('1631115')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(15階)');
ok($zip->set_number('1631116')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(16階)');
ok($zip->set_number('1631117')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(17階)');
ok($zip->set_number('1631118')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(18階)');
ok($zip->set_number('1631119')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(19階)');
ok($zip->set_number('1631120')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(20階)');
ok($zip->set_number('1631121')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(21階)');
ok($zip->set_number('1631122')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(22階)');
ok($zip->set_number('1631123')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(23階)');
ok($zip->set_number('1631124')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(24階)');
ok($zip->set_number('1631125')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(25階)');
ok($zip->set_number('1631126')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(26階)');
ok($zip->set_number('1631127')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(27階)');
ok($zip->set_number('1631128')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(28階)');
ok($zip->set_number('1631129')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(29階)');
ok($zip->set_number('1631130')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(30階)');
ok($zip->set_number('1631190')->is_valid_number, '東京都新宿区西新宿新宿スクエアタワー(地階・階層不明)');
ok($zip->set_number('1631301')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(1階)');
ok($zip->set_number('1631302')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(2階)');
ok($zip->set_number('1631303')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(3階)');
ok($zip->set_number('1631304')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(4階)');
ok($zip->set_number('1631305')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(5階)');
ok($zip->set_number('1631306')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(6階)');
ok($zip->set_number('1631307')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(7階)');
ok($zip->set_number('1631308')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(8階)');
ok($zip->set_number('1631309')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(9階)');
ok($zip->set_number('1631310')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(10階)');
ok($zip->set_number('1631311')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(11階)');
ok($zip->set_number('1631312')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(12階)');
ok($zip->set_number('1631313')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(13階)');
ok($zip->set_number('1631314')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(14階)');
ok($zip->set_number('1631315')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(15階)');
ok($zip->set_number('1631316')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(16階)');
ok($zip->set_number('1631317')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(17階)');
ok($zip->set_number('1631318')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(18階)');
ok($zip->set_number('1631319')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(19階)');
ok($zip->set_number('1631320')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(20階)');
ok($zip->set_number('1631321')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(21階)');
ok($zip->set_number('1631322')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(22階)');
ok($zip->set_number('1631323')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(23階)');
ok($zip->set_number('1631324')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(24階)');
ok($zip->set_number('1631325')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(25階)');
ok($zip->set_number('1631326')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(26階)');
ok($zip->set_number('1631327')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(27階)');
ok($zip->set_number('1631328')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(28階)');
ok($zip->set_number('1631329')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(29階)');
ok($zip->set_number('1631330')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(30階)');
ok($zip->set_number('1631331')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(31階)');
ok($zip->set_number('1631332')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(32階)');
ok($zip->set_number('1631333')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(33階)');
ok($zip->set_number('1631334')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(34階)');
ok($zip->set_number('1631335')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(35階)');
ok($zip->set_number('1631336')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(36階)');
ok($zip->set_number('1631337')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(37階)');
ok($zip->set_number('1631338')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(38階)');
ok($zip->set_number('1631339')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(39階)');
ok($zip->set_number('1631340')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(40階)');
ok($zip->set_number('1631341')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(41階)');
ok($zip->set_number('1631342')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(42階)');
ok($zip->set_number('1631343')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(43階)');
ok($zip->set_number('1631344')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(44階)');
ok($zip->set_number('1631390')->is_valid_number, '東京都新宿区西新宿新宿アイランドタワー(地階・階層不明)');
ok($zip->set_number('1631401')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(1階)');
ok($zip->set_number('1631402')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(2階)');
ok($zip->set_number('1631403')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(3階)');
ok($zip->set_number('1631404')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(4階)');
ok($zip->set_number('1631405')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(5階)');
ok($zip->set_number('1631406')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(6階)');
ok($zip->set_number('1631407')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(7階)');
ok($zip->set_number('1631408')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(8階)');
ok($zip->set_number('1631409')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(9階)');
ok($zip->set_number('1631410')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(10階)');
ok($zip->set_number('1631411')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(11階)');
ok($zip->set_number('1631412')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(12階)');
ok($zip->set_number('1631413')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(13階)');
ok($zip->set_number('1631414')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(14階)');
ok($zip->set_number('1631415')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(15階)');
ok($zip->set_number('1631416')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(16階)');
ok($zip->set_number('1631417')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(17階)');
ok($zip->set_number('1631418')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(18階)');
ok($zip->set_number('1631419')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(19階)');
ok($zip->set_number('1631420')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(20階)');
ok($zip->set_number('1631421')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(21階)');
ok($zip->set_number('1631422')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(22階)');
ok($zip->set_number('1631423')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(23階)');
ok($zip->set_number('1631424')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(24階)');
ok($zip->set_number('1631425')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(25階)');
ok($zip->set_number('1631426')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(26階)');
ok($zip->set_number('1631427')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(27階)');
ok($zip->set_number('1631428')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(28階)');
ok($zip->set_number('1631429')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(29階)');
ok($zip->set_number('1631430')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(30階)');
ok($zip->set_number('1631431')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(31階)');
ok($zip->set_number('1631432')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(32階)');
ok($zip->set_number('1631433')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(33階)');
ok($zip->set_number('1631434')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(34階)');
ok($zip->set_number('1631435')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(35階)');
ok($zip->set_number('1631436')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(36階)');
ok($zip->set_number('1631437')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(37階)');
ok($zip->set_number('1631438')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(38階)');
ok($zip->set_number('1631439')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(39階)');
ok($zip->set_number('1631440')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(40階)');
ok($zip->set_number('1631441')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(41階)');
ok($zip->set_number('1631442')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(42階)');
ok($zip->set_number('1631443')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(43階)');
ok($zip->set_number('1631444')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(44階)');
ok($zip->set_number('1631445')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(45階)');
ok($zip->set_number('1631446')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(46階)');
ok($zip->set_number('1631447')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(47階)');
ok($zip->set_number('1631448')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(48階)');
ok($zip->set_number('1631449')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(49階)');
ok($zip->set_number('1631450')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(50階)');
ok($zip->set_number('1631451')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(51階)');
ok($zip->set_number('1631452')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(52階)');
ok($zip->set_number('1631453')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(53階)');
ok($zip->set_number('1631454')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(54階)');
ok($zip->set_number('1631490')->is_valid_number, '東京都新宿区西新宿東京オペラシティ(地階・階層不明)');
ok($zip->set_number('1631501')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(1階)');
ok($zip->set_number('1631502')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(2階)');
ok($zip->set_number('1631503')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(3階)');
ok($zip->set_number('1631504')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(4階)');
ok($zip->set_number('1631505')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(5階)');
ok($zip->set_number('1631506')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(6階)');
ok($zip->set_number('1631507')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(7階)');
ok($zip->set_number('1631508')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(8階)');
ok($zip->set_number('1631509')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(9階)');
ok($zip->set_number('1631510')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(10階)');
ok($zip->set_number('1631511')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(11階)');
ok($zip->set_number('1631512')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(12階)');
ok($zip->set_number('1631513')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(13階)');
ok($zip->set_number('1631514')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(14階)');
ok($zip->set_number('1631515')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(15階)');
ok($zip->set_number('1631516')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(16階)');
ok($zip->set_number('1631517')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(17階)');
ok($zip->set_number('1631518')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(18階)');
ok($zip->set_number('1631519')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(19階)');
ok($zip->set_number('1631520')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(20階)');
ok($zip->set_number('1631521')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(21階)');
ok($zip->set_number('1631522')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(22階)');
ok($zip->set_number('1631523')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(23階)');
ok($zip->set_number('1631524')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(24階)');
ok($zip->set_number('1631525')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(25階)');
ok($zip->set_number('1631526')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(26階)');
ok($zip->set_number('1631527')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(27階)');
ok($zip->set_number('1631528')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(28階)');
ok($zip->set_number('1631529')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(29階)');
ok($zip->set_number('1631530')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(30階)');
ok($zip->set_number('1631531')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(31階)');
ok($zip->set_number('1631590')->is_valid_number, '東京都新宿区西新宿新宿エルタワー(地階・階層不明)');
ok($zip->set_number('1636001')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(1階)');
ok($zip->set_number('1636002')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(2階)');
ok($zip->set_number('1636003')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(3階)');
ok($zip->set_number('1636004')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(4階)');
ok($zip->set_number('1636005')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(5階)');
ok($zip->set_number('1636006')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(6階)');
ok($zip->set_number('1636007')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(7階)');
ok($zip->set_number('1636008')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(8階)');
ok($zip->set_number('1636009')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(9階)');
ok($zip->set_number('1636010')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(10階)');
ok($zip->set_number('1636011')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(11階)');
ok($zip->set_number('1636012')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(12階)');
ok($zip->set_number('1636013')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(13階)');
ok($zip->set_number('1636014')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(14階)');
ok($zip->set_number('1636015')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(15階)');
ok($zip->set_number('1636016')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(16階)');
ok($zip->set_number('1636017')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(17階)');
ok($zip->set_number('1636018')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(18階)');
ok($zip->set_number('1636019')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(19階)');
ok($zip->set_number('1636020')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(20階)');
ok($zip->set_number('1636021')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(21階)');
ok($zip->set_number('1636022')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(22階)');
ok($zip->set_number('1636023')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(23階)');
ok($zip->set_number('1636024')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(24階)');
ok($zip->set_number('1636025')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(25階)');
ok($zip->set_number('1636026')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(26階)');
ok($zip->set_number('1636027')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(27階)');
ok($zip->set_number('1636028')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(28階)');
ok($zip->set_number('1636029')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(29階)');
ok($zip->set_number('1636030')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(30階)');
ok($zip->set_number('1636031')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(31階)');
ok($zip->set_number('1636032')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(32階)');
ok($zip->set_number('1636033')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(33階)');
ok($zip->set_number('1636034')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(34階)');
ok($zip->set_number('1636035')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(35階)');
ok($zip->set_number('1636036')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(36階)');
ok($zip->set_number('1636037')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(37階)');
ok($zip->set_number('1636038')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(38階)');
ok($zip->set_number('1636090')->is_valid_number, '東京都新宿区西新宿住友不動産新宿オークタワー(地階・階層不明)');
ok($zip->set_number('1640000')->is_valid_number, '東京都中野区以下に掲載がない場合');
ok($zip->set_number('1640001')->is_valid_number, '東京都中野区中野');
ok($zip->set_number('1640002')->is_valid_number, '東京都中野区上高田');
ok($zip->set_number('1640003')->is_valid_number, '東京都中野区東中野');
ok($zip->set_number('1640011')->is_valid_number, '東京都中野区中央');
ok($zip->set_number('1640012')->is_valid_number, '東京都中野区本町');
ok($zip->set_number('1640013')->is_valid_number, '東京都中野区弥生町');
ok($zip->set_number('1640014')->is_valid_number, '東京都中野区南台');
ok($zip->set_number('1650021')->is_valid_number, '東京都中野区丸山');
ok($zip->set_number('1650022')->is_valid_number, '東京都中野区江古田');
ok($zip->set_number('1650023')->is_valid_number, '東京都中野区江原町');
ok($zip->set_number('1650024')->is_valid_number, '東京都中野区松が丘');
ok($zip->set_number('1650025')->is_valid_number, '東京都中野区沼袋');
ok($zip->set_number('1650026')->is_valid_number, '東京都中野区新井');
ok($zip->set_number('1650027')->is_valid_number, '東京都中野区野方');
ok($zip->set_number('1650031')->is_valid_number, '東京都中野区上鷺宮');
ok($zip->set_number('1650032')->is_valid_number, '東京都中野区鷺宮');
ok($zip->set_number('1650033')->is_valid_number, '東京都中野区若宮');
ok($zip->set_number('1650034')->is_valid_number, '東京都中野区大和町');
ok($zip->set_number('1650035')->is_valid_number, '東京都中野区白鷺');
ok($zip->set_number('1660000')->is_valid_number, '東京都杉並区以下に掲載がない場合');
ok($zip->set_number('1660001')->is_valid_number, '東京都杉並区阿佐谷北');
ok($zip->set_number('1660002')->is_valid_number, '東京都杉並区高円寺北');
ok($zip->set_number('1660003')->is_valid_number, '東京都杉並区高円寺南');
ok($zip->set_number('1660004')->is_valid_number, '東京都杉並区阿佐谷南');
ok($zip->set_number('1660011')->is_valid_number, '東京都杉並区梅里');
ok($zip->set_number('1660012')->is_valid_number, '東京都杉並区和田');
ok($zip->set_number('1660013')->is_valid_number, '東京都杉並区堀ノ内');
ok($zip->set_number('1660014')->is_valid_number, '東京都杉並区松ノ木');
ok($zip->set_number('1660015')->is_valid_number, '東京都杉並区成田東');
ok($zip->set_number('1660016')->is_valid_number, '東京都杉並区成田西');
ok($zip->set_number('1670021')->is_valid_number, '東京都杉並区井草');
ok($zip->set_number('1670022')->is_valid_number, '東京都杉並区下井草');
ok($zip->set_number('1670023')->is_valid_number, '東京都杉並区上井草');
ok($zip->set_number('1670031')->is_valid_number, '東京都杉並区本天沼');
ok($zip->set_number('1670032')->is_valid_number, '東京都杉並区天沼');
ok($zip->set_number('1670033')->is_valid_number, '東京都杉並区清水');
ok($zip->set_number('1670034')->is_valid_number, '東京都杉並区桃井');
ok($zip->set_number('1670035')->is_valid_number, '東京都杉並区今川');
ok($zip->set_number('1670041')->is_valid_number, '東京都杉並区善福寺');
ok($zip->set_number('1670042')->is_valid_number, '東京都杉並区西荻北');
ok($zip->set_number('1670043')->is_valid_number, '東京都杉並区上荻');
ok($zip->set_number('1670051')->is_valid_number, '東京都杉並区荻窪');
ok($zip->set_number('1670052')->is_valid_number, '東京都杉並区南荻窪');
ok($zip->set_number('1670053')->is_valid_number, '東京都杉並区西荻南');
ok($zip->set_number('1670054')->is_valid_number, '東京都杉並区松庵');
ok($zip->set_number('1680061')->is_valid_number, '東京都杉並区大宮');
ok($zip->set_number('1680062')->is_valid_number, '東京都杉並区方南');
ok($zip->set_number('1680063')->is_valid_number, '東京都杉並区和泉');
ok($zip->set_number('1680064')->is_valid_number, '東京都杉並区永福');
ok($zip->set_number('1680065')->is_valid_number, '東京都杉並区浜田山');
ok($zip->set_number('1680071')->is_valid_number, '東京都杉並区高井戸西');
ok($zip->set_number('1680072')->is_valid_number, '東京都杉並区高井戸東');
ok($zip->set_number('1680073')->is_valid_number, '東京都杉並区下高井戸');
ok($zip->set_number('1680074')->is_valid_number, '東京都杉並区上高井戸');
ok($zip->set_number('1680081')->is_valid_number, '東京都杉並区宮前');
ok($zip->set_number('1680082')->is_valid_number, '東京都杉並区久我山');
ok($zip->set_number('1690051')->is_valid_number, '東京都新宿区西早稲田(その他)');
ok($zip->set_number('1690052')->is_valid_number, '東京都新宿区戸山(3丁目18・21番)');
ok($zip->set_number('1690071')->is_valid_number, '東京都新宿区戸塚町');
ok($zip->set_number('1690072')->is_valid_number, '東京都新宿区大久保');
ok($zip->set_number('1690073')->is_valid_number, '東京都新宿区百人町');
ok($zip->set_number('1690074')->is_valid_number, '東京都新宿区北新宿');
ok($zip->set_number('1690075')->is_valid_number, '東京都新宿区高田馬場');
ok($zip->set_number('1700000')->is_valid_number, '東京都豊島区以下に掲載がない場合');
ok($zip->set_number('1700001')->is_valid_number, '東京都豊島区西巣鴨');
ok($zip->set_number('1700002')->is_valid_number, '東京都豊島区巣鴨');
ok($zip->set_number('1700003')->is_valid_number, '東京都豊島区駒込');
ok($zip->set_number('1700004')->is_valid_number, '東京都豊島区北大塚');
ok($zip->set_number('1700005')->is_valid_number, '東京都豊島区南大塚');
ok($zip->set_number('1700011')->is_valid_number, '東京都豊島区池袋本町');
ok($zip->set_number('1700012')->is_valid_number, '東京都豊島区上池袋');
ok($zip->set_number('1700013')->is_valid_number, '東京都豊島区東池袋(次のビルを除く)');
ok($zip->set_number('1700014')->is_valid_number, '東京都豊島区池袋(1丁目)');
ok($zip->set_number('1706001')->is_valid_number, '東京都豊島区東池袋サンシャイン60(1階)');
ok($zip->set_number('1706002')->is_valid_number, '東京都豊島区東池袋サンシャイン60(2階)');
ok($zip->set_number('1706003')->is_valid_number, '東京都豊島区東池袋サンシャイン60(3階)');
ok($zip->set_number('1706004')->is_valid_number, '東京都豊島区東池袋サンシャイン60(4階)');
ok($zip->set_number('1706005')->is_valid_number, '東京都豊島区東池袋サンシャイン60(5階)');
ok($zip->set_number('1706006')->is_valid_number, '東京都豊島区東池袋サンシャイン60(6階)');
ok($zip->set_number('1706007')->is_valid_number, '東京都豊島区東池袋サンシャイン60(7階)');
ok($zip->set_number('1706008')->is_valid_number, '東京都豊島区東池袋サンシャイン60(8階)');
ok($zip->set_number('1706009')->is_valid_number, '東京都豊島区東池袋サンシャイン60(9階)');
ok($zip->set_number('1706010')->is_valid_number, '東京都豊島区東池袋サンシャイン60(10階)');
ok($zip->set_number('1706011')->is_valid_number, '東京都豊島区東池袋サンシャイン60(11階)');
ok($zip->set_number('1706012')->is_valid_number, '東京都豊島区東池袋サンシャイン60(12階)');
ok($zip->set_number('1706013')->is_valid_number, '東京都豊島区東池袋サンシャイン60(13階)');
ok($zip->set_number('1706014')->is_valid_number, '東京都豊島区東池袋サンシャイン60(14階)');
ok($zip->set_number('1706015')->is_valid_number, '東京都豊島区東池袋サンシャイン60(15階)');
ok($zip->set_number('1706016')->is_valid_number, '東京都豊島区東池袋サンシャイン60(16階)');
ok($zip->set_number('1706017')->is_valid_number, '東京都豊島区東池袋サンシャイン60(17階)');
ok($zip->set_number('1706018')->is_valid_number, '東京都豊島区東池袋サンシャイン60(18階)');
ok($zip->set_number('1706019')->is_valid_number, '東京都豊島区東池袋サンシャイン60(19階)');
ok($zip->set_number('1706020')->is_valid_number, '東京都豊島区東池袋サンシャイン60(20階)');
ok($zip->set_number('1706021')->is_valid_number, '東京都豊島区東池袋サンシャイン60(21階)');
ok($zip->set_number('1706022')->is_valid_number, '東京都豊島区東池袋サンシャイン60(22階)');
ok($zip->set_number('1706023')->is_valid_number, '東京都豊島区東池袋サンシャイン60(23階)');
ok($zip->set_number('1706024')->is_valid_number, '東京都豊島区東池袋サンシャイン60(24階)');
ok($zip->set_number('1706025')->is_valid_number, '東京都豊島区東池袋サンシャイン60(25階)');
ok($zip->set_number('1706026')->is_valid_number, '東京都豊島区東池袋サンシャイン60(26階)');
ok($zip->set_number('1706027')->is_valid_number, '東京都豊島区東池袋サンシャイン60(27階)');
ok($zip->set_number('1706028')->is_valid_number, '東京都豊島区東池袋サンシャイン60(28階)');
ok($zip->set_number('1706029')->is_valid_number, '東京都豊島区東池袋サンシャイン60(29階)');
ok($zip->set_number('1706030')->is_valid_number, '東京都豊島区東池袋サンシャイン60(30階)');
ok($zip->set_number('1706031')->is_valid_number, '東京都豊島区東池袋サンシャイン60(31階)');
ok($zip->set_number('1706032')->is_valid_number, '東京都豊島区東池袋サンシャイン60(32階)');
ok($zip->set_number('1706033')->is_valid_number, '東京都豊島区東池袋サンシャイン60(33階)');
ok($zip->set_number('1706034')->is_valid_number, '東京都豊島区東池袋サンシャイン60(34階)');
ok($zip->set_number('1706035')->is_valid_number, '東京都豊島区東池袋サンシャイン60(35階)');
ok($zip->set_number('1706036')->is_valid_number, '東京都豊島区東池袋サンシャイン60(36階)');
ok($zip->set_number('1706037')->is_valid_number, '東京都豊島区東池袋サンシャイン60(37階)');
ok($zip->set_number('1706038')->is_valid_number, '東京都豊島区東池袋サンシャイン60(38階)');
ok($zip->set_number('1706039')->is_valid_number, '東京都豊島区東池袋サンシャイン60(39階)');
ok($zip->set_number('1706040')->is_valid_number, '東京都豊島区東池袋サンシャイン60(40階)');
ok($zip->set_number('1706041')->is_valid_number, '東京都豊島区東池袋サンシャイン60(41階)');
ok($zip->set_number('1706042')->is_valid_number, '東京都豊島区東池袋サンシャイン60(42階)');
ok($zip->set_number('1706043')->is_valid_number, '東京都豊島区東池袋サンシャイン60(43階)');
ok($zip->set_number('1706044')->is_valid_number, '東京都豊島区東池袋サンシャイン60(44階)');
ok($zip->set_number('1706045')->is_valid_number, '東京都豊島区東池袋サンシャイン60(45階)');
ok($zip->set_number('1706046')->is_valid_number, '東京都豊島区東池袋サンシャイン60(46階)');
ok($zip->set_number('1706047')->is_valid_number, '東京都豊島区東池袋サンシャイン60(47階)');
ok($zip->set_number('1706048')->is_valid_number, '東京都豊島区東池袋サンシャイン60(48階)');
ok($zip->set_number('1706049')->is_valid_number, '東京都豊島区東池袋サンシャイン60(49階)');
ok($zip->set_number('1706050')->is_valid_number, '東京都豊島区東池袋サンシャイン60(50階)');
ok($zip->set_number('1706051')->is_valid_number, '東京都豊島区東池袋サンシャイン60(51階)');
ok($zip->set_number('1706052')->is_valid_number, '東京都豊島区東池袋サンシャイン60(52階)');
ok($zip->set_number('1706053')->is_valid_number, '東京都豊島区東池袋サンシャイン60(53階)');
ok($zip->set_number('1706054')->is_valid_number, '東京都豊島区東池袋サンシャイン60(54階)');
ok($zip->set_number('1706055')->is_valid_number, '東京都豊島区東池袋サンシャイン60(55階)');
ok($zip->set_number('1706056')->is_valid_number, '東京都豊島区東池袋サンシャイン60(56階)');
ok($zip->set_number('1706057')->is_valid_number, '東京都豊島区東池袋サンシャイン60(57階)');
ok($zip->set_number('1706058')->is_valid_number, '東京都豊島区東池袋サンシャイン60(58階)');
ok($zip->set_number('1706059')->is_valid_number, '東京都豊島区東池袋サンシャイン60(59階)');
ok($zip->set_number('1706060')->is_valid_number, '東京都豊島区東池袋サンシャイン60(60階)');
ok($zip->set_number('1706090')->is_valid_number, '東京都豊島区東池袋サンシャイン60(地階・階層不明)');
ok($zip->set_number('1710014')->is_valid_number, '東京都豊島区池袋(2~4丁目)');
ok($zip->set_number('1710021')->is_valid_number, '東京都豊島区西池袋');
ok($zip->set_number('1710022')->is_valid_number, '東京都豊島区南池袋');
ok($zip->set_number('1710031')->is_valid_number, '東京都豊島区目白');
ok($zip->set_number('1710032')->is_valid_number, '東京都豊島区雑司が谷');
ok($zip->set_number('1710033')->is_valid_number, '東京都豊島区高田');
ok($zip->set_number('1710041')->is_valid_number, '東京都豊島区千川');
ok($zip->set_number('1710042')->is_valid_number, '東京都豊島区高松');
ok($zip->set_number('1710043')->is_valid_number, '東京都豊島区要町');
ok($zip->set_number('1710044')->is_valid_number, '東京都豊島区千早');
ok($zip->set_number('1710051')->is_valid_number, '東京都豊島区長崎');
ok($zip->set_number('1710052')->is_valid_number, '東京都豊島区南長崎');
ok($zip->set_number('1730001')->is_valid_number, '東京都板橋区本町');
ok($zip->set_number('1730002')->is_valid_number, '東京都板橋区稲荷台');
ok($zip->set_number('1730003')->is_valid_number, '東京都板橋区加賀');
ok($zip->set_number('1730004')->is_valid_number, '東京都板橋区板橋');
ok($zip->set_number('1730005')->is_valid_number, '東京都板橋区仲宿');
ok($zip->set_number('1730011')->is_valid_number, '東京都板橋区双葉町');
ok($zip->set_number('1730012')->is_valid_number, '東京都板橋区大和町');
ok($zip->set_number('1730013')->is_valid_number, '東京都板橋区氷川町');
ok($zip->set_number('1730014')->is_valid_number, '東京都板橋区大山東町');
ok($zip->set_number('1730015')->is_valid_number, '東京都板橋区栄町');
ok($zip->set_number('1730016')->is_valid_number, '東京都板橋区中板橋');
ok($zip->set_number('1730021')->is_valid_number, '東京都板橋区弥生町');
ok($zip->set_number('1730022')->is_valid_number, '東京都板橋区仲町');
ok($zip->set_number('1730023')->is_valid_number, '東京都板橋区大山町');
ok($zip->set_number('1730024')->is_valid_number, '東京都板橋区大山金井町');
ok($zip->set_number('1730025')->is_valid_number, '東京都板橋区熊野町');
ok($zip->set_number('1730026')->is_valid_number, '東京都板橋区中丸町');
ok($zip->set_number('1730027')->is_valid_number, '東京都板橋区南町');
ok($zip->set_number('1730031')->is_valid_number, '東京都板橋区大谷口北町');
ok($zip->set_number('1730032')->is_valid_number, '東京都板橋区大谷口上町');
ok($zip->set_number('1730033')->is_valid_number, '東京都板橋区大山西町');
ok($zip->set_number('1730034')->is_valid_number, '東京都板橋区幸町');
ok($zip->set_number('1730035')->is_valid_number, '東京都板橋区大谷口');
ok($zip->set_number('1730036')->is_valid_number, '東京都板橋区向原');
ok($zip->set_number('1730037')->is_valid_number, '東京都板橋区小茂根');
ok($zip->set_number('1740000')->is_valid_number, '東京都板橋区以下に掲載がない場合');
ok($zip->set_number('1740041')->is_valid_number, '東京都板橋区舟渡');
ok($zip->set_number('1740042')->is_valid_number, '東京都板橋区東坂下');
ok($zip->set_number('1740043')->is_valid_number, '東京都板橋区坂下');
ok($zip->set_number('1740044')->is_valid_number, '東京都板橋区相生町');
ok($zip->set_number('1740045')->is_valid_number, '東京都板橋区西台(1丁目)');
ok($zip->set_number('1740046')->is_valid_number, '東京都板橋区蓮根');
ok($zip->set_number('1740051')->is_valid_number, '東京都板橋区小豆沢');
ok($zip->set_number('1740052')->is_valid_number, '東京都板橋区蓮沼町');
ok($zip->set_number('1740053')->is_valid_number, '東京都板橋区清水町');
ok($zip->set_number('1740054')->is_valid_number, '東京都板橋区宮本町');
ok($zip->set_number('1740055')->is_valid_number, '東京都板橋区泉町');
ok($zip->set_number('1740056')->is_valid_number, '東京都板橋区志村');
ok($zip->set_number('1740061')->is_valid_number, '東京都板橋区大原町');
ok($zip->set_number('1740062')->is_valid_number, '東京都板橋区富士見町');
ok($zip->set_number('1740063')->is_valid_number, '東京都板橋区前野町');
ok($zip->set_number('1740064')->is_valid_number, '東京都板橋区中台');
ok($zip->set_number('1740065')->is_valid_number, '東京都板橋区若木');
ok($zip->set_number('1740071')->is_valid_number, '東京都板橋区常盤台');
ok($zip->set_number('1740072')->is_valid_number, '東京都板橋区南常盤台');
ok($zip->set_number('1740073')->is_valid_number, '東京都板橋区東山町');
ok($zip->set_number('1740074')->is_valid_number, '東京都板橋区東新町');
ok($zip->set_number('1740075')->is_valid_number, '東京都板橋区桜川');
ok($zip->set_number('1740076')->is_valid_number, '東京都板橋区上板橋');
ok($zip->set_number('1750045')->is_valid_number, '東京都板橋区西台(2~4丁目)');
ok($zip->set_number('1750081')->is_valid_number, '東京都板橋区新河岸');
ok($zip->set_number('1750082')->is_valid_number, '東京都板橋区高島平');
ok($zip->set_number('1750083')->is_valid_number, '東京都板橋区徳丸');
ok($zip->set_number('1750084')->is_valid_number, '東京都板橋区四葉');
ok($zip->set_number('1750085')->is_valid_number, '東京都板橋区大門');
ok($zip->set_number('1750091')->is_valid_number, '東京都板橋区三園');
ok($zip->set_number('1750092')->is_valid_number, '東京都板橋区赤塚');
ok($zip->set_number('1750093')->is_valid_number, '東京都板橋区赤塚新町');
ok($zip->set_number('1750094')->is_valid_number, '東京都板橋区成増');
ok($zip->set_number('1760000')->is_valid_number, '東京都練馬区以下に掲載がない場合');
ok($zip->set_number('1760001')->is_valid_number, '東京都練馬区練馬');
ok($zip->set_number('1760002')->is_valid_number, '東京都練馬区桜台');
ok($zip->set_number('1760003')->is_valid_number, '東京都練馬区羽沢');
ok($zip->set_number('1760004')->is_valid_number, '東京都練馬区小竹町');
ok($zip->set_number('1760005')->is_valid_number, '東京都練馬区旭丘');
ok($zip->set_number('1760006')->is_valid_number, '東京都練馬区栄町');
ok($zip->set_number('1760011')->is_valid_number, '東京都練馬区豊玉上');
ok($zip->set_number('1760012')->is_valid_number, '東京都練馬区豊玉北');
ok($zip->set_number('1760013')->is_valid_number, '東京都練馬区豊玉中');
ok($zip->set_number('1760014')->is_valid_number, '東京都練馬区豊玉南');
ok($zip->set_number('1760021')->is_valid_number, '東京都練馬区貫井');
ok($zip->set_number('1760022')->is_valid_number, '東京都練馬区向山');
ok($zip->set_number('1760023')->is_valid_number, '東京都練馬区中村北');
ok($zip->set_number('1760024')->is_valid_number, '東京都練馬区中村');
ok($zip->set_number('1760025')->is_valid_number, '東京都練馬区中村南');
ok($zip->set_number('1770031')->is_valid_number, '東京都練馬区三原台');
ok($zip->set_number('1770032')->is_valid_number, '東京都練馬区谷原');
ok($zip->set_number('1770033')->is_valid_number, '東京都練馬区高野台');
ok($zip->set_number('1770034')->is_valid_number, '東京都練馬区富士見台');
ok($zip->set_number('1770035')->is_valid_number, '東京都練馬区南田中');
ok($zip->set_number('1770041')->is_valid_number, '東京都練馬区石神井町');
ok($zip->set_number('1770042')->is_valid_number, '東京都練馬区下石神井');
ok($zip->set_number('1770043')->is_valid_number, '東京都練馬区上石神井南町');
ok($zip->set_number('1770044')->is_valid_number, '東京都練馬区上石神井');
ok($zip->set_number('1770045')->is_valid_number, '東京都練馬区石神井台');
ok($zip->set_number('1770051')->is_valid_number, '東京都練馬区関町北');
ok($zip->set_number('1770052')->is_valid_number, '東京都練馬区関町東');
ok($zip->set_number('1770053')->is_valid_number, '東京都練馬区関町南');
ok($zip->set_number('1770054')->is_valid_number, '東京都練馬区立野町');
ok($zip->set_number('1780061')->is_valid_number, '東京都練馬区大泉学園町');
ok($zip->set_number('1780062')->is_valid_number, '東京都練馬区大泉町');
ok($zip->set_number('1780063')->is_valid_number, '東京都練馬区東大泉');
ok($zip->set_number('1780064')->is_valid_number, '東京都練馬区南大泉');
ok($zip->set_number('1780065')->is_valid_number, '東京都練馬区西大泉');
ok($zip->set_number('1780066')->is_valid_number, '東京都練馬区西大泉町');
ok($zip->set_number('1790071')->is_valid_number, '東京都練馬区旭町');
ok($zip->set_number('1790072')->is_valid_number, '東京都練馬区光が丘');
ok($zip->set_number('1790073')->is_valid_number, '東京都練馬区田柄');
ok($zip->set_number('1790074')->is_valid_number, '東京都練馬区春日町');
ok($zip->set_number('1790075')->is_valid_number, '東京都練馬区高松');
ok($zip->set_number('1790076')->is_valid_number, '東京都練馬区土支田');
ok($zip->set_number('1790081')->is_valid_number, '東京都練馬区北町');
ok($zip->set_number('1790082')->is_valid_number, '東京都練馬区錦');
ok($zip->set_number('1790083')->is_valid_number, '東京都練馬区平和台');
ok($zip->set_number('1790084')->is_valid_number, '東京都練馬区氷川台');
ok($zip->set_number('1790085')->is_valid_number, '東京都練馬区早宮');
ok($zip->set_number('1800000')->is_valid_number, '東京都武蔵野市以下に掲載がない場合');
ok($zip->set_number('1800001')->is_valid_number, '東京都武蔵野市吉祥寺北町');
ok($zip->set_number('1800002')->is_valid_number, '東京都武蔵野市吉祥寺東町');
ok($zip->set_number('1800003')->is_valid_number, '東京都武蔵野市吉祥寺南町');
ok($zip->set_number('1800004')->is_valid_number, '東京都武蔵野市吉祥寺本町');
ok($zip->set_number('1800005')->is_valid_number, '東京都武蔵野市御殿山');
ok($zip->set_number('1800006')->is_valid_number, '東京都武蔵野市中町');
ok($zip->set_number('1800011')->is_valid_number, '東京都武蔵野市八幡町');
ok($zip->set_number('1800012')->is_valid_number, '東京都武蔵野市緑町');
ok($zip->set_number('1800013')->is_valid_number, '東京都武蔵野市西久保');
ok($zip->set_number('1800014')->is_valid_number, '東京都武蔵野市関前');
ok($zip->set_number('1800021')->is_valid_number, '東京都武蔵野市桜堤');
ok($zip->set_number('1800022')->is_valid_number, '東京都武蔵野市境');
ok($zip->set_number('1800023')->is_valid_number, '東京都武蔵野市境南町');
ok($zip->set_number('1810000')->is_valid_number, '東京都三鷹市以下に掲載がない場合');
ok($zip->set_number('1810001')->is_valid_number, '東京都三鷹市井の頭');
ok($zip->set_number('1810002')->is_valid_number, '東京都三鷹市牟礼');
ok($zip->set_number('1810003')->is_valid_number, '東京都三鷹市北野');
ok($zip->set_number('1810004')->is_valid_number, '東京都三鷹市新川');
ok($zip->set_number('1810005')->is_valid_number, '東京都三鷹市中原');
ok($zip->set_number('1810011')->is_valid_number, '東京都三鷹市井口');
ok($zip->set_number('1810012')->is_valid_number, '東京都三鷹市上連雀');
ok($zip->set_number('1810013')->is_valid_number, '東京都三鷹市下連雀');
ok($zip->set_number('1810014')->is_valid_number, '東京都三鷹市野崎');
ok($zip->set_number('1810015')->is_valid_number, '東京都三鷹市大沢');
ok($zip->set_number('1810016')->is_valid_number, '東京都三鷹市深大寺');
ok($zip->set_number('1820000')->is_valid_number, '東京都調布市以下に掲載がない場合');
ok($zip->set_number('1820001')->is_valid_number, '東京都調布市緑ケ丘');
ok($zip->set_number('1820002')->is_valid_number, '東京都調布市仙川町');
ok($zip->set_number('1820003')->is_valid_number, '東京都調布市若葉町');
ok($zip->set_number('1820004')->is_valid_number, '東京都調布市入間町');
ok($zip->set_number('1820005')->is_valid_number, '東京都調布市東つつじケ丘');
ok($zip->set_number('1820006')->is_valid_number, '東京都調布市西つつじケ丘');
ok($zip->set_number('1820007')->is_valid_number, '東京都調布市菊野台');
ok($zip->set_number('1820011')->is_valid_number, '東京都調布市深大寺北町');
ok($zip->set_number('1820012')->is_valid_number, '東京都調布市深大寺東町');
ok($zip->set_number('1820013')->is_valid_number, '東京都調布市深大寺南町');
ok($zip->set_number('1820014')->is_valid_number, '東京都調布市柴崎');
ok($zip->set_number('1820015')->is_valid_number, '東京都調布市八雲台');
ok($zip->set_number('1820016')->is_valid_number, '東京都調布市佐須町');
ok($zip->set_number('1820017')->is_valid_number, '東京都調布市深大寺元町');
ok($zip->set_number('1820021')->is_valid_number, '東京都調布市調布ケ丘');
ok($zip->set_number('1820022')->is_valid_number, '東京都調布市国領町');
ok($zip->set_number('1820023')->is_valid_number, '東京都調布市染地');
ok($zip->set_number('1820024')->is_valid_number, '東京都調布市布田');
ok($zip->set_number('1820025')->is_valid_number, '東京都調布市多摩川');
ok($zip->set_number('1820026')->is_valid_number, '東京都調布市小島町');
ok($zip->set_number('1820031')->is_valid_number, '東京都調布市野水');
ok($zip->set_number('1820032')->is_valid_number, '東京都調布市西町');
ok($zip->set_number('1820033')->is_valid_number, '東京都調布市富士見町');
ok($zip->set_number('1820034')->is_valid_number, '東京都調布市下石原');
ok($zip->set_number('1820035')->is_valid_number, '東京都調布市上石原');
ok($zip->set_number('1820036')->is_valid_number, '東京都調布市飛田給');
ok($zip->set_number('1830000')->is_valid_number, '東京都府中市以下に掲載がない場合');
ok($zip->set_number('1830001')->is_valid_number, '東京都府中市浅間町');
ok($zip->set_number('1830002')->is_valid_number, '東京都府中市多磨町');
ok($zip->set_number('1830003')->is_valid_number, '東京都府中市朝日町');
ok($zip->set_number('1830004')->is_valid_number, '東京都府中市紅葉丘');
ok($zip->set_number('1830005')->is_valid_number, '東京都府中市若松町');
ok($zip->set_number('1830006')->is_valid_number, '東京都府中市緑町');
ok($zip->set_number('1830011')->is_valid_number, '東京都府中市白糸台');
ok($zip->set_number('1830012')->is_valid_number, '東京都府中市押立町');
ok($zip->set_number('1830013')->is_valid_number, '東京都府中市小柳町');
ok($zip->set_number('1830014')->is_valid_number, '東京都府中市是政');
ok($zip->set_number('1830015')->is_valid_number, '東京都府中市清水が丘');
ok($zip->set_number('1830016')->is_valid_number, '東京都府中市八幡町');
ok($zip->set_number('1830021')->is_valid_number, '東京都府中市片町');
ok($zip->set_number('1830022')->is_valid_number, '東京都府中市宮西町');
ok($zip->set_number('1830023')->is_valid_number, '東京都府中市宮町');
ok($zip->set_number('1830024')->is_valid_number, '東京都府中市日吉町');
ok($zip->set_number('1830025')->is_valid_number, '東京都府中市矢崎町');
ok($zip->set_number('1830026')->is_valid_number, '東京都府中市南町');
ok($zip->set_number('1830027')->is_valid_number, '東京都府中市本町');
ok($zip->set_number('1830031')->is_valid_number, '東京都府中市西府町');
ok($zip->set_number('1830032')->is_valid_number, '東京都府中市本宿町');
ok($zip->set_number('1830033')->is_valid_number, '東京都府中市分梅町');
ok($zip->set_number('1830034')->is_valid_number, '東京都府中市住吉町');
ok($zip->set_number('1830035')->is_valid_number, '東京都府中市四谷');
ok($zip->set_number('1830036')->is_valid_number, '東京都府中市日新町');
ok($zip->set_number('1830041')->is_valid_number, '東京都府中市北山町');
ok($zip->set_number('1830042')->is_valid_number, '東京都府中市武蔵台');
ok($zip->set_number('1830043')->is_valid_number, '東京都府中市東芝町');
ok($zip->set_number('1830044')->is_valid_number, '東京都府中市日鋼町');
ok($zip->set_number('1830045')->is_valid_number, '東京都府中市美好町');
ok($zip->set_number('1830046')->is_valid_number, '東京都府中市西原町');
ok($zip->set_number('1830051')->is_valid_number, '東京都府中市栄町');
ok($zip->set_number('1830052')->is_valid_number, '東京都府中市新町');
ok($zip->set_number('1830053')->is_valid_number, '東京都府中市天神町');
ok($zip->set_number('1830054')->is_valid_number, '東京都府中市幸町');
ok($zip->set_number('1830055')->is_valid_number, '東京都府中市府中町');
ok($zip->set_number('1830056')->is_valid_number, '東京都府中市寿町');
ok($zip->set_number('1830057')->is_valid_number, '東京都府中市晴見町');
ok($zip->set_number('1840000')->is_valid_number, '東京都小金井市以下に掲載がない場合');
ok($zip->set_number('1840001')->is_valid_number, '東京都小金井市関野町');
ok($zip->set_number('1840002')->is_valid_number, '東京都小金井市梶野町');
ok($zip->set_number('1840003')->is_valid_number, '東京都小金井市緑町');
ok($zip->set_number('1840004')->is_valid_number, '東京都小金井市本町');
ok($zip->set_number('1840005')->is_valid_number, '東京都小金井市桜町');
ok($zip->set_number('1840011')->is_valid_number, '東京都小金井市東町');
ok($zip->set_number('1840012')->is_valid_number, '東京都小金井市中町');
ok($zip->set_number('1840013')->is_valid_number, '東京都小金井市前原町');
ok($zip->set_number('1840014')->is_valid_number, '東京都小金井市貫井南町');
ok($zip->set_number('1840015')->is_valid_number, '東京都小金井市貫井北町');
ok($zip->set_number('1850000')->is_valid_number, '東京都国分寺市以下に掲載がない場合');
ok($zip->set_number('1850001')->is_valid_number, '東京都国分寺市北町');
ok($zip->set_number('1850002')->is_valid_number, '東京都国分寺市東戸倉');
ok($zip->set_number('1850003')->is_valid_number, '東京都国分寺市戸倉');
ok($zip->set_number('1850004')->is_valid_number, '東京都国分寺市新町');
ok($zip->set_number('1850005')->is_valid_number, '東京都国分寺市並木町');
ok($zip->set_number('1850011')->is_valid_number, '東京都国分寺市本多');
ok($zip->set_number('1850012')->is_valid_number, '東京都国分寺市本町');
ok($zip->set_number('1850013')->is_valid_number, '東京都国分寺市西恋ケ窪');
ok($zip->set_number('1850014')->is_valid_number, '東京都国分寺市東恋ケ窪');
ok($zip->set_number('1850021')->is_valid_number, '東京都国分寺市南町');
ok($zip->set_number('1850022')->is_valid_number, '東京都国分寺市東元町');
ok($zip->set_number('1850023')->is_valid_number, '東京都国分寺市西元町');
ok($zip->set_number('1850024')->is_valid_number, '東京都国分寺市泉町');
ok($zip->set_number('1850031')->is_valid_number, '東京都国分寺市富士本');
ok($zip->set_number('1850032')->is_valid_number, '東京都国分寺市日吉町');
ok($zip->set_number('1850033')->is_valid_number, '東京都国分寺市内藤');
ok($zip->set_number('1850034')->is_valid_number, '東京都国分寺市光町');
ok($zip->set_number('1850035')->is_valid_number, '東京都国分寺市西町');
ok($zip->set_number('1850036')->is_valid_number, '東京都国分寺市高木町');
ok($zip->set_number('1860000')->is_valid_number, '東京都国立市以下に掲載がない場合');
ok($zip->set_number('1860001')->is_valid_number, '東京都国立市北');
ok($zip->set_number('1860002')->is_valid_number, '東京都国立市東');
ok($zip->set_number('1860003')->is_valid_number, '東京都国立市富士見台');
ok($zip->set_number('1860004')->is_valid_number, '東京都国立市中');
ok($zip->set_number('1860005')->is_valid_number, '東京都国立市西');
ok($zip->set_number('1860011')->is_valid_number, '東京都国立市谷保');
ok($zip->set_number('1860012')->is_valid_number, '東京都国立市泉');
ok($zip->set_number('1860013')->is_valid_number, '東京都国立市青柳');
ok($zip->set_number('1860014')->is_valid_number, '東京都国立市石田');
ok($zip->set_number('1860015')->is_valid_number, '東京都国立市矢川');
ok($zip->set_number('1870000')->is_valid_number, '東京都小平市以下に掲載がない場合');
ok($zip->set_number('1870001')->is_valid_number, '東京都小平市大沼町');
ok($zip->set_number('1870002')->is_valid_number, '東京都小平市花小金井');
ok($zip->set_number('1870003')->is_valid_number, '東京都小平市花小金井南町');
ok($zip->set_number('1870004')->is_valid_number, '東京都小平市天神町');
ok($zip->set_number('1870011')->is_valid_number, '東京都小平市鈴木町');
ok($zip->set_number('1870012')->is_valid_number, '東京都小平市御幸町');
ok($zip->set_number('1870013')->is_valid_number, '東京都小平市回田町');
ok($zip->set_number('1870021')->is_valid_number, '東京都小平市上水南町');
ok($zip->set_number('1870022')->is_valid_number, '東京都小平市上水本町');
ok($zip->set_number('1870023')->is_valid_number, '東京都小平市上水新町');
ok($zip->set_number('1870024')->is_valid_number, '東京都小平市たかの台');
ok($zip->set_number('1870025')->is_valid_number, '東京都小平市津田町');
ok($zip->set_number('1870031')->is_valid_number, '東京都小平市小川東町');
ok($zip->set_number('1870032')->is_valid_number, '東京都小平市小川町');
ok($zip->set_number('1870033')->is_valid_number, '東京都小平市中島町');
ok($zip->set_number('1870034')->is_valid_number, '東京都小平市栄町');
ok($zip->set_number('1870035')->is_valid_number, '東京都小平市小川西町');
ok($zip->set_number('1870041')->is_valid_number, '東京都小平市美園町');
ok($zip->set_number('1870042')->is_valid_number, '東京都小平市仲町');
ok($zip->set_number('1870043')->is_valid_number, '東京都小平市学園東町');
ok($zip->set_number('1870044')->is_valid_number, '東京都小平市喜平町');
ok($zip->set_number('1870045')->is_valid_number, '東京都小平市学園西町');
ok($zip->set_number('1880001')->is_valid_number, '東京都西東京市谷戸町');
ok($zip->set_number('1880002')->is_valid_number, '東京都西東京市緑町');
ok($zip->set_number('1880003')->is_valid_number, '東京都西東京市北原町');
ok($zip->set_number('1880004')->is_valid_number, '東京都西東京市西原町');
ok($zip->set_number('1880011')->is_valid_number, '東京都西東京市田無町');
ok($zip->set_number('1880012')->is_valid_number, '東京都西東京市南町');
ok($zip->set_number('1880013')->is_valid_number, '東京都西東京市向台町');
ok($zip->set_number('1880014')->is_valid_number, '東京都西東京市芝久保町');
ok($zip->set_number('1890000')->is_valid_number, '東京都東村山市以下に掲載がない場合');
ok($zip->set_number('1890001')->is_valid_number, '東京都東村山市秋津町');
ok($zip->set_number('1890002')->is_valid_number, '東京都東村山市青葉町');
ok($zip->set_number('1890003')->is_valid_number, '東京都東村山市久米川町');
ok($zip->set_number('1890011')->is_valid_number, '東京都東村山市恩多町');
ok($zip->set_number('1890012')->is_valid_number, '東京都東村山市萩山町');
ok($zip->set_number('1890013')->is_valid_number, '東京都東村山市栄町');
ok($zip->set_number('1890014')->is_valid_number, '東京都東村山市本町');
ok($zip->set_number('1890021')->is_valid_number, '東京都東村山市諏訪町');
ok($zip->set_number('1890022')->is_valid_number, '東京都東村山市野口町');
ok($zip->set_number('1890023')->is_valid_number, '東京都東村山市美住町');
ok($zip->set_number('1890024')->is_valid_number, '東京都東村山市富士見町');
ok($zip->set_number('1890025')->is_valid_number, '東京都東村山市廻田町');
ok($zip->set_number('1890026')->is_valid_number, '東京都東村山市多摩湖町');
ok($zip->set_number('1900000')->is_valid_number, '東京都立川市以下に掲載がない場合');
ok($zip->set_number('1900001')->is_valid_number, '東京都立川市若葉町');
ok($zip->set_number('1900002')->is_valid_number, '東京都立川市幸町');
ok($zip->set_number('1900003')->is_valid_number, '東京都立川市栄町');
ok($zip->set_number('1900004')->is_valid_number, '東京都立川市柏町');
ok($zip->set_number('1900011')->is_valid_number, '東京都立川市高松町');
ok($zip->set_number('1900012')->is_valid_number, '東京都立川市曙町');
ok($zip->set_number('1900013')->is_valid_number, '東京都立川市富士見町');
ok($zip->set_number('1900014')->is_valid_number, '東京都立川市緑町');
ok($zip->set_number('1900015')->is_valid_number, '東京都立川市泉町');
ok($zip->set_number('1900021')->is_valid_number, '東京都立川市羽衣町');
ok($zip->set_number('1900022')->is_valid_number, '東京都立川市錦町');
ok($zip->set_number('1900023')->is_valid_number, '東京都立川市柴崎町');
ok($zip->set_number('1900031')->is_valid_number, '東京都立川市砂川町');
ok($zip->set_number('1900032')->is_valid_number, '東京都立川市上砂町');
ok($zip->set_number('1900033')->is_valid_number, '東京都立川市一番町');
ok($zip->set_number('1900034')->is_valid_number, '東京都立川市西砂町');
ok($zip->set_number('1900100')->is_valid_number, '東京都あきる野市以下に掲載がない場合');
ok($zip->set_number('1900100')->is_valid_number, '東京都西多摩郡日の出町以下に掲載がない場合');
ok($zip->set_number('1900141')->is_valid_number, '東京都あきる野市横沢');
ok($zip->set_number('1900142')->is_valid_number, '東京都あきる野市伊奈');
ok($zip->set_number('1900143')->is_valid_number, '東京都あきる野市上ノ台');
ok($zip->set_number('1900144')->is_valid_number, '東京都あきる野市山田');
ok($zip->set_number('1900151')->is_valid_number, '東京都あきる野市小和田');
ok($zip->set_number('1900152')->is_valid_number, '東京都あきる野市留原');
ok($zip->set_number('1900153')->is_valid_number, '東京都あきる野市小峰台');
ok($zip->set_number('1900154')->is_valid_number, '東京都あきる野市高尾');
ok($zip->set_number('1900155')->is_valid_number, '東京都あきる野市網代');
ok($zip->set_number('1900161')->is_valid_number, '東京都あきる野市入野');
ok($zip->set_number('1900162')->is_valid_number, '東京都あきる野市三内');
ok($zip->set_number('1900163')->is_valid_number, '東京都あきる野市舘谷');
ok($zip->set_number('1900164')->is_valid_number, '東京都あきる野市五日市');
ok($zip->set_number('1900165')->is_valid_number, '東京都あきる野市小中野');
ok($zip->set_number('1900166')->is_valid_number, '東京都あきる野市舘谷台');
ok($zip->set_number('1900171')->is_valid_number, '東京都あきる野市養沢');
ok($zip->set_number('1900172')->is_valid_number, '東京都あきる野市深沢');
ok($zip->set_number('1900173')->is_valid_number, '東京都あきる野市戸倉');
ok($zip->set_number('1900174')->is_valid_number, '東京都あきる野市乙津');
ok($zip->set_number('1900181')->is_valid_number, '東京都西多摩郡日の出町大久野');
ok($zip->set_number('1900182')->is_valid_number, '東京都西多摩郡日の出町平井');
ok($zip->set_number('1900200')->is_valid_number, '東京都西多摩郡檜原村以下に掲載がない場合');
ok($zip->set_number('1900201')->is_valid_number, '東京都西多摩郡檜原村倉掛');
ok($zip->set_number('1900202')->is_valid_number, '東京都西多摩郡檜原村藤原');
ok($zip->set_number('1900203')->is_valid_number, '東京都西多摩郡檜原村神戸');
ok($zip->set_number('1900204')->is_valid_number, '東京都西多摩郡檜原村小沢');
ok($zip->set_number('1900205')->is_valid_number, '東京都西多摩郡檜原村樋里');
ok($zip->set_number('1900211')->is_valid_number, '東京都西多摩郡檜原村三都郷');
ok($zip->set_number('1900212')->is_valid_number, '東京都西多摩郡檜原村上元郷');
ok($zip->set_number('1900213')->is_valid_number, '東京都西多摩郡檜原村下元郷');
ok($zip->set_number('1900214')->is_valid_number, '東京都西多摩郡檜原村本宿');
ok($zip->set_number('1900221')->is_valid_number, '東京都西多摩郡檜原村数馬');
ok($zip->set_number('1900222')->is_valid_number, '東京都西多摩郡檜原村人里');
ok($zip->set_number('1900223')->is_valid_number, '東京都西多摩郡檜原村南郷');
ok($zip->set_number('1901200')->is_valid_number, '東京都西多摩郡瑞穂町以下に掲載がない場合');
ok($zip->set_number('1901201')->is_valid_number, '東京都西多摩郡瑞穂町二本木');
ok($zip->set_number('1901202')->is_valid_number, '東京都西多摩郡瑞穂町駒形富士山');
ok($zip->set_number('1901203')->is_valid_number, '東京都西多摩郡瑞穂町高根');
ok($zip->set_number('1901204')->is_valid_number, '東京都西多摩郡瑞穂町富士山栗原新田');
ok($zip->set_number('1901211')->is_valid_number, '東京都西多摩郡瑞穂町石畑');
ok($zip->set_number('1901212')->is_valid_number, '東京都西多摩郡瑞穂町殿ケ谷');
ok($zip->set_number('1901213')->is_valid_number, '東京都西多摩郡瑞穂町武蔵');
ok($zip->set_number('1901214')->is_valid_number, '東京都西多摩郡瑞穂町むさし野');
ok($zip->set_number('1901221')->is_valid_number, '東京都西多摩郡瑞穂町箱根ケ崎');
ok($zip->set_number('1901222')->is_valid_number, '東京都西多摩郡瑞穂町箱根ケ崎東松原');
ok($zip->set_number('1901223')->is_valid_number, '東京都西多摩郡瑞穂町箱根ケ崎西松原');
ok($zip->set_number('1901224')->is_valid_number, '東京都西多摩郡瑞穂町南平');
ok($zip->set_number('1901231')->is_valid_number, '東京都西多摩郡瑞穂町長岡長谷部');
ok($zip->set_number('1901232')->is_valid_number, '東京都西多摩郡瑞穂町長岡');
ok($zip->set_number('1901233')->is_valid_number, '東京都西多摩郡瑞穂町長岡下師岡');
ok($zip->set_number('1901234')->is_valid_number, '東京都西多摩郡瑞穂町長岡藤橋');
ok($zip->set_number('1910000')->is_valid_number, '東京都日野市以下に掲載がない場合');
ok($zip->set_number('1910001')->is_valid_number, '東京都日野市栄町');
ok($zip->set_number('1910002')->is_valid_number, '東京都日野市新町');
ok($zip->set_number('1910003')->is_valid_number, '東京都日野市日野台');
ok($zip->set_number('1910011')->is_valid_number, '東京都日野市日野本町');
ok($zip->set_number('1910012')->is_valid_number, '東京都日野市日野');
ok($zip->set_number('1910013')->is_valid_number, '東京都日野市宮');
ok($zip->set_number('1910014')->is_valid_number, '東京都日野市上田');
ok($zip->set_number('1910015')->is_valid_number, '東京都日野市川辺堀之内');
ok($zip->set_number('1910016')->is_valid_number, '東京都日野市神明');
ok($zip->set_number('1910021')->is_valid_number, '東京都日野市石田');
ok($zip->set_number('1910022')->is_valid_number, '東京都日野市新井');
ok($zip->set_number('1910023')->is_valid_number, '東京都日野市下田');
ok($zip->set_number('1910024')->is_valid_number, '東京都日野市万願寺');
ok($zip->set_number('1910031')->is_valid_number, '東京都日野市高幡');
ok($zip->set_number('1910032')->is_valid_number, '東京都日野市三沢');
ok($zip->set_number('1910033')->is_valid_number, '東京都日野市百草');
ok($zip->set_number('1910034')->is_valid_number, '東京都日野市落川');
ok($zip->set_number('1910041')->is_valid_number, '東京都日野市南平');
ok($zip->set_number('1910042')->is_valid_number, '東京都日野市程久保');
ok($zip->set_number('1910043')->is_valid_number, '東京都日野市平山');
ok($zip->set_number('1910051')->is_valid_number, '東京都日野市豊田(大字)');
ok($zip->set_number('1910052')->is_valid_number, '東京都日野市東豊田');
ok($zip->set_number('1910053')->is_valid_number, '東京都日野市豊田(丁目)');
ok($zip->set_number('1910054')->is_valid_number, '東京都日野市東平山');
ok($zip->set_number('1910055')->is_valid_number, '東京都日野市西平山');
ok($zip->set_number('1910061')->is_valid_number, '東京都日野市大坂上');
ok($zip->set_number('1910062')->is_valid_number, '東京都日野市多摩平');
ok($zip->set_number('1910063')->is_valid_number, '東京都日野市さくら町');
ok($zip->set_number('1910064')->is_valid_number, '東京都日野市富士町');
ok($zip->set_number('1910065')->is_valid_number, '東京都日野市旭が丘');
ok($zip->set_number('1920000')->is_valid_number, '東京都八王子市以下に掲載がない場合');
ok($zip->set_number('1920001')->is_valid_number, '東京都八王子市戸吹町');
ok($zip->set_number('1920002')->is_valid_number, '東京都八王子市高月町');
ok($zip->set_number('1920003')->is_valid_number, '東京都八王子市丹木町');
ok($zip->set_number('1920004')->is_valid_number, '東京都八王子市加住町');
ok($zip->set_number('1920005')->is_valid_number, '東京都八王子市宮下町');
ok($zip->set_number('1920011')->is_valid_number, '東京都八王子市滝山町');
ok($zip->set_number('1920012')->is_valid_number, '東京都八王子市左入町');
ok($zip->set_number('1920013')->is_valid_number, '東京都八王子市梅坪町');
ok($zip->set_number('1920014')->is_valid_number, '東京都八王子市みつい台');
ok($zip->set_number('1920015')->is_valid_number, '東京都八王子市中野町');
ok($zip->set_number('1920016')->is_valid_number, '東京都八王子市谷野町');
ok($zip->set_number('1920021')->is_valid_number, '東京都八王子市丸山町');
ok($zip->set_number('1920022')->is_valid_number, '東京都八王子市平町');
ok($zip->set_number('1920023')->is_valid_number, '東京都八王子市久保山町');
ok($zip->set_number('1920024')->is_valid_number, '東京都八王子市宇津木町');
ok($zip->set_number('1920025')->is_valid_number, '東京都八王子市尾崎町');
ok($zip->set_number('1920031')->is_valid_number, '東京都八王子市小宮町');
ok($zip->set_number('1920032')->is_valid_number, '東京都八王子市石川町');
ok($zip->set_number('1920033')->is_valid_number, '東京都八王子市高倉町');
ok($zip->set_number('1920034')->is_valid_number, '東京都八王子市大谷町');
ok($zip->set_number('1920041')->is_valid_number, '東京都八王子市中野上町');
ok($zip->set_number('1920042')->is_valid_number, '東京都八王子市中野山王');
ok($zip->set_number('1920043')->is_valid_number, '東京都八王子市暁町');
ok($zip->set_number('1920044')->is_valid_number, '東京都八王子市富士見町');
ok($zip->set_number('1920045')->is_valid_number, '東京都八王子市大和田町');
ok($zip->set_number('1920046')->is_valid_number, '東京都八王子市明神町');
ok($zip->set_number('1920051')->is_valid_number, '東京都八王子市元本郷町');
ok($zip->set_number('1920052')->is_valid_number, '東京都八王子市本郷町');
ok($zip->set_number('1920053')->is_valid_number, '東京都八王子市八幡町');
ok($zip->set_number('1920054')->is_valid_number, '東京都八王子市小門町');
ok($zip->set_number('1920055')->is_valid_number, '東京都八王子市八木町');
ok($zip->set_number('1920056')->is_valid_number, '東京都八王子市追分町');
ok($zip->set_number('1920061')->is_valid_number, '東京都八王子市平岡町');
ok($zip->set_number('1920062')->is_valid_number, '東京都八王子市大横町');
ok($zip->set_number('1920063')->is_valid_number, '東京都八王子市元横山町');
ok($zip->set_number('1920064')->is_valid_number, '東京都八王子市田町');
ok($zip->set_number('1920065')->is_valid_number, '東京都八王子市新町');
ok($zip->set_number('1920066')->is_valid_number, '東京都八王子市本町');
ok($zip->set_number('1920071')->is_valid_number, '東京都八王子市八日町');
ok($zip->set_number('1920072')->is_valid_number, '東京都八王子市南町');
ok($zip->set_number('1920073')->is_valid_number, '東京都八王子市寺町');
ok($zip->set_number('1920074')->is_valid_number, '東京都八王子市天神町');
ok($zip->set_number('1920075')->is_valid_number, '東京都八王子市南新町');
ok($zip->set_number('1920081')->is_valid_number, '東京都八王子市横山町');
ok($zip->set_number('1920082')->is_valid_number, '東京都八王子市東町');
ok($zip->set_number('1920083')->is_valid_number, '東京都八王子市旭町');
ok($zip->set_number('1920084')->is_valid_number, '東京都八王子市三崎町');
ok($zip->set_number('1920085')->is_valid_number, '東京都八王子市中町');
ok($zip->set_number('1920151')->is_valid_number, '東京都八王子市上川町');
ok($zip->set_number('1920152')->is_valid_number, '東京都八王子市美山町');
ok($zip->set_number('1920153')->is_valid_number, '東京都八王子市西寺方町');
ok($zip->set_number('1920154')->is_valid_number, '東京都八王子市下恩方町');
ok($zip->set_number('1920155')->is_valid_number, '東京都八王子市小津町');
ok($zip->set_number('1920156')->is_valid_number, '東京都八王子市上恩方町');
ok($zip->set_number('1920351')->is_valid_number, '東京都八王子市東中野');
ok($zip->set_number('1920352')->is_valid_number, '東京都八王子市大塚');
ok($zip->set_number('1920353')->is_valid_number, '東京都八王子市鹿島');
ok($zip->set_number('1920354')->is_valid_number, '東京都八王子市松が谷');
ok($zip->set_number('1920355')->is_valid_number, '東京都八王子市堀之内');
ok($zip->set_number('1920361')->is_valid_number, '東京都八王子市越野');
ok($zip->set_number('1920362')->is_valid_number, '東京都八王子市松木');
ok($zip->set_number('1920363')->is_valid_number, '東京都八王子市別所');
ok($zip->set_number('1920364')->is_valid_number, '東京都八王子市南大沢');
ok($zip->set_number('1920371')->is_valid_number, '東京都八王子市南陽台');
ok($zip->set_number('1920372')->is_valid_number, '東京都八王子市下柚木');
ok($zip->set_number('1920373')->is_valid_number, '東京都八王子市上柚木');
ok($zip->set_number('1920374')->is_valid_number, '東京都八王子市中山');
ok($zip->set_number('1920375')->is_valid_number, '東京都八王子市鑓水');
ok($zip->set_number('1920902')->is_valid_number, '東京都八王子市上野町');
ok($zip->set_number('1920903')->is_valid_number, '東京都八王子市万町');
ok($zip->set_number('1920904')->is_valid_number, '東京都八王子市子安町');
ok($zip->set_number('1920906')->is_valid_number, '東京都八王子市北野町');
ok($zip->set_number('1920907')->is_valid_number, '東京都八王子市長沼町');
ok($zip->set_number('1920911')->is_valid_number, '東京都八王子市打越町');
ok($zip->set_number('1920912')->is_valid_number, '東京都八王子市絹ケ丘');
ok($zip->set_number('1920913')->is_valid_number, '東京都八王子市北野台');
ok($zip->set_number('1920914')->is_valid_number, '東京都八王子市片倉町');
ok($zip->set_number('1920915')->is_valid_number, '東京都八王子市宇津貫町');
ok($zip->set_number('1920916')->is_valid_number, '東京都八王子市みなみ野');
ok($zip->set_number('1920917')->is_valid_number, '東京都八王子市西片倉');
ok($zip->set_number('1920918')->is_valid_number, '東京都八王子市兵衛');
ok($zip->set_number('1920919')->is_valid_number, '東京都八王子市七国');
ok($zip->set_number('1930801')->is_valid_number, '東京都八王子市川口町');
ok($zip->set_number('1930802')->is_valid_number, '東京都八王子市犬目町');
ok($zip->set_number('1930803')->is_valid_number, '東京都八王子市楢原町');
ok($zip->set_number('1930804')->is_valid_number, '東京都八王子市清川町');
ok($zip->set_number('1930811')->is_valid_number, '東京都八王子市上壱分方町');
ok($zip->set_number('1930812')->is_valid_number, '東京都八王子市諏訪町');
ok($zip->set_number('1930813')->is_valid_number, '東京都八王子市四谷町');
ok($zip->set_number('1930814')->is_valid_number, '東京都八王子市泉町');
ok($zip->set_number('1930815')->is_valid_number, '東京都八王子市叶谷町');
ok($zip->set_number('1930816')->is_valid_number, '東京都八王子市大楽寺町');
ok($zip->set_number('1930821')->is_valid_number, '東京都八王子市川町');
ok($zip->set_number('1930822')->is_valid_number, '東京都八王子市弐分方町');
ok($zip->set_number('1930823')->is_valid_number, '東京都八王子市横川町');
ok($zip->set_number('1930824')->is_valid_number, '東京都八王子市長房町');
ok($zip->set_number('1930825')->is_valid_number, '東京都八王子市城山手');
ok($zip->set_number('1930826')->is_valid_number, '東京都八王子市元八王子町');
ok($zip->set_number('1930831')->is_valid_number, '東京都八王子市並木町');
ok($zip->set_number('1930832')->is_valid_number, '東京都八王子市散田町');
ok($zip->set_number('1930833')->is_valid_number, '東京都八王子市めじろ台');
ok($zip->set_number('1930834')->is_valid_number, '東京都八王子市東浅川町');
ok($zip->set_number('1930835')->is_valid_number, '東京都八王子市千人町');
ok($zip->set_number('1930836')->is_valid_number, '東京都八王子市日吉町');
ok($zip->set_number('1930841')->is_valid_number, '東京都八王子市裏高尾町');
ok($zip->set_number('1930842')->is_valid_number, '東京都八王子市西浅川町');
ok($zip->set_number('1930843')->is_valid_number, '東京都八王子市廿里町');
ok($zip->set_number('1930844')->is_valid_number, '東京都八王子市高尾町');
ok($zip->set_number('1930845')->is_valid_number, '東京都八王子市初沢町');
ok($zip->set_number('1930846')->is_valid_number, '東京都八王子市南浅川町');
ok($zip->set_number('1930931')->is_valid_number, '東京都八王子市台町');
ok($zip->set_number('1930932')->is_valid_number, '東京都八王子市緑町');
ok($zip->set_number('1930933')->is_valid_number, '東京都八王子市山田町');
ok($zip->set_number('1930934')->is_valid_number, '東京都八王子市小比企町');
ok($zip->set_number('1930935')->is_valid_number, '東京都八王子市大船町');
ok($zip->set_number('1930941')->is_valid_number, '東京都八王子市狭間町');
ok($zip->set_number('1930942')->is_valid_number, '東京都八王子市椚田町');
ok($zip->set_number('1930943')->is_valid_number, '東京都八王子市寺田町');
ok($zip->set_number('1930944')->is_valid_number, '東京都八王子市館町');
ok($zip->set_number('1940000')->is_valid_number, '東京都町田市以下に掲載がない場合');
ok($zip->set_number('1940001')->is_valid_number, '東京都町田市つくし野');
ok($zip->set_number('1940002')->is_valid_number, '東京都町田市南つくし野');
ok($zip->set_number('1940003')->is_valid_number, '東京都町田市小川');
ok($zip->set_number('1940004')->is_valid_number, '東京都町田市鶴間');
ok($zip->set_number('1940005')->is_valid_number, '東京都町田市南町田');
ok($zip->set_number('1940011')->is_valid_number, '東京都町田市成瀬が丘');
ok($zip->set_number('1940012')->is_valid_number, '東京都町田市金森');
ok($zip->set_number('1940013')->is_valid_number, '東京都町田市原町田');
ok($zip->set_number('1940014')->is_valid_number, '東京都町田市高ヶ坂');
ok($zip->set_number('1940015')->is_valid_number, '東京都町田市金森東');
ok($zip->set_number('1940021')->is_valid_number, '東京都町田市中町');
ok($zip->set_number('1940022')->is_valid_number, '東京都町田市森野');
ok($zip->set_number('1940023')->is_valid_number, '東京都町田市旭町');
ok($zip->set_number('1940031')->is_valid_number, '東京都町田市南大谷');
ok($zip->set_number('1940032')->is_valid_number, '東京都町田市本町田');
ok($zip->set_number('1940033')->is_valid_number, '東京都町田市木曽町');
ok($zip->set_number('1940034')->is_valid_number, '東京都町田市根岸町');
ok($zip->set_number('1940035')->is_valid_number, '東京都町田市忠生');
ok($zip->set_number('1940036')->is_valid_number, '東京都町田市木曽東');
ok($zip->set_number('1940037')->is_valid_number, '東京都町田市木曽西');
ok($zip->set_number('1940038')->is_valid_number, '東京都町田市根岸');
ok($zip->set_number('1940039')->is_valid_number, '東京都町田市藤の台(1、2丁目)');
ok($zip->set_number('1940041')->is_valid_number, '東京都町田市玉川学園');
ok($zip->set_number('1940042')->is_valid_number, '東京都町田市東玉川学園');
ok($zip->set_number('1940043')->is_valid_number, '東京都町田市成瀬台');
ok($zip->set_number('1940044')->is_valid_number, '東京都町田市成瀬');
ok($zip->set_number('1940045')->is_valid_number, '東京都町田市南成瀬');
ok($zip->set_number('1940046')->is_valid_number, '東京都町田市西成瀬');
ok($zip->set_number('1940201')->is_valid_number, '東京都町田市上小山田町');
ok($zip->set_number('1940202')->is_valid_number, '東京都町田市下小山田町');
ok($zip->set_number('1940203')->is_valid_number, '東京都町田市図師町');
ok($zip->set_number('1940204')->is_valid_number, '東京都町田市小山田桜台');
ok($zip->set_number('1940211')->is_valid_number, '東京都町田市相原町');
ok($zip->set_number('1940212')->is_valid_number, '東京都町田市小山町');
ok($zip->set_number('1940213')->is_valid_number, '東京都町田市常盤町');
ok($zip->set_number('1940214')->is_valid_number, '東京都町田市矢部町');
ok($zip->set_number('1940215')->is_valid_number, '東京都町田市小山ヶ丘');
ok($zip->set_number('1950039')->is_valid_number, '東京都町田市藤の台(3丁目)');
ok($zip->set_number('1950051')->is_valid_number, '東京都町田市真光寺町');
ok($zip->set_number('1950052')->is_valid_number, '東京都町田市広袴町');
ok($zip->set_number('1950053')->is_valid_number, '東京都町田市能ヶ谷');
ok($zip->set_number('1950054')->is_valid_number, '東京都町田市三輪町');
ok($zip->set_number('1950055')->is_valid_number, '東京都町田市三輪緑山');
ok($zip->set_number('1950056')->is_valid_number, '東京都町田市広袴');
ok($zip->set_number('1950057')->is_valid_number, '東京都町田市真光寺');
ok($zip->set_number('1950061')->is_valid_number, '東京都町田市鶴川');
ok($zip->set_number('1950062')->is_valid_number, '東京都町田市大蔵町');
ok($zip->set_number('1950063')->is_valid_number, '東京都町田市野津田町');
ok($zip->set_number('1950064')->is_valid_number, '東京都町田市小野路町');
ok($zip->set_number('1950071')->is_valid_number, '東京都町田市金井町');
ok($zip->set_number('1950072')->is_valid_number, '東京都町田市金井');
ok($zip->set_number('1950073')->is_valid_number, '東京都町田市薬師台');
ok($zip->set_number('1950074')->is_valid_number, '東京都町田市山崎町');
ok($zip->set_number('1950075')->is_valid_number, '東京都町田市山崎');
ok($zip->set_number('1950076')->is_valid_number, '東京都町田市金井ヶ丘');
ok($zip->set_number('1960000')->is_valid_number, '東京都昭島市以下に掲載がない場合');
ok($zip->set_number('1960001')->is_valid_number, '東京都昭島市美堀町');
ok($zip->set_number('1960002')->is_valid_number, '東京都昭島市拝島町');
ok($zip->set_number('1960003')->is_valid_number, '東京都昭島市松原町');
ok($zip->set_number('1960004')->is_valid_number, '東京都昭島市緑町');
ok($zip->set_number('1960011')->is_valid_number, '東京都昭島市上川原町');
ok($zip->set_number('1960012')->is_valid_number, '東京都昭島市つつじが丘');
ok($zip->set_number('1960013')->is_valid_number, '東京都昭島市大神町');
ok($zip->set_number('1960014')->is_valid_number, '東京都昭島市田中町');
ok($zip->set_number('1960015')->is_valid_number, '東京都昭島市昭和町');
ok($zip->set_number('1960021')->is_valid_number, '東京都昭島市武蔵野');
ok($zip->set_number('1960022')->is_valid_number, '東京都昭島市中神町');
ok($zip->set_number('1960023')->is_valid_number, '東京都昭島市築地町');
ok($zip->set_number('1960024')->is_valid_number, '東京都昭島市宮沢町');
ok($zip->set_number('1960025')->is_valid_number, '東京都昭島市朝日町');
ok($zip->set_number('1960031')->is_valid_number, '東京都昭島市福島町');
ok($zip->set_number('1960032')->is_valid_number, '東京都昭島市郷地町');
ok($zip->set_number('1960033')->is_valid_number, '東京都昭島市東町');
ok($zip->set_number('1960034')->is_valid_number, '東京都昭島市玉川町');
ok($zip->set_number('1960035')->is_valid_number, '東京都昭島市もくせいの杜');
ok($zip->set_number('1970000')->is_valid_number, '東京都福生市以下に掲載がない場合');
ok($zip->set_number('1970001')->is_valid_number, '東京都福生市横田基地内');
ok($zip->set_number('1970002')->is_valid_number, '東京都福生市熊川二宮');
ok($zip->set_number('1970003')->is_valid_number, '東京都福生市熊川');
ok($zip->set_number('1970004')->is_valid_number, '東京都福生市南田園');
ok($zip->set_number('1970005')->is_valid_number, '東京都福生市北田園');
ok($zip->set_number('1970011')->is_valid_number, '東京都福生市福生');
ok($zip->set_number('1970012')->is_valid_number, '東京都福生市加美平');
ok($zip->set_number('1970013')->is_valid_number, '東京都福生市武蔵野台');
ok($zip->set_number('1970014')->is_valid_number, '東京都福生市福生二宮');
ok($zip->set_number('1970021')->is_valid_number, '東京都福生市東町');
ok($zip->set_number('1970022')->is_valid_number, '東京都福生市本町');
ok($zip->set_number('1970023')->is_valid_number, '東京都福生市志茂');
ok($zip->set_number('1970024')->is_valid_number, '東京都福生市牛浜');
ok($zip->set_number('1970801')->is_valid_number, '東京都あきる野市菅生');
ok($zip->set_number('1970802')->is_valid_number, '東京都あきる野市草花');
ok($zip->set_number('1970803')->is_valid_number, '東京都あきる野市瀬戸岡');
ok($zip->set_number('1970804')->is_valid_number, '東京都あきる野市秋川');
ok($zip->set_number('1970811')->is_valid_number, '東京都あきる野市原小宮');
ok($zip->set_number('1970812')->is_valid_number, '東京都あきる野市平沢');
ok($zip->set_number('1970813')->is_valid_number, '東京都あきる野市平沢東');
ok($zip->set_number('1970814')->is_valid_number, '東京都あきる野市二宮');
ok($zip->set_number('1970815')->is_valid_number, '東京都あきる野市二宮東');
ok($zip->set_number('1970816')->is_valid_number, '東京都あきる野市平沢西');
ok($zip->set_number('1970821')->is_valid_number, '東京都あきる野市小川');
ok($zip->set_number('1970822')->is_valid_number, '東京都あきる野市小川東');
ok($zip->set_number('1970823')->is_valid_number, '東京都あきる野市野辺');
ok($zip->set_number('1970824')->is_valid_number, '東京都あきる野市切欠');
ok($zip->set_number('1970825')->is_valid_number, '東京都あきる野市雨間');
ok($zip->set_number('1970826')->is_valid_number, '東京都あきる野市牛沼');
ok($zip->set_number('1970827')->is_valid_number, '東京都あきる野市油平');
ok($zip->set_number('1970828')->is_valid_number, '東京都あきる野市秋留');
ok($zip->set_number('1970831')->is_valid_number, '東京都あきる野市下代継');
ok($zip->set_number('1970832')->is_valid_number, '東京都あきる野市上代継');
ok($zip->set_number('1970833')->is_valid_number, '東京都あきる野市渕上');
ok($zip->set_number('1970834')->is_valid_number, '東京都あきる野市引田');
ok($zip->set_number('1980000')->is_valid_number, '東京都青梅市以下に掲載がない場合');
ok($zip->set_number('1980000')->is_valid_number, '東京都西多摩郡奥多摩町以下に掲載がない場合');
ok($zip->set_number('1980001')->is_valid_number, '東京都青梅市成木');
ok($zip->set_number('1980002')->is_valid_number, '東京都青梅市富岡');
ok($zip->set_number('1980003')->is_valid_number, '東京都青梅市小曾木');
ok($zip->set_number('1980004')->is_valid_number, '東京都青梅市根ケ布');
ok($zip->set_number('1980005')->is_valid_number, '東京都青梅市黒沢');
ok($zip->set_number('1980011')->is_valid_number, '東京都青梅市塩船');
ok($zip->set_number('1980012')->is_valid_number, '東京都青梅市谷野');
ok($zip->set_number('1980013')->is_valid_number, '東京都青梅市木野下');
ok($zip->set_number('1980014')->is_valid_number, '東京都青梅市大門');
ok($zip->set_number('1980015')->is_valid_number, '東京都青梅市吹上');
ok($zip->set_number('1980021')->is_valid_number, '東京都青梅市今寺');
ok($zip->set_number('1980022')->is_valid_number, '東京都青梅市藤橋');
ok($zip->set_number('1980023')->is_valid_number, '東京都青梅市今井');
ok($zip->set_number('1980024')->is_valid_number, '東京都青梅市新町');
ok($zip->set_number('1980025')->is_valid_number, '東京都青梅市末広町');
ok($zip->set_number('1980031')->is_valid_number, '東京都青梅市師岡町');
ok($zip->set_number('1980032')->is_valid_number, '東京都青梅市野上町');
ok($zip->set_number('1980036')->is_valid_number, '東京都青梅市河辺町');
ok($zip->set_number('1980041')->is_valid_number, '東京都青梅市勝沼');
ok($zip->set_number('1980042')->is_valid_number, '東京都青梅市東青梅');
ok($zip->set_number('1980043')->is_valid_number, '東京都青梅市千ケ瀬町');
ok($zip->set_number('1980044')->is_valid_number, '東京都青梅市西分町');
ok($zip->set_number('1980046')->is_valid_number, '東京都青梅市日向和田');
ok($zip->set_number('1980051')->is_valid_number, '東京都青梅市友田町');
ok($zip->set_number('1980052')->is_valid_number, '東京都青梅市長淵');
ok($zip->set_number('1980053')->is_valid_number, '東京都青梅市駒木町');
ok($zip->set_number('1980061')->is_valid_number, '東京都青梅市畑中');
ok($zip->set_number('1980062')->is_valid_number, '東京都青梅市和田町');
ok($zip->set_number('1980063')->is_valid_number, '東京都青梅市梅郷');
ok($zip->set_number('1980064')->is_valid_number, '東京都青梅市柚木町');
ok($zip->set_number('1980081')->is_valid_number, '東京都青梅市上町');
ok($zip->set_number('1980082')->is_valid_number, '東京都青梅市仲町');
ok($zip->set_number('1980083')->is_valid_number, '東京都青梅市本町');
ok($zip->set_number('1980084')->is_valid_number, '東京都青梅市住江町');
ok($zip->set_number('1980085')->is_valid_number, '東京都青梅市滝ノ上町');
ok($zip->set_number('1980086')->is_valid_number, '東京都青梅市大柳町');
ok($zip->set_number('1980087')->is_valid_number, '東京都青梅市天ケ瀬町');
ok($zip->set_number('1980088')->is_valid_number, '東京都青梅市裏宿町');
ok($zip->set_number('1980089')->is_valid_number, '東京都青梅市森下町');
ok($zip->set_number('1980101')->is_valid_number, '東京都西多摩郡奥多摩町大丹波');
ok($zip->set_number('1980102')->is_valid_number, '東京都西多摩郡奥多摩町川井');
ok($zip->set_number('1980103')->is_valid_number, '東京都西多摩郡奥多摩町梅沢');
ok($zip->set_number('1980104')->is_valid_number, '東京都西多摩郡奥多摩町丹三郎');
ok($zip->set_number('1980105')->is_valid_number, '東京都西多摩郡奥多摩町小丹波');
ok($zip->set_number('1980106')->is_valid_number, '東京都西多摩郡奥多摩町棚沢');
ok($zip->set_number('1980107')->is_valid_number, '東京都西多摩郡奥多摩町白丸');
ok($zip->set_number('1980171')->is_valid_number, '東京都青梅市二俣尾');
ok($zip->set_number('1980172')->is_valid_number, '東京都青梅市沢井');
ok($zip->set_number('1980173')->is_valid_number, '東京都青梅市御岳本町');
ok($zip->set_number('1980174')->is_valid_number, '東京都青梅市御岳');
ok($zip->set_number('1980175')->is_valid_number, '東京都青梅市御岳山');
ok($zip->set_number('1980211')->is_valid_number, '東京都西多摩郡奥多摩町日原');
ok($zip->set_number('1980212')->is_valid_number, '東京都西多摩郡奥多摩町氷川');
ok($zip->set_number('1980213')->is_valid_number, '東京都西多摩郡奥多摩町海沢');
ok($zip->set_number('1980221')->is_valid_number, '東京都西多摩郡奥多摩町留浦');
ok($zip->set_number('1980222')->is_valid_number, '東京都西多摩郡奥多摩町境');
ok($zip->set_number('1980223')->is_valid_number, '東京都西多摩郡奥多摩町原');
ok($zip->set_number('1980224')->is_valid_number, '東京都西多摩郡奥多摩町河内');
ok($zip->set_number('1980225')->is_valid_number, '東京都西多摩郡奥多摩町川野');
ok($zip->set_number('2010000')->is_valid_number, '東京都狛江市以下に掲載がない場合');
ok($zip->set_number('2010001')->is_valid_number, '東京都狛江市西野川');
ok($zip->set_number('2010002')->is_valid_number, '東京都狛江市東野川');
ok($zip->set_number('2010003')->is_valid_number, '東京都狛江市和泉本町');
ok($zip->set_number('2010004')->is_valid_number, '東京都狛江市岩戸北');
ok($zip->set_number('2010005')->is_valid_number, '東京都狛江市岩戸南');
ok($zip->set_number('2010011')->is_valid_number, '東京都狛江市西和泉');
ok($zip->set_number('2010012')->is_valid_number, '東京都狛江市中和泉');
ok($zip->set_number('2010013')->is_valid_number, '東京都狛江市元和泉');
ok($zip->set_number('2010014')->is_valid_number, '東京都狛江市東和泉');
ok($zip->set_number('2010015')->is_valid_number, '東京都狛江市猪方');
ok($zip->set_number('2010016')->is_valid_number, '東京都狛江市駒井町');
ok($zip->set_number('2020000')->is_valid_number, '東京都西東京市以下に掲載がない場合');
ok($zip->set_number('2020001')->is_valid_number, '東京都西東京市ひばりが丘');
ok($zip->set_number('2020002')->is_valid_number, '東京都西東京市ひばりが丘北');
ok($zip->set_number('2020003')->is_valid_number, '東京都西東京市北町');
ok($zip->set_number('2020004')->is_valid_number, '東京都西東京市下保谷');
ok($zip->set_number('2020005')->is_valid_number, '東京都西東京市住吉町');
ok($zip->set_number('2020006')->is_valid_number, '東京都西東京市栄町');
ok($zip->set_number('2020011')->is_valid_number, '東京都西東京市泉町');
ok($zip->set_number('2020012')->is_valid_number, '東京都西東京市東町');
ok($zip->set_number('2020013')->is_valid_number, '東京都西東京市中町');
ok($zip->set_number('2020014')->is_valid_number, '東京都西東京市富士町');
ok($zip->set_number('2020015')->is_valid_number, '東京都西東京市保谷町');
ok($zip->set_number('2020021')->is_valid_number, '東京都西東京市東伏見');
ok($zip->set_number('2020022')->is_valid_number, '東京都西東京市柳沢');
ok($zip->set_number('2020023')->is_valid_number, '東京都西東京市新町');
ok($zip->set_number('2030000')->is_valid_number, '東京都東久留米市以下に掲載がない場合');
ok($zip->set_number('2030001')->is_valid_number, '東京都東久留米市上の原');
ok($zip->set_number('2030002')->is_valid_number, '東京都東久留米市神宝町');
ok($zip->set_number('2030003')->is_valid_number, '東京都東久留米市金山町');
ok($zip->set_number('2030004')->is_valid_number, '東京都東久留米市氷川台');
ok($zip->set_number('2030011')->is_valid_number, '東京都東久留米市大門町');
ok($zip->set_number('2030012')->is_valid_number, '東京都東久留米市浅間町');
ok($zip->set_number('2030013')->is_valid_number, '東京都東久留米市新川町');
ok($zip->set_number('2030014')->is_valid_number, '東京都東久留米市東本町');
ok($zip->set_number('2030021')->is_valid_number, '東京都東久留米市学園町');
ok($zip->set_number('2030022')->is_valid_number, '東京都東久留米市ひばりが丘団地');
ok($zip->set_number('2030023')->is_valid_number, '東京都東久留米市南沢');
ok($zip->set_number('2030031')->is_valid_number, '東京都東久留米市南町');
ok($zip->set_number('2030032')->is_valid_number, '東京都東久留米市前沢');
ok($zip->set_number('2030033')->is_valid_number, '東京都東久留米市滝山');
ok($zip->set_number('2030034')->is_valid_number, '東京都東久留米市弥生');
ok($zip->set_number('2030041')->is_valid_number, '東京都東久留米市野火止');
ok($zip->set_number('2030042')->is_valid_number, '東京都東久留米市八幡町');
ok($zip->set_number('2030043')->is_valid_number, '東京都東久留米市下里');
ok($zip->set_number('2030044')->is_valid_number, '東京都東久留米市柳窪');
ok($zip->set_number('2030051')->is_valid_number, '東京都東久留米市小山');
ok($zip->set_number('2030052')->is_valid_number, '東京都東久留米市幸町');
ok($zip->set_number('2030053')->is_valid_number, '東京都東久留米市本町');
ok($zip->set_number('2030054')->is_valid_number, '東京都東久留米市中央町');
ok($zip->set_number('2040000')->is_valid_number, '東京都清瀬市以下に掲載がない場合');
ok($zip->set_number('2040001')->is_valid_number, '東京都清瀬市下宿');
ok($zip->set_number('2040002')->is_valid_number, '東京都清瀬市旭が丘');
ok($zip->set_number('2040003')->is_valid_number, '東京都清瀬市中里');
ok($zip->set_number('2040004')->is_valid_number, '東京都清瀬市野塩');
ok($zip->set_number('2040011')->is_valid_number, '東京都清瀬市下清戸');
ok($zip->set_number('2040012')->is_valid_number, '東京都清瀬市中清戸');
ok($zip->set_number('2040013')->is_valid_number, '東京都清瀬市上清戸');
ok($zip->set_number('2040021')->is_valid_number, '東京都清瀬市元町');
ok($zip->set_number('2040022')->is_valid_number, '東京都清瀬市松山');
ok($zip->set_number('2040023')->is_valid_number, '東京都清瀬市竹丘');
ok($zip->set_number('2040024')->is_valid_number, '東京都清瀬市梅園');
ok($zip->set_number('2050000')->is_valid_number, '東京都羽村市以下に掲載がない場合');
ok($zip->set_number('2050001')->is_valid_number, '東京都羽村市小作台');
ok($zip->set_number('2050002')->is_valid_number, '東京都羽村市栄町');
ok($zip->set_number('2050003')->is_valid_number, '東京都羽村市緑ケ丘');
ok($zip->set_number('2050011')->is_valid_number, '東京都羽村市五ノ神');
ok($zip->set_number('2050012')->is_valid_number, '東京都羽村市羽');
ok($zip->set_number('2050013')->is_valid_number, '東京都羽村市富士見平');
ok($zip->set_number('2050014')->is_valid_number, '東京都羽村市羽東');
ok($zip->set_number('2050015')->is_valid_number, '東京都羽村市羽中');
ok($zip->set_number('2050016')->is_valid_number, '東京都羽村市羽加美');
ok($zip->set_number('2050017')->is_valid_number, '東京都羽村市羽西');
ok($zip->set_number('2050021')->is_valid_number, '東京都羽村市川崎');
ok($zip->set_number('2050022')->is_valid_number, '東京都羽村市双葉町');
ok($zip->set_number('2050023')->is_valid_number, '東京都羽村市神明台');
ok($zip->set_number('2050024')->is_valid_number, '東京都羽村市玉川');
ok($zip->set_number('2060000')->is_valid_number, '東京都多摩市以下に掲載がない場合');
ok($zip->set_number('2060000')->is_valid_number, '東京都稲城市以下に掲載がない場合');
ok($zip->set_number('2060001')->is_valid_number, '東京都多摩市和田');
ok($zip->set_number('2060002')->is_valid_number, '東京都多摩市一ノ宮');
ok($zip->set_number('2060003')->is_valid_number, '東京都多摩市東寺方');
ok($zip->set_number('2060004')->is_valid_number, '東京都多摩市百草');
ok($zip->set_number('2060011')->is_valid_number, '東京都多摩市関戸');
ok($zip->set_number('2060012')->is_valid_number, '東京都多摩市貝取');
ok($zip->set_number('2060013')->is_valid_number, '東京都多摩市桜ヶ丘');
ok($zip->set_number('2060014')->is_valid_number, '東京都多摩市乞田');
ok($zip->set_number('2060015')->is_valid_number, '東京都多摩市落川');
ok($zip->set_number('2060021')->is_valid_number, '東京都多摩市連光寺');
ok($zip->set_number('2060022')->is_valid_number, '東京都多摩市聖ヶ丘');
ok($zip->set_number('2060023')->is_valid_number, '東京都多摩市馬引沢');
ok($zip->set_number('2060024')->is_valid_number, '東京都多摩市諏訪');
ok($zip->set_number('2060025')->is_valid_number, '東京都多摩市永山');
ok($zip->set_number('2060031')->is_valid_number, '東京都多摩市豊ヶ丘');
ok($zip->set_number('2060032')->is_valid_number, '東京都多摩市南野');
ok($zip->set_number('2060033')->is_valid_number, '東京都多摩市落合');
ok($zip->set_number('2060034')->is_valid_number, '東京都多摩市鶴牧');
ok($zip->set_number('2060035')->is_valid_number, '東京都多摩市唐木田');
ok($zip->set_number('2060036')->is_valid_number, '東京都多摩市中沢');
ok($zip->set_number('2060041')->is_valid_number, '東京都多摩市愛宕');
ok($zip->set_number('2060042')->is_valid_number, '東京都多摩市山王下');
ok($zip->set_number('2060801')->is_valid_number, '東京都稲城市大丸');
ok($zip->set_number('2060802')->is_valid_number, '東京都稲城市東長沼');
ok($zip->set_number('2060803')->is_valid_number, '東京都稲城市向陽台');
ok($zip->set_number('2060804')->is_valid_number, '東京都稲城市百村');
ok($zip->set_number('2060811')->is_valid_number, '東京都稲城市押立');
ok($zip->set_number('2060812')->is_valid_number, '東京都稲城市矢野口');
ok($zip->set_number('2060821')->is_valid_number, '東京都稲城市長峰');
ok($zip->set_number('2060822')->is_valid_number, '東京都稲城市坂浜');
ok($zip->set_number('2060823')->is_valid_number, '東京都稲城市平尾');
ok($zip->set_number('2060824')->is_valid_number, '東京都稲城市若葉台');
ok($zip->set_number('2070000')->is_valid_number, '東京都東大和市以下に掲載がない場合');
ok($zip->set_number('2070001')->is_valid_number, '東京都東大和市多摩湖');
ok($zip->set_number('2070002')->is_valid_number, '東京都東大和市湖畔');
ok($zip->set_number('2070003')->is_valid_number, '東京都東大和市狭山');
ok($zip->set_number('2070004')->is_valid_number, '東京都東大和市清水');
ok($zip->set_number('2070005')->is_valid_number, '東京都東大和市高木');
ok($zip->set_number('2070011')->is_valid_number, '東京都東大和市清原');
ok($zip->set_number('2070012')->is_valid_number, '東京都東大和市新堀');
ok($zip->set_number('2070013')->is_valid_number, '東京都東大和市向原');
ok($zip->set_number('2070014')->is_valid_number, '東京都東大和市南街');
ok($zip->set_number('2070015')->is_valid_number, '東京都東大和市中央');
ok($zip->set_number('2070016')->is_valid_number, '東京都東大和市仲原');
ok($zip->set_number('2070021')->is_valid_number, '東京都東大和市立野');
ok($zip->set_number('2070022')->is_valid_number, '東京都東大和市桜が丘');
ok($zip->set_number('2070023')->is_valid_number, '東京都東大和市上北台');
ok($zip->set_number('2070031')->is_valid_number, '東京都東大和市奈良橋');
ok($zip->set_number('2070032')->is_valid_number, '東京都東大和市蔵敷');
ok($zip->set_number('2070033')->is_valid_number, '東京都東大和市芋窪');
ok($zip->set_number('2080000')->is_valid_number, '東京都武蔵村山市以下に掲載がない場合');
ok($zip->set_number('2080001')->is_valid_number, '東京都武蔵村山市中藤');
ok($zip->set_number('2080002')->is_valid_number, '東京都武蔵村山市神明');
ok($zip->set_number('2080003')->is_valid_number, '東京都武蔵村山市中央');
ok($zip->set_number('2080004')->is_valid_number, '東京都武蔵村山市本町');
ok($zip->set_number('2080011')->is_valid_number, '東京都武蔵村山市学園');
ok($zip->set_number('2080012')->is_valid_number, '東京都武蔵村山市緑が丘');
ok($zip->set_number('2080013')->is_valid_number, '東京都武蔵村山市大南');
ok($zip->set_number('2080021')->is_valid_number, '東京都武蔵村山市三ツ藤');
ok($zip->set_number('2080022')->is_valid_number, '東京都武蔵村山市榎');
ok($zip->set_number('2080023')->is_valid_number, '東京都武蔵村山市伊奈平');
ok($zip->set_number('2080031')->is_valid_number, '東京都武蔵村山市岸');
ok($zip->set_number('2080032')->is_valid_number, '東京都武蔵村山市三ツ木(1~5丁目)');
ok($zip->set_number('2080033')->is_valid_number, '東京都武蔵村山市三ツ木(大字)');
ok($zip->set_number('2080034')->is_valid_number, '東京都武蔵村山市残堀');
ok($zip->set_number('2080035')->is_valid_number, '東京都武蔵村山市中原');
ok($zip->set_number('2100000')->is_valid_number, '神奈川県川崎市川崎区以下に掲載がない場合');
ok($zip->set_number('2100001')->is_valid_number, '神奈川県川崎市川崎区本町');
ok($zip->set_number('2100002')->is_valid_number, '神奈川県川崎市川崎区榎町');
ok($zip->set_number('2100003')->is_valid_number, '神奈川県川崎市川崎区堀之内町');
ok($zip->set_number('2100004')->is_valid_number, '神奈川県川崎市川崎区宮本町');
ok($zip->set_number('2100005')->is_valid_number, '神奈川県川崎市川崎区東田町');
ok($zip->set_number('2100006')->is_valid_number, '神奈川県川崎市川崎区砂子');
ok($zip->set_number('2100007')->is_valid_number, '神奈川県川崎市川崎区駅前本町');
ok($zip->set_number('2100011')->is_valid_number, '神奈川県川崎市川崎区富士見');
ok($zip->set_number('2100012')->is_valid_number, '神奈川県川崎市川崎区宮前町');
ok($zip->set_number('2100013')->is_valid_number, '神奈川県川崎市川崎区新川通');
ok($zip->set_number('2100014')->is_valid_number, '神奈川県川崎市川崎区貝塚');
ok($zip->set_number('2100015')->is_valid_number, '神奈川県川崎市川崎区南町');
ok($zip->set_number('2100021')->is_valid_number, '神奈川県川崎市川崎区元木');
ok($zip->set_number('2100022')->is_valid_number, '神奈川県川崎市川崎区池田');
ok($zip->set_number('2100023')->is_valid_number, '神奈川県川崎市川崎区小川町');
ok($zip->set_number('2100024')->is_valid_number, '神奈川県川崎市川崎区日進町');
ok($zip->set_number('2100025')->is_valid_number, '神奈川県川崎市川崎区下並木');
ok($zip->set_number('2100026')->is_valid_number, '神奈川県川崎市川崎区堤根');
ok($zip->set_number('2100801')->is_valid_number, '神奈川県川崎市川崎区鈴木町');
ok($zip->set_number('2100802')->is_valid_number, '神奈川県川崎市川崎区大師駅前');
ok($zip->set_number('2100803')->is_valid_number, '神奈川県川崎市川崎区川中島');
ok($zip->set_number('2100804')->is_valid_number, '神奈川県川崎市川崎区藤崎');
ok($zip->set_number('2100805')->is_valid_number, '神奈川県川崎市川崎区伊勢町');
ok($zip->set_number('2100806')->is_valid_number, '神奈川県川崎市川崎区中島');
ok($zip->set_number('2100807')->is_valid_number, '神奈川県川崎市川崎区港町');
ok($zip->set_number('2100808')->is_valid_number, '神奈川県川崎市川崎区旭町');
ok($zip->set_number('2100811')->is_valid_number, '神奈川県川崎市川崎区大師河原');
ok($zip->set_number('2100812')->is_valid_number, '神奈川県川崎市川崎区東門前');
ok($zip->set_number('2100813')->is_valid_number, '神奈川県川崎市川崎区昭和');
ok($zip->set_number('2100814')->is_valid_number, '神奈川県川崎市川崎区台町');
ok($zip->set_number('2100815')->is_valid_number, '神奈川県川崎市川崎区大師公園');
ok($zip->set_number('2100816')->is_valid_number, '神奈川県川崎市川崎区大師町');
ok($zip->set_number('2100817')->is_valid_number, '神奈川県川崎市川崎区大師本町');
ok($zip->set_number('2100818')->is_valid_number, '神奈川県川崎市川崎区中瀬');
ok($zip->set_number('2100821')->is_valid_number, '神奈川県川崎市川崎区殿町');
ok($zip->set_number('2100822')->is_valid_number, '神奈川県川崎市川崎区田町');
ok($zip->set_number('2100823')->is_valid_number, '神奈川県川崎市川崎区江川');
ok($zip->set_number('2100824')->is_valid_number, '神奈川県川崎市川崎区日ノ出');
ok($zip->set_number('2100825')->is_valid_number, '神奈川県川崎市川崎区出来野');
ok($zip->set_number('2100826')->is_valid_number, '神奈川県川崎市川崎区塩浜');
ok($zip->set_number('2100827')->is_valid_number, '神奈川県川崎市川崎区四谷下町');
ok($zip->set_number('2100828')->is_valid_number, '神奈川県川崎市川崎区四谷上町');
ok($zip->set_number('2100831')->is_valid_number, '神奈川県川崎市川崎区観音');
ok($zip->set_number('2100832')->is_valid_number, '神奈川県川崎市川崎区池上新町');
ok($zip->set_number('2100833')->is_valid_number, '神奈川県川崎市川崎区桜本');
ok($zip->set_number('2100834')->is_valid_number, '神奈川県川崎市川崎区大島');
ok($zip->set_number('2100835')->is_valid_number, '神奈川県川崎市川崎区追分町');
ok($zip->set_number('2100836')->is_valid_number, '神奈川県川崎市川崎区大島上町');
ok($zip->set_number('2100837')->is_valid_number, '神奈川県川崎市川崎区渡田');
ok($zip->set_number('2100838')->is_valid_number, '神奈川県川崎市川崎区境町');
ok($zip->set_number('2100841')->is_valid_number, '神奈川県川崎市川崎区渡田向町');
ok($zip->set_number('2100842')->is_valid_number, '神奈川県川崎市川崎区渡田東町');
ok($zip->set_number('2100843')->is_valid_number, '神奈川県川崎市川崎区小田栄');
ok($zip->set_number('2100844')->is_valid_number, '神奈川県川崎市川崎区渡田新町');
ok($zip->set_number('2100845')->is_valid_number, '神奈川県川崎市川崎区渡田山王町');
ok($zip->set_number('2100846')->is_valid_number, '神奈川県川崎市川崎区小田');
ok($zip->set_number('2100847')->is_valid_number, '神奈川県川崎市川崎区浅田');
ok($zip->set_number('2100848')->is_valid_number, '神奈川県川崎市川崎区京町');
ok($zip->set_number('2100851')->is_valid_number, '神奈川県川崎市川崎区浜町');
ok($zip->set_number('2100852')->is_valid_number, '神奈川県川崎市川崎区鋼管通');
ok($zip->set_number('2100853')->is_valid_number, '神奈川県川崎市川崎区田島町');
ok($zip->set_number('2100854')->is_valid_number, '神奈川県川崎市川崎区浅野町');
ok($zip->set_number('2100855')->is_valid_number, '神奈川県川崎市川崎区南渡田町');
ok($zip->set_number('2100856')->is_valid_number, '神奈川県川崎市川崎区田辺新田');
ok($zip->set_number('2100857')->is_valid_number, '神奈川県川崎市川崎区白石町');
ok($zip->set_number('2100858')->is_valid_number, '神奈川県川崎市川崎区大川町');
ok($zip->set_number('2100861')->is_valid_number, '神奈川県川崎市川崎区小島町');
ok($zip->set_number('2100862')->is_valid_number, '神奈川県川崎市川崎区浮島町');
ok($zip->set_number('2100863')->is_valid_number, '神奈川県川崎市川崎区夜光');
ok($zip->set_number('2100864')->is_valid_number, '神奈川県川崎市川崎区池上町');
ok($zip->set_number('2100865')->is_valid_number, '神奈川県川崎市川崎区千鳥町');
ok($zip->set_number('2100866')->is_valid_number, '神奈川県川崎市川崎区水江町');
ok($zip->set_number('2100867')->is_valid_number, '神奈川県川崎市川崎区扇町');
ok($zip->set_number('2100868')->is_valid_number, '神奈川県川崎市川崎区扇島');
ok($zip->set_number('2100869')->is_valid_number, '神奈川県川崎市川崎区東扇島');
ok($zip->set_number('2110000')->is_valid_number, '神奈川県川崎市中原区以下に掲載がない場合');
ok($zip->set_number('2110001')->is_valid_number, '神奈川県川崎市中原区上丸子八幡町');
ok($zip->set_number('2110002')->is_valid_number, '神奈川県川崎市中原区上丸子山王町');
ok($zip->set_number('2110003')->is_valid_number, '神奈川県川崎市中原区上丸子');
ok($zip->set_number('2110004')->is_valid_number, '神奈川県川崎市中原区新丸子東');
ok($zip->set_number('2110005')->is_valid_number, '神奈川県川崎市中原区新丸子町');
ok($zip->set_number('2110006')->is_valid_number, '神奈川県川崎市中原区丸子通');
ok($zip->set_number('2110007')->is_valid_number, '神奈川県川崎市中原区上丸子天神町');
ok($zip->set_number('2110011')->is_valid_number, '神奈川県川崎市中原区下沼部');
ok($zip->set_number('2110012')->is_valid_number, '神奈川県川崎市中原区中丸子');
ok($zip->set_number('2110013')->is_valid_number, '神奈川県川崎市中原区上平間');
ok($zip->set_number('2110014')->is_valid_number, '神奈川県川崎市中原区田尻町');
ok($zip->set_number('2110015')->is_valid_number, '神奈川県川崎市中原区北谷町');
ok($zip->set_number('2110016')->is_valid_number, '神奈川県川崎市中原区市ノ坪');
ok($zip->set_number('2110021')->is_valid_number, '神奈川県川崎市中原区木月住吉町');
ok($zip->set_number('2110022')->is_valid_number, '神奈川県川崎市中原区苅宿');
ok($zip->set_number('2110023')->is_valid_number, '神奈川県川崎市中原区大倉町');
ok($zip->set_number('2110024')->is_valid_number, '神奈川県川崎市中原区西加瀬');
ok($zip->set_number('2110025')->is_valid_number, '神奈川県川崎市中原区木月');
ok($zip->set_number('2110031')->is_valid_number, '神奈川県川崎市中原区木月大町');
ok($zip->set_number('2110032')->is_valid_number, '神奈川県川崎市中原区木月伊勢町');
ok($zip->set_number('2110033')->is_valid_number, '神奈川県川崎市中原区木月祗園町');
ok($zip->set_number('2110034')->is_valid_number, '神奈川県川崎市中原区井田中ノ町');
ok($zip->set_number('2110035')->is_valid_number, '神奈川県川崎市中原区井田');
ok($zip->set_number('2110036')->is_valid_number, '神奈川県川崎市中原区井田杉山町');
ok($zip->set_number('2110037')->is_valid_number, '神奈川県川崎市中原区井田三舞町');
ok($zip->set_number('2110041')->is_valid_number, '神奈川県川崎市中原区下小田中');
ok($zip->set_number('2110042')->is_valid_number, '神奈川県川崎市中原区下新城');
ok($zip->set_number('2110043')->is_valid_number, '神奈川県川崎市中原区新城中町');
ok($zip->set_number('2110044')->is_valid_number, '神奈川県川崎市中原区新城');
ok($zip->set_number('2110045')->is_valid_number, '神奈川県川崎市中原区上新城');
ok($zip->set_number('2110051')->is_valid_number, '神奈川県川崎市中原区宮内');
ok($zip->set_number('2110052')->is_valid_number, '神奈川県川崎市中原区等々力');
ok($zip->set_number('2110053')->is_valid_number, '神奈川県川崎市中原区上小田中');
ok($zip->set_number('2110061')->is_valid_number, '神奈川県川崎市中原区小杉');
ok($zip->set_number('2110062')->is_valid_number, '神奈川県川崎市中原区小杉陣屋町');
ok($zip->set_number('2110063')->is_valid_number, '神奈川県川崎市中原区小杉町');
ok($zip->set_number('2110064')->is_valid_number, '神奈川県川崎市中原区今井南町');
ok($zip->set_number('2110065')->is_valid_number, '神奈川県川崎市中原区今井仲町');
ok($zip->set_number('2110066')->is_valid_number, '神奈川県川崎市中原区今井西町');
ok($zip->set_number('2110067')->is_valid_number, '神奈川県川崎市中原区今井上町');
ok($zip->set_number('2110068')->is_valid_number, '神奈川県川崎市中原区小杉御殿町');
ok($zip->set_number('2120000')->is_valid_number, '神奈川県川崎市幸区以下に掲載がない場合');
ok($zip->set_number('2120001')->is_valid_number, '神奈川県川崎市幸区小向東芝町');
ok($zip->set_number('2120002')->is_valid_number, '神奈川県川崎市幸区小向仲野町');
ok($zip->set_number('2120003')->is_valid_number, '神奈川県川崎市幸区小向町');
ok($zip->set_number('2120004')->is_valid_number, '神奈川県川崎市幸区小向西町');
ok($zip->set_number('2120005')->is_valid_number, '神奈川県川崎市幸区戸手');
ok($zip->set_number('2120006')->is_valid_number, '神奈川県川崎市幸区遠藤町');
ok($zip->set_number('2120007')->is_valid_number, '神奈川県川崎市幸区河原町');
ok($zip->set_number('2120011')->is_valid_number, '神奈川県川崎市幸区幸町');
ok($zip->set_number('2120012')->is_valid_number, '神奈川県川崎市幸区中幸町');
ok($zip->set_number('2120013')->is_valid_number, '神奈川県川崎市幸区堀川町');
ok($zip->set_number('2120014')->is_valid_number, '神奈川県川崎市幸区大宮町');
ok($zip->set_number('2120015')->is_valid_number, '神奈川県川崎市幸区柳町');
ok($zip->set_number('2120016')->is_valid_number, '神奈川県川崎市幸区南幸町');
ok($zip->set_number('2120021')->is_valid_number, '神奈川県川崎市幸区都町');
ok($zip->set_number('2120022')->is_valid_number, '神奈川県川崎市幸区神明町');
ok($zip->set_number('2120023')->is_valid_number, '神奈川県川崎市幸区戸手本町');
ok($zip->set_number('2120024')->is_valid_number, '神奈川県川崎市幸区塚越');
ok($zip->set_number('2120025')->is_valid_number, '神奈川県川崎市幸区古川町');
ok($zip->set_number('2120026')->is_valid_number, '神奈川県川崎市幸区紺屋町');
ok($zip->set_number('2120027')->is_valid_number, '神奈川県川崎市幸区新塚越');
ok($zip->set_number('2120031')->is_valid_number, '神奈川県川崎市幸区新小倉');
ok($zip->set_number('2120032')->is_valid_number, '神奈川県川崎市幸区新川崎');
ok($zip->set_number('2120033')->is_valid_number, '神奈川県川崎市幸区東小倉');
ok($zip->set_number('2120051')->is_valid_number, '神奈川県川崎市幸区東古市場');
ok($zip->set_number('2120052')->is_valid_number, '神奈川県川崎市幸区古市場');
ok($zip->set_number('2120053')->is_valid_number, '神奈川県川崎市幸区下平間');
ok($zip->set_number('2120054')->is_valid_number, '神奈川県川崎市幸区小倉');
ok($zip->set_number('2120055')->is_valid_number, '神奈川県川崎市幸区南加瀬');
ok($zip->set_number('2120056')->is_valid_number, '神奈川県川崎市幸区矢上');
ok($zip->set_number('2120057')->is_valid_number, '神奈川県川崎市幸区北加瀬');
ok($zip->set_number('2120058')->is_valid_number, '神奈川県川崎市幸区鹿島田');
ok($zip->set_number('2130000')->is_valid_number, '神奈川県川崎市高津区以下に掲載がない場合');
ok($zip->set_number('2130001')->is_valid_number, '神奈川県川崎市高津区溝口');
ok($zip->set_number('2130002')->is_valid_number, '神奈川県川崎市高津区二子');
ok($zip->set_number('2130003')->is_valid_number, '神奈川県川崎市高津区瀬田');
ok($zip->set_number('2130004')->is_valid_number, '神奈川県川崎市高津区諏訪');
ok($zip->set_number('2130005')->is_valid_number, '神奈川県川崎市高津区北見方');
ok($zip->set_number('2130006')->is_valid_number, '神奈川県川崎市高津区下野毛');
ok($zip->set_number('2130011')->is_valid_number, '神奈川県川崎市高津区久本');
ok($zip->set_number('2130012')->is_valid_number, '神奈川県川崎市高津区坂戸');
ok($zip->set_number('2130013')->is_valid_number, '神奈川県川崎市高津区末長');
ok($zip->set_number('2130014')->is_valid_number, '神奈川県川崎市高津区新作');
ok($zip->set_number('2130015')->is_valid_number, '神奈川県川崎市高津区梶ケ谷');
ok($zip->set_number('2130021')->is_valid_number, '神奈川県川崎市高津区千年新町');
ok($zip->set_number('2130022')->is_valid_number, '神奈川県川崎市高津区千年');
ok($zip->set_number('2130023')->is_valid_number, '神奈川県川崎市高津区子母口');
ok($zip->set_number('2130024')->is_valid_number, '神奈川県川崎市高津区明津');
ok($zip->set_number('2130025')->is_valid_number, '神奈川県川崎市高津区蟹ケ谷');
ok($zip->set_number('2130026')->is_valid_number, '神奈川県川崎市高津区久末');
ok($zip->set_number('2130028')->is_valid_number, '神奈川県川崎市高津区北野川');
ok($zip->set_number('2130029')->is_valid_number, '神奈川県川崎市高津区東野川');
ok($zip->set_number('2130031')->is_valid_number, '神奈川県川崎市高津区宇奈根');
ok($zip->set_number('2130032')->is_valid_number, '神奈川県川崎市高津区久地');
ok($zip->set_number('2130033')->is_valid_number, '神奈川県川崎市高津区下作延');
ok($zip->set_number('2130034')->is_valid_number, '神奈川県川崎市高津区上作延');
ok($zip->set_number('2130035')->is_valid_number, '神奈川県川崎市高津区向ケ丘');
ok($zip->set_number('2140000')->is_valid_number, '神奈川県川崎市多摩区以下に掲載がない場合');
ok($zip->set_number('2140001')->is_valid_number, '神奈川県川崎市多摩区菅');
ok($zip->set_number('2140002')->is_valid_number, '神奈川県川崎市多摩区菅野戸呂');
ok($zip->set_number('2140003')->is_valid_number, '神奈川県川崎市多摩区菅稲田堤');
ok($zip->set_number('2140004')->is_valid_number, '神奈川県川崎市多摩区菅馬場');
ok($zip->set_number('2140005')->is_valid_number, '神奈川県川崎市多摩区寺尾台');
ok($zip->set_number('2140006')->is_valid_number, '神奈川県川崎市多摩区菅仙谷');
ok($zip->set_number('2140007')->is_valid_number, '神奈川県川崎市多摩区菅城下');
ok($zip->set_number('2140008')->is_valid_number, '神奈川県川崎市多摩区菅北浦');
ok($zip->set_number('2140011')->is_valid_number, '神奈川県川崎市多摩区布田');
ok($zip->set_number('2140012')->is_valid_number, '神奈川県川崎市多摩区中野島');
ok($zip->set_number('2140013')->is_valid_number, '神奈川県川崎市多摩区登戸新町');
ok($zip->set_number('2140014')->is_valid_number, '神奈川県川崎市多摩区登戸');
ok($zip->set_number('2140021')->is_valid_number, '神奈川県川崎市多摩区宿河原');
ok($zip->set_number('2140022')->is_valid_number, '神奈川県川崎市多摩区堰');
ok($zip->set_number('2140023')->is_valid_number, '神奈川県川崎市多摩区長尾');
ok($zip->set_number('2140031')->is_valid_number, '神奈川県川崎市多摩区東生田');
ok($zip->set_number('2140032')->is_valid_number, '神奈川県川崎市多摩区枡形');
ok($zip->set_number('2140033')->is_valid_number, '神奈川県川崎市多摩区東三田');
ok($zip->set_number('2140034')->is_valid_number, '神奈川県川崎市多摩区三田');
ok($zip->set_number('2140035')->is_valid_number, '神奈川県川崎市多摩区長沢');
ok($zip->set_number('2140036')->is_valid_number, '神奈川県川崎市多摩区南生田');
ok($zip->set_number('2140037')->is_valid_number, '神奈川県川崎市多摩区西生田');
ok($zip->set_number('2140038')->is_valid_number, '神奈川県川崎市多摩区生田');
ok($zip->set_number('2140039')->is_valid_number, '神奈川県川崎市多摩区栗谷');
ok($zip->set_number('2150000')->is_valid_number, '神奈川県川崎市麻生区以下に掲載がない場合');
ok($zip->set_number('2150001')->is_valid_number, '神奈川県川崎市麻生区細山');
ok($zip->set_number('2150002')->is_valid_number, '神奈川県川崎市麻生区多摩美');
ok($zip->set_number('2150003')->is_valid_number, '神奈川県川崎市麻生区高石');
ok($zip->set_number('2150004')->is_valid_number, '神奈川県川崎市麻生区万福寺');
ok($zip->set_number('2150005')->is_valid_number, '神奈川県川崎市麻生区千代ケ丘');
ok($zip->set_number('2150006')->is_valid_number, '神奈川県川崎市麻生区金程');
ok($zip->set_number('2150007')->is_valid_number, '神奈川県川崎市麻生区向原');
ok($zip->set_number('2150011')->is_valid_number, '神奈川県川崎市麻生区百合丘');
ok($zip->set_number('2150012')->is_valid_number, '神奈川県川崎市麻生区東百合丘');
ok($zip->set_number('2150013')->is_valid_number, '神奈川県川崎市麻生区王禅寺');
ok($zip->set_number('2150014')->is_valid_number, '神奈川県川崎市麻生区白山');
ok($zip->set_number('2150015')->is_valid_number, '神奈川県川崎市麻生区虹ケ丘');
ok($zip->set_number('2150016')->is_valid_number, '神奈川県川崎市麻生区早野');
ok($zip->set_number('2150017')->is_valid_number, '神奈川県川崎市麻生区王禅寺西');
ok($zip->set_number('2150018')->is_valid_number, '神奈川県川崎市麻生区王禅寺東');
ok($zip->set_number('2150021')->is_valid_number, '神奈川県川崎市麻生区上麻生');
ok($zip->set_number('2150022')->is_valid_number, '神奈川県川崎市麻生区下麻生');
ok($zip->set_number('2150023')->is_valid_number, '神奈川県川崎市麻生区片平');
ok($zip->set_number('2150024')->is_valid_number, '神奈川県川崎市麻生区白鳥');
ok($zip->set_number('2150025')->is_valid_number, '神奈川県川崎市麻生区五力田');
ok($zip->set_number('2150026')->is_valid_number, '神奈川県川崎市麻生区古沢');
ok($zip->set_number('2150027')->is_valid_number, '神奈川県川崎市麻生区岡上');
ok($zip->set_number('2150031')->is_valid_number, '神奈川県川崎市麻生区栗平');
ok($zip->set_number('2150032')->is_valid_number, '神奈川県川崎市麻生区栗木台');
ok($zip->set_number('2150033')->is_valid_number, '神奈川県川崎市麻生区栗木');
ok($zip->set_number('2150034')->is_valid_number, '神奈川県川崎市麻生区南黒川');
ok($zip->set_number('2150035')->is_valid_number, '神奈川県川崎市麻生区黒川');
ok($zip->set_number('2150036')->is_valid_number, '神奈川県川崎市麻生区はるひ野');
ok($zip->set_number('2160000')->is_valid_number, '神奈川県川崎市宮前区以下に掲載がない場合');
ok($zip->set_number('2160002')->is_valid_number, '神奈川県川崎市宮前区東有馬');
ok($zip->set_number('2160003')->is_valid_number, '神奈川県川崎市宮前区有馬');
ok($zip->set_number('2160004')->is_valid_number, '神奈川県川崎市宮前区鷺沼');
ok($zip->set_number('2160005')->is_valid_number, '神奈川県川崎市宮前区土橋');
ok($zip->set_number('2160006')->is_valid_number, '神奈川県川崎市宮前区宮前平');
ok($zip->set_number('2160007')->is_valid_number, '神奈川県川崎市宮前区小台');
ok($zip->set_number('2160011')->is_valid_number, '神奈川県川崎市宮前区犬蔵');
ok($zip->set_number('2160012')->is_valid_number, '神奈川県川崎市宮前区水沢');
ok($zip->set_number('2160013')->is_valid_number, '神奈川県川崎市宮前区潮見台');
ok($zip->set_number('2160014')->is_valid_number, '神奈川県川崎市宮前区菅生ケ丘');
ok($zip->set_number('2160015')->is_valid_number, '神奈川県川崎市宮前区菅生');
ok($zip->set_number('2160021')->is_valid_number, '神奈川県川崎市宮前区五所塚');
ok($zip->set_number('2160022')->is_valid_number, '神奈川県川崎市宮前区平');
ok($zip->set_number('2160023')->is_valid_number, '神奈川県川崎市宮前区けやき平');
ok($zip->set_number('2160024')->is_valid_number, '神奈川県川崎市宮前区南平台');
ok($zip->set_number('2160025')->is_valid_number, '神奈川県川崎市宮前区白幡台');
ok($zip->set_number('2160026')->is_valid_number, '神奈川県川崎市宮前区初山');
ok($zip->set_number('2160031')->is_valid_number, '神奈川県川崎市宮前区神木本町');
ok($zip->set_number('2160032')->is_valid_number, '神奈川県川崎市宮前区神木');
ok($zip->set_number('2160033')->is_valid_number, '神奈川県川崎市宮前区宮崎');
ok($zip->set_number('2160034')->is_valid_number, '神奈川県川崎市宮前区梶ケ谷');
ok($zip->set_number('2160035')->is_valid_number, '神奈川県川崎市宮前区馬絹');
ok($zip->set_number('2160041')->is_valid_number, '神奈川県川崎市宮前区野川本町');
ok($zip->set_number('2160042')->is_valid_number, '神奈川県川崎市宮前区南野川');
ok($zip->set_number('2160043')->is_valid_number, '神奈川県川崎市宮前区野川台');
ok($zip->set_number('2160044')->is_valid_number, '神奈川県川崎市宮前区西野川');
ok($zip->set_number('2200000')->is_valid_number, '神奈川県横浜市西区以下に掲載がない場合');
ok($zip->set_number('2200001')->is_valid_number, '神奈川県横浜市西区北軽井沢');
ok($zip->set_number('2200002')->is_valid_number, '神奈川県横浜市西区南軽井沢');
ok($zip->set_number('2200003')->is_valid_number, '神奈川県横浜市西区楠町');
ok($zip->set_number('2200004')->is_valid_number, '神奈川県横浜市西区北幸');
ok($zip->set_number('2200005')->is_valid_number, '神奈川県横浜市西区南幸');
ok($zip->set_number('2200006')->is_valid_number, '神奈川県横浜市西区宮ケ谷');
ok($zip->set_number('2200011')->is_valid_number, '神奈川県横浜市西区高島');
ok($zip->set_number('2200012')->is_valid_number, '神奈川県横浜市西区みなとみらい(次のビルを除く)');
ok($zip->set_number('2200013')->is_valid_number, '神奈川県横浜市西区緑町');
ok($zip->set_number('2200021')->is_valid_number, '神奈川県横浜市西区桜木町(4~7丁目)');
ok($zip->set_number('2200022')->is_valid_number, '神奈川県横浜市西区花咲町(4~7丁目)');
ok($zip->set_number('2200023')->is_valid_number, '神奈川県横浜市西区平沼');
ok($zip->set_number('2200024')->is_valid_number, '神奈川県横浜市西区西平沼町');
ok($zip->set_number('2200031')->is_valid_number, '神奈川県横浜市西区宮崎町');
ok($zip->set_number('2200032')->is_valid_number, '神奈川県横浜市西区老松町');
ok($zip->set_number('2200033')->is_valid_number, '神奈川県横浜市西区東ケ丘');
ok($zip->set_number('2200034')->is_valid_number, '神奈川県横浜市西区赤門町');
ok($zip->set_number('2200035')->is_valid_number, '神奈川県横浜市西区霞ケ丘');
ok($zip->set_number('2200041')->is_valid_number, '神奈川県横浜市西区戸部本町');
ok($zip->set_number('2200042')->is_valid_number, '神奈川県横浜市西区戸部町');
ok($zip->set_number('2200043')->is_valid_number, '神奈川県横浜市西区御所山町');
ok($zip->set_number('2200044')->is_valid_number, '神奈川県横浜市西区紅葉ケ丘');
ok($zip->set_number('2200045')->is_valid_number, '神奈川県横浜市西区伊勢町');
ok($zip->set_number('2200046')->is_valid_number, '神奈川県横浜市西区西戸部町');
ok($zip->set_number('2200051')->is_valid_number, '神奈川県横浜市西区中央');
ok($zip->set_number('2200052')->is_valid_number, '神奈川県横浜市西区西前町');
ok($zip->set_number('2200053')->is_valid_number, '神奈川県横浜市西区藤棚町');
ok($zip->set_number('2200054')->is_valid_number, '神奈川県横浜市西区境之谷');
ok($zip->set_number('2200055')->is_valid_number, '神奈川県横浜市西区浜松町');
ok($zip->set_number('2200061')->is_valid_number, '神奈川県横浜市西区久保町');
ok($zip->set_number('2200062')->is_valid_number, '神奈川県横浜市西区東久保町');
ok($zip->set_number('2200063')->is_valid_number, '神奈川県横浜市西区元久保町');
ok($zip->set_number('2200071')->is_valid_number, '神奈川県横浜市西区浅間台');
ok($zip->set_number('2200072')->is_valid_number, '神奈川県横浜市西区浅間町');
ok($zip->set_number('2200073')->is_valid_number, '神奈川県横浜市西区岡野');
ok($zip->set_number('2200074')->is_valid_number, '神奈川県横浜市西区南浅間町');
ok($zip->set_number('2206001')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(1階)');
ok($zip->set_number('2206002')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(2階)');
ok($zip->set_number('2206003')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(3階)');
ok($zip->set_number('2206004')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(4階)');
ok($zip->set_number('2206005')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(5階)');
ok($zip->set_number('2206006')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(6階)');
ok($zip->set_number('2206007')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(7階)');
ok($zip->set_number('2206008')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(8階)');
ok($zip->set_number('2206009')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(9階)');
ok($zip->set_number('2206010')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(10階)');
ok($zip->set_number('2206011')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(11階)');
ok($zip->set_number('2206012')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(12階)');
ok($zip->set_number('2206013')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(13階)');
ok($zip->set_number('2206014')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(14階)');
ok($zip->set_number('2206015')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(15階)');
ok($zip->set_number('2206016')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(16階)');
ok($zip->set_number('2206017')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(17階)');
ok($zip->set_number('2206018')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(18階)');
ok($zip->set_number('2206019')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(19階)');
ok($zip->set_number('2206020')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(20階)');
ok($zip->set_number('2206021')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(21階)');
ok($zip->set_number('2206022')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(22階)');
ok($zip->set_number('2206023')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(23階)');
ok($zip->set_number('2206024')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(24階)');
ok($zip->set_number('2206025')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(25階)');
ok($zip->set_number('2206026')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(26階)');
ok($zip->set_number('2206027')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(27階)');
ok($zip->set_number('2206028')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(28階)');
ok($zip->set_number('2206029')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(29階)');
ok($zip->set_number('2206030')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(30階)');
ok($zip->set_number('2206031')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(31階)');
ok($zip->set_number('2206032')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(32階)');
ok($zip->set_number('2206033')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(33階)');
ok($zip->set_number('2206034')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(34階)');
ok($zip->set_number('2206035')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(35階)');
ok($zip->set_number('2206090')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーA(地階・階層不明)');
ok($zip->set_number('2206101')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(1階)');
ok($zip->set_number('2206102')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(2階)');
ok($zip->set_number('2206103')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(3階)');
ok($zip->set_number('2206104')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(4階)');
ok($zip->set_number('2206105')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(5階)');
ok($zip->set_number('2206106')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(6階)');
ok($zip->set_number('2206107')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(7階)');
ok($zip->set_number('2206108')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(8階)');
ok($zip->set_number('2206109')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(9階)');
ok($zip->set_number('2206110')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(10階)');
ok($zip->set_number('2206111')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(11階)');
ok($zip->set_number('2206112')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(12階)');
ok($zip->set_number('2206113')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(13階)');
ok($zip->set_number('2206114')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(14階)');
ok($zip->set_number('2206115')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(15階)');
ok($zip->set_number('2206116')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(16階)');
ok($zip->set_number('2206117')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(17階)');
ok($zip->set_number('2206118')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(18階)');
ok($zip->set_number('2206119')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(19階)');
ok($zip->set_number('2206120')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(20階)');
ok($zip->set_number('2206121')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(21階)');
ok($zip->set_number('2206122')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(22階)');
ok($zip->set_number('2206123')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(23階)');
ok($zip->set_number('2206124')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(24階)');
ok($zip->set_number('2206125')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(25階)');
ok($zip->set_number('2206126')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(26階)');
ok($zip->set_number('2206127')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(27階)');
ok($zip->set_number('2206128')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(28階)');
ok($zip->set_number('2206190')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーB(地階・階層不明)');
ok($zip->set_number('2206201')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(1階)');
ok($zip->set_number('2206202')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(2階)');
ok($zip->set_number('2206203')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(3階)');
ok($zip->set_number('2206204')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(4階)');
ok($zip->set_number('2206205')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(5階)');
ok($zip->set_number('2206206')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(6階)');
ok($zip->set_number('2206207')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(7階)');
ok($zip->set_number('2206208')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(8階)');
ok($zip->set_number('2206209')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(9階)');
ok($zip->set_number('2206210')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(10階)');
ok($zip->set_number('2206211')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(11階)');
ok($zip->set_number('2206212')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(12階)');
ok($zip->set_number('2206213')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(13階)');
ok($zip->set_number('2206214')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(14階)');
ok($zip->set_number('2206215')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(15階)');
ok($zip->set_number('2206216')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(16階)');
ok($zip->set_number('2206217')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(17階)');
ok($zip->set_number('2206218')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(18階)');
ok($zip->set_number('2206219')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(19階)');
ok($zip->set_number('2206220')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(20階)');
ok($zip->set_number('2206221')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(21階)');
ok($zip->set_number('2206290')->is_valid_number, '神奈川県横浜市西区みなとみらいクイーンズタワーC(地階・階層不明)');
ok($zip->set_number('2208101')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(1階)');
ok($zip->set_number('2208102')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(2階)');
ok($zip->set_number('2208103')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(3階)');
ok($zip->set_number('2208104')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(4階)');
ok($zip->set_number('2208105')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(5階)');
ok($zip->set_number('2208106')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(6階)');
ok($zip->set_number('2208107')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(7階)');
ok($zip->set_number('2208108')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(8階)');
ok($zip->set_number('2208109')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(9階)');
ok($zip->set_number('2208110')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(10階)');
ok($zip->set_number('2208111')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(11階)');
ok($zip->set_number('2208112')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(12階)');
ok($zip->set_number('2208113')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(13階)');
ok($zip->set_number('2208114')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(14階)');
ok($zip->set_number('2208115')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(15階)');
ok($zip->set_number('2208116')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(16階)');
ok($zip->set_number('2208117')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(17階)');
ok($zip->set_number('2208118')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(18階)');
ok($zip->set_number('2208119')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(19階)');
ok($zip->set_number('2208120')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(20階)');
ok($zip->set_number('2208121')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(21階)');
ok($zip->set_number('2208122')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(22階)');
ok($zip->set_number('2208123')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(23階)');
ok($zip->set_number('2208124')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(24階)');
ok($zip->set_number('2208125')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(25階)');
ok($zip->set_number('2208126')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(26階)');
ok($zip->set_number('2208127')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(27階)');
ok($zip->set_number('2208128')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(28階)');
ok($zip->set_number('2208129')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(29階)');
ok($zip->set_number('2208130')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(30階)');
ok($zip->set_number('2208131')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(31階)');
ok($zip->set_number('2208132')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(32階)');
ok($zip->set_number('2208133')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(33階)');
ok($zip->set_number('2208134')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(34階)');
ok($zip->set_number('2208135')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(35階)');
ok($zip->set_number('2208136')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(36階)');
ok($zip->set_number('2208137')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(37階)');
ok($zip->set_number('2208138')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(38階)');
ok($zip->set_number('2208139')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(39階)');
ok($zip->set_number('2208140')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(40階)');
ok($zip->set_number('2208141')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(41階)');
ok($zip->set_number('2208142')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(42階)');
ok($zip->set_number('2208143')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(43階)');
ok($zip->set_number('2208144')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(44階)');
ok($zip->set_number('2208145')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(45階)');
ok($zip->set_number('2208146')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(46階)');
ok($zip->set_number('2208147')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(47階)');
ok($zip->set_number('2208148')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(48階)');
ok($zip->set_number('2208149')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(49階)');
ok($zip->set_number('2208150')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(50階)');
ok($zip->set_number('2208151')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(51階)');
ok($zip->set_number('2208152')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(52階)');
ok($zip->set_number('2208153')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(53階)');
ok($zip->set_number('2208154')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(54階)');
ok($zip->set_number('2208155')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(55階)');
ok($zip->set_number('2208156')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(56階)');
ok($zip->set_number('2208157')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(57階)');
ok($zip->set_number('2208158')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(58階)');
ok($zip->set_number('2208159')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(59階)');
ok($zip->set_number('2208160')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(60階)');
ok($zip->set_number('2208161')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(61階)');
ok($zip->set_number('2208162')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(62階)');
ok($zip->set_number('2208163')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(63階)');
ok($zip->set_number('2208164')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(64階)');
ok($zip->set_number('2208165')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(65階)');
ok($zip->set_number('2208166')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(66階)');
ok($zip->set_number('2208167')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(67階)');
ok($zip->set_number('2208168')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(68階)');
ok($zip->set_number('2208169')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(69階)');
ok($zip->set_number('2208170')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(70階)');
ok($zip->set_number('2208190')->is_valid_number, '神奈川県横浜市西区みなとみらいランドマークタワー(地階・階層不明)');
ok($zip->set_number('2210000')->is_valid_number, '神奈川県横浜市神奈川区以下に掲載がない場合');
ok($zip->set_number('2210001')->is_valid_number, '神奈川県横浜市神奈川区西寺尾');
ok($zip->set_number('2210002')->is_valid_number, '神奈川県横浜市神奈川区大口通');
ok($zip->set_number('2210003')->is_valid_number, '神奈川県横浜市神奈川区大口仲町');
ok($zip->set_number('2210004')->is_valid_number, '神奈川県横浜市神奈川区西大口');
ok($zip->set_number('2210005')->is_valid_number, '神奈川県横浜市神奈川区松見町');
ok($zip->set_number('2210011')->is_valid_number, '神奈川県横浜市神奈川区神之木台');
ok($zip->set_number('2210012')->is_valid_number, '神奈川県横浜市神奈川区子安台');
ok($zip->set_number('2210013')->is_valid_number, '神奈川県横浜市神奈川区新子安');
ok($zip->set_number('2210014')->is_valid_number, '神奈川県横浜市神奈川区入江');
ok($zip->set_number('2210015')->is_valid_number, '神奈川県横浜市神奈川区神之木町');
ok($zip->set_number('2210021')->is_valid_number, '神奈川県横浜市神奈川区子安通');
ok($zip->set_number('2210022')->is_valid_number, '神奈川県横浜市神奈川区守屋町');
ok($zip->set_number('2210023')->is_valid_number, '神奈川県横浜市神奈川区宝町');
ok($zip->set_number('2210024')->is_valid_number, '神奈川県横浜市神奈川区恵比須町');
ok($zip->set_number('2210031')->is_valid_number, '神奈川県横浜市神奈川区新浦島町');
ok($zip->set_number('2210032')->is_valid_number, '神奈川県横浜市神奈川区出田町');
ok($zip->set_number('2210033')->is_valid_number, '神奈川県横浜市神奈川区鈴繁町');
ok($zip->set_number('2210034')->is_valid_number, '神奈川県横浜市神奈川区瑞穂町');
ok($zip->set_number('2210035')->is_valid_number, '神奈川県横浜市神奈川区星野町');
ok($zip->set_number('2210036')->is_valid_number, '神奈川県横浜市神奈川区千若町');
ok($zip->set_number('2210041')->is_valid_number, '神奈川県横浜市神奈川区亀住町');
ok($zip->set_number('2210042')->is_valid_number, '神奈川県横浜市神奈川区浦島町');
ok($zip->set_number('2210043')->is_valid_number, '神奈川県横浜市神奈川区新町');
ok($zip->set_number('2210044')->is_valid_number, '神奈川県横浜市神奈川区東神奈川');
ok($zip->set_number('2210045')->is_valid_number, '神奈川県横浜市神奈川区神奈川');
ok($zip->set_number('2210046')->is_valid_number, '神奈川県横浜市神奈川区神奈川本町');
ok($zip->set_number('2210051')->is_valid_number, '神奈川県横浜市神奈川区幸ケ谷');
ok($zip->set_number('2210052')->is_valid_number, '神奈川県横浜市神奈川区栄町');
ok($zip->set_number('2210053')->is_valid_number, '神奈川県横浜市神奈川区橋本町');
ok($zip->set_number('2210054')->is_valid_number, '神奈川県横浜市神奈川区山内町');
ok($zip->set_number('2210055')->is_valid_number, '神奈川県横浜市神奈川区大野町');
ok($zip->set_number('2210056')->is_valid_number, '神奈川県横浜市神奈川区金港町');
ok($zip->set_number('2210057')->is_valid_number, '神奈川県横浜市神奈川区青木町');
ok($zip->set_number('2210061')->is_valid_number, '神奈川県横浜市神奈川区七島町');
ok($zip->set_number('2210062')->is_valid_number, '神奈川県横浜市神奈川区浦島丘');
ok($zip->set_number('2210063')->is_valid_number, '神奈川県横浜市神奈川区立町');
ok($zip->set_number('2210064')->is_valid_number, '神奈川県横浜市神奈川区鳥越');
ok($zip->set_number('2210065')->is_valid_number, '神奈川県横浜市神奈川区白楽');
ok($zip->set_number('2210071')->is_valid_number, '神奈川県横浜市神奈川区白幡仲町');
ok($zip->set_number('2210072')->is_valid_number, '神奈川県横浜市神奈川区白幡東町');
ok($zip->set_number('2210073')->is_valid_number, '神奈川県横浜市神奈川区白幡南町');
ok($zip->set_number('2210074')->is_valid_number, '神奈川県横浜市神奈川区白幡西町');
ok($zip->set_number('2210075')->is_valid_number, '神奈川県横浜市神奈川区白幡上町');
ok($zip->set_number('2210076')->is_valid_number, '神奈川県横浜市神奈川区白幡町');
ok($zip->set_number('2210077')->is_valid_number, '神奈川県横浜市神奈川区白幡向町');
ok($zip->set_number('2210801')->is_valid_number, '神奈川県横浜市神奈川区神大寺');
ok($zip->set_number('2210802')->is_valid_number, '神奈川県横浜市神奈川区六角橋');
ok($zip->set_number('2210803')->is_valid_number, '神奈川県横浜市神奈川区中丸');
ok($zip->set_number('2210804')->is_valid_number, '神奈川県横浜市神奈川区栗田谷');
ok($zip->set_number('2210811')->is_valid_number, '神奈川県横浜市神奈川区斎藤分町');
ok($zip->set_number('2210812')->is_valid_number, '神奈川県横浜市神奈川区平川町');
ok($zip->set_number('2210813')->is_valid_number, '神奈川県横浜市神奈川区二本榎');
ok($zip->set_number('2210814')->is_valid_number, '神奈川県横浜市神奈川区旭ケ丘');
ok($zip->set_number('2210821')->is_valid_number, '神奈川県横浜市神奈川区富家町');
ok($zip->set_number('2210822')->is_valid_number, '神奈川県横浜市神奈川区西神奈川');
ok($zip->set_number('2210823')->is_valid_number, '神奈川県横浜市神奈川区二ツ谷町');
ok($zip->set_number('2210824')->is_valid_number, '神奈川県横浜市神奈川区広台太田町');
ok($zip->set_number('2210825')->is_valid_number, '神奈川県横浜市神奈川区反町');
ok($zip->set_number('2210831')->is_valid_number, '神奈川県横浜市神奈川区上反町');
ok($zip->set_number('2210832')->is_valid_number, '神奈川県横浜市神奈川区桐畑');
ok($zip->set_number('2210833')->is_valid_number, '神奈川県横浜市神奈川区高島台');
ok($zip->set_number('2210834')->is_valid_number, '神奈川県横浜市神奈川区台町');
ok($zip->set_number('2210835')->is_valid_number, '神奈川県横浜市神奈川区鶴屋町');
ok($zip->set_number('2210841')->is_valid_number, '神奈川県横浜市神奈川区松本町');
ok($zip->set_number('2210842')->is_valid_number, '神奈川県横浜市神奈川区泉町');
ok($zip->set_number('2210843')->is_valid_number, '神奈川県横浜市神奈川区松ケ丘');
ok($zip->set_number('2210844')->is_valid_number, '神奈川県横浜市神奈川区沢渡');
ok($zip->set_number('2210851')->is_valid_number, '神奈川県横浜市神奈川区三ツ沢中町');
ok($zip->set_number('2210852')->is_valid_number, '神奈川県横浜市神奈川区三ツ沢下町');
ok($zip->set_number('2210853')->is_valid_number, '神奈川県横浜市神奈川区三ツ沢東町');
ok($zip->set_number('2210854')->is_valid_number, '神奈川県横浜市神奈川区三ツ沢南町');
ok($zip->set_number('2210855')->is_valid_number, '神奈川県横浜市神奈川区三ツ沢西町');
ok($zip->set_number('2210856')->is_valid_number, '神奈川県横浜市神奈川区三ツ沢上町');
ok($zip->set_number('2210862')->is_valid_number, '神奈川県横浜市神奈川区三枚町');
ok($zip->set_number('2210863')->is_valid_number, '神奈川県横浜市神奈川区羽沢町');
ok($zip->set_number('2210864')->is_valid_number, '神奈川県横浜市神奈川区菅田町');
ok($zip->set_number('2210865')->is_valid_number, '神奈川県横浜市神奈川区片倉');
ok($zip->set_number('2210866')->is_valid_number, '神奈川県横浜市神奈川区羽沢南');
ok($zip->set_number('2220000')->is_valid_number, '神奈川県横浜市港北区以下に掲載がない場合');
ok($zip->set_number('2220001')->is_valid_number, '神奈川県横浜市港北区樽町');
ok($zip->set_number('2220002')->is_valid_number, '神奈川県横浜市港北区師岡町');
ok($zip->set_number('2220003')->is_valid_number, '神奈川県横浜市港北区大曽根');
ok($zip->set_number('2220004')->is_valid_number, '神奈川県横浜市港北区大曽根台');
ok($zip->set_number('2220011')->is_valid_number, '神奈川県横浜市港北区菊名');
ok($zip->set_number('2220012')->is_valid_number, '神奈川県横浜市港北区富士塚');
ok($zip->set_number('2220013')->is_valid_number, '神奈川県横浜市港北区錦が丘');
ok($zip->set_number('2220021')->is_valid_number, '神奈川県横浜市港北区篠原北');
ok($zip->set_number('2220022')->is_valid_number, '神奈川県横浜市港北区篠原東');
ok($zip->set_number('2220023')->is_valid_number, '神奈川県横浜市港北区仲手原');
ok($zip->set_number('2220024')->is_valid_number, '神奈川県横浜市港北区篠原台町');
ok($zip->set_number('2220025')->is_valid_number, '神奈川県横浜市港北区篠原西町');
ok($zip->set_number('2220026')->is_valid_number, '神奈川県横浜市港北区篠原町');
ok($zip->set_number('2220032')->is_valid_number, '神奈川県横浜市港北区大豆戸町');
ok($zip->set_number('2220033')->is_valid_number, '神奈川県横浜市港北区新横浜');
ok($zip->set_number('2220034')->is_valid_number, '神奈川県横浜市港北区岸根町');
ok($zip->set_number('2220035')->is_valid_number, '神奈川県横浜市港北区鳥山町');
ok($zip->set_number('2220036')->is_valid_number, '神奈川県横浜市港北区小机町');
ok($zip->set_number('2220037')->is_valid_number, '神奈川県横浜市港北区大倉山');
ok($zip->set_number('2230051')->is_valid_number, '神奈川県横浜市港北区箕輪町');
ok($zip->set_number('2230052')->is_valid_number, '神奈川県横浜市港北区綱島東');
ok($zip->set_number('2230053')->is_valid_number, '神奈川県横浜市港北区綱島西');
ok($zip->set_number('2230054')->is_valid_number, '神奈川県横浜市港北区綱島台');
ok($zip->set_number('2230055')->is_valid_number, '神奈川県横浜市港北区綱島上町');
ok($zip->set_number('2230056')->is_valid_number, '神奈川県横浜市港北区新吉田町');
ok($zip->set_number('2230057')->is_valid_number, '神奈川県横浜市港北区新羽町');
ok($zip->set_number('2230058')->is_valid_number, '神奈川県横浜市港北区新吉田東');
ok($zip->set_number('2230059')->is_valid_number, '神奈川県横浜市港北区北新横浜');
ok($zip->set_number('2230061')->is_valid_number, '神奈川県横浜市港北区日吉');
ok($zip->set_number('2230062')->is_valid_number, '神奈川県横浜市港北区日吉本町');
ok($zip->set_number('2230063')->is_valid_number, '神奈川県横浜市港北区高田町');
ok($zip->set_number('2230064')->is_valid_number, '神奈川県横浜市港北区下田町');
ok($zip->set_number('2230065')->is_valid_number, '神奈川県横浜市港北区高田東');
ok($zip->set_number('2230066')->is_valid_number, '神奈川県横浜市港北区高田西');
ok($zip->set_number('2240000')->is_valid_number, '神奈川県横浜市都筑区以下に掲載がない場合');
ok($zip->set_number('2240001')->is_valid_number, '神奈川県横浜市都筑区中川');
ok($zip->set_number('2240003')->is_valid_number, '神奈川県横浜市都筑区中川中央');
ok($zip->set_number('2240004')->is_valid_number, '神奈川県横浜市都筑区荏田東町');
ok($zip->set_number('2240006')->is_valid_number, '神奈川県横浜市都筑区荏田東');
ok($zip->set_number('2240007')->is_valid_number, '神奈川県横浜市都筑区荏田南');
ok($zip->set_number('2240008')->is_valid_number, '神奈川県横浜市都筑区荏田南町');
ok($zip->set_number('2240011')->is_valid_number, '神奈川県横浜市都筑区牛久保町');
ok($zip->set_number('2240012')->is_valid_number, '神奈川県横浜市都筑区牛久保');
ok($zip->set_number('2240013')->is_valid_number, '神奈川県横浜市都筑区すみれが丘');
ok($zip->set_number('2240014')->is_valid_number, '神奈川県横浜市都筑区牛久保東');
ok($zip->set_number('2240015')->is_valid_number, '神奈川県横浜市都筑区牛久保西');
ok($zip->set_number('2240016')->is_valid_number, '神奈川県横浜市都筑区あゆみが丘');
ok($zip->set_number('2240021')->is_valid_number, '神奈川県横浜市都筑区北山田');
ok($zip->set_number('2240023')->is_valid_number, '神奈川県横浜市都筑区東山田');
ok($zip->set_number('2240024')->is_valid_number, '神奈川県横浜市都筑区東山田町');
ok($zip->set_number('2240025')->is_valid_number, '神奈川県横浜市都筑区早渕');
ok($zip->set_number('2240026')->is_valid_number, '神奈川県横浜市都筑区南山田町');
ok($zip->set_number('2240027')->is_valid_number, '神奈川県横浜市都筑区大棚町');
ok($zip->set_number('2240028')->is_valid_number, '神奈川県横浜市都筑区大棚西');
ok($zip->set_number('2240029')->is_valid_number, '神奈川県横浜市都筑区南山田');
ok($zip->set_number('2240031')->is_valid_number, '神奈川県横浜市都筑区茅ケ崎町');
ok($zip->set_number('2240032')->is_valid_number, '神奈川県横浜市都筑区茅ケ崎中央');
ok($zip->set_number('2240033')->is_valid_number, '神奈川県横浜市都筑区茅ケ崎東');
ok($zip->set_number('2240034')->is_valid_number, '神奈川県横浜市都筑区勝田町');
ok($zip->set_number('2240035')->is_valid_number, '神奈川県横浜市都筑区新栄町');
ok($zip->set_number('2240036')->is_valid_number, '神奈川県横浜市都筑区勝田南');
ok($zip->set_number('2240037')->is_valid_number, '神奈川県横浜市都筑区茅ケ崎南');
ok($zip->set_number('2240041')->is_valid_number, '神奈川県横浜市都筑区仲町台');
ok($zip->set_number('2240042')->is_valid_number, '神奈川県横浜市都筑区大熊町');
ok($zip->set_number('2240043')->is_valid_number, '神奈川県横浜市都筑区折本町');
ok($zip->set_number('2240044')->is_valid_number, '神奈川県横浜市都筑区川向町');
ok($zip->set_number('2240045')->is_valid_number, '神奈川県横浜市都筑区東方町');
ok($zip->set_number('2240046')->is_valid_number, '神奈川県横浜市都筑区桜並木');
ok($zip->set_number('2240051')->is_valid_number, '神奈川県横浜市都筑区富士見が丘');
ok($zip->set_number('2240052')->is_valid_number, '神奈川県横浜市都筑区二の丸');
ok($zip->set_number('2240053')->is_valid_number, '神奈川県横浜市都筑区池辺町');
ok($zip->set_number('2240054')->is_valid_number, '神奈川県横浜市都筑区佐江戸町');
ok($zip->set_number('2240055')->is_valid_number, '神奈川県横浜市都筑区加賀原');
ok($zip->set_number('2240056')->is_valid_number, '神奈川県横浜市都筑区川和台');
ok($zip->set_number('2240057')->is_valid_number, '神奈川県横浜市都筑区川和町');
ok($zip->set_number('2240061')->is_valid_number, '神奈川県横浜市都筑区大丸');
ok($zip->set_number('2240062')->is_valid_number, '神奈川県横浜市都筑区葛が谷');
ok($zip->set_number('2240063')->is_valid_number, '神奈川県横浜市都筑区長坂');
ok($zip->set_number('2240064')->is_valid_number, '神奈川県横浜市都筑区平台');
ok($zip->set_number('2240065')->is_valid_number, '神奈川県横浜市都筑区高山');
ok($zip->set_number('2240066')->is_valid_number, '神奈川県横浜市都筑区見花山');
ok($zip->set_number('2250001')->is_valid_number, '神奈川県横浜市青葉区美しが丘西');
ok($zip->set_number('2250002')->is_valid_number, '神奈川県横浜市青葉区美しが丘');
ok($zip->set_number('2250003')->is_valid_number, '神奈川県横浜市青葉区新石川');
ok($zip->set_number('2250004')->is_valid_number, '神奈川県横浜市青葉区元石川町');
ok($zip->set_number('2250005')->is_valid_number, '神奈川県横浜市青葉区荏子田');
ok($zip->set_number('2250011')->is_valid_number, '神奈川県横浜市青葉区あざみ野');
ok($zip->set_number('2250012')->is_valid_number, '神奈川県横浜市青葉区あざみ野南');
ok($zip->set_number('2250013')->is_valid_number, '神奈川県横浜市青葉区荏田町');
ok($zip->set_number('2250014')->is_valid_number, '神奈川県横浜市青葉区荏田西');
ok($zip->set_number('2250015')->is_valid_number, '神奈川県横浜市青葉区荏田北');
ok($zip->set_number('2250016')->is_valid_number, '神奈川県横浜市青葉区みすずが丘');
ok($zip->set_number('2250021')->is_valid_number, '神奈川県横浜市青葉区すすき野');
ok($zip->set_number('2250022')->is_valid_number, '神奈川県横浜市青葉区黒須田');
ok($zip->set_number('2250023')->is_valid_number, '神奈川県横浜市青葉区大場町');
ok($zip->set_number('2250024')->is_valid_number, '神奈川県横浜市青葉区市ケ尾町');
ok($zip->set_number('2250025')->is_valid_number, '神奈川県横浜市青葉区鉄町');
ok($zip->set_number('2250026')->is_valid_number, '神奈川県横浜市青葉区もみの木台');
ok($zip->set_number('2260000')->is_valid_number, '神奈川県横浜市緑区以下に掲載がない場合');
ok($zip->set_number('2260001')->is_valid_number, '神奈川県横浜市緑区東本郷町');
ok($zip->set_number('2260002')->is_valid_number, '神奈川県横浜市緑区東本郷');
ok($zip->set_number('2260003')->is_valid_number, '神奈川県横浜市緑区鴨居');
ok($zip->set_number('2260004')->is_valid_number, '神奈川県横浜市緑区鴨居町');
ok($zip->set_number('2260005')->is_valid_number, '神奈川県横浜市緑区竹山');
ok($zip->set_number('2260006')->is_valid_number, '神奈川県横浜市緑区白山');
ok($zip->set_number('2260012')->is_valid_number, '神奈川県横浜市緑区上山');
ok($zip->set_number('2260013')->is_valid_number, '神奈川県横浜市緑区寺山町');
ok($zip->set_number('2260014')->is_valid_number, '神奈川県横浜市緑区台村町');
ok($zip->set_number('2260015')->is_valid_number, '神奈川県横浜市緑区三保町');
ok($zip->set_number('2260016')->is_valid_number, '神奈川県横浜市緑区霧が丘');
ok($zip->set_number('2260017')->is_valid_number, '神奈川県横浜市緑区新治町');
ok($zip->set_number('2260018')->is_valid_number, '神奈川県横浜市緑区長津田みなみ台');
ok($zip->set_number('2260019')->is_valid_number, '神奈川県横浜市緑区中山');
ok($zip->set_number('2260021')->is_valid_number, '神奈川県横浜市緑区北八朔町');
ok($zip->set_number('2260022')->is_valid_number, '神奈川県横浜市緑区青砥町');
ok($zip->set_number('2260023')->is_valid_number, '神奈川県横浜市緑区小山町');
ok($zip->set_number('2260024')->is_valid_number, '神奈川県横浜市緑区西八朔町');
ok($zip->set_number('2260025')->is_valid_number, '神奈川県横浜市緑区十日市場町');
ok($zip->set_number('2260026')->is_valid_number, '神奈川県横浜市緑区長津田町');
ok($zip->set_number('2260027')->is_valid_number, '神奈川県横浜市緑区長津田');
ok($zip->set_number('2260028')->is_valid_number, '神奈川県横浜市緑区いぶき野');
ok($zip->set_number('2260029')->is_valid_number, '神奈川県横浜市緑区森の台');
ok($zip->set_number('2270000')->is_valid_number, '神奈川県横浜市青葉区以下に掲載がない場合');
ok($zip->set_number('2270031')->is_valid_number, '神奈川県横浜市青葉区寺家町');
ok($zip->set_number('2270032')->is_valid_number, '神奈川県横浜市青葉区成合町');
ok($zip->set_number('2270033')->is_valid_number, '神奈川県横浜市青葉区鴨志田町');
ok($zip->set_number('2270034')->is_valid_number, '神奈川県横浜市青葉区桂台');
ok($zip->set_number('2270035')->is_valid_number, '神奈川県横浜市青葉区すみよし台');
ok($zip->set_number('2270036')->is_valid_number, '神奈川県横浜市青葉区奈良町');
ok($zip->set_number('2270037')->is_valid_number, '神奈川県横浜市青葉区緑山');
ok($zip->set_number('2270038')->is_valid_number, '神奈川県横浜市青葉区奈良');
ok($zip->set_number('2270041')->is_valid_number, '神奈川県横浜市青葉区上谷本町');
ok($zip->set_number('2270042')->is_valid_number, '神奈川県横浜市青葉区下谷本町');
ok($zip->set_number('2270043')->is_valid_number, '神奈川県横浜市青葉区藤が丘');
ok($zip->set_number('2270044')->is_valid_number, '神奈川県横浜市青葉区もえぎ野');
ok($zip->set_number('2270045')->is_valid_number, '神奈川県横浜市青葉区若草台');
ok($zip->set_number('2270046')->is_valid_number, '神奈川県横浜市青葉区たちばな台');
ok($zip->set_number('2270047')->is_valid_number, '神奈川県横浜市青葉区みたけ台');
ok($zip->set_number('2270048')->is_valid_number, '神奈川県横浜市青葉区柿の木台');
ok($zip->set_number('2270051')->is_valid_number, '神奈川県横浜市青葉区千草台');
ok($zip->set_number('2270052')->is_valid_number, '神奈川県横浜市青葉区梅が丘');
ok($zip->set_number('2270053')->is_valid_number, '神奈川県横浜市青葉区さつきが丘');
ok($zip->set_number('2270054')->is_valid_number, '神奈川県横浜市青葉区しらとり台');
ok($zip->set_number('2270055')->is_valid_number, '神奈川県横浜市青葉区つつじが丘');
ok($zip->set_number('2270061')->is_valid_number, '神奈川県横浜市青葉区桜台');
ok($zip->set_number('2270062')->is_valid_number, '神奈川県横浜市青葉区青葉台');
ok($zip->set_number('2270063')->is_valid_number, '神奈川県横浜市青葉区榎が丘');
ok($zip->set_number('2270064')->is_valid_number, '神奈川県横浜市青葉区田奈町');
ok($zip->set_number('2270065')->is_valid_number, '神奈川県横浜市青葉区恩田町');
ok($zip->set_number('2270066')->is_valid_number, '神奈川県横浜市青葉区あかね台');
ok($zip->set_number('2270067')->is_valid_number, '神奈川県横浜市青葉区松風台');
ok($zip->set_number('2300000')->is_valid_number, '神奈川県横浜市鶴見区以下に掲載がない場合');
ok($zip->set_number('2300001')->is_valid_number, '神奈川県横浜市鶴見区矢向');
ok($zip->set_number('2300002')->is_valid_number, '神奈川県横浜市鶴見区江ケ崎町');
ok($zip->set_number('2300003')->is_valid_number, '神奈川県横浜市鶴見区尻手');
ok($zip->set_number('2300004')->is_valid_number, '神奈川県横浜市鶴見区元宮');
ok($zip->set_number('2300011')->is_valid_number, '神奈川県横浜市鶴見区上末吉');
ok($zip->set_number('2300012')->is_valid_number, '神奈川県横浜市鶴見区下末吉');
ok($zip->set_number('2300013')->is_valid_number, '神奈川県横浜市鶴見区三ツ池公園');
ok($zip->set_number('2300014')->is_valid_number, '神奈川県横浜市鶴見区諏訪坂');
ok($zip->set_number('2300015')->is_valid_number, '神奈川県横浜市鶴見区寺谷');
ok($zip->set_number('2300016')->is_valid_number, '神奈川県横浜市鶴見区東寺尾北台');
ok($zip->set_number('2300017')->is_valid_number, '神奈川県横浜市鶴見区東寺尾中台');
ok($zip->set_number('2300018')->is_valid_number, '神奈川県横浜市鶴見区東寺尾東台');
ok($zip->set_number('2300021')->is_valid_number, '神奈川県横浜市鶴見区市場上町');
ok($zip->set_number('2300022')->is_valid_number, '神奈川県横浜市鶴見区市場東中町');
ok($zip->set_number('2300023')->is_valid_number, '神奈川県横浜市鶴見区市場西中町');
ok($zip->set_number('2300024')->is_valid_number, '神奈川県横浜市鶴見区市場下町');
ok($zip->set_number('2300025')->is_valid_number, '神奈川県横浜市鶴見区市場大和町');
ok($zip->set_number('2300026')->is_valid_number, '神奈川県横浜市鶴見区市場富士見町');
ok($zip->set_number('2300027')->is_valid_number, '神奈川県横浜市鶴見区菅沢町');
ok($zip->set_number('2300031')->is_valid_number, '神奈川県横浜市鶴見区平安町');
ok($zip->set_number('2300032')->is_valid_number, '神奈川県横浜市鶴見区大東町');
ok($zip->set_number('2300033')->is_valid_number, '神奈川県横浜市鶴見区朝日町');
ok($zip->set_number('2300034')->is_valid_number, '神奈川県横浜市鶴見区寛政町');
ok($zip->set_number('2300035')->is_valid_number, '神奈川県横浜市鶴見区安善町');
ok($zip->set_number('2300036')->is_valid_number, '神奈川県横浜市鶴見区浜町');
ok($zip->set_number('2300037')->is_valid_number, '神奈川県横浜市鶴見区向井町');
ok($zip->set_number('2300038')->is_valid_number, '神奈川県横浜市鶴見区栄町通');
ok($zip->set_number('2300041')->is_valid_number, '神奈川県横浜市鶴見区潮田町');
ok($zip->set_number('2300042')->is_valid_number, '神奈川県横浜市鶴見区仲通');
ok($zip->set_number('2300043')->is_valid_number, '神奈川県横浜市鶴見区汐入町');
ok($zip->set_number('2300044')->is_valid_number, '神奈川県横浜市鶴見区弁天町');
ok($zip->set_number('2300045')->is_valid_number, '神奈川県横浜市鶴見区末広町');
ok($zip->set_number('2300046')->is_valid_number, '神奈川県横浜市鶴見区小野町');
ok($zip->set_number('2300047')->is_valid_number, '神奈川県横浜市鶴見区下野谷町');
ok($zip->set_number('2300048')->is_valid_number, '神奈川県横浜市鶴見区本町通');
ok($zip->set_number('2300051')->is_valid_number, '神奈川県横浜市鶴見区鶴見中央');
ok($zip->set_number('2300052')->is_valid_number, '神奈川県横浜市鶴見区生麦');
ok($zip->set_number('2300053')->is_valid_number, '神奈川県横浜市鶴見区大黒町');
ok($zip->set_number('2300054')->is_valid_number, '神奈川県横浜市鶴見区大黒ふ頭');
ok($zip->set_number('2300055')->is_valid_number, '神奈川県横浜市鶴見区扇島');
ok($zip->set_number('2300061')->is_valid_number, '神奈川県横浜市鶴見区佃野町');
ok($zip->set_number('2300062')->is_valid_number, '神奈川県横浜市鶴見区豊岡町');
ok($zip->set_number('2300063')->is_valid_number, '神奈川県横浜市鶴見区鶴見');
ok($zip->set_number('2300071')->is_valid_number, '神奈川県横浜市鶴見区駒岡');
ok($zip->set_number('2300072')->is_valid_number, '神奈川県横浜市鶴見区梶山');
ok($zip->set_number('2300073')->is_valid_number, '神奈川県横浜市鶴見区獅子ケ谷');
ok($zip->set_number('2300074')->is_valid_number, '神奈川県横浜市鶴見区北寺尾');
ok($zip->set_number('2300075')->is_valid_number, '神奈川県横浜市鶴見区上の宮');
ok($zip->set_number('2300076')->is_valid_number, '神奈川県横浜市鶴見区馬場');
ok($zip->set_number('2300077')->is_valid_number, '神奈川県横浜市鶴見区東寺尾');
ok($zip->set_number('2300078')->is_valid_number, '神奈川県横浜市鶴見区岸谷');
ok($zip->set_number('2310000')->is_valid_number, '神奈川県横浜市中区以下に掲載がない場合');
ok($zip->set_number('2310001')->is_valid_number, '神奈川県横浜市中区新港');
ok($zip->set_number('2310002')->is_valid_number, '神奈川県横浜市中区海岸通');
ok($zip->set_number('2310003')->is_valid_number, '神奈川県横浜市中区北仲通');
ok($zip->set_number('2310004')->is_valid_number, '神奈川県横浜市中区元浜町');
ok($zip->set_number('2310005')->is_valid_number, '神奈川県横浜市中区本町');
ok($zip->set_number('2310006')->is_valid_number, '神奈川県横浜市中区南仲通');
ok($zip->set_number('2310007')->is_valid_number, '神奈川県横浜市中区弁天通');
ok($zip->set_number('2310011')->is_valid_number, '神奈川県横浜市中区太田町');
ok($zip->set_number('2310012')->is_valid_number, '神奈川県横浜市中区相生町');
ok($zip->set_number('2310013')->is_valid_number, '神奈川県横浜市中区住吉町');
ok($zip->set_number('2310014')->is_valid_number, '神奈川県横浜市中区常盤町');
ok($zip->set_number('2310015')->is_valid_number, '神奈川県横浜市中区尾上町');
ok($zip->set_number('2310016')->is_valid_number, '神奈川県横浜市中区真砂町');
ok($zip->set_number('2310017')->is_valid_number, '神奈川県横浜市中区港町');
ok($zip->set_number('2310021')->is_valid_number, '神奈川県横浜市中区日本大通');
ok($zip->set_number('2310022')->is_valid_number, '神奈川県横浜市中区横浜公園');
ok($zip->set_number('2310023')->is_valid_number, '神奈川県横浜市中区山下町');
ok($zip->set_number('2310024')->is_valid_number, '神奈川県横浜市中区吉浜町');
ok($zip->set_number('2310025')->is_valid_number, '神奈川県横浜市中区松影町');
ok($zip->set_number('2310026')->is_valid_number, '神奈川県横浜市中区寿町');
ok($zip->set_number('2310027')->is_valid_number, '神奈川県横浜市中区扇町');
ok($zip->set_number('2310028')->is_valid_number, '神奈川県横浜市中区翁町');
ok($zip->set_number('2310031')->is_valid_number, '神奈川県横浜市中区万代町');
ok($zip->set_number('2310032')->is_valid_number, '神奈川県横浜市中区不老町');
ok($zip->set_number('2310033')->is_valid_number, '神奈川県横浜市中区長者町');
ok($zip->set_number('2310034')->is_valid_number, '神奈川県横浜市中区三吉町');
ok($zip->set_number('2310035')->is_valid_number, '神奈川県横浜市中区千歳町');
ok($zip->set_number('2310036')->is_valid_number, '神奈川県横浜市中区山田町');
ok($zip->set_number('2310037')->is_valid_number, '神奈川県横浜市中区富士見町');
ok($zip->set_number('2310038')->is_valid_number, '神奈川県横浜市中区山吹町');
ok($zip->set_number('2310041')->is_valid_number, '神奈川県横浜市中区吉田町');
ok($zip->set_number('2310042')->is_valid_number, '神奈川県横浜市中区福富町西通');
ok($zip->set_number('2310043')->is_valid_number, '神奈川県横浜市中区福富町仲通');
ok($zip->set_number('2310044')->is_valid_number, '神奈川県横浜市中区福富町東通');
ok($zip->set_number('2310045')->is_valid_number, '神奈川県横浜市中区伊勢佐木町');
ok($zip->set_number('2310046')->is_valid_number, '神奈川県横浜市中区末広町');
ok($zip->set_number('2310047')->is_valid_number, '神奈川県横浜市中区羽衣町');
ok($zip->set_number('2310048')->is_valid_number, '神奈川県横浜市中区蓬莱町');
ok($zip->set_number('2310051')->is_valid_number, '神奈川県横浜市中区赤門町');
ok($zip->set_number('2310052')->is_valid_number, '神奈川県横浜市中区英町');
ok($zip->set_number('2310053')->is_valid_number, '神奈川県横浜市中区初音町');
ok($zip->set_number('2310054')->is_valid_number, '神奈川県横浜市中区黄金町');
ok($zip->set_number('2310055')->is_valid_number, '神奈川県横浜市中区末吉町');
ok($zip->set_number('2310056')->is_valid_number, '神奈川県横浜市中区若葉町');
ok($zip->set_number('2310057')->is_valid_number, '神奈川県横浜市中区曙町');
ok($zip->set_number('2310058')->is_valid_number, '神奈川県横浜市中区弥生町');
ok($zip->set_number('2310061')->is_valid_number, '神奈川県横浜市中区内田町');
ok($zip->set_number('2310062')->is_valid_number, '神奈川県横浜市中区桜木町');
ok($zip->set_number('2310063')->is_valid_number, '神奈川県横浜市中区花咲町');
ok($zip->set_number('2310064')->is_valid_number, '神奈川県横浜市中区野毛町');
ok($zip->set_number('2310065')->is_valid_number, '神奈川県横浜市中区宮川町');
ok($zip->set_number('2310066')->is_valid_number, '神奈川県横浜市中区日ノ出町');
ok($zip->set_number('2310801')->is_valid_number, '神奈川県横浜市中区新山下');
ok($zip->set_number('2310802')->is_valid_number, '神奈川県横浜市中区小港町');
ok($zip->set_number('2310803')->is_valid_number, '神奈川県横浜市中区本牧十二天');
ok($zip->set_number('2310804')->is_valid_number, '神奈川県横浜市中区本牧宮原');
ok($zip->set_number('2310805')->is_valid_number, '神奈川県横浜市中区和田山');
ok($zip->set_number('2310806')->is_valid_number, '神奈川県横浜市中区本牧町');
ok($zip->set_number('2310811')->is_valid_number, '神奈川県横浜市中区本牧ふ頭');
ok($zip->set_number('2310812')->is_valid_number, '神奈川県横浜市中区錦町');
ok($zip->set_number('2310813')->is_valid_number, '神奈川県横浜市中区かもめ町');
ok($zip->set_number('2310814')->is_valid_number, '神奈川県横浜市中区豊浦町');
ok($zip->set_number('2310815')->is_valid_number, '神奈川県横浜市中区千鳥町');
ok($zip->set_number('2310816')->is_valid_number, '神奈川県横浜市中区南本牧');
ok($zip->set_number('2310821')->is_valid_number, '神奈川県横浜市中区本牧原');
ok($zip->set_number('2310822')->is_valid_number, '神奈川県横浜市中区本牧元町');
ok($zip->set_number('2310823')->is_valid_number, '神奈川県横浜市中区本牧大里町');
ok($zip->set_number('2310824')->is_valid_number, '神奈川県横浜市中区本牧三之谷');
ok($zip->set_number('2310825')->is_valid_number, '神奈川県横浜市中区本牧間門');
ok($zip->set_number('2310826')->is_valid_number, '神奈川県横浜市中区本牧荒井');
ok($zip->set_number('2310827')->is_valid_number, '神奈川県横浜市中区本牧和田');
ok($zip->set_number('2310831')->is_valid_number, '神奈川県横浜市中区矢口台');
ok($zip->set_number('2310832')->is_valid_number, '神奈川県横浜市中区本牧緑ケ丘');
ok($zip->set_number('2310833')->is_valid_number, '神奈川県横浜市中区本牧満坂');
ok($zip->set_number('2310834')->is_valid_number, '神奈川県横浜市中区池袋');
ok($zip->set_number('2310835')->is_valid_number, '神奈川県横浜市中区根岸加曽台');
ok($zip->set_number('2310836')->is_valid_number, '神奈川県横浜市中区根岸町');
ok($zip->set_number('2310837')->is_valid_number, '神奈川県横浜市中区滝之上');
ok($zip->set_number('2310838')->is_valid_number, '神奈川県横浜市中区豆口台');
ok($zip->set_number('2310839')->is_valid_number, '神奈川県横浜市中区仲尾台');
ok($zip->set_number('2310841')->is_valid_number, '神奈川県横浜市中区妙香寺台');
ok($zip->set_number('2310842')->is_valid_number, '神奈川県横浜市中区上野町');
ok($zip->set_number('2310843')->is_valid_number, '神奈川県横浜市中区本郷町');
ok($zip->set_number('2310844')->is_valid_number, '神奈川県横浜市中区西之谷町');
ok($zip->set_number('2310845')->is_valid_number, '神奈川県横浜市中区立野');
ok($zip->set_number('2310846')->is_valid_number, '神奈川県横浜市中区大和町');
ok($zip->set_number('2310847')->is_valid_number, '神奈川県横浜市中区竹之丸');
ok($zip->set_number('2310848')->is_valid_number, '神奈川県横浜市中区鷺山');
ok($zip->set_number('2310849')->is_valid_number, '神奈川県横浜市中区麦田町');
ok($zip->set_number('2310851')->is_valid_number, '神奈川県横浜市中区山元町');
ok($zip->set_number('2310852')->is_valid_number, '神奈川県横浜市中区西竹之丸');
ok($zip->set_number('2310853')->is_valid_number, '神奈川県横浜市中区根岸台');
ok($zip->set_number('2310854')->is_valid_number, '神奈川県横浜市中区根岸旭台');
ok($zip->set_number('2310855')->is_valid_number, '神奈川県横浜市中区寺久保');
ok($zip->set_number('2310856')->is_valid_number, '神奈川県横浜市中区簑沢');
ok($zip->set_number('2310857')->is_valid_number, '神奈川県横浜市中区塚越');
ok($zip->set_number('2310858')->is_valid_number, '神奈川県横浜市中区大芝台');
ok($zip->set_number('2310859')->is_valid_number, '神奈川県横浜市中区大平町');
ok($zip->set_number('2310861')->is_valid_number, '神奈川県横浜市中区元町');
ok($zip->set_number('2310862')->is_valid_number, '神奈川県横浜市中区山手町');
ok($zip->set_number('2310863')->is_valid_number, '神奈川県横浜市中区諏訪町');
ok($zip->set_number('2310864')->is_valid_number, '神奈川県横浜市中区千代崎町');
ok($zip->set_number('2310865')->is_valid_number, '神奈川県横浜市中区北方町');
ok($zip->set_number('2310866')->is_valid_number, '神奈川県横浜市中区柏葉');
ok($zip->set_number('2310867')->is_valid_number, '神奈川県横浜市中区打越');
ok($zip->set_number('2310868')->is_valid_number, '神奈川県横浜市中区石川町');
ok($zip->set_number('2320000')->is_valid_number, '神奈川県横浜市南区以下に掲載がない場合');
ok($zip->set_number('2320001')->is_valid_number, '神奈川県横浜市南区伏見町');
ok($zip->set_number('2320002')->is_valid_number, '神奈川県横浜市南区三春台');
ok($zip->set_number('2320003')->is_valid_number, '神奈川県横浜市南区西中町');
ok($zip->set_number('2320004')->is_valid_number, '神奈川県横浜市南区前里町');
ok($zip->set_number('2320005')->is_valid_number, '神奈川県横浜市南区白金町');
ok($zip->set_number('2320006')->is_valid_number, '神奈川県横浜市南区南太田');
ok($zip->set_number('2320007')->is_valid_number, '神奈川県横浜市南区清水ケ丘');
ok($zip->set_number('2320008')->is_valid_number, '神奈川県横浜市南区庚台');
ok($zip->set_number('2320011')->is_valid_number, '神奈川県横浜市南区日枝町');
ok($zip->set_number('2320012')->is_valid_number, '神奈川県横浜市南区南吉田町');
ok($zip->set_number('2320013')->is_valid_number, '神奈川県横浜市南区山王町');
ok($zip->set_number('2320014')->is_valid_number, '神奈川県横浜市南区吉野町');
ok($zip->set_number('2320015')->is_valid_number, '神奈川県横浜市南区共進町');
ok($zip->set_number('2320016')->is_valid_number, '神奈川県横浜市南区宮元町');
ok($zip->set_number('2320017')->is_valid_number, '神奈川県横浜市南区宿町');
ok($zip->set_number('2320018')->is_valid_number, '神奈川県横浜市南区花之木町');
ok($zip->set_number('2320021')->is_valid_number, '神奈川県横浜市南区真金町');
ok($zip->set_number('2320022')->is_valid_number, '神奈川県横浜市南区高根町');
ok($zip->set_number('2320023')->is_valid_number, '神奈川県横浜市南区白妙町');
ok($zip->set_number('2320024')->is_valid_number, '神奈川県横浜市南区浦舟町');
ok($zip->set_number('2320025')->is_valid_number, '神奈川県横浜市南区高砂町');
ok($zip->set_number('2320026')->is_valid_number, '神奈川県横浜市南区二葉町');
ok($zip->set_number('2320027')->is_valid_number, '神奈川県横浜市南区新川町');
ok($zip->set_number('2320031')->is_valid_number, '神奈川県横浜市南区永楽町');
ok($zip->set_number('2320032')->is_valid_number, '神奈川県横浜市南区万世町');
ok($zip->set_number('2320033')->is_valid_number, '神奈川県横浜市南区中村町');
ok($zip->set_number('2320034')->is_valid_number, '神奈川県横浜市南区唐沢');
ok($zip->set_number('2320035')->is_valid_number, '神奈川県横浜市南区平楽');
ok($zip->set_number('2320036')->is_valid_number, '神奈川県横浜市南区山谷');
ok($zip->set_number('2320037')->is_valid_number, '神奈川県横浜市南区八幡町');
ok($zip->set_number('2320041')->is_valid_number, '神奈川県横浜市南区睦町');
ok($zip->set_number('2320042')->is_valid_number, '神奈川県横浜市南区堀ノ内町');
ok($zip->set_number('2320043')->is_valid_number, '神奈川県横浜市南区蒔田町');
ok($zip->set_number('2320044')->is_valid_number, '神奈川県横浜市南区榎町');
ok($zip->set_number('2320045')->is_valid_number, '神奈川県横浜市南区東蒔田町');
ok($zip->set_number('2320051')->is_valid_number, '神奈川県横浜市南区井土ケ谷上町');
ok($zip->set_number('2320052')->is_valid_number, '神奈川県横浜市南区井土ケ谷中町');
ok($zip->set_number('2320053')->is_valid_number, '神奈川県横浜市南区井土ケ谷下町');
ok($zip->set_number('2320054')->is_valid_number, '神奈川県横浜市南区大橋町');
ok($zip->set_number('2320055')->is_valid_number, '神奈川県横浜市南区中島町');
ok($zip->set_number('2320056')->is_valid_number, '神奈川県横浜市南区通町');
ok($zip->set_number('2320057')->is_valid_number, '神奈川県横浜市南区若宮町');
ok($zip->set_number('2320061')->is_valid_number, '神奈川県横浜市南区大岡');
ok($zip->set_number('2320062')->is_valid_number, '神奈川県横浜市南区中里町');
ok($zip->set_number('2320063')->is_valid_number, '神奈川県横浜市南区中里');
ok($zip->set_number('2320064')->is_valid_number, '神奈川県横浜市南区別所');
ok($zip->set_number('2320065')->is_valid_number, '神奈川県横浜市南区別所中里台');
ok($zip->set_number('2320066')->is_valid_number, '神奈川県横浜市南区六ツ川');
ok($zip->set_number('2320067')->is_valid_number, '神奈川県横浜市南区弘明寺町');
ok($zip->set_number('2320071')->is_valid_number, '神奈川県横浜市南区永田北');
ok($zip->set_number('2320072')->is_valid_number, '神奈川県横浜市南区永田東');
ok($zip->set_number('2320073')->is_valid_number, '神奈川県横浜市南区永田南');
ok($zip->set_number('2320074')->is_valid_number, '神奈川県横浜市南区永田山王台');
ok($zip->set_number('2320075')->is_valid_number, '神奈川県横浜市南区永田みなみ台');
ok($zip->set_number('2320076')->is_valid_number, '神奈川県横浜市南区永田台');
ok($zip->set_number('2330000')->is_valid_number, '神奈川県横浜市港南区以下に掲載がない場合');
ok($zip->set_number('2330001')->is_valid_number, '神奈川県横浜市港南区上大岡東');
ok($zip->set_number('2330002')->is_valid_number, '神奈川県横浜市港南区上大岡西');
ok($zip->set_number('2330003')->is_valid_number, '神奈川県横浜市港南区港南');
ok($zip->set_number('2330004')->is_valid_number, '神奈川県横浜市港南区港南中央通');
ok($zip->set_number('2330005')->is_valid_number, '神奈川県横浜市港南区東芹が谷');
ok($zip->set_number('2330006')->is_valid_number, '神奈川県横浜市港南区芹が谷');
ok($zip->set_number('2330007')->is_valid_number, '神奈川県横浜市港南区大久保');
ok($zip->set_number('2330008')->is_valid_number, '神奈川県横浜市港南区最戸');
ok($zip->set_number('2330011')->is_valid_number, '神奈川県横浜市港南区東永谷');
ok($zip->set_number('2330012')->is_valid_number, '神奈川県横浜市港南区上永谷');
ok($zip->set_number('2330013')->is_valid_number, '神奈川県横浜市港南区丸山台');
ok($zip->set_number('2330014')->is_valid_number, '神奈川県横浜市港南区上永谷町');
ok($zip->set_number('2330015')->is_valid_number, '神奈川県横浜市港南区日限山');
ok($zip->set_number('2330016')->is_valid_number, '神奈川県横浜市港南区下永谷');
ok($zip->set_number('2340051')->is_valid_number, '神奈川県横浜市港南区日野');
ok($zip->set_number('2340052')->is_valid_number, '神奈川県横浜市港南区笹下');
ok($zip->set_number('2340053')->is_valid_number, '神奈川県横浜市港南区日野中央');
ok($zip->set_number('2340054')->is_valid_number, '神奈川県横浜市港南区港南台');
ok($zip->set_number('2340055')->is_valid_number, '神奈川県横浜市港南区日野南');
ok($zip->set_number('2340056')->is_valid_number, '神奈川県横浜市港南区野庭町');
ok($zip->set_number('2350000')->is_valid_number, '神奈川県横浜市磯子区以下に掲載がない場合');
ok($zip->set_number('2350001')->is_valid_number, '神奈川県横浜市磯子区上町');
ok($zip->set_number('2350002')->is_valid_number, '神奈川県横浜市磯子区馬場町');
ok($zip->set_number('2350003')->is_valid_number, '神奈川県横浜市磯子区坂下町');
ok($zip->set_number('2350004')->is_valid_number, '神奈川県横浜市磯子区下町');
ok($zip->set_number('2350005')->is_valid_number, '神奈川県横浜市磯子区東町');
ok($zip->set_number('2350006')->is_valid_number, '神奈川県横浜市磯子区鳳町');
ok($zip->set_number('2350007')->is_valid_number, '神奈川県横浜市磯子区西町');
ok($zip->set_number('2350008')->is_valid_number, '神奈川県横浜市磯子区原町');
ok($zip->set_number('2350011')->is_valid_number, '神奈川県横浜市磯子区丸山');
ok($zip->set_number('2350012')->is_valid_number, '神奈川県横浜市磯子区滝頭');
ok($zip->set_number('2350013')->is_valid_number, '神奈川県横浜市磯子区広地町');
ok($zip->set_number('2350014')->is_valid_number, '神奈川県横浜市磯子区中浜町');
ok($zip->set_number('2350015')->is_valid_number, '神奈川県横浜市磯子区久木町');
ok($zip->set_number('2350016')->is_valid_number, '神奈川県横浜市磯子区磯子');
ok($zip->set_number('2350017')->is_valid_number, '神奈川県横浜市磯子区新磯子町');
ok($zip->set_number('2350018')->is_valid_number, '神奈川県横浜市磯子区新森町');
ok($zip->set_number('2350019')->is_valid_number, '神奈川県横浜市磯子区磯子台');
ok($zip->set_number('2350021')->is_valid_number, '神奈川県横浜市磯子区岡村');
ok($zip->set_number('2350022')->is_valid_number, '神奈川県横浜市磯子区汐見台');
ok($zip->set_number('2350023')->is_valid_number, '神奈川県横浜市磯子区森');
ok($zip->set_number('2350024')->is_valid_number, '神奈川県横浜市磯子区森が丘');
ok($zip->set_number('2350031')->is_valid_number, '神奈川県横浜市磯子区新中原町');
ok($zip->set_number('2350032')->is_valid_number, '神奈川県横浜市磯子区新杉田町');
ok($zip->set_number('2350033')->is_valid_number, '神奈川県横浜市磯子区杉田');
ok($zip->set_number('2350034')->is_valid_number, '神奈川県横浜市磯子区杉田坪呑');
ok($zip->set_number('2350035')->is_valid_number, '神奈川県横浜市磯子区田中');
ok($zip->set_number('2350036')->is_valid_number, '神奈川県横浜市磯子区中原');
ok($zip->set_number('2350041')->is_valid_number, '神奈川県横浜市磯子区栗木');
ok($zip->set_number('2350042')->is_valid_number, '神奈川県横浜市磯子区上中里町');
ok($zip->set_number('2350043')->is_valid_number, '神奈川県横浜市磯子区氷取沢町');
ok($zip->set_number('2350044')->is_valid_number, '神奈川県横浜市磯子区峰町');
ok($zip->set_number('2350045')->is_valid_number, '神奈川県横浜市磯子区洋光台');
ok($zip->set_number('2360000')->is_valid_number, '神奈川県横浜市金沢区以下に掲載がない場合');
ok($zip->set_number('2360001')->is_valid_number, '神奈川県横浜市金沢区昭和町');
ok($zip->set_number('2360002')->is_valid_number, '神奈川県横浜市金沢区鳥浜町');
ok($zip->set_number('2360003')->is_valid_number, '神奈川県横浜市金沢区幸浦');
ok($zip->set_number('2360004')->is_valid_number, '神奈川県横浜市金沢区福浦');
ok($zip->set_number('2360005')->is_valid_number, '神奈川県横浜市金沢区並木');
ok($zip->set_number('2360006')->is_valid_number, '神奈川県横浜市金沢区八景島');
ok($zip->set_number('2360007')->is_valid_number, '神奈川県横浜市金沢区白帆');
ok($zip->set_number('2360011')->is_valid_number, '神奈川県横浜市金沢区長浜');
ok($zip->set_number('2360012')->is_valid_number, '神奈川県横浜市金沢区柴町');
ok($zip->set_number('2360013')->is_valid_number, '神奈川県横浜市金沢区海の公園');
ok($zip->set_number('2360014')->is_valid_number, '神奈川県横浜市金沢区寺前');
ok($zip->set_number('2360015')->is_valid_number, '神奈川県横浜市金沢区金沢町');
ok($zip->set_number('2360016')->is_valid_number, '神奈川県横浜市金沢区谷津町');
ok($zip->set_number('2360017')->is_valid_number, '神奈川県横浜市金沢区西柴');
ok($zip->set_number('2360021')->is_valid_number, '神奈川県横浜市金沢区泥亀');
ok($zip->set_number('2360022')->is_valid_number, '神奈川県横浜市金沢区町屋町');
ok($zip->set_number('2360023')->is_valid_number, '神奈川県横浜市金沢区平潟町');
ok($zip->set_number('2360024')->is_valid_number, '神奈川県横浜市金沢区乙舳町');
ok($zip->set_number('2360025')->is_valid_number, '神奈川県横浜市金沢区野島町');
ok($zip->set_number('2360026')->is_valid_number, '神奈川県横浜市金沢区柳町');
ok($zip->set_number('2360027')->is_valid_number, '神奈川県横浜市金沢区瀬戸');
ok($zip->set_number('2360028')->is_valid_number, '神奈川県横浜市金沢区洲崎町');
ok($zip->set_number('2360031')->is_valid_number, '神奈川県横浜市金沢区六浦');
ok($zip->set_number('2360032')->is_valid_number, '神奈川県横浜市金沢区六浦町');
ok($zip->set_number('2360033')->is_valid_number, '神奈川県横浜市金沢区東朝比奈');
ok($zip->set_number('2360034')->is_valid_number, '神奈川県横浜市金沢区朝比奈町');
ok($zip->set_number('2360035')->is_valid_number, '神奈川県横浜市金沢区大道');
ok($zip->set_number('2360036')->is_valid_number, '神奈川県横浜市金沢区みず木町');
ok($zip->set_number('2360037')->is_valid_number, '神奈川県横浜市金沢区六浦東');
ok($zip->set_number('2360038')->is_valid_number, '神奈川県横浜市金沢区六浦南');
ok($zip->set_number('2360041')->is_valid_number, '神奈川県横浜市金沢区釜利谷町');
ok($zip->set_number('2360042')->is_valid_number, '神奈川県横浜市金沢区釜利谷東');
ok($zip->set_number('2360043')->is_valid_number, '神奈川県横浜市金沢区大川');
ok($zip->set_number('2360044')->is_valid_number, '神奈川県横浜市金沢区高舟台');
ok($zip->set_number('2360045')->is_valid_number, '神奈川県横浜市金沢区釜利谷南');
ok($zip->set_number('2360046')->is_valid_number, '神奈川県横浜市金沢区釜利谷西');
ok($zip->set_number('2360051')->is_valid_number, '神奈川県横浜市金沢区富岡東');
ok($zip->set_number('2360052')->is_valid_number, '神奈川県横浜市金沢区富岡西');
ok($zip->set_number('2360053')->is_valid_number, '神奈川県横浜市金沢区能見台通');
ok($zip->set_number('2360054')->is_valid_number, '神奈川県横浜市金沢区堀口');
ok($zip->set_number('2360055')->is_valid_number, '神奈川県横浜市金沢区片吹');
ok($zip->set_number('2360056')->is_valid_number, '神奈川県横浜市金沢区能見台森');
ok($zip->set_number('2360057')->is_valid_number, '神奈川県横浜市金沢区能見台');
ok($zip->set_number('2360058')->is_valid_number, '神奈川県横浜市金沢区能見台東');
ok($zip->set_number('2370061')->is_valid_number, '神奈川県横須賀市夏島町');
ok($zip->set_number('2370062')->is_valid_number, '神奈川県横須賀市浦郷町');
ok($zip->set_number('2370063')->is_valid_number, '神奈川県横須賀市追浜東町');
ok($zip->set_number('2370064')->is_valid_number, '神奈川県横須賀市追浜町');
ok($zip->set_number('2370065')->is_valid_number, '神奈川県横須賀市追浜南町');
ok($zip->set_number('2370066')->is_valid_number, '神奈川県横須賀市湘南鷹取');
ok($zip->set_number('2370067')->is_valid_number, '神奈川県横須賀市鷹取');
ok($zip->set_number('2370068')->is_valid_number, '神奈川県横須賀市追浜本町');
ok($zip->set_number('2370071')->is_valid_number, '神奈川県横須賀市田浦港町');
ok($zip->set_number('2370072')->is_valid_number, '神奈川県横須賀市長浦町');
ok($zip->set_number('2370073')->is_valid_number, '神奈川県横須賀市田浦泉町');
ok($zip->set_number('2370074')->is_valid_number, '神奈川県横須賀市田浦大作町');
ok($zip->set_number('2370075')->is_valid_number, '神奈川県横須賀市田浦町');
ok($zip->set_number('2370076')->is_valid_number, '神奈川県横須賀市船越町');
ok($zip->set_number('2370077')->is_valid_number, '神奈川県横須賀市浜見台');
ok($zip->set_number('2370078')->is_valid_number, '神奈川県横須賀市箱崎町');
ok($zip->set_number('2370079')->is_valid_number, '神奈川県横須賀市港が丘');
ok($zip->set_number('2380000')->is_valid_number, '神奈川県横須賀市以下に掲載がない場合');
ok($zip->set_number('2380001')->is_valid_number, '神奈川県横須賀市泊町');
ok($zip->set_number('2380002')->is_valid_number, '神奈川県横須賀市楠ケ浦町');
ok($zip->set_number('2380003')->is_valid_number, '神奈川県横須賀市稲岡町');
ok($zip->set_number('2380004')->is_valid_number, '神奈川県横須賀市小川町');
ok($zip->set_number('2380005')->is_valid_number, '神奈川県横須賀市新港町');
ok($zip->set_number('2380006')->is_valid_number, '神奈川県横須賀市日の出町');
ok($zip->set_number('2380007')->is_valid_number, '神奈川県横須賀市若松町');
ok($zip->set_number('2380008')->is_valid_number, '神奈川県横須賀市大滝町');
ok($zip->set_number('2380011')->is_valid_number, '神奈川県横須賀市米が浜通');
ok($zip->set_number('2380012')->is_valid_number, '神奈川県横須賀市安浦町');
ok($zip->set_number('2380013')->is_valid_number, '神奈川県横須賀市平成町');
ok($zip->set_number('2380014')->is_valid_number, '神奈川県横須賀市三春町');
ok($zip->set_number('2380015')->is_valid_number, '神奈川県横須賀市田戸台');
ok($zip->set_number('2380016')->is_valid_number, '神奈川県横須賀市深田台');
ok($zip->set_number('2380017')->is_valid_number, '神奈川県横須賀市上町');
ok($zip->set_number('2380018')->is_valid_number, '神奈川県横須賀市緑が丘');
ok($zip->set_number('2380019')->is_valid_number, '神奈川県横須賀市猿島');
ok($zip->set_number('2380021')->is_valid_number, '神奈川県横須賀市富士見町');
ok($zip->set_number('2380022')->is_valid_number, '神奈川県横須賀市公郷町');
ok($zip->set_number('2380023')->is_valid_number, '神奈川県横須賀市森崎');
ok($zip->set_number('2380024')->is_valid_number, '神奈川県横須賀市大矢部');
ok($zip->set_number('2380025')->is_valid_number, '神奈川県横須賀市衣笠町');
ok($zip->set_number('2380026')->is_valid_number, '神奈川県横須賀市小矢部');
ok($zip->set_number('2380031')->is_valid_number, '神奈川県横須賀市衣笠栄町');
ok($zip->set_number('2380032')->is_valid_number, '神奈川県横須賀市平作');
ok($zip->set_number('2380033')->is_valid_number, '神奈川県横須賀市阿部倉');
ok($zip->set_number('2380034')->is_valid_number, '神奈川県横須賀市金谷');
ok($zip->set_number('2380035')->is_valid_number, '神奈川県横須賀市池上');
ok($zip->set_number('2380036')->is_valid_number, '神奈川県横須賀市山中町');
ok($zip->set_number('2380041')->is_valid_number, '神奈川県横須賀市本町');
ok($zip->set_number('2380042')->is_valid_number, '神奈川県横須賀市汐入町');
ok($zip->set_number('2380043')->is_valid_number, '神奈川県横須賀市坂本町');
ok($zip->set_number('2380044')->is_valid_number, '神奈川県横須賀市逸見が丘');
ok($zip->set_number('2380045')->is_valid_number, '神奈川県横須賀市東逸見町');
ok($zip->set_number('2380046')->is_valid_number, '神奈川県横須賀市西逸見町');
ok($zip->set_number('2380047')->is_valid_number, '神奈川県横須賀市吉倉町');
ok($zip->set_number('2380048')->is_valid_number, '神奈川県横須賀市安針台');
ok($zip->set_number('2380051')->is_valid_number, '神奈川県横須賀市不入斗町');
ok($zip->set_number('2380052')->is_valid_number, '神奈川県横須賀市佐野町');
ok($zip->set_number('2380053')->is_valid_number, '神奈川県横須賀市望洋台');
ok($zip->set_number('2380054')->is_valid_number, '神奈川県横須賀市汐見台');
ok($zip->set_number('2380055')->is_valid_number, '神奈川県横須賀市平和台');
ok($zip->set_number('2380056')->is_valid_number, '神奈川県横須賀市鶴が丘');
ok($zip->set_number('2380101')->is_valid_number, '神奈川県三浦市南下浦町上宮田');
ok($zip->set_number('2380102')->is_valid_number, '神奈川県三浦市南下浦町菊名');
ok($zip->set_number('2380103')->is_valid_number, '神奈川県三浦市南下浦町金田');
ok($zip->set_number('2380104')->is_valid_number, '神奈川県三浦市南下浦町松輪');
ok($zip->set_number('2380105')->is_valid_number, '神奈川県三浦市南下浦町毘沙門');
ok($zip->set_number('2380111')->is_valid_number, '神奈川県三浦市初声町下宮田');
ok($zip->set_number('2380112')->is_valid_number, '神奈川県三浦市初声町三戸');
ok($zip->set_number('2380113')->is_valid_number, '神奈川県三浦市初声町入江');
ok($zip->set_number('2380114')->is_valid_number, '神奈川県三浦市初声町和田');
ok($zip->set_number('2380115')->is_valid_number, '神奈川県三浦市初声町高円坊');
ok($zip->set_number('2380200')->is_valid_number, '神奈川県三浦市以下に掲載がない場合');
ok($zip->set_number('2380221')->is_valid_number, '神奈川県三浦市三崎町六合');
ok($zip->set_number('2380222')->is_valid_number, '神奈川県三浦市岬陽町');
ok($zip->set_number('2380223')->is_valid_number, '神奈川県三浦市原町');
ok($zip->set_number('2380224')->is_valid_number, '神奈川県三浦市三崎町諸磯');
ok($zip->set_number('2380225')->is_valid_number, '神奈川県三浦市三崎町小網代');
ok($zip->set_number('2380231')->is_valid_number, '神奈川県三浦市宮川町');
ok($zip->set_number('2380232')->is_valid_number, '神奈川県三浦市晴海町');
ok($zip->set_number('2380233')->is_valid_number, '神奈川県三浦市向ケ崎町');
ok($zip->set_number('2380234')->is_valid_number, '神奈川県三浦市諏訪町');
ok($zip->set_number('2380235')->is_valid_number, '神奈川県三浦市城山町');
ok($zip->set_number('2380236')->is_valid_number, '神奈川県三浦市栄町');
ok($zip->set_number('2380237')->is_valid_number, '神奈川県三浦市三崎町城ケ島');
ok($zip->set_number('2380241')->is_valid_number, '神奈川県三浦市天神町');
ok($zip->set_number('2380242')->is_valid_number, '神奈川県三浦市東岡町');
ok($zip->set_number('2380243')->is_valid_number, '神奈川県三浦市三崎');
ok($zip->set_number('2380244')->is_valid_number, '神奈川県三浦市白石町');
ok($zip->set_number('2380245')->is_valid_number, '神奈川県三浦市海外町');
ok($zip->set_number('2380246')->is_valid_number, '神奈川県三浦市尾上町');
ok($zip->set_number('2380311')->is_valid_number, '神奈川県横須賀市太田和');
ok($zip->set_number('2380312')->is_valid_number, '神奈川県横須賀市山科台');
ok($zip->set_number('2380313')->is_valid_number, '神奈川県横須賀市武');
ok($zip->set_number('2380314')->is_valid_number, '神奈川県横須賀市須軽谷');
ok($zip->set_number('2380315')->is_valid_number, '神奈川県横須賀市林');
ok($zip->set_number('2380316')->is_valid_number, '神奈川県横須賀市長井');
ok($zip->set_number('2380317')->is_valid_number, '神奈川県横須賀市御幸浜');
ok($zip->set_number('2390801')->is_valid_number, '神奈川県横須賀市馬堀海岸');
ok($zip->set_number('2390802')->is_valid_number, '神奈川県横須賀市馬堀町');
ok($zip->set_number('2390803')->is_valid_number, '神奈川県横須賀市桜が丘');
ok($zip->set_number('2390804')->is_valid_number, '神奈川県横須賀市吉井');
ok($zip->set_number('2390805')->is_valid_number, '神奈川県横須賀市舟倉');
ok($zip->set_number('2390806')->is_valid_number, '神奈川県横須賀市池田町');
ok($zip->set_number('2390807')->is_valid_number, '神奈川県横須賀市根岸町');
ok($zip->set_number('2390808')->is_valid_number, '神奈川県横須賀市大津町');
ok($zip->set_number('2390811')->is_valid_number, '神奈川県横須賀市走水');
ok($zip->set_number('2390812')->is_valid_number, '神奈川県横須賀市小原台');
ok($zip->set_number('2390813')->is_valid_number, '神奈川県横須賀市鴨居');
ok($zip->set_number('2390814')->is_valid_number, '神奈川県横須賀市二葉');
ok($zip->set_number('2390815')->is_valid_number, '神奈川県横須賀市浦上台');
ok($zip->set_number('2390820')->is_valid_number, '神奈川県横須賀市光風台');
ok($zip->set_number('2390821')->is_valid_number, '神奈川県横須賀市東浦賀');
ok($zip->set_number('2390822')->is_valid_number, '神奈川県横須賀市浦賀');
ok($zip->set_number('2390823')->is_valid_number, '神奈川県横須賀市浦賀丘');
ok($zip->set_number('2390824')->is_valid_number, '神奈川県横須賀市西浦賀');
ok($zip->set_number('2390825')->is_valid_number, '神奈川県横須賀市南浦賀');
ok($zip->set_number('2390826')->is_valid_number, '神奈川県横須賀市長瀬');
ok($zip->set_number('2390827')->is_valid_number, '神奈川県横須賀市久里浜台');
ok($zip->set_number('2390828')->is_valid_number, '神奈川県横須賀市久比里');
ok($zip->set_number('2390829')->is_valid_number, '神奈川県横須賀市若宮台');
ok($zip->set_number('2390831')->is_valid_number, '神奈川県横須賀市久里浜');
ok($zip->set_number('2390832')->is_valid_number, '神奈川県横須賀市神明町');
ok($zip->set_number('2390833')->is_valid_number, '神奈川県横須賀市ハイランド');
ok($zip->set_number('2390834')->is_valid_number, '神奈川県横須賀市久村');
ok($zip->set_number('2390835')->is_valid_number, '神奈川県横須賀市佐原');
ok($zip->set_number('2390836')->is_valid_number, '神奈川県横須賀市内川');
ok($zip->set_number('2390837')->is_valid_number, '神奈川県横須賀市内川新田');
ok($zip->set_number('2390841')->is_valid_number, '神奈川県横須賀市野比');
ok($zip->set_number('2390842')->is_valid_number, '神奈川県横須賀市長沢');
ok($zip->set_number('2390843')->is_valid_number, '神奈川県横須賀市津久井');
ok($zip->set_number('2390844')->is_valid_number, '神奈川県横須賀市岩戸');
ok($zip->set_number('2390845')->is_valid_number, '神奈川県横須賀市粟田');
ok($zip->set_number('2390846')->is_valid_number, '神奈川県横須賀市グリーンハイツ');
ok($zip->set_number('2390847')->is_valid_number, '神奈川県横須賀市光の丘');
ok($zip->set_number('2400000')->is_valid_number, '神奈川県横浜市保土ケ谷区以下に掲載がない場合');
ok($zip->set_number('2400001')->is_valid_number, '神奈川県横浜市保土ケ谷区川辺町');
ok($zip->set_number('2400002')->is_valid_number, '神奈川県横浜市保土ケ谷区宮田町');
ok($zip->set_number('2400003')->is_valid_number, '神奈川県横浜市保土ケ谷区天王町');
ok($zip->set_number('2400004')->is_valid_number, '神奈川県横浜市保土ケ谷区岩間町');
ok($zip->set_number('2400005')->is_valid_number, '神奈川県横浜市保土ケ谷区神戸町');
ok($zip->set_number('2400006')->is_valid_number, '神奈川県横浜市保土ケ谷区星川');
ok($zip->set_number('2400007')->is_valid_number, '神奈川県横浜市保土ケ谷区明神台');
ok($zip->set_number('2400011')->is_valid_number, '神奈川県横浜市保土ケ谷区桜ケ丘');
ok($zip->set_number('2400012')->is_valid_number, '神奈川県横浜市保土ケ谷区月見台');
ok($zip->set_number('2400013')->is_valid_number, '神奈川県横浜市保土ケ谷区帷子町');
ok($zip->set_number('2400014')->is_valid_number, '神奈川県横浜市保土ケ谷区霞台');
ok($zip->set_number('2400015')->is_valid_number, '神奈川県横浜市保土ケ谷区岩崎町');
ok($zip->set_number('2400016')->is_valid_number, '神奈川県横浜市保土ケ谷区初音ケ丘');
ok($zip->set_number('2400017')->is_valid_number, '神奈川県横浜市保土ケ谷区花見台');
ok($zip->set_number('2400021')->is_valid_number, '神奈川県横浜市保土ケ谷区保土ケ谷町');
ok($zip->set_number('2400022')->is_valid_number, '神奈川県横浜市保土ケ谷区西久保町');
ok($zip->set_number('2400023')->is_valid_number, '神奈川県横浜市保土ケ谷区岩井町');
ok($zip->set_number('2400024')->is_valid_number, '神奈川県横浜市保土ケ谷区瀬戸ケ谷町');
ok($zip->set_number('2400025')->is_valid_number, '神奈川県横浜市保土ケ谷区狩場町');
ok($zip->set_number('2400026')->is_valid_number, '神奈川県横浜市保土ケ谷区権太坂');
ok($zip->set_number('2400031')->is_valid_number, '神奈川県横浜市保土ケ谷区藤塚町');
ok($zip->set_number('2400032')->is_valid_number, '神奈川県横浜市保土ケ谷区法泉');
ok($zip->set_number('2400033')->is_valid_number, '神奈川県横浜市保土ケ谷区境木本町');
ok($zip->set_number('2400034')->is_valid_number, '神奈川県横浜市保土ケ谷区境木町');
ok($zip->set_number('2400035')->is_valid_number, '神奈川県横浜市保土ケ谷区今井町');
ok($zip->set_number('2400036')->is_valid_number, '神奈川県横浜市保土ケ谷区新桜ケ丘');
ok($zip->set_number('2400041')->is_valid_number, '神奈川県横浜市保土ケ谷区東川島町');
ok($zip->set_number('2400042')->is_valid_number, '神奈川県横浜市保土ケ谷区上星川');
ok($zip->set_number('2400043')->is_valid_number, '神奈川県横浜市保土ケ谷区坂本町');
ok($zip->set_number('2400044')->is_valid_number, '神奈川県横浜市保土ケ谷区仏向町');
ok($zip->set_number('2400045')->is_valid_number, '神奈川県横浜市保土ケ谷区川島町');
ok($zip->set_number('2400046')->is_valid_number, '神奈川県横浜市保土ケ谷区仏向西');
ok($zip->set_number('2400051')->is_valid_number, '神奈川県横浜市保土ケ谷区上菅田町');
ok($zip->set_number('2400052')->is_valid_number, '神奈川県横浜市保土ケ谷区西谷町');
ok($zip->set_number('2400053')->is_valid_number, '神奈川県横浜市保土ケ谷区新井町');
ok($zip->set_number('2400054')->is_valid_number, '神奈川県横浜市保土ケ谷区西谷');
ok($zip->set_number('2400061')->is_valid_number, '神奈川県横浜市保土ケ谷区峰沢町');
ok($zip->set_number('2400062')->is_valid_number, '神奈川県横浜市保土ケ谷区岡沢町');
ok($zip->set_number('2400063')->is_valid_number, '神奈川県横浜市保土ケ谷区鎌谷町');
ok($zip->set_number('2400064')->is_valid_number, '神奈川県横浜市保土ケ谷区峰岡町');
ok($zip->set_number('2400065')->is_valid_number, '神奈川県横浜市保土ケ谷区和田');
ok($zip->set_number('2400066')->is_valid_number, '神奈川県横浜市保土ケ谷区釜台町');
ok($zip->set_number('2400067')->is_valid_number, '神奈川県横浜市保土ケ谷区常盤台');
ok($zip->set_number('2400100')->is_valid_number, '神奈川県三浦郡葉山町以下に掲載がない場合');
ok($zip->set_number('2400101')->is_valid_number, '神奈川県横須賀市長坂');
ok($zip->set_number('2400102')->is_valid_number, '神奈川県横須賀市荻野');
ok($zip->set_number('2400103')->is_valid_number, '神奈川県横須賀市佐島');
ok($zip->set_number('2400104')->is_valid_number, '神奈川県横須賀市芦名');
ok($zip->set_number('2400105')->is_valid_number, '神奈川県横須賀市秋谷');
ok($zip->set_number('2400106')->is_valid_number, '神奈川県横須賀市子安');
ok($zip->set_number('2400107')->is_valid_number, '神奈川県横須賀市湘南国際村');
ok($zip->set_number('2400108')->is_valid_number, '神奈川県横須賀市佐島の丘');
ok($zip->set_number('2400111')->is_valid_number, '神奈川県三浦郡葉山町一色');
ok($zip->set_number('2400112')->is_valid_number, '神奈川県三浦郡葉山町堀内');
ok($zip->set_number('2400113')->is_valid_number, '神奈川県三浦郡葉山町長柄');
ok($zip->set_number('2400114')->is_valid_number, '神奈川県三浦郡葉山町木古庭');
ok($zip->set_number('2400115')->is_valid_number, '神奈川県三浦郡葉山町上山口');
ok($zip->set_number('2400116')->is_valid_number, '神奈川県三浦郡葉山町下山口');
ok($zip->set_number('2410000')->is_valid_number, '神奈川県横浜市旭区以下に掲載がない場合');
ok($zip->set_number('2410001')->is_valid_number, '神奈川県横浜市旭区上白根町');
ok($zip->set_number('2410002')->is_valid_number, '神奈川県横浜市旭区上白根');
ok($zip->set_number('2410003')->is_valid_number, '神奈川県横浜市旭区白根町');
ok($zip->set_number('2410004')->is_valid_number, '神奈川県横浜市旭区中白根');
ok($zip->set_number('2410005')->is_valid_number, '神奈川県横浜市旭区白根');
ok($zip->set_number('2410011')->is_valid_number, '神奈川県横浜市旭区川島町');
ok($zip->set_number('2410012')->is_valid_number, '神奈川県横浜市旭区西川島町');
ok($zip->set_number('2410013')->is_valid_number, '神奈川県横浜市旭区三反田町');
ok($zip->set_number('2410014')->is_valid_number, '神奈川県横浜市旭区市沢町');
ok($zip->set_number('2410015')->is_valid_number, '神奈川県横浜市旭区小高町');
ok($zip->set_number('2410021')->is_valid_number, '神奈川県横浜市旭区鶴ケ峰本町');
ok($zip->set_number('2410022')->is_valid_number, '神奈川県横浜市旭区鶴ケ峰');
ok($zip->set_number('2410023')->is_valid_number, '神奈川県横浜市旭区本宿町');
ok($zip->set_number('2410024')->is_valid_number, '神奈川県横浜市旭区本村町');
ok($zip->set_number('2410025')->is_valid_number, '神奈川県横浜市旭区四季美台');
ok($zip->set_number('2410031')->is_valid_number, '神奈川県横浜市旭区今宿西町');
ok($zip->set_number('2410032')->is_valid_number, '神奈川県横浜市旭区今宿東町');
ok($zip->set_number('2410033')->is_valid_number, '神奈川県横浜市旭区今川町');
ok($zip->set_number('2410034')->is_valid_number, '神奈川県横浜市旭区今宿南町');
ok($zip->set_number('2410801')->is_valid_number, '神奈川県横浜市旭区若葉台');
ok($zip->set_number('2410802')->is_valid_number, '神奈川県横浜市旭区上川井町');
ok($zip->set_number('2410803')->is_valid_number, '神奈川県横浜市旭区川井本町');
ok($zip->set_number('2410804')->is_valid_number, '神奈川県横浜市旭区川井宿町');
ok($zip->set_number('2410805')->is_valid_number, '神奈川県横浜市旭区都岡町');
ok($zip->set_number('2410806')->is_valid_number, '神奈川県横浜市旭区下川井町');
ok($zip->set_number('2410811')->is_valid_number, '神奈川県横浜市旭区矢指町');
ok($zip->set_number('2410812')->is_valid_number, '神奈川県横浜市旭区金が谷');
ok($zip->set_number('2410813')->is_valid_number, '神奈川県横浜市旭区今宿町');
ok($zip->set_number('2410814')->is_valid_number, '神奈川県横浜市旭区中沢');
ok($zip->set_number('2410815')->is_valid_number, '神奈川県横浜市旭区中尾');
ok($zip->set_number('2410816')->is_valid_number, '神奈川県横浜市旭区笹野台');
ok($zip->set_number('2410817')->is_valid_number, '神奈川県横浜市旭区今宿');
ok($zip->set_number('2410821')->is_valid_number, '神奈川県横浜市旭区二俣川');
ok($zip->set_number('2410822')->is_valid_number, '神奈川県横浜市旭区さちが丘');
ok($zip->set_number('2410823')->is_valid_number, '神奈川県横浜市旭区善部町');
ok($zip->set_number('2410824')->is_valid_number, '神奈川県横浜市旭区南希望が丘');
ok($zip->set_number('2410825')->is_valid_number, '神奈川県横浜市旭区中希望が丘');
ok($zip->set_number('2410826')->is_valid_number, '神奈川県横浜市旭区東希望が丘');
ok($zip->set_number('2410831')->is_valid_number, '神奈川県横浜市旭区左近山');
ok($zip->set_number('2410832')->is_valid_number, '神奈川県横浜市旭区桐が作');
ok($zip->set_number('2410833')->is_valid_number, '神奈川県横浜市旭区南本宿町');
ok($zip->set_number('2410834')->is_valid_number, '神奈川県横浜市旭区大池町');
ok($zip->set_number('2410835')->is_valid_number, '神奈川県横浜市旭区柏町');
ok($zip->set_number('2410836')->is_valid_number, '神奈川県横浜市旭区万騎が原');
ok($zip->set_number('2420000')->is_valid_number, '神奈川県大和市以下に掲載がない場合');
ok($zip->set_number('2420001')->is_valid_number, '神奈川県大和市下鶴間');
ok($zip->set_number('2420002')->is_valid_number, '神奈川県大和市つきみ野');
ok($zip->set_number('2420003')->is_valid_number, '神奈川県大和市林間');
ok($zip->set_number('2420004')->is_valid_number, '神奈川県大和市鶴間');
ok($zip->set_number('2420005')->is_valid_number, '神奈川県大和市西鶴間');
ok($zip->set_number('2420006')->is_valid_number, '神奈川県大和市南林間');
ok($zip->set_number('2420007')->is_valid_number, '神奈川県大和市中央林間');
ok($zip->set_number('2420008')->is_valid_number, '神奈川県大和市中央林間西');
ok($zip->set_number('2420011')->is_valid_number, '神奈川県大和市深見');
ok($zip->set_number('2420012')->is_valid_number, '神奈川県大和市深見東');
ok($zip->set_number('2420013')->is_valid_number, '神奈川県大和市深見台');
ok($zip->set_number('2420014')->is_valid_number, '神奈川県大和市上和田');
ok($zip->set_number('2420015')->is_valid_number, '神奈川県大和市下和田');
ok($zip->set_number('2420016')->is_valid_number, '神奈川県大和市大和南');
ok($zip->set_number('2420017')->is_valid_number, '神奈川県大和市大和東');
ok($zip->set_number('2420018')->is_valid_number, '神奈川県大和市深見西');
ok($zip->set_number('2420021')->is_valid_number, '神奈川県大和市中央');
ok($zip->set_number('2420022')->is_valid_number, '神奈川県大和市柳橋');
ok($zip->set_number('2420023')->is_valid_number, '神奈川県大和市渋谷');
ok($zip->set_number('2420024')->is_valid_number, '神奈川県大和市福田');
ok($zip->set_number('2420025')->is_valid_number, '神奈川県大和市代官');
ok($zip->set_number('2420026')->is_valid_number, '神奈川県大和市草柳');
ok($zip->set_number('2420027')->is_valid_number, '神奈川県大和市下草柳');
ok($zip->set_number('2420028')->is_valid_number, '神奈川県大和市桜森');
ok($zip->set_number('2420029')->is_valid_number, '神奈川県大和市上草柳');
ok($zip->set_number('2430000')->is_valid_number, '神奈川県厚木市以下に掲載がない場合');
ok($zip->set_number('2430001')->is_valid_number, '神奈川県厚木市東町');
ok($zip->set_number('2430002')->is_valid_number, '神奈川県厚木市元町');
ok($zip->set_number('2430003')->is_valid_number, '神奈川県厚木市寿町');
ok($zip->set_number('2430004')->is_valid_number, '神奈川県厚木市水引');
ok($zip->set_number('2430005')->is_valid_number, '神奈川県厚木市松枝');
ok($zip->set_number('2430006')->is_valid_number, '神奈川県厚木市吾妻町');
ok($zip->set_number('2430007')->is_valid_number, '神奈川県厚木市厚木');
ok($zip->set_number('2430011')->is_valid_number, '神奈川県厚木市厚木町');
ok($zip->set_number('2430012')->is_valid_number, '神奈川県厚木市幸町');
ok($zip->set_number('2430013')->is_valid_number, '神奈川県厚木市泉町');
ok($zip->set_number('2430014')->is_valid_number, '神奈川県厚木市旭町');
ok($zip->set_number('2430015')->is_valid_number, '神奈川県厚木市南町');
ok($zip->set_number('2430016')->is_valid_number, '神奈川県厚木市田村町');
ok($zip->set_number('2430017')->is_valid_number, '神奈川県厚木市栄町');
ok($zip->set_number('2430018')->is_valid_number, '神奈川県厚木市中町');
ok($zip->set_number('2430021')->is_valid_number, '神奈川県厚木市岡田');
ok($zip->set_number('2430022')->is_valid_number, '神奈川県厚木市酒井');
ok($zip->set_number('2430023')->is_valid_number, '神奈川県厚木市戸田');
ok($zip->set_number('2430024')->is_valid_number, '神奈川県厚木市長沼');
ok($zip->set_number('2430025')->is_valid_number, '神奈川県厚木市上落合');
ok($zip->set_number('2430026')->is_valid_number, '神奈川県厚木市下津古久');
ok($zip->set_number('2430027')->is_valid_number, '神奈川県厚木市愛甲東');
ok($zip->set_number('2430028')->is_valid_number, '神奈川県厚木市愛甲西');
ok($zip->set_number('2430031')->is_valid_number, '神奈川県厚木市戸室');
ok($zip->set_number('2430032')->is_valid_number, '神奈川県厚木市恩名');
ok($zip->set_number('2430033')->is_valid_number, '神奈川県厚木市温水');
ok($zip->set_number('2430034')->is_valid_number, '神奈川県厚木市船子');
ok($zip->set_number('2430035')->is_valid_number, '神奈川県厚木市愛甲');
ok($zip->set_number('2430036')->is_valid_number, '神奈川県厚木市長谷');
ok($zip->set_number('2430037')->is_valid_number, '神奈川県厚木市毛利台');
ok($zip->set_number('2430038')->is_valid_number, '神奈川県厚木市愛名');
ok($zip->set_number('2430039')->is_valid_number, '神奈川県厚木市温水西');
ok($zip->set_number('2430041')->is_valid_number, '神奈川県厚木市緑ケ丘');
ok($zip->set_number('2430100')->is_valid_number, '神奈川県愛甲郡清川村以下に掲載がない場合');
ok($zip->set_number('2430111')->is_valid_number, '神奈川県愛甲郡清川村宮ヶ瀬');
ok($zip->set_number('2430112')->is_valid_number, '神奈川県愛甲郡清川村煤ヶ谷(その他)');
ok($zip->set_number('2430121')->is_valid_number, '神奈川県厚木市七沢');
ok($zip->set_number('2430122')->is_valid_number, '神奈川県厚木市森の里');
ok($zip->set_number('2430123')->is_valid_number, '神奈川県厚木市森の里青山');
ok($zip->set_number('2430124')->is_valid_number, '神奈川県厚木市森の里若宮');
ok($zip->set_number('2430125')->is_valid_number, '神奈川県厚木市小野');
ok($zip->set_number('2430126')->is_valid_number, '神奈川県厚木市岡津古久');
ok($zip->set_number('2430201')->is_valid_number, '神奈川県厚木市上荻野');
ok($zip->set_number('2430202')->is_valid_number, '神奈川県厚木市中荻野');
ok($zip->set_number('2430203')->is_valid_number, '神奈川県厚木市下荻野');
ok($zip->set_number('2430204')->is_valid_number, '神奈川県厚木市鳶尾');
ok($zip->set_number('2430205')->is_valid_number, '神奈川県厚木市棚沢');
ok($zip->set_number('2430206')->is_valid_number, '神奈川県厚木市下川入');
ok($zip->set_number('2430207')->is_valid_number, '神奈川県厚木市まつかげ台');
ok($zip->set_number('2430208')->is_valid_number, '神奈川県厚木市みはる野');
ok($zip->set_number('2430211')->is_valid_number, '神奈川県厚木市三田');
ok($zip->set_number('2430212')->is_valid_number, '神奈川県厚木市及川');
ok($zip->set_number('2430213')->is_valid_number, '神奈川県厚木市飯山');
ok($zip->set_number('2430214')->is_valid_number, '神奈川県厚木市下古沢');
ok($zip->set_number('2430215')->is_valid_number, '神奈川県厚木市上古沢');
ok($zip->set_number('2430216')->is_valid_number, '神奈川県厚木市宮の里');
ok($zip->set_number('2430217')->is_valid_number, '神奈川県厚木市三田南');
ok($zip->set_number('2430218')->is_valid_number, '神奈川県厚木市飯山南');
ok($zip->set_number('2430300')->is_valid_number, '神奈川県愛甲郡愛川町以下に掲載がない場合');
ok($zip->set_number('2430301')->is_valid_number, '神奈川県愛甲郡愛川町角田');
ok($zip->set_number('2430302')->is_valid_number, '神奈川県愛甲郡愛川町春日台');
ok($zip->set_number('2430303')->is_valid_number, '神奈川県愛甲郡愛川町中津');
ok($zip->set_number('2430304')->is_valid_number, '神奈川県愛甲郡愛川町棚沢');
ok($zip->set_number('2430305')->is_valid_number, '神奈川県愛甲郡愛川町八菅山');
ok($zip->set_number('2430306')->is_valid_number, '神奈川県愛甲郡愛川町田代');
ok($zip->set_number('2430307')->is_valid_number, '神奈川県愛甲郡愛川町半原');
ok($zip->set_number('2430308')->is_valid_number, '神奈川県愛甲郡愛川町三増');
ok($zip->set_number('2430400')->is_valid_number, '神奈川県海老名市以下に掲載がない場合');
ok($zip->set_number('2430401')->is_valid_number, '神奈川県海老名市東柏ケ谷');
ok($zip->set_number('2430402')->is_valid_number, '神奈川県海老名市柏ケ谷');
ok($zip->set_number('2430403')->is_valid_number, '神奈川県海老名市望地');
ok($zip->set_number('2430404')->is_valid_number, '神奈川県海老名市勝瀬');
ok($zip->set_number('2430405')->is_valid_number, '神奈川県海老名市国分南');
ok($zip->set_number('2430406')->is_valid_number, '神奈川県海老名市国分北');
ok($zip->set_number('2430410')->is_valid_number, '神奈川県海老名市杉久保北');
ok($zip->set_number('2430411')->is_valid_number, '神奈川県海老名市大谷');
ok($zip->set_number('2430412')->is_valid_number, '神奈川県海老名市浜田町');
ok($zip->set_number('2430413')->is_valid_number, '神奈川県海老名市国分寺台');
ok($zip->set_number('2430414')->is_valid_number, '神奈川県海老名市杉久保');
ok($zip->set_number('2430415')->is_valid_number, '神奈川県海老名市上河内');
ok($zip->set_number('2430416')->is_valid_number, '神奈川県海老名市中河内');
ok($zip->set_number('2430417')->is_valid_number, '神奈川県海老名市本郷');
ok($zip->set_number('2430418')->is_valid_number, '神奈川県海老名市大谷南');
ok($zip->set_number('2430419')->is_valid_number, '神奈川県海老名市大谷北');
ok($zip->set_number('2430421')->is_valid_number, '神奈川県海老名市さつき町');
ok($zip->set_number('2430422')->is_valid_number, '神奈川県海老名市中新田');
ok($zip->set_number('2430423')->is_valid_number, '神奈川県海老名市今里');
ok($zip->set_number('2430424')->is_valid_number, '神奈川県海老名市社家');
ok($zip->set_number('2430425')->is_valid_number, '神奈川県海老名市中野');
ok($zip->set_number('2430426')->is_valid_number, '神奈川県海老名市門沢橋');
ok($zip->set_number('2430427')->is_valid_number, '神奈川県海老名市杉久保南');
ok($zip->set_number('2430431')->is_valid_number, '神奈川県海老名市上今泉');
ok($zip->set_number('2430432')->is_valid_number, '神奈川県海老名市中央');
ok($zip->set_number('2430433')->is_valid_number, '神奈川県海老名市河原口');
ok($zip->set_number('2430434')->is_valid_number, '神奈川県海老名市上郷');
ok($zip->set_number('2430435')->is_valid_number, '神奈川県海老名市下今泉');
ok($zip->set_number('2430436')->is_valid_number, '神奈川県海老名市扇町');
ok($zip->set_number('2430437')->is_valid_number, '神奈川県海老名市泉');
ok($zip->set_number('2430438')->is_valid_number, '神奈川県海老名市めぐみ町');
ok($zip->set_number('2430801')->is_valid_number, '神奈川県厚木市上依知');
ok($zip->set_number('2430802')->is_valid_number, '神奈川県厚木市猿ケ島');
ok($zip->set_number('2430803')->is_valid_number, '神奈川県厚木市山際');
ok($zip->set_number('2430804')->is_valid_number, '神奈川県厚木市関口');
ok($zip->set_number('2430805')->is_valid_number, '神奈川県厚木市中依知');
ok($zip->set_number('2430806')->is_valid_number, '神奈川県厚木市下依知');
ok($zip->set_number('2430807')->is_valid_number, '神奈川県厚木市金田');
ok($zip->set_number('2430811')->is_valid_number, '神奈川県厚木市妻田');
ok($zip->set_number('2430812')->is_valid_number, '神奈川県厚木市妻田北');
ok($zip->set_number('2430813')->is_valid_number, '神奈川県厚木市妻田東');
ok($zip->set_number('2430814')->is_valid_number, '神奈川県厚木市妻田南');
ok($zip->set_number('2430815')->is_valid_number, '神奈川県厚木市妻田西');
ok($zip->set_number('2430816')->is_valid_number, '神奈川県厚木市林');
ok($zip->set_number('2430817')->is_valid_number, '神奈川県厚木市王子');
ok($zip->set_number('2440000')->is_valid_number, '神奈川県横浜市戸塚区以下に掲載がない場合');
ok($zip->set_number('2440001')->is_valid_number, '神奈川県横浜市戸塚区鳥が丘');
ok($zip->set_number('2440002')->is_valid_number, '神奈川県横浜市戸塚区矢部町');
ok($zip->set_number('2440003')->is_valid_number, '神奈川県横浜市戸塚区戸塚町');
ok($zip->set_number('2440004')->is_valid_number, '神奈川県横浜市戸塚区小雀町');
ok($zip->set_number('2440801')->is_valid_number, '神奈川県横浜市戸塚区品濃町');
ok($zip->set_number('2440802')->is_valid_number, '神奈川県横浜市戸塚区平戸');
ok($zip->set_number('2440803')->is_valid_number, '神奈川県横浜市戸塚区平戸町');
ok($zip->set_number('2440804')->is_valid_number, '神奈川県横浜市戸塚区前田町');
ok($zip->set_number('2440805')->is_valid_number, '神奈川県横浜市戸塚区川上町');
ok($zip->set_number('2440806')->is_valid_number, '神奈川県横浜市戸塚区上品濃');
ok($zip->set_number('2440811')->is_valid_number, '神奈川県横浜市戸塚区上柏尾町');
ok($zip->set_number('2440812')->is_valid_number, '神奈川県横浜市戸塚区柏尾町');
ok($zip->set_number('2440813')->is_valid_number, '神奈川県横浜市戸塚区舞岡町');
ok($zip->set_number('2440814')->is_valid_number, '神奈川県横浜市戸塚区南舞岡');
ok($zip->set_number('2440815')->is_valid_number, '神奈川県横浜市戸塚区下倉田町');
ok($zip->set_number('2440816')->is_valid_number, '神奈川県横浜市戸塚区上倉田町');
ok($zip->set_number('2440817')->is_valid_number, '神奈川県横浜市戸塚区吉田町');
ok($zip->set_number('2440841')->is_valid_number, '神奈川県横浜市栄区長沼町');
ok($zip->set_number('2440842')->is_valid_number, '神奈川県横浜市栄区飯島町');
ok($zip->set_number('2440843')->is_valid_number, '神奈川県横浜市栄区長尾台町');
ok($zip->set_number('2440844')->is_valid_number, '神奈川県横浜市栄区田谷町');
ok($zip->set_number('2440845')->is_valid_number, '神奈川県横浜市栄区金井町');
ok($zip->set_number('2450000')->is_valid_number, '神奈川県横浜市泉区以下に掲載がない場合');
ok($zip->set_number('2450001')->is_valid_number, '神奈川県横浜市泉区池の谷');
ok($zip->set_number('2450002')->is_valid_number, '神奈川県横浜市泉区緑園');
ok($zip->set_number('2450003')->is_valid_number, '神奈川県横浜市泉区岡津町');
ok($zip->set_number('2450004')->is_valid_number, '神奈川県横浜市泉区領家');
ok($zip->set_number('2450005')->is_valid_number, '神奈川県横浜市泉区白百合');
ok($zip->set_number('2450006')->is_valid_number, '神奈川県横浜市泉区西が岡');
ok($zip->set_number('2450007')->is_valid_number, '神奈川県横浜市泉区桂坂');
ok($zip->set_number('2450008')->is_valid_number, '神奈川県横浜市泉区弥生台');
ok($zip->set_number('2450009')->is_valid_number, '神奈川県横浜市泉区新橋町');
ok($zip->set_number('2450011')->is_valid_number, '神奈川県横浜市泉区中田町');
ok($zip->set_number('2450012')->is_valid_number, '神奈川県横浜市泉区中田北');
ok($zip->set_number('2450013')->is_valid_number, '神奈川県横浜市泉区中田東');
ok($zip->set_number('2450014')->is_valid_number, '神奈川県横浜市泉区中田南');
ok($zip->set_number('2450015')->is_valid_number, '神奈川県横浜市泉区中田西');
ok($zip->set_number('2450016')->is_valid_number, '神奈川県横浜市泉区和泉町');
ok($zip->set_number('2450017')->is_valid_number, '神奈川県横浜市泉区下飯田町');
ok($zip->set_number('2450018')->is_valid_number, '神奈川県横浜市泉区上飯田町');
ok($zip->set_number('2450021')->is_valid_number, '神奈川県横浜市泉区下和泉');
ok($zip->set_number('2450022')->is_valid_number, '神奈川県横浜市泉区和泉が丘');
ok($zip->set_number('2450023')->is_valid_number, '神奈川県横浜市泉区和泉中央南');
ok($zip->set_number('2450024')->is_valid_number, '神奈川県横浜市泉区和泉中央北');
ok($zip->set_number('2450051')->is_valid_number, '神奈川県横浜市戸塚区名瀬町');
ok($zip->set_number('2450052')->is_valid_number, '神奈川県横浜市戸塚区秋葉町');
ok($zip->set_number('2450053')->is_valid_number, '神奈川県横浜市戸塚区上矢部町');
ok($zip->set_number('2450061')->is_valid_number, '神奈川県横浜市戸塚区汲沢');
ok($zip->set_number('2450062')->is_valid_number, '神奈川県横浜市戸塚区汲沢町');
ok($zip->set_number('2450063')->is_valid_number, '神奈川県横浜市戸塚区原宿');
ok($zip->set_number('2450064')->is_valid_number, '神奈川県横浜市戸塚区影取町');
ok($zip->set_number('2450065')->is_valid_number, '神奈川県横浜市戸塚区東俣野町');
ok($zip->set_number('2450066')->is_valid_number, '神奈川県横浜市戸塚区俣野町');
ok($zip->set_number('2450067')->is_valid_number, '神奈川県横浜市戸塚区深谷町');
ok($zip->set_number('2460000')->is_valid_number, '神奈川県横浜市瀬谷区以下に掲載がない場合');
ok($zip->set_number('2460001')->is_valid_number, '神奈川県横浜市瀬谷区卸本町');
ok($zip->set_number('2460002')->is_valid_number, '神奈川県横浜市瀬谷区北町');
ok($zip->set_number('2460003')->is_valid_number, '神奈川県横浜市瀬谷区瀬谷町');
ok($zip->set_number('2460004')->is_valid_number, '神奈川県横浜市瀬谷区中屋敷');
ok($zip->set_number('2460005')->is_valid_number, '神奈川県横浜市瀬谷区竹村町');
ok($zip->set_number('2460006')->is_valid_number, '神奈川県横浜市瀬谷区上瀬谷町');
ok($zip->set_number('2460007')->is_valid_number, '神奈川県横浜市瀬谷区目黒町');
ok($zip->set_number('2460008')->is_valid_number, '神奈川県横浜市瀬谷区五貫目町');
ok($zip->set_number('2460011')->is_valid_number, '神奈川県横浜市瀬谷区東野台');
ok($zip->set_number('2460012')->is_valid_number, '神奈川県横浜市瀬谷区東野');
ok($zip->set_number('2460013')->is_valid_number, '神奈川県横浜市瀬谷区相沢');
ok($zip->set_number('2460014')->is_valid_number, '神奈川県横浜市瀬谷区中央');
ok($zip->set_number('2460015')->is_valid_number, '神奈川県横浜市瀬谷区本郷');
ok($zip->set_number('2460021')->is_valid_number, '神奈川県横浜市瀬谷区二ツ橋町');
ok($zip->set_number('2460022')->is_valid_number, '神奈川県横浜市瀬谷区三ツ境');
ok($zip->set_number('2460023')->is_valid_number, '神奈川県横浜市瀬谷区阿久和東');
ok($zip->set_number('2460025')->is_valid_number, '神奈川県横浜市瀬谷区阿久和西');
ok($zip->set_number('2460026')->is_valid_number, '神奈川県横浜市瀬谷区阿久和南');
ok($zip->set_number('2460031')->is_valid_number, '神奈川県横浜市瀬谷区瀬谷');
ok($zip->set_number('2460032')->is_valid_number, '神奈川県横浜市瀬谷区南台');
ok($zip->set_number('2460034')->is_valid_number, '神奈川県横浜市瀬谷区南瀬谷');
ok($zip->set_number('2460035')->is_valid_number, '神奈川県横浜市瀬谷区下瀬谷');
ok($zip->set_number('2460036')->is_valid_number, '神奈川県横浜市瀬谷区北新');
ok($zip->set_number('2460037')->is_valid_number, '神奈川県横浜市瀬谷区橋戸');
ok($zip->set_number('2460038')->is_valid_number, '神奈川県横浜市瀬谷区宮沢');
ok($zip->set_number('2470000')->is_valid_number, '神奈川県横浜市栄区以下に掲載がない場合');
ok($zip->set_number('2470001')->is_valid_number, '神奈川県横浜市栄区小菅ケ谷町');
ok($zip->set_number('2470002')->is_valid_number, '神奈川県横浜市栄区小山台');
ok($zip->set_number('2470003')->is_valid_number, '神奈川県横浜市栄区鍛冶ケ谷町');
ok($zip->set_number('2470004')->is_valid_number, '神奈川県横浜市栄区柏陽');
ok($zip->set_number('2470005')->is_valid_number, '神奈川県横浜市栄区桂町');
ok($zip->set_number('2470006')->is_valid_number, '神奈川県横浜市栄区笠間');
ok($zip->set_number('2470007')->is_valid_number, '神奈川県横浜市栄区小菅ケ谷');
ok($zip->set_number('2470008')->is_valid_number, '神奈川県横浜市栄区本郷台');
ok($zip->set_number('2470009')->is_valid_number, '神奈川県横浜市栄区鍛冶ケ谷');
ok($zip->set_number('2470011')->is_valid_number, '神奈川県横浜市栄区元大橋');
ok($zip->set_number('2470012')->is_valid_number, '神奈川県横浜市栄区若竹町');
ok($zip->set_number('2470013')->is_valid_number, '神奈川県横浜市栄区上郷町');
ok($zip->set_number('2470014')->is_valid_number, '神奈川県横浜市栄区公田町');
ok($zip->set_number('2470015')->is_valid_number, '神奈川県横浜市栄区中野町');
ok($zip->set_number('2470021')->is_valid_number, '神奈川県横浜市栄区東上郷町');
ok($zip->set_number('2470022')->is_valid_number, '神奈川県横浜市栄区庄戸');
ok($zip->set_number('2470023')->is_valid_number, '神奈川県横浜市栄区長倉町');
ok($zip->set_number('2470024')->is_valid_number, '神奈川県横浜市栄区野七里');
ok($zip->set_number('2470025')->is_valid_number, '神奈川県横浜市栄区上之町');
ok($zip->set_number('2470026')->is_valid_number, '神奈川県横浜市栄区犬山町');
ok($zip->set_number('2470027')->is_valid_number, '神奈川県横浜市栄区尾月');
ok($zip->set_number('2470028')->is_valid_number, '神奈川県横浜市栄区亀井町');
ok($zip->set_number('2470031')->is_valid_number, '神奈川県横浜市栄区桂台北');
ok($zip->set_number('2470032')->is_valid_number, '神奈川県横浜市栄区桂台東');
ok($zip->set_number('2470033')->is_valid_number, '神奈川県横浜市栄区桂台南');
ok($zip->set_number('2470034')->is_valid_number, '神奈川県横浜市栄区桂台中');
ok($zip->set_number('2470035')->is_valid_number, '神奈川県横浜市栄区桂台西');
ok($zip->set_number('2470051')->is_valid_number, '神奈川県鎌倉市岩瀬');
ok($zip->set_number('2470052')->is_valid_number, '神奈川県鎌倉市今泉');
ok($zip->set_number('2470053')->is_valid_number, '神奈川県鎌倉市今泉台');
ok($zip->set_number('2470054')->is_valid_number, '神奈川県鎌倉市高野');
ok($zip->set_number('2470055')->is_valid_number, '神奈川県鎌倉市小袋谷');
ok($zip->set_number('2470056')->is_valid_number, '神奈川県鎌倉市大船');
ok($zip->set_number('2470061')->is_valid_number, '神奈川県鎌倉市台');
ok($zip->set_number('2470062')->is_valid_number, '神奈川県鎌倉市山ノ内');
ok($zip->set_number('2470063')->is_valid_number, '神奈川県鎌倉市梶原');
ok($zip->set_number('2470064')->is_valid_number, '神奈川県鎌倉市寺分');
ok($zip->set_number('2470065')->is_valid_number, '神奈川県鎌倉市上町屋');
ok($zip->set_number('2470066')->is_valid_number, '神奈川県鎌倉市山崎');
ok($zip->set_number('2470071')->is_valid_number, '神奈川県鎌倉市玉縄');
ok($zip->set_number('2470072')->is_valid_number, '神奈川県鎌倉市岡本');
ok($zip->set_number('2470073')->is_valid_number, '神奈川県鎌倉市植木');
ok($zip->set_number('2470074')->is_valid_number, '神奈川県鎌倉市城廻');
ok($zip->set_number('2470075')->is_valid_number, '神奈川県鎌倉市関谷');
ok($zip->set_number('2480000')->is_valid_number, '神奈川県鎌倉市以下に掲載がない場合');
ok($zip->set_number('2480001')->is_valid_number, '神奈川県鎌倉市十二所');
ok($zip->set_number('2480002')->is_valid_number, '神奈川県鎌倉市二階堂');
ok($zip->set_number('2480003')->is_valid_number, '神奈川県鎌倉市浄明寺');
ok($zip->set_number('2480004')->is_valid_number, '神奈川県鎌倉市西御門');
ok($zip->set_number('2480005')->is_valid_number, '神奈川県鎌倉市雪ノ下');
ok($zip->set_number('2480006')->is_valid_number, '神奈川県鎌倉市小町');
ok($zip->set_number('2480007')->is_valid_number, '神奈川県鎌倉市大町');
ok($zip->set_number('2480011')->is_valid_number, '神奈川県鎌倉市扇ガ谷');
ok($zip->set_number('2480012')->is_valid_number, '神奈川県鎌倉市御成町');
ok($zip->set_number('2480013')->is_valid_number, '神奈川県鎌倉市材木座');
ok($zip->set_number('2480014')->is_valid_number, '神奈川県鎌倉市由比ガ浜');
ok($zip->set_number('2480015')->is_valid_number, '神奈川県鎌倉市笹目町');
ok($zip->set_number('2480016')->is_valid_number, '神奈川県鎌倉市長谷');
ok($zip->set_number('2480017')->is_valid_number, '神奈川県鎌倉市佐助');
ok($zip->set_number('2480021')->is_valid_number, '神奈川県鎌倉市坂ノ下');
ok($zip->set_number('2480022')->is_valid_number, '神奈川県鎌倉市常盤');
ok($zip->set_number('2480023')->is_valid_number, '神奈川県鎌倉市極楽寺');
ok($zip->set_number('2480024')->is_valid_number, '神奈川県鎌倉市稲村ガ崎');
ok($zip->set_number('2480025')->is_valid_number, '神奈川県鎌倉市七里ガ浜東');
ok($zip->set_number('2480026')->is_valid_number, '神奈川県鎌倉市七里ガ浜');
ok($zip->set_number('2480027')->is_valid_number, '神奈川県鎌倉市笛田');
ok($zip->set_number('2480031')->is_valid_number, '神奈川県鎌倉市鎌倉山');
ok($zip->set_number('2480032')->is_valid_number, '神奈川県鎌倉市津');
ok($zip->set_number('2480033')->is_valid_number, '神奈川県鎌倉市腰越');
ok($zip->set_number('2480034')->is_valid_number, '神奈川県鎌倉市津西');
ok($zip->set_number('2480035')->is_valid_number, '神奈川県鎌倉市西鎌倉');
ok($zip->set_number('2480036')->is_valid_number, '神奈川県鎌倉市手広');
ok($zip->set_number('2490000')->is_valid_number, '神奈川県逗子市以下に掲載がない場合');
ok($zip->set_number('2490001')->is_valid_number, '神奈川県逗子市久木');
ok($zip->set_number('2490002')->is_valid_number, '神奈川県逗子市山の根');
ok($zip->set_number('2490003')->is_valid_number, '神奈川県逗子市池子');
ok($zip->set_number('2490004')->is_valid_number, '神奈川県逗子市沼間');
ok($zip->set_number('2490005')->is_valid_number, '神奈川県逗子市桜山');
ok($zip->set_number('2490006')->is_valid_number, '神奈川県逗子市逗子');
ok($zip->set_number('2490007')->is_valid_number, '神奈川県逗子市新宿');
ok($zip->set_number('2490008')->is_valid_number, '神奈川県逗子市小坪');
ok($zip->set_number('2500000')->is_valid_number, '神奈川県小田原市以下に掲載がない場合');
ok($zip->set_number('2500001')->is_valid_number, '神奈川県小田原市扇町');
ok($zip->set_number('2500002')->is_valid_number, '神奈川県小田原市寿町');
ok($zip->set_number('2500003')->is_valid_number, '神奈川県小田原市東町');
ok($zip->set_number('2500004')->is_valid_number, '神奈川県小田原市浜町');
ok($zip->set_number('2500005')->is_valid_number, '神奈川県小田原市中町');
ok($zip->set_number('2500011')->is_valid_number, '神奈川県小田原市栄町');
ok($zip->set_number('2500012')->is_valid_number, '神奈川県小田原市本町');
ok($zip->set_number('2500013')->is_valid_number, '神奈川県小田原市南町');
ok($zip->set_number('2500014')->is_valid_number, '神奈川県小田原市城内');
ok($zip->set_number('2500021')->is_valid_number, '神奈川県小田原市早川');
ok($zip->set_number('2500022')->is_valid_number, '神奈川県小田原市石橋');
ok($zip->set_number('2500023')->is_valid_number, '神奈川県小田原市米神');
ok($zip->set_number('2500024')->is_valid_number, '神奈川県小田原市根府川');
ok($zip->set_number('2500025')->is_valid_number, '神奈川県小田原市江之浦');
ok($zip->set_number('2500031')->is_valid_number, '神奈川県小田原市入生田');
ok($zip->set_number('2500032')->is_valid_number, '神奈川県小田原市風祭');
ok($zip->set_number('2500033')->is_valid_number, '神奈川県小田原市水之尾');
ok($zip->set_number('2500034')->is_valid_number, '神奈川県小田原市板橋');
ok($zip->set_number('2500035')->is_valid_number, '神奈川県小田原市南板橋');
ok($zip->set_number('2500041')->is_valid_number, '神奈川県小田原市池上');
ok($zip->set_number('2500042')->is_valid_number, '神奈川県小田原市荻窪');
ok($zip->set_number('2500043')->is_valid_number, '神奈川県小田原市谷津');
ok($zip->set_number('2500044')->is_valid_number, '神奈川県小田原市緑');
ok($zip->set_number('2500045')->is_valid_number, '神奈川県小田原市城山');
ok($zip->set_number('2500046')->is_valid_number, '神奈川県小田原市十字');
ok($zip->set_number('2500051')->is_valid_number, '神奈川県小田原市北ノ窪');
ok($zip->set_number('2500052')->is_valid_number, '神奈川県小田原市府川');
ok($zip->set_number('2500053')->is_valid_number, '神奈川県小田原市穴部');
ok($zip->set_number('2500054')->is_valid_number, '神奈川県小田原市多古');
ok($zip->set_number('2500055')->is_valid_number, '神奈川県小田原市久野');
ok($zip->set_number('2500056')->is_valid_number, '神奈川県小田原市井細田');
ok($zip->set_number('2500100')->is_valid_number, '神奈川県南足柄市以下に掲載がない場合');
ok($zip->set_number('2500101')->is_valid_number, '神奈川県南足柄市班目');
ok($zip->set_number('2500102')->is_valid_number, '神奈川県南足柄市千津島');
ok($zip->set_number('2500103')->is_valid_number, '神奈川県南足柄市壗下');
ok($zip->set_number('2500104')->is_valid_number, '神奈川県南足柄市向田');
ok($zip->set_number('2500105')->is_valid_number, '神奈川県南足柄市関本');
ok($zip->set_number('2500106')->is_valid_number, '神奈川県南足柄市怒田');
ok($zip->set_number('2500107')->is_valid_number, '神奈川県南足柄市小市');
ok($zip->set_number('2500111')->is_valid_number, '神奈川県南足柄市竹松');
ok($zip->set_number('2500112')->is_valid_number, '神奈川県南足柄市和田河原');
ok($zip->set_number('2500113')->is_valid_number, '神奈川県南足柄市岩原');
ok($zip->set_number('2500114')->is_valid_number, '神奈川県南足柄市北窪');
ok($zip->set_number('2500115')->is_valid_number, '神奈川県南足柄市沼田');
ok($zip->set_number('2500116')->is_valid_number, '神奈川県南足柄市三竹');
ok($zip->set_number('2500117')->is_valid_number, '神奈川県南足柄市塚原');
ok($zip->set_number('2500121')->is_valid_number, '神奈川県南足柄市広町');
ok($zip->set_number('2500122')->is_valid_number, '神奈川県南足柄市飯沢');
ok($zip->set_number('2500123')->is_valid_number, '神奈川県南足柄市中沼');
ok($zip->set_number('2500124')->is_valid_number, '神奈川県南足柄市生駒');
ok($zip->set_number('2500125')->is_valid_number, '神奈川県南足柄市駒形新宿');
ok($zip->set_number('2500126')->is_valid_number, '神奈川県南足柄市狩野');
ok($zip->set_number('2500127')->is_valid_number, '神奈川県南足柄市大雄町');
ok($zip->set_number('2500131')->is_valid_number, '神奈川県南足柄市内山');
ok($zip->set_number('2500132')->is_valid_number, '神奈川県南足柄市弘西寺');
ok($zip->set_number('2500133')->is_valid_number, '神奈川県南足柄市福泉');
ok($zip->set_number('2500134')->is_valid_number, '神奈川県南足柄市雨坪');
ok($zip->set_number('2500135')->is_valid_number, '神奈川県南足柄市苅野');
ok($zip->set_number('2500136')->is_valid_number, '神奈川県南足柄市矢倉沢');
ok($zip->set_number('2500201')->is_valid_number, '神奈川県小田原市曽我大沢');
ok($zip->set_number('2500202')->is_valid_number, '神奈川県小田原市上曽我');
ok($zip->set_number('2500203')->is_valid_number, '神奈川県小田原市曽我岸');
ok($zip->set_number('2500204')->is_valid_number, '神奈川県小田原市曽我谷津');
ok($zip->set_number('2500205')->is_valid_number, '神奈川県小田原市曽我別所');
ok($zip->set_number('2500206')->is_valid_number, '神奈川県小田原市曽我原');
ok($zip->set_number('2500207')->is_valid_number, '神奈川県小田原市曽我光海');
ok($zip->set_number('2500208')->is_valid_number, '神奈川県小田原市下大井');
ok($zip->set_number('2500211')->is_valid_number, '神奈川県小田原市鬼柳');
ok($zip->set_number('2500212')->is_valid_number, '神奈川県小田原市西大友');
ok($zip->set_number('2500213')->is_valid_number, '神奈川県小田原市東大友');
ok($zip->set_number('2500214')->is_valid_number, '神奈川県小田原市永塚');
ok($zip->set_number('2500215')->is_valid_number, '神奈川県小田原市千代');
ok($zip->set_number('2500216')->is_valid_number, '神奈川県小田原市高田');
ok($zip->set_number('2500217')->is_valid_number, '神奈川県小田原市別堀');
ok($zip->set_number('2500218')->is_valid_number, '神奈川県小田原市延清');
ok($zip->set_number('2500311')->is_valid_number, '神奈川県足柄下郡箱根町湯本');
ok($zip->set_number('2500312')->is_valid_number, '神奈川県足柄下郡箱根町湯本茶屋');
ok($zip->set_number('2500313')->is_valid_number, '神奈川県足柄下郡箱根町須雲川');
ok($zip->set_number('2500314')->is_valid_number, '神奈川県足柄下郡箱根町畑宿');
ok($zip->set_number('2500315')->is_valid_number, '神奈川県足柄下郡箱根町塔之澤');
ok($zip->set_number('2500401')->is_valid_number, '神奈川県足柄下郡箱根町宮城野');
ok($zip->set_number('2500402')->is_valid_number, '神奈川県足柄下郡箱根町木賀');
ok($zip->set_number('2500403')->is_valid_number, '神奈川県足柄下郡箱根町底倉');
ok($zip->set_number('2500404')->is_valid_number, '神奈川県足柄下郡箱根町宮ノ下');
ok($zip->set_number('2500405')->is_valid_number, '神奈川県足柄下郡箱根町大平台');
ok($zip->set_number('2500406')->is_valid_number, '神奈川県足柄下郡箱根町小涌谷');
ok($zip->set_number('2500407')->is_valid_number, '神奈川県足柄下郡箱根町二ノ平');
ok($zip->set_number('2500408')->is_valid_number, '神奈川県足柄下郡箱根町強羅');
ok($zip->set_number('2500500')->is_valid_number, '神奈川県足柄下郡箱根町以下に掲載がない場合');
ok($zip->set_number('2500521')->is_valid_number, '神奈川県足柄下郡箱根町箱根');
ok($zip->set_number('2500522')->is_valid_number, '神奈川県足柄下郡箱根町元箱根');
ok($zip->set_number('2500523')->is_valid_number, '神奈川県足柄下郡箱根町芦之湯');
ok($zip->set_number('2500631')->is_valid_number, '神奈川県足柄下郡箱根町仙石原');
ok($zip->set_number('2500851')->is_valid_number, '神奈川県小田原市曽比');
ok($zip->set_number('2500852')->is_valid_number, '神奈川県小田原市栢山');
ok($zip->set_number('2500853')->is_valid_number, '神奈川県小田原市堀之内');
ok($zip->set_number('2500854')->is_valid_number, '神奈川県小田原市飯田岡');
ok($zip->set_number('2500855')->is_valid_number, '神奈川県小田原市清水新田');
ok($zip->set_number('2500856')->is_valid_number, '神奈川県小田原市新屋');
ok($zip->set_number('2500857')->is_valid_number, '神奈川県小田原市柳新田');
ok($zip->set_number('2500858')->is_valid_number, '神奈川県小田原市小台');
ok($zip->set_number('2500861')->is_valid_number, '神奈川県小田原市桑原');
ok($zip->set_number('2500862')->is_valid_number, '神奈川県小田原市成田');
ok($zip->set_number('2500863')->is_valid_number, '神奈川県小田原市飯泉');
ok($zip->set_number('2500864')->is_valid_number, '神奈川県小田原市穴部新田');
ok($zip->set_number('2500865')->is_valid_number, '神奈川県小田原市蓮正寺');
ok($zip->set_number('2500866')->is_valid_number, '神奈川県小田原市中曽根');
ok($zip->set_number('2500871')->is_valid_number, '神奈川県小田原市下堀');
ok($zip->set_number('2500872')->is_valid_number, '神奈川県小田原市中里');
ok($zip->set_number('2500873')->is_valid_number, '神奈川県小田原市矢作');
ok($zip->set_number('2500874')->is_valid_number, '神奈川県小田原市鴨宮');
ok($zip->set_number('2500875')->is_valid_number, '神奈川県小田原市南鴨宮');
ok($zip->set_number('2500876')->is_valid_number, '神奈川県小田原市中新田');
ok($zip->set_number('2500877')->is_valid_number, '神奈川県小田原市上新田');
ok($zip->set_number('2500878')->is_valid_number, '神奈川県小田原市下新田');
ok($zip->set_number('2510000')->is_valid_number, '神奈川県藤沢市以下に掲載がない場合');
ok($zip->set_number('2510001')->is_valid_number, '神奈川県藤沢市西富');
ok($zip->set_number('2510002')->is_valid_number, '神奈川県藤沢市大鋸');
ok($zip->set_number('2510003')->is_valid_number, '神奈川県藤沢市柄沢');
ok($zip->set_number('2510004')->is_valid_number, '神奈川県藤沢市藤が岡');
ok($zip->set_number('2510005')->is_valid_number, '神奈川県藤沢市並木台');
ok($zip->set_number('2510011')->is_valid_number, '神奈川県藤沢市渡内');
ok($zip->set_number('2510012')->is_valid_number, '神奈川県藤沢市村岡東');
ok($zip->set_number('2510013')->is_valid_number, '神奈川県藤沢市小塚');
ok($zip->set_number('2510014')->is_valid_number, '神奈川県藤沢市宮前');
ok($zip->set_number('2510015')->is_valid_number, '神奈川県藤沢市川名');
ok($zip->set_number('2510016')->is_valid_number, '神奈川県藤沢市弥勒寺');
ok($zip->set_number('2510017')->is_valid_number, '神奈川県藤沢市高谷');
ok($zip->set_number('2510021')->is_valid_number, '神奈川県藤沢市鵠沼神明');
ok($zip->set_number('2510022')->is_valid_number, '神奈川県藤沢市鵠沼');
ok($zip->set_number('2510023')->is_valid_number, '神奈川県藤沢市鵠沼花沢町');
ok($zip->set_number('2510024')->is_valid_number, '神奈川県藤沢市鵠沼橘');
ok($zip->set_number('2510025')->is_valid_number, '神奈川県藤沢市鵠沼石上');
ok($zip->set_number('2510026')->is_valid_number, '神奈川県藤沢市鵠沼東');
ok($zip->set_number('2510027')->is_valid_number, '神奈川県藤沢市鵠沼桜が岡');
ok($zip->set_number('2510028')->is_valid_number, '神奈川県藤沢市本鵠沼');
ok($zip->set_number('2510031')->is_valid_number, '神奈川県藤沢市鵠沼藤が谷');
ok($zip->set_number('2510032')->is_valid_number, '神奈川県藤沢市片瀬');
ok($zip->set_number('2510033')->is_valid_number, '神奈川県藤沢市片瀬山');
ok($zip->set_number('2510034')->is_valid_number, '神奈川県藤沢市片瀬目白山');
ok($zip->set_number('2510035')->is_valid_number, '神奈川県藤沢市片瀬海岸');
ok($zip->set_number('2510036')->is_valid_number, '神奈川県藤沢市江の島');
ok($zip->set_number('2510037')->is_valid_number, '神奈川県藤沢市鵠沼海岸');
ok($zip->set_number('2510038')->is_valid_number, '神奈川県藤沢市鵠沼松が岡');
ok($zip->set_number('2510041')->is_valid_number, '神奈川県藤沢市辻堂神台');
ok($zip->set_number('2510042')->is_valid_number, '神奈川県藤沢市辻堂新町');
ok($zip->set_number('2510043')->is_valid_number, '神奈川県藤沢市辻堂元町');
ok($zip->set_number('2510044')->is_valid_number, '神奈川県藤沢市辻堂太平台');
ok($zip->set_number('2510045')->is_valid_number, '神奈川県藤沢市辻堂東海岸');
ok($zip->set_number('2510046')->is_valid_number, '神奈川県藤沢市辻堂西海岸');
ok($zip->set_number('2510047')->is_valid_number, '神奈川県藤沢市辻堂');
ok($zip->set_number('2510051')->is_valid_number, '神奈川県藤沢市白旗');
ok($zip->set_number('2510052')->is_valid_number, '神奈川県藤沢市藤沢');
ok($zip->set_number('2510053')->is_valid_number, '神奈川県藤沢市本町');
ok($zip->set_number('2510054')->is_valid_number, '神奈川県藤沢市朝日町');
ok($zip->set_number('2510055')->is_valid_number, '神奈川県藤沢市南藤沢');
ok($zip->set_number('2510056')->is_valid_number, '神奈川県藤沢市羽鳥');
ok($zip->set_number('2510057')->is_valid_number, '神奈川県藤沢市城南');
ok($zip->set_number('2510861')->is_valid_number, '神奈川県藤沢市大庭');
ok($zip->set_number('2510862')->is_valid_number, '神奈川県藤沢市稲荷');
ok($zip->set_number('2510871')->is_valid_number, '神奈川県藤沢市善行');
ok($zip->set_number('2510872')->is_valid_number, '神奈川県藤沢市立石');
ok($zip->set_number('2510873')->is_valid_number, '神奈川県藤沢市みその台');
ok($zip->set_number('2510874')->is_valid_number, '神奈川県藤沢市花の木');
ok($zip->set_number('2510875')->is_valid_number, '神奈川県藤沢市本藤沢');
ok($zip->set_number('2510876')->is_valid_number, '神奈川県藤沢市善行坂');
ok($zip->set_number('2510877')->is_valid_number, '神奈川県藤沢市善行団地');
ok($zip->set_number('2520000')->is_valid_number, '神奈川県座間市以下に掲載がない場合');
ok($zip->set_number('2520001')->is_valid_number, '神奈川県座間市相模が丘');
ok($zip->set_number('2520002')->is_valid_number, '神奈川県座間市小松原');
ok($zip->set_number('2520003')->is_valid_number, '神奈川県座間市ひばりが丘');
ok($zip->set_number('2520004')->is_valid_number, '神奈川県座間市東原');
ok($zip->set_number('2520005')->is_valid_number, '神奈川県座間市さがみ野');
ok($zip->set_number('2520011')->is_valid_number, '神奈川県座間市相武台');
ok($zip->set_number('2520012')->is_valid_number, '神奈川県座間市広野台');
ok($zip->set_number('2520013')->is_valid_number, '神奈川県座間市栗原');
ok($zip->set_number('2520014')->is_valid_number, '神奈川県座間市栗原中央');
ok($zip->set_number('2520015')->is_valid_number, '神奈川県座間市南栗原');
ok($zip->set_number('2520016')->is_valid_number, '神奈川県座間市西栗原');
ok($zip->set_number('2520021')->is_valid_number, '神奈川県座間市緑ケ丘');
ok($zip->set_number('2520022')->is_valid_number, '神奈川県座間市明王');
ok($zip->set_number('2520023')->is_valid_number, '神奈川県座間市立野台');
ok($zip->set_number('2520025')->is_valid_number, '神奈川県座間市四ツ谷');
ok($zip->set_number('2520026')->is_valid_number, '神奈川県座間市新田宿');
ok($zip->set_number('2520027')->is_valid_number, '神奈川県座間市座間');
ok($zip->set_number('2520028')->is_valid_number, '神奈川県座間市入谷東');
ok($zip->set_number('2520029')->is_valid_number, '神奈川県座間市入谷西');
ok($zip->set_number('2520100')->is_valid_number, '神奈川県相模原市緑区以下に掲載がない場合');
ok($zip->set_number('2520101')->is_valid_number, '神奈川県相模原市緑区町屋');
ok($zip->set_number('2520102')->is_valid_number, '神奈川県相模原市緑区原宿');
ok($zip->set_number('2520103')->is_valid_number, '神奈川県相模原市緑区原宿南');
ok($zip->set_number('2520104')->is_valid_number, '神奈川県相模原市緑区向原');
ok($zip->set_number('2520105')->is_valid_number, '神奈川県相模原市緑区久保沢');
ok($zip->set_number('2520106')->is_valid_number, '神奈川県相模原市緑区広田');
ok($zip->set_number('2520111')->is_valid_number, '神奈川県相模原市緑区川尻');
ok($zip->set_number('2520112')->is_valid_number, '神奈川県相模原市緑区若葉台');
ok($zip->set_number('2520113')->is_valid_number, '神奈川県相模原市緑区谷ヶ原');
ok($zip->set_number('2520114')->is_valid_number, '神奈川県相模原市緑区葉山島');
ok($zip->set_number('2520115')->is_valid_number, '神奈川県相模原市緑区小倉');
ok($zip->set_number('2520116')->is_valid_number, '神奈川県相模原市緑区城山');
ok($zip->set_number('2520117')->is_valid_number, '神奈川県相模原市緑区中沢');
ok($zip->set_number('2520124')->is_valid_number, '神奈川県相模原市緑区田名');
ok($zip->set_number('2520131')->is_valid_number, '神奈川県相模原市緑区西橋本');
ok($zip->set_number('2520132')->is_valid_number, '神奈川県相模原市緑区橋本台');
ok($zip->set_number('2520134')->is_valid_number, '神奈川県相模原市緑区下九沢');
ok($zip->set_number('2520135')->is_valid_number, '神奈川県相模原市緑区大島');
ok($zip->set_number('2520136')->is_valid_number, '神奈川県相模原市緑区上九沢');
ok($zip->set_number('2520137')->is_valid_number, '神奈川県相模原市緑区二本松');
ok($zip->set_number('2520141')->is_valid_number, '神奈川県相模原市緑区相原');
ok($zip->set_number('2520142')->is_valid_number, '神奈川県相模原市緑区元橋本町');
ok($zip->set_number('2520143')->is_valid_number, '神奈川県相模原市緑区橋本');
ok($zip->set_number('2520144')->is_valid_number, '神奈川県相模原市緑区東橋本');
ok($zip->set_number('2520146')->is_valid_number, '神奈川県相模原市緑区大山町');
ok($zip->set_number('2520151')->is_valid_number, '神奈川県相模原市緑区三井');
ok($zip->set_number('2520152')->is_valid_number, '神奈川県相模原市緑区太井');
ok($zip->set_number('2520153')->is_valid_number, '神奈川県相模原市緑区根小屋');
ok($zip->set_number('2520154')->is_valid_number, '神奈川県相模原市緑区長竹');
ok($zip->set_number('2520155')->is_valid_number, '神奈川県相模原市緑区鳥屋');
ok($zip->set_number('2520156')->is_valid_number, '神奈川県相模原市緑区青山');
ok($zip->set_number('2520157')->is_valid_number, '神奈川県相模原市緑区中野');
ok($zip->set_number('2520158')->is_valid_number, '神奈川県相模原市緑区又野');
ok($zip->set_number('2520159')->is_valid_number, '神奈川県相模原市緑区三ケ木');
ok($zip->set_number('2520161')->is_valid_number, '神奈川県相模原市緑区青野原');
ok($zip->set_number('2520162')->is_valid_number, '神奈川県相模原市緑区青根');
ok($zip->set_number('2520171')->is_valid_number, '神奈川県相模原市緑区与瀬');
ok($zip->set_number('2520172')->is_valid_number, '神奈川県相模原市緑区与瀬本町');
ok($zip->set_number('2520173')->is_valid_number, '神奈川県相模原市緑区小原');
ok($zip->set_number('2520174')->is_valid_number, '神奈川県相模原市緑区千木良');
ok($zip->set_number('2520175')->is_valid_number, '神奈川県相模原市緑区若柳');
ok($zip->set_number('2520176')->is_valid_number, '神奈川県相模原市緑区寸沢嵐(その他)');
ok($zip->set_number('2520181')->is_valid_number, '神奈川県相模原市緑区佐野川');
ok($zip->set_number('2520182')->is_valid_number, '神奈川県相模原市緑区澤井');
ok($zip->set_number('2520183')->is_valid_number, '神奈川県相模原市緑区吉野');
ok($zip->set_number('2520184')->is_valid_number, '神奈川県相模原市緑区小渕');
ok($zip->set_number('2520185')->is_valid_number, '神奈川県相模原市緑区日連');
ok($zip->set_number('2520186')->is_valid_number, '神奈川県相模原市緑区牧野');
ok($zip->set_number('2520187')->is_valid_number, '神奈川県相模原市緑区名倉');
ok($zip->set_number('2520188')->is_valid_number, '神奈川県相模原市緑区寸沢嵐(新戸)');
ok($zip->set_number('2520200')->is_valid_number, '神奈川県相模原市中央区以下に掲載がない場合');
ok($zip->set_number('2520201')->is_valid_number, '神奈川県相模原市中央区上矢部');
ok($zip->set_number('2520202')->is_valid_number, '神奈川県相模原市中央区淵野辺本町');
ok($zip->set_number('2520203')->is_valid_number, '神奈川県相模原市中央区東淵野辺');
ok($zip->set_number('2520205')->is_valid_number, '神奈川県相模原市中央区小山');
ok($zip->set_number('2520206')->is_valid_number, '神奈川県相模原市中央区淵野辺');
ok($zip->set_number('2520207')->is_valid_number, '神奈川県相模原市中央区矢部新町');
ok($zip->set_number('2520208')->is_valid_number, '神奈川県相模原市中央区矢部新田');
ok($zip->set_number('2520211')->is_valid_number, '神奈川県相模原市中央区宮下本町');
ok($zip->set_number('2520212')->is_valid_number, '神奈川県相模原市中央区宮下');
ok($zip->set_number('2520213')->is_valid_number, '神奈川県相模原市中央区すすきの町');
ok($zip->set_number('2520214')->is_valid_number, '神奈川県相模原市中央区向陽町');
ok($zip->set_number('2520215')->is_valid_number, '神奈川県相模原市中央区氷川町');
ok($zip->set_number('2520216')->is_valid_number, '神奈川県相模原市中央区清新');
ok($zip->set_number('2520217')->is_valid_number, '神奈川県相模原市中央区小町通');
ok($zip->set_number('2520221')->is_valid_number, '神奈川県相模原市中央区高根');
ok($zip->set_number('2520222')->is_valid_number, '神奈川県相模原市中央区由野台');
ok($zip->set_number('2520223')->is_valid_number, '神奈川県相模原市中央区松が丘');
ok($zip->set_number('2520224')->is_valid_number, '神奈川県相模原市中央区青葉');
ok($zip->set_number('2520225')->is_valid_number, '神奈川県相模原市中央区緑が丘');
ok($zip->set_number('2520226')->is_valid_number, '神奈川県相模原市中央区陽光台');
ok($zip->set_number('2520227')->is_valid_number, '神奈川県相模原市中央区光が丘');
ok($zip->set_number('2520228')->is_valid_number, '神奈川県相模原市中央区並木');
ok($zip->set_number('2520229')->is_valid_number, '神奈川県相模原市中央区弥栄');
ok($zip->set_number('2520231')->is_valid_number, '神奈川県相模原市中央区相模原');
ok($zip->set_number('2520232')->is_valid_number, '神奈川県相模原市中央区矢部');
ok($zip->set_number('2520233')->is_valid_number, '神奈川県相模原市中央区鹿沼台');
ok($zip->set_number('2520234')->is_valid_number, '神奈川県相模原市中央区共和');
ok($zip->set_number('2520235')->is_valid_number, '神奈川県相模原市中央区相生');
ok($zip->set_number('2520236')->is_valid_number, '神奈川県相模原市中央区富士見');
ok($zip->set_number('2520237')->is_valid_number, '神奈川県相模原市中央区千代田');
ok($zip->set_number('2520238')->is_valid_number, '神奈川県相模原市中央区星が丘');
ok($zip->set_number('2520239')->is_valid_number, '神奈川県相模原市中央区中央');
ok($zip->set_number('2520241')->is_valid_number, '神奈川県相模原市中央区横山台');
ok($zip->set_number('2520242')->is_valid_number, '神奈川県相模原市中央区横山');
ok($zip->set_number('2520243')->is_valid_number, '神奈川県相模原市中央区上溝');
ok($zip->set_number('2520244')->is_valid_number, '神奈川県相模原市中央区田名');
ok($zip->set_number('2520245')->is_valid_number, '神奈川県相模原市中央区田名塩田');
ok($zip->set_number('2520246')->is_valid_number, '神奈川県相模原市中央区水郷田名');
ok($zip->set_number('2520251')->is_valid_number, '神奈川県相模原市中央区大野台');
ok($zip->set_number('2520253')->is_valid_number, '神奈川県相模原市中央区南橋本');
ok($zip->set_number('2520254')->is_valid_number, '神奈川県相模原市中央区下九沢');
ok($zip->set_number('2520300')->is_valid_number, '神奈川県相模原市南区以下に掲載がない場合');
ok($zip->set_number('2520301')->is_valid_number, '神奈川県相模原市南区鵜野森');
ok($zip->set_number('2520302')->is_valid_number, '神奈川県相模原市南区上鶴間');
ok($zip->set_number('2520303')->is_valid_number, '神奈川県相模原市南区相模大野');
ok($zip->set_number('2520304')->is_valid_number, '神奈川県相模原市南区旭町');
ok($zip->set_number('2520305')->is_valid_number, '神奈川県相模原市南区豊町');
ok($zip->set_number('2520306')->is_valid_number, '神奈川県相模原市南区栄町');
ok($zip->set_number('2520307')->is_valid_number, '神奈川県相模原市南区文京');
ok($zip->set_number('2520311')->is_valid_number, '神奈川県相模原市南区東林間');
ok($zip->set_number('2520312')->is_valid_number, '神奈川県相模原市南区相南');
ok($zip->set_number('2520313')->is_valid_number, '神奈川県相模原市南区松が枝町');
ok($zip->set_number('2520314')->is_valid_number, '神奈川県相模原市南区南台');
ok($zip->set_number('2520315')->is_valid_number, '神奈川県相模原市南区桜台');
ok($zip->set_number('2520316')->is_valid_number, '神奈川県相模原市南区双葉');
ok($zip->set_number('2520317')->is_valid_number, '神奈川県相模原市南区御園');
ok($zip->set_number('2520318')->is_valid_number, '神奈川県相模原市南区上鶴間本町');
ok($zip->set_number('2520321')->is_valid_number, '神奈川県相模原市南区相模台');
ok($zip->set_number('2520322')->is_valid_number, '神奈川県相模原市南区相模台団地');
ok($zip->set_number('2520323')->is_valid_number, '神奈川県相模原市南区相武台団地');
ok($zip->set_number('2520324')->is_valid_number, '神奈川県相模原市南区相武台');
ok($zip->set_number('2520325')->is_valid_number, '神奈川県相模原市南区新磯野');
ok($zip->set_number('2520326')->is_valid_number, '神奈川県相模原市南区新戸');
ok($zip->set_number('2520327')->is_valid_number, '神奈川県相模原市南区磯部');
ok($zip->set_number('2520328')->is_valid_number, '神奈川県相模原市南区麻溝台');
ok($zip->set_number('2520329')->is_valid_number, '神奈川県相模原市南区北里');
ok($zip->set_number('2520331')->is_valid_number, '神奈川県相模原市南区大野台');
ok($zip->set_number('2520332')->is_valid_number, '神奈川県相模原市南区西大沼');
ok($zip->set_number('2520333')->is_valid_number, '神奈川県相模原市南区東大沼');
ok($zip->set_number('2520334')->is_valid_number, '神奈川県相模原市南区若松');
ok($zip->set_number('2520335')->is_valid_number, '神奈川県相模原市南区下溝');
ok($zip->set_number('2520336')->is_valid_number, '神奈川県相模原市南区当麻');
ok($zip->set_number('2520344')->is_valid_number, '神奈川県相模原市南区古淵');
ok($zip->set_number('2520801')->is_valid_number, '神奈川県藤沢市長後');
ok($zip->set_number('2520802')->is_valid_number, '神奈川県藤沢市高倉');
ok($zip->set_number('2520803')->is_valid_number, '神奈川県藤沢市今田');
ok($zip->set_number('2520804')->is_valid_number, '神奈川県藤沢市湘南台');
ok($zip->set_number('2520805')->is_valid_number, '神奈川県藤沢市円行');
ok($zip->set_number('2520806')->is_valid_number, '神奈川県藤沢市土棚');
ok($zip->set_number('2520807')->is_valid_number, '神奈川県藤沢市下土棚');
ok($zip->set_number('2520811')->is_valid_number, '神奈川県藤沢市桐原町');
ok($zip->set_number('2520812')->is_valid_number, '神奈川県藤沢市西俣野');
ok($zip->set_number('2520813')->is_valid_number, '神奈川県藤沢市亀井野');
ok($zip->set_number('2520814')->is_valid_number, '神奈川県藤沢市天神町');
ok($zip->set_number('2520815')->is_valid_number, '神奈川県藤沢市石川');
ok($zip->set_number('2520816')->is_valid_number, '神奈川県藤沢市遠藤');
ok($zip->set_number('2520821')->is_valid_number, '神奈川県藤沢市用田');
ok($zip->set_number('2520822')->is_valid_number, '神奈川県藤沢市葛原');
ok($zip->set_number('2520823')->is_valid_number, '神奈川県藤沢市菖蒲沢');
ok($zip->set_number('2520824')->is_valid_number, '神奈川県藤沢市打戻');
ok($zip->set_number('2520825')->is_valid_number, '神奈川県藤沢市獺郷');
ok($zip->set_number('2520826')->is_valid_number, '神奈川県藤沢市宮原');
ok($zip->set_number('2521100')->is_valid_number, '神奈川県綾瀬市以下に掲載がない場合');
ok($zip->set_number('2521101')->is_valid_number, '神奈川県綾瀬市厚木航空基地');
ok($zip->set_number('2521102')->is_valid_number, '神奈川県綾瀬市本蓼川');
ok($zip->set_number('2521103')->is_valid_number, '神奈川県綾瀬市深谷');
ok($zip->set_number('2521104')->is_valid_number, '神奈川県綾瀬市大上');
ok($zip->set_number('2521105')->is_valid_number, '神奈川県綾瀬市蓼川');
ok($zip->set_number('2521106')->is_valid_number, '神奈川県綾瀬市深谷南');
ok($zip->set_number('2521107')->is_valid_number, '神奈川県綾瀬市深谷中');
ok($zip->set_number('2521108')->is_valid_number, '神奈川県綾瀬市深谷上');
ok($zip->set_number('2521111')->is_valid_number, '神奈川県綾瀬市上土棚北');
ok($zip->set_number('2521112')->is_valid_number, '神奈川県綾瀬市上土棚');
ok($zip->set_number('2521113')->is_valid_number, '神奈川県綾瀬市上土棚中');
ok($zip->set_number('2521114')->is_valid_number, '神奈川県綾瀬市上土棚南');
ok($zip->set_number('2521115')->is_valid_number, '神奈川県綾瀬市落合南');
ok($zip->set_number('2521116')->is_valid_number, '神奈川県綾瀬市落合北');
ok($zip->set_number('2521121')->is_valid_number, '神奈川県綾瀬市小園');
ok($zip->set_number('2521122')->is_valid_number, '神奈川県綾瀬市小園南');
ok($zip->set_number('2521123')->is_valid_number, '神奈川県綾瀬市早川');
ok($zip->set_number('2521124')->is_valid_number, '神奈川県綾瀬市吉岡');
ok($zip->set_number('2521125')->is_valid_number, '神奈川県綾瀬市吉岡東');
ok($zip->set_number('2521126')->is_valid_number, '神奈川県綾瀬市綾西');
ok($zip->set_number('2521127')->is_valid_number, '神奈川県綾瀬市早川城山');
ok($zip->set_number('2521131')->is_valid_number, '神奈川県綾瀬市寺尾北');
ok($zip->set_number('2521132')->is_valid_number, '神奈川県綾瀬市寺尾中');
ok($zip->set_number('2521133')->is_valid_number, '神奈川県綾瀬市寺尾本町');
ok($zip->set_number('2521134')->is_valid_number, '神奈川県綾瀬市寺尾南');
ok($zip->set_number('2521135')->is_valid_number, '神奈川県綾瀬市寺尾釜田');
ok($zip->set_number('2521136')->is_valid_number, '神奈川県綾瀬市寺尾西');
ok($zip->set_number('2521137')->is_valid_number, '神奈川県綾瀬市寺尾台');
ok($zip->set_number('2530000')->is_valid_number, '神奈川県茅ヶ崎市以下に掲載がない場合');
ok($zip->set_number('2530001')->is_valid_number, '神奈川県茅ヶ崎市赤羽根');
ok($zip->set_number('2530002')->is_valid_number, '神奈川県茅ヶ崎市高田');
ok($zip->set_number('2530003')->is_valid_number, '神奈川県茅ヶ崎市鶴が台');
ok($zip->set_number('2530004')->is_valid_number, '神奈川県茅ヶ崎市甘沼');
ok($zip->set_number('2530005')->is_valid_number, '神奈川県茅ヶ崎市松風台');
ok($zip->set_number('2530006')->is_valid_number, '神奈川県茅ヶ崎市堤');
ok($zip->set_number('2530007')->is_valid_number, '神奈川県茅ヶ崎市行谷');
ok($zip->set_number('2530008')->is_valid_number, '神奈川県茅ヶ崎市芹沢');
ok($zip->set_number('2530011')->is_valid_number, '神奈川県茅ヶ崎市菱沼');
ok($zip->set_number('2530012')->is_valid_number, '神奈川県茅ヶ崎市小和田');
ok($zip->set_number('2530013')->is_valid_number, '神奈川県茅ヶ崎市赤松町');
ok($zip->set_number('2530014')->is_valid_number, '神奈川県茅ヶ崎市本宿町');
ok($zip->set_number('2530015')->is_valid_number, '神奈川県茅ヶ崎市代官町');
ok($zip->set_number('2530016')->is_valid_number, '神奈川県茅ヶ崎市小桜町');
ok($zip->set_number('2530017')->is_valid_number, '神奈川県茅ヶ崎市松林');
ok($zip->set_number('2530018')->is_valid_number, '神奈川県茅ヶ崎市室田');
ok($zip->set_number('2530021')->is_valid_number, '神奈川県茅ヶ崎市浜竹');
ok($zip->set_number('2530022')->is_valid_number, '神奈川県茅ヶ崎市松浪');
ok($zip->set_number('2530023')->is_valid_number, '神奈川県茅ヶ崎市美住町');
ok($zip->set_number('2530024')->is_valid_number, '神奈川県茅ヶ崎市平和町');
ok($zip->set_number('2530025')->is_valid_number, '神奈川県茅ヶ崎市松が丘');
ok($zip->set_number('2530026')->is_valid_number, '神奈川県茅ヶ崎市旭が丘');
ok($zip->set_number('2530027')->is_valid_number, '神奈川県茅ヶ崎市ひばりが丘');
ok($zip->set_number('2530028')->is_valid_number, '神奈川県茅ヶ崎市出口町');
ok($zip->set_number('2530031')->is_valid_number, '神奈川県茅ヶ崎市富士見町');
ok($zip->set_number('2530032')->is_valid_number, '神奈川県茅ヶ崎市常盤町');
ok($zip->set_number('2530033')->is_valid_number, '神奈川県茅ヶ崎市汐見台');
ok($zip->set_number('2530034')->is_valid_number, '神奈川県茅ヶ崎市緑が浜');
ok($zip->set_number('2530035')->is_valid_number, '神奈川県茅ヶ崎市浜須賀');
ok($zip->set_number('2530036')->is_valid_number, '神奈川県茅ヶ崎市白浜町');
ok($zip->set_number('2530037')->is_valid_number, '神奈川県茅ヶ崎市菱沼海岸');
ok($zip->set_number('2530041')->is_valid_number, '神奈川県茅ヶ崎市茅ヶ崎');
ok($zip->set_number('2530042')->is_valid_number, '神奈川県茅ヶ崎市本村');
ok($zip->set_number('2530043')->is_valid_number, '神奈川県茅ヶ崎市元町');
ok($zip->set_number('2530044')->is_valid_number, '神奈川県茅ヶ崎市新栄町');
ok($zip->set_number('2530045')->is_valid_number, '神奈川県茅ヶ崎市十間坂');
ok($zip->set_number('2530051')->is_valid_number, '神奈川県茅ヶ崎市若松町');
ok($zip->set_number('2530052')->is_valid_number, '神奈川県茅ヶ崎市幸町');
ok($zip->set_number('2530053')->is_valid_number, '神奈川県茅ヶ崎市東海岸北');
ok($zip->set_number('2530054')->is_valid_number, '神奈川県茅ヶ崎市東海岸南');
ok($zip->set_number('2530055')->is_valid_number, '神奈川県茅ヶ崎市中海岸');
ok($zip->set_number('2530056')->is_valid_number, '神奈川県茅ヶ崎市共恵');
ok($zip->set_number('2530061')->is_valid_number, '神奈川県茅ヶ崎市南湖');
ok($zip->set_number('2530062')->is_valid_number, '神奈川県茅ヶ崎市浜見平');
ok($zip->set_number('2530063')->is_valid_number, '神奈川県茅ヶ崎市柳島海岸');
ok($zip->set_number('2530064')->is_valid_number, '神奈川県茅ヶ崎市柳島');
ok($zip->set_number('2530065')->is_valid_number, '神奈川県茅ヶ崎市松尾');
ok($zip->set_number('2530071')->is_valid_number, '神奈川県茅ヶ崎市萩園');
ok($zip->set_number('2530072')->is_valid_number, '神奈川県茅ヶ崎市今宿');
ok($zip->set_number('2530073')->is_valid_number, '神奈川県茅ヶ崎市中島');
ok($zip->set_number('2530074')->is_valid_number, '神奈川県茅ヶ崎市平太夫新田');
ok($zip->set_number('2530081')->is_valid_number, '神奈川県茅ヶ崎市下寺尾');
ok($zip->set_number('2530082')->is_valid_number, '神奈川県茅ヶ崎市香川');
ok($zip->set_number('2530083')->is_valid_number, '神奈川県茅ヶ崎市西久保');
ok($zip->set_number('2530084')->is_valid_number, '神奈川県茅ヶ崎市円蔵');
ok($zip->set_number('2530085')->is_valid_number, '神奈川県茅ヶ崎市矢畑');
ok($zip->set_number('2530086')->is_valid_number, '神奈川県茅ヶ崎市浜之郷');
ok($zip->set_number('2530087')->is_valid_number, '神奈川県茅ヶ崎市下町屋');
ok($zip->set_number('2530088')->is_valid_number, '神奈川県茅ヶ崎市みずき');
ok($zip->set_number('2530100')->is_valid_number, '神奈川県高座郡寒川町以下に掲載がない場合');
ok($zip->set_number('2530101')->is_valid_number, '神奈川県高座郡寒川町倉見');
ok($zip->set_number('2530102')->is_valid_number, '神奈川県高座郡寒川町小動');
ok($zip->set_number('2530103')->is_valid_number, '神奈川県高座郡寒川町小谷');
ok($zip->set_number('2530104')->is_valid_number, '神奈川県高座郡寒川町大蔵');
ok($zip->set_number('2530105')->is_valid_number, '神奈川県高座郡寒川町岡田');
ok($zip->set_number('2530106')->is_valid_number, '神奈川県高座郡寒川町宮山');
ok($zip->set_number('2530111')->is_valid_number, '神奈川県高座郡寒川町一之宮');
ok($zip->set_number('2530112')->is_valid_number, '神奈川県高座郡寒川町中瀬');
ok($zip->set_number('2530113')->is_valid_number, '神奈川県高座郡寒川町大曲');
ok($zip->set_number('2530114')->is_valid_number, '神奈川県高座郡寒川町田端');
ok($zip->set_number('2540000')->is_valid_number, '神奈川県平塚市以下に掲載がない場合');
ok($zip->set_number('2540001')->is_valid_number, '神奈川県平塚市大島');
ok($zip->set_number('2540002')->is_valid_number, '神奈川県平塚市横内');
ok($zip->set_number('2540003')->is_valid_number, '神奈川県平塚市下島');
ok($zip->set_number('2540004')->is_valid_number, '神奈川県平塚市小鍋島');
ok($zip->set_number('2540005')->is_valid_number, '神奈川県平塚市城所');
ok($zip->set_number('2540011')->is_valid_number, '神奈川県平塚市吉際');
ok($zip->set_number('2540012')->is_valid_number, '神奈川県平塚市大神');
ok($zip->set_number('2540013')->is_valid_number, '神奈川県平塚市田村');
ok($zip->set_number('2540014')->is_valid_number, '神奈川県平塚市四之宮');
ok($zip->set_number('2540015')->is_valid_number, '神奈川県平塚市八幡');
ok($zip->set_number('2540016')->is_valid_number, '神奈川県平塚市東八幡');
ok($zip->set_number('2540018')->is_valid_number, '神奈川県平塚市東真土');
ok($zip->set_number('2540019')->is_valid_number, '神奈川県平塚市西真土');
ok($zip->set_number('2540021')->is_valid_number, '神奈川県平塚市長瀞');
ok($zip->set_number('2540022')->is_valid_number, '神奈川県平塚市須賀');
ok($zip->set_number('2540023')->is_valid_number, '神奈川県平塚市馬入');
ok($zip->set_number('2540024')->is_valid_number, '神奈川県平塚市馬入本町');
ok($zip->set_number('2540025')->is_valid_number, '神奈川県平塚市榎木町');
ok($zip->set_number('2540026')->is_valid_number, '神奈川県平塚市中堂');
ok($zip->set_number('2540027')->is_valid_number, '神奈川県平塚市堤町');
ok($zip->set_number('2540031')->is_valid_number, '神奈川県平塚市天沼');
ok($zip->set_number('2540032')->is_valid_number, '神奈川県平塚市八千代町');
ok($zip->set_number('2540033')->is_valid_number, '神奈川県平塚市老松町');
ok($zip->set_number('2540034')->is_valid_number, '神奈川県平塚市宝町');
ok($zip->set_number('2540035')->is_valid_number, '神奈川県平塚市宮の前');
ok($zip->set_number('2540036')->is_valid_number, '神奈川県平塚市宮松町');
ok($zip->set_number('2540041')->is_valid_number, '神奈川県平塚市浅間町');
ok($zip->set_number('2540042')->is_valid_number, '神奈川県平塚市明石町');
ok($zip->set_number('2540043')->is_valid_number, '神奈川県平塚市紅谷町');
ok($zip->set_number('2540044')->is_valid_number, '神奈川県平塚市錦町');
ok($zip->set_number('2540045')->is_valid_number, '神奈川県平塚市見附町');
ok($zip->set_number('2540046')->is_valid_number, '神奈川県平塚市立野町');
ok($zip->set_number('2540047')->is_valid_number, '神奈川県平塚市追分');
ok($zip->set_number('2540051')->is_valid_number, '神奈川県平塚市豊原町');
ok($zip->set_number('2540052')->is_valid_number, '神奈川県平塚市平塚');
ok($zip->set_number('2540053')->is_valid_number, '神奈川県平塚市桜ケ丘');
ok($zip->set_number('2540054')->is_valid_number, '神奈川県平塚市中里');
ok($zip->set_number('2540055')->is_valid_number, '神奈川県平塚市上平塚');
ok($zip->set_number('2540061')->is_valid_number, '神奈川県平塚市御殿');
ok($zip->set_number('2540062')->is_valid_number, '神奈川県平塚市富士見町');
ok($zip->set_number('2540063')->is_valid_number, '神奈川県平塚市諏訪町');
ok($zip->set_number('2540064')->is_valid_number, '神奈川県平塚市達上ケ丘');
ok($zip->set_number('2540065')->is_valid_number, '神奈川県平塚市南原');
ok($zip->set_number('2540071')->is_valid_number, '神奈川県平塚市中原上宿');
ok($zip->set_number('2540072')->is_valid_number, '神奈川県平塚市中原下宿');
ok($zip->set_number('2540073')->is_valid_number, '神奈川県平塚市西八幡');
ok($zip->set_number('2540074')->is_valid_number, '神奈川県平塚市大原');
ok($zip->set_number('2540075')->is_valid_number, '神奈川県平塚市中原');
ok($zip->set_number('2540076')->is_valid_number, '神奈川県平塚市新町');
ok($zip->set_number('2540077')->is_valid_number, '神奈川県平塚市東中原');
ok($zip->set_number('2540081')->is_valid_number, '神奈川県平塚市豊田打間木');
ok($zip->set_number('2540082')->is_valid_number, '神奈川県平塚市東豊田');
ok($zip->set_number('2540083')->is_valid_number, '神奈川県平塚市豊田小嶺');
ok($zip->set_number('2540084')->is_valid_number, '神奈川県平塚市南豊田');
ok($zip->set_number('2540085')->is_valid_number, '神奈川県平塚市豊田宮下');
ok($zip->set_number('2540086')->is_valid_number, '神奈川県平塚市豊田平等寺');
ok($zip->set_number('2540087')->is_valid_number, '神奈川県平塚市豊田本郷');
ok($zip->set_number('2540088')->is_valid_number, '神奈川県平塚市北豊田');
ok($zip->set_number('2540801')->is_valid_number, '神奈川県平塚市久領堤');
ok($zip->set_number('2540802')->is_valid_number, '神奈川県平塚市札場町');
ok($zip->set_number('2540803')->is_valid_number, '神奈川県平塚市千石河岸');
ok($zip->set_number('2540804')->is_valid_number, '神奈川県平塚市幸町');
ok($zip->set_number('2540805')->is_valid_number, '神奈川県平塚市高浜台');
ok($zip->set_number('2540806')->is_valid_number, '神奈川県平塚市夕陽ケ丘');
ok($zip->set_number('2540807')->is_valid_number, '神奈川県平塚市代官町');
ok($zip->set_number('2540811')->is_valid_number, '神奈川県平塚市八重咲町');
ok($zip->set_number('2540812')->is_valid_number, '神奈川県平塚市松風町');
ok($zip->set_number('2540813')->is_valid_number, '神奈川県平塚市袖ケ浜');
ok($zip->set_number('2540814')->is_valid_number, '神奈川県平塚市龍城ケ丘');
ok($zip->set_number('2540815')->is_valid_number, '神奈川県平塚市桃浜町');
ok($zip->set_number('2540821')->is_valid_number, '神奈川県平塚市黒部丘');
ok($zip->set_number('2540822')->is_valid_number, '神奈川県平塚市菫平');
ok($zip->set_number('2540823')->is_valid_number, '神奈川県平塚市虹ケ浜');
ok($zip->set_number('2540824')->is_valid_number, '神奈川県平塚市花水台');
ok($zip->set_number('2540825')->is_valid_number, '神奈川県平塚市撫子原');
ok($zip->set_number('2540826')->is_valid_number, '神奈川県平塚市唐ケ原');
ok($zip->set_number('2540901')->is_valid_number, '神奈川県平塚市纒');
ok($zip->set_number('2540902')->is_valid_number, '神奈川県平塚市徳延');
ok($zip->set_number('2540903')->is_valid_number, '神奈川県平塚市河内');
ok($zip->set_number('2540904')->is_valid_number, '神奈川県平塚市根坂間');
ok($zip->set_number('2540905')->is_valid_number, '神奈川県平塚市日向岡');
ok($zip->set_number('2540906')->is_valid_number, '神奈川県平塚市公所');
ok($zip->set_number('2540911')->is_valid_number, '神奈川県平塚市山下');
ok($zip->set_number('2540912')->is_valid_number, '神奈川県平塚市高根');
ok($zip->set_number('2540913')->is_valid_number, '神奈川県平塚市万田');
ok($zip->set_number('2540914')->is_valid_number, '神奈川県平塚市高村');
ok($zip->set_number('2540915')->is_valid_number, '神奈川県平塚市出縄');
ok($zip->set_number('2550000')->is_valid_number, '神奈川県中郡大磯町以下に掲載がない場合');
ok($zip->set_number('2550001')->is_valid_number, '神奈川県中郡大磯町高麗');
ok($zip->set_number('2550002')->is_valid_number, '神奈川県中郡大磯町東町');
ok($zip->set_number('2550003')->is_valid_number, '神奈川県中郡大磯町大磯');
ok($zip->set_number('2550004')->is_valid_number, '神奈川県中郡大磯町東小磯');
ok($zip->set_number('2550005')->is_valid_number, '神奈川県中郡大磯町西小磯');
ok($zip->set_number('2560801')->is_valid_number, '神奈川県小田原市沼代');
ok($zip->set_number('2560802')->is_valid_number, '神奈川県小田原市小竹');
ok($zip->set_number('2560803')->is_valid_number, '神奈川県小田原市中村原');
ok($zip->set_number('2560804')->is_valid_number, '神奈川県小田原市羽根尾');
ok($zip->set_number('2560805')->is_valid_number, '神奈川県小田原市上町');
ok($zip->set_number('2560806')->is_valid_number, '神奈川県小田原市小船');
ok($zip->set_number('2560807')->is_valid_number, '神奈川県小田原市山西');
ok($zip->set_number('2560808')->is_valid_number, '神奈川県小田原市東ヶ丘');
ok($zip->set_number('2560811')->is_valid_number, '神奈川県小田原市田島');
ok($zip->set_number('2560812')->is_valid_number, '神奈川県小田原市国府津');
ok($zip->set_number('2560813')->is_valid_number, '神奈川県小田原市前川');
ok($zip->set_number('2560814')->is_valid_number, '神奈川県小田原市川匂');
ok($zip->set_number('2560815')->is_valid_number, '神奈川県小田原市小八幡');
ok($zip->set_number('2560816')->is_valid_number, '神奈川県小田原市酒匂');
ok($zip->set_number('2560817')->is_valid_number, '神奈川県小田原市西酒匂');
ok($zip->set_number('2570000')->is_valid_number, '神奈川県秦野市以下に掲載がない場合');
ok($zip->set_number('2570001')->is_valid_number, '神奈川県秦野市鶴巻北');
ok($zip->set_number('2570002')->is_valid_number, '神奈川県秦野市鶴巻南');
ok($zip->set_number('2570003')->is_valid_number, '神奈川県秦野市南矢名');
ok($zip->set_number('2570004')->is_valid_number, '神奈川県秦野市下大槻');
ok($zip->set_number('2570005')->is_valid_number, '神奈川県秦野市上大槻');
ok($zip->set_number('2570006')->is_valid_number, '神奈川県秦野市北矢名');
ok($zip->set_number('2570007')->is_valid_number, '神奈川県秦野市鶴巻');
ok($zip->set_number('2570011')->is_valid_number, '神奈川県秦野市尾尻');
ok($zip->set_number('2570012')->is_valid_number, '神奈川県秦野市西大竹');
ok($zip->set_number('2570013')->is_valid_number, '神奈川県秦野市南が丘');
ok($zip->set_number('2570014')->is_valid_number, '神奈川県秦野市今泉');
ok($zip->set_number('2570015')->is_valid_number, '神奈川県秦野市平沢');
ok($zip->set_number('2570016')->is_valid_number, '神奈川県秦野市栃窪(600~603番地)');
ok($zip->set_number('2570017')->is_valid_number, '神奈川県秦野市立野台');
ok($zip->set_number('2570018')->is_valid_number, '神奈川県秦野市今泉台');
ok($zip->set_number('2570021')->is_valid_number, '神奈川県秦野市蓑毛');
ok($zip->set_number('2570022')->is_valid_number, '神奈川県秦野市小蓑毛');
ok($zip->set_number('2570023')->is_valid_number, '神奈川県秦野市寺山');
ok($zip->set_number('2570024')->is_valid_number, '神奈川県秦野市名古木');
ok($zip->set_number('2570025')->is_valid_number, '神奈川県秦野市落合');
ok($zip->set_number('2570026')->is_valid_number, '神奈川県秦野市下落合');
ok($zip->set_number('2570027')->is_valid_number, '神奈川県秦野市西田原');
ok($zip->set_number('2570028')->is_valid_number, '神奈川県秦野市東田原');
ok($zip->set_number('2570031')->is_valid_number, '神奈川県秦野市曽屋');
ok($zip->set_number('2570032')->is_valid_number, '神奈川県秦野市河原町');
ok($zip->set_number('2570033')->is_valid_number, '神奈川県秦野市室町');
ok($zip->set_number('2570034')->is_valid_number, '神奈川県秦野市大秦町');
ok($zip->set_number('2570035')->is_valid_number, '神奈川県秦野市本町');
ok($zip->set_number('2570036')->is_valid_number, '神奈川県秦野市元町');
ok($zip->set_number('2570037')->is_valid_number, '神奈川県秦野市末広町');
ok($zip->set_number('2570041')->is_valid_number, '神奈川県秦野市入船町');
ok($zip->set_number('2570042')->is_valid_number, '神奈川県秦野市寿町');
ok($zip->set_number('2570043')->is_valid_number, '神奈川県秦野市栄町');
ok($zip->set_number('2570044')->is_valid_number, '神奈川県秦野市文京町');
ok($zip->set_number('2570045')->is_valid_number, '神奈川県秦野市桜町');
ok($zip->set_number('2570046')->is_valid_number, '神奈川県秦野市ひばりケ丘');
ok($zip->set_number('2570047')->is_valid_number, '神奈川県秦野市水神町');
ok($zip->set_number('2570048')->is_valid_number, '神奈川県秦野市幸町');
ok($zip->set_number('2570051')->is_valid_number, '神奈川県秦野市今川町');
ok($zip->set_number('2570052')->is_valid_number, '神奈川県秦野市上今川町');
ok($zip->set_number('2570053')->is_valid_number, '神奈川県秦野市清水町');
ok($zip->set_number('2570054')->is_valid_number, '神奈川県秦野市緑町');
ok($zip->set_number('2570055')->is_valid_number, '神奈川県秦野市鈴張町');
ok($zip->set_number('2570056')->is_valid_number, '神奈川県秦野市新町');
ok($zip->set_number('2570057')->is_valid_number, '神奈川県秦野市富士見町');
ok($zip->set_number('2570061')->is_valid_number, '神奈川県愛甲郡清川村煤ヶ谷(丹沢山札掛)');
ok($zip->set_number('2580000')->is_valid_number, '神奈川県足柄上郡大井町以下に掲載がない場合');
ok($zip->set_number('2580000')->is_valid_number, '神奈川県足柄上郡松田町以下に掲載がない場合');
ok($zip->set_number('2580000')->is_valid_number, '神奈川県足柄上郡開成町以下に掲載がない場合');
ok($zip->set_number('2580001')->is_valid_number, '神奈川県足柄上郡松田町寄');
ok($zip->set_number('2580002')->is_valid_number, '神奈川県足柄上郡松田町神山');
ok($zip->set_number('2580003')->is_valid_number, '神奈川県足柄上郡松田町松田惣領');
ok($zip->set_number('2580004')->is_valid_number, '神奈川県足柄上郡松田町松田庶子');
ok($zip->set_number('2580010')->is_valid_number, '神奈川県足柄上郡大井町大井中央');
ok($zip->set_number('2580011')->is_valid_number, '神奈川県足柄上郡大井町篠窪');
ok($zip->set_number('2580012')->is_valid_number, '神奈川県足柄上郡大井町柳');
ok($zip->set_number('2580013')->is_valid_number, '神奈川県足柄上郡大井町高尾');
ok($zip->set_number('2580014')->is_valid_number, '神奈川県足柄上郡大井町赤田');
ok($zip->set_number('2580015')->is_valid_number, '神奈川県足柄上郡大井町山田');
ok($zip->set_number('2580016')->is_valid_number, '神奈川県足柄上郡大井町上大井');
ok($zip->set_number('2580017')->is_valid_number, '神奈川県足柄上郡大井町西大井');
ok($zip->set_number('2580018')->is_valid_number, '神奈川県足柄上郡大井町金手');
ok($zip->set_number('2580019')->is_valid_number, '神奈川県足柄上郡大井町金子');
ok($zip->set_number('2580021')->is_valid_number, '神奈川県足柄上郡開成町吉田島');
ok($zip->set_number('2580022')->is_valid_number, '神奈川県足柄上郡開成町牛島');
ok($zip->set_number('2580023')->is_valid_number, '神奈川県足柄上郡開成町宮台');
ok($zip->set_number('2580024')->is_valid_number, '神奈川県足柄上郡開成町中之名');
ok($zip->set_number('2580025')->is_valid_number, '神奈川県足柄上郡開成町円通寺');
ok($zip->set_number('2580026')->is_valid_number, '神奈川県足柄上郡開成町延沢');
ok($zip->set_number('2580027')->is_valid_number, '神奈川県足柄上郡開成町岡野');
ok($zip->set_number('2580028')->is_valid_number, '神奈川県足柄上郡開成町金井島');
ok($zip->set_number('2580029')->is_valid_number, '神奈川県足柄上郡開成町みなみ');
ok($zip->set_number('2580100')->is_valid_number, '神奈川県足柄上郡山北町以下に掲載がない場合');
ok($zip->set_number('2580111')->is_valid_number, '神奈川県足柄上郡山北町向原');
ok($zip->set_number('2580112')->is_valid_number, '神奈川県足柄上郡山北町岸');
ok($zip->set_number('2580113')->is_valid_number, '神奈川県足柄上郡山北町山北');
ok($zip->set_number('2580114')->is_valid_number, '神奈川県足柄上郡山北町平山');
ok($zip->set_number('2580115')->is_valid_number, '神奈川県足柄上郡山北町谷ケ');
ok($zip->set_number('2580121')->is_valid_number, '神奈川県足柄上郡山北町皆瀬川');
ok($zip->set_number('2580122')->is_valid_number, '神奈川県足柄上郡山北町都夫良野');
ok($zip->set_number('2580123')->is_valid_number, '神奈川県足柄上郡山北町湯触');
ok($zip->set_number('2580124')->is_valid_number, '神奈川県足柄上郡山北町川西');
ok($zip->set_number('2580125')->is_valid_number, '神奈川県足柄上郡山北町山市場');
ok($zip->set_number('2580126')->is_valid_number, '神奈川県足柄上郡山北町神縄');
ok($zip->set_number('2580201')->is_valid_number, '神奈川県足柄上郡山北町中川');
ok($zip->set_number('2580202')->is_valid_number, '神奈川県足柄上郡山北町玄倉');
ok($zip->set_number('2580203')->is_valid_number, '神奈川県足柄上郡山北町神尾田');
ok($zip->set_number('2580204')->is_valid_number, '神奈川県足柄上郡山北町世附');
ok($zip->set_number('2590100')->is_valid_number, '神奈川県中郡二宮町以下に掲載がない場合');
ok($zip->set_number('2590100')->is_valid_number, '神奈川県足柄上郡中井町以下に掲載がない場合');
ok($zip->set_number('2590101')->is_valid_number, '神奈川県中郡大磯町寺坂');
ok($zip->set_number('2590102')->is_valid_number, '神奈川県中郡大磯町生沢');
ok($zip->set_number('2590103')->is_valid_number, '神奈川県中郡大磯町虫窪');
ok($zip->set_number('2590104')->is_valid_number, '神奈川県中郡大磯町西久保');
ok($zip->set_number('2590105')->is_valid_number, '神奈川県中郡大磯町黒岩');
ok($zip->set_number('2590111')->is_valid_number, '神奈川県中郡大磯町国府本郷');
ok($zip->set_number('2590112')->is_valid_number, '神奈川県中郡大磯町国府新宿');
ok($zip->set_number('2590113')->is_valid_number, '神奈川県中郡大磯町石神台');
ok($zip->set_number('2590114')->is_valid_number, '神奈川県中郡大磯町月京');
ok($zip->set_number('2590121')->is_valid_number, '神奈川県中郡二宮町松根');
ok($zip->set_number('2590122')->is_valid_number, '神奈川県中郡二宮町富士見が丘');
ok($zip->set_number('2590123')->is_valid_number, '神奈川県中郡二宮町二宮');
ok($zip->set_number('2590124')->is_valid_number, '神奈川県中郡二宮町山西');
ok($zip->set_number('2590125')->is_valid_number, '神奈川県中郡二宮町川匂');
ok($zip->set_number('2590131')->is_valid_number, '神奈川県中郡二宮町中里');
ok($zip->set_number('2590132')->is_valid_number, '神奈川県中郡二宮町緑が丘');
ok($zip->set_number('2590133')->is_valid_number, '神奈川県中郡二宮町百合が丘');
ok($zip->set_number('2590134')->is_valid_number, '神奈川県中郡二宮町一色');
ok($zip->set_number('2590141')->is_valid_number, '神奈川県足柄上郡中井町遠藤');
ok($zip->set_number('2590142')->is_valid_number, '神奈川県足柄上郡中井町久所');
ok($zip->set_number('2590143')->is_valid_number, '神奈川県足柄上郡中井町北田');
ok($zip->set_number('2590144')->is_valid_number, '神奈川県足柄上郡中井町半分形');
ok($zip->set_number('2590145')->is_valid_number, '神奈川県足柄上郡中井町田中');
ok($zip->set_number('2590146')->is_valid_number, '神奈川県足柄上郡中井町古怒田');
ok($zip->set_number('2590147')->is_valid_number, '神奈川県足柄上郡中井町鴨沢');
ok($zip->set_number('2590148')->is_valid_number, '神奈川県足柄上郡中井町雑色');
ok($zip->set_number('2590151')->is_valid_number, '神奈川県足柄上郡中井町井ノ口');
ok($zip->set_number('2590152')->is_valid_number, '神奈川県足柄上郡中井町藤沢');
ok($zip->set_number('2590153')->is_valid_number, '神奈川県足柄上郡中井町比奈窪');
ok($zip->set_number('2590154')->is_valid_number, '神奈川県足柄上郡中井町岩倉');
ok($zip->set_number('2590155')->is_valid_number, '神奈川県足柄上郡中井町松本');
ok($zip->set_number('2590156')->is_valid_number, '神奈川県足柄上郡中井町境別所');
ok($zip->set_number('2590157')->is_valid_number, '神奈川県足柄上郡中井町境');
ok($zip->set_number('2590200')->is_valid_number, '神奈川県足柄下郡真鶴町以下に掲載がない場合');
ok($zip->set_number('2590201')->is_valid_number, '神奈川県足柄下郡真鶴町真鶴');
ok($zip->set_number('2590202')->is_valid_number, '神奈川県足柄下郡真鶴町岩');
ok($zip->set_number('2590300')->is_valid_number, '神奈川県足柄下郡湯河原町以下に掲載がない場合');
ok($zip->set_number('2590301')->is_valid_number, '神奈川県足柄下郡湯河原町中央');
ok($zip->set_number('2590302')->is_valid_number, '神奈川県足柄下郡湯河原町門川');
ok($zip->set_number('2590303')->is_valid_number, '神奈川県足柄下郡湯河原町土肥');
ok($zip->set_number('2590304')->is_valid_number, '神奈川県足柄下郡湯河原町宮下');
ok($zip->set_number('2590305')->is_valid_number, '神奈川県足柄下郡湯河原町城堀');
ok($zip->set_number('2590311')->is_valid_number, '神奈川県足柄下郡湯河原町福浦');
ok($zip->set_number('2590312')->is_valid_number, '神奈川県足柄下郡湯河原町吉浜');
ok($zip->set_number('2590313')->is_valid_number, '神奈川県足柄下郡湯河原町鍛冶屋');
ok($zip->set_number('2590314')->is_valid_number, '神奈川県足柄下郡湯河原町宮上');
ok($zip->set_number('2590316')->is_valid_number, '神奈川県足柄下郡湯河原町福浦吉浜');
ok($zip->set_number('2590317')->is_valid_number, '神奈川県足柄下郡湯河原町福浦鍛冶屋');
ok($zip->set_number('2590318')->is_valid_number, '神奈川県足柄下郡湯河原町吉浜福浦');
ok($zip->set_number('2591100')->is_valid_number, '神奈川県伊勢原市以下に掲載がない場合');
ok($zip->set_number('2591101')->is_valid_number, '神奈川県伊勢原市日向');
ok($zip->set_number('2591102')->is_valid_number, '神奈川県伊勢原市子易');
ok($zip->set_number('2591103')->is_valid_number, '神奈川県伊勢原市三ノ宮');
ok($zip->set_number('2591104')->is_valid_number, '神奈川県伊勢原市坪ノ内');
ok($zip->set_number('2591105')->is_valid_number, '神奈川県伊勢原市大住台');
ok($zip->set_number('2591106')->is_valid_number, '神奈川県伊勢原市善波');
ok($zip->set_number('2591107')->is_valid_number, '神奈川県伊勢原市大山');
ok($zip->set_number('2591111')->is_valid_number, '神奈川県伊勢原市西富岡');
ok($zip->set_number('2591112')->is_valid_number, '神奈川県伊勢原市東富岡');
ok($zip->set_number('2591113')->is_valid_number, '神奈川県伊勢原市粟窪');
ok($zip->set_number('2591114')->is_valid_number, '神奈川県伊勢原市高森');
ok($zip->set_number('2591115')->is_valid_number, '神奈川県伊勢原市高森台');
ok($zip->set_number('2591116')->is_valid_number, '神奈川県伊勢原市石田');
ok($zip->set_number('2591117')->is_valid_number, '神奈川県伊勢原市東成瀬');
ok($zip->set_number('2591118')->is_valid_number, '神奈川県伊勢原市見附島');
ok($zip->set_number('2591121')->is_valid_number, '神奈川県伊勢原市下落合');
ok($zip->set_number('2591122')->is_valid_number, '神奈川県伊勢原市小稲葉');
ok($zip->set_number('2591123')->is_valid_number, '神奈川県伊勢原市下谷');
ok($zip->set_number('2591124')->is_valid_number, '神奈川県伊勢原市上平間');
ok($zip->set_number('2591125')->is_valid_number, '神奈川県伊勢原市下平間');
ok($zip->set_number('2591126')->is_valid_number, '神奈川県伊勢原市沼目');
ok($zip->set_number('2591127')->is_valid_number, '神奈川県伊勢原市上谷');
ok($zip->set_number('2591128')->is_valid_number, '神奈川県伊勢原市歌川');
ok($zip->set_number('2591131')->is_valid_number, '神奈川県伊勢原市伊勢原');
ok($zip->set_number('2591132')->is_valid_number, '神奈川県伊勢原市桜台');
ok($zip->set_number('2591133')->is_valid_number, '神奈川県伊勢原市東大竹');
ok($zip->set_number('2591134')->is_valid_number, '神奈川県伊勢原市八幡台');
ok($zip->set_number('2591135')->is_valid_number, '神奈川県伊勢原市岡崎');
ok($zip->set_number('2591136')->is_valid_number, '神奈川県伊勢原市串橋');
ok($zip->set_number('2591137')->is_valid_number, '神奈川県伊勢原市笠窪');
ok($zip->set_number('2591138')->is_valid_number, '神奈川県伊勢原市神戸');
ok($zip->set_number('2591141')->is_valid_number, '神奈川県伊勢原市上粕屋');
ok($zip->set_number('2591142')->is_valid_number, '神奈川県伊勢原市田中');
ok($zip->set_number('2591143')->is_valid_number, '神奈川県伊勢原市下糟屋');
ok($zip->set_number('2591144')->is_valid_number, '神奈川県伊勢原市池端');
ok($zip->set_number('2591145')->is_valid_number, '神奈川県伊勢原市板戸');
ok($zip->set_number('2591146')->is_valid_number, '神奈川県伊勢原市鈴川');
ok($zip->set_number('2591147')->is_valid_number, '神奈川県伊勢原市白根');
ok($zip->set_number('2591148')->is_valid_number, '神奈川県伊勢原市下糟屋東');
ok($zip->set_number('2591201')->is_valid_number, '神奈川県平塚市南金目');
ok($zip->set_number('2591202')->is_valid_number, '神奈川県平塚市千須谷');
ok($zip->set_number('2591203')->is_valid_number, '神奈川県平塚市下吉沢');
ok($zip->set_number('2591204')->is_valid_number, '神奈川県平塚市上吉沢');
ok($zip->set_number('2591205')->is_valid_number, '神奈川県平塚市土屋');
ok($zip->set_number('2591206')->is_valid_number, '神奈川県平塚市真田');
ok($zip->set_number('2591207')->is_valid_number, '神奈川県平塚市北金目');
ok($zip->set_number('2591211')->is_valid_number, '神奈川県平塚市ふじみ野');
ok($zip->set_number('2591212')->is_valid_number, '神奈川県平塚市岡崎');
ok($zip->set_number('2591213')->is_valid_number, '神奈川県平塚市片岡');
ok($zip->set_number('2591214')->is_valid_number, '神奈川県平塚市飯島');
ok($zip->set_number('2591215')->is_valid_number, '神奈川県平塚市寺田縄');
ok($zip->set_number('2591216')->is_valid_number, '神奈川県平塚市入野');
ok($zip->set_number('2591217')->is_valid_number, '神奈川県平塚市長持');
ok($zip->set_number('2591218')->is_valid_number, '神奈川県平塚市入部');
ok($zip->set_number('2591219')->is_valid_number, '神奈川県平塚市広川');
ok($zip->set_number('2591220')->is_valid_number, '神奈川県平塚市めぐみが丘');
ok($zip->set_number('2591301')->is_valid_number, '神奈川県秦野市羽根');
ok($zip->set_number('2591302')->is_valid_number, '神奈川県秦野市菩提');
ok($zip->set_number('2591303')->is_valid_number, '神奈川県秦野市三屋');
ok($zip->set_number('2591304')->is_valid_number, '神奈川県秦野市堀山下');
ok($zip->set_number('2591305')->is_valid_number, '神奈川県秦野市堀川');
ok($zip->set_number('2591306')->is_valid_number, '神奈川県秦野市戸川');
ok($zip->set_number('2591307')->is_valid_number, '神奈川県秦野市横野');
ok($zip->set_number('2591311')->is_valid_number, '神奈川県秦野市弥生町');
ok($zip->set_number('2591312')->is_valid_number, '神奈川県秦野市春日町');
ok($zip->set_number('2591313')->is_valid_number, '神奈川県秦野市松原町');
ok($zip->set_number('2591314')->is_valid_number, '神奈川県秦野市若松町');
ok($zip->set_number('2591315')->is_valid_number, '神奈川県秦野市柳町');
ok($zip->set_number('2591316')->is_valid_number, '神奈川県秦野市沼代新町');
ok($zip->set_number('2591317')->is_valid_number, '神奈川県秦野市並木町');
ok($zip->set_number('2591321')->is_valid_number, '神奈川県秦野市曲松');
ok($zip->set_number('2591322')->is_valid_number, '神奈川県秦野市渋沢');
ok($zip->set_number('2591323')->is_valid_number, '神奈川県秦野市栃窪(その他)');
ok($zip->set_number('2591324')->is_valid_number, '神奈川県秦野市千村');
ok($zip->set_number('2591325')->is_valid_number, '神奈川県秦野市萩が丘');
ok($zip->set_number('2591326')->is_valid_number, '神奈川県秦野市渋沢上');
ok($zip->set_number('2591331')->is_valid_number, '神奈川県秦野市堀西');
ok($zip->set_number('2591332')->is_valid_number, '神奈川県秦野市菖蒲');
ok($zip->set_number('2591333')->is_valid_number, '神奈川県秦野市八沢');
ok($zip->set_number('2591334')->is_valid_number, '神奈川県秦野市柳川');
ok($zip->set_number('2591335')->is_valid_number, '神奈川県秦野市三廻部');
ok($zip->set_number('2600000')->is_valid_number, '千葉県千葉市中央区以下に掲載がない場合');
ok($zip->set_number('2600001')->is_valid_number, '千葉県千葉市中央区都町');
ok($zip->set_number('2600002')->is_valid_number, '千葉県千葉市中央区旭町');
ok($zip->set_number('2600003')->is_valid_number, '千葉県千葉市中央区鶴沢町');
ok($zip->set_number('2600004')->is_valid_number, '千葉県千葉市中央区東本町');
ok($zip->set_number('2600005')->is_valid_number, '千葉県千葉市中央区道場南');
ok($zip->set_number('2600006')->is_valid_number, '千葉県千葉市中央区道場北');
ok($zip->set_number('2600007')->is_valid_number, '千葉県千葉市中央区祐光');
ok($zip->set_number('2600011')->is_valid_number, '千葉県千葉市中央区亀井町');
ok($zip->set_number('2600012')->is_valid_number, '千葉県千葉市中央区本町');
ok($zip->set_number('2600013')->is_valid_number, '千葉県千葉市中央区中央');
ok($zip->set_number('2600014')->is_valid_number, '千葉県千葉市中央区本千葉町');
ok($zip->set_number('2600015')->is_valid_number, '千葉県千葉市中央区富士見');
ok($zip->set_number('2600016')->is_valid_number, '千葉県千葉市中央区栄町');
ok($zip->set_number('2600017')->is_valid_number, '千葉県千葉市中央区要町');
ok($zip->set_number('2600018')->is_valid_number, '千葉県千葉市中央区院内');
ok($zip->set_number('2600021')->is_valid_number, '千葉県千葉市中央区新宿');
ok($zip->set_number('2600022')->is_valid_number, '千葉県千葉市中央区神明町');
ok($zip->set_number('2600023')->is_valid_number, '千葉県千葉市中央区出洲港');
ok($zip->set_number('2600024')->is_valid_number, '千葉県千葉市中央区中央港');
ok($zip->set_number('2600025')->is_valid_number, '千葉県千葉市中央区問屋町');
ok($zip->set_number('2600026')->is_valid_number, '千葉県千葉市中央区千葉港');
ok($zip->set_number('2600027')->is_valid_number, '千葉県千葉市中央区新田町');
ok($zip->set_number('2600028')->is_valid_number, '千葉県千葉市中央区新町');
ok($zip->set_number('2600031')->is_valid_number, '千葉県千葉市中央区新千葉');
ok($zip->set_number('2600032')->is_valid_number, '千葉県千葉市中央区登戸');
ok($zip->set_number('2600033')->is_valid_number, '千葉県千葉市中央区春日');
ok($zip->set_number('2600034')->is_valid_number, '千葉県千葉市中央区汐見丘町');
ok($zip->set_number('2600041')->is_valid_number, '千葉県千葉市中央区東千葉');
ok($zip->set_number('2600042')->is_valid_number, '千葉県千葉市中央区椿森');
ok($zip->set_number('2600044')->is_valid_number, '千葉県千葉市中央区松波');
ok($zip->set_number('2600045')->is_valid_number, '千葉県千葉市中央区弁天');
ok($zip->set_number('2600801')->is_valid_number, '千葉県千葉市中央区仁戸名町');
ok($zip->set_number('2600802')->is_valid_number, '千葉県千葉市中央区川戸町');
ok($zip->set_number('2600803')->is_valid_number, '千葉県千葉市中央区花輪町');
ok($zip->set_number('2600804')->is_valid_number, '千葉県千葉市中央区赤井町');
ok($zip->set_number('2600805')->is_valid_number, '千葉県千葉市中央区宮崎町');
ok($zip->set_number('2600806')->is_valid_number, '千葉県千葉市中央区宮崎');
ok($zip->set_number('2600807')->is_valid_number, '千葉県千葉市中央区松ケ丘町');
ok($zip->set_number('2600808')->is_valid_number, '千葉県千葉市中央区星久喜町');
ok($zip->set_number('2600811')->is_valid_number, '千葉県千葉市中央区大森町');
ok($zip->set_number('2600812')->is_valid_number, '千葉県千葉市中央区大巌寺町');
ok($zip->set_number('2600813')->is_valid_number, '千葉県千葉市中央区生実町');
ok($zip->set_number('2600814')->is_valid_number, '千葉県千葉市中央区南生実町');
ok($zip->set_number('2600815')->is_valid_number, '千葉県千葉市中央区今井町');
ok($zip->set_number('2600816')->is_valid_number, '千葉県千葉市中央区鵜の森町');
ok($zip->set_number('2600821')->is_valid_number, '千葉県千葉市中央区若草');
ok($zip->set_number('2600822')->is_valid_number, '千葉県千葉市中央区蘇我');
ok($zip->set_number('2600822')->is_valid_number, '千葉県千葉市中央区蘇我町');
ok($zip->set_number('2600823')->is_valid_number, '千葉県千葉市中央区塩田町');
ok($zip->set_number('2600824')->is_valid_number, '千葉県千葉市中央区浜野町');
ok($zip->set_number('2600825')->is_valid_number, '千葉県千葉市中央区村田町');
ok($zip->set_number('2600826')->is_valid_number, '千葉県千葉市中央区新浜町');
ok($zip->set_number('2600831')->is_valid_number, '千葉県千葉市中央区港町');
ok($zip->set_number('2600832')->is_valid_number, '千葉県千葉市中央区寒川町');
ok($zip->set_number('2600833')->is_valid_number, '千葉県千葉市中央区稲荷町');
ok($zip->set_number('2600834')->is_valid_number, '千葉県千葉市中央区今井');
ok($zip->set_number('2600835')->is_valid_number, '千葉県千葉市中央区川崎町');
ok($zip->set_number('2600841')->is_valid_number, '千葉県千葉市中央区白旗');
ok($zip->set_number('2600842')->is_valid_number, '千葉県千葉市中央区南町');
ok($zip->set_number('2600843')->is_valid_number, '千葉県千葉市中央区末広');
ok($zip->set_number('2600844')->is_valid_number, '千葉県千葉市中央区千葉寺町');
ok($zip->set_number('2600851')->is_valid_number, '千葉県千葉市中央区矢作町');
ok($zip->set_number('2600852')->is_valid_number, '千葉県千葉市中央区青葉町');
ok($zip->set_number('2600853')->is_valid_number, '千葉県千葉市中央区葛城');
ok($zip->set_number('2600854')->is_valid_number, '千葉県千葉市中央区長洲');
ok($zip->set_number('2600855')->is_valid_number, '千葉県千葉市中央区市場町');
ok($zip->set_number('2600856')->is_valid_number, '千葉県千葉市中央区亥鼻');
ok($zip->set_number('2600857')->is_valid_number, '千葉県千葉市中央区亀岡町');
ok($zip->set_number('2610000')->is_valid_number, '千葉県千葉市美浜区以下に掲載がない場合');
ok($zip->set_number('2610001')->is_valid_number, '千葉県千葉市美浜区幸町');
ok($zip->set_number('2610002')->is_valid_number, '千葉県千葉市美浜区新港');
ok($zip->set_number('2610003')->is_valid_number, '千葉県千葉市美浜区高浜');
ok($zip->set_number('2610004')->is_valid_number, '千葉県千葉市美浜区高洲');
ok($zip->set_number('2610005')->is_valid_number, '千葉県千葉市美浜区稲毛海岸');
ok($zip->set_number('2610011')->is_valid_number, '千葉県千葉市美浜区真砂');
ok($zip->set_number('2610012')->is_valid_number, '千葉県千葉市美浜区磯辺');
ok($zip->set_number('2610013')->is_valid_number, '千葉県千葉市美浜区打瀬');
ok($zip->set_number('2610014')->is_valid_number, '千葉県千葉市美浜区若葉');
ok($zip->set_number('2610021')->is_valid_number, '千葉県千葉市美浜区ひび野');
ok($zip->set_number('2610022')->is_valid_number, '千葉県千葉市美浜区美浜');
ok($zip->set_number('2610023')->is_valid_number, '千葉県千葉市美浜区中瀬(次のビルを除く)');
ok($zip->set_number('2610024')->is_valid_number, '千葉県千葉市美浜区豊砂');
ok($zip->set_number('2610025')->is_valid_number, '千葉県千葉市美浜区浜田');
ok($zip->set_number('2610026')->is_valid_number, '千葉県千葉市美浜区幕張西');
ok($zip->set_number('2617101')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(1階)');
ok($zip->set_number('2617102')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(2階)');
ok($zip->set_number('2617103')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(3階)');
ok($zip->set_number('2617104')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(4階)');
ok($zip->set_number('2617105')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(5階)');
ok($zip->set_number('2617106')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(6階)');
ok($zip->set_number('2617107')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(7階)');
ok($zip->set_number('2617108')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(8階)');
ok($zip->set_number('2617109')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(9階)');
ok($zip->set_number('2617110')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(10階)');
ok($zip->set_number('2617111')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(11階)');
ok($zip->set_number('2617112')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(12階)');
ok($zip->set_number('2617113')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(13階)');
ok($zip->set_number('2617114')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(14階)');
ok($zip->set_number('2617115')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(15階)');
ok($zip->set_number('2617116')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(16階)');
ok($zip->set_number('2617117')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(17階)');
ok($zip->set_number('2617118')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(18階)');
ok($zip->set_number('2617119')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(19階)');
ok($zip->set_number('2617120')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(20階)');
ok($zip->set_number('2617121')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(21階)');
ok($zip->set_number('2617122')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(22階)');
ok($zip->set_number('2617123')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(23階)');
ok($zip->set_number('2617124')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(24階)');
ok($zip->set_number('2617125')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(25階)');
ok($zip->set_number('2617126')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(26階)');
ok($zip->set_number('2617127')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(27階)');
ok($zip->set_number('2617128')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(28階)');
ok($zip->set_number('2617129')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(29階)');
ok($zip->set_number('2617130')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(30階)');
ok($zip->set_number('2617131')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(31階)');
ok($zip->set_number('2617132')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(32階)');
ok($zip->set_number('2617133')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(33階)');
ok($zip->set_number('2617134')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(34階)');
ok($zip->set_number('2617135')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(35階)');
ok($zip->set_number('2617190')->is_valid_number, '千葉県千葉市美浜区中瀬ワールドビジネスガーデン(地階・階層不明)');
ok($zip->set_number('2620000')->is_valid_number, '千葉県千葉市花見川区以下に掲載がない場合');
ok($zip->set_number('2620001')->is_valid_number, '千葉県千葉市花見川区横戸町');
ok($zip->set_number('2620002')->is_valid_number, '千葉県千葉市花見川区内山町');
ok($zip->set_number('2620003')->is_valid_number, '千葉県千葉市花見川区宇那谷町');
ok($zip->set_number('2620004')->is_valid_number, '千葉県千葉市花見川区大日町');
ok($zip->set_number('2620005')->is_valid_number, '千葉県千葉市花見川区こてはし台');
ok($zip->set_number('2620006')->is_valid_number, '千葉県千葉市花見川区横戸台');
ok($zip->set_number('2620007')->is_valid_number, '千葉県千葉市花見川区み春野');
ok($zip->set_number('2620011')->is_valid_number, '千葉県千葉市花見川区三角町');
ok($zip->set_number('2620012')->is_valid_number, '千葉県千葉市花見川区千種町');
ok($zip->set_number('2620013')->is_valid_number, '千葉県千葉市花見川区犢橋町');
ok($zip->set_number('2620014')->is_valid_number, '千葉県千葉市花見川区さつきが丘');
ok($zip->set_number('2620015')->is_valid_number, '千葉県千葉市花見川区宮野木台');
ok($zip->set_number('2620016')->is_valid_number, '千葉県千葉市花見川区西小中台');
ok($zip->set_number('2620017')->is_valid_number, '千葉県千葉市花見川区朝日ケ丘町');
ok($zip->set_number('2620018')->is_valid_number, '千葉県千葉市花見川区畑町');
ok($zip->set_number('2620019')->is_valid_number, '千葉県千葉市花見川区朝日ケ丘');
ok($zip->set_number('2620021')->is_valid_number, '千葉県千葉市花見川区花園町');
ok($zip->set_number('2620022')->is_valid_number, '千葉県千葉市花見川区南花園');
ok($zip->set_number('2620023')->is_valid_number, '千葉県千葉市花見川区検見川町');
ok($zip->set_number('2620024')->is_valid_number, '千葉県千葉市花見川区浪花町');
ok($zip->set_number('2620025')->is_valid_number, '千葉県千葉市花見川区花園');
ok($zip->set_number('2620026')->is_valid_number, '千葉県千葉市花見川区瑞穂');
ok($zip->set_number('2620031')->is_valid_number, '千葉県千葉市花見川区武石町');
ok($zip->set_number('2620032')->is_valid_number, '千葉県千葉市花見川区幕張町');
ok($zip->set_number('2620033')->is_valid_number, '千葉県千葉市花見川区幕張本郷');
ok($zip->set_number('2620041')->is_valid_number, '千葉県千葉市花見川区柏井町');
ok($zip->set_number('2620042')->is_valid_number, '千葉県千葉市花見川区花島町');
ok($zip->set_number('2620043')->is_valid_number, '千葉県千葉市花見川区天戸町');
ok($zip->set_number('2620044')->is_valid_number, '千葉県千葉市花見川区長作町');
ok($zip->set_number('2620045')->is_valid_number, '千葉県千葉市花見川区作新台');
ok($zip->set_number('2620046')->is_valid_number, '千葉県千葉市花見川区花見川');
ok($zip->set_number('2620047')->is_valid_number, '千葉県千葉市花見川区長作台');
ok($zip->set_number('2620048')->is_valid_number, '千葉県千葉市花見川区柏井');
ok($zip->set_number('2630000')->is_valid_number, '千葉県千葉市稲毛区以下に掲載がない場合');
ok($zip->set_number('2630001')->is_valid_number, '千葉県千葉市稲毛区長沼原町');
ok($zip->set_number('2630002')->is_valid_number, '千葉県千葉市稲毛区山王町');
ok($zip->set_number('2630003')->is_valid_number, '千葉県千葉市稲毛区小深町');
ok($zip->set_number('2630004')->is_valid_number, '千葉県千葉市稲毛区六方町');
ok($zip->set_number('2630005')->is_valid_number, '千葉県千葉市稲毛区長沼町');
ok($zip->set_number('2630011')->is_valid_number, '千葉県千葉市稲毛区天台町');
ok($zip->set_number('2630012')->is_valid_number, '千葉県千葉市稲毛区萩台町');
ok($zip->set_number('2630013')->is_valid_number, '千葉県千葉市稲毛区千草台');
ok($zip->set_number('2630014')->is_valid_number, '千葉県千葉市稲毛区作草部町');
ok($zip->set_number('2630015')->is_valid_number, '千葉県千葉市稲毛区作草部');
ok($zip->set_number('2630016')->is_valid_number, '千葉県千葉市稲毛区天台');
ok($zip->set_number('2630021')->is_valid_number, '千葉県千葉市稲毛区轟町');
ok($zip->set_number('2630022')->is_valid_number, '千葉県千葉市稲毛区弥生町');
ok($zip->set_number('2630023')->is_valid_number, '千葉県千葉市稲毛区緑町');
ok($zip->set_number('2630024')->is_valid_number, '千葉県千葉市稲毛区穴川');
ok($zip->set_number('2630025')->is_valid_number, '千葉県千葉市稲毛区穴川町');
ok($zip->set_number('2630031')->is_valid_number, '千葉県千葉市稲毛区稲毛東');
ok($zip->set_number('2630032')->is_valid_number, '千葉県千葉市稲毛区稲毛台町');
ok($zip->set_number('2630033')->is_valid_number, '千葉県千葉市稲毛区稲丘町');
ok($zip->set_number('2630034')->is_valid_number, '千葉県千葉市稲毛区稲毛');
ok($zip->set_number('2630035')->is_valid_number, '千葉県千葉市稲毛区稲毛町');
ok($zip->set_number('2630041')->is_valid_number, '千葉県千葉市稲毛区黒砂台');
ok($zip->set_number('2630042')->is_valid_number, '千葉県千葉市稲毛区黒砂');
ok($zip->set_number('2630043')->is_valid_number, '千葉県千葉市稲毛区小仲台');
ok($zip->set_number('2630044')->is_valid_number, '千葉県千葉市稲毛区小中台町');
ok($zip->set_number('2630051')->is_valid_number, '千葉県千葉市稲毛区園生町');
ok($zip->set_number('2630052')->is_valid_number, '千葉県千葉市稲毛区あやめ台');
ok($zip->set_number('2630053')->is_valid_number, '千葉県千葉市稲毛区柏台');
ok($zip->set_number('2630054')->is_valid_number, '千葉県千葉市稲毛区宮野木町');
ok($zip->set_number('2640000')->is_valid_number, '千葉県千葉市若葉区以下に掲載がない場合');
ok($zip->set_number('2640001')->is_valid_number, '千葉県千葉市若葉区金親町');
ok($zip->set_number('2640002')->is_valid_number, '千葉県千葉市若葉区千城台東');
ok($zip->set_number('2640003')->is_valid_number, '千葉県千葉市若葉区千城台南');
ok($zip->set_number('2640004')->is_valid_number, '千葉県千葉市若葉区千城台西');
ok($zip->set_number('2640005')->is_valid_number, '千葉県千葉市若葉区千城台北');
ok($zip->set_number('2640006')->is_valid_number, '千葉県千葉市若葉区小倉台');
ok($zip->set_number('2640007')->is_valid_number, '千葉県千葉市若葉区小倉町');
ok($zip->set_number('2640011')->is_valid_number, '千葉県千葉市若葉区大草町');
ok($zip->set_number('2640012')->is_valid_number, '千葉県千葉市若葉区坂月町');
ok($zip->set_number('2640013')->is_valid_number, '千葉県千葉市若葉区太田町');
ok($zip->set_number('2640014')->is_valid_number, '千葉県千葉市若葉区北大宮台');
ok($zip->set_number('2640015')->is_valid_number, '千葉県千葉市若葉区大宮台');
ok($zip->set_number('2640016')->is_valid_number, '千葉県千葉市若葉区大宮町');
ok($zip->set_number('2640017')->is_valid_number, '千葉県千葉市若葉区加曽利町');
ok($zip->set_number('2640020')->is_valid_number, '千葉県千葉市若葉区貝塚');
ok($zip->set_number('2640021')->is_valid_number, '千葉県千葉市若葉区若松町');
ok($zip->set_number('2640023')->is_valid_number, '千葉県千葉市若葉区貝塚町');
ok($zip->set_number('2640024')->is_valid_number, '千葉県千葉市若葉区高品町');
ok($zip->set_number('2640025')->is_valid_number, '千葉県千葉市若葉区都賀');
ok($zip->set_number('2640026')->is_valid_number, '千葉県千葉市若葉区西都賀');
ok($zip->set_number('2640027')->is_valid_number, '千葉県千葉市若葉区若松台');
ok($zip->set_number('2640028')->is_valid_number, '千葉県千葉市若葉区桜木');
ok($zip->set_number('2640029')->is_valid_number, '千葉県千葉市若葉区桜木北');
ok($zip->set_number('2640031')->is_valid_number, '千葉県千葉市若葉区愛生町');
ok($zip->set_number('2640032')->is_valid_number, '千葉県千葉市若葉区みつわ台');
ok($zip->set_number('2640033')->is_valid_number, '千葉県千葉市若葉区都賀の台');
ok($zip->set_number('2640034')->is_valid_number, '千葉県千葉市若葉区原町');
ok($zip->set_number('2640035')->is_valid_number, '千葉県千葉市若葉区東寺山町');
ok($zip->set_number('2640036')->is_valid_number, '千葉県千葉市若葉区殿台町');
ok($zip->set_number('2640037')->is_valid_number, '千葉県千葉市若葉区源町');
ok($zip->set_number('2650041')->is_valid_number, '千葉県千葉市若葉区富田町');
ok($zip->set_number('2650042')->is_valid_number, '千葉県千葉市若葉区古泉町');
ok($zip->set_number('2650043')->is_valid_number, '千葉県千葉市若葉区中田町');
ok($zip->set_number('2650044')->is_valid_number, '千葉県千葉市若葉区下泉町');
ok($zip->set_number('2650045')->is_valid_number, '千葉県千葉市若葉区上泉町');
ok($zip->set_number('2650046')->is_valid_number, '千葉県千葉市若葉区小間子町');
ok($zip->set_number('2650051')->is_valid_number, '千葉県千葉市若葉区中野町');
ok($zip->set_number('2650052')->is_valid_number, '千葉県千葉市若葉区和泉町');
ok($zip->set_number('2650053')->is_valid_number, '千葉県千葉市若葉区野呂町');
ok($zip->set_number('2650061')->is_valid_number, '千葉県千葉市若葉区高根町');
ok($zip->set_number('2650062')->is_valid_number, '千葉県千葉市若葉区川井町');
ok($zip->set_number('2650063')->is_valid_number, '千葉県千葉市若葉区五十土町');
ok($zip->set_number('2650064')->is_valid_number, '千葉県千葉市若葉区大広町');
ok($zip->set_number('2650065')->is_valid_number, '千葉県千葉市若葉区佐和町');
ok($zip->set_number('2650066')->is_valid_number, '千葉県千葉市若葉区多部田町');
ok($zip->set_number('2650067')->is_valid_number, '千葉県千葉市若葉区北谷津町');
ok($zip->set_number('2650071')->is_valid_number, '千葉県千葉市若葉区旦谷町');
ok($zip->set_number('2650072')->is_valid_number, '千葉県千葉市若葉区谷当町');
ok($zip->set_number('2650073')->is_valid_number, '千葉県千葉市若葉区更科町');
ok($zip->set_number('2650074')->is_valid_number, '千葉県千葉市若葉区御殿町');
ok($zip->set_number('2650075')->is_valid_number, '千葉県千葉市若葉区大井戸町');
ok($zip->set_number('2650076')->is_valid_number, '千葉県千葉市若葉区下田町');
ok($zip->set_number('2650077')->is_valid_number, '千葉県千葉市若葉区御成台');
ok($zip->set_number('2660000')->is_valid_number, '千葉県千葉市緑区以下に掲載がない場合');
ok($zip->set_number('2660001')->is_valid_number, '千葉県千葉市緑区東山科町');
ok($zip->set_number('2660002')->is_valid_number, '千葉県千葉市緑区平山町');
ok($zip->set_number('2660003')->is_valid_number, '千葉県千葉市緑区高田町');
ok($zip->set_number('2660004')->is_valid_number, '千葉県千葉市緑区平川町');
ok($zip->set_number('2660005')->is_valid_number, '千葉県千葉市緑区誉田町');
ok($zip->set_number('2660006')->is_valid_number, '千葉県千葉市緑区大膳野町');
ok($zip->set_number('2660007')->is_valid_number, '千葉県千葉市緑区辺田町');
ok($zip->set_number('2660011')->is_valid_number, '千葉県千葉市緑区鎌取町');
ok($zip->set_number('2660014')->is_valid_number, '千葉県千葉市緑区大金沢町');
ok($zip->set_number('2660015')->is_valid_number, '千葉県千葉市緑区小金沢町');
ok($zip->set_number('2660016')->is_valid_number, '千葉県千葉市緑区椎名崎町');
ok($zip->set_number('2660021')->is_valid_number, '千葉県千葉市緑区刈田子町');
ok($zip->set_number('2660022')->is_valid_number, '千葉県千葉市緑区富岡町');
ok($zip->set_number('2660023')->is_valid_number, '千葉県千葉市緑区茂呂町');
ok($zip->set_number('2660024')->is_valid_number, '千葉県千葉市緑区中西町');
ok($zip->set_number('2660025')->is_valid_number, '千葉県千葉市緑区落井町');
ok($zip->set_number('2660026')->is_valid_number, '千葉県千葉市緑区古市場町');
ok($zip->set_number('2660031')->is_valid_number, '千葉県千葉市緑区おゆみ野');
ok($zip->set_number('2660032')->is_valid_number, '千葉県千葉市緑区おゆみ野中央');
ok($zip->set_number('2660033')->is_valid_number, '千葉県千葉市緑区おゆみ野南');
ok($zip->set_number('2660034')->is_valid_number, '千葉県千葉市緑区おゆみ野有吉');
ok($zip->set_number('2670051')->is_valid_number, '千葉県千葉市緑区上大和田町');
ok($zip->set_number('2670052')->is_valid_number, '千葉県千葉市緑区下大和田町');
ok($zip->set_number('2670053')->is_valid_number, '千葉県千葉市緑区高津戸町');
ok($zip->set_number('2670054')->is_valid_number, '千葉県千葉市緑区大高町');
ok($zip->set_number('2670055')->is_valid_number, '千葉県千葉市緑区越智町');
ok($zip->set_number('2670056')->is_valid_number, '千葉県千葉市緑区大野台');
ok($zip->set_number('2670057')->is_valid_number, '千葉県千葉市緑区大木戸町');
ok($zip->set_number('2670061')->is_valid_number, '千葉県千葉市緑区土気町');
ok($zip->set_number('2670062')->is_valid_number, '千葉県千葉市緑区小食土町');
ok($zip->set_number('2670063')->is_valid_number, '千葉県千葉市緑区小山町');
ok($zip->set_number('2670064')->is_valid_number, '千葉県千葉市緑区板倉町');
ok($zip->set_number('2670065')->is_valid_number, '千葉県千葉市緑区大椎町');
ok($zip->set_number('2670066')->is_valid_number, '千葉県千葉市緑区あすみが丘');
ok($zip->set_number('2670067')->is_valid_number, '千葉県千葉市緑区あすみが丘東');
ok($zip->set_number('2700000')->is_valid_number, '千葉県松戸市以下に掲載がない場合');
ok($zip->set_number('2700001')->is_valid_number, '千葉県松戸市幸田');
ok($zip->set_number('2700002')->is_valid_number, '千葉県松戸市平賀');
ok($zip->set_number('2700003')->is_valid_number, '千葉県松戸市東平賀');
ok($zip->set_number('2700004')->is_valid_number, '千葉県松戸市殿平賀');
ok($zip->set_number('2700005')->is_valid_number, '千葉県松戸市大谷口');
ok($zip->set_number('2700006')->is_valid_number, '千葉県松戸市大金平');
ok($zip->set_number('2700007')->is_valid_number, '千葉県松戸市中金杉');
ok($zip->set_number('2700011')->is_valid_number, '千葉県松戸市根木内');
ok($zip->set_number('2700012')->is_valid_number, '千葉県松戸市久保平賀');
ok($zip->set_number('2700013')->is_valid_number, '千葉県松戸市小金きよしケ丘');
ok($zip->set_number('2700014')->is_valid_number, '千葉県松戸市小金');
ok($zip->set_number('2700015')->is_valid_number, '千葉県松戸市小金上総町');
ok($zip->set_number('2700016')->is_valid_number, '千葉県松戸市小金清志町');
ok($zip->set_number('2700017')->is_valid_number, '千葉県松戸市幸谷');
ok($zip->set_number('2700018')->is_valid_number, '千葉県松戸市上総内');
ok($zip->set_number('2700021')->is_valid_number, '千葉県松戸市小金原');
ok($zip->set_number('2700022')->is_valid_number, '千葉県松戸市栗ケ沢');
ok($zip->set_number('2700023')->is_valid_number, '千葉県松戸市八ケ崎');
ok($zip->set_number('2700024')->is_valid_number, '千葉県松戸市八ケ崎緑町');
ok($zip->set_number('2700025')->is_valid_number, '千葉県松戸市中和倉');
ok($zip->set_number('2700026')->is_valid_number, '千葉県松戸市三ケ月');
ok($zip->set_number('2700027')->is_valid_number, '千葉県松戸市二ツ木');
ok($zip->set_number('2700028')->is_valid_number, '千葉県松戸市二ツ木二葉町');
ok($zip->set_number('2700031')->is_valid_number, '千葉県松戸市横須賀');
ok($zip->set_number('2700032')->is_valid_number, '千葉県松戸市新松戸北');
ok($zip->set_number('2700033')->is_valid_number, '千葉県松戸市新松戸東');
ok($zip->set_number('2700034')->is_valid_number, '千葉県松戸市新松戸');
ok($zip->set_number('2700035')->is_valid_number, '千葉県松戸市新松戸南');
ok($zip->set_number('2700036')->is_valid_number, '千葉県松戸市大谷口新田');
ok($zip->set_number('2700100')->is_valid_number, '千葉県流山市以下に掲載がない場合');
ok($zip->set_number('2700101')->is_valid_number, '千葉県流山市東深井');
ok($zip->set_number('2700102')->is_valid_number, '千葉県流山市こうのす台');
ok($zip->set_number('2700103')->is_valid_number, '千葉県流山市美原');
ok($zip->set_number('2700105')->is_valid_number, '千葉県流山市平方');
ok($zip->set_number('2700106')->is_valid_number, '千葉県流山市平方村新田');
ok($zip->set_number('2700107')->is_valid_number, '千葉県流山市西深井');
ok($zip->set_number('2700108')->is_valid_number, '千葉県流山市深井新田');
ok($zip->set_number('2700111')->is_valid_number, '千葉県流山市江戸川台東');
ok($zip->set_number('2700112')->is_valid_number, '千葉県流山市青田');
ok($zip->set_number('2700113')->is_valid_number, '千葉県流山市駒木台');
ok($zip->set_number('2700114')->is_valid_number, '千葉県流山市東初石');
ok($zip->set_number('2700115')->is_valid_number, '千葉県流山市江戸川台西');
ok($zip->set_number('2700116')->is_valid_number, '千葉県流山市中野久木');
ok($zip->set_number('2700117')->is_valid_number, '千葉県流山市北');
ok($zip->set_number('2700118')->is_valid_number, '千葉県流山市小屋');
ok($zip->set_number('2700119')->is_valid_number, '千葉県流山市おおたかの森北');
ok($zip->set_number('2700121')->is_valid_number, '千葉県流山市西初石');
ok($zip->set_number('2700122')->is_valid_number, '千葉県流山市大畔');
ok($zip->set_number('2700123')->is_valid_number, '千葉県流山市若葉台');
ok($zip->set_number('2700124')->is_valid_number, '千葉県流山市南');
ok($zip->set_number('2700125')->is_valid_number, '千葉県流山市上新宿');
ok($zip->set_number('2700126')->is_valid_number, '千葉県流山市上新宿新田');
ok($zip->set_number('2700127')->is_valid_number, '千葉県流山市富士見台');
ok($zip->set_number('2700128')->is_valid_number, '千葉県流山市おおたかの森西');
ok($zip->set_number('2700131')->is_valid_number, '千葉県流山市美田');
ok($zip->set_number('2700132')->is_valid_number, '千葉県流山市駒木');
ok($zip->set_number('2700133')->is_valid_number, '千葉県流山市十太夫');
ok($zip->set_number('2700134')->is_valid_number, '千葉県流山市長崎');
ok($zip->set_number('2700135')->is_valid_number, '千葉県流山市野々下');
ok($zip->set_number('2700136')->is_valid_number, '千葉県流山市古間木');
ok($zip->set_number('2700137')->is_valid_number, '千葉県流山市市野谷');
ok($zip->set_number('2700138')->is_valid_number, '千葉県流山市おおたかの森東');
ok($zip->set_number('2700139')->is_valid_number, '千葉県流山市おおたかの森南');
ok($zip->set_number('2700141')->is_valid_number, '千葉県流山市松ケ丘');
ok($zip->set_number('2700142')->is_valid_number, '千葉県流山市西松ケ丘');
ok($zip->set_number('2700143')->is_valid_number, '千葉県流山市向小金');
ok($zip->set_number('2700144')->is_valid_number, '千葉県流山市前ケ崎');
ok($zip->set_number('2700145')->is_valid_number, '千葉県流山市名都借');
ok($zip->set_number('2700146')->is_valid_number, '千葉県流山市芝崎');
ok($zip->set_number('2700151')->is_valid_number, '千葉県流山市後平井');
ok($zip->set_number('2700152')->is_valid_number, '千葉県流山市前平井');
ok($zip->set_number('2700153')->is_valid_number, '千葉県流山市中');
ok($zip->set_number('2700154')->is_valid_number, '千葉県流山市思井');
ok($zip->set_number('2700155')->is_valid_number, '千葉県流山市宮園');
ok($zip->set_number('2700156')->is_valid_number, '千葉県流山市西平井');
ok($zip->set_number('2700157')->is_valid_number, '千葉県流山市平和台');
ok($zip->set_number('2700161')->is_valid_number, '千葉県流山市鰭ケ崎');
ok($zip->set_number('2700162')->is_valid_number, '千葉県流山市木');
ok($zip->set_number('2700163')->is_valid_number, '千葉県流山市南流山');
ok($zip->set_number('2700164')->is_valid_number, '千葉県流山市流山');
ok($zip->set_number('2700171')->is_valid_number, '千葉県流山市上貝塚');
ok($zip->set_number('2700172')->is_valid_number, '千葉県流山市桐ケ谷');
ok($zip->set_number('2700173')->is_valid_number, '千葉県流山市谷');
ok($zip->set_number('2700174')->is_valid_number, '千葉県流山市下花輪');
ok($zip->set_number('2700175')->is_valid_number, '千葉県流山市三輪野山');
ok($zip->set_number('2700176')->is_valid_number, '千葉県流山市加');
ok($zip->set_number('2700201')->is_valid_number, '千葉県野田市関宿三軒家');
ok($zip->set_number('2700202')->is_valid_number, '千葉県野田市関宿台町');
ok($zip->set_number('2700203')->is_valid_number, '千葉県野田市関宿元町');
ok($zip->set_number('2700204')->is_valid_number, '千葉県野田市関宿内町');
ok($zip->set_number('2700205')->is_valid_number, '千葉県野田市関宿江戸町');
ok($zip->set_number('2700206')->is_valid_number, '千葉県野田市関宿町');
ok($zip->set_number('2700211')->is_valid_number, '千葉県野田市東高野');
ok($zip->set_number('2700212')->is_valid_number, '千葉県野田市新田戸');
ok($zip->set_number('2700213')->is_valid_number, '千葉県野田市桐ケ作');
ok($zip->set_number('2700214')->is_valid_number, '千葉県野田市柏寺');
ok($zip->set_number('2700215')->is_valid_number, '千葉県野田市中戸');
ok($zip->set_number('2700216')->is_valid_number, '千葉県野田市西高野');
ok($zip->set_number('2700217')->is_valid_number, '千葉県野田市はやま');
ok($zip->set_number('2700221')->is_valid_number, '千葉県野田市古布内');
ok($zip->set_number('2700222')->is_valid_number, '千葉県野田市木間ケ瀬');
ok($zip->set_number('2700223')->is_valid_number, '千葉県野田市岡田');
ok($zip->set_number('2700224')->is_valid_number, '千葉県野田市丸井');
ok($zip->set_number('2700225')->is_valid_number, '千葉県野田市平井');
ok($zip->set_number('2700226')->is_valid_number, '千葉県野田市東宝珠花');
ok($zip->set_number('2700227')->is_valid_number, '千葉県野田市親野井');
ok($zip->set_number('2700228')->is_valid_number, '千葉県野田市次木');
ok($zip->set_number('2700229')->is_valid_number, '千葉県野田市なみき');
ok($zip->set_number('2700231')->is_valid_number, '千葉県野田市小山');
ok($zip->set_number('2700232')->is_valid_number, '千葉県野田市莚打');
ok($zip->set_number('2700233')->is_valid_number, '千葉県野田市船形');
ok($zip->set_number('2700234')->is_valid_number, '千葉県野田市日の出町');
ok($zip->set_number('2700235')->is_valid_number, '千葉県野田市尾崎');
ok($zip->set_number('2700236')->is_valid_number, '千葉県野田市東金野井');
ok($zip->set_number('2700237')->is_valid_number, '千葉県野田市中里');
ok($zip->set_number('2700238')->is_valid_number, '千葉県野田市尾崎台');
ok($zip->set_number('2700239')->is_valid_number, '千葉県野田市泉');
ok($zip->set_number('2701100')->is_valid_number, '千葉県我孫子市以下に掲載がない場合');
ok($zip->set_number('2701101')->is_valid_number, '千葉県我孫子市布佐');
ok($zip->set_number('2701102')->is_valid_number, '千葉県我孫子市都');
ok($zip->set_number('2701103')->is_valid_number, '千葉県我孫子市布佐酉町');
ok($zip->set_number('2701104')->is_valid_number, '千葉県我孫子市新々田');
ok($zip->set_number('2701105')->is_valid_number, '千葉県我孫子市三河屋新田');
ok($zip->set_number('2701106')->is_valid_number, '千葉県我孫子市相島新田');
ok($zip->set_number('2701107')->is_valid_number, '千葉県我孫子市布佐下新田');
ok($zip->set_number('2701108')->is_valid_number, '千葉県我孫子市布佐平和台');
ok($zip->set_number('2701111')->is_valid_number, '千葉県我孫子市古戸');
ok($zip->set_number('2701112')->is_valid_number, '千葉県我孫子市新木');
ok($zip->set_number('2701113')->is_valid_number, '千葉県我孫子市江蔵地');
ok($zip->set_number('2701114')->is_valid_number, '千葉県我孫子市新木野');
ok($zip->set_number('2701115')->is_valid_number, '千葉県我孫子市大作新田');
ok($zip->set_number('2701116')->is_valid_number, '千葉県我孫子市浅間前新田');
ok($zip->set_number('2701117')->is_valid_number, '千葉県我孫子市下沼田');
ok($zip->set_number('2701118')->is_valid_number, '千葉県我孫子市新木村下');
ok($zip->set_number('2701119')->is_valid_number, '千葉県我孫子市南新木');
ok($zip->set_number('2701121')->is_valid_number, '千葉県我孫子市中峠');
ok($zip->set_number('2701122')->is_valid_number, '千葉県我孫子市中里');
ok($zip->set_number('2701123')->is_valid_number, '千葉県我孫子市日秀');
ok($zip->set_number('2701124')->is_valid_number, '千葉県我孫子市日秀新田');
ok($zip->set_number('2701125')->is_valid_number, '千葉県我孫子市中沼田');
ok($zip->set_number('2701126')->is_valid_number, '千葉県我孫子市中里新田');
ok($zip->set_number('2701127')->is_valid_number, '千葉県我孫子市中峠村下');
ok($zip->set_number('2701128')->is_valid_number, '千葉県我孫子市中峠台');
ok($zip->set_number('2701131')->is_valid_number, '千葉県我孫子市都部');
ok($zip->set_number('2701132')->is_valid_number, '千葉県我孫子市湖北台');
ok($zip->set_number('2701133')->is_valid_number, '千葉県我孫子市上沼田');
ok($zip->set_number('2701134')->is_valid_number, '千葉県我孫子市都部村新田');
ok($zip->set_number('2701135')->is_valid_number, '千葉県我孫子市都部新田');
ok($zip->set_number('2701136')->is_valid_number, '千葉県我孫子市岡発戸新田');
ok($zip->set_number('2701137')->is_valid_number, '千葉県我孫子市岡発戸');
ok($zip->set_number('2701138')->is_valid_number, '千葉県我孫子市下ケ戸');
ok($zip->set_number('2701141')->is_valid_number, '千葉県我孫子市栄');
ok($zip->set_number('2701142')->is_valid_number, '千葉県我孫子市泉');
ok($zip->set_number('2701143')->is_valid_number, '千葉県我孫子市天王台');
ok($zip->set_number('2701144')->is_valid_number, '千葉県我孫子市東我孫子');
ok($zip->set_number('2701145')->is_valid_number, '千葉県我孫子市高野山');
ok($zip->set_number('2701146')->is_valid_number, '千葉県我孫子市高野山新田');
ok($zip->set_number('2701147')->is_valid_number, '千葉県我孫子市若松');
ok($zip->set_number('2701151')->is_valid_number, '千葉県我孫子市本町');
ok($zip->set_number('2701152')->is_valid_number, '千葉県我孫子市寿');
ok($zip->set_number('2701153')->is_valid_number, '千葉県我孫子市緑');
ok($zip->set_number('2701154')->is_valid_number, '千葉県我孫子市白山');
ok($zip->set_number('2701155')->is_valid_number, '千葉県我孫子市我孫子新田');
ok($zip->set_number('2701156')->is_valid_number, '千葉県我孫子市根戸新田');
ok($zip->set_number('2701157')->is_valid_number, '千葉県我孫子市呼塚新田');
ok($zip->set_number('2701158')->is_valid_number, '千葉県我孫子市船戸');
ok($zip->set_number('2701161')->is_valid_number, '千葉県我孫子市布施下');
ok($zip->set_number('2701162')->is_valid_number, '千葉県我孫子市布施');
ok($zip->set_number('2701163')->is_valid_number, '千葉県我孫子市久寺家');
ok($zip->set_number('2701164')->is_valid_number, '千葉県我孫子市つくし野');
ok($zip->set_number('2701165')->is_valid_number, '千葉県我孫子市並木');
ok($zip->set_number('2701166')->is_valid_number, '千葉県我孫子市我孫子');
ok($zip->set_number('2701167')->is_valid_number, '千葉県我孫子市台田');
ok($zip->set_number('2701168')->is_valid_number, '千葉県我孫子市根戸');
ok($zip->set_number('2701171')->is_valid_number, '千葉県我孫子市弁天下');
ok($zip->set_number('2701172')->is_valid_number, '千葉県我孫子市北新田');
ok($zip->set_number('2701173')->is_valid_number, '千葉県我孫子市青山');
ok($zip->set_number('2701174')->is_valid_number, '千葉県我孫子市日の出');
ok($zip->set_number('2701175')->is_valid_number, '千葉県我孫子市青山台');
ok($zip->set_number('2701176')->is_valid_number, '千葉県我孫子市柴崎台');
ok($zip->set_number('2701177')->is_valid_number, '千葉県我孫子市柴崎');
ok($zip->set_number('2701178')->is_valid_number, '千葉県我孫子市南青山');
ok($zip->set_number('2701300')->is_valid_number, '千葉県印西市以下に掲載がない場合');
ok($zip->set_number('2701313')->is_valid_number, '千葉県印西市小林北');
ok($zip->set_number('2701315')->is_valid_number, '千葉県印西市小林浅間');
ok($zip->set_number('2701316')->is_valid_number, '千葉県印西市小林大門下');
ok($zip->set_number('2701318')->is_valid_number, '千葉県印西市小林');
ok($zip->set_number('2701321')->is_valid_number, '千葉県印西市相嶋');
ok($zip->set_number('2701322')->is_valid_number, '千葉県印西市浅間前');
ok($zip->set_number('2701323')->is_valid_number, '千葉県印西市木下東');
ok($zip->set_number('2701324')->is_valid_number, '千葉県印西市平岡');
ok($zip->set_number('2701325')->is_valid_number, '千葉県印西市竹袋');
ok($zip->set_number('2701326')->is_valid_number, '千葉県印西市木下');
ok($zip->set_number('2701327')->is_valid_number, '千葉県印西市大森');
ok($zip->set_number('2701328')->is_valid_number, '千葉県印西市木下南');
ok($zip->set_number('2701331')->is_valid_number, '千葉県印西市牧の原');
ok($zip->set_number('2701332')->is_valid_number, '千葉県印西市別所');
ok($zip->set_number('2701333')->is_valid_number, '千葉県印西市宗甫');
ok($zip->set_number('2701334')->is_valid_number, '千葉県印西市西の原');
ok($zip->set_number('2701335')->is_valid_number, '千葉県印西市原');
ok($zip->set_number('2701336')->is_valid_number, '千葉県印西市東の原');
ok($zip->set_number('2701337')->is_valid_number, '千葉県印西市草深');
ok($zip->set_number('2701338')->is_valid_number, '千葉県印西市松崎台');
ok($zip->set_number('2701339')->is_valid_number, '千葉県印西市牧の台');
ok($zip->set_number('2701340')->is_valid_number, '千葉県印西市中央南');
ok($zip->set_number('2701341')->is_valid_number, '千葉県印西市原山');
ok($zip->set_number('2701342')->is_valid_number, '千葉県印西市高花');
ok($zip->set_number('2701343')->is_valid_number, '千葉県印西市結縁寺');
ok($zip->set_number('2701344')->is_valid_number, '千葉県印西市松崎');
ok($zip->set_number('2701345')->is_valid_number, '千葉県印西市船尾');
ok($zip->set_number('2701346')->is_valid_number, '千葉県印西市多々羅田');
ok($zip->set_number('2701347')->is_valid_number, '千葉県印西市内野');
ok($zip->set_number('2701348')->is_valid_number, '千葉県印西市戸神');
ok($zip->set_number('2701349')->is_valid_number, '千葉県印西市戸神台');
ok($zip->set_number('2701350')->is_valid_number, '千葉県印西市中央北');
ok($zip->set_number('2701351')->is_valid_number, '千葉県印西市和泉');
ok($zip->set_number('2701352')->is_valid_number, '千葉県印西市大塚');
ok($zip->set_number('2701353')->is_valid_number, '千葉県印西市泉');
ok($zip->set_number('2701354')->is_valid_number, '千葉県印西市武西');
ok($zip->set_number('2701355')->is_valid_number, '千葉県印西市武西学園台');
ok($zip->set_number('2701356')->is_valid_number, '千葉県印西市小倉台');
ok($zip->set_number('2701357')->is_valid_number, '千葉県印西市牧の木戸');
ok($zip->set_number('2701358')->is_valid_number, '千葉県印西市小倉');
ok($zip->set_number('2701359')->is_valid_number, '千葉県印西市木刈');
ok($zip->set_number('2701360')->is_valid_number, '千葉県印西市泉野');
ok($zip->set_number('2701361')->is_valid_number, '千葉県印西市発作');
ok($zip->set_number('2701362')->is_valid_number, '千葉県印西市亀成');
ok($zip->set_number('2701363')->is_valid_number, '千葉県印西市鹿黒');
ok($zip->set_number('2701364')->is_valid_number, '千葉県印西市浦幡新田');
ok($zip->set_number('2701365')->is_valid_number, '千葉県印西市高西新田');
ok($zip->set_number('2701366')->is_valid_number, '千葉県印西市白幡');
ok($zip->set_number('2701367')->is_valid_number, '千葉県印西市浦部');
ok($zip->set_number('2701368')->is_valid_number, '千葉県印西市浦部村新田');
ok($zip->set_number('2701369')->is_valid_number, '千葉県印西市鹿黒南');
ok($zip->set_number('2701400')->is_valid_number, '千葉県白井市以下に掲載がない場合');
ok($zip->set_number('2701401')->is_valid_number, '千葉県白井市今井');
ok($zip->set_number('2701402')->is_valid_number, '千葉県白井市平塚');
ok($zip->set_number('2701403')->is_valid_number, '千葉県白井市河原子');
ok($zip->set_number('2701404')->is_valid_number, '千葉県白井市折立');
ok($zip->set_number('2701405')->is_valid_number, '千葉県白井市富塚');
ok($zip->set_number('2701406')->is_valid_number, '千葉県白井市中');
ok($zip->set_number('2701407')->is_valid_number, '千葉県白井市名内');
ok($zip->set_number('2701408')->is_valid_number, '千葉県白井市西白井');
ok($zip->set_number('2701411')->is_valid_number, '千葉県白井市十余一');
ok($zip->set_number('2701412')->is_valid_number, '千葉県白井市桜台');
ok($zip->set_number('2701413')->is_valid_number, '千葉県白井市武西');
ok($zip->set_number('2701414')->is_valid_number, '千葉県白井市谷田');
ok($zip->set_number('2701415')->is_valid_number, '千葉県白井市清戸');
ok($zip->set_number('2701416')->is_valid_number, '千葉県白井市神々廻');
ok($zip->set_number('2701421')->is_valid_number, '千葉県白井市白井');
ok($zip->set_number('2701422')->is_valid_number, '千葉県白井市復');
ok($zip->set_number('2701423')->is_valid_number, '千葉県白井市南山');
ok($zip->set_number('2701424')->is_valid_number, '千葉県白井市堀込');
ok($zip->set_number('2701425')->is_valid_number, '千葉県白井市池の上');
ok($zip->set_number('2701426')->is_valid_number, '千葉県白井市笹塚');
ok($zip->set_number('2701431')->is_valid_number, '千葉県白井市根');
ok($zip->set_number('2701432')->is_valid_number, '千葉県白井市冨士');
ok($zip->set_number('2701433')->is_valid_number, '千葉県白井市けやき台');
ok($zip->set_number('2701434')->is_valid_number, '千葉県白井市大山口');
ok($zip->set_number('2701435')->is_valid_number, '千葉県白井市清水口');
ok($zip->set_number('2701436')->is_valid_number, '千葉県白井市七次台');
ok($zip->set_number('2701437')->is_valid_number, '千葉県白井市木');
ok($zip->set_number('2701438')->is_valid_number, '千葉県白井市野口');
ok($zip->set_number('2701439')->is_valid_number, '千葉県白井市大松');
ok($zip->set_number('2701441')->is_valid_number, '千葉県柏市鷲野谷新田');
ok($zip->set_number('2701442')->is_valid_number, '千葉県柏市染井入新田');
ok($zip->set_number('2701443')->is_valid_number, '千葉県柏市鷲野谷');
ok($zip->set_number('2701444')->is_valid_number, '千葉県柏市若白毛');
ok($zip->set_number('2701445')->is_valid_number, '千葉県柏市岩井');
ok($zip->set_number('2701446')->is_valid_number, '千葉県柏市岩井村新田');
ok($zip->set_number('2701447')->is_valid_number, '千葉県柏市手賀の杜');
ok($zip->set_number('2701451')->is_valid_number, '千葉県柏市曙橋');
ok($zip->set_number('2701452')->is_valid_number, '千葉県柏市片山新田');
ok($zip->set_number('2701453')->is_valid_number, '千葉県柏市片山');
ok($zip->set_number('2701454')->is_valid_number, '千葉県柏市柳戸');
ok($zip->set_number('2701455')->is_valid_number, '千葉県柏市金山');
ok($zip->set_number('2701456')->is_valid_number, '千葉県柏市泉');
ok($zip->set_number('2701457')->is_valid_number, '千葉県柏市泉村新田');
ok($zip->set_number('2701461')->is_valid_number, '千葉県柏市水道橋');
ok($zip->set_number('2701462')->is_valid_number, '千葉県柏市千間橋');
ok($zip->set_number('2701463')->is_valid_number, '千葉県柏市布瀬新田');
ok($zip->set_number('2701464')->is_valid_number, '千葉県柏市布瀬');
ok($zip->set_number('2701465')->is_valid_number, '千葉県柏市手賀');
ok($zip->set_number('2701466')->is_valid_number, '千葉県柏市手賀新田');
ok($zip->set_number('2701471')->is_valid_number, '千葉県船橋市小室町');
ok($zip->set_number('2701500')->is_valid_number, '千葉県印旛郡栄町以下に掲載がない場合');
ok($zip->set_number('2701501')->is_valid_number, '千葉県印旛郡栄町矢口神明');
ok($zip->set_number('2701502')->is_valid_number, '千葉県印旛郡栄町矢口');
ok($zip->set_number('2701503')->is_valid_number, '千葉県印旛郡栄町興津');
ok($zip->set_number('2701504')->is_valid_number, '千葉県印旛郡栄町麻生');
ok($zip->set_number('2701505')->is_valid_number, '千葉県印旛郡栄町竜角寺台');
ok($zip->set_number('2701506')->is_valid_number, '千葉県印旛郡栄町龍角寺');
ok($zip->set_number('2701511')->is_valid_number, '千葉県印旛郡栄町北辺田');
ok($zip->set_number('2701512')->is_valid_number, '千葉県印旛郡栄町須賀');
ok($zip->set_number('2701513')->is_valid_number, '千葉県印旛郡栄町酒直');
ok($zip->set_number('2701514')->is_valid_number, '千葉県印旛郡栄町酒直台');
ok($zip->set_number('2701515')->is_valid_number, '千葉県印旛郡栄町安食台');
ok($zip->set_number('2701516')->is_valid_number, '千葉県印旛郡栄町安食');
ok($zip->set_number('2701517')->is_valid_number, '千葉県印旛郡栄町安食卜杭新田');
ok($zip->set_number('2701521')->is_valid_number, '千葉県印旛郡栄町和田');
ok($zip->set_number('2701522')->is_valid_number, '千葉県印旛郡栄町布鎌酒直');
ok($zip->set_number('2701523')->is_valid_number, '千葉県印旛郡栄町脇川');
ok($zip->set_number('2701524')->is_valid_number, '千葉県印旛郡栄町長門谷');
ok($zip->set_number('2701525')->is_valid_number, '千葉県印旛郡栄町四箇');
ok($zip->set_number('2701526')->is_valid_number, '千葉県印旛郡栄町大森');
ok($zip->set_number('2701527')->is_valid_number, '千葉県印旛郡栄町押付');
ok($zip->set_number('2701531')->is_valid_number, '千葉県印旛郡栄町曽根');
ok($zip->set_number('2701532')->is_valid_number, '千葉県印旛郡栄町南');
ok($zip->set_number('2701533')->is_valid_number, '千葉県印旛郡栄町南ケ丘');
ok($zip->set_number('2701534')->is_valid_number, '千葉県印旛郡栄町西');
ok($zip->set_number('2701535')->is_valid_number, '千葉県印旛郡栄町布太');
ok($zip->set_number('2701536')->is_valid_number, '千葉県印旛郡栄町三和');
ok($zip->set_number('2701541')->is_valid_number, '千葉県印旛郡栄町龍ケ崎町歩');
ok($zip->set_number('2701542')->is_valid_number, '千葉県印旛郡栄町四ッ谷');
ok($zip->set_number('2701543')->is_valid_number, '千葉県印旛郡栄町請方');
ok($zip->set_number('2701544')->is_valid_number, '千葉県印旛郡栄町中谷');
ok($zip->set_number('2701545')->is_valid_number, '千葉県印旛郡栄町北');
ok($zip->set_number('2701546')->is_valid_number, '千葉県印旛郡栄町生板鍋子新田');
ok($zip->set_number('2701601')->is_valid_number, '千葉県印西市萩原');
ok($zip->set_number('2701602')->is_valid_number, '千葉県印西市松虫');
ok($zip->set_number('2701603')->is_valid_number, '千葉県印西市吉高');
ok($zip->set_number('2701604')->is_valid_number, '千葉県印西市山田');
ok($zip->set_number('2701605')->is_valid_number, '千葉県印西市平賀');
ok($zip->set_number('2701606')->is_valid_number, '千葉県印西市平賀学園台');
ok($zip->set_number('2701607')->is_valid_number, '千葉県印西市美瀬');
ok($zip->set_number('2701608')->is_valid_number, '千葉県印西市舞姫');
ok($zip->set_number('2701609')->is_valid_number, '千葉県印西市若萩');
ok($zip->set_number('2701611')->is_valid_number, '千葉県印西市造谷');
ok($zip->set_number('2701612')->is_valid_number, '千葉県印西市大廻');
ok($zip->set_number('2701613')->is_valid_number, '千葉県印西市鎌苅');
ok($zip->set_number('2701614')->is_valid_number, '千葉県印西市瀬戸');
ok($zip->set_number('2701615')->is_valid_number, '千葉県印西市師戸');
ok($zip->set_number('2701616')->is_valid_number, '千葉県印西市岩戸');
ok($zip->set_number('2701617')->is_valid_number, '千葉県印西市吉田');
ok($zip->set_number('2701618')->is_valid_number, '千葉県印西市つくりや台');
ok($zip->set_number('2702201')->is_valid_number, '千葉県松戸市高柳新田');
ok($zip->set_number('2702202')->is_valid_number, '千葉県松戸市高柳');
ok($zip->set_number('2702203')->is_valid_number, '千葉県松戸市六高台');
ok($zip->set_number('2702204')->is_valid_number, '千葉県松戸市六実');
ok($zip->set_number('2702205')->is_valid_number, '千葉県松戸市六高台西');
ok($zip->set_number('2702211')->is_valid_number, '千葉県松戸市五香六実');
ok($zip->set_number('2702212')->is_valid_number, '千葉県松戸市五香南');
ok($zip->set_number('2702213')->is_valid_number, '千葉県松戸市五香');
ok($zip->set_number('2702214')->is_valid_number, '千葉県松戸市松飛台');
ok($zip->set_number('2702215')->is_valid_number, '千葉県松戸市串崎南町');
ok($zip->set_number('2702216')->is_valid_number, '千葉県松戸市串崎新田');
ok($zip->set_number('2702217')->is_valid_number, '千葉県松戸市初富飛地');
ok($zip->set_number('2702218')->is_valid_number, '千葉県松戸市五香西');
ok($zip->set_number('2702221')->is_valid_number, '千葉県松戸市紙敷');
ok($zip->set_number('2702222')->is_valid_number, '千葉県松戸市高塚新田');
ok($zip->set_number('2702223')->is_valid_number, '千葉県松戸市秋山');
ok($zip->set_number('2702224')->is_valid_number, '千葉県松戸市大橋');
ok($zip->set_number('2702225')->is_valid_number, '千葉県松戸市東松戸');
ok($zip->set_number('2702231')->is_valid_number, '千葉県松戸市稔台');
ok($zip->set_number('2702232')->is_valid_number, '千葉県松戸市和名ケ谷');
ok($zip->set_number('2702241')->is_valid_number, '千葉県松戸市松戸新田');
ok($zip->set_number('2702242')->is_valid_number, '千葉県松戸市仲井町');
ok($zip->set_number('2702243')->is_valid_number, '千葉県松戸市野菊野');
ok($zip->set_number('2702251')->is_valid_number, '千葉県松戸市金ケ作');
ok($zip->set_number('2702252')->is_valid_number, '千葉県松戸市千駄堀');
ok($zip->set_number('2702253')->is_valid_number, '千葉県松戸市日暮');
ok($zip->set_number('2702254')->is_valid_number, '千葉県松戸市河原塚');
ok($zip->set_number('2702255')->is_valid_number, '千葉県松戸市田中新田');
ok($zip->set_number('2702261')->is_valid_number, '千葉県松戸市常盤平');
ok($zip->set_number('2702262')->is_valid_number, '千葉県松戸市常盤平双葉町');
ok($zip->set_number('2702263')->is_valid_number, '千葉県松戸市常盤平柳町');
ok($zip->set_number('2702264')->is_valid_number, '千葉県松戸市常盤平松葉町');
ok($zip->set_number('2702265')->is_valid_number, '千葉県松戸市常盤平陣屋前');
ok($zip->set_number('2702266')->is_valid_number, '千葉県松戸市常盤平西窪町');
ok($zip->set_number('2702267')->is_valid_number, '千葉県松戸市牧の原');
ok($zip->set_number('2702301')->is_valid_number, '千葉県印西市将監');
ok($zip->set_number('2702302')->is_valid_number, '千葉県印西市安食卜杭');
ok($zip->set_number('2702303')->is_valid_number, '千葉県印西市酒直卜杭');
ok($zip->set_number('2702304')->is_valid_number, '千葉県印西市甚兵衛');
ok($zip->set_number('2702305')->is_valid_number, '千葉県印西市佐野屋');
ok($zip->set_number('2702306')->is_valid_number, '千葉県印西市中田切');
ok($zip->set_number('2702307')->is_valid_number, '千葉県印西市松木');
ok($zip->set_number('2702308')->is_valid_number, '千葉県印西市本埜小林');
ok($zip->set_number('2702311')->is_valid_number, '千葉県印西市萩埜');
ok($zip->set_number('2702312')->is_valid_number, '千葉県印西市長門屋');
ok($zip->set_number('2702313')->is_valid_number, '千葉県印西市下井');
ok($zip->set_number('2702314')->is_valid_number, '千葉県印西市桜野');
ok($zip->set_number('2702315')->is_valid_number, '千葉県印西市中');
ok($zip->set_number('2702316')->is_valid_number, '千葉県印西市行徳');
ok($zip->set_number('2702317')->is_valid_number, '千葉県印西市下曽根');
ok($zip->set_number('2702318')->is_valid_number, '千葉県印西市押付');
ok($zip->set_number('2702319')->is_valid_number, '千葉県印西市川向');
ok($zip->set_number('2702321')->is_valid_number, '千葉県印西市物木');
ok($zip->set_number('2702322')->is_valid_number, '千葉県印西市笠神');
ok($zip->set_number('2702323')->is_valid_number, '千葉県印西市和泉屋');
ok($zip->set_number('2702324')->is_valid_number, '千葉県印西市中根');
ok($zip->set_number('2702325')->is_valid_number, '千葉県印西市角田');
ok($zip->set_number('2702326')->is_valid_number, '千葉県印西市荒野');
ok($zip->set_number('2702327')->is_valid_number, '千葉県印西市竜腹寺');
ok($zip->set_number('2702328')->is_valid_number, '千葉県印西市滝');
ok($zip->set_number('2702329')->is_valid_number, '千葉県印西市滝野');
ok($zip->set_number('2702331')->is_valid_number, '千葉県印西市みどり台');
ok($zip->set_number('2710041')->is_valid_number, '千葉県松戸市七右衛門新田');
ok($zip->set_number('2710042')->is_valid_number, '千葉県松戸市主水新田');
ok($zip->set_number('2710043')->is_valid_number, '千葉県松戸市旭町');
ok($zip->set_number('2710044')->is_valid_number, '千葉県松戸市西馬橋');
ok($zip->set_number('2710045')->is_valid_number, '千葉県松戸市西馬橋相川町');
ok($zip->set_number('2710046')->is_valid_number, '千葉県松戸市西馬橋蔵元町');
ok($zip->set_number('2710047')->is_valid_number, '千葉県松戸市西馬橋幸町');
ok($zip->set_number('2710048')->is_valid_number, '千葉県松戸市西馬橋広手町');
ok($zip->set_number('2710051')->is_valid_number, '千葉県松戸市馬橋');
ok($zip->set_number('2710052')->is_valid_number, '千葉県松戸市新作');
ok($zip->set_number('2710053')->is_valid_number, '千葉県松戸市中根');
ok($zip->set_number('2710054')->is_valid_number, '千葉県松戸市中根長津町');
ok($zip->set_number('2710061')->is_valid_number, '千葉県松戸市栄町西');
ok($zip->set_number('2710062')->is_valid_number, '千葉県松戸市栄町');
ok($zip->set_number('2710063')->is_valid_number, '千葉県松戸市北松戸');
ok($zip->set_number('2710064')->is_valid_number, '千葉県松戸市上本郷');
ok($zip->set_number('2710065')->is_valid_number, '千葉県松戸市南花島');
ok($zip->set_number('2710066')->is_valid_number, '千葉県松戸市吉井町');
ok($zip->set_number('2710067')->is_valid_number, '千葉県松戸市樋野口');
ok($zip->set_number('2710068')->is_valid_number, '千葉県松戸市古ケ崎');
ok($zip->set_number('2710071')->is_valid_number, '千葉県松戸市竹ケ花西町');
ok($zip->set_number('2710072')->is_valid_number, '千葉県松戸市竹ケ花');
ok($zip->set_number('2710073')->is_valid_number, '千葉県松戸市小根本');
ok($zip->set_number('2710074')->is_valid_number, '千葉県松戸市緑ケ丘');
ok($zip->set_number('2710075')->is_valid_number, '千葉県松戸市胡録台');
ok($zip->set_number('2710076')->is_valid_number, '千葉県松戸市岩瀬');
ok($zip->set_number('2710077')->is_valid_number, '千葉県松戸市根本');
ok($zip->set_number('2710081')->is_valid_number, '千葉県松戸市二十世紀が丘美野里町');
ok($zip->set_number('2710082')->is_valid_number, '千葉県松戸市二十世紀が丘戸山町');
ok($zip->set_number('2710083')->is_valid_number, '千葉県松戸市二十世紀が丘梨元町');
ok($zip->set_number('2710084')->is_valid_number, '千葉県松戸市二十世紀が丘丸山町');
ok($zip->set_number('2710085')->is_valid_number, '千葉県松戸市二十世紀が丘中松町');
ok($zip->set_number('2710086')->is_valid_number, '千葉県松戸市二十世紀が丘萩町');
ok($zip->set_number('2710087')->is_valid_number, '千葉県松戸市三矢小台');
ok($zip->set_number('2710088')->is_valid_number, '千葉県松戸市二十世紀が丘柿の木町');
ok($zip->set_number('2710091')->is_valid_number, '千葉県松戸市本町');
ok($zip->set_number('2710092')->is_valid_number, '千葉県松戸市松戸');
ok($zip->set_number('2710093')->is_valid_number, '千葉県松戸市小山');
ok($zip->set_number('2710094')->is_valid_number, '千葉県松戸市上矢切');
ok($zip->set_number('2710095')->is_valid_number, '千葉県松戸市中矢切');
ok($zip->set_number('2710096')->is_valid_number, '千葉県松戸市下矢切');
ok($zip->set_number('2710097')->is_valid_number, '千葉県松戸市栗山');
ok($zip->set_number('2720000')->is_valid_number, '千葉県市川市以下に掲載がない場合');
ok($zip->set_number('2720001')->is_valid_number, '千葉県市川市二俣');
ok($zip->set_number('2720002')->is_valid_number, '千葉県市川市二俣新町');
ok($zip->set_number('2720003')->is_valid_number, '千葉県市川市東浜');
ok($zip->set_number('2720004')->is_valid_number, '千葉県市川市原木');
ok($zip->set_number('2720011')->is_valid_number, '千葉県市川市高谷新町');
ok($zip->set_number('2720012')->is_valid_number, '千葉県市川市上妙典(その他)');
ok($zip->set_number('2720013')->is_valid_number, '千葉県市川市高谷');
ok($zip->set_number('2720014')->is_valid_number, '千葉県市川市田尻');
ok($zip->set_number('2720015')->is_valid_number, '千葉県市川市鬼高');
ok($zip->set_number('2720021')->is_valid_number, '千葉県市川市八幡');
ok($zip->set_number('2720022')->is_valid_number, '千葉県市川市鬼越');
ok($zip->set_number('2720023')->is_valid_number, '千葉県市川市南八幡');
ok($zip->set_number('2720024')->is_valid_number, '千葉県市川市稲荷木');
ok($zip->set_number('2720025')->is_valid_number, '千葉県市川市大和田');
ok($zip->set_number('2720026')->is_valid_number, '千葉県市川市東大和田');
ok($zip->set_number('2720031')->is_valid_number, '千葉県市川市平田');
ok($zip->set_number('2720032')->is_valid_number, '千葉県市川市大洲');
ok($zip->set_number('2720033')->is_valid_number, '千葉県市川市市川南');
ok($zip->set_number('2720034')->is_valid_number, '千葉県市川市市川');
ok($zip->set_number('2720035')->is_valid_number, '千葉県市川市新田');
ok($zip->set_number('2720101')->is_valid_number, '千葉県市川市河原');
ok($zip->set_number('2720102')->is_valid_number, '千葉県市川市下新宿');
ok($zip->set_number('2720103')->is_valid_number, '千葉県市川市本行徳');
ok($zip->set_number('2720104')->is_valid_number, '千葉県市川市本塩');
ok($zip->set_number('2720105')->is_valid_number, '千葉県市川市関ケ島');
ok($zip->set_number('2720106')->is_valid_number, '千葉県市川市伊勢宿');
ok($zip->set_number('2720107')->is_valid_number, '千葉県市川市押切');
ok($zip->set_number('2720111')->is_valid_number, '千葉県市川市妙典');
ok($zip->set_number('2720112')->is_valid_number, '千葉県市川市上妙典(1~999番地)');
ok($zip->set_number('2720113')->is_valid_number, '千葉県市川市下妙典');
ok($zip->set_number('2720114')->is_valid_number, '千葉県市川市塩焼');
ok($zip->set_number('2720115')->is_valid_number, '千葉県市川市富浜');
ok($zip->set_number('2720121')->is_valid_number, '千葉県市川市末広');
ok($zip->set_number('2720122')->is_valid_number, '千葉県市川市宝');
ok($zip->set_number('2720123')->is_valid_number, '千葉県市川市幸');
ok($zip->set_number('2720124')->is_valid_number, '千葉県市川市加藤新田');
ok($zip->set_number('2720125')->is_valid_number, '千葉県市川市高浜町');
ok($zip->set_number('2720126')->is_valid_number, '千葉県市川市千鳥町');
ok($zip->set_number('2720127')->is_valid_number, '千葉県市川市塩浜');
ok($zip->set_number('2720131')->is_valid_number, '千葉県市川市湊');
ok($zip->set_number('2720132')->is_valid_number, '千葉県市川市湊新田');
ok($zip->set_number('2720133')->is_valid_number, '千葉県市川市行徳駅前');
ok($zip->set_number('2720134')->is_valid_number, '千葉県市川市入船');
ok($zip->set_number('2720135')->is_valid_number, '千葉県市川市日之出');
ok($zip->set_number('2720136')->is_valid_number, '千葉県市川市新浜');
ok($zip->set_number('2720137')->is_valid_number, '千葉県市川市福栄');
ok($zip->set_number('2720138')->is_valid_number, '千葉県市川市南行徳');
ok($zip->set_number('2720141')->is_valid_number, '千葉県市川市香取');
ok($zip->set_number('2720142')->is_valid_number, '千葉県市川市欠真間');
ok($zip->set_number('2720143')->is_valid_number, '千葉県市川市相之川');
ok($zip->set_number('2720144')->is_valid_number, '千葉県市川市新井');
ok($zip->set_number('2720145')->is_valid_number, '千葉県市川市島尻');
ok($zip->set_number('2720146')->is_valid_number, '千葉県市川市広尾');
ok($zip->set_number('2720801')->is_valid_number, '千葉県市川市大町');
ok($zip->set_number('2720802')->is_valid_number, '千葉県市川市柏井町');
ok($zip->set_number('2720803')->is_valid_number, '千葉県市川市奉免町');
ok($zip->set_number('2720804')->is_valid_number, '千葉県市川市南大野');
ok($zip->set_number('2720805')->is_valid_number, '千葉県市川市大野町');
ok($zip->set_number('2720811')->is_valid_number, '千葉県市川市北方町');
ok($zip->set_number('2720812')->is_valid_number, '千葉県市川市若宮');
ok($zip->set_number('2720813')->is_valid_number, '千葉県市川市中山');
ok($zip->set_number('2720814')->is_valid_number, '千葉県市川市高石神');
ok($zip->set_number('2720815')->is_valid_number, '千葉県市川市北方');
ok($zip->set_number('2720816')->is_valid_number, '千葉県市川市本北方');
ok($zip->set_number('2720821')->is_valid_number, '千葉県市川市下貝塚');
ok($zip->set_number('2720822')->is_valid_number, '千葉県市川市宮久保');
ok($zip->set_number('2720823')->is_valid_number, '千葉県市川市東菅野');
ok($zip->set_number('2720824')->is_valid_number, '千葉県市川市菅野');
ok($zip->set_number('2720825')->is_valid_number, '千葉県市川市須和田');
ok($zip->set_number('2720826')->is_valid_number, '千葉県市川市真間');
ok($zip->set_number('2720827')->is_valid_number, '千葉県市川市国府台');
ok($zip->set_number('2720831')->is_valid_number, '千葉県市川市稲越');
ok($zip->set_number('2720832')->is_valid_number, '千葉県市川市曽谷');
ok($zip->set_number('2720833')->is_valid_number, '千葉県市川市東国分');
ok($zip->set_number('2720834')->is_valid_number, '千葉県市川市国分');
ok($zip->set_number('2720835')->is_valid_number, '千葉県市川市中国分');
ok($zip->set_number('2720836')->is_valid_number, '千葉県市川市北国分');
ok($zip->set_number('2720837')->is_valid_number, '千葉県市川市堀之内');
ok($zip->set_number('2730000')->is_valid_number, '千葉県船橋市以下に掲載がない場合');
ok($zip->set_number('2730001')->is_valid_number, '千葉県船橋市市場');
ok($zip->set_number('2730002')->is_valid_number, '千葉県船橋市東船橋');
ok($zip->set_number('2730003')->is_valid_number, '千葉県船橋市宮本');
ok($zip->set_number('2730004')->is_valid_number, '千葉県船橋市南本町');
ok($zip->set_number('2730005')->is_valid_number, '千葉県船橋市本町');
ok($zip->set_number('2730011')->is_valid_number, '千葉県船橋市湊町');
ok($zip->set_number('2730012')->is_valid_number, '千葉県船橋市浜町');
ok($zip->set_number('2730013')->is_valid_number, '千葉県船橋市若松');
ok($zip->set_number('2730014')->is_valid_number, '千葉県船橋市高瀬町');
ok($zip->set_number('2730015')->is_valid_number, '千葉県船橋市日の出');
ok($zip->set_number('2730016')->is_valid_number, '千葉県船橋市潮見町');
ok($zip->set_number('2730017')->is_valid_number, '千葉県船橋市西浦');
ok($zip->set_number('2730018')->is_valid_number, '千葉県船橋市栄町');
ok($zip->set_number('2730021')->is_valid_number, '千葉県船橋市海神');
ok($zip->set_number('2730022')->is_valid_number, '千葉県船橋市海神町');
ok($zip->set_number('2730023')->is_valid_number, '千葉県船橋市南海神');
ok($zip->set_number('2730024')->is_valid_number, '千葉県船橋市海神町南');
ok($zip->set_number('2730025')->is_valid_number, '千葉県船橋市印内町');
ok($zip->set_number('2730026')->is_valid_number, '千葉県船橋市山野町');
ok($zip->set_number('2730027')->is_valid_number, '千葉県船橋市海神町西');
ok($zip->set_number('2730028')->is_valid_number, '千葉県船橋市海神町東');
ok($zip->set_number('2730031')->is_valid_number, '千葉県船橋市西船');
ok($zip->set_number('2730032')->is_valid_number, '千葉県船橋市葛飾町');
ok($zip->set_number('2730033')->is_valid_number, '千葉県船橋市本郷町');
ok($zip->set_number('2730034')->is_valid_number, '千葉県船橋市二子町');
ok($zip->set_number('2730035')->is_valid_number, '千葉県船橋市本中山');
ok($zip->set_number('2730036')->is_valid_number, '千葉県船橋市東中山');
ok($zip->set_number('2730037')->is_valid_number, '千葉県船橋市古作');
ok($zip->set_number('2730038')->is_valid_number, '千葉県船橋市古作町');
ok($zip->set_number('2730039')->is_valid_number, '千葉県船橋市印内');
ok($zip->set_number('2730041')->is_valid_number, '千葉県船橋市旭町');
ok($zip->set_number('2730042')->is_valid_number, '千葉県船橋市前貝塚町');
ok($zip->set_number('2730043')->is_valid_number, '千葉県船橋市行田町');
ok($zip->set_number('2730044')->is_valid_number, '千葉県船橋市行田');
ok($zip->set_number('2730045')->is_valid_number, '千葉県船橋市山手');
ok($zip->set_number('2730046')->is_valid_number, '千葉県船橋市上山町');
ok($zip->set_number('2730047')->is_valid_number, '千葉県船橋市藤原');
ok($zip->set_number('2730048')->is_valid_number, '千葉県船橋市丸山');
ok($zip->set_number('2730100')->is_valid_number, '千葉県鎌ケ谷市以下に掲載がない場合');
ok($zip->set_number('2730101')->is_valid_number, '千葉県鎌ケ谷市富岡');
ok($zip->set_number('2730102')->is_valid_number, '千葉県鎌ケ谷市右京塚');
ok($zip->set_number('2730103')->is_valid_number, '千葉県鎌ケ谷市丸山');
ok($zip->set_number('2730104')->is_valid_number, '千葉県鎌ケ谷市東鎌ケ谷');
ok($zip->set_number('2730105')->is_valid_number, '千葉県鎌ケ谷市鎌ケ谷');
ok($zip->set_number('2730106')->is_valid_number, '千葉県鎌ケ谷市南鎌ケ谷');
ok($zip->set_number('2730107')->is_valid_number, '千葉県鎌ケ谷市新鎌ケ谷');
ok($zip->set_number('2730111')->is_valid_number, '千葉県鎌ケ谷市北中沢');
ok($zip->set_number('2730112')->is_valid_number, '千葉県鎌ケ谷市東中沢');
ok($zip->set_number('2730113')->is_valid_number, '千葉県鎌ケ谷市道野辺中央');
ok($zip->set_number('2730114')->is_valid_number, '千葉県鎌ケ谷市道野辺');
ok($zip->set_number('2730115')->is_valid_number, '千葉県鎌ケ谷市東道野辺');
ok($zip->set_number('2730116')->is_valid_number, '千葉県鎌ケ谷市馬込沢');
ok($zip->set_number('2730117')->is_valid_number, '千葉県鎌ケ谷市西道野辺');
ok($zip->set_number('2730118')->is_valid_number, '千葉県鎌ケ谷市中沢');
ok($zip->set_number('2730119')->is_valid_number, '千葉県鎌ケ谷市中沢新町');
ok($zip->set_number('2730121')->is_valid_number, '千葉県鎌ケ谷市初富');
ok($zip->set_number('2730122')->is_valid_number, '千葉県鎌ケ谷市東初富');
ok($zip->set_number('2730123')->is_valid_number, '千葉県鎌ケ谷市南初富');
ok($zip->set_number('2730124')->is_valid_number, '千葉県鎌ケ谷市中央');
ok($zip->set_number('2730125')->is_valid_number, '千葉県鎌ケ谷市初富本町');
ok($zip->set_number('2730126')->is_valid_number, '千葉県鎌ケ谷市北初富');
ok($zip->set_number('2730127')->is_valid_number, '千葉県鎌ケ谷市串崎新田');
ok($zip->set_number('2730128')->is_valid_number, '千葉県鎌ケ谷市くぬぎ山');
ok($zip->set_number('2730131')->is_valid_number, '千葉県鎌ケ谷市軽井沢');
ok($zip->set_number('2730132')->is_valid_number, '千葉県鎌ケ谷市粟野');
ok($zip->set_number('2730133')->is_valid_number, '千葉県鎌ケ谷市南佐津間');
ok($zip->set_number('2730134')->is_valid_number, '千葉県鎌ケ谷市西佐津間');
ok($zip->set_number('2730135')->is_valid_number, '千葉県鎌ケ谷市中佐津間');
ok($zip->set_number('2730136')->is_valid_number, '千葉県鎌ケ谷市佐津間');
ok($zip->set_number('2730137')->is_valid_number, '千葉県鎌ケ谷市道野辺本町');
ok($zip->set_number('2730851')->is_valid_number, '千葉県船橋市馬込町');
ok($zip->set_number('2730852')->is_valid_number, '千葉県船橋市金杉台');
ok($zip->set_number('2730853')->is_valid_number, '千葉県船橋市金杉');
ok($zip->set_number('2730854')->is_valid_number, '千葉県船橋市金杉町');
ok($zip->set_number('2730855')->is_valid_number, '千葉県船橋市馬込西');
ok($zip->set_number('2730861')->is_valid_number, '千葉県船橋市米ケ崎町');
ok($zip->set_number('2730862')->is_valid_number, '千葉県船橋市駿河台');
ok($zip->set_number('2730863')->is_valid_number, '千葉県船橋市東町');
ok($zip->set_number('2730864')->is_valid_number, '千葉県船橋市北本町');
ok($zip->set_number('2730865')->is_valid_number, '千葉県船橋市夏見');
ok($zip->set_number('2730866')->is_valid_number, '千葉県船橋市夏見台');
ok($zip->set_number('2730867')->is_valid_number, '千葉県船橋市夏見町');
ok($zip->set_number('2740051')->is_valid_number, '千葉県船橋市車方町');
ok($zip->set_number('2740052')->is_valid_number, '千葉県船橋市鈴身町');
ok($zip->set_number('2740053')->is_valid_number, '千葉県船橋市豊富町');
ok($zip->set_number('2740054')->is_valid_number, '千葉県船橋市金堀町');
ok($zip->set_number('2740055')->is_valid_number, '千葉県船橋市楠が山町');
ok($zip->set_number('2740056')->is_valid_number, '千葉県船橋市神保町');
ok($zip->set_number('2740060')->is_valid_number, '千葉県船橋市坪井東');
ok($zip->set_number('2740061')->is_valid_number, '千葉県船橋市古和釜町');
ok($zip->set_number('2740062')->is_valid_number, '千葉県船橋市坪井町');
ok($zip->set_number('2740063')->is_valid_number, '千葉県船橋市習志野台');
ok($zip->set_number('2740064')->is_valid_number, '千葉県船橋市松が丘');
ok($zip->set_number('2740065')->is_valid_number, '千葉県船橋市高根台');
ok($zip->set_number('2740066')->is_valid_number, '千葉県船橋市大穴町');
ok($zip->set_number('2740067')->is_valid_number, '千葉県船橋市大穴南');
ok($zip->set_number('2740068')->is_valid_number, '千葉県船橋市大穴北');
ok($zip->set_number('2740069')->is_valid_number, '千葉県船橋市坪井西');
ok($zip->set_number('2740071')->is_valid_number, '千葉県船橋市習志野');
ok($zip->set_number('2740072')->is_valid_number, '千葉県船橋市三山');
ok($zip->set_number('2740073')->is_valid_number, '千葉県船橋市田喜野井');
ok($zip->set_number('2740074')->is_valid_number, '千葉県船橋市滝台');
ok($zip->set_number('2740075')->is_valid_number, '千葉県船橋市滝台町');
ok($zip->set_number('2740076')->is_valid_number, '千葉県船橋市薬園台町');
ok($zip->set_number('2740077')->is_valid_number, '千葉県船橋市薬円台');
ok($zip->set_number('2740081')->is_valid_number, '千葉県船橋市小野田町');
ok($zip->set_number('2740082')->is_valid_number, '千葉県船橋市大神保町');
ok($zip->set_number('2740801')->is_valid_number, '千葉県船橋市高野台');
ok($zip->set_number('2740802')->is_valid_number, '千葉県船橋市八木が谷');
ok($zip->set_number('2740803')->is_valid_number, '千葉県船橋市八木が谷町');
ok($zip->set_number('2740804')->is_valid_number, '千葉県船橋市みやぎ台');
ok($zip->set_number('2740805')->is_valid_number, '千葉県船橋市二和東');
ok($zip->set_number('2740806')->is_valid_number, '千葉県船橋市二和西');
ok($zip->set_number('2740807')->is_valid_number, '千葉県船橋市咲が丘');
ok($zip->set_number('2740811')->is_valid_number, '千葉県船橋市三咲町');
ok($zip->set_number('2740812')->is_valid_number, '千葉県船橋市三咲');
ok($zip->set_number('2740813')->is_valid_number, '千葉県船橋市南三咲');
ok($zip->set_number('2740814')->is_valid_number, '千葉県船橋市新高根');
ok($zip->set_number('2740815')->is_valid_number, '千葉県船橋市西習志野');
ok($zip->set_number('2740816')->is_valid_number, '千葉県船橋市芝山');
ok($zip->set_number('2740817')->is_valid_number, '千葉県船橋市高根町');
ok($zip->set_number('2740818')->is_valid_number, '千葉県船橋市緑台');
ok($zip->set_number('2740821')->is_valid_number, '千葉県船橋市七林町');
ok($zip->set_number('2740822')->is_valid_number, '千葉県船橋市飯山満町');
ok($zip->set_number('2740823')->is_valid_number, '千葉県船橋市二宮');
ok($zip->set_number('2740824')->is_valid_number, '千葉県船橋市前原東');
ok($zip->set_number('2740825')->is_valid_number, '千葉県船橋市前原西');
ok($zip->set_number('2740826')->is_valid_number, '千葉県船橋市中野木');
ok($zip->set_number('2750000')->is_valid_number, '千葉県習志野市以下に掲載がない場合');
ok($zip->set_number('2750001')->is_valid_number, '千葉県習志野市東習志野');
ok($zip->set_number('2750002')->is_valid_number, '千葉県習志野市実籾');
ok($zip->set_number('2750003')->is_valid_number, '千葉県習志野市実籾本郷');
ok($zip->set_number('2750004')->is_valid_number, '千葉県習志野市屋敷');
ok($zip->set_number('2750005')->is_valid_number, '千葉県習志野市新栄');
ok($zip->set_number('2750006')->is_valid_number, '千葉県習志野市泉町');
ok($zip->set_number('2750011')->is_valid_number, '千葉県習志野市大久保');
ok($zip->set_number('2750012')->is_valid_number, '千葉県習志野市本大久保');
ok($zip->set_number('2750013')->is_valid_number, '千葉県習志野市花咲');
ok($zip->set_number('2750014')->is_valid_number, '千葉県習志野市鷺沼');
ok($zip->set_number('2750015')->is_valid_number, '千葉県習志野市鷺沼台');
ok($zip->set_number('2750016')->is_valid_number, '千葉県習志野市津田沼');
ok($zip->set_number('2750017')->is_valid_number, '千葉県習志野市藤崎');
ok($zip->set_number('2750021')->is_valid_number, '千葉県習志野市袖ケ浦');
ok($zip->set_number('2750022')->is_valid_number, '千葉県習志野市香澄');
ok($zip->set_number('2750023')->is_valid_number, '千葉県習志野市芝園');
ok($zip->set_number('2750024')->is_valid_number, '千葉県習志野市茜浜');
ok($zip->set_number('2750025')->is_valid_number, '千葉県習志野市秋津');
ok($zip->set_number('2750026')->is_valid_number, '千葉県習志野市谷津');
ok($zip->set_number('2750027')->is_valid_number, '千葉県習志野市谷津町');
ok($zip->set_number('2750028')->is_valid_number, '千葉県習志野市奏の杜');
ok($zip->set_number('2760000')->is_valid_number, '千葉県八千代市以下に掲載がない場合');
ok($zip->set_number('2760001')->is_valid_number, '千葉県八千代市小池');
ok($zip->set_number('2760002')->is_valid_number, '千葉県八千代市真木野');
ok($zip->set_number('2760003')->is_valid_number, '千葉県八千代市大学町');
ok($zip->set_number('2760004')->is_valid_number, '千葉県八千代市島田台');
ok($zip->set_number('2760005')->is_valid_number, '千葉県八千代市島田');
ok($zip->set_number('2760006')->is_valid_number, '千葉県八千代市桑納');
ok($zip->set_number('2760007')->is_valid_number, '千葉県八千代市桑橋');
ok($zip->set_number('2760008')->is_valid_number, '千葉県八千代市神久保');
ok($zip->set_number('2760011')->is_valid_number, '千葉県八千代市佐山');
ok($zip->set_number('2760012')->is_valid_number, '千葉県八千代市堀の内');
ok($zip->set_number('2760013')->is_valid_number, '千葉県八千代市保品');
ok($zip->set_number('2760014')->is_valid_number, '千葉県八千代市米本(米本団地)');
ok($zip->set_number('2760015')->is_valid_number, '千葉県八千代市米本(その他)');
ok($zip->set_number('2760016')->is_valid_number, '千葉県八千代市神野');
ok($zip->set_number('2760017')->is_valid_number, '千葉県八千代市平戸');
ok($zip->set_number('2760020')->is_valid_number, '千葉県八千代市勝田台北');
ok($zip->set_number('2760021')->is_valid_number, '千葉県八千代市下高野');
ok($zip->set_number('2760022')->is_valid_number, '千葉県八千代市上高野');
ok($zip->set_number('2760023')->is_valid_number, '千葉県八千代市勝田台');
ok($zip->set_number('2760024')->is_valid_number, '千葉県八千代市勝田');
ok($zip->set_number('2760025')->is_valid_number, '千葉県八千代市勝田台南');
ok($zip->set_number('2760026')->is_valid_number, '千葉県八千代市下市場');
ok($zip->set_number('2760027')->is_valid_number, '千葉県八千代市村上(村上団地)');
ok($zip->set_number('2760028')->is_valid_number, '千葉県八千代市村上(その他)');
ok($zip->set_number('2760029')->is_valid_number, '千葉県八千代市村上南');
ok($zip->set_number('2760031')->is_valid_number, '千葉県八千代市八千代台北');
ok($zip->set_number('2760032')->is_valid_number, '千葉県八千代市八千代台東');
ok($zip->set_number('2760033')->is_valid_number, '千葉県八千代市八千代台南');
ok($zip->set_number('2760034')->is_valid_number, '千葉県八千代市八千代台西');
ok($zip->set_number('2760035')->is_valid_number, '千葉県八千代市大和田新田(高津団地)');
ok($zip->set_number('2760035')->is_valid_number, '千葉県八千代市高津(高津団地)');
ok($zip->set_number('2760036')->is_valid_number, '千葉県八千代市高津(その他)');
ok($zip->set_number('2760037')->is_valid_number, '千葉県八千代市高津東');
ok($zip->set_number('2760040')->is_valid_number, '千葉県八千代市緑が丘西');
ok($zip->set_number('2760041')->is_valid_number, '千葉県八千代市麦丸');
ok($zip->set_number('2760042')->is_valid_number, '千葉県八千代市ゆりのき台');
ok($zip->set_number('2760043')->is_valid_number, '千葉県八千代市萱田');
ok($zip->set_number('2760044')->is_valid_number, '千葉県八千代市萱田町');
ok($zip->set_number('2760045')->is_valid_number, '千葉県八千代市大和田');
ok($zip->set_number('2760046')->is_valid_number, '千葉県八千代市大和田新田(その他)');
ok($zip->set_number('2760047')->is_valid_number, '千葉県八千代市吉橋');
ok($zip->set_number('2760048')->is_valid_number, '千葉県八千代市尾崎');
ok($zip->set_number('2760049')->is_valid_number, '千葉県八千代市緑が丘');
ok($zip->set_number('2770000')->is_valid_number, '千葉県柏市以下に掲載がない場合');
ok($zip->set_number('2770001')->is_valid_number, '千葉県柏市呼塚新田');
ok($zip->set_number('2770002')->is_valid_number, '千葉県柏市呼塚');
ok($zip->set_number('2770003')->is_valid_number, '千葉県柏市柏堀之内新田');
ok($zip->set_number('2770004')->is_valid_number, '千葉県柏市柏下');
ok($zip->set_number('2770005')->is_valid_number, '千葉県柏市柏');
ok($zip->set_number('2770006')->is_valid_number, '千葉県柏市柏中村下');
ok($zip->set_number('2770007')->is_valid_number, '千葉県柏市戸張新田');
ok($zip->set_number('2770008')->is_valid_number, '千葉県柏市戸張');
ok($zip->set_number('2770011')->is_valid_number, '千葉県柏市東上町');
ok($zip->set_number('2770012')->is_valid_number, '千葉県柏市桜台');
ok($zip->set_number('2770013')->is_valid_number, '千葉県柏市東台本町');
ok($zip->set_number('2770014')->is_valid_number, '千葉県柏市東');
ok($zip->set_number('2770015')->is_valid_number, '千葉県柏市弥生町');
ok($zip->set_number('2770016')->is_valid_number, '千葉県柏市八幡町');
ok($zip->set_number('2770017')->is_valid_number, '千葉県柏市東柏');
ok($zip->set_number('2770021')->is_valid_number, '千葉県柏市中央町');
ok($zip->set_number('2770022')->is_valid_number, '千葉県柏市泉町');
ok($zip->set_number('2770023')->is_valid_number, '千葉県柏市中央');
ok($zip->set_number('2770024')->is_valid_number, '千葉県柏市若葉町');
ok($zip->set_number('2770025')->is_valid_number, '千葉県柏市千代田');
ok($zip->set_number('2770026')->is_valid_number, '千葉県柏市大塚町');
ok($zip->set_number('2770027')->is_valid_number, '千葉県柏市あかね町');
ok($zip->set_number('2770028')->is_valid_number, '千葉県柏市関場町');
ok($zip->set_number('2770031')->is_valid_number, '千葉県柏市亀甲台町');
ok($zip->set_number('2770032')->is_valid_number, '千葉県柏市名戸ケ谷');
ok($zip->set_number('2770033')->is_valid_number, '千葉県柏市増尾');
ok($zip->set_number('2770034')->is_valid_number, '千葉県柏市藤心');
ok($zip->set_number('2770041')->is_valid_number, '千葉県柏市逆井藤ノ台');
ok($zip->set_number('2770042')->is_valid_number, '千葉県柏市逆井');
ok($zip->set_number('2770043')->is_valid_number, '千葉県柏市南逆井');
ok($zip->set_number('2770044')->is_valid_number, '千葉県柏市新逆井');
ok($zip->set_number('2770045')->is_valid_number, '千葉県柏市東逆井');
ok($zip->set_number('2770051')->is_valid_number, '千葉県柏市加賀');
ok($zip->set_number('2770052')->is_valid_number, '千葉県柏市増尾台');
ok($zip->set_number('2770053')->is_valid_number, '千葉県柏市酒井根');
ok($zip->set_number('2770054')->is_valid_number, '千葉県柏市南増尾');
ok($zip->set_number('2770055')->is_valid_number, '千葉県柏市青葉台');
ok($zip->set_number('2770061')->is_valid_number, '千葉県柏市東中新宿');
ok($zip->set_number('2770062')->is_valid_number, '千葉県柏市光ケ丘団地');
ok($zip->set_number('2770063')->is_valid_number, '千葉県柏市西山');
ok($zip->set_number('2770064')->is_valid_number, '千葉県柏市東山');
ok($zip->set_number('2770065')->is_valid_number, '千葉県柏市光ケ丘');
ok($zip->set_number('2770066')->is_valid_number, '千葉県柏市中新宿');
ok($zip->set_number('2770071')->is_valid_number, '千葉県柏市豊住');
ok($zip->set_number('2770072')->is_valid_number, '千葉県柏市つくしが丘');
ok($zip->set_number('2770073')->is_valid_number, '千葉県柏市今谷南町');
ok($zip->set_number('2770074')->is_valid_number, '千葉県柏市今谷上町');
ok($zip->set_number('2770075')->is_valid_number, '千葉県柏市南柏中央');
ok($zip->set_number('2770081')->is_valid_number, '千葉県柏市富里');
ok($zip->set_number('2770082')->is_valid_number, '千葉県柏市緑ケ丘');
ok($zip->set_number('2770083')->is_valid_number, '千葉県柏市日立台');
ok($zip->set_number('2770084')->is_valid_number, '千葉県柏市新柏');
ok($zip->set_number('2770085')->is_valid_number, '千葉県柏市中原');
ok($zip->set_number('2770086')->is_valid_number, '千葉県柏市永楽台');
ok($zip->set_number('2770087')->is_valid_number, '千葉県柏市常盤台');
ok($zip->set_number('2770088')->is_valid_number, '千葉県柏市ひばりが丘');
ok($zip->set_number('2770801')->is_valid_number, '千葉県柏市船戸山高野');
ok($zip->set_number('2770802')->is_valid_number, '千葉県柏市船戸');
ok($zip->set_number('2770803')->is_valid_number, '千葉県柏市小青田');
ok($zip->set_number('2770804')->is_valid_number, '千葉県柏市新十余二');
ok($zip->set_number('2770805')->is_valid_number, '千葉県柏市大青田');
ok($zip->set_number('2770806')->is_valid_number, '千葉県柏市柏インター東');
ok($zip->set_number('2770811')->is_valid_number, '千葉県柏市上利根');
ok($zip->set_number('2770812')->is_valid_number, '千葉県柏市花野井');
ok($zip->set_number('2770813')->is_valid_number, '千葉県柏市大室');
ok($zip->set_number('2770814')->is_valid_number, '千葉県柏市正連寺');
ok($zip->set_number('2770821')->is_valid_number, '千葉県柏市弁天下');
ok($zip->set_number('2770822')->is_valid_number, '千葉県柏市布施下');
ok($zip->set_number('2770823')->is_valid_number, '千葉県柏市布施新町');
ok($zip->set_number('2770824')->is_valid_number, '千葉県柏市布施新田');
ok($zip->set_number('2770825')->is_valid_number, '千葉県柏市布施');
ok($zip->set_number('2770826')->is_valid_number, '千葉県柏市宿連寺');
ok($zip->set_number('2770827')->is_valid_number, '千葉県柏市松葉町');
ok($zip->set_number('2770831')->is_valid_number, '千葉県柏市根戸');
ok($zip->set_number('2770832')->is_valid_number, '千葉県柏市北柏');
ok($zip->set_number('2770833')->is_valid_number, '千葉県柏市根戸新田');
ok($zip->set_number('2770834')->is_valid_number, '千葉県柏市松ケ崎新田');
ok($zip->set_number('2770835')->is_valid_number, '千葉県柏市松ケ崎');
ok($zip->set_number('2770836')->is_valid_number, '千葉県柏市北柏台');
ok($zip->set_number('2770837')->is_valid_number, '千葉県柏市大山台');
ok($zip->set_number('2770841')->is_valid_number, '千葉県柏市あけぼの');
ok($zip->set_number('2770842')->is_valid_number, '千葉県柏市末広町');
ok($zip->set_number('2770843')->is_valid_number, '千葉県柏市明原');
ok($zip->set_number('2770844')->is_valid_number, '千葉県柏市西町');
ok($zip->set_number('2770845')->is_valid_number, '千葉県柏市豊四季台');
ok($zip->set_number('2770846')->is_valid_number, '千葉県柏市かやの町');
ok($zip->set_number('2770851')->is_valid_number, '千葉県柏市向原町');
ok($zip->set_number('2770852')->is_valid_number, '千葉県柏市旭町');
ok($zip->set_number('2770853')->is_valid_number, '千葉県柏市吉野沢');
ok($zip->set_number('2770854')->is_valid_number, '千葉県柏市豊町');
ok($zip->set_number('2770855')->is_valid_number, '千葉県柏市南柏');
ok($zip->set_number('2770856')->is_valid_number, '千葉県柏市新富町');
ok($zip->set_number('2770857')->is_valid_number, '千葉県柏市豊平町');
ok($zip->set_number('2770858')->is_valid_number, '千葉県柏市豊上町');
ok($zip->set_number('2770861')->is_valid_number, '千葉県柏市高田');
ok($zip->set_number('2770862')->is_valid_number, '千葉県柏市篠籠田');
ok($zip->set_number('2770863')->is_valid_number, '千葉県柏市豊四季');
ok($zip->set_number('2770871')->is_valid_number, '千葉県柏市若柴');
ok($zip->set_number('2770872')->is_valid_number, '千葉県柏市十余二');
ok($zip->set_number('2770873')->is_valid_number, '千葉県柏市中十余二');
ok($zip->set_number('2770874')->is_valid_number, '千葉県柏市柏インター南');
ok($zip->set_number('2770881')->is_valid_number, '千葉県柏市青田新田飛地');
ok($zip->set_number('2770882')->is_valid_number, '千葉県柏市柏の葉');
ok($zip->set_number('2770883')->is_valid_number, '千葉県柏市伊勢原');
ok($zip->set_number('2770884')->is_valid_number, '千葉県柏市みどり台');
ok($zip->set_number('2770885')->is_valid_number, '千葉県柏市西原');
ok($zip->set_number('2770886')->is_valid_number, '千葉県柏市西柏台');
ok($zip->set_number('2770901')->is_valid_number, '千葉県柏市大井新田');
ok($zip->set_number('2770902')->is_valid_number, '千葉県柏市大井');
ok($zip->set_number('2770903')->is_valid_number, '千葉県柏市緑台');
ok($zip->set_number('2770911')->is_valid_number, '千葉県柏市箕輪新田');
ok($zip->set_number('2770912')->is_valid_number, '千葉県柏市箕輪');
ok($zip->set_number('2770913')->is_valid_number, '千葉県柏市五條谷');
ok($zip->set_number('2770921')->is_valid_number, '千葉県柏市大津ケ丘');
ok($zip->set_number('2770922')->is_valid_number, '千葉県柏市大島田');
ok($zip->set_number('2770923')->is_valid_number, '千葉県柏市塚崎');
ok($zip->set_number('2770924')->is_valid_number, '千葉県柏市風早');
ok($zip->set_number('2770931')->is_valid_number, '千葉県柏市藤ケ谷');
ok($zip->set_number('2770932')->is_valid_number, '千葉県柏市藤ケ谷新田');
ok($zip->set_number('2770941')->is_valid_number, '千葉県柏市高柳');
ok($zip->set_number('2770942')->is_valid_number, '千葉県柏市高南台');
ok($zip->set_number('2770943')->is_valid_number, '千葉県柏市高柳新田');
ok($zip->set_number('2770944')->is_valid_number, '千葉県柏市南高柳');
ok($zip->set_number('2770945')->is_valid_number, '千葉県柏市しいの木台');
ok($zip->set_number('2780000')->is_valid_number, '千葉県野田市以下に掲載がない場合');
ok($zip->set_number('2780001')->is_valid_number, '千葉県野田市目吹');
ok($zip->set_number('2780002')->is_valid_number, '千葉県野田市木野崎');
ok($zip->set_number('2780003')->is_valid_number, '千葉県野田市鶴奉');
ok($zip->set_number('2780004')->is_valid_number, '千葉県野田市横内');
ok($zip->set_number('2780005')->is_valid_number, '千葉県野田市宮崎');
ok($zip->set_number('2780006')->is_valid_number, '千葉県野田市柳沢');
ok($zip->set_number('2780007')->is_valid_number, '千葉県野田市金杉');
ok($zip->set_number('2780011')->is_valid_number, '千葉県野田市三ツ堀');
ok($zip->set_number('2780012')->is_valid_number, '千葉県野田市瀬戸');
ok($zip->set_number('2780013')->is_valid_number, '千葉県野田市上三ケ尾');
ok($zip->set_number('2780014')->is_valid_number, '千葉県野田市下三ケ尾');
ok($zip->set_number('2780015')->is_valid_number, '千葉県野田市西三ケ尾');
ok($zip->set_number('2780016')->is_valid_number, '千葉県野田市二ツ塚');
ok($zip->set_number('2780017')->is_valid_number, '千葉県野田市大殿井');
ok($zip->set_number('2780021')->is_valid_number, '千葉県野田市堤根');
ok($zip->set_number('2780022')->is_valid_number, '千葉県野田市山崎');
ok($zip->set_number('2780023')->is_valid_number, '千葉県野田市山崎貝塚町');
ok($zip->set_number('2780024')->is_valid_number, '千葉県野田市山崎梅の台');
ok($zip->set_number('2780025')->is_valid_number, '千葉県野田市今上');
ok($zip->set_number('2780026')->is_valid_number, '千葉県野田市花井');
ok($zip->set_number('2780027')->is_valid_number, '千葉県野田市みずき');
ok($zip->set_number('2780028')->is_valid_number, '千葉県野田市桜木');
ok($zip->set_number('2780029')->is_valid_number, '千葉県野田市山崎新町');
ok($zip->set_number('2780031')->is_valid_number, '千葉県野田市中根');
ok($zip->set_number('2780032')->is_valid_number, '千葉県野田市桜台');
ok($zip->set_number('2780033')->is_valid_number, '千葉県野田市上花輪');
ok($zip->set_number('2780034')->is_valid_number, '千葉県野田市上花輪新町');
ok($zip->set_number('2780035')->is_valid_number, '千葉県野田市中野台');
ok($zip->set_number('2780036')->is_valid_number, '千葉県野田市中野台鹿島町');
ok($zip->set_number('2780037')->is_valid_number, '千葉県野田市野田');
ok($zip->set_number('2780038')->is_valid_number, '千葉県野田市つつみ野');
ok($zip->set_number('2780041')->is_valid_number, '千葉県野田市蕃昌');
ok($zip->set_number('2780042')->is_valid_number, '千葉県野田市吉春');
ok($zip->set_number('2780043')->is_valid_number, '千葉県野田市清水');
ok($zip->set_number('2780044')->is_valid_number, '千葉県野田市堤台');
ok($zip->set_number('2780045')->is_valid_number, '千葉県野田市座生');
ok($zip->set_number('2780046')->is_valid_number, '千葉県野田市谷津');
ok($zip->set_number('2780047')->is_valid_number, '千葉県野田市清水公園東');
ok($zip->set_number('2780048')->is_valid_number, '千葉県野田市桜の里');
ok($zip->set_number('2780051')->is_valid_number, '千葉県野田市七光台');
ok($zip->set_number('2780052')->is_valid_number, '千葉県野田市春日町');
ok($zip->set_number('2780053')->is_valid_number, '千葉県野田市五木新町');
ok($zip->set_number('2780054')->is_valid_number, '千葉県野田市五木');
ok($zip->set_number('2780055')->is_valid_number, '千葉県野田市岩名');
ok($zip->set_number('2780056')->is_valid_number, '千葉県野田市五木新田');
ok($zip->set_number('2780057')->is_valid_number, '千葉県野田市光葉町');
ok($zip->set_number('2790000')->is_valid_number, '千葉県浦安市以下に掲載がない場合');
ok($zip->set_number('2790001')->is_valid_number, '千葉県浦安市当代島');
ok($zip->set_number('2790002')->is_valid_number, '千葉県浦安市北栄');
ok($zip->set_number('2790003')->is_valid_number, '千葉県浦安市海楽');
ok($zip->set_number('2790004')->is_valid_number, '千葉県浦安市猫実');
ok($zip->set_number('2790011')->is_valid_number, '千葉県浦安市美浜');
ok($zip->set_number('2790012')->is_valid_number, '千葉県浦安市入船');
ok($zip->set_number('2790013')->is_valid_number, '千葉県浦安市日の出');
ok($zip->set_number('2790014')->is_valid_number, '千葉県浦安市明海');
ok($zip->set_number('2790021')->is_valid_number, '千葉県浦安市富岡');
ok($zip->set_number('2790022')->is_valid_number, '千葉県浦安市今川');
ok($zip->set_number('2790023')->is_valid_number, '千葉県浦安市高洲');
ok($zip->set_number('2790024')->is_valid_number, '千葉県浦安市港');
ok($zip->set_number('2790025')->is_valid_number, '千葉県浦安市鉄鋼通り');
ok($zip->set_number('2790026')->is_valid_number, '千葉県浦安市弁天');
ok($zip->set_number('2790031')->is_valid_number, '千葉県浦安市舞浜');
ok($zip->set_number('2790032')->is_valid_number, '千葉県浦安市千鳥');
ok($zip->set_number('2790041')->is_valid_number, '千葉県浦安市堀江');
ok($zip->set_number('2790042')->is_valid_number, '千葉県浦安市東野');
ok($zip->set_number('2790043')->is_valid_number, '千葉県浦安市富士見');
ok($zip->set_number('2820001')->is_valid_number, '千葉県成田市天浪');
ok($zip->set_number('2820002')->is_valid_number, '千葉県成田市天神峰(成田国際空港内)');
ok($zip->set_number('2820003')->is_valid_number, '千葉県成田市東峰(成田国際空港内)');
ok($zip->set_number('2820004')->is_valid_number, '千葉県成田市古込(成田国際空港内)');
ok($zip->set_number('2820005')->is_valid_number, '千葉県成田市木の根(成田国際空港内)');
ok($zip->set_number('2820006')->is_valid_number, '千葉県成田市取香(成田国際空港内)');
ok($zip->set_number('2820007')->is_valid_number, '千葉県成田市堀之内(成田国際空港内)');
ok($zip->set_number('2820009')->is_valid_number, '千葉県成田市十余三(成田国際空港内)');
ok($zip->set_number('2820010')->is_valid_number, '千葉県成田市吉岡(成田国際空港内)');
ok($zip->set_number('2820011')->is_valid_number, '千葉県成田市三里塚(御料牧場・成田国際空港内)');
ok($zip->set_number('2820012')->is_valid_number, '千葉県成田市東三里塚(成田国際空港内)');
ok($zip->set_number('2820021')->is_valid_number, '千葉県成田市駒井野(成田国際空港内)');
ok($zip->set_number('2820027')->is_valid_number, '千葉県成田市小菅(成田国際空港内)');
ok($zip->set_number('2820031')->is_valid_number, '千葉県香取郡多古町一鍬田(成田国際空港内)');
ok($zip->set_number('2820032')->is_valid_number, '千葉県山武郡芝山町香山新田(成田国際空港内)');
ok($zip->set_number('2820033')->is_valid_number, '千葉県山武郡芝山町菱田(成田国際空港内)');
ok($zip->set_number('2820034')->is_valid_number, '千葉県山武郡芝山町大里(成田国際空港内)');
ok($zip->set_number('2820035')->is_valid_number, '千葉県山武郡芝山町岩山(成田国際空港内)');
ok($zip->set_number('2830000')->is_valid_number, '千葉県東金市以下に掲載がない場合');
ok($zip->set_number('2830001')->is_valid_number, '千葉県東金市家之子');
ok($zip->set_number('2830002')->is_valid_number, '千葉県東金市求名');
ok($zip->set_number('2830003')->is_valid_number, '千葉県東金市道庭');
ok($zip->set_number('2830004')->is_valid_number, '千葉県東金市二又');
ok($zip->set_number('2830005')->is_valid_number, '千葉県東金市田間');
ok($zip->set_number('2830006')->is_valid_number, '千葉県東金市東新宿');
ok($zip->set_number('2830011')->is_valid_number, '千葉県東金市上武射田');
ok($zip->set_number('2830012')->is_valid_number, '千葉県東金市下武射田');
ok($zip->set_number('2830013')->is_valid_number, '千葉県東金市士農田');
ok($zip->set_number('2830014')->is_valid_number, '千葉県東金市関内');
ok($zip->set_number('2830015')->is_valid_number, '千葉県東金市前之内');
ok($zip->set_number('2830016')->is_valid_number, '千葉県東金市菱沼');
ok($zip->set_number('2830021')->is_valid_number, '千葉県東金市東中');
ok($zip->set_number('2830022')->is_valid_number, '千葉県東金市高倉');
ok($zip->set_number('2830023')->is_valid_number, '千葉県東金市宮');
ok($zip->set_number('2830024')->is_valid_number, '千葉県東金市御門');
ok($zip->set_number('2830025')->is_valid_number, '千葉県東金市殿廻');
ok($zip->set_number('2830026')->is_valid_number, '千葉県東金市中野');
ok($zip->set_number('2830027')->is_valid_number, '千葉県東金市堀之内');
ok($zip->set_number('2830028')->is_valid_number, '千葉県東金市三浦名');
ok($zip->set_number('2830031')->is_valid_number, '千葉県東金市薄島');
ok($zip->set_number('2830032')->is_valid_number, '千葉県東金市荒生');
ok($zip->set_number('2830033')->is_valid_number, '千葉県東金市宿');
ok($zip->set_number('2830034')->is_valid_number, '千葉県東金市大沼');
ok($zip->set_number('2830035')->is_valid_number, '千葉県東金市粟生飛地');
ok($zip->set_number('2830036')->is_valid_number, '千葉県東金市不動堂飛地');
ok($zip->set_number('2830037')->is_valid_number, '千葉県東金市細屋敷');
ok($zip->set_number('2830038')->is_valid_number, '千葉県東金市関下');
ok($zip->set_number('2830041')->is_valid_number, '千葉県東金市広瀬');
ok($zip->set_number('2830042')->is_valid_number, '千葉県東金市西野飛地');
ok($zip->set_number('2830043')->is_valid_number, '千葉県東金市藤下飛地');
ok($zip->set_number('2830044')->is_valid_number, '千葉県東金市小沼田');
ok($zip->set_number('2830045')->is_valid_number, '千葉県東金市西中');
ok($zip->set_number('2830046')->is_valid_number, '千葉県東金市上谷');
ok($zip->set_number('2830047')->is_valid_number, '千葉県東金市北幸谷');
ok($zip->set_number('2830048')->is_valid_number, '千葉県東金市幸田');
ok($zip->set_number('2830051')->is_valid_number, '千葉県東金市大沼田');
ok($zip->set_number('2830052')->is_valid_number, '千葉県東金市二之袋');
ok($zip->set_number('2830053')->is_valid_number, '千葉県東金市東中島');
ok($zip->set_number('2830054')->is_valid_number, '千葉県東金市下谷');
ok($zip->set_number('2830055')->is_valid_number, '千葉県東金市依古島');
ok($zip->set_number('2830056')->is_valid_number, '千葉県東金市砂古瀬');
ok($zip->set_number('2830057')->is_valid_number, '千葉県東金市一之袋');
ok($zip->set_number('2830061')->is_valid_number, '千葉県東金市北之幸谷');
ok($zip->set_number('2830062')->is_valid_number, '千葉県東金市家徳');
ok($zip->set_number('2830063')->is_valid_number, '千葉県東金市堀上');
ok($zip->set_number('2830064')->is_valid_number, '千葉県東金市川場');
ok($zip->set_number('2830065')->is_valid_number, '千葉県東金市押堀');
ok($zip->set_number('2830066')->is_valid_number, '千葉県東金市南上宿');
ok($zip->set_number('2830067')->is_valid_number, '千葉県東金市東上宿');
ok($zip->set_number('2830068')->is_valid_number, '千葉県東金市東岩崎');
ok($zip->set_number('2830100')->is_valid_number, '千葉県山武郡九十九里町以下に掲載がない場合');
ok($zip->set_number('2830101')->is_valid_number, '千葉県山武郡九十九里町作田');
ok($zip->set_number('2830102')->is_valid_number, '千葉県山武郡九十九里町小関');
ok($zip->set_number('2830103')->is_valid_number, '千葉県山武郡九十九里町田中荒生');
ok($zip->set_number('2830104')->is_valid_number, '千葉県山武郡九十九里町片貝');
ok($zip->set_number('2830105')->is_valid_number, '千葉県山武郡九十九里町粟生');
ok($zip->set_number('2830106')->is_valid_number, '千葉県山武郡九十九里町宿');
ok($zip->set_number('2830107')->is_valid_number, '千葉県山武郡九十九里町荒生');
ok($zip->set_number('2830111')->is_valid_number, '千葉県山武郡九十九里町細屋敷');
ok($zip->set_number('2830112')->is_valid_number, '千葉県山武郡九十九里町藤下');
ok($zip->set_number('2830113')->is_valid_number, '千葉県山武郡九十九里町不動堂');
ok($zip->set_number('2830114')->is_valid_number, '千葉県山武郡九十九里町真亀');
ok($zip->set_number('2830115')->is_valid_number, '千葉県山武郡九十九里町真亀新田');
ok($zip->set_number('2830116')->is_valid_number, '千葉県山武郡九十九里町西野');
ok($zip->set_number('2830117')->is_valid_number, '千葉県山武郡九十九里町下貝塚');
ok($zip->set_number('2830801')->is_valid_number, '千葉県東金市八坂台');
ok($zip->set_number('2830802')->is_valid_number, '千葉県東金市東金');
ok($zip->set_number('2830803')->is_valid_number, '千葉県東金市日吉台');
ok($zip->set_number('2830804')->is_valid_number, '千葉県東金市油井');
ok($zip->set_number('2830805')->is_valid_number, '千葉県東金市松之郷');
ok($zip->set_number('2830811')->is_valid_number, '千葉県東金市台方');
ok($zip->set_number('2830812')->is_valid_number, '千葉県東金市福俵');
ok($zip->set_number('2830813')->is_valid_number, '千葉県東金市山口');
ok($zip->set_number('2830814')->is_valid_number, '千葉県東金市田中');
ok($zip->set_number('2830815')->is_valid_number, '千葉県東金市大豆谷');
ok($zip->set_number('2830816')->is_valid_number, '千葉県東金市西福俵');
ok($zip->set_number('2830821')->is_valid_number, '千葉県東金市小野');
ok($zip->set_number('2830822')->is_valid_number, '千葉県東金市季美の森東');
ok($zip->set_number('2830823')->is_valid_number, '千葉県東金市山田');
ok($zip->set_number('2830824')->is_valid_number, '千葉県東金市丹尾');
ok($zip->set_number('2830825')->is_valid_number, '千葉県東金市滝');
ok($zip->set_number('2830826')->is_valid_number, '千葉県東金市丘山台');
ok($zip->set_number('2830831')->is_valid_number, '千葉県東金市酒蔵');
ok($zip->set_number('2830832')->is_valid_number, '千葉県東金市三ケ尻');
ok($zip->set_number('2830833')->is_valid_number, '千葉県東金市滝沢');
ok($zip->set_number('2830834')->is_valid_number, '千葉県東金市上布田');
ok($zip->set_number('2830835')->is_valid_number, '千葉県東金市極楽寺');
ok($zip->set_number('2840000')->is_valid_number, '千葉県四街道市以下に掲載がない場合');
ok($zip->set_number('2840001')->is_valid_number, '千葉県四街道市大日');
ok($zip->set_number('2840002')->is_valid_number, '千葉県四街道市萱橋');
ok($zip->set_number('2840003')->is_valid_number, '千葉県四街道市鹿渡');
ok($zip->set_number('2840004')->is_valid_number, '千葉県四街道市みのり町');
ok($zip->set_number('2840005')->is_valid_number, '千葉県四街道市四街道');
ok($zip->set_number('2840006')->is_valid_number, '千葉県四街道市下志津新田');
ok($zip->set_number('2840007')->is_valid_number, '千葉県四街道市さつきケ丘');
ok($zip->set_number('2840008')->is_valid_number, '千葉県四街道市鹿放ケ丘');
ok($zip->set_number('2840009')->is_valid_number, '千葉県四街道市中央');
ok($zip->set_number('2840011')->is_valid_number, '千葉県四街道市亀崎');
ok($zip->set_number('2840012')->is_valid_number, '千葉県四街道市物井');
ok($zip->set_number('2840013')->is_valid_number, '千葉県四街道市内黒田');
ok($zip->set_number('2840014')->is_valid_number, '千葉県四街道市池花');
ok($zip->set_number('2840015')->is_valid_number, '千葉県四街道市千代田');
ok($zip->set_number('2840016')->is_valid_number, '千葉県四街道市もねの里');
ok($zip->set_number('2840021')->is_valid_number, '千葉県四街道市長岡');
ok($zip->set_number('2840022')->is_valid_number, '千葉県四街道市山梨');
ok($zip->set_number('2840023')->is_valid_number, '千葉県四街道市みそら');
ok($zip->set_number('2840024')->is_valid_number, '千葉県四街道市旭ケ丘');
ok($zip->set_number('2840025')->is_valid_number, '千葉県四街道市さちが丘');
ok($zip->set_number('2840026')->is_valid_number, '千葉県四街道市つくし座');
ok($zip->set_number('2840027')->is_valid_number, '千葉県四街道市栗山');
ok($zip->set_number('2840031')->is_valid_number, '千葉県四街道市成山');
ok($zip->set_number('2840032')->is_valid_number, '千葉県四街道市吉岡');
ok($zip->set_number('2840033')->is_valid_number, '千葉県四街道市鷹の台');
ok($zip->set_number('2840034')->is_valid_number, '千葉県四街道市南波佐間');
ok($zip->set_number('2840035')->is_valid_number, '千葉県四街道市和田');
ok($zip->set_number('2840036')->is_valid_number, '千葉県四街道市中野');
ok($zip->set_number('2840037')->is_valid_number, '千葉県四街道市中台');
ok($zip->set_number('2840038')->is_valid_number, '千葉県四街道市たかおの杜');
ok($zip->set_number('2840041')->is_valid_number, '千葉県四街道市上野');
ok($zip->set_number('2840042')->is_valid_number, '千葉県四街道市小名木');
ok($zip->set_number('2840043')->is_valid_number, '千葉県四街道市めいわ');
ok($zip->set_number('2840044')->is_valid_number, '千葉県四街道市和良比');
ok($zip->set_number('2840045')->is_valid_number, '千葉県四街道市美しが丘');
ok($zip->set_number('2850000')->is_valid_number, '千葉県佐倉市以下に掲載がない場合');
ok($zip->set_number('2850001')->is_valid_number, '千葉県佐倉市土浮');
ok($zip->set_number('2850002')->is_valid_number, '千葉県佐倉市萩山新田');
ok($zip->set_number('2850003')->is_valid_number, '千葉県佐倉市飯野');
ok($zip->set_number('2850004')->is_valid_number, '千葉県佐倉市岩名');
ok($zip->set_number('2850005')->is_valid_number, '千葉県佐倉市宮前');
ok($zip->set_number('2850006')->is_valid_number, '千葉県佐倉市下根');
ok($zip->set_number('2850007')->is_valid_number, '千葉県佐倉市下根町');
ok($zip->set_number('2850008')->is_valid_number, '千葉県佐倉市鹿島干拓');
ok($zip->set_number('2850009')->is_valid_number, '千葉県佐倉市飯野町');
ok($zip->set_number('2850011')->is_valid_number, '千葉県佐倉市山崎');
ok($zip->set_number('2850012')->is_valid_number, '千葉県佐倉市田町');
ok($zip->set_number('2850013')->is_valid_number, '千葉県佐倉市海隣寺町');
ok($zip->set_number('2850014')->is_valid_number, '千葉県佐倉市栄町');
ok($zip->set_number('2850015')->is_valid_number, '千葉県佐倉市並木町');
ok($zip->set_number('2850016')->is_valid_number, '千葉県佐倉市宮小路町');
ok($zip->set_number('2850017')->is_valid_number, '千葉県佐倉市城内町');
ok($zip->set_number('2850021')->is_valid_number, '千葉県佐倉市最上町');
ok($zip->set_number('2850022')->is_valid_number, '千葉県佐倉市中尾余町');
ok($zip->set_number('2850023')->is_valid_number, '千葉県佐倉市新町');
ok($zip->set_number('2850024')->is_valid_number, '千葉県佐倉市裏新町');
ok($zip->set_number('2850025')->is_valid_number, '千葉県佐倉市鏑木町');
ok($zip->set_number('2850026')->is_valid_number, '千葉県佐倉市鏑木仲田町');
ok($zip->set_number('2850031')->is_valid_number, '千葉県佐倉市飯田台');
ok($zip->set_number('2850032')->is_valid_number, '千葉県佐倉市飯田');
ok($zip->set_number('2850033')->is_valid_number, '千葉県佐倉市鍋山町');
ok($zip->set_number('2850034')->is_valid_number, '千葉県佐倉市千成');
ok($zip->set_number('2850035')->is_valid_number, '千葉県佐倉市樹木町');
ok($zip->set_number('2850036')->is_valid_number, '千葉県佐倉市藤沢町');
ok($zip->set_number('2850037')->is_valid_number, '千葉県佐倉市本町');
ok($zip->set_number('2850038')->is_valid_number, '千葉県佐倉市弥勒町');
ok($zip->set_number('2850039')->is_valid_number, '千葉県佐倉市野狐台町');
ok($zip->set_number('2850041')->is_valid_number, '千葉県佐倉市大佐倉');
ok($zip->set_number('2850042')->is_valid_number, '千葉県佐倉市将門町');
ok($zip->set_number('2850043')->is_valid_number, '千葉県佐倉市大蛇町');
ok($zip->set_number('2850044')->is_valid_number, '千葉県佐倉市上代');
ok($zip->set_number('2850045')->is_valid_number, '千葉県佐倉市白銀');
ok($zip->set_number('2850046')->is_valid_number, '千葉県佐倉市高岡');
ok($zip->set_number('2850051')->is_valid_number, '千葉県佐倉市長熊');
ok($zip->set_number('2850052')->is_valid_number, '千葉県佐倉市八木');
ok($zip->set_number('2850053')->is_valid_number, '千葉県佐倉市下勝田');
ok($zip->set_number('2850054')->is_valid_number, '千葉県佐倉市上勝田');
ok($zip->set_number('2850055')->is_valid_number, '千葉県佐倉市瓜坪新田');
ok($zip->set_number('2850056')->is_valid_number, '千葉県佐倉市坪山新田');
ok($zip->set_number('2850057')->is_valid_number, '千葉県佐倉市米戸');
ok($zip->set_number('2850061')->is_valid_number, '千葉県佐倉市高崎');
ok($zip->set_number('2850062')->is_valid_number, '千葉県佐倉市寒風');
ok($zip->set_number('2850063')->is_valid_number, '千葉県佐倉市宮本');
ok($zip->set_number('2850064')->is_valid_number, '千葉県佐倉市天辺');
ok($zip->set_number('2850065')->is_valid_number, '千葉県佐倉市直弥');
ok($zip->set_number('2850066')->is_valid_number, '千葉県佐倉市上別所');
ok($zip->set_number('2850071')->is_valid_number, '千葉県佐倉市岩富');
ok($zip->set_number('2850072')->is_valid_number, '千葉県佐倉市岩富町');
ok($zip->set_number('2850073')->is_valid_number, '千葉県佐倉市七曲');
ok($zip->set_number('2850074')->is_valid_number, '千葉県佐倉市西御門');
ok($zip->set_number('2850075')->is_valid_number, '千葉県佐倉市宮内');
ok($zip->set_number('2850076')->is_valid_number, '千葉県佐倉市飯塚');
ok($zip->set_number('2850077')->is_valid_number, '千葉県佐倉市内田');
ok($zip->set_number('2850078')->is_valid_number, '千葉県佐倉市坂戸');
ok($zip->set_number('2850801')->is_valid_number, '千葉県佐倉市木野子');
ok($zip->set_number('2850802')->is_valid_number, '千葉県佐倉市大作');
ok($zip->set_number('2850803')->is_valid_number, '千葉県佐倉市神門');
ok($zip->set_number('2850804')->is_valid_number, '千葉県佐倉市馬渡');
ok($zip->set_number('2850805')->is_valid_number, '千葉県佐倉市小篠塚');
ok($zip->set_number('2850806')->is_valid_number, '千葉県佐倉市大篠塚');
ok($zip->set_number('2850807')->is_valid_number, '千葉県佐倉市山王');
ok($zip->set_number('2850808')->is_valid_number, '千葉県佐倉市太田');
ok($zip->set_number('2850811')->is_valid_number, '千葉県佐倉市表町');
ok($zip->set_number('2850812')->is_valid_number, '千葉県佐倉市六崎');
ok($zip->set_number('2850813')->is_valid_number, '千葉県佐倉市石川');
ok($zip->set_number('2850814')->is_valid_number, '千葉県佐倉市春路');
ok($zip->set_number('2850815')->is_valid_number, '千葉県佐倉市城');
ok($zip->set_number('2850816')->is_valid_number, '千葉県佐倉市藤治台');
ok($zip->set_number('2850817')->is_valid_number, '千葉県佐倉市大崎台');
ok($zip->set_number('2850818')->is_valid_number, '千葉県佐倉市寺崎');
ok($zip->set_number('2850819')->is_valid_number, '千葉県佐倉市寺崎北');
ok($zip->set_number('2850821')->is_valid_number, '千葉県佐倉市角来');
ok($zip->set_number('2850822')->is_valid_number, '千葉県佐倉市印南');
ok($zip->set_number('2850823')->is_valid_number, '千葉県佐倉市江原新田');
ok($zip->set_number('2850824')->is_valid_number, '千葉県佐倉市江原');
ok($zip->set_number('2850825')->is_valid_number, '千葉県佐倉市江原台');
ok($zip->set_number('2850831')->is_valid_number, '千葉県佐倉市染井野');
ok($zip->set_number('2850832')->is_valid_number, '千葉県佐倉市飯重');
ok($zip->set_number('2850833')->is_valid_number, '千葉県佐倉市羽鳥');
ok($zip->set_number('2850834')->is_valid_number, '千葉県佐倉市吉見');
ok($zip->set_number('2850835')->is_valid_number, '千葉県佐倉市畔田');
ok($zip->set_number('2850836')->is_valid_number, '千葉県佐倉市生谷');
ok($zip->set_number('2850837')->is_valid_number, '千葉県佐倉市王子台');
ok($zip->set_number('2850841')->is_valid_number, '千葉県佐倉市下志津');
ok($zip->set_number('2850842')->is_valid_number, '千葉県佐倉市下志津原');
ok($zip->set_number('2850843')->is_valid_number, '千葉県佐倉市中志津');
ok($zip->set_number('2850844')->is_valid_number, '千葉県佐倉市上志津原');
ok($zip->set_number('2850845')->is_valid_number, '千葉県佐倉市西志津');
ok($zip->set_number('2850846')->is_valid_number, '千葉県佐倉市上志津');
ok($zip->set_number('2850850')->is_valid_number, '千葉県佐倉市西ユーカリが丘');
ok($zip->set_number('2850851')->is_valid_number, '千葉県佐倉市先崎');
ok($zip->set_number('2850852')->is_valid_number, '千葉県佐倉市青菅');
ok($zip->set_number('2850853')->is_valid_number, '千葉県佐倉市小竹');
ok($zip->set_number('2850854')->is_valid_number, '千葉県佐倉市上座');
ok($zip->set_number('2850855')->is_valid_number, '千葉県佐倉市井野');
ok($zip->set_number('2850856')->is_valid_number, '千葉県佐倉市井野町');
ok($zip->set_number('2850857')->is_valid_number, '千葉県佐倉市宮ノ台');
ok($zip->set_number('2850858')->is_valid_number, '千葉県佐倉市ユーカリが丘');
ok($zip->set_number('2850859')->is_valid_number, '千葉県佐倉市南ユーカリが丘');
ok($zip->set_number('2850861')->is_valid_number, '千葉県佐倉市臼井田');
ok($zip->set_number('2850862')->is_valid_number, '千葉県佐倉市新臼井田');
ok($zip->set_number('2850863')->is_valid_number, '千葉県佐倉市臼井');
ok($zip->set_number('2850864')->is_valid_number, '千葉県佐倉市稲荷台');
ok($zip->set_number('2850865')->is_valid_number, '千葉県佐倉市南臼井台');
ok($zip->set_number('2850866')->is_valid_number, '千葉県佐倉市臼井台');
ok($zip->set_number('2850867')->is_valid_number, '千葉県佐倉市八幡台');
ok($zip->set_number('2850900')->is_valid_number, '千葉県印旛郡酒々井町以下に掲載がない場合');
ok($zip->set_number('2850901')->is_valid_number, '千葉県印旛郡酒々井町篠山新田');
ok($zip->set_number('2850902')->is_valid_number, '千葉県印旛郡酒々井町伊篠');
ok($zip->set_number('2850903')->is_valid_number, '千葉県印旛郡酒々井町今倉新田');
ok($zip->set_number('2850904')->is_valid_number, '千葉県印旛郡酒々井町伊篠新田');
ok($zip->set_number('2850905')->is_valid_number, '千葉県印旛郡酒々井町上岩橋');
ok($zip->set_number('2850906')->is_valid_number, '千葉県印旛郡酒々井町柏木');
ok($zip->set_number('2850907')->is_valid_number, '千葉県印旛郡酒々井町下岩橋');
ok($zip->set_number('2850911')->is_valid_number, '千葉県印旛郡酒々井町尾上');
ok($zip->set_number('2850912')->is_valid_number, '千葉県印旛郡酒々井町飯積');
ok($zip->set_number('2850913')->is_valid_number, '千葉県印旛郡酒々井町墨');
ok($zip->set_number('2850914')->is_valid_number, '千葉県印旛郡酒々井町馬橋');
ok($zip->set_number('2850921')->is_valid_number, '千葉県印旛郡酒々井町中川');
ok($zip->set_number('2850922')->is_valid_number, '千葉県印旛郡酒々井町中央台');
ok($zip->set_number('2850923')->is_valid_number, '千葉県印旛郡酒々井町東酒々井');
ok($zip->set_number('2850924')->is_valid_number, '千葉県印旛郡酒々井町下台');
ok($zip->set_number('2850925')->is_valid_number, '千葉県印旛郡酒々井町上本佐倉');
ok($zip->set_number('2850926')->is_valid_number, '千葉県印旛郡酒々井町本佐倉');
ok($zip->set_number('2850927')->is_valid_number, '千葉県印旛郡酒々井町酒々井');
ok($zip->set_number('2850928')->is_valid_number, '千葉県印旛郡酒々井町ふじき野');
ok($zip->set_number('2860000')->is_valid_number, '千葉県成田市以下に掲載がない場合');
ok($zip->set_number('2860001')->is_valid_number, '千葉県成田市船形');
ok($zip->set_number('2860002')->is_valid_number, '千葉県成田市八代');
ok($zip->set_number('2860003')->is_valid_number, '千葉県成田市台方');
ok($zip->set_number('2860004')->is_valid_number, '千葉県成田市宗吾');
ok($zip->set_number('2860005')->is_valid_number, '千葉県成田市下方');
ok($zip->set_number('2860006')->is_valid_number, '千葉県成田市北須賀');
ok($zip->set_number('2860007')->is_valid_number, '千葉県成田市はなのき台');
ok($zip->set_number('2860011')->is_valid_number, '千葉県成田市玉造');
ok($zip->set_number('2860012')->is_valid_number, '千葉県成田市山口');
ok($zip->set_number('2860013')->is_valid_number, '千葉県成田市美郷台');
ok($zip->set_number('2860014')->is_valid_number, '千葉県成田市郷部');
ok($zip->set_number('2860015')->is_valid_number, '千葉県成田市中台');
ok($zip->set_number('2860016')->is_valid_number, '千葉県成田市米野');
ok($zip->set_number('2860017')->is_valid_number, '千葉県成田市赤坂');
ok($zip->set_number('2860018')->is_valid_number, '千葉県成田市吾妻');
ok($zip->set_number('2860021')->is_valid_number, '千葉県成田市土屋');
ok($zip->set_number('2860022')->is_valid_number, '千葉県成田市寺台');
ok($zip->set_number('2860023')->is_valid_number, '千葉県成田市成田');
ok($zip->set_number('2860024')->is_valid_number, '千葉県成田市田町');
ok($zip->set_number('2860025')->is_valid_number, '千葉県成田市東町');
ok($zip->set_number('2860026')->is_valid_number, '千葉県成田市本町');
ok($zip->set_number('2860027')->is_valid_number, '千葉県成田市仲町');
ok($zip->set_number('2860028')->is_valid_number, '千葉県成田市幸町');
ok($zip->set_number('2860029')->is_valid_number, '千葉県成田市ウイング土屋');
ok($zip->set_number('2860031')->is_valid_number, '千葉県成田市新町');
ok($zip->set_number('2860032')->is_valid_number, '千葉県成田市上町');
ok($zip->set_number('2860033')->is_valid_number, '千葉県成田市花崎町');
ok($zip->set_number('2860034')->is_valid_number, '千葉県成田市馬橋');
ok($zip->set_number('2860035')->is_valid_number, '千葉県成田市囲護台');
ok($zip->set_number('2860036')->is_valid_number, '千葉県成田市加良部');
ok($zip->set_number('2860037')->is_valid_number, '千葉県成田市橋賀台');
ok($zip->set_number('2860041')->is_valid_number, '千葉県成田市飯田町');
ok($zip->set_number('2860042')->is_valid_number, '千葉県成田市南平台');
ok($zip->set_number('2860043')->is_valid_number, '千葉県成田市大袋');
ok($zip->set_number('2860044')->is_valid_number, '千葉県成田市不動ケ岡');
ok($zip->set_number('2860045')->is_valid_number, '千葉県成田市並木町');
ok($zip->set_number('2860046')->is_valid_number, '千葉県成田市飯仲');
ok($zip->set_number('2860047')->is_valid_number, '千葉県成田市江弁須');
ok($zip->set_number('2860048')->is_valid_number, '千葉県成田市公津の杜');
ok($zip->set_number('2860101')->is_valid_number, '千葉県成田市十余三(その他)');
ok($zip->set_number('2860102')->is_valid_number, '千葉県成田市天神峰(その他)');
ok($zip->set_number('2860103')->is_valid_number, '千葉県成田市東峰(その他)');
ok($zip->set_number('2860104')->is_valid_number, '千葉県成田市古込(その他)');
ok($zip->set_number('2860105')->is_valid_number, '千葉県成田市木の根(その他)');
ok($zip->set_number('2860106')->is_valid_number, '千葉県成田市取香(その他)');
ok($zip->set_number('2860107')->is_valid_number, '千葉県成田市堀之内(その他)');
ok($zip->set_number('2860108')->is_valid_number, '千葉県成田市長田');
ok($zip->set_number('2860111')->is_valid_number, '千葉県成田市三里塚(その他)');
ok($zip->set_number('2860112')->is_valid_number, '千葉県成田市東三里塚(その他)');
ok($zip->set_number('2860113')->is_valid_number, '千葉県成田市南三里塚');
ok($zip->set_number('2860114')->is_valid_number, '千葉県成田市本城');
ok($zip->set_number('2860115')->is_valid_number, '千葉県成田市西三里塚');
ok($zip->set_number('2860116')->is_valid_number, '千葉県成田市三里塚御料');
ok($zip->set_number('2860117')->is_valid_number, '千葉県成田市三里塚光ケ丘');
ok($zip->set_number('2860118')->is_valid_number, '千葉県成田市本三里塚');
ok($zip->set_number('2860121')->is_valid_number, '千葉県成田市駒井野(その他)');
ok($zip->set_number('2860122')->is_valid_number, '千葉県成田市大清水');
ok($zip->set_number('2860123')->is_valid_number, '千葉県成田市新駒井野');
ok($zip->set_number('2860124')->is_valid_number, '千葉県成田市畑ケ田');
ok($zip->set_number('2860125')->is_valid_number, '千葉県成田市川栗');
ok($zip->set_number('2860126')->is_valid_number, '千葉県成田市久米野');
ok($zip->set_number('2860127')->is_valid_number, '千葉県成田市小菅(その他)');
ok($zip->set_number('2860131')->is_valid_number, '千葉県成田市大山');
ok($zip->set_number('2860132')->is_valid_number, '千葉県成田市馬場');
ok($zip->set_number('2860133')->is_valid_number, '千葉県成田市吉倉');
ok($zip->set_number('2860134')->is_valid_number, '千葉県成田市東和田');
ok($zip->set_number('2860135')->is_valid_number, '千葉県成田市山之作');
ok($zip->set_number('2860136')->is_valid_number, '千葉県成田市久米');
ok($zip->set_number('2860137')->is_valid_number, '千葉県成田市御所の内');
ok($zip->set_number('2860200')->is_valid_number, '千葉県富里市以下に掲載がない場合');
ok($zip->set_number('2860201')->is_valid_number, '千葉県富里市日吉台');
ok($zip->set_number('2860202')->is_valid_number, '千葉県富里市日吉倉');
ok($zip->set_number('2860203')->is_valid_number, '千葉県富里市久能');
ok($zip->set_number('2860204')->is_valid_number, '千葉県富里市大和');
ok($zip->set_number('2860205')->is_valid_number, '千葉県富里市根木名');
ok($zip->set_number('2860211')->is_valid_number, '千葉県富里市御料');
ok($zip->set_number('2860212')->is_valid_number, '千葉県富里市十倉');
ok($zip->set_number('2860213')->is_valid_number, '千葉県富里市高松');
ok($zip->set_number('2860214')->is_valid_number, '千葉県富里市立沢');
ok($zip->set_number('2860215')->is_valid_number, '千葉県富里市立沢新田');
ok($zip->set_number('2860216')->is_valid_number, '千葉県富里市高野');
ok($zip->set_number('2860221')->is_valid_number, '千葉県富里市七栄');
ok($zip->set_number('2860222')->is_valid_number, '千葉県富里市中沢');
ok($zip->set_number('2860223')->is_valid_number, '千葉県富里市新中沢');
ok($zip->set_number('2860224')->is_valid_number, '千葉県富里市新橋');
ok($zip->set_number('2860225')->is_valid_number, '千葉県富里市美沢');
ok($zip->set_number('2860801')->is_valid_number, '千葉県成田市竜台');
ok($zip->set_number('2860802')->is_valid_number, '千葉県成田市北部');
ok($zip->set_number('2860803')->is_valid_number, '千葉県成田市安西');
ok($zip->set_number('2860804')->is_valid_number, '千葉県成田市長沼');
ok($zip->set_number('2860805')->is_valid_number, '千葉県成田市南羽鳥');
ok($zip->set_number('2860806')->is_valid_number, '千葉県成田市南部');
ok($zip->set_number('2860807')->is_valid_number, '千葉県成田市北羽鳥');
ok($zip->set_number('2860808')->is_valid_number, '千葉県成田市佐野');
ok($zip->set_number('2860811')->is_valid_number, '千葉県成田市磯部');
ok($zip->set_number('2860812')->is_valid_number, '千葉県成田市水掛');
ok($zip->set_number('2860813')->is_valid_number, '千葉県成田市飯岡');
ok($zip->set_number('2860814')->is_valid_number, '千葉県成田市幡谷');
ok($zip->set_number('2860815')->is_valid_number, '千葉県成田市土室');
ok($zip->set_number('2860816')->is_valid_number, '千葉県成田市成毛');
ok($zip->set_number('2860817')->is_valid_number, '千葉県成田市大生');
ok($zip->set_number('2860818')->is_valid_number, '千葉県成田市荒海');
ok($zip->set_number('2860819')->is_valid_number, '千葉県成田市久住中央');
ok($zip->set_number('2860821')->is_valid_number, '千葉県成田市大室');
ok($zip->set_number('2860822')->is_valid_number, '千葉県成田市芝');
ok($zip->set_number('2860823')->is_valid_number, '千葉県成田市小泉');
ok($zip->set_number('2860824')->is_valid_number, '千葉県成田市野毛平');
ok($zip->set_number('2860825')->is_valid_number, '千葉県成田市新泉');
ok($zip->set_number('2860826')->is_valid_number, '千葉県成田市東和泉');
ok($zip->set_number('2860827')->is_valid_number, '千葉県成田市西和泉');
ok($zip->set_number('2860831')->is_valid_number, '千葉県成田市芦田');
ok($zip->set_number('2860832')->is_valid_number, '千葉県成田市赤荻');
ok($zip->set_number('2860833')->is_valid_number, '千葉県成田市東金山');
ok($zip->set_number('2860834')->is_valid_number, '千葉県成田市和田');
ok($zip->set_number('2860835')->is_valid_number, '千葉県成田市関戸');
ok($zip->set_number('2860836')->is_valid_number, '千葉県成田市下金山');
ok($zip->set_number('2860837')->is_valid_number, '千葉県成田市新妻');
ok($zip->set_number('2860841')->is_valid_number, '千葉県成田市大竹');
ok($zip->set_number('2860842')->is_valid_number, '千葉県成田市上福田');
ok($zip->set_number('2860843')->is_valid_number, '千葉県成田市下福田');
ok($zip->set_number('2860844')->is_valid_number, '千葉県成田市宝田');
ok($zip->set_number('2860845')->is_valid_number, '千葉県成田市押畑');
ok($zip->set_number('2860846')->is_valid_number, '千葉県成田市松崎');
ok($zip->set_number('2870000')->is_valid_number, '千葉県香取市以下に掲載がない場合');
ok($zip->set_number('2870001')->is_valid_number, '千葉県香取市佐原ロ');
ok($zip->set_number('2870002')->is_valid_number, '千葉県香取市北');
ok($zip->set_number('2870003')->is_valid_number, '千葉県香取市佐原イ');
ok($zip->set_number('2870004')->is_valid_number, '千葉県香取市岩ケ崎台');
ok($zip->set_number('2870005')->is_valid_number, '千葉県香取市佐原ホ');
ok($zip->set_number('2870006')->is_valid_number, '千葉県香取市篠原イ');
ok($zip->set_number('2870011')->is_valid_number, '千葉県香取市津宮');
ok($zip->set_number('2870012')->is_valid_number, '千葉県香取市大倉丁子');
ok($zip->set_number('2870013')->is_valid_number, '千葉県香取市大倉');
ok($zip->set_number('2870014')->is_valid_number, '千葉県香取市多田');
ok($zip->set_number('2870015')->is_valid_number, '千葉県香取市吉原');
ok($zip->set_number('2870016')->is_valid_number, '千葉県香取市新市場');
ok($zip->set_number('2870017')->is_valid_number, '千葉県香取市香取');
ok($zip->set_number('2870018')->is_valid_number, '千葉県香取市丁子');
ok($zip->set_number('2870021')->is_valid_number, '千葉県香取市下小野');
ok($zip->set_number('2870022')->is_valid_number, '千葉県香取市九美上');
ok($zip->set_number('2870023')->is_valid_number, '千葉県香取市伊地山');
ok($zip->set_number('2870024')->is_valid_number, '千葉県香取市福田');
ok($zip->set_number('2870025')->is_valid_number, '千葉県香取市本矢作');
ok($zip->set_number('2870026')->is_valid_number, '千葉県香取市大根');
ok($zip->set_number('2870027')->is_valid_number, '千葉県香取市返田');
ok($zip->set_number('2870031')->is_valid_number, '千葉県香取市新部');
ok($zip->set_number('2870032')->is_valid_number, '千葉県香取市釜塚');
ok($zip->set_number('2870033')->is_valid_number, '千葉県香取市牧野');
ok($zip->set_number('2870034')->is_valid_number, '千葉県香取市長山');
ok($zip->set_number('2870035')->is_valid_number, '千葉県香取市大崎');
ok($zip->set_number('2870036')->is_valid_number, '千葉県香取市観音');
ok($zip->set_number('2870037')->is_valid_number, '千葉県香取市与倉');
ok($zip->set_number('2870038')->is_valid_number, '千葉県香取市鳥羽');
ok($zip->set_number('2870041')->is_valid_number, '千葉県香取市玉造');
ok($zip->set_number('2870042')->is_valid_number, '千葉県香取市山之辺');
ok($zip->set_number('2870043')->is_valid_number, '千葉県香取市大戸');
ok($zip->set_number('2870044')->is_valid_number, '千葉県香取市片野');
ok($zip->set_number('2870045')->is_valid_number, '千葉県香取市関');
ok($zip->set_number('2870046')->is_valid_number, '千葉県香取市上小川');
ok($zip->set_number('2870047')->is_valid_number, '千葉県香取市鴇崎');
ok($zip->set_number('2870048')->is_valid_number, '千葉県香取市西和田');
ok($zip->set_number('2870051')->is_valid_number, '千葉県香取市新寺');
ok($zip->set_number('2870052')->is_valid_number, '千葉県香取市森戸');
ok($zip->set_number('2870053')->is_valid_number, '千葉県香取市大戸新田');
ok($zip->set_number('2870054')->is_valid_number, '千葉県香取市大戸川');
ok($zip->set_number('2870055')->is_valid_number, '千葉県香取市昭和町');
ok($zip->set_number('2870056')->is_valid_number, '千葉県香取市飯島');
ok($zip->set_number('2870061')->is_valid_number, '千葉県香取市谷中');
ok($zip->set_number('2870062')->is_valid_number, '千葉県香取市寺内');
ok($zip->set_number('2870063')->is_valid_number, '千葉県香取市西坂');
ok($zip->set_number('2870064')->is_valid_number, '千葉県香取市みずほ台');
ok($zip->set_number('2870065')->is_valid_number, '千葉県香取市西部田');
ok($zip->set_number('2870066')->is_valid_number, '千葉県香取市堀之内');
ok($zip->set_number('2870067')->is_valid_number, '千葉県香取市川尻');
ok($zip->set_number('2870101')->is_valid_number, '千葉県香取市高萩');
ok($zip->set_number('2870102')->is_valid_number, '千葉県香取市岩部');
ok($zip->set_number('2870103')->is_valid_number, '千葉県香取市西田部');
ok($zip->set_number('2870104')->is_valid_number, '千葉県香取市苅毛');
ok($zip->set_number('2870105')->is_valid_number, '千葉県香取市沢');
ok($zip->set_number('2870106')->is_valid_number, '千葉県香取市荒北');
ok($zip->set_number('2870107')->is_valid_number, '千葉県香取市助沢');
ok($zip->set_number('2870201')->is_valid_number, '千葉県成田市柴田');
ok($zip->set_number('2870202')->is_valid_number, '千葉県成田市堀籠');
ok($zip->set_number('2870203')->is_valid_number, '千葉県成田市村田');
ok($zip->set_number('2870204')->is_valid_number, '千葉県成田市伊能');
ok($zip->set_number('2870205')->is_valid_number, '千葉県成田市奈土');
ok($zip->set_number('2870206')->is_valid_number, '千葉県成田市浅間');
ok($zip->set_number('2870211')->is_valid_number, '千葉県成田市所');
ok($zip->set_number('2870212')->is_valid_number, '千葉県成田市東ノ台');
ok($zip->set_number('2870213')->is_valid_number, '千葉県成田市大沼');
ok($zip->set_number('2870214')->is_valid_number, '千葉県成田市横山');
ok($zip->set_number('2870215')->is_valid_number, '千葉県成田市馬乗里');
ok($zip->set_number('2870216')->is_valid_number, '千葉県成田市南敷');
ok($zip->set_number('2870217')->is_valid_number, '千葉県成田市桜田');
ok($zip->set_number('2870221')->is_valid_number, '千葉県成田市官林');
ok($zip->set_number('2870222')->is_valid_number, '千葉県成田市前林');
ok($zip->set_number('2870224')->is_valid_number, '千葉県成田市新田');
ok($zip->set_number('2870225')->is_valid_number, '千葉県成田市吉岡(その他)');
ok($zip->set_number('2870227')->is_valid_number, '千葉県成田市一坪田');
ok($zip->set_number('2870232')->is_valid_number, '千葉県成田市久井崎');
ok($zip->set_number('2870233')->is_valid_number, '千葉県成田市稲荷山');
ok($zip->set_number('2870234')->is_valid_number, '千葉県成田市松子');
ok($zip->set_number('2870235')->is_valid_number, '千葉県成田市臼作');
ok($zip->set_number('2870236')->is_valid_number, '千葉県成田市津富浦');
ok($zip->set_number('2870237')->is_valid_number, '千葉県成田市中野');
ok($zip->set_number('2870241')->is_valid_number, '千葉県成田市水の上');
ok($zip->set_number('2870242')->is_valid_number, '千葉県成田市多良貝');
ok($zip->set_number('2870243')->is_valid_number, '千葉県成田市大栄十余三');
ok($zip->set_number('2870244')->is_valid_number, '千葉県成田市川上');
ok($zip->set_number('2870801')->is_valid_number, '千葉県香取市扇島');
ok($zip->set_number('2870802')->is_valid_number, '千葉県香取市加藤洲');
ok($zip->set_number('2870803')->is_valid_number, '千葉県香取市磯山');
ok($zip->set_number('2870804')->is_valid_number, '千葉県香取市市和田');
ok($zip->set_number('2870805')->is_valid_number, '千葉県香取市公官洲');
ok($zip->set_number('2870806')->is_valid_number, '千葉県香取市附洲新田');
ok($zip->set_number('2870811')->is_valid_number, '千葉県香取市大島');
ok($zip->set_number('2870812')->is_valid_number, '千葉県香取市三島');
ok($zip->set_number('2870813')->is_valid_number, '千葉県香取市境島');
ok($zip->set_number('2870814')->is_valid_number, '千葉県香取市中洲');
ok($zip->set_number('2870815')->is_valid_number, '千葉県香取市八筋川');
ok($zip->set_number('2870816')->is_valid_number, '千葉県香取市佐原ハ');
ok($zip->set_number('2870821')->is_valid_number, '千葉県香取市篠原ロ');
ok($zip->set_number('2870822')->is_valid_number, '千葉県香取市佐原ニ');
ok($zip->set_number('2870823')->is_valid_number, '千葉県香取市笄島');
ok($zip->set_number('2870824')->is_valid_number, '千葉県香取市長島');
ok($zip->set_number('2870825')->is_valid_number, '千葉県香取市野間谷原');
ok($zip->set_number('2870826')->is_valid_number, '千葉県香取市石納');
ok($zip->set_number('2880000')->is_valid_number, '千葉県銚子市以下に掲載がない場合');
ok($zip->set_number('2880001')->is_valid_number, '千葉県銚子市川口町');
ok($zip->set_number('2880002')->is_valid_number, '千葉県銚子市明神町');
ok($zip->set_number('2880003')->is_valid_number, '千葉県銚子市黒生町');
ok($zip->set_number('2880004')->is_valid_number, '千葉県銚子市笠上町');
ok($zip->set_number('2880005')->is_valid_number, '千葉県銚子市海鹿島町');
ok($zip->set_number('2880006')->is_valid_number, '千葉県銚子市榊町');
ok($zip->set_number('2880007')->is_valid_number, '千葉県銚子市愛宕町');
ok($zip->set_number('2880011')->is_valid_number, '千葉県銚子市君ケ浜');
ok($zip->set_number('2880012')->is_valid_number, '千葉県銚子市犬吠埼');
ok($zip->set_number('2880013')->is_valid_number, '千葉県銚子市長崎町');
ok($zip->set_number('2880014')->is_valid_number, '千葉県銚子市外川町');
ok($zip->set_number('2880015')->is_valid_number, '千葉県銚子市犬若');
ok($zip->set_number('2880016')->is_valid_number, '千葉県銚子市外川台町');
ok($zip->set_number('2880021')->is_valid_number, '千葉県銚子市小畑新町');
ok($zip->set_number('2880022')->is_valid_number, '千葉県銚子市小畑町');
ok($zip->set_number('2880023')->is_valid_number, '千葉県銚子市高神東町');
ok($zip->set_number('2880024')->is_valid_number, '千葉県銚子市天王台');
ok($zip->set_number('2880025')->is_valid_number, '千葉県銚子市潮見町');
ok($zip->set_number('2880026')->is_valid_number, '千葉県銚子市高神西町');
ok($zip->set_number('2880027')->is_valid_number, '千葉県銚子市高神原町');
ok($zip->set_number('2880031')->is_valid_number, '千葉県銚子市前宿町');
ok($zip->set_number('2880032')->is_valid_number, '千葉県銚子市東小川町');
ok($zip->set_number('2880033')->is_valid_number, '千葉県銚子市南小川町');
ok($zip->set_number('2880034')->is_valid_number, '千葉県銚子市粟島町');
ok($zip->set_number('2880035')->is_valid_number, '千葉県銚子市名洗町');
ok($zip->set_number('2880036')->is_valid_number, '千葉県銚子市西小川町');
ok($zip->set_number('2880037')->is_valid_number, '千葉県銚子市北小川町');
ok($zip->set_number('2880038')->is_valid_number, '千葉県銚子市南町');
ok($zip->set_number('2880041')->is_valid_number, '千葉県銚子市中央町');
ok($zip->set_number('2880042')->is_valid_number, '千葉県銚子市末広町');
ok($zip->set_number('2880043')->is_valid_number, '千葉県銚子市東芝町');
ok($zip->set_number('2880044')->is_valid_number, '千葉県銚子市西芝町');
ok($zip->set_number('2880045')->is_valid_number, '千葉県銚子市三軒町');
ok($zip->set_number('2880046')->is_valid_number, '千葉県銚子市大橋町');
ok($zip->set_number('2880047')->is_valid_number, '千葉県銚子市若宮町');
ok($zip->set_number('2880048')->is_valid_number, '千葉県銚子市双葉町');
ok($zip->set_number('2880051')->is_valid_number, '千葉県銚子市飯沼町');
ok($zip->set_number('2880052')->is_valid_number, '千葉県銚子市浜町');
ok($zip->set_number('2880053')->is_valid_number, '千葉県銚子市東町');
ok($zip->set_number('2880054')->is_valid_number, '千葉県銚子市馬場町');
ok($zip->set_number('2880055')->is_valid_number, '千葉県銚子市陣屋町');
ok($zip->set_number('2880056')->is_valid_number, '千葉県銚子市新生町');
ok($zip->set_number('2880061')->is_valid_number, '千葉県銚子市港町');
ok($zip->set_number('2880062')->is_valid_number, '千葉県銚子市竹町');
ok($zip->set_number('2880063')->is_valid_number, '千葉県銚子市清水町');
ok($zip->set_number('2880064')->is_valid_number, '千葉県銚子市後飯町');
ok($zip->set_number('2880065')->is_valid_number, '千葉県銚子市田中町');
ok($zip->set_number('2880066')->is_valid_number, '千葉県銚子市和田町');
ok($zip->set_number('2880067')->is_valid_number, '千葉県銚子市新地町');
ok($zip->set_number('2880068')->is_valid_number, '千葉県銚子市内浜町');
ok($zip->set_number('2880071')->is_valid_number, '千葉県銚子市植松町');
ok($zip->set_number('2880072')->is_valid_number, '千葉県銚子市弥生町');
ok($zip->set_number('2880073')->is_valid_number, '千葉県銚子市幸町');
ok($zip->set_number('2880074')->is_valid_number, '千葉県銚子市橋本町');
ok($zip->set_number('2880075')->is_valid_number, '千葉県銚子市通町');
ok($zip->set_number('2880076')->is_valid_number, '千葉県銚子市本町');
ok($zip->set_number('2880077')->is_valid_number, '千葉県銚子市仲町');
ok($zip->set_number('2880801')->is_valid_number, '千葉県銚子市唐子町');
ok($zip->set_number('2880802')->is_valid_number, '千葉県銚子市松本町');
ok($zip->set_number('2880803')->is_valid_number, '千葉県銚子市八幡町');
ok($zip->set_number('2880804')->is_valid_number, '千葉県銚子市今宮町');
ok($zip->set_number('2880805')->is_valid_number, '千葉県銚子市上野町');
ok($zip->set_number('2880811')->is_valid_number, '千葉県銚子市妙見町');
ok($zip->set_number('2880812')->is_valid_number, '千葉県銚子市栄町');
ok($zip->set_number('2880813')->is_valid_number, '千葉県銚子市台町');
ok($zip->set_number('2880814')->is_valid_number, '千葉県銚子市春日町');
ok($zip->set_number('2880815')->is_valid_number, '千葉県銚子市三崎町');
ok($zip->set_number('2880816')->is_valid_number, '千葉県銚子市春日台町');
ok($zip->set_number('2880817')->is_valid_number, '千葉県銚子市清川町');
ok($zip->set_number('2880821')->is_valid_number, '千葉県銚子市小浜町');
ok($zip->set_number('2880822')->is_valid_number, '千葉県銚子市八木町');
ok($zip->set_number('2880823')->is_valid_number, '千葉県銚子市親田町');
ok($zip->set_number('2880824')->is_valid_number, '千葉県銚子市常世田町');
ok($zip->set_number('2880825')->is_valid_number, '千葉県銚子市新町');
ok($zip->set_number('2880831')->is_valid_number, '千葉県銚子市本城町');
ok($zip->set_number('2880832')->is_valid_number, '千葉県銚子市松岸見晴台');
ok($zip->set_number('2880833')->is_valid_number, '千葉県銚子市垣根見晴台');
ok($zip->set_number('2880834')->is_valid_number, '千葉県銚子市高野町');
ok($zip->set_number('2880835')->is_valid_number, '千葉県銚子市垣根町');
ok($zip->set_number('2880836')->is_valid_number, '千葉県銚子市松岸町');
ok($zip->set_number('2880837')->is_valid_number, '千葉県銚子市長塚町');
ok($zip->set_number('2880841')->is_valid_number, '千葉県銚子市四日市場町');
ok($zip->set_number('2880842')->is_valid_number, '千葉県銚子市柴崎町');
ok($zip->set_number('2880843')->is_valid_number, '千葉県銚子市四日市場台');
ok($zip->set_number('2880844')->is_valid_number, '千葉県銚子市赤塚町');
ok($zip->set_number('2880845')->is_valid_number, '千葉県銚子市三宅町');
ok($zip->set_number('2880846')->is_valid_number, '千葉県銚子市余山町');
ok($zip->set_number('2880851')->is_valid_number, '千葉県銚子市三門町');
ok($zip->set_number('2880852')->is_valid_number, '千葉県銚子市岡野台町');
ok($zip->set_number('2880853')->is_valid_number, '千葉県銚子市白石町');
ok($zip->set_number('2880854')->is_valid_number, '千葉県銚子市茶畑町');
ok($zip->set_number('2880855')->is_valid_number, '千葉県銚子市猿田町');
ok($zip->set_number('2880856')->is_valid_number, '千葉県銚子市正明寺町');
ok($zip->set_number('2880857')->is_valid_number, '千葉県銚子市船木町');
ok($zip->set_number('2880858')->is_valid_number, '千葉県銚子市中島町');
ok($zip->set_number('2880861')->is_valid_number, '千葉県銚子市芦崎町');
ok($zip->set_number('2880862')->is_valid_number, '千葉県銚子市高田町');
ok($zip->set_number('2880863')->is_valid_number, '千葉県銚子市野尻町');
ok($zip->set_number('2880864')->is_valid_number, '千葉県銚子市小船木町');
ok($zip->set_number('2880865')->is_valid_number, '千葉県銚子市長山町');
ok($zip->set_number('2880866')->is_valid_number, '千葉県銚子市小長町');
ok($zip->set_number('2880867')->is_valid_number, '千葉県銚子市忍町');
ok($zip->set_number('2880868')->is_valid_number, '千葉県銚子市塚本町');
ok($zip->set_number('2880871')->is_valid_number, '千葉県銚子市富川町');
ok($zip->set_number('2880872')->is_valid_number, '千葉県銚子市森戸町');
ok($zip->set_number('2880873')->is_valid_number, '千葉県銚子市笹本町');
ok($zip->set_number('2880874')->is_valid_number, '千葉県銚子市豊里台');
ok($zip->set_number('2880875')->is_valid_number, '千葉県銚子市諸持町');
ok($zip->set_number('2880876')->is_valid_number, '千葉県銚子市桜井町');
ok($zip->set_number('2880877')->is_valid_number, '千葉県銚子市宮原町');
ok($zip->set_number('2890100')->is_valid_number, '千葉県香取郡神崎町以下に掲載がない場合');
ok($zip->set_number('2890101')->is_valid_number, '千葉県成田市小浮');
ok($zip->set_number('2890102')->is_valid_number, '千葉県成田市野馬込');
ok($zip->set_number('2890103')->is_valid_number, '千葉県成田市高');
ok($zip->set_number('2890104')->is_valid_number, '千葉県成田市冬父');
ok($zip->set_number('2890105')->is_valid_number, '千葉県成田市中里');
ok($zip->set_number('2890106')->is_valid_number, '千葉県成田市小野');
ok($zip->set_number('2890107')->is_valid_number, '千葉県成田市猿山');
ok($zip->set_number('2890108')->is_valid_number, '千葉県成田市高岡');
ok($zip->set_number('2890109')->is_valid_number, '千葉県成田市大和田');
ok($zip->set_number('2890111')->is_valid_number, '千葉県成田市名木');
ok($zip->set_number('2890112')->is_valid_number, '千葉県成田市青山');
ok($zip->set_number('2890113')->is_valid_number, '千葉県成田市倉水');
ok($zip->set_number('2890114')->is_valid_number, '千葉県成田市成井');
ok($zip->set_number('2890115')->is_valid_number, '千葉県成田市地蔵原新田');
ok($zip->set_number('2890116')->is_valid_number, '千葉県成田市名古屋');
ok($zip->set_number('2890117')->is_valid_number, '千葉県成田市七沢');
ok($zip->set_number('2890121')->is_valid_number, '千葉県成田市大菅');
ok($zip->set_number('2890122')->is_valid_number, '千葉県成田市高倉');
ok($zip->set_number('2890123')->is_valid_number, '千葉県成田市四谷');
ok($zip->set_number('2890124')->is_valid_number, '千葉県成田市西大須賀');
ok($zip->set_number('2890125')->is_valid_number, '千葉県成田市滑川');
ok($zip->set_number('2890126')->is_valid_number, '千葉県成田市新川');
ok($zip->set_number('2890201')->is_valid_number, '千葉県香取郡神崎町高谷');
ok($zip->set_number('2890202')->is_valid_number, '千葉県香取郡神崎町郡');
ok($zip->set_number('2890203')->is_valid_number, '千葉県香取郡神崎町大貫');
ok($zip->set_number('2890204')->is_valid_number, '千葉県香取郡神崎町四季の丘');
ok($zip->set_number('2890205')->is_valid_number, '千葉県香取郡神崎町今');
ok($zip->set_number('2890211')->is_valid_number, '千葉県香取郡神崎町立野');
ok($zip->set_number('2890212')->is_valid_number, '千葉県香取郡神崎町武田');
ok($zip->set_number('2890213')->is_valid_number, '千葉県香取郡神崎町新');
ok($zip->set_number('2890214')->is_valid_number, '千葉県香取郡神崎町毛成');
ok($zip->set_number('2890215')->is_valid_number, '千葉県香取郡神崎町古原');
ok($zip->set_number('2890216')->is_valid_number, '千葉県香取郡神崎町植房');
ok($zip->set_number('2890217')->is_valid_number, '千葉県香取郡神崎町藤の台');
ok($zip->set_number('2890221')->is_valid_number, '千葉県香取郡神崎町神崎本宿');
ok($zip->set_number('2890222')->is_valid_number, '千葉県香取郡神崎町並木');
ok($zip->set_number('2890223')->is_valid_number, '千葉県香取郡神崎町小松');
ok($zip->set_number('2890224')->is_valid_number, '千葉県香取郡神崎町松崎');
ok($zip->set_number('2890225')->is_valid_number, '千葉県香取郡神崎町十三間戸');
ok($zip->set_number('2890226')->is_valid_number, '千葉県香取郡神崎町神崎神宿');
ok($zip->set_number('2890301')->is_valid_number, '千葉県香取市一ノ分目');
ok($zip->set_number('2890302')->is_valid_number, '千葉県香取市三ノ分目');
ok($zip->set_number('2890303')->is_valid_number, '千葉県香取市富田');
ok($zip->set_number('2890304')->is_valid_number, '千葉県香取市下小堀');
ok($zip->set_number('2890305')->is_valid_number, '千葉県香取市分郷');
ok($zip->set_number('2890306')->is_valid_number, '千葉県香取市上小堀');
ok($zip->set_number('2890307')->is_valid_number, '千葉県香取市増田');
ok($zip->set_number('2890308')->is_valid_number, '千葉県香取市木内虫幡上小堀入会地大平');
ok($zip->set_number('2890311')->is_valid_number, '千葉県香取市八日市場');
ok($zip->set_number('2890312')->is_valid_number, '千葉県香取市本郷');
ok($zip->set_number('2890313')->is_valid_number, '千葉県香取市小見川');
ok($zip->set_number('2890314')->is_valid_number, '千葉県香取市野田');
ok($zip->set_number('2890321')->is_valid_number, '千葉県香取市阿玉川');
ok($zip->set_number('2890322')->is_valid_number, '千葉県香取市下飯田');
ok($zip->set_number('2890323')->is_valid_number, '千葉県香取市岡飯田');
ok($zip->set_number('2890324')->is_valid_number, '千葉県香取市和泉');
ok($zip->set_number('2890325')->is_valid_number, '千葉県香取市貝塚');
ok($zip->set_number('2890326')->is_valid_number, '千葉県香取市阿玉台');
ok($zip->set_number('2890327')->is_valid_number, '千葉県香取市久保');
ok($zip->set_number('2890328')->is_valid_number, '千葉県香取市五郷内');
ok($zip->set_number('2890329')->is_valid_number, '千葉県香取市布野');
ok($zip->set_number('2890331')->is_valid_number, '千葉県香取市羽根川');
ok($zip->set_number('2890332')->is_valid_number, '千葉県香取市南原地新田');
ok($zip->set_number('2890333')->is_valid_number, '千葉県香取市入会地');
ok($zip->set_number('2890334')->is_valid_number, '千葉県香取市川頭');
ok($zip->set_number('2890335')->is_valid_number, '千葉県香取市北原地新田');
ok($zip->set_number('2890336')->is_valid_number, '千葉県香取市新々田');
ok($zip->set_number('2890337')->is_valid_number, '千葉県香取市木内');
ok($zip->set_number('2890338')->is_valid_number, '千葉県香取市下小川');
ok($zip->set_number('2890341')->is_valid_number, '千葉県香取市虫幡');
ok($zip->set_number('2890342')->is_valid_number, '千葉県香取市竜谷');
ok($zip->set_number('2890343')->is_valid_number, '千葉県香取市山川');
ok($zip->set_number('2890344')->is_valid_number, '千葉県香取市白井');
ok($zip->set_number('2890345')->is_valid_number, '千葉県香取市八本');
ok($zip->set_number('2890346')->is_valid_number, '千葉県香取市油田');
ok($zip->set_number('2890347')->is_valid_number, '千葉県香取市旗鉾');
ok($zip->set_number('2890348')->is_valid_number, '千葉県香取市織幡');
ok($zip->set_number('2890349')->is_valid_number, '千葉県香取市内野');
ok($zip->set_number('2890401')->is_valid_number, '千葉県香取市米野井');
ok($zip->set_number('2890402')->is_valid_number, '千葉県香取市小見');
ok($zip->set_number('2890403')->is_valid_number, '千葉県香取市川上');
ok($zip->set_number('2890404')->is_valid_number, '千葉県香取市高野');
ok($zip->set_number('2890405')->is_valid_number, '千葉県香取市竹之内');
ok($zip->set_number('2890406')->is_valid_number, '千葉県香取市田部');
ok($zip->set_number('2890407')->is_valid_number, '千葉県香取市仁良');
ok($zip->set_number('2890408')->is_valid_number, '千葉県香取市神生');
ok($zip->set_number('2890411')->is_valid_number, '千葉県香取市府馬');
ok($zip->set_number('2890412')->is_valid_number, '千葉県香取市古内');
ok($zip->set_number('2890413')->is_valid_number, '千葉県香取市志高');
ok($zip->set_number('2890414')->is_valid_number, '千葉県香取市長岡');
ok($zip->set_number('2890421')->is_valid_number, '千葉県香取市鳩山');
ok($zip->set_number('2890422')->is_valid_number, '千葉県香取市桐谷');
ok($zip->set_number('2890423')->is_valid_number, '千葉県香取市小川');
ok($zip->set_number('2890424')->is_valid_number, '千葉県香取市新里');
ok($zip->set_number('2890425')->is_valid_number, '千葉県香取市大角');
ok($zip->set_number('2890426')->is_valid_number, '千葉県香取市山倉');
ok($zip->set_number('2890501')->is_valid_number, '千葉県旭市清和乙');
ok($zip->set_number('2890502')->is_valid_number, '千葉県旭市長部');
ok($zip->set_number('2890503')->is_valid_number, '千葉県旭市溝原');
ok($zip->set_number('2890504')->is_valid_number, '千葉県旭市櫻井');
ok($zip->set_number('2890505')->is_valid_number, '千葉県旭市萬歳');
ok($zip->set_number('2890506')->is_valid_number, '千葉県旭市さくら台');
ok($zip->set_number('2890507')->is_valid_number, '千葉県旭市清和甲');
ok($zip->set_number('2890511')->is_valid_number, '千葉県旭市鏑木');
ok($zip->set_number('2890512')->is_valid_number, '千葉県旭市南堀之内');
ok($zip->set_number('2890513')->is_valid_number, '千葉県旭市舟戸');
ok($zip->set_number('2890514')->is_valid_number, '千葉県旭市関戸');
ok($zip->set_number('2890515')->is_valid_number, '千葉県旭市入野');
ok($zip->set_number('2890516')->is_valid_number, '千葉県旭市米込');
ok($zip->set_number('2890517')->is_valid_number, '千葉県旭市萬力');
ok($zip->set_number('2890518')->is_valid_number, '千葉県旭市秋田');
ok($zip->set_number('2890600')->is_valid_number, '千葉県香取郡東庄町以下に掲載がない場合');
ok($zip->set_number('2890601')->is_valid_number, '千葉県香取郡東庄町笹川い');
ok($zip->set_number('2890602')->is_valid_number, '千葉県香取郡東庄町笹川ろ');
ok($zip->set_number('2890611')->is_valid_number, '千葉県香取郡東庄町新宿');
ok($zip->set_number('2890612')->is_valid_number, '千葉県香取郡東庄町石出');
ok($zip->set_number('2890613')->is_valid_number, '千葉県香取郡東庄町東今泉');
ok($zip->set_number('2890614')->is_valid_number, '千葉県香取郡東庄町宮本');
ok($zip->set_number('2890615')->is_valid_number, '千葉県香取郡東庄町青馬');
ok($zip->set_number('2890616')->is_valid_number, '千葉県香取郡東庄町高部');
ok($zip->set_number('2890617')->is_valid_number, '千葉県香取郡東庄町羽計');
ok($zip->set_number('2890618')->is_valid_number, '千葉県香取郡東庄町谷津');
ok($zip->set_number('2890619')->is_valid_number, '千葉県香取郡東庄町今郡');
ok($zip->set_number('2890621')->is_valid_number, '千葉県香取郡東庄町大友');
ok($zip->set_number('2890622')->is_valid_number, '千葉県香取郡東庄町小座');
ok($zip->set_number('2890623')->is_valid_number, '千葉県香取郡東庄町宮野台');
ok($zip->set_number('2890624')->is_valid_number, '千葉県香取郡東庄町小南');
ok($zip->set_number('2890625')->is_valid_number, '千葉県香取郡東庄町夏目');
ok($zip->set_number('2890626')->is_valid_number, '千葉県香取郡東庄町八重穂');
ok($zip->set_number('2890627')->is_valid_number, '千葉県香取郡東庄町粟野');
ok($zip->set_number('2890631')->is_valid_number, '千葉県香取郡東庄町平山');
ok($zip->set_number('2890632')->is_valid_number, '千葉県香取郡東庄町窪野谷');
ok($zip->set_number('2890633')->is_valid_number, '千葉県香取郡東庄町大久保');
ok($zip->set_number('2890634')->is_valid_number, '千葉県香取郡東庄町舟戸');
ok($zip->set_number('2890635')->is_valid_number, '千葉県香取郡東庄町神田');
ok($zip->set_number('2890636')->is_valid_number, '千葉県香取郡東庄町東和田');
ok($zip->set_number('2890637')->is_valid_number, '千葉県香取郡東庄町小貝野');
ok($zip->set_number('2891100')->is_valid_number, '千葉県八街市以下に掲載がない場合');
ok($zip->set_number('2891101')->is_valid_number, '千葉県八街市朝日');
ok($zip->set_number('2891102')->is_valid_number, '千葉県八街市沖渡');
ok($zip->set_number('2891103')->is_valid_number, '千葉県八街市八街に');
ok($zip->set_number('2891104')->is_valid_number, '千葉県八街市文違');
ok($zip->set_number('2891105')->is_valid_number, '千葉県八街市泉台');
ok($zip->set_number('2891106')->is_valid_number, '千葉県八街市榎戸');
ok($zip->set_number('2891107')->is_valid_number, '千葉県八街市八街は');
ok($zip->set_number('2891108')->is_valid_number, '千葉県八街市雁丸');
ok($zip->set_number('2891111')->is_valid_number, '千葉県八街市大木');
ok($zip->set_number('2891112')->is_valid_number, '千葉県八街市木原');
ok($zip->set_number('2891113')->is_valid_number, '千葉県八街市八街へ');
ok($zip->set_number('2891114')->is_valid_number, '千葉県八街市東吉田');
ok($zip->set_number('2891115')->is_valid_number, '千葉県八街市八街ほ');
ok($zip->set_number('2891116')->is_valid_number, '千葉県八街市中央');
ok($zip->set_number('2891121')->is_valid_number, '千葉県八街市砂');
ok($zip->set_number('2891122')->is_valid_number, '千葉県八街市四木');
ok($zip->set_number('2891123')->is_valid_number, '千葉県八街市滝台');
ok($zip->set_number('2891124')->is_valid_number, '千葉県八街市山田台');
ok($zip->set_number('2891125')->is_valid_number, '千葉県八街市上砂');
ok($zip->set_number('2891126')->is_valid_number, '千葉県八街市沖');
ok($zip->set_number('2891131')->is_valid_number, '千葉県八街市希望ケ丘');
ok($zip->set_number('2891132')->is_valid_number, '千葉県八街市勢田');
ok($zip->set_number('2891133')->is_valid_number, '千葉県八街市吉倉');
ok($zip->set_number('2891134')->is_valid_number, '千葉県八街市大谷流');
ok($zip->set_number('2891135')->is_valid_number, '千葉県八街市小谷流');
ok($zip->set_number('2891136')->is_valid_number, '千葉県八街市根古谷');
ok($zip->set_number('2891137')->is_valid_number, '千葉県八街市岡田');
ok($zip->set_number('2891138')->is_valid_number, '千葉県八街市用草');
ok($zip->set_number('2891141')->is_valid_number, '千葉県八街市富山');
ok($zip->set_number('2891142')->is_valid_number, '千葉県八街市大関');
ok($zip->set_number('2891143')->is_valid_number, '千葉県八街市八街い');
ok($zip->set_number('2891144')->is_valid_number, '千葉県八街市八街ろ');
ok($zip->set_number('2891145')->is_valid_number, '千葉県八街市みどり台');
ok($zip->set_number('2891201')->is_valid_number, '千葉県山武市板川');
ok($zip->set_number('2891202')->is_valid_number, '千葉県山武市中津田');
ok($zip->set_number('2891203')->is_valid_number, '千葉県山武市麻生新田');
ok($zip->set_number('2891204')->is_valid_number, '千葉県山武市戸田');
ok($zip->set_number('2891205')->is_valid_number, '千葉県山武市椎崎');
ok($zip->set_number('2891206')->is_valid_number, '千葉県山武市日向台');
ok($zip->set_number('2891211')->is_valid_number, '千葉県山武市大木');
ok($zip->set_number('2891212')->is_valid_number, '千葉県山武市木原');
ok($zip->set_number('2891213')->is_valid_number, '千葉県山武市雨坪');
ok($zip->set_number('2891214')->is_valid_number, '千葉県山武市森');
ok($zip->set_number('2891215')->is_valid_number, '千葉県山武市矢部');
ok($zip->set_number('2891216')->is_valid_number, '千葉県山武市植草');
ok($zip->set_number('2891217')->is_valid_number, '千葉県山武市下布田');
ok($zip->set_number('2891218')->is_valid_number, '千葉県山武市武勝');
ok($zip->set_number('2891221')->is_valid_number, '千葉県山武市実門');
ok($zip->set_number('2891222')->is_valid_number, '千葉県山武市板中新田');
ok($zip->set_number('2891223')->is_valid_number, '千葉県山武市埴谷');
ok($zip->set_number('2891224')->is_valid_number, '千葉県山武市美杉野');
ok($zip->set_number('2891225')->is_valid_number, '千葉県山武市沖渡');
ok($zip->set_number('2891226')->is_valid_number, '千葉県山武市横田');
ok($zip->set_number('2891300')->is_valid_number, '千葉県山武市以下に掲載がない場合');
ok($zip->set_number('2891301')->is_valid_number, '千葉県山武市木戸');
ok($zip->set_number('2891302')->is_valid_number, '千葉県山武市小松');
ok($zip->set_number('2891303')->is_valid_number, '千葉県山武市松ヶ谷');
ok($zip->set_number('2891304')->is_valid_number, '千葉県山武市井之内');
ok($zip->set_number('2891305')->is_valid_number, '千葉県山武市本須賀');
ok($zip->set_number('2891306')->is_valid_number, '千葉県山武市白幡');
ok($zip->set_number('2891311')->is_valid_number, '千葉県山武市早船');
ok($zip->set_number('2891312')->is_valid_number, '千葉県山武市柴原');
ok($zip->set_number('2891313')->is_valid_number, '千葉県山武市上横地');
ok($zip->set_number('2891314')->is_valid_number, '千葉県山武市下横地');
ok($zip->set_number('2891315')->is_valid_number, '千葉県山武市草深');
ok($zip->set_number('2891316')->is_valid_number, '千葉県山武市五木田');
ok($zip->set_number('2891317')->is_valid_number, '千葉県山武市小泉');
ok($zip->set_number('2891318')->is_valid_number, '千葉県山武市寺崎');
ok($zip->set_number('2891321')->is_valid_number, '千葉県山武市富田');
ok($zip->set_number('2891322')->is_valid_number, '千葉県山武市富田幸谷');
ok($zip->set_number('2891323')->is_valid_number, '千葉県山武市富口');
ok($zip->set_number('2891324')->is_valid_number, '千葉県山武市殿台');
ok($zip->set_number('2891325')->is_valid_number, '千葉県山武市島');
ok($zip->set_number('2891326')->is_valid_number, '千葉県山武市成東');
ok($zip->set_number('2891327')->is_valid_number, '千葉県山武市姫島');
ok($zip->set_number('2891328')->is_valid_number, '千葉県山武市湯坂');
ok($zip->set_number('2891331')->is_valid_number, '千葉県山武市川崎');
ok($zip->set_number('2891332')->is_valid_number, '千葉県山武市親田');
ok($zip->set_number('2891333')->is_valid_number, '千葉県山武市市場');
ok($zip->set_number('2891334')->is_valid_number, '千葉県山武市和田');
ok($zip->set_number('2891335')->is_valid_number, '千葉県山武市板附');
ok($zip->set_number('2891341')->is_valid_number, '千葉県山武市野堀');
ok($zip->set_number('2891342')->is_valid_number, '千葉県山武市嶋戸');
ok($zip->set_number('2891343')->is_valid_number, '千葉県山武市真行寺');
ok($zip->set_number('2891344')->is_valid_number, '千葉県山武市新泉');
ok($zip->set_number('2891345')->is_valid_number, '千葉県山武市津辺');
ok($zip->set_number('2891501')->is_valid_number, '千葉県山武市松尾町山室');
ok($zip->set_number('2891502')->is_valid_number, '千葉県山武市松尾町引越');
ok($zip->set_number('2891503')->is_valid_number, '千葉県山武市松尾町谷津');
ok($zip->set_number('2891504')->is_valid_number, '千葉県山武市松尾町古和');
ok($zip->set_number('2891505')->is_valid_number, '千葉県山武市松尾町金尾');
ok($zip->set_number('2891506')->is_valid_number, '千葉県山武市松尾町上大蔵');
ok($zip->set_number('2891507')->is_valid_number, '千葉県山武市松尾町小川');
ok($zip->set_number('2891511')->is_valid_number, '千葉県山武市松尾町蕪木');
ok($zip->set_number('2891512')->is_valid_number, '千葉県山武市松尾町八田');
ok($zip->set_number('2891513')->is_valid_number, '千葉県山武市松尾町猿尾');
ok($zip->set_number('2891514')->is_valid_number, '千葉県山武市松尾町松尾');
ok($zip->set_number('2891515')->is_valid_number, '千葉県山武市松尾町富士見台');
ok($zip->set_number('2891516')->is_valid_number, '千葉県山武市松尾町田越');
ok($zip->set_number('2891517')->is_valid_number, '千葉県山武市松尾町下大蔵');
ok($zip->set_number('2891521')->is_valid_number, '千葉県山武市松尾町本柏');
ok($zip->set_number('2891522')->is_valid_number, '千葉県山武市松尾町高富');
ok($zip->set_number('2891523')->is_valid_number, '千葉県山武市松尾町五反田');
ok($zip->set_number('2891524')->is_valid_number, '千葉県山武市松尾町祝田');
ok($zip->set_number('2891525')->is_valid_number, '千葉県山武市松尾町本水深');
ok($zip->set_number('2891526')->is_valid_number, '千葉県山武市松尾町水深');
ok($zip->set_number('2891527')->is_valid_number, '千葉県山武市松尾町大堤');
ok($zip->set_number('2891531')->is_valid_number, '千葉県山武市松尾町木刀');
ok($zip->set_number('2891532')->is_valid_number, '千葉県山武市松尾町武野里');
ok($zip->set_number('2891533')->is_valid_number, '千葉県山武市松尾町広根');
ok($zip->set_number('2891534')->is_valid_number, '千葉県山武市松尾町下野');
ok($zip->set_number('2891535')->is_valid_number, '千葉県山武市松尾町折戸');
ok($zip->set_number('2891536')->is_valid_number, '千葉県山武市松尾町下之郷');
ok($zip->set_number('2891537')->is_valid_number, '千葉県山武市松尾町借毛本郷');
ok($zip->set_number('2891600')->is_valid_number, '千葉県山武郡芝山町以下に掲載がない場合');
ok($zip->set_number('2891601')->is_valid_number, '千葉県山武郡芝山町香山新田(その他)');
ok($zip->set_number('2891602')->is_valid_number, '千葉県山武郡芝山町菱田(その他)');
ok($zip->set_number('2891603')->is_valid_number, '千葉県山武郡芝山町大里(その他)');
ok($zip->set_number('2891604')->is_valid_number, '千葉県山武郡芝山町飯櫃');
ok($zip->set_number('2891605')->is_valid_number, '千葉県山武郡芝山町大台');
ok($zip->set_number('2891606')->is_valid_number, '千葉県山武郡芝山町山田');
ok($zip->set_number('2891607')->is_valid_number, '千葉県山武郡芝山町朝倉');
ok($zip->set_number('2891608')->is_valid_number, '千葉県山武郡芝山町岩山(その他)');
ok($zip->set_number('2891611')->is_valid_number, '千葉県山武郡芝山町小原子');
ok($zip->set_number('2891612')->is_valid_number, '千葉県山武郡芝山町上吹入');
ok($zip->set_number('2891613')->is_valid_number, '千葉県山武郡芝山町下吹入');
ok($zip->set_number('2891614')->is_valid_number, '千葉県山武郡芝山町宮崎');
ok($zip->set_number('2891615')->is_valid_number, '千葉県山武郡芝山町境');
ok($zip->set_number('2891616')->is_valid_number, '千葉県山武郡芝山町高谷');
ok($zip->set_number('2891617')->is_valid_number, '千葉県山武郡芝山町殿部田');
ok($zip->set_number('2891618')->is_valid_number, '千葉県山武郡芝山町山中');
ok($zip->set_number('2891619')->is_valid_number, '千葉県山武郡芝山町芝山');
ok($zip->set_number('2891621')->is_valid_number, '千葉県山武郡芝山町牧野');
ok($zip->set_number('2891622')->is_valid_number, '千葉県山武郡芝山町宝馬');
ok($zip->set_number('2891623')->is_valid_number, '千葉県山武郡芝山町高田');
ok($zip->set_number('2891624')->is_valid_number, '千葉県山武郡芝山町小池');
ok($zip->set_number('2891625')->is_valid_number, '千葉県山武郡芝山町新井田');
ok($zip->set_number('2891626')->is_valid_number, '千葉県山武郡芝山町新井田新田');
ok($zip->set_number('2891700')->is_valid_number, '千葉県山武郡横芝光町以下に掲載がない場合');
ok($zip->set_number('2891701')->is_valid_number, '千葉県山武郡横芝光町篠本');
ok($zip->set_number('2891702')->is_valid_number, '千葉県山武郡横芝光町二又');
ok($zip->set_number('2891703')->is_valid_number, '千葉県山武郡横芝光町傍示戸');
ok($zip->set_number('2891704')->is_valid_number, '千葉県山武郡横芝光町富下');
ok($zip->set_number('2891705')->is_valid_number, '千葉県山武郡横芝光町宝米');
ok($zip->set_number('2891706')->is_valid_number, '千葉県山武郡横芝光町市野原');
ok($zip->set_number('2891707')->is_valid_number, '千葉県山武郡横芝光町新井');
ok($zip->set_number('2891708')->is_valid_number, '千葉県山武郡横芝光町篠本根切');
ok($zip->set_number('2891711')->is_valid_number, '千葉県山武郡横芝光町小川台');
ok($zip->set_number('2891712')->is_valid_number, '千葉県山武郡横芝光町台');
ok($zip->set_number('2891713')->is_valid_number, '千葉県山武郡横芝光町小田部');
ok($zip->set_number('2891714')->is_valid_number, '千葉県山武郡横芝光町母子');
ok($zip->set_number('2891715')->is_valid_number, '千葉県山武郡横芝光町芝崎');
ok($zip->set_number('2891716')->is_valid_number, '千葉県山武郡横芝光町芝崎南');
ok($zip->set_number('2891717')->is_valid_number, '千葉県山武郡横芝光町虫生');
ok($zip->set_number('2891721')->is_valid_number, '千葉県山武郡横芝光町谷中');
ok($zip->set_number('2891722')->is_valid_number, '千葉県山武郡横芝光町目篠');
ok($zip->set_number('2891723')->is_valid_number, '千葉県山武郡横芝光町上原');
ok($zip->set_number('2891724')->is_valid_number, '千葉県山武郡横芝光町原方');
ok($zip->set_number('2891725')->is_valid_number, '千葉県山武郡横芝光町尾垂');
ok($zip->set_number('2891726')->is_valid_number, '千葉県山武郡横芝光町木戸');
ok($zip->set_number('2891727')->is_valid_number, '千葉県山武郡横芝光町宮川');
ok($zip->set_number('2891731')->is_valid_number, '千葉県山武郡横芝光町古川');
ok($zip->set_number('2891732')->is_valid_number, '千葉県山武郡横芝光町横芝');
ok($zip->set_number('2891733')->is_valid_number, '千葉県山武郡横芝光町栗山');
ok($zip->set_number('2891734')->is_valid_number, '千葉県山武郡横芝光町北清水');
ok($zip->set_number('2891735')->is_valid_number, '千葉県山武郡横芝光町屋形');
ok($zip->set_number('2891736')->is_valid_number, '千葉県山武郡横芝光町新島');
ok($zip->set_number('2891737')->is_valid_number, '千葉県山武郡横芝光町鳥喰下');
ok($zip->set_number('2891738')->is_valid_number, '千葉県山武郡横芝光町鳥喰上');
ok($zip->set_number('2891739')->is_valid_number, '千葉県山武郡横芝光町鳥喰新田');
ok($zip->set_number('2891741')->is_valid_number, '千葉県山武郡横芝光町中台');
ok($zip->set_number('2891742')->is_valid_number, '千葉県山武郡横芝光町牛熊');
ok($zip->set_number('2891743')->is_valid_number, '千葉県山武郡横芝光町谷台');
ok($zip->set_number('2891744')->is_valid_number, '千葉県山武郡横芝光町木戸台');
ok($zip->set_number('2891745')->is_valid_number, '千葉県山武郡横芝光町小堤');
ok($zip->set_number('2891746')->is_valid_number, '千葉県山武郡横芝光町寺方');
ok($zip->set_number('2891747')->is_valid_number, '千葉県山武郡横芝光町曽根合');
ok($zip->set_number('2891748')->is_valid_number, '千葉県山武郡横芝光町於幾');
ok($zip->set_number('2891749')->is_valid_number, '千葉県山武郡横芝光町両国新田');
ok($zip->set_number('2891751')->is_valid_number, '千葉県山武郡横芝光町長山台');
ok($zip->set_number('2891752')->is_valid_number, '千葉県山武郡横芝光町姥山');
ok($zip->set_number('2891753')->is_valid_number, '千葉県山武郡横芝光町取立');
ok($zip->set_number('2891754')->is_valid_number, '千葉県山武郡横芝光町坂田');
ok($zip->set_number('2891755')->is_valid_number, '千葉県山武郡横芝光町坂田池');
ok($zip->set_number('2891756')->is_valid_number, '千葉県山武郡横芝光町長倉');
ok($zip->set_number('2891757')->is_valid_number, '千葉県山武郡横芝光町遠山');
ok($zip->set_number('2891801')->is_valid_number, '千葉県山武市蓮沼イ');
ok($zip->set_number('2891802')->is_valid_number, '千葉県山武市蓮沼ロ');
ok($zip->set_number('2891803')->is_valid_number, '千葉県山武市蓮沼ホ');
ok($zip->set_number('2891804')->is_valid_number, '千葉県山武市蓮沼平');
ok($zip->set_number('2891805')->is_valid_number, '千葉県山武市蓮沼ニ');
ok($zip->set_number('2891806')->is_valid_number, '千葉県山武市蓮沼ハ');
ok($zip->set_number('2892100')->is_valid_number, '千葉県匝瑳市以下に掲載がない場合');
ok($zip->set_number('2892101')->is_valid_number, '千葉県匝瑳市春海');
ok($zip->set_number('2892102')->is_valid_number, '千葉県匝瑳市椿');
ok($zip->set_number('2892103')->is_valid_number, '千葉県匝瑳市宮本');
ok($zip->set_number('2892104')->is_valid_number, '千葉県匝瑳市生尾');
ok($zip->set_number('2892105')->is_valid_number, '千葉県匝瑳市山桑');
ok($zip->set_number('2892106')->is_valid_number, '千葉県匝瑳市飯塚');
ok($zip->set_number('2892107')->is_valid_number, '千葉県匝瑳市米持');
ok($zip->set_number('2892108')->is_valid_number, '千葉県匝瑳市大寺');
ok($zip->set_number('2892111')->is_valid_number, '千葉県匝瑳市川向');
ok($zip->set_number('2892112')->is_valid_number, '千葉県匝瑳市荻野');
ok($zip->set_number('2892113')->is_valid_number, '千葉県匝瑳市平木');
ok($zip->set_number('2892114')->is_valid_number, '千葉県匝瑳市上谷中');
ok($zip->set_number('2892115')->is_valid_number, '千葉県匝瑳市東谷');
ok($zip->set_number('2892121')->is_valid_number, '千葉県匝瑳市東小笹');
ok($zip->set_number('2892122')->is_valid_number, '千葉県匝瑳市吉崎');
ok($zip->set_number('2892123')->is_valid_number, '千葉県匝瑳市長谷');
ok($zip->set_number('2892124')->is_valid_number, '千葉県匝瑳市登戸');
ok($zip->set_number('2892125')->is_valid_number, '千葉県匝瑳市西小笹');
ok($zip->set_number('2892131')->is_valid_number, '千葉県匝瑳市みどり平');
ok($zip->set_number('2892132')->is_valid_number, '千葉県匝瑳市高');
ok($zip->set_number('2892133')->is_valid_number, '千葉県匝瑳市蕪里');
ok($zip->set_number('2892134')->is_valid_number, '千葉県匝瑳市横須賀');
ok($zip->set_number('2892135')->is_valid_number, '千葉県匝瑳市高野');
ok($zip->set_number('2892136')->is_valid_number, '千葉県匝瑳市時曽根');
ok($zip->set_number('2892141')->is_valid_number, '千葉県匝瑳市八日市場ハ');
ok($zip->set_number('2892142')->is_valid_number, '千葉県匝瑳市八日市場ニ');
ok($zip->set_number('2892143')->is_valid_number, '千葉県匝瑳市八日市場ロ');
ok($zip->set_number('2892144')->is_valid_number, '千葉県匝瑳市八日市場イ');
ok($zip->set_number('2892145')->is_valid_number, '千葉県匝瑳市若潮町');
ok($zip->set_number('2892146')->is_valid_number, '千葉県匝瑳市八日市場ホ');
ok($zip->set_number('2892147')->is_valid_number, '千葉県匝瑳市飯倉');
ok($zip->set_number('2892148')->is_valid_number, '千葉県匝瑳市飯倉台');
ok($zip->set_number('2892149')->is_valid_number, '千葉県匝瑳市貝塚');
ok($zip->set_number('2892151')->is_valid_number, '千葉県匝瑳市大浦');
ok($zip->set_number('2892152')->is_valid_number, '千葉県匝瑳市松山');
ok($zip->set_number('2892153')->is_valid_number, '千葉県匝瑳市中台');
ok($zip->set_number('2892154')->is_valid_number, '千葉県匝瑳市富岡');
ok($zip->set_number('2892155')->is_valid_number, '千葉県匝瑳市八辺');
ok($zip->set_number('2892156')->is_valid_number, '千葉県匝瑳市長岡');
ok($zip->set_number('2892157')->is_valid_number, '千葉県匝瑳市堀之内');
ok($zip->set_number('2892161')->is_valid_number, '千葉県匝瑳市入山崎');
ok($zip->set_number('2892162')->is_valid_number, '千葉県匝瑳市南山崎');
ok($zip->set_number('2892163')->is_valid_number, '千葉県匝瑳市南神崎');
ok($zip->set_number('2892164')->is_valid_number, '千葉県匝瑳市木積');
ok($zip->set_number('2892165')->is_valid_number, '千葉県匝瑳市田久保');
ok($zip->set_number('2892166')->is_valid_number, '千葉県匝瑳市新');
ok($zip->set_number('2892167')->is_valid_number, '千葉県匝瑳市亀崎');
ok($zip->set_number('2892168')->is_valid_number, '千葉県匝瑳市久方');
ok($zip->set_number('2892169')->is_valid_number, '千葉県匝瑳市吉田');
ok($zip->set_number('2892171')->is_valid_number, '千葉県匝瑳市内山');
ok($zip->set_number('2892172')->is_valid_number, '千葉県匝瑳市城下');
ok($zip->set_number('2892173')->is_valid_number, '千葉県匝瑳市飯高');
ok($zip->set_number('2892174')->is_valid_number, '千葉県匝瑳市公崎');
ok($zip->set_number('2892175')->is_valid_number, '千葉県匝瑳市片子');
ok($zip->set_number('2892176')->is_valid_number, '千葉県匝瑳市大堀');
ok($zip->set_number('2892177')->is_valid_number, '千葉県匝瑳市金原');
ok($zip->set_number('2892178')->is_valid_number, '千葉県匝瑳市安久山');
ok($zip->set_number('2892179')->is_valid_number, '千葉県匝瑳市小高');
ok($zip->set_number('2892200')->is_valid_number, '千葉県香取郡多古町以下に掲載がない場合');
ok($zip->set_number('2892231')->is_valid_number, '千葉県香取郡多古町飯笹');
ok($zip->set_number('2892232')->is_valid_number, '千葉県香取郡多古町喜多');
ok($zip->set_number('2892233')->is_valid_number, '千葉県香取郡多古町林');
ok($zip->set_number('2892234')->is_valid_number, '千葉県香取郡多古町五反田');
ok($zip->set_number('2892235')->is_valid_number, '千葉県香取郡多古町間倉');
ok($zip->set_number('2892236')->is_valid_number, '千葉県香取郡多古町一鍬田(その他)');
ok($zip->set_number('2892241')->is_valid_number, '千葉県香取郡多古町多古');
ok($zip->set_number('2892242')->is_valid_number, '千葉県香取郡多古町染井');
ok($zip->set_number('2892243')->is_valid_number, '千葉県香取郡多古町島');
ok($zip->set_number('2892244')->is_valid_number, '千葉県香取郡多古町船越');
ok($zip->set_number('2892245')->is_valid_number, '千葉県香取郡多古町牛尾');
ok($zip->set_number('2892246')->is_valid_number, '千葉県香取郡多古町千田');
ok($zip->set_number('2892247')->is_valid_number, '千葉県香取郡多古町水戸');
ok($zip->set_number('2892251')->is_valid_number, '千葉県香取郡多古町北中');
ok($zip->set_number('2892252')->is_valid_number, '千葉県香取郡多古町南和田');
ok($zip->set_number('2892253')->is_valid_number, '千葉県香取郡多古町南借当');
ok($zip->set_number('2892254')->is_valid_number, '千葉県香取郡多古町東輝');
ok($zip->set_number('2892255')->is_valid_number, '千葉県香取郡多古町南並木');
ok($zip->set_number('2892256')->is_valid_number, '千葉県香取郡多古町中村新田');
ok($zip->set_number('2892257')->is_valid_number, '千葉県香取郡多古町南中');
ok($zip->set_number('2892301')->is_valid_number, '千葉県香取郡多古町出沼');
ok($zip->set_number('2892302')->is_valid_number, '千葉県香取郡多古町桧木');
ok($zip->set_number('2892303')->is_valid_number, '千葉県香取郡多古町大門');
ok($zip->set_number('2892304')->is_valid_number, '千葉県香取郡多古町高津原');
ok($zip->set_number('2892305')->is_valid_number, '千葉県香取郡多古町大高');
ok($zip->set_number('2892306')->is_valid_number, '千葉県香取郡多古町十余三');
ok($zip->set_number('2892311')->is_valid_number, '千葉県香取郡多古町本三倉');
ok($zip->set_number('2892312')->is_valid_number, '千葉県香取郡多古町谷三倉');
ok($zip->set_number('2892313')->is_valid_number, '千葉県香取郡多古町次浦');
ok($zip->set_number('2892314')->is_valid_number, '千葉県香取郡多古町西古内');
ok($zip->set_number('2892315')->is_valid_number, '千葉県香取郡多古町御所台');
ok($zip->set_number('2892316')->is_valid_number, '千葉県香取郡多古町寺作');
ok($zip->set_number('2892317')->is_valid_number, '千葉県香取郡多古町井戸山');
ok($zip->set_number('2892321')->is_valid_number, '千葉県香取郡多古町東松崎');
ok($zip->set_number('2892322')->is_valid_number, '千葉県香取郡多古町坂');
ok($zip->set_number('2892323')->is_valid_number, '千葉県香取郡多古町方田');
ok($zip->set_number('2892324')->is_valid_number, '千葉県香取郡多古町川島');
ok($zip->set_number('2892325')->is_valid_number, '千葉県香取郡多古町南玉造');
ok($zip->set_number('2892500')->is_valid_number, '千葉県旭市以下に掲載がない場合');
ok($zip->set_number('2892501')->is_valid_number, '千葉県旭市新町');
ok($zip->set_number('2892502')->is_valid_number, '千葉県旭市琴田(その他)');
ok($zip->set_number('2892503')->is_valid_number, '千葉県旭市江ケ崎(その他)');
ok($zip->set_number('2892504')->is_valid_number, '千葉県旭市ニ');
ok($zip->set_number('2892505')->is_valid_number, '千葉県旭市鎌数');
ok($zip->set_number('2892511')->is_valid_number, '千葉県旭市イ');
ok($zip->set_number('2892512')->is_valid_number, '千葉県旭市東足洗');
ok($zip->set_number('2892513')->is_valid_number, '千葉県旭市野中');
ok($zip->set_number('2892514')->is_valid_number, '千葉県旭市椎名内');
ok($zip->set_number('2892515')->is_valid_number, '千葉県旭市西足洗');
ok($zip->set_number('2892516')->is_valid_number, '千葉県旭市ロ');
ok($zip->set_number('2892521')->is_valid_number, '千葉県旭市ハ');
ok($zip->set_number('2892522')->is_valid_number, '千葉県旭市足川');
ok($zip->set_number('2892523')->is_valid_number, '千葉県旭市中谷里');
ok($zip->set_number('2892524')->is_valid_number, '千葉県旭市神宮寺');
ok($zip->set_number('2892525')->is_valid_number, '千葉県旭市仁玉');
ok($zip->set_number('2892531')->is_valid_number, '千葉県旭市井戸野');
ok($zip->set_number('2892532')->is_valid_number, '千葉県旭市駒込');
ok($zip->set_number('2892533')->is_valid_number, '千葉県旭市大塚原');
ok($zip->set_number('2892534')->is_valid_number, '千葉県旭市泉川');
ok($zip->set_number('2892535')->is_valid_number, '千葉県旭市川口');
ok($zip->set_number('2892601')->is_valid_number, '千葉県旭市松ケ谷');
ok($zip->set_number('2892602')->is_valid_number, '千葉県旭市岩井');
ok($zip->set_number('2892603')->is_valid_number, '千葉県旭市大間手');
ok($zip->set_number('2892604')->is_valid_number, '千葉県旭市高生');
ok($zip->set_number('2892605')->is_valid_number, '千葉県旭市琴田(85~160、1386~1815、2593~2820、');
ok($zip->set_number('2892605')->is_valid_number, '千葉県旭市3598~3614番地)');
ok($zip->set_number('2892606')->is_valid_number, '千葉県旭市清滝');
ok($zip->set_number('2892607')->is_valid_number, '千葉県旭市幾世');
ok($zip->set_number('2892611')->is_valid_number, '千葉県旭市倉橋');
ok($zip->set_number('2892612')->is_valid_number, '千葉県旭市蛇園');
ok($zip->set_number('2892613')->is_valid_number, '千葉県旭市後草');
ok($zip->set_number('2892614')->is_valid_number, '千葉県旭市江ケ崎(12~22、127~140、1709、1723-3、');
ok($zip->set_number('2892614')->is_valid_number, '千葉県旭市1728-4番地)');
ok($zip->set_number('2892615')->is_valid_number, '千葉県旭市長尾');
ok($zip->set_number('2892616')->is_valid_number, '千葉県旭市見広');
ok($zip->set_number('2892701')->is_valid_number, '千葉県旭市狢野');
ok($zip->set_number('2892702')->is_valid_number, '千葉県旭市塙');
ok($zip->set_number('2892703')->is_valid_number, '千葉県旭市八木');
ok($zip->set_number('2892704')->is_valid_number, '千葉県旭市上永井');
ok($zip->set_number('2892705')->is_valid_number, '千葉県旭市飯岡');
ok($zip->set_number('2892706')->is_valid_number, '千葉県旭市下永井');
ok($zip->set_number('2892707')->is_valid_number, '千葉県旭市行内');
ok($zip->set_number('2892708')->is_valid_number, '千葉県旭市平松');
ok($zip->set_number('2892711')->is_valid_number, '千葉県旭市岩崎');
ok($zip->set_number('2892712')->is_valid_number, '千葉県旭市横根');
ok($zip->set_number('2892713')->is_valid_number, '千葉県旭市萩園');
ok($zip->set_number('2892714')->is_valid_number, '千葉県旭市三川');
ok($zip->set_number('2892715')->is_valid_number, '千葉県旭市権田沼新田');
ok($zip->set_number('2893181')->is_valid_number, '千葉県匝瑳市野手');
ok($zip->set_number('2893182')->is_valid_number, '千葉県匝瑳市今泉');
ok($zip->set_number('2893183')->is_valid_number, '千葉県匝瑳市新堀');
ok($zip->set_number('2893184')->is_valid_number, '千葉県匝瑳市栢田');
ok($zip->set_number('2893185')->is_valid_number, '千葉県匝瑳市堀川');
ok($zip->set_number('2893186')->is_valid_number, '千葉県匝瑳市川辺');
ok($zip->set_number('2900000')->is_valid_number, '千葉県市原市以下に掲載がない場合');
ok($zip->set_number('2900001')->is_valid_number, '千葉県市原市草刈(その他)');
ok($zip->set_number('2900002')->is_valid_number, '千葉県市原市大厩');
ok($zip->set_number('2900003')->is_valid_number, '千葉県市原市辰巳台東');
ok($zip->set_number('2900004')->is_valid_number, '千葉県市原市辰巳台西');
ok($zip->set_number('2900005')->is_valid_number, '千葉県市原市山木');
ok($zip->set_number('2900006')->is_valid_number, '千葉県市原市若宮');
ok($zip->set_number('2900007')->is_valid_number, '千葉県市原市菊間');
ok($zip->set_number('2900008')->is_valid_number, '千葉県市原市古市場');
ok($zip->set_number('2900011')->is_valid_number, '千葉県市原市能満');
ok($zip->set_number('2900012')->is_valid_number, '千葉県市原市藤井');
ok($zip->set_number('2900013')->is_valid_number, '千葉県市原市郡本');
ok($zip->set_number('2900014')->is_valid_number, '千葉県市原市西野谷');
ok($zip->set_number('2900015')->is_valid_number, '千葉県市原市市原');
ok($zip->set_number('2900016')->is_valid_number, '千葉県市原市門前');
ok($zip->set_number('2900021')->is_valid_number, '千葉県市原市山田橋');
ok($zip->set_number('2900022')->is_valid_number, '千葉県市原市西広');
ok($zip->set_number('2900023')->is_valid_number, '千葉県市原市惣社');
ok($zip->set_number('2900024')->is_valid_number, '千葉県市原市根田');
ok($zip->set_number('2900025')->is_valid_number, '千葉県市原市加茂');
ok($zip->set_number('2900026')->is_valid_number, '千葉県市原市諏訪');
ok($zip->set_number('2900031')->is_valid_number, '千葉県市原市村上');
ok($zip->set_number('2900032')->is_valid_number, '千葉県市原市廿五里');
ok($zip->set_number('2900033')->is_valid_number, '千葉県市原市野毛');
ok($zip->set_number('2900034')->is_valid_number, '千葉県市原市島野');
ok($zip->set_number('2900035')->is_valid_number, '千葉県市原市松ケ島');
ok($zip->set_number('2900036')->is_valid_number, '千葉県市原市松ケ島西');
ok($zip->set_number('2900037')->is_valid_number, '千葉県市原市飯沼');
ok($zip->set_number('2900038')->is_valid_number, '千葉県市原市五井西');
ok($zip->set_number('2900041')->is_valid_number, '千葉県市原市玉前');
ok($zip->set_number('2900042')->is_valid_number, '千葉県市原市出津');
ok($zip->set_number('2900043')->is_valid_number, '千葉県市原市出津西');
ok($zip->set_number('2900044')->is_valid_number, '千葉県市原市玉前西');
ok($zip->set_number('2900045')->is_valid_number, '千葉県市原市五井南海岸');
ok($zip->set_number('2900046')->is_valid_number, '千葉県市原市岩崎西');
ok($zip->set_number('2900047')->is_valid_number, '千葉県市原市岩崎');
ok($zip->set_number('2900050')->is_valid_number, '千葉県市原市更級');
ok($zip->set_number('2900051')->is_valid_number, '千葉県市原市君塚');
ok($zip->set_number('2900052')->is_valid_number, '千葉県市原市岩野見');
ok($zip->set_number('2900053')->is_valid_number, '千葉県市原市平田');
ok($zip->set_number('2900054')->is_valid_number, '千葉県市原市五井中央東');
ok($zip->set_number('2900055')->is_valid_number, '千葉県市原市五井東');
ok($zip->set_number('2900056')->is_valid_number, '千葉県市原市五井');
ok($zip->set_number('2900057')->is_valid_number, '千葉県市原市五井金杉');
ok($zip->set_number('2900058')->is_valid_number, '千葉県市原市五井海岸');
ok($zip->set_number('2900059')->is_valid_number, '千葉県市原市白金町');
ok($zip->set_number('2900061')->is_valid_number, '千葉県市原市八幡石塚');
ok($zip->set_number('2900062')->is_valid_number, '千葉県市原市八幡');
ok($zip->set_number('2900063')->is_valid_number, '千葉県市原市旭五所');
ok($zip->set_number('2900064')->is_valid_number, '千葉県市原市東五所');
ok($zip->set_number('2900065')->is_valid_number, '千葉県市原市西五所');
ok($zip->set_number('2900066')->is_valid_number, '千葉県市原市五所');
ok($zip->set_number('2900067')->is_valid_number, '千葉県市原市八幡海岸通');
ok($zip->set_number('2900068')->is_valid_number, '千葉県市原市八幡浦');
ok($zip->set_number('2900069')->is_valid_number, '千葉県市原市八幡北町');
ok($zip->set_number('2900071')->is_valid_number, '千葉県市原市北国分寺台');
ok($zip->set_number('2900072')->is_valid_number, '千葉県市原市西国分寺台');
ok($zip->set_number('2900073')->is_valid_number, '千葉県市原市国分寺台中央');
ok($zip->set_number('2900074')->is_valid_number, '千葉県市原市東国分寺台');
ok($zip->set_number('2900075')->is_valid_number, '千葉県市原市南国分寺台');
ok($zip->set_number('2900081')->is_valid_number, '千葉県市原市五井中央西');
ok($zip->set_number('2900082')->is_valid_number, '千葉県市原市五井中央南');
ok($zip->set_number('2900141')->is_valid_number, '千葉県市原市ちはら台東');
ok($zip->set_number('2900142')->is_valid_number, '千葉県市原市ちはら台南');
ok($zip->set_number('2900143')->is_valid_number, '千葉県市原市ちはら台西');
ok($zip->set_number('2900151')->is_valid_number, '千葉県市原市瀬又');
ok($zip->set_number('2900152')->is_valid_number, '千葉県市原市高田');
ok($zip->set_number('2900153')->is_valid_number, '千葉県市原市中野');
ok($zip->set_number('2900154')->is_valid_number, '千葉県市原市下野');
ok($zip->set_number('2900155')->is_valid_number, '千葉県市原市番場');
ok($zip->set_number('2900156')->is_valid_number, '千葉県市原市草刈(1656~1999)');
ok($zip->set_number('2900157')->is_valid_number, '千葉県市原市押沼');
ok($zip->set_number('2900161')->is_valid_number, '千葉県市原市高倉');
ok($zip->set_number('2900162')->is_valid_number, '千葉県市原市金剛地');
ok($zip->set_number('2900163')->is_valid_number, '千葉県市原市東国吉');
ok($zip->set_number('2900164')->is_valid_number, '千葉県市原市奈良');
ok($zip->set_number('2900165')->is_valid_number, '千葉県市原市古都辺');
ok($zip->set_number('2900166')->is_valid_number, '千葉県市原市犬成');
ok($zip->set_number('2900167')->is_valid_number, '千葉県市原市喜多');
ok($zip->set_number('2900168')->is_valid_number, '千葉県市原市永吉');
ok($zip->set_number('2900170')->is_valid_number, '千葉県市原市うるいど南');
ok($zip->set_number('2900171')->is_valid_number, '千葉県市原市潤井戸');
ok($zip->set_number('2900172')->is_valid_number, '千葉県市原市大作');
ok($zip->set_number('2900173')->is_valid_number, '千葉県市原市滝口');
ok($zip->set_number('2900174')->is_valid_number, '千葉県市原市勝間');
ok($zip->set_number('2900175')->is_valid_number, '千葉県市原市葉木');
ok($zip->set_number('2900176')->is_valid_number, '千葉県市原市小田部');
ok($zip->set_number('2900177')->is_valid_number, '千葉県市原市荻作');
ok($zip->set_number('2900178')->is_valid_number, '千葉県市原市神崎');
ok($zip->set_number('2900179')->is_valid_number, '千葉県市原市久々津');
ok($zip->set_number('2900201')->is_valid_number, '千葉県市原市山倉');
ok($zip->set_number('2900202')->is_valid_number, '千葉県市原市福増');
ok($zip->set_number('2900203')->is_valid_number, '千葉県市原市武士');
ok($zip->set_number('2900204')->is_valid_number, '千葉県市原市磯ケ谷');
ok($zip->set_number('2900205')->is_valid_number, '千葉県市原市山田');
ok($zip->set_number('2900206')->is_valid_number, '千葉県市原市新堀');
ok($zip->set_number('2900207')->is_valid_number, '千葉県市原市海士有木');
ok($zip->set_number('2900208')->is_valid_number, '千葉県市原市大坪');
ok($zip->set_number('2900209')->is_valid_number, '千葉県市原市権現堂');
ok($zip->set_number('2900211')->is_valid_number, '千葉県市原市大桶');
ok($zip->set_number('2900212')->is_valid_number, '千葉県市原市新巻');
ok($zip->set_number('2900213')->is_valid_number, '千葉県市原市川在');
ok($zip->set_number('2900214')->is_valid_number, '千葉県市原市櫃挾');
ok($zip->set_number('2900215')->is_valid_number, '千葉県市原市土宇');
ok($zip->set_number('2900216')->is_valid_number, '千葉県市原市二日市場');
ok($zip->set_number('2900217')->is_valid_number, '千葉県市原市松崎');
ok($zip->set_number('2900221')->is_valid_number, '千葉県市原市馬立');
ok($zip->set_number('2900222')->is_valid_number, '千葉県市原市上原');
ok($zip->set_number('2900223')->is_valid_number, '千葉県市原市妙香');
ok($zip->set_number('2900224')->is_valid_number, '千葉県市原市奉免');
ok($zip->set_number('2900225')->is_valid_number, '千葉県市原市牛久');
ok($zip->set_number('2900226')->is_valid_number, '千葉県市原市中');
ok($zip->set_number('2900227')->is_valid_number, '千葉県市原市藪');
ok($zip->set_number('2900228')->is_valid_number, '千葉県市原市岩');
ok($zip->set_number('2900229')->is_valid_number, '千葉県市原市佐是');
ok($zip->set_number('2900231')->is_valid_number, '千葉県市原市西国吉');
ok($zip->set_number('2900232')->is_valid_number, '千葉県市原市皆吉');
ok($zip->set_number('2900233')->is_valid_number, '千葉県市原市金沢');
ok($zip->set_number('2900234')->is_valid_number, '千葉県市原市大蔵');
ok($zip->set_number('2900235')->is_valid_number, '千葉県市原市栢橋');
ok($zip->set_number('2900236')->is_valid_number, '千葉県市原市寺谷');
ok($zip->set_number('2900241')->is_valid_number, '千葉県市原市風戸');
ok($zip->set_number('2900242')->is_valid_number, '千葉県市原市中高根');
ok($zip->set_number('2900243')->is_valid_number, '千葉県市原市上高根');
ok($zip->set_number('2900244')->is_valid_number, '千葉県市原市南岩崎');
ok($zip->set_number('2900251')->is_valid_number, '千葉県市原市浅井小向');
ok($zip->set_number('2900252')->is_valid_number, '千葉県市原市相川');
ok($zip->set_number('2900253')->is_valid_number, '千葉県市原市安須');
ok($zip->set_number('2900254')->is_valid_number, '千葉県市原市高坂');
ok($zip->set_number('2900255')->is_valid_number, '千葉県市原市光風台');
ok($zip->set_number('2900256')->is_valid_number, '千葉県市原市引田');
ok($zip->set_number('2900257')->is_valid_number, '千葉県市原市新生');
ok($zip->set_number('2900258')->is_valid_number, '千葉県市原市神代');
ok($zip->set_number('2900259')->is_valid_number, '千葉県市原市分目');
ok($zip->set_number('2900261')->is_valid_number, '千葉県市原市西野');
ok($zip->set_number('2900262')->is_valid_number, '千葉県市原市糸久');
ok($zip->set_number('2900263')->is_valid_number, '千葉県市原市十五沢');
ok($zip->set_number('2900264')->is_valid_number, '千葉県市原市宮原');
ok($zip->set_number('2900265')->is_valid_number, '千葉県市原市今富');
ok($zip->set_number('2900266')->is_valid_number, '千葉県市原市海保');
ok($zip->set_number('2900267')->is_valid_number, '千葉県市原市町田');
ok($zip->set_number('2900268')->is_valid_number, '千葉県市原市柳原');
ok($zip->set_number('2900269')->is_valid_number, '千葉県市原市小折');
ok($zip->set_number('2900501')->is_valid_number, '千葉県市原市米沢');
ok($zip->set_number('2900502')->is_valid_number, '千葉県市原市真ケ谷');
ok($zip->set_number('2900503')->is_valid_number, '千葉県市原市宿');
ok($zip->set_number('2900504')->is_valid_number, '千葉県市原市堀越');
ok($zip->set_number('2900505')->is_valid_number, '千葉県市原市市場');
ok($zip->set_number('2900506')->is_valid_number, '千葉県市原市島田');
ok($zip->set_number('2900507')->is_valid_number, '千葉県市原市原田');
ok($zip->set_number('2900508')->is_valid_number, '千葉県市原市江子田');
ok($zip->set_number('2900509')->is_valid_number, '千葉県市原市安久谷');
ok($zip->set_number('2900511')->is_valid_number, '千葉県市原市石川');
ok($zip->set_number('2900512')->is_valid_number, '千葉県市原市鶴舞');
ok($zip->set_number('2900513')->is_valid_number, '千葉県市原市奥野');
ok($zip->set_number('2900514')->is_valid_number, '千葉県市原市水沢');
ok($zip->set_number('2900515')->is_valid_number, '千葉県市原市田尾');
ok($zip->set_number('2900516')->is_valid_number, '千葉県市原市池和田');
ok($zip->set_number('2900517')->is_valid_number, '千葉県市原市矢田');
ok($zip->set_number('2900518')->is_valid_number, '千葉県市原市下矢田');
ok($zip->set_number('2900521')->is_valid_number, '千葉県市原市山小川');
ok($zip->set_number('2900522')->is_valid_number, '千葉県市原市新井');
ok($zip->set_number('2900523')->is_valid_number, '千葉県市原市吉沢');
ok($zip->set_number('2900524')->is_valid_number, '千葉県市原市平蔵');
ok($zip->set_number('2900525')->is_valid_number, '千葉県市原市米原');
ok($zip->set_number('2900526')->is_valid_number, '千葉県市原市小草畑');
ok($zip->set_number('2900527')->is_valid_number, '千葉県市原市月出');
ok($zip->set_number('2900528')->is_valid_number, '千葉県市原市古敷谷');
ok($zip->set_number('2900529')->is_valid_number, '千葉県市原市小谷田');
ok($zip->set_number('2900531')->is_valid_number, '千葉県市原市国本');
ok($zip->set_number('2900532')->is_valid_number, '千葉県市原市大久保');
ok($zip->set_number('2900533')->is_valid_number, '千葉県市原市折津');
ok($zip->set_number('2900534')->is_valid_number, '千葉県市原市石神');
ok($zip->set_number('2900535')->is_valid_number, '千葉県市原市朝生原');
ok($zip->set_number('2900536')->is_valid_number, '千葉県市原市戸面');
ok($zip->set_number('2900537')->is_valid_number, '千葉県市原市石塚');
ok($zip->set_number('2900538')->is_valid_number, '千葉県市原市柳川');
ok($zip->set_number('2900539')->is_valid_number, '千葉県市原市菅野');
ok($zip->set_number('2900541')->is_valid_number, '千葉県市原市平野');
ok($zip->set_number('2900542')->is_valid_number, '千葉県市原市大戸');
ok($zip->set_number('2900543')->is_valid_number, '千葉県市原市飯給');
ok($zip->set_number('2900544')->is_valid_number, '千葉県市原市徳氏');
ok($zip->set_number('2900545')->is_valid_number, '千葉県市原市田淵旧日竹');
ok($zip->set_number('2900546')->is_valid_number, '千葉県市原市田淵');
ok($zip->set_number('2900547')->is_valid_number, '千葉県市原市月崎');
ok($zip->set_number('2900548')->is_valid_number, '千葉県市原市柿木台');
ok($zip->set_number('2900549')->is_valid_number, '千葉県市原市万田野');
ok($zip->set_number('2900551')->is_valid_number, '千葉県市原市外部田');
ok($zip->set_number('2900552')->is_valid_number, '千葉県市原市久保');
ok($zip->set_number('2900553')->is_valid_number, '千葉県市原市大和田');
ok($zip->set_number('2900554')->is_valid_number, '千葉県市原市不入');
ok($zip->set_number('2900555')->is_valid_number, '千葉県市原市高滝');
ok($zip->set_number('2900556')->is_valid_number, '千葉県市原市本郷');
ok($zip->set_number('2900557')->is_valid_number, '千葉県市原市養老');
ok($zip->set_number('2900558')->is_valid_number, '千葉県市原市山口');
ok($zip->set_number('2900559')->is_valid_number, '千葉県市原市駒込');
ok($zip->set_number('2920000')->is_valid_number, '千葉県木更津市以下に掲載がない場合');
ok($zip->set_number('2920001')->is_valid_number, '千葉県木更津市牛込');
ok($zip->set_number('2920002')->is_valid_number, '千葉県木更津市中野');
ok($zip->set_number('2920003')->is_valid_number, '千葉県木更津市万石');
ok($zip->set_number('2920004')->is_valid_number, '千葉県木更津市久津間');
ok($zip->set_number('2920005')->is_valid_number, '千葉県木更津市畔戸');
ok($zip->set_number('2920006')->is_valid_number, '千葉県木更津市北浜町');
ok($zip->set_number('2920007')->is_valid_number, '千葉県木更津市瓜倉');
ok($zip->set_number('2920008')->is_valid_number, '千葉県木更津市中島');
ok($zip->set_number('2920009')->is_valid_number, '千葉県木更津市金田東');
ok($zip->set_number('2920011')->is_valid_number, '千葉県木更津市牛袋野');
ok($zip->set_number('2920012')->is_valid_number, '千葉県木更津市牛袋');
ok($zip->set_number('2920013')->is_valid_number, '千葉県木更津市若葉町');
ok($zip->set_number('2920014')->is_valid_number, '千葉県木更津市高柳');
ok($zip->set_number('2920015')->is_valid_number, '千葉県木更津市本郷');
ok($zip->set_number('2920016')->is_valid_number, '千葉県木更津市高砂');
ok($zip->set_number('2920021')->is_valid_number, '千葉県木更津市有吉');
ok($zip->set_number('2920022')->is_valid_number, '千葉県木更津市上望陀');
ok($zip->set_number('2920023')->is_valid_number, '千葉県木更津市下望陀');
ok($zip->set_number('2920024')->is_valid_number, '千葉県木更津市大寺');
ok($zip->set_number('2920025')->is_valid_number, '千葉県木更津市十日市場');
ok($zip->set_number('2920026')->is_valid_number, '千葉県木更津市井尻');
ok($zip->set_number('2920027')->is_valid_number, '千葉県木更津市曽根');
ok($zip->set_number('2920031')->is_valid_number, '千葉県木更津市椿');
ok($zip->set_number('2920032')->is_valid_number, '千葉県木更津市笹子');
ok($zip->set_number('2920033')->is_valid_number, '千葉県木更津市犬成');
ok($zip->set_number('2920034')->is_valid_number, '千葉県木更津市伊豆島');
ok($zip->set_number('2920035')->is_valid_number, '千葉県木更津市中尾');
ok($zip->set_number('2920036')->is_valid_number, '千葉県木更津市菅生');
ok($zip->set_number('2920037')->is_valid_number, '千葉県木更津市日の出町');
ok($zip->set_number('2920038')->is_valid_number, '千葉県木更津市ほたる野');
ok($zip->set_number('2920041')->is_valid_number, '千葉県木更津市清見台東');
ok($zip->set_number('2920042')->is_valid_number, '千葉県木更津市清見台南');
ok($zip->set_number('2920043')->is_valid_number, '千葉県木更津市東太田');
ok($zip->set_number('2920044')->is_valid_number, '千葉県木更津市太田');
ok($zip->set_number('2920045')->is_valid_number, '千葉県木更津市清見台');
ok($zip->set_number('2920051')->is_valid_number, '千葉県木更津市清川');
ok($zip->set_number('2920052')->is_valid_number, '千葉県木更津市祇園');
ok($zip->set_number('2920053')->is_valid_number, '千葉県木更津市永井作');
ok($zip->set_number('2920054')->is_valid_number, '千葉県木更津市長須賀');
ok($zip->set_number('2920055')->is_valid_number, '千葉県木更津市朝日');
ok($zip->set_number('2920056')->is_valid_number, '千葉県木更津市木更津');
ok($zip->set_number('2920057')->is_valid_number, '千葉県木更津市東中央');
ok($zip->set_number('2920061')->is_valid_number, '千葉県木更津市岩根');
ok($zip->set_number('2920062')->is_valid_number, '千葉県木更津市西岩根');
ok($zip->set_number('2920063')->is_valid_number, '千葉県木更津市江川');
ok($zip->set_number('2920064')->is_valid_number, '千葉県木更津市中里');
ok($zip->set_number('2920065')->is_valid_number, '千葉県木更津市吾妻');
ok($zip->set_number('2920066')->is_valid_number, '千葉県木更津市新宿');
ok($zip->set_number('2920067')->is_valid_number, '千葉県木更津市中央');
ok($zip->set_number('2920071')->is_valid_number, '千葉県木更津市中島地先海ほたる');
ok($zip->set_number('2920201')->is_valid_number, '千葉県木更津市真里谷');
ok($zip->set_number('2920202')->is_valid_number, '千葉県木更津市茅野七曲');
ok($zip->set_number('2920203')->is_valid_number, '千葉県木更津市山本七曲');
ok($zip->set_number('2920204')->is_valid_number, '千葉県木更津市茅野');
ok($zip->set_number('2920205')->is_valid_number, '千葉県木更津市下郡');
ok($zip->set_number('2920206')->is_valid_number, '千葉県木更津市佐野');
ok($zip->set_number('2920207')->is_valid_number, '千葉県木更津市田川');
ok($zip->set_number('2920211')->is_valid_number, '千葉県木更津市大稲');
ok($zip->set_number('2920212')->is_valid_number, '千葉県木更津市真里');
ok($zip->set_number('2920213')->is_valid_number, '千葉県木更津市下内橋');
ok($zip->set_number('2920214')->is_valid_number, '千葉県木更津市戸国');
ok($zip->set_number('2920215')->is_valid_number, '千葉県木更津市上根岸');
ok($zip->set_number('2920216')->is_valid_number, '千葉県木更津市根岸');
ok($zip->set_number('2920217')->is_valid_number, '千葉県木更津市下宮田');
ok($zip->set_number('2920401')->is_valid_number, '千葉県君津市山本');
ok($zip->set_number('2920402')->is_valid_number, '千葉県君津市西原');
ok($zip->set_number('2920403')->is_valid_number, '千葉県君津市三田');
ok($zip->set_number('2920404')->is_valid_number, '千葉県君津市賀恵渕');
ok($zip->set_number('2920411')->is_valid_number, '千葉県君津市長谷川');
ok($zip->set_number('2920412')->is_valid_number, '千葉県君津市小櫃台');
ok($zip->set_number('2920413')->is_valid_number, '千葉県君津市吉野');
ok($zip->set_number('2920414')->is_valid_number, '千葉県君津市久留里大谷');
ok($zip->set_number('2920415')->is_valid_number, '千葉県君津市川谷');
ok($zip->set_number('2920416')->is_valid_number, '千葉県君津市小市部');
ok($zip->set_number('2920421')->is_valid_number, '千葉県君津市久留里市場');
ok($zip->set_number('2920422')->is_valid_number, '千葉県君津市久留里');
ok($zip->set_number('2920423')->is_valid_number, '千葉県君津市久留里大和田');
ok($zip->set_number('2920431')->is_valid_number, '千葉県君津市怒田');
ok($zip->set_number('2920432')->is_valid_number, '千葉県君津市浦田');
ok($zip->set_number('2920433')->is_valid_number, '千葉県君津市芋窪');
ok($zip->set_number('2920434')->is_valid_number, '千葉県君津市向郷');
ok($zip->set_number('2920435')->is_valid_number, '千葉県君津市栗坪');
ok($zip->set_number('2920441')->is_valid_number, '千葉県君津市戸崎');
ok($zip->set_number('2920442')->is_valid_number, '千葉県君津市岩出');
ok($zip->set_number('2920443')->is_valid_number, '千葉県君津市寺沢');
ok($zip->set_number('2920444')->is_valid_number, '千葉県君津市富田');
ok($zip->set_number('2920445')->is_valid_number, '千葉県君津市愛宕');
ok($zip->set_number('2920451')->is_valid_number, '千葉県君津市末吉');
ok($zip->set_number('2920452')->is_valid_number, '千葉県君津市上新田');
ok($zip->set_number('2920453')->is_valid_number, '千葉県君津市箕輪');
ok($zip->set_number('2920454')->is_valid_number, '千葉県君津市青柳');
ok($zip->set_number('2920455')->is_valid_number, '千葉県君津市俵田');
ok($zip->set_number('2920501')->is_valid_number, '千葉県君津市山滝野');
ok($zip->set_number('2920502')->is_valid_number, '千葉県君津市平山');
ok($zip->set_number('2920503')->is_valid_number, '千葉県君津市広岡');
ok($zip->set_number('2920511')->is_valid_number, '千葉県君津市大坂');
ok($zip->set_number('2920512')->is_valid_number, '千葉県君津市大戸見');
ok($zip->set_number('2920513')->is_valid_number, '千葉県君津市加名盛');
ok($zip->set_number('2920514')->is_valid_number, '千葉県君津市大戸見旧名殿');
ok($zip->set_number('2920515')->is_valid_number, '千葉県君津市柳城');
ok($zip->set_number('2920516')->is_valid_number, '千葉県君津市高水');
ok($zip->set_number('2920521')->is_valid_number, '千葉県君津市利根');
ok($zip->set_number('2920522')->is_valid_number, '千葉県君津市大中');
ok($zip->set_number('2920523')->is_valid_number, '千葉県君津市豊田');
ok($zip->set_number('2920524')->is_valid_number, '千葉県君津市川俣');
ok($zip->set_number('2920525')->is_valid_number, '千葉県君津市草川原');
ok($zip->set_number('2920526')->is_valid_number, '千葉県君津市笹');
ok($zip->set_number('2920527')->is_valid_number, '千葉県君津市香木原');
ok($zip->set_number('2920531')->is_valid_number, '千葉県君津市藤林');
ok($zip->set_number('2920532')->is_valid_number, '千葉県君津市坂畑');
ok($zip->set_number('2920533')->is_valid_number, '千葉県君津市折木沢');
ok($zip->set_number('2920534')->is_valid_number, '千葉県君津市滝原');
ok($zip->set_number('2920535')->is_valid_number, '千葉県君津市釜生');
ok($zip->set_number('2920536')->is_valid_number, '千葉県君津市蔵玉');
ok($zip->set_number('2920537')->is_valid_number, '千葉県君津市黄和田畑');
ok($zip->set_number('2920801')->is_valid_number, '千葉県木更津市請西');
ok($zip->set_number('2920802')->is_valid_number, '千葉県木更津市真舟');
ok($zip->set_number('2920803')->is_valid_number, '千葉県木更津市幸町');
ok($zip->set_number('2920804')->is_valid_number, '千葉県木更津市文京');
ok($zip->set_number('2920805')->is_valid_number, '千葉県木更津市大和');
ok($zip->set_number('2920806')->is_valid_number, '千葉県木更津市請西東');
ok($zip->set_number('2920807')->is_valid_number, '千葉県木更津市請西南');
ok($zip->set_number('2920808')->is_valid_number, '千葉県木更津市千束台');
ok($zip->set_number('2920811')->is_valid_number, '千葉県木更津市草敷');
ok($zip->set_number('2920812')->is_valid_number, '千葉県木更津市矢那');
ok($zip->set_number('2920813')->is_valid_number, '千葉県木更津市上烏田');
ok($zip->set_number('2920814')->is_valid_number, '千葉県木更津市八幡台');
ok($zip->set_number('2920815')->is_valid_number, '千葉県木更津市大久保');
ok($zip->set_number('2920816')->is_valid_number, '千葉県木更津市下烏田');
ok($zip->set_number('2920817')->is_valid_number, '千葉県木更津市中烏田');
ok($zip->set_number('2920818')->is_valid_number, '千葉県木更津市かずさ鎌足');
ok($zip->set_number('2920819')->is_valid_number, '千葉県木更津市羽鳥野');
ok($zip->set_number('2920821')->is_valid_number, '千葉県木更津市桜町');
ok($zip->set_number('2920822')->is_valid_number, '千葉県木更津市桜井');
ok($zip->set_number('2920823')->is_valid_number, '千葉県木更津市桜井新町');
ok($zip->set_number('2920824')->is_valid_number, '千葉県木更津市小浜');
ok($zip->set_number('2920825')->is_valid_number, '千葉県木更津市畑沢');
ok($zip->set_number('2920826')->is_valid_number, '千葉県木更津市畑沢南');
ok($zip->set_number('2920827')->is_valid_number, '千葉県木更津市港南台');
ok($zip->set_number('2920831')->is_valid_number, '千葉県木更津市富士見');
ok($zip->set_number('2920832')->is_valid_number, '千葉県木更津市新田');
ok($zip->set_number('2920833')->is_valid_number, '千葉県木更津市貝渕');
ok($zip->set_number('2920834')->is_valid_number, '千葉県木更津市潮見');
ok($zip->set_number('2920835')->is_valid_number, '千葉県木更津市築地');
ok($zip->set_number('2920836')->is_valid_number, '千葉県木更津市新港');
ok($zip->set_number('2920837')->is_valid_number, '千葉県木更津市木材港');
ok($zip->set_number('2920838')->is_valid_number, '千葉県木更津市潮浜');
ok($zip->set_number('2920839')->is_valid_number, '千葉県木更津市中の島');
ok($zip->set_number('2921140')->is_valid_number, '千葉県君津市糠田飛地');
ok($zip->set_number('2921141')->is_valid_number, '千葉県君津市根本');
ok($zip->set_number('2921142')->is_valid_number, '千葉県君津市小糸大谷');
ok($zip->set_number('2921143')->is_valid_number, '千葉県君津市長石');
ok($zip->set_number('2921144')->is_valid_number, '千葉県君津市法木');
ok($zip->set_number('2921145')->is_valid_number, '千葉県君津市糸川');
ok($zip->set_number('2921146')->is_valid_number, '千葉県君津市大井戸');
ok($zip->set_number('2921147')->is_valid_number, '千葉県君津市塚原');
ok($zip->set_number('2921148')->is_valid_number, '千葉県君津市行馬');
ok($zip->set_number('2921149')->is_valid_number, '千葉県君津市かずさ小糸');
ok($zip->set_number('2921151')->is_valid_number, '千葉県君津市大野台');
ok($zip->set_number('2921152')->is_valid_number, '千葉県君津市日渡根');
ok($zip->set_number('2921153')->is_valid_number, '千葉県君津市市宿');
ok($zip->set_number('2921154')->is_valid_number, '千葉県君津市清和市場');
ok($zip->set_number('2921155')->is_valid_number, '千葉県君津市鹿野山');
ok($zip->set_number('2921156')->is_valid_number, '千葉県君津市荻作');
ok($zip->set_number('2921157')->is_valid_number, '千葉県君津市福岡');
ok($zip->set_number('2921158')->is_valid_number, '千葉県君津市鎌滝');
ok($zip->set_number('2921161')->is_valid_number, '千葉県君津市東猪原');
ok($zip->set_number('2921162')->is_valid_number, '千葉県君津市西猪原');
ok($zip->set_number('2921163')->is_valid_number, '千葉県君津市東粟倉');
ok($zip->set_number('2921164')->is_valid_number, '千葉県君津市東日笠');
ok($zip->set_number('2921165')->is_valid_number, '千葉県君津市西日笠');
ok($zip->set_number('2921166')->is_valid_number, '千葉県君津市植畑');
ok($zip->set_number('2921167')->is_valid_number, '千葉県君津市平田');
ok($zip->set_number('2921168')->is_valid_number, '千葉県君津市西粟倉');
ok($zip->set_number('2921171')->is_valid_number, '千葉県君津市二入');
ok($zip->set_number('2921172')->is_valid_number, '千葉県君津市辻森');
ok($zip->set_number('2921173')->is_valid_number, '千葉県君津市大岩');
ok($zip->set_number('2921174')->is_valid_number, '千葉県君津市正木');
ok($zip->set_number('2921175')->is_valid_number, '千葉県君津市奥米');
ok($zip->set_number('2921176')->is_valid_number, '千葉県君津市宿原');
ok($zip->set_number('2921177')->is_valid_number, '千葉県君津市怒田沢');
ok($zip->set_number('2921178')->is_valid_number, '千葉県君津市旅名');
ok($zip->set_number('2921179')->is_valid_number, '千葉県君津市豊英');
ok($zip->set_number('2930000')->is_valid_number, '千葉県富津市以下に掲載がない場合');
ok($zip->set_number('2930001')->is_valid_number, '千葉県富津市大堀');
ok($zip->set_number('2930002')->is_valid_number, '千葉県富津市二間塚');
ok($zip->set_number('2930003')->is_valid_number, '千葉県富津市本郷');
ok($zip->set_number('2930004')->is_valid_number, '千葉県富津市前久保');
ok($zip->set_number('2930005')->is_valid_number, '千葉県富津市上飯野');
ok($zip->set_number('2930006')->is_valid_number, '千葉県富津市下飯野');
ok($zip->set_number('2930011')->is_valid_number, '千葉県富津市新富');
ok($zip->set_number('2930012')->is_valid_number, '千葉県富津市青木');
ok($zip->set_number('2930013')->is_valid_number, '千葉県富津市西川');
ok($zip->set_number('2930021')->is_valid_number, '千葉県富津市富津');
ok($zip->set_number('2930022')->is_valid_number, '千葉県富津市新井');
ok($zip->set_number('2930023')->is_valid_number, '千葉県富津市川名');
ok($zip->set_number('2930024')->is_valid_number, '千葉県富津市篠部');
ok($zip->set_number('2930031')->is_valid_number, '千葉県富津市相野谷');
ok($zip->set_number('2930032')->is_valid_number, '千葉県富津市障子谷');
ok($zip->set_number('2930033')->is_valid_number, '千葉県富津市一色');
ok($zip->set_number('2930034')->is_valid_number, '千葉県富津市絹');
ok($zip->set_number('2930035')->is_valid_number, '千葉県富津市西大和田');
ok($zip->set_number('2930036')->is_valid_number, '千葉県富津市千種新田');
ok($zip->set_number('2930041')->is_valid_number, '千葉県富津市上');
ok($zip->set_number('2930042')->is_valid_number, '千葉県富津市小久保');
ok($zip->set_number('2930043')->is_valid_number, '千葉県富津市岩瀬');
ok($zip->set_number('2930044')->is_valid_number, '千葉県富津市中');
ok($zip->set_number('2930045')->is_valid_number, '千葉県富津市八田沼');
ok($zip->set_number('2930046')->is_valid_number, '千葉県富津市近藤');
ok($zip->set_number('2930051')->is_valid_number, '千葉県富津市亀沢');
ok($zip->set_number('2930052')->is_valid_number, '千葉県富津市宝竜寺');
ok($zip->set_number('2930053')->is_valid_number, '千葉県富津市花香谷');
ok($zip->set_number('2930054')->is_valid_number, '千葉県富津市鶴岡');
ok($zip->set_number('2930055')->is_valid_number, '千葉県富津市笹毛');
ok($zip->set_number('2930056')->is_valid_number, '千葉県富津市八幡');
ok($zip->set_number('2930057')->is_valid_number, '千葉県富津市亀田');
ok($zip->set_number('2930058')->is_valid_number, '千葉県富津市佐貫');
ok($zip->set_number('2940000')->is_valid_number, '千葉県館山市以下に掲載がない場合');
ok($zip->set_number('2940001')->is_valid_number, '千葉県館山市竹原');
ok($zip->set_number('2940002')->is_valid_number, '千葉県館山市大井');
ok($zip->set_number('2940003')->is_valid_number, '千葉県館山市水玉');
ok($zip->set_number('2940004')->is_valid_number, '千葉県館山市水岡');
ok($zip->set_number('2940005')->is_valid_number, '千葉県館山市安東');
ok($zip->set_number('2940006')->is_valid_number, '千葉県館山市薗');
ok($zip->set_number('2940007')->is_valid_number, '千葉県館山市腰越');
ok($zip->set_number('2940008')->is_valid_number, '千葉県館山市広瀬');
ok($zip->set_number('2940009')->is_valid_number, '千葉県館山市江田');
ok($zip->set_number('2940011')->is_valid_number, '千葉県館山市二子');
ok($zip->set_number('2940012')->is_valid_number, '千葉県館山市稲');
ok($zip->set_number('2940013')->is_valid_number, '千葉県館山市宝貝');
ok($zip->set_number('2940014')->is_valid_number, '千葉県館山市山本');
ok($zip->set_number('2940015')->is_valid_number, '千葉県館山市古茂口');
ok($zip->set_number('2940016')->is_valid_number, '千葉県館山市飯沼');
ok($zip->set_number('2940017')->is_valid_number, '千葉県館山市南条');
ok($zip->set_number('2940018')->is_valid_number, '千葉県館山市国分');
ok($zip->set_number('2940021')->is_valid_number, '千葉県館山市山荻');
ok($zip->set_number('2940022')->is_valid_number, '千葉県館山市畑');
ok($zip->set_number('2940023')->is_valid_number, '千葉県館山市神余');
ok($zip->set_number('2940024')->is_valid_number, '千葉県館山市岡田');
ok($zip->set_number('2940025')->is_valid_number, '千葉県館山市大戸');
ok($zip->set_number('2940026')->is_valid_number, '千葉県館山市出野尾');
ok($zip->set_number('2940027')->is_valid_number, '千葉県館山市西長田');
ok($zip->set_number('2940028')->is_valid_number, '千葉県館山市東長田');
ok($zip->set_number('2940029')->is_valid_number, '千葉県館山市作名');
ok($zip->set_number('2940031')->is_valid_number, '千葉県館山市大賀');
ok($zip->set_number('2940032')->is_valid_number, '千葉県館山市笠名');
ok($zip->set_number('2940033')->is_valid_number, '千葉県館山市宮城');
ok($zip->set_number('2940034')->is_valid_number, '千葉県館山市沼');
ok($zip->set_number('2940035')->is_valid_number, '千葉県館山市富士見');
ok($zip->set_number('2940036')->is_valid_number, '千葉県館山市館山');
ok($zip->set_number('2940037')->is_valid_number, '千葉県館山市長須賀');
ok($zip->set_number('2940038')->is_valid_number, '千葉県館山市上真倉');
ok($zip->set_number('2940041')->is_valid_number, '千葉県館山市高井');
ok($zip->set_number('2940042')->is_valid_number, '千葉県館山市上野原');
ok($zip->set_number('2940043')->is_valid_number, '千葉県館山市安布里');
ok($zip->set_number('2940044')->is_valid_number, '千葉県館山市大網');
ok($zip->set_number('2940045')->is_valid_number, '千葉県館山市北条');
ok($zip->set_number('2940046')->is_valid_number, '千葉県館山市新宿');
ok($zip->set_number('2940047')->is_valid_number, '千葉県館山市八幡');
ok($zip->set_number('2940048')->is_valid_number, '千葉県館山市下真倉');
ok($zip->set_number('2940051')->is_valid_number, '千葉県館山市正木');
ok($zip->set_number('2940052')->is_valid_number, '千葉県館山市亀ケ原');
ok($zip->set_number('2940053')->is_valid_number, '千葉県館山市北条正木');
ok($zip->set_number('2940054')->is_valid_number, '千葉県館山市湊');
ok($zip->set_number('2940055')->is_valid_number, '千葉県館山市那古');
ok($zip->set_number('2940056')->is_valid_number, '千葉県館山市船形');
ok($zip->set_number('2940057')->is_valid_number, '千葉県館山市川名');
ok($zip->set_number('2940058')->is_valid_number, '千葉県館山市小原');
ok($zip->set_number('2940221')->is_valid_number, '千葉県館山市布沼');
ok($zip->set_number('2940222')->is_valid_number, '千葉県館山市茂名');
ok($zip->set_number('2940223')->is_valid_number, '千葉県館山市洲宮');
ok($zip->set_number('2940224')->is_valid_number, '千葉県館山市藤原');
ok($zip->set_number('2940225')->is_valid_number, '千葉県館山市佐野');
ok($zip->set_number('2940226')->is_valid_number, '千葉県館山市犬石');
ok($zip->set_number('2940231')->is_valid_number, '千葉県館山市中里');
ok($zip->set_number('2940232')->is_valid_number, '千葉県館山市竜岡');
ok($zip->set_number('2940233')->is_valid_number, '千葉県館山市大神宮');
ok($zip->set_number('2940234')->is_valid_number, '千葉県館山市布良');
ok($zip->set_number('2940235')->is_valid_number, '千葉県館山市相浜');
ok($zip->set_number('2940301')->is_valid_number, '千葉県館山市香');
ok($zip->set_number('2940302')->is_valid_number, '千葉県館山市塩見');
ok($zip->set_number('2940303')->is_valid_number, '千葉県館山市浜田');
ok($zip->set_number('2940304')->is_valid_number, '千葉県館山市早物');
ok($zip->set_number('2940305')->is_valid_number, '千葉県館山市見物');
ok($zip->set_number('2940306')->is_valid_number, '千葉県館山市加賀名');
ok($zip->set_number('2940307')->is_valid_number, '千葉県館山市波左間');
ok($zip->set_number('2940308')->is_valid_number, '千葉県館山市坂田');
ok($zip->set_number('2940311')->is_valid_number, '千葉県館山市坂井');
ok($zip->set_number('2940312')->is_valid_number, '千葉県館山市小沼');
ok($zip->set_number('2940313')->is_valid_number, '千葉県館山市坂足');
ok($zip->set_number('2940314')->is_valid_number, '千葉県館山市伊戸');
ok($zip->set_number('2940315')->is_valid_number, '千葉県館山市西川名');
ok($zip->set_number('2940316')->is_valid_number, '千葉県館山市洲崎');
ok($zip->set_number('2940801')->is_valid_number, '千葉県南房総市増間');
ok($zip->set_number('2940802')->is_valid_number, '千葉県南房総市山名');
ok($zip->set_number('2940803')->is_valid_number, '千葉県南房総市御庄');
ok($zip->set_number('2940804')->is_valid_number, '千葉県南房総市海老敷');
ok($zip->set_number('2940805')->is_valid_number, '千葉県南房総市下滝田');
ok($zip->set_number('2940806')->is_valid_number, '千葉県南房総市上滝田');
ok($zip->set_number('2940811')->is_valid_number, '千葉県南房総市中');
ok($zip->set_number('2940812')->is_valid_number, '千葉県南房総市池之内');
ok($zip->set_number('2940813')->is_valid_number, '千葉県南房総市谷向');
ok($zip->set_number('2940814')->is_valid_number, '千葉県南房総市川田');
ok($zip->set_number('2940815')->is_valid_number, '千葉県南房総市千代');
ok($zip->set_number('2940816')->is_valid_number, '千葉県南房総市山下');
ok($zip->set_number('2940817')->is_valid_number, '千葉県南房総市大学口');
ok($zip->set_number('2940821')->is_valid_number, '千葉県南房総市明石');
ok($zip->set_number('2940822')->is_valid_number, '千葉県南房総市本織');
ok($zip->set_number('2940823')->is_valid_number, '千葉県南房総市府中');
ok($zip->set_number('2940824')->is_valid_number, '千葉県南房総市下堀');
ok($zip->set_number('2940825')->is_valid_number, '千葉県南房総市上堀');
ok($zip->set_number('2940826')->is_valid_number, '千葉県南房総市三坂');
ok($zip->set_number('2950001')->is_valid_number, '千葉県南房総市千倉町久保');
ok($zip->set_number('2950002')->is_valid_number, '千葉県南房総市千倉町川合');
ok($zip->set_number('2950003')->is_valid_number, '千葉県南房総市千倉町白子');
ok($zip->set_number('2950004')->is_valid_number, '千葉県南房総市千倉町瀬戸');
ok($zip->set_number('2950005')->is_valid_number, '千葉県南房総市千倉町牧田');
ok($zip->set_number('2950006')->is_valid_number, '千葉県南房総市千倉町宇田');
ok($zip->set_number('2950011')->is_valid_number, '千葉県南房総市千倉町北朝夷');
ok($zip->set_number('2950012')->is_valid_number, '千葉県南房総市千倉町南朝夷');
ok($zip->set_number('2950013')->is_valid_number, '千葉県南房総市千倉町大貫');
ok($zip->set_number('2950014')->is_valid_number, '千葉県南房総市千倉町川戸');
ok($zip->set_number('2950021')->is_valid_number, '千葉県南房総市千倉町平舘');
ok($zip->set_number('2950022')->is_valid_number, '千葉県南房総市千倉町忽戸');
ok($zip->set_number('2950023')->is_valid_number, '千葉県南房総市千倉町川口');
ok($zip->set_number('2950024')->is_valid_number, '千葉県南房総市千倉町平磯');
ok($zip->set_number('2950025')->is_valid_number, '千葉県南房総市千倉町千田');
ok($zip->set_number('2950026')->is_valid_number, '千葉県南房総市千倉町大川');
ok($zip->set_number('2950027')->is_valid_number, '千葉県南房総市千倉町白間津');
ok($zip->set_number('2950101')->is_valid_number, '千葉県南房総市白浜町乙浜');
ok($zip->set_number('2950102')->is_valid_number, '千葉県南房総市白浜町白浜');
ok($zip->set_number('2950103')->is_valid_number, '千葉県南房総市白浜町滝口');
ok($zip->set_number('2950104')->is_valid_number, '千葉県南房総市白浜町根本');
ok($zip->set_number('2960000')->is_valid_number, '千葉県鴨川市以下に掲載がない場合');
ok($zip->set_number('2960001')->is_valid_number, '千葉県鴨川市横渚');
ok($zip->set_number('2960002')->is_valid_number, '千葉県鴨川市前原');
ok($zip->set_number('2960003')->is_valid_number, '千葉県鴨川市磯村');
ok($zip->set_number('2960004')->is_valid_number, '千葉県鴨川市貝渚');
ok($zip->set_number('2960011')->is_valid_number, '千葉県鴨川市大里');
ok($zip->set_number('2960012')->is_valid_number, '千葉県鴨川市来秀');
ok($zip->set_number('2960013')->is_valid_number, '千葉県鴨川市田原西');
ok($zip->set_number('2960014')->is_valid_number, '千葉県鴨川市太尾');
ok($zip->set_number('2960015')->is_valid_number, '千葉県鴨川市川代');
ok($zip->set_number('2960016')->is_valid_number, '千葉県鴨川市坂東');
ok($zip->set_number('2960021')->is_valid_number, '千葉県鴨川市竹平');
ok($zip->set_number('2960022')->is_valid_number, '千葉県鴨川市京田');
ok($zip->set_number('2960023')->is_valid_number, '千葉県鴨川市押切');
ok($zip->set_number('2960024')->is_valid_number, '千葉県鴨川市池田');
ok($zip->set_number('2960025')->is_valid_number, '千葉県鴨川市太田学');
ok($zip->set_number('2960031')->is_valid_number, '千葉県鴨川市粟斗');
ok($zip->set_number('2960032')->is_valid_number, '千葉県鴨川市花房');
ok($zip->set_number('2960033')->is_valid_number, '千葉県鴨川市八色');
ok($zip->set_number('2960034')->is_valid_number, '千葉県鴨川市滑谷');
ok($zip->set_number('2960035')->is_valid_number, '千葉県鴨川市打墨');
ok($zip->set_number('2960041')->is_valid_number, '千葉県鴨川市東町');
ok($zip->set_number('2960042')->is_valid_number, '千葉県鴨川市東元浜荻飛地');
ok($zip->set_number('2960043')->is_valid_number, '千葉県鴨川市西町');
ok($zip->set_number('2960044')->is_valid_number, '千葉県鴨川市広場');
ok($zip->set_number('2960045')->is_valid_number, '千葉県鴨川市和泉');
ok($zip->set_number('2960101')->is_valid_number, '千葉県鴨川市北小町');
ok($zip->set_number('2960102')->is_valid_number, '千葉県鴨川市下小原');
ok($zip->set_number('2960103')->is_valid_number, '千葉県鴨川市上小原');
ok($zip->set_number('2960104')->is_valid_number, '千葉県鴨川市南小町');
ok($zip->set_number('2960105')->is_valid_number, '千葉県鴨川市成川');
ok($zip->set_number('2960106')->is_valid_number, '千葉県鴨川市主基西');
ok($zip->set_number('2960111')->is_valid_number, '千葉県鴨川市仲');
ok($zip->set_number('2960112')->is_valid_number, '千葉県鴨川市宮山');
ok($zip->set_number('2960113')->is_valid_number, '千葉県鴨川市吉尾平塚');
ok($zip->set_number('2960114')->is_valid_number, '千葉県鴨川市細野');
ok($zip->set_number('2960115')->is_valid_number, '千葉県鴨川市松尾寺');
ok($zip->set_number('2960121')->is_valid_number, '千葉県鴨川市大川面');
ok($zip->set_number('2960122')->is_valid_number, '千葉県鴨川市寺門');
ok($zip->set_number('2960123')->is_valid_number, '千葉県鴨川市北風原');
ok($zip->set_number('2960124')->is_valid_number, '千葉県鴨川市大幡');
ok($zip->set_number('2960125')->is_valid_number, '千葉県鴨川市横尾');
ok($zip->set_number('2960126')->is_valid_number, '千葉県鴨川市吉尾西');
ok($zip->set_number('2960231')->is_valid_number, '千葉県鴨川市釜沼');
ok($zip->set_number('2960232')->is_valid_number, '千葉県鴨川市平塚');
ok($zip->set_number('2960233')->is_valid_number, '千葉県鴨川市金束');
ok($zip->set_number('2960234')->is_valid_number, '千葉県鴨川市古畑');
ok($zip->set_number('2960235')->is_valid_number, '千葉県鴨川市奈良林');
ok($zip->set_number('2960236')->is_valid_number, '千葉県鴨川市佐野');
ok($zip->set_number('2960237')->is_valid_number, '千葉県鴨川市大山平塚');
ok($zip->set_number('2970000')->is_valid_number, '千葉県茂原市以下に掲載がない場合');
ok($zip->set_number('2970001')->is_valid_number, '千葉県茂原市七渡');
ok($zip->set_number('2970002')->is_valid_number, '千葉県茂原市千町');
ok($zip->set_number('2970003')->is_valid_number, '千葉県茂原市北高根飛地');
ok($zip->set_number('2970004')->is_valid_number, '千葉県茂原市小轡');
ok($zip->set_number('2970005')->is_valid_number, '千葉県茂原市本小轡');
ok($zip->set_number('2970006')->is_valid_number, '千葉県茂原市新小轡');
ok($zip->set_number('2970007')->is_valid_number, '千葉県茂原市腰当');
ok($zip->set_number('2970008')->is_valid_number, '千葉県茂原市渋谷');
ok($zip->set_number('2970009')->is_valid_number, '千葉県茂原市北塚');
ok($zip->set_number('2970011')->is_valid_number, '千葉県茂原市谷本');
ok($zip->set_number('2970012')->is_valid_number, '千葉県茂原市六ツ野');
ok($zip->set_number('2970013')->is_valid_number, '千葉県茂原市中之郷飛地');
ok($zip->set_number('2970014')->is_valid_number, '千葉県茂原市川島飛地');
ok($zip->set_number('2970015')->is_valid_number, '千葉県茂原市東部台');
ok($zip->set_number('2970016')->is_valid_number, '千葉県茂原市木崎');
ok($zip->set_number('2970017')->is_valid_number, '千葉県茂原市東郷');
ok($zip->set_number('2970018')->is_valid_number, '千葉県茂原市萩原町');
ok($zip->set_number('2970019')->is_valid_number, '千葉県茂原市上林');
ok($zip->set_number('2970021')->is_valid_number, '千葉県茂原市高師町');
ok($zip->set_number('2970022')->is_valid_number, '千葉県茂原市町保');
ok($zip->set_number('2970023')->is_valid_number, '千葉県茂原市千代田町');
ok($zip->set_number('2970024')->is_valid_number, '千葉県茂原市八千代');
ok($zip->set_number('2970025')->is_valid_number, '千葉県茂原市緑町');
ok($zip->set_number('2970026')->is_valid_number, '千葉県茂原市茂原');
ok($zip->set_number('2970027')->is_valid_number, '千葉県茂原市中部');
ok($zip->set_number('2970028')->is_valid_number, '千葉県茂原市道表');
ok($zip->set_number('2970029')->is_valid_number, '千葉県茂原市高師');
ok($zip->set_number('2970031')->is_valid_number, '千葉県茂原市早野新田');
ok($zip->set_number('2970032')->is_valid_number, '千葉県茂原市東茂原');
ok($zip->set_number('2970033')->is_valid_number, '千葉県茂原市大芝');
ok($zip->set_number('2970034')->is_valid_number, '千葉県茂原市中の島町');
ok($zip->set_number('2970035')->is_valid_number, '千葉県茂原市下永吉');
ok($zip->set_number('2970036')->is_valid_number, '千葉県茂原市上永吉');
ok($zip->set_number('2970037')->is_valid_number, '千葉県茂原市早野');
ok($zip->set_number('2970038')->is_valid_number, '千葉県茂原市長清水');
ok($zip->set_number('2970039')->is_valid_number, '千葉県茂原市茂原西');
ok($zip->set_number('2970041')->is_valid_number, '千葉県茂原市猿袋');
ok($zip->set_number('2970042')->is_valid_number, '千葉県茂原市三ケ谷');
ok($zip->set_number('2970043')->is_valid_number, '千葉県茂原市立木');
ok($zip->set_number('2970044')->is_valid_number, '千葉県茂原市台田');
ok($zip->set_number('2970045')->is_valid_number, '千葉県茂原市野牛');
ok($zip->set_number('2970051')->is_valid_number, '千葉県茂原市鷲巣');
ok($zip->set_number('2970052')->is_valid_number, '千葉県茂原市上茂原');
ok($zip->set_number('2970053')->is_valid_number, '千葉県茂原市墨田');
ok($zip->set_number('2970054')->is_valid_number, '千葉県茂原市八幡原');
ok($zip->set_number('2970055')->is_valid_number, '千葉県茂原市綱島');
ok($zip->set_number('2970056')->is_valid_number, '千葉県茂原市六田台');
ok($zip->set_number('2970057')->is_valid_number, '千葉県茂原市中善寺');
ok($zip->set_number('2970058')->is_valid_number, '千葉県茂原市石神');
ok($zip->set_number('2970061')->is_valid_number, '千葉県茂原市山崎');
ok($zip->set_number('2970062')->is_valid_number, '千葉県茂原市内長谷');
ok($zip->set_number('2970063')->is_valid_number, '千葉県茂原市長谷');
ok($zip->set_number('2970064')->is_valid_number, '千葉県茂原市箕輪');
ok($zip->set_number('2970065')->is_valid_number, '千葉県茂原市緑ケ丘');
ok($zip->set_number('2970066')->is_valid_number, '千葉県茂原市芦網');
ok($zip->set_number('2970067')->is_valid_number, '千葉県茂原市国府関');
ok($zip->set_number('2970071')->is_valid_number, '千葉県茂原市黒戸');
ok($zip->set_number('2970072')->is_valid_number, '千葉県茂原市大登');
ok($zip->set_number('2970073')->is_valid_number, '千葉県茂原市長尾');
ok($zip->set_number('2970074')->is_valid_number, '千葉県茂原市小林');
ok($zip->set_number('2970075')->is_valid_number, '千葉県茂原市押日');
ok($zip->set_number('2970076')->is_valid_number, '千葉県茂原市庄吉');
ok($zip->set_number('2970077')->is_valid_number, '千葉県茂原市真名');
ok($zip->set_number('2970078')->is_valid_number, '千葉県茂原市高師台');
ok($zip->set_number('2970079')->is_valid_number, '千葉県茂原市ゆたか');
ok($zip->set_number('2970100')->is_valid_number, '千葉県長生郡長南町以下に掲載がない場合');
ok($zip->set_number('2970101')->is_valid_number, '千葉県長生郡長南町岩川');
ok($zip->set_number('2970102')->is_valid_number, '千葉県長生郡長南町本台');
ok($zip->set_number('2970103')->is_valid_number, '千葉県長生郡長南町今泉');
ok($zip->set_number('2970104')->is_valid_number, '千葉県長生郡長南町又富');
ok($zip->set_number('2970105')->is_valid_number, '千葉県長生郡長南町棚毛');
ok($zip->set_number('2970111')->is_valid_number, '千葉県長生郡長南町須田');
ok($zip->set_number('2970112')->is_valid_number, '千葉県長生郡長南町米満');
ok($zip->set_number('2970113')->is_valid_number, '千葉県長生郡長南町関原');
ok($zip->set_number('2970114')->is_valid_number, '千葉県長生郡長南町千手堂');
ok($zip->set_number('2970115')->is_valid_number, '千葉県長生郡長南町千田');
ok($zip->set_number('2970121')->is_valid_number, '千葉県長生郡長南町長南');
ok($zip->set_number('2970122')->is_valid_number, '千葉県長生郡長南町坂本');
ok($zip->set_number('2970123')->is_valid_number, '千葉県長生郡長南町蔵持');
ok($zip->set_number('2970124')->is_valid_number, '千葉県長生郡長南町深沢');
ok($zip->set_number('2970125')->is_valid_number, '千葉県長生郡長南町笠森');
ok($zip->set_number('2970131')->is_valid_number, '千葉県長生郡長南町中原');
ok($zip->set_number('2970132')->is_valid_number, '千葉県長生郡長南町給田');
ok($zip->set_number('2970133')->is_valid_number, '千葉県長生郡長南町豊原');
ok($zip->set_number('2970134')->is_valid_number, '千葉県長生郡長南町芝原');
ok($zip->set_number('2970135')->is_valid_number, '千葉県長生郡長南町地引');
ok($zip->set_number('2970136')->is_valid_number, '千葉県長生郡長南町小生田');
ok($zip->set_number('2970137')->is_valid_number, '千葉県長生郡長南町上小野田');
ok($zip->set_number('2970138')->is_valid_number, '千葉県長生郡長南町下小野田');
ok($zip->set_number('2970141')->is_valid_number, '千葉県長生郡長南町報恩寺');
ok($zip->set_number('2970142')->is_valid_number, '千葉県長生郡長南町小沢');
ok($zip->set_number('2970143')->is_valid_number, '千葉県長生郡長南町美原台');
ok($zip->set_number('2970144')->is_valid_number, '千葉県長生郡長南町市野々');
ok($zip->set_number('2970145')->is_valid_number, '千葉県長生郡長南町佐坪');
ok($zip->set_number('2970151')->is_valid_number, '千葉県長生郡長南町茗荷沢');
ok($zip->set_number('2970152')->is_valid_number, '千葉県長生郡長南町水沼');
ok($zip->set_number('2970153')->is_valid_number, '千葉県長生郡長南町山内');
ok($zip->set_number('2970154')->is_valid_number, '千葉県長生郡長南町岩撫');
ok($zip->set_number('2970155')->is_valid_number, '千葉県長生郡長南町竹林');
ok($zip->set_number('2970200')->is_valid_number, '千葉県長生郡長柄町以下に掲載がない場合');
ok($zip->set_number('2970201')->is_valid_number, '千葉県長生郡長柄町上野');
ok($zip->set_number('2970202')->is_valid_number, '千葉県長生郡長柄町味庄');
ok($zip->set_number('2970203')->is_valid_number, '千葉県長生郡長柄町国府里');
ok($zip->set_number('2970204')->is_valid_number, '千葉県長生郡長柄町力丸');
ok($zip->set_number('2970205')->is_valid_number, '千葉県長生郡長柄町千代丸');
ok($zip->set_number('2970206')->is_valid_number, '千葉県長生郡長柄町山根');
ok($zip->set_number('2970207')->is_valid_number, '千葉県長生郡長柄町船木');
ok($zip->set_number('2970211')->is_valid_number, '千葉県長生郡長柄町榎本');
ok($zip->set_number('2970212')->is_valid_number, '千葉県長生郡長柄町小榎本');
ok($zip->set_number('2970213')->is_valid_number, '千葉県長生郡長柄町徳増');
ok($zip->set_number('2970214')->is_valid_number, '千葉県長生郡長柄町長富');
ok($zip->set_number('2970215')->is_valid_number, '千葉県長生郡長柄町鴇谷');
ok($zip->set_number('2970216')->is_valid_number, '千葉県長生郡長柄町立鳥');
ok($zip->set_number('2970217')->is_valid_number, '千葉県長生郡長柄町針ケ谷');
ok($zip->set_number('2970218')->is_valid_number, '千葉県長生郡長柄町桜谷');
ok($zip->set_number('2970221')->is_valid_number, '千葉県長生郡長柄町高山');
ok($zip->set_number('2970222')->is_valid_number, '千葉県長生郡長柄町大庭');
ok($zip->set_number('2970223')->is_valid_number, '千葉県長生郡長柄町大津倉');
ok($zip->set_number('2970224')->is_valid_number, '千葉県長生郡長柄町田代');
ok($zip->set_number('2970225')->is_valid_number, '千葉県長生郡長柄町刑部');
ok($zip->set_number('2970226')->is_valid_number, '千葉県長生郡長柄町金谷');
ok($zip->set_number('2970231')->is_valid_number, '千葉県長生郡長柄町山之郷');
ok($zip->set_number('2970232')->is_valid_number, '千葉県長生郡長柄町中野台');
ok($zip->set_number('2970233')->is_valid_number, '千葉県長生郡長柄町六地蔵');
ok($zip->set_number('2970234')->is_valid_number, '千葉県長生郡長柄町長柄山');
ok($zip->set_number('2970235')->is_valid_number, '千葉県長生郡長柄町皿木');
ok($zip->set_number('2980000')->is_valid_number, '千葉県いすみ市以下に掲載がない場合');
ok($zip->set_number('2980001')->is_valid_number, '千葉県いすみ市若山');
ok($zip->set_number('2980002')->is_valid_number, '千葉県いすみ市日在');
ok($zip->set_number('2980003')->is_valid_number, '千葉県いすみ市深堀');
ok($zip->set_number('2980004')->is_valid_number, '千葉県いすみ市大原');
ok($zip->set_number('2980005')->is_valid_number, '千葉県いすみ市新田');
ok($zip->set_number('2980006')->is_valid_number, '千葉県いすみ市大原最上台');
ok($zip->set_number('2980011')->is_valid_number, '千葉県いすみ市岩船');
ok($zip->set_number('2980012')->is_valid_number, '千葉県いすみ市小沢');
ok($zip->set_number('2980013')->is_valid_number, '千葉県いすみ市小池');
ok($zip->set_number('2980014')->is_valid_number, '千葉県いすみ市大原台');
ok($zip->set_number('2980015')->is_valid_number, '千葉県いすみ市釈迦谷');
ok($zip->set_number('2980016')->is_valid_number, '千葉県いすみ市新田若山深堀入会地');
ok($zip->set_number('2980017')->is_valid_number, '千葉県いすみ市下布施');
ok($zip->set_number('2980018')->is_valid_number, '千葉県いすみ市上布施');
ok($zip->set_number('2980021')->is_valid_number, '千葉県いすみ市高谷');
ok($zip->set_number('2980022')->is_valid_number, '千葉県いすみ市佐室');
ok($zip->set_number('2980023')->is_valid_number, '千葉県いすみ市沢部');
ok($zip->set_number('2980024')->is_valid_number, '千葉県いすみ市長志');
ok($zip->set_number('2980025')->is_valid_number, '千葉県いすみ市山田');
ok($zip->set_number('2980026')->is_valid_number, '千葉県いすみ市新田野');
ok($zip->set_number('2980027')->is_valid_number, '千葉県いすみ市下原');
ok($zip->set_number('2980028')->is_valid_number, '千葉県いすみ市細尾');
ok($zip->set_number('2980029')->is_valid_number, '千葉県いすみ市大和田');
ok($zip->set_number('2980101')->is_valid_number, '千葉県いすみ市小又井');
ok($zip->set_number('2980102')->is_valid_number, '千葉県いすみ市小高');
ok($zip->set_number('2980103')->is_valid_number, '千葉県いすみ市神置');
ok($zip->set_number('2980104')->is_valid_number, '千葉県いすみ市松丸');
ok($zip->set_number('2980105')->is_valid_number, '千葉県いすみ市能実');
ok($zip->set_number('2980106')->is_valid_number, '千葉県いすみ市須賀谷');
ok($zip->set_number('2980111')->is_valid_number, '千葉県いすみ市万木');
ok($zip->set_number('2980112')->is_valid_number, '千葉県いすみ市国府台');
ok($zip->set_number('2980113')->is_valid_number, '千葉県いすみ市大野');
ok($zip->set_number('2980114')->is_valid_number, '千葉県いすみ市札森');
ok($zip->set_number('2980115')->is_valid_number, '千葉県いすみ市柿和田');
ok($zip->set_number('2980116')->is_valid_number, '千葉県いすみ市正立寺');
ok($zip->set_number('2980117')->is_valid_number, '千葉県いすみ市増田');
ok($zip->set_number('2980121')->is_valid_number, '千葉県いすみ市島');
ok($zip->set_number('2980122')->is_valid_number, '千葉県いすみ市楽町');
ok($zip->set_number('2980123')->is_valid_number, '千葉県いすみ市苅谷');
ok($zip->set_number('2980124')->is_valid_number, '千葉県いすみ市弥正');
ok($zip->set_number('2980125')->is_valid_number, '千葉県いすみ市深谷');
ok($zip->set_number('2980126')->is_valid_number, '千葉県いすみ市今関');
ok($zip->set_number('2980131')->is_valid_number, '千葉県いすみ市荻原');
ok($zip->set_number('2980132')->is_valid_number, '千葉県いすみ市八乙女');
ok($zip->set_number('2980133')->is_valid_number, '千葉県いすみ市引田');
ok($zip->set_number('2980134')->is_valid_number, '千葉県いすみ市行川');
ok($zip->set_number('2980135')->is_valid_number, '千葉県いすみ市作田');
ok($zip->set_number('2980200')->is_valid_number, '千葉県夷隅郡大多喜町以下に掲載がない場合');
ok($zip->set_number('2980201')->is_valid_number, '千葉県夷隅郡大多喜町小土呂');
ok($zip->set_number('2980202')->is_valid_number, '千葉県夷隅郡大多喜町下大多喜');
ok($zip->set_number('2980203')->is_valid_number, '千葉県夷隅郡大多喜町森宮');
ok($zip->set_number('2980204')->is_valid_number, '千葉県夷隅郡大多喜町船子');
ok($zip->set_number('2980205')->is_valid_number, '千葉県夷隅郡大多喜町上原西部田柳原入会');
ok($zip->set_number('2980206')->is_valid_number, '千葉県夷隅郡大多喜町横山');
ok($zip->set_number('2980207')->is_valid_number, '千葉県夷隅郡大多喜町泉水');
ok($zip->set_number('2980211')->is_valid_number, '千葉県夷隅郡大多喜町紺屋');
ok($zip->set_number('2980212')->is_valid_number, '千葉県夷隅郡大多喜町猿稲');
ok($zip->set_number('2980213')->is_valid_number, '千葉県夷隅郡大多喜町桜台');
ok($zip->set_number('2980214')->is_valid_number, '千葉県夷隅郡大多喜町新丁');
ok($zip->set_number('2980215')->is_valid_number, '千葉県夷隅郡大多喜町久保');
ok($zip->set_number('2980216')->is_valid_number, '千葉県夷隅郡大多喜町大多喜');
ok($zip->set_number('2980217')->is_valid_number, '千葉県夷隅郡大多喜町田丁');
ok($zip->set_number('2980221')->is_valid_number, '千葉県夷隅郡大多喜町柳原');
ok($zip->set_number('2980222')->is_valid_number, '千葉県夷隅郡大多喜町八声');
ok($zip->set_number('2980223')->is_valid_number, '千葉県夷隅郡大多喜町上原');
ok($zip->set_number('2980224')->is_valid_number, '千葉県夷隅郡大多喜町堀之内');
ok($zip->set_number('2980225')->is_valid_number, '千葉県夷隅郡大多喜町大戸');
ok($zip->set_number('2980226')->is_valid_number, '千葉県夷隅郡大多喜町部田');
ok($zip->set_number('2980227')->is_valid_number, '千葉県夷隅郡大多喜町西部田');
ok($zip->set_number('2980228')->is_valid_number, '千葉県夷隅郡大多喜町小谷松');
ok($zip->set_number('2980231')->is_valid_number, '千葉県夷隅郡大多喜町馬場内');
ok($zip->set_number('2980232')->is_valid_number, '千葉県夷隅郡大多喜町小内');
ok($zip->set_number('2980233')->is_valid_number, '千葉県夷隅郡大多喜町笛倉');
ok($zip->set_number('2980234')->is_valid_number, '千葉県夷隅郡大多喜町押沼');
ok($zip->set_number('2980235')->is_valid_number, '千葉県夷隅郡大多喜町宇筒原');
ok($zip->set_number('2980236')->is_valid_number, '千葉県夷隅郡大多喜町百鉾');
ok($zip->set_number('2980237')->is_valid_number, '千葉県夷隅郡大多喜町原内');
ok($zip->set_number('2980238')->is_valid_number, '千葉県夷隅郡大多喜町小内笛倉入会');
ok($zip->set_number('2980241')->is_valid_number, '千葉県夷隅郡大多喜町紙敷');
ok($zip->set_number('2980242')->is_valid_number, '千葉県夷隅郡大多喜町小苗');
ok($zip->set_number('2980243')->is_valid_number, '千葉県夷隅郡大多喜町湯倉');
ok($zip->set_number('2980244')->is_valid_number, '千葉県夷隅郡大多喜町松尾');
ok($zip->set_number('2980245')->is_valid_number, '千葉県夷隅郡大多喜町弥喜用');
ok($zip->set_number('2980246')->is_valid_number, '千葉県夷隅郡大多喜町庄司');
ok($zip->set_number('2980251')->is_valid_number, '千葉県夷隅郡大多喜町久我原');
ok($zip->set_number('2980252')->is_valid_number, '千葉県夷隅郡大多喜町三又');
ok($zip->set_number('2980253')->is_valid_number, '千葉県夷隅郡大多喜町川畑');
ok($zip->set_number('2980254')->is_valid_number, '千葉県夷隅郡大多喜町平沢');
ok($zip->set_number('2980255')->is_valid_number, '千葉県夷隅郡大多喜町黒原');
ok($zip->set_number('2980256')->is_valid_number, '千葉県夷隅郡大多喜町石神');
ok($zip->set_number('2980261')->is_valid_number, '千葉県夷隅郡大多喜町板谷');
ok($zip->set_number('2980262')->is_valid_number, '千葉県夷隅郡大多喜町堀切');
ok($zip->set_number('2980263')->is_valid_number, '千葉県夷隅郡大多喜町伊保田');
ok($zip->set_number('2980264')->is_valid_number, '千葉県夷隅郡大多喜町大田代');
ok($zip->set_number('2980265')->is_valid_number, '千葉県夷隅郡大多喜町小田代');
ok($zip->set_number('2980266')->is_valid_number, '千葉県夷隅郡大多喜町筒森');
ok($zip->set_number('2980267')->is_valid_number, '千葉県夷隅郡大多喜町葛藤');
ok($zip->set_number('2980271')->is_valid_number, '千葉県夷隅郡大多喜町中野');
ok($zip->set_number('2980272')->is_valid_number, '千葉県夷隅郡大多喜町市川');
ok($zip->set_number('2980273')->is_valid_number, '千葉県夷隅郡大多喜町三条');
ok($zip->set_number('2980274')->is_valid_number, '千葉県夷隅郡大多喜町田代');
ok($zip->set_number('2980275')->is_valid_number, '千葉県夷隅郡大多喜町弓木');
ok($zip->set_number('2980276')->is_valid_number, '千葉県夷隅郡大多喜町会所');
ok($zip->set_number('2980277')->is_valid_number, '千葉県夷隅郡大多喜町粟又');
ok($zip->set_number('2980278')->is_valid_number, '千葉県夷隅郡大多喜町小沢又');
ok($zip->set_number('2980279')->is_valid_number, '千葉県夷隅郡大多喜町面白');
ok($zip->set_number('2990101')->is_valid_number, '千葉県市原市青柳北');
ok($zip->set_number('2990102')->is_valid_number, '千葉県市原市青柳');
ok($zip->set_number('2990103')->is_valid_number, '千葉県市原市青柳海岸');
ok($zip->set_number('2990104')->is_valid_number, '千葉県市原市白塚');
ok($zip->set_number('2990105')->is_valid_number, '千葉県市原市柏原');
ok($zip->set_number('2990106')->is_valid_number, '千葉県市原市今津朝山');
ok($zip->set_number('2990107')->is_valid_number, '千葉県市原市姉崎海岸');
ok($zip->set_number('2990108')->is_valid_number, '千葉県市原市千種海岸');
ok($zip->set_number('2990109')->is_valid_number, '千葉県市原市千種');
ok($zip->set_number('2990110')->is_valid_number, '千葉県市原市姉崎東');
ok($zip->set_number('2990111')->is_valid_number, '千葉県市原市姉崎');
ok($zip->set_number('2990112')->is_valid_number, '千葉県市原市畑木');
ok($zip->set_number('2990113')->is_valid_number, '千葉県市原市片又木');
ok($zip->set_number('2990114')->is_valid_number, '千葉県市原市泉台');
ok($zip->set_number('2990115')->is_valid_number, '千葉県市原市不入斗');
ok($zip->set_number('2990116')->is_valid_number, '千葉県市原市迎田');
ok($zip->set_number('2990117')->is_valid_number, '千葉県市原市青葉台');
ok($zip->set_number('2990118')->is_valid_number, '千葉県市原市椎津');
ok($zip->set_number('2990119')->is_valid_number, '千葉県市原市姉崎西');
ok($zip->set_number('2990121')->is_valid_number, '千葉県市原市立野');
ok($zip->set_number('2990122')->is_valid_number, '千葉県市原市豊成');
ok($zip->set_number('2990123')->is_valid_number, '千葉県市原市深城');
ok($zip->set_number('2990124')->is_valid_number, '千葉県市原市有秋台東');
ok($zip->set_number('2990125')->is_valid_number, '千葉県市原市有秋台西');
ok($zip->set_number('2990126')->is_valid_number, '千葉県市原市天羽田');
ok($zip->set_number('2990127')->is_valid_number, '千葉県市原市桜台');
ok($zip->set_number('2990128')->is_valid_number, '千葉県市原市椎の木台');
ok($zip->set_number('2990200')->is_valid_number, '千葉県袖ケ浦市以下に掲載がない場合');
ok($zip->set_number('2990201')->is_valid_number, '千葉県袖ケ浦市川原井');
ok($zip->set_number('2990202')->is_valid_number, '千葉県袖ケ浦市林');
ok($zip->set_number('2990203')->is_valid_number, '千葉県袖ケ浦市高谷');
ok($zip->set_number('2990204')->is_valid_number, '千葉県袖ケ浦市永吉');
ok($zip->set_number('2990205')->is_valid_number, '千葉県袖ケ浦市上泉');
ok($zip->set_number('2990211')->is_valid_number, '千葉県袖ケ浦市野里');
ok($zip->set_number('2990212')->is_valid_number, '千葉県袖ケ浦市三箇');
ok($zip->set_number('2990213')->is_valid_number, '千葉県袖ケ浦市百目木');
ok($zip->set_number('2990214')->is_valid_number, '千葉県袖ケ浦市下根岸');
ok($zip->set_number('2990215')->is_valid_number, '千葉県袖ケ浦市堂谷');
ok($zip->set_number('2990216')->is_valid_number, '千葉県袖ケ浦市阿部');
ok($zip->set_number('2990217')->is_valid_number, '千葉県袖ケ浦市打越');
ok($zip->set_number('2990221')->is_valid_number, '千葉県袖ケ浦市大竹');
ok($zip->set_number('2990222')->is_valid_number, '千葉県袖ケ浦市上宮田');
ok($zip->set_number('2990223')->is_valid_number, '千葉県袖ケ浦市下宮田');
ok($zip->set_number('2990224')->is_valid_number, '千葉県袖ケ浦市吉野田');
ok($zip->set_number('2990225')->is_valid_number, '千葉県袖ケ浦市玉野');
ok($zip->set_number('2990226')->is_valid_number, '千葉県袖ケ浦市滝の口');
ok($zip->set_number('2990231')->is_valid_number, '千葉県袖ケ浦市下泉');
ok($zip->set_number('2990232')->is_valid_number, '千葉県袖ケ浦市永地');
ok($zip->set_number('2990233')->is_valid_number, '千葉県袖ケ浦市岩井');
ok($zip->set_number('2990234')->is_valid_number, '千葉県袖ケ浦市谷中');
ok($zip->set_number('2990235')->is_valid_number, '千葉県袖ケ浦市三黒');
ok($zip->set_number('2990236')->is_valid_number, '千葉県袖ケ浦市横田');
ok($zip->set_number('2990237')->is_valid_number, '千葉県袖ケ浦市大鳥居');
ok($zip->set_number('2990241')->is_valid_number, '千葉県袖ケ浦市代宿');
ok($zip->set_number('2990242')->is_valid_number, '千葉県袖ケ浦市久保田');
ok($zip->set_number('2990243')->is_valid_number, '千葉県袖ケ浦市蔵波');
ok($zip->set_number('2990244')->is_valid_number, '千葉県袖ケ浦市野田');
ok($zip->set_number('2990245')->is_valid_number, '千葉県袖ケ浦市蔵波台');
ok($zip->set_number('2990246')->is_valid_number, '千葉県袖ケ浦市長浦駅前');
ok($zip->set_number('2990247')->is_valid_number, '千葉県袖ケ浦市椎の森');
ok($zip->set_number('2990251')->is_valid_number, '千葉県袖ケ浦市のぞみ野');
ok($zip->set_number('2990252')->is_valid_number, '千葉県袖ケ浦市勝');
ok($zip->set_number('2990253')->is_valid_number, '千葉県袖ケ浦市大曽根');
ok($zip->set_number('2990254')->is_valid_number, '千葉県袖ケ浦市三ツ作');
ok($zip->set_number('2990255')->is_valid_number, '千葉県袖ケ浦市下新田');
ok($zip->set_number('2990256')->is_valid_number, '千葉県袖ケ浦市飯富');
ok($zip->set_number('2990257')->is_valid_number, '千葉県袖ケ浦市神納');
ok($zip->set_number('2990261')->is_valid_number, '千葉県袖ケ浦市福王台');
ok($zip->set_number('2990262')->is_valid_number, '千葉県袖ケ浦市坂戸市場');
ok($zip->set_number('2990263')->is_valid_number, '千葉県袖ケ浦市奈良輪');
ok($zip->set_number('2990264')->is_valid_number, '千葉県袖ケ浦市今井');
ok($zip->set_number('2990265')->is_valid_number, '千葉県袖ケ浦市長浦');
ok($zip->set_number('2990266')->is_valid_number, '千葉県袖ケ浦市北袖');
ok($zip->set_number('2990267')->is_valid_number, '千葉県袖ケ浦市中袖');
ok($zip->set_number('2990268')->is_valid_number, '千葉県袖ケ浦市南袖');
ok($zip->set_number('2990269')->is_valid_number, '千葉県袖ケ浦市袖ケ浦駅前');
ok($zip->set_number('2990271')->is_valid_number, '千葉県木更津市坂戸市場');
ok($zip->set_number('2991100')->is_valid_number, '千葉県君津市以下に掲載がない場合');
ok($zip->set_number('2991101')->is_valid_number, '千葉県君津市大鷲新田');
ok($zip->set_number('2991102')->is_valid_number, '千葉県君津市大鷲');
ok($zip->set_number('2991103')->is_valid_number, '千葉県君津市大井');
ok($zip->set_number('2991104')->is_valid_number, '千葉県君津市糠田');
ok($zip->set_number('2991105')->is_valid_number, '千葉県君津市白駒');
ok($zip->set_number('2991106')->is_valid_number, '千葉県君津市中島');
ok($zip->set_number('2991107')->is_valid_number, '千葉県君津市上');
ok($zip->set_number('2991108')->is_valid_number, '千葉県君津市練木');
ok($zip->set_number('2991111')->is_valid_number, '千葉県君津市六手');
ok($zip->set_number('2991112')->is_valid_number, '千葉県君津市泉');
ok($zip->set_number('2991113')->is_valid_number, '千葉県君津市尾車');
ok($zip->set_number('2991114')->is_valid_number, '千葉県君津市草牛');
ok($zip->set_number('2991115')->is_valid_number, '千葉県君津市馬登');
ok($zip->set_number('2991116')->is_valid_number, '千葉県君津市皿引');
ok($zip->set_number('2991117')->is_valid_number, '千葉県君津市宮下');
ok($zip->set_number('2991121')->is_valid_number, '千葉県君津市常代');
ok($zip->set_number('2991122')->is_valid_number, '千葉県君津市浜子');
ok($zip->set_number('2991123')->is_valid_number, '千葉県君津市大山野');
ok($zip->set_number('2991124')->is_valid_number, '千葉県君津市作木');
ok($zip->set_number('2991125')->is_valid_number, '千葉県君津市山高原');
ok($zip->set_number('2991126')->is_valid_number, '千葉県君津市小山野');
ok($zip->set_number('2991127')->is_valid_number, '千葉県君津市郡');
ok($zip->set_number('2991131')->is_valid_number, '千葉県君津市下湯江');
ok($zip->set_number('2991132')->is_valid_number, '千葉県君津市中富');
ok($zip->set_number('2991133')->is_valid_number, '千葉県君津市貞元');
ok($zip->set_number('2991134')->is_valid_number, '千葉県君津市八幡');
ok($zip->set_number('2991135')->is_valid_number, '千葉県君津市杉谷');
ok($zip->set_number('2991136')->is_valid_number, '千葉県君津市新御堂');
ok($zip->set_number('2991137')->is_valid_number, '千葉県君津市小香');
ok($zip->set_number('2991138')->is_valid_number, '千葉県君津市上湯江');
ok($zip->set_number('2991141')->is_valid_number, '千葉県君津市君津');
ok($zip->set_number('2991142')->is_valid_number, '千葉県君津市坂田');
ok($zip->set_number('2991143')->is_valid_number, '千葉県君津市君津台');
ok($zip->set_number('2991144')->is_valid_number, '千葉県君津市東坂田');
ok($zip->set_number('2991145')->is_valid_number, '千葉県君津市西坂田');
ok($zip->set_number('2991146')->is_valid_number, '千葉県君津市大和田');
ok($zip->set_number('2991147')->is_valid_number, '千葉県君津市人見');
ok($zip->set_number('2991151')->is_valid_number, '千葉県君津市中野');
ok($zip->set_number('2991152')->is_valid_number, '千葉県君津市久保');
ok($zip->set_number('2991153')->is_valid_number, '千葉県君津市台');
ok($zip->set_number('2991154')->is_valid_number, '千葉県君津市南久保');
ok($zip->set_number('2991161')->is_valid_number, '千葉県君津市北子安');
ok($zip->set_number('2991162')->is_valid_number, '千葉県君津市南子安');
ok($zip->set_number('2991163')->is_valid_number, '千葉県君津市杢師');
ok($zip->set_number('2991164')->is_valid_number, '千葉県君津市北久保');
ok($zip->set_number('2991165')->is_valid_number, '千葉県君津市高坂');
ok($zip->set_number('2991166')->is_valid_number, '千葉県君津市陽光台');
ok($zip->set_number('2991171')->is_valid_number, '千葉県君津市八重原');
ok($zip->set_number('2991172')->is_valid_number, '千葉県君津市三直');
ok($zip->set_number('2991173')->is_valid_number, '千葉県君津市外箕輪');
ok($zip->set_number('2991174')->is_valid_number, '千葉県君津市法木作');
ok($zip->set_number('2991175')->is_valid_number, '千葉県君津市内箕輪');
ok($zip->set_number('2991176')->is_valid_number, '千葉県君津市内蓑輪');
ok($zip->set_number('2991601')->is_valid_number, '千葉県富津市桜井総稱鬼泪山');
ok($zip->set_number('2991602')->is_valid_number, '千葉県富津市桜井');
ok($zip->set_number('2991603')->is_valid_number, '千葉県富津市更和');
ok($zip->set_number('2991604')->is_valid_number, '千葉県富津市台原');
ok($zip->set_number('2991605')->is_valid_number, '千葉県富津市望井');
ok($zip->set_number('2991606')->is_valid_number, '千葉県富津市数馬');
ok($zip->set_number('2991607')->is_valid_number, '千葉県富津市湊');
ok($zip->set_number('2991608')->is_valid_number, '千葉県富津市岩坂');
ok($zip->set_number('2991609')->is_valid_number, '千葉県富津市加藤');
ok($zip->set_number('2991611')->is_valid_number, '千葉県富津市長崎');
ok($zip->set_number('2991612')->is_valid_number, '千葉県富津市横山');
ok($zip->set_number('2991613')->is_valid_number, '千葉県富津市不入斗');
ok($zip->set_number('2991614')->is_valid_number, '千葉県富津市梨沢(その他)');
ok($zip->set_number('2991615')->is_valid_number, '千葉県富津市相川');
ok($zip->set_number('2991616')->is_valid_number, '千葉県富津市海良');
ok($zip->set_number('2991617')->is_valid_number, '千葉県富津市売津');
ok($zip->set_number('2991618')->is_valid_number, '千葉県富津市花輪');
ok($zip->set_number('2991621')->is_valid_number, '千葉県富津市竹岡');
ok($zip->set_number('2991622')->is_valid_number, '千葉県富津市萩生');
ok($zip->set_number('2991731')->is_valid_number, '千葉県富津市田倉');
ok($zip->set_number('2991732')->is_valid_number, '千葉県富津市宇藤原');
ok($zip->set_number('2991733')->is_valid_number, '千葉県富津市高溝');
ok($zip->set_number('2991734')->is_valid_number, '千葉県富津市関');
ok($zip->set_number('2991735')->is_valid_number, '千葉県富津市大田和');
ok($zip->set_number('2991736')->is_valid_number, '千葉県富津市大川崎');
ok($zip->set_number('2991737')->is_valid_number, '千葉県富津市東大和田');
ok($zip->set_number('2991741')->is_valid_number, '千葉県富津市御代原');
ok($zip->set_number('2991742')->is_valid_number, '千葉県富津市豊岡');
ok($zip->set_number('2991743')->is_valid_number, '千葉県富津市山中');
ok($zip->set_number('2991744')->is_valid_number, '千葉県富津市梨沢(東井戸堀)');
ok($zip->set_number('2991745')->is_valid_number, '千葉県富津市志駒');
ok($zip->set_number('2991746')->is_valid_number, '千葉県富津市岩本');
ok($zip->set_number('2991747')->is_valid_number, '千葉県富津市小志駒');
ok($zip->set_number('2991751')->is_valid_number, '千葉県富津市恩田');
ok($zip->set_number('2991752')->is_valid_number, '千葉県富津市関尻');
ok($zip->set_number('2991753')->is_valid_number, '千葉県富津市上後');
ok($zip->set_number('2991754')->is_valid_number, '千葉県富津市山脇');
ok($zip->set_number('2991755')->is_valid_number, '千葉県富津市田原');
ok($zip->set_number('2991756')->is_valid_number, '千葉県富津市六野');
ok($zip->set_number('2991757')->is_valid_number, '千葉県富津市押切');
ok($zip->set_number('2991758')->is_valid_number, '千葉県富津市大森');
ok($zip->set_number('2991759')->is_valid_number, '千葉県富津市寺尾');
ok($zip->set_number('2991861')->is_valid_number, '千葉県富津市金谷');
ok($zip->set_number('2991901')->is_valid_number, '千葉県安房郡鋸南町元名');
ok($zip->set_number('2991902')->is_valid_number, '千葉県安房郡鋸南町保田');
ok($zip->set_number('2991903')->is_valid_number, '千葉県安房郡鋸南町大帷子');
ok($zip->set_number('2991904')->is_valid_number, '千葉県安房郡鋸南町小保田');
ok($zip->set_number('2991905')->is_valid_number, '千葉県安房郡鋸南町市井原');
ok($zip->set_number('2991906')->is_valid_number, '千葉県安房郡鋸南町横根');
ok($zip->set_number('2991907')->is_valid_number, '千葉県安房郡鋸南町江月');
ok($zip->set_number('2991908')->is_valid_number, '千葉県安房郡鋸南町吉浜');
ok($zip->set_number('2991909')->is_valid_number, '千葉県安房郡鋸南町大六');
ok($zip->set_number('2992100')->is_valid_number, '千葉県安房郡鋸南町以下に掲載がない場合');
ok($zip->set_number('2992111')->is_valid_number, '千葉県安房郡鋸南町大崩');
ok($zip->set_number('2992112')->is_valid_number, '千葉県安房郡鋸南町奥山');
ok($zip->set_number('2992113')->is_valid_number, '千葉県安房郡鋸南町上佐久間');
ok($zip->set_number('2992114')->is_valid_number, '千葉県安房郡鋸南町中佐久間');
ok($zip->set_number('2992115')->is_valid_number, '千葉県安房郡鋸南町下佐久間');
ok($zip->set_number('2992116')->is_valid_number, '千葉県安房郡鋸南町岩井袋');
ok($zip->set_number('2992117')->is_valid_number, '千葉県安房郡鋸南町勝山');
ok($zip->set_number('2992118')->is_valid_number, '千葉県安房郡鋸南町竜島');
ok($zip->set_number('2992201')->is_valid_number, '千葉県南房総市荒川');
ok($zip->set_number('2992202')->is_valid_number, '千葉県南房総市平塚');
ok($zip->set_number('2992203')->is_valid_number, '千葉県南房総市山田');
ok($zip->set_number('2992204')->is_valid_number, '千葉県南房総市平久里中');
ok($zip->set_number('2992205')->is_valid_number, '千葉県南房総市犬掛');
ok($zip->set_number('2992206')->is_valid_number, '千葉県南房総市平久里下');
ok($zip->set_number('2992211')->is_valid_number, '千葉県南房総市川上');
ok($zip->set_number('2992212')->is_valid_number, '千葉県南房総市井野');
ok($zip->set_number('2992213')->is_valid_number, '千葉県南房総市吉沢');
ok($zip->set_number('2992214')->is_valid_number, '千葉県南房総市二部');
ok($zip->set_number('2992215')->is_valid_number, '千葉県南房総市検儀谷');
ok($zip->set_number('2992216')->is_valid_number, '千葉県南房総市久枝');
ok($zip->set_number('2992221')->is_valid_number, '千葉県南房総市合戸');
ok($zip->set_number('2992222')->is_valid_number, '千葉県南房総市宮谷');
ok($zip->set_number('2992223')->is_valid_number, '千葉県南房総市高崎');
ok($zip->set_number('2992224')->is_valid_number, '千葉県南房総市小浦');
ok($zip->set_number('2992225')->is_valid_number, '千葉県南房総市竹内');
ok($zip->set_number('2992226')->is_valid_number, '千葉県南房総市市部');
ok($zip->set_number('2992400')->is_valid_number, '千葉県南房総市以下に掲載がない場合');
ok($zip->set_number('2992401')->is_valid_number, '千葉県南房総市富浦町南無谷');
ok($zip->set_number('2992402')->is_valid_number, '千葉県南房総市富浦町豊岡');
ok($zip->set_number('2992403')->is_valid_number, '千葉県南房総市富浦町原岡');
ok($zip->set_number('2992404')->is_valid_number, '千葉県南房総市富浦町多田良');
ok($zip->set_number('2992411')->is_valid_number, '千葉県南房総市富浦町居倉');
ok($zip->set_number('2992412')->is_valid_number, '千葉県南房総市富浦町大津');
ok($zip->set_number('2992413')->is_valid_number, '千葉県南房総市富浦町宮本');
ok($zip->set_number('2992414')->is_valid_number, '千葉県南房総市富浦町福澤');
ok($zip->set_number('2992415')->is_valid_number, '千葉県南房総市富浦町深名');
ok($zip->set_number('2992416')->is_valid_number, '千葉県南房総市富浦町青木');
ok($zip->set_number('2992417')->is_valid_number, '千葉県南房総市富浦町丹生');
ok($zip->set_number('2992418')->is_valid_number, '千葉県南房総市富浦町手取');
ok($zip->set_number('2992501')->is_valid_number, '千葉県南房総市珠師ケ谷');
ok($zip->set_number('2992502')->is_valid_number, '千葉県南房総市石堂原');
ok($zip->set_number('2992503')->is_valid_number, '千葉県南房総市石堂');
ok($zip->set_number('2992504')->is_valid_number, '千葉県南房総市川谷');
ok($zip->set_number('2992505')->is_valid_number, '千葉県南房総市宮下');
ok($zip->set_number('2992506')->is_valid_number, '千葉県南房総市御子神');
ok($zip->set_number('2992507')->is_valid_number, '千葉県南房総市大井');
ok($zip->set_number('2992508')->is_valid_number, '千葉県南房総市丸山平塚');
ok($zip->set_number('2992511')->is_valid_number, '千葉県南房総市小戸');
ok($zip->set_number('2992512')->is_valid_number, '千葉県南房総市岩糸');
ok($zip->set_number('2992513')->is_valid_number, '千葉県南房総市古川');
ok($zip->set_number('2992514')->is_valid_number, '千葉県南房総市西原');
ok($zip->set_number('2992515')->is_valid_number, '千葉県南房総市石神');
ok($zip->set_number('2992516')->is_valid_number, '千葉県南房総市前田');
ok($zip->set_number('2992517')->is_valid_number, '千葉県南房総市丸本郷');
ok($zip->set_number('2992521')->is_valid_number, '千葉県南房総市白子');
ok($zip->set_number('2992522')->is_valid_number, '千葉県南房総市安馬谷');
ok($zip->set_number('2992523')->is_valid_number, '千葉県南房総市峰');
ok($zip->set_number('2992524')->is_valid_number, '千葉県南房総市久保');
ok($zip->set_number('2992525')->is_valid_number, '千葉県南房総市加茂');
ok($zip->set_number('2992526')->is_valid_number, '千葉県南房総市沓見');
ok($zip->set_number('2992701')->is_valid_number, '千葉県南房総市和田町花園');
ok($zip->set_number('2992702')->is_valid_number, '千葉県南房総市和田町柴');
ok($zip->set_number('2992703')->is_valid_number, '千葉県南房総市和田町仁我浦');
ok($zip->set_number('2992704')->is_valid_number, '千葉県南房総市和田町和田');
ok($zip->set_number('2992705')->is_valid_number, '千葉県南房総市和田町真浦');
ok($zip->set_number('2992711')->is_valid_number, '千葉県南房総市和田町白渚');
ok($zip->set_number('2992712')->is_valid_number, '千葉県南房総市和田町海発');
ok($zip->set_number('2992713')->is_valid_number, '千葉県南房総市和田町松田');
ok($zip->set_number('2992714')->is_valid_number, '千葉県南房総市和田町沼');
ok($zip->set_number('2992715')->is_valid_number, '千葉県南房総市和田町下三原');
ok($zip->set_number('2992716')->is_valid_number, '千葉県南房総市和田町中三原');
ok($zip->set_number('2992721')->is_valid_number, '千葉県南房総市和田町五十蔵');
ok($zip->set_number('2992722')->is_valid_number, '千葉県南房総市和田町磑森');
ok($zip->set_number('2992723')->is_valid_number, '千葉県南房総市和田町布野');
ok($zip->set_number('2992724')->is_valid_number, '千葉県南房総市和田町小向');
ok($zip->set_number('2992725')->is_valid_number, '千葉県南房総市和田町黒岩');
ok($zip->set_number('2992726')->is_valid_number, '千葉県南房総市和田町小川');
ok($zip->set_number('2992727')->is_valid_number, '千葉県南房総市和田町上三原');
ok($zip->set_number('2992728')->is_valid_number, '千葉県南房総市和田町石堂');
ok($zip->set_number('2992841')->is_valid_number, '千葉県鴨川市西江見');
ok($zip->set_number('2992842')->is_valid_number, '千葉県鴨川市江見青木');
ok($zip->set_number('2992843')->is_valid_number, '千葉県鴨川市東江見');
ok($zip->set_number('2992844')->is_valid_number, '千葉県鴨川市江見東真門');
ok($zip->set_number('2992845')->is_valid_number, '千葉県鴨川市江見西真門');
ok($zip->set_number('2992846')->is_valid_number, '千葉県鴨川市江見外堀');
ok($zip->set_number('2992847')->is_valid_number, '千葉県鴨川市江見内遠野');
ok($zip->set_number('2992851')->is_valid_number, '千葉県鴨川市仲町');
ok($zip->set_number('2992852')->is_valid_number, '千葉県鴨川市二子');
ok($zip->set_number('2992853')->is_valid_number, '千葉県鴨川市宮');
ok($zip->set_number('2992854')->is_valid_number, '千葉県鴨川市代');
ok($zip->set_number('2992855')->is_valid_number, '千葉県鴨川市畑');
ok($zip->set_number('2992856')->is_valid_number, '千葉県鴨川市西');
ok($zip->set_number('2992857')->is_valid_number, '千葉県鴨川市東');
ok($zip->set_number('2992858')->is_valid_number, '千葉県鴨川市上');
ok($zip->set_number('2992861')->is_valid_number, '千葉県鴨川市太海西');
ok($zip->set_number('2992862')->is_valid_number, '千葉県鴨川市太海');
ok($zip->set_number('2992863')->is_valid_number, '千葉県鴨川市太海浜');
ok($zip->set_number('2992864')->is_valid_number, '千葉県鴨川市天面');
ok($zip->set_number('2992865')->is_valid_number, '千葉県鴨川市江見太夫崎');
ok($zip->set_number('2992866')->is_valid_number, '千葉県鴨川市江見吉浦');
ok($zip->set_number('2992867')->is_valid_number, '千葉県鴨川市西山');
ok($zip->set_number('2993200')->is_valid_number, '千葉県大網白里市以下に掲載がない場合');
ok($zip->set_number('2993201')->is_valid_number, '千葉県大網白里市北今泉');
ok($zip->set_number('2993202')->is_valid_number, '千葉県大網白里市南今泉');
ok($zip->set_number('2993203')->is_valid_number, '千葉県大網白里市四天木');
ok($zip->set_number('2993211')->is_valid_number, '千葉県大網白里市細草');
ok($zip->set_number('2993212')->is_valid_number, '千葉県大網白里市清水');
ok($zip->set_number('2993213')->is_valid_number, '千葉県大網白里市二之袋');
ok($zip->set_number('2993214')->is_valid_number, '千葉県大網白里市下ヶ傍示');
ok($zip->set_number('2993215')->is_valid_number, '千葉県大網白里市長国');
ok($zip->set_number('2993216')->is_valid_number, '千葉県大網白里市北吉田');
ok($zip->set_number('2993217')->is_valid_number, '千葉県大網白里市木崎');
ok($zip->set_number('2993218')->is_valid_number, '千葉県大網白里市北飯塚');
ok($zip->set_number('2993219')->is_valid_number, '千葉県大網白里市南飯塚');
ok($zip->set_number('2993221')->is_valid_number, '千葉県大網白里市富田');
ok($zip->set_number('2993222')->is_valid_number, '千葉県大網白里市星谷');
ok($zip->set_number('2993223')->is_valid_number, '千葉県大網白里市南横川');
ok($zip->set_number('2993231')->is_valid_number, '千葉県大網白里市経田');
ok($zip->set_number('2993232')->is_valid_number, '千葉県大網白里市ながた野');
ok($zip->set_number('2993233')->is_valid_number, '千葉県大網白里市永田');
ok($zip->set_number('2993234')->is_valid_number, '千葉県大網白里市みずほ台');
ok($zip->set_number('2993235')->is_valid_number, '千葉県大網白里市駒込');
ok($zip->set_number('2993236')->is_valid_number, '千葉県大網白里市みやこ野');
ok($zip->set_number('2993237')->is_valid_number, '千葉県大網白里市仏島');
ok($zip->set_number('2993238')->is_valid_number, '千葉県大網白里市東駒込');
ok($zip->set_number('2993241')->is_valid_number, '千葉県大網白里市季美の森南');
ok($zip->set_number('2993242')->is_valid_number, '千葉県大網白里市金谷郷');
ok($zip->set_number('2993243')->is_valid_number, '千葉県大網白里市大竹');
ok($zip->set_number('2993244')->is_valid_number, '千葉県大網白里市南玉');
ok($zip->set_number('2993245')->is_valid_number, '千葉県大網白里市池田');
ok($zip->set_number('2993246')->is_valid_number, '千葉県大網白里市小中');
ok($zip->set_number('2993247')->is_valid_number, '千葉県大網白里市神房');
ok($zip->set_number('2993248')->is_valid_number, '千葉県大網白里市萱野');
ok($zip->set_number('2993249')->is_valid_number, '千葉県大網白里市砂田');
ok($zip->set_number('2993251')->is_valid_number, '千葉県大網白里市大網');
ok($zip->set_number('2993252')->is_valid_number, '千葉県大網白里市餅木');
ok($zip->set_number('2993253')->is_valid_number, '千葉県大網白里市小西');
ok($zip->set_number('2993254')->is_valid_number, '千葉県大網白里市養安寺');
ok($zip->set_number('2993255')->is_valid_number, '千葉県大網白里市みどりが丘');
ok($zip->set_number('2993256')->is_valid_number, '千葉県大網白里市山口');
ok($zip->set_number('2993261')->is_valid_number, '千葉県大網白里市九十根');
ok($zip->set_number('2993262')->is_valid_number, '千葉県大網白里市桂山');
ok($zip->set_number('2993263')->is_valid_number, '千葉県大網白里市柳橋');
ok($zip->set_number('2993264')->is_valid_number, '千葉県大網白里市柿餅');
ok($zip->set_number('2993265')->is_valid_number, '千葉県大網白里市上貝塚');
ok($zip->set_number('2993266')->is_valid_number, '千葉県大網白里市北横川');
ok($zip->set_number('2993267')->is_valid_number, '千葉県大網白里市清名幸谷');
ok($zip->set_number('2993268')->is_valid_number, '千葉県大網白里市上谷新田');
ok($zip->set_number('2994101')->is_valid_number, '千葉県茂原市清水');
ok($zip->set_number('2994102')->is_valid_number, '千葉県茂原市御蔵芝');
ok($zip->set_number('2994103')->is_valid_number, '千葉県茂原市千沢');
ok($zip->set_number('2994104')->is_valid_number, '千葉県茂原市南吉田');
ok($zip->set_number('2994105')->is_valid_number, '千葉県茂原市弓渡');
ok($zip->set_number('2994106')->is_valid_number, '千葉県茂原市粟生野');
ok($zip->set_number('2994111')->is_valid_number, '千葉県茂原市萱場');
ok($zip->set_number('2994112')->is_valid_number, '千葉県茂原市西野');
ok($zip->set_number('2994113')->is_valid_number, '千葉県茂原市法目');
ok($zip->set_number('2994114')->is_valid_number, '千葉県茂原市本納');
ok($zip->set_number('2994115')->is_valid_number, '千葉県茂原市榎神房');
ok($zip->set_number('2994116')->is_valid_number, '千葉県茂原市高田');
ok($zip->set_number('2994117')->is_valid_number, '千葉県茂原市小萱場');
ok($zip->set_number('2994118')->is_valid_number, '千葉県茂原市榎神房飛地');
ok($zip->set_number('2994121')->is_valid_number, '千葉県茂原市吉井下');
ok($zip->set_number('2994122')->is_valid_number, '千葉県茂原市吉井上');
ok($zip->set_number('2994123')->is_valid_number, '千葉県茂原市下太田');
ok($zip->set_number('2994124')->is_valid_number, '千葉県茂原市上太田');
ok($zip->set_number('2994125')->is_valid_number, '千葉県茂原市大沢');
ok($zip->set_number('2994126')->is_valid_number, '千葉県茂原市柴名');
ok($zip->set_number('2994127')->is_valid_number, '千葉県茂原市桂');
ok($zip->set_number('2994128')->is_valid_number, '千葉県茂原市桂飛地');
ok($zip->set_number('2994129')->is_valid_number, '千葉県茂原市にいはる工業団地');
ok($zip->set_number('2994200')->is_valid_number, '千葉県長生郡白子町以下に掲載がない場合');
ok($zip->set_number('2994201')->is_valid_number, '千葉県長生郡白子町浜宿');
ok($zip->set_number('2994202')->is_valid_number, '千葉県長生郡白子町牛込');
ok($zip->set_number('2994203')->is_valid_number, '千葉県長生郡白子町剃金');
ok($zip->set_number('2994204')->is_valid_number, '千葉県長生郡白子町福島');
ok($zip->set_number('2994205')->is_valid_number, '千葉県長生郡白子町南日当');
ok($zip->set_number('2994206')->is_valid_number, '千葉県長生郡白子町北日当');
ok($zip->set_number('2994211')->is_valid_number, '千葉県長生郡白子町五井');
ok($zip->set_number('2994212')->is_valid_number, '千葉県長生郡白子町古所');
ok($zip->set_number('2994213')->is_valid_number, '千葉県長生郡白子町八斗');
ok($zip->set_number('2994214')->is_valid_number, '千葉県長生郡白子町驚');
ok($zip->set_number('2994215')->is_valid_number, '千葉県長生郡白子町中里');
ok($zip->set_number('2994216')->is_valid_number, '千葉県長生郡白子町幸治');
ok($zip->set_number('2994217')->is_valid_number, '千葉県長生郡白子町北高根');
ok($zip->set_number('2994218')->is_valid_number, '千葉県長生郡白子町関');
ok($zip->set_number('2994300')->is_valid_number, '千葉県長生郡一宮町以下に掲載がない場合');
ok($zip->set_number('2994300')->is_valid_number, '千葉県長生郡長生村以下に掲載がない場合');
ok($zip->set_number('2994301')->is_valid_number, '千葉県長生郡一宮町一宮');
ok($zip->set_number('2994302')->is_valid_number, '千葉県長生郡一宮町田町');
ok($zip->set_number('2994303')->is_valid_number, '千葉県長生郡一宮町東浪見');
ok($zip->set_number('2994304')->is_valid_number, '千葉県長生郡一宮町綱田');
ok($zip->set_number('2994305')->is_valid_number, '千葉県長生郡一宮町本給');
ok($zip->set_number('2994306')->is_valid_number, '千葉県長生郡一宮町東野');
ok($zip->set_number('2994311')->is_valid_number, '千葉県長生郡一宮町白山');
ok($zip->set_number('2994312')->is_valid_number, '千葉県長生郡一宮町宮原');
ok($zip->set_number('2994313')->is_valid_number, '千葉県長生郡一宮町船頭給');
ok($zip->set_number('2994314')->is_valid_number, '千葉県長生郡一宮町新地');
ok($zip->set_number('2994315')->is_valid_number, '千葉県長生郡一宮町新地甲');
ok($zip->set_number('2994316')->is_valid_number, '千葉県長生郡一宮町新地丙');
ok($zip->set_number('2994321')->is_valid_number, '千葉県長生郡長生村入山津');
ok($zip->set_number('2994322')->is_valid_number, '千葉県長生郡長生村驚');
ok($zip->set_number('2994323')->is_valid_number, '千葉県長生郡長生村一松戊');
ok($zip->set_number('2994324')->is_valid_number, '千葉県長生郡長生村一松丁');
ok($zip->set_number('2994325')->is_valid_number, '千葉県長生郡長生村一松丙');
ok($zip->set_number('2994326')->is_valid_number, '千葉県長生郡長生村一松乙');
ok($zip->set_number('2994327')->is_valid_number, '千葉県長生郡長生村一松');
ok($zip->set_number('2994328')->is_valid_number, '千葉県長生郡長生村一松甲');
ok($zip->set_number('2994331')->is_valid_number, '千葉県長生郡長生村信友');
ok($zip->set_number('2994332')->is_valid_number, '千葉県長生郡長生村金田');
ok($zip->set_number('2994333')->is_valid_number, '千葉県長生郡長生村七井土');
ok($zip->set_number('2994334')->is_valid_number, '千葉県長生郡長生村薮塚');
ok($zip->set_number('2994335')->is_valid_number, '千葉県長生郡長生村水口');
ok($zip->set_number('2994336')->is_valid_number, '千葉県長生郡長生村岩沼');
ok($zip->set_number('2994337')->is_valid_number, '千葉県長生郡長生村北水口');
ok($zip->set_number('2994338')->is_valid_number, '千葉県長生郡長生村六ツ野飛地');
ok($zip->set_number('2994341')->is_valid_number, '千葉県長生郡長生村宮成');
ok($zip->set_number('2994342')->is_valid_number, '千葉県長生郡長生村一松飛地甲');
ok($zip->set_number('2994343')->is_valid_number, '千葉県長生郡長生村岩沼飛地');
ok($zip->set_number('2994344')->is_valid_number, '千葉県長生郡長生村曽根');
ok($zip->set_number('2994345')->is_valid_number, '千葉県長生郡長生村本郷');
ok($zip->set_number('2994346')->is_valid_number, '千葉県長生郡長生村中之郷');
ok($zip->set_number('2994347')->is_valid_number, '千葉県長生郡長生村小泉');
ok($zip->set_number('2994400')->is_valid_number, '千葉県長生郡睦沢町以下に掲載がない場合');
ok($zip->set_number('2994401')->is_valid_number, '千葉県長生郡睦沢町寺崎');
ok($zip->set_number('2994402')->is_valid_number, '千葉県長生郡睦沢町川島');
ok($zip->set_number('2994403')->is_valid_number, '千葉県長生郡睦沢町上市場');
ok($zip->set_number('2994404')->is_valid_number, '千葉県長生郡睦沢町北山田');
ok($zip->set_number('2994405')->is_valid_number, '千葉県長生郡睦沢町大谷木');
ok($zip->set_number('2994406')->is_valid_number, '千葉県長生郡睦沢町北山田寺崎新田');
ok($zip->set_number('2994411')->is_valid_number, '千葉県長生郡睦沢町河須ケ谷');
ok($zip->set_number('2994412')->is_valid_number, '千葉県長生郡睦沢町岩井');
ok($zip->set_number('2994413')->is_valid_number, '千葉県長生郡睦沢町上之郷');
ok($zip->set_number('2994414')->is_valid_number, '千葉県長生郡睦沢町下之郷');
ok($zip->set_number('2994415')->is_valid_number, '千葉県長生郡睦沢町小滝');
ok($zip->set_number('2994421')->is_valid_number, '千葉県長生郡睦沢町長楽寺');
ok($zip->set_number('2994422')->is_valid_number, '千葉県長生郡睦沢町森');
ok($zip->set_number('2994423')->is_valid_number, '千葉県長生郡睦沢町大上');
ok($zip->set_number('2994424')->is_valid_number, '千葉県長生郡睦沢町妙楽寺');
ok($zip->set_number('2994425')->is_valid_number, '千葉県長生郡睦沢町佐貫');
ok($zip->set_number('2994501')->is_valid_number, '千葉県いすみ市岬町椎木');
ok($zip->set_number('2994502')->is_valid_number, '千葉県いすみ市岬町中原');
ok($zip->set_number('2994503')->is_valid_number, '千葉県いすみ市岬町和泉(その他)');
ok($zip->set_number('2994504')->is_valid_number, '千葉県いすみ市岬町桑田');
ok($zip->set_number('2994505')->is_valid_number, '千葉県いすみ市岬町岩熊');
ok($zip->set_number('2994506')->is_valid_number, '千葉県いすみ市岬町市野々');
ok($zip->set_number('2994507')->is_valid_number, '千葉県いすみ市岬町谷上');
ok($zip->set_number('2994508')->is_valid_number, '千葉県いすみ市岬町榎沢');
ok($zip->set_number('2994611')->is_valid_number, '千葉県いすみ市岬町和泉(4400番以上)');
ok($zip->set_number('2994612')->is_valid_number, '千葉県いすみ市岬町江場土');
ok($zip->set_number('2994613')->is_valid_number, '千葉県いすみ市岬町三門');
ok($zip->set_number('2994614')->is_valid_number, '千葉県いすみ市岬町東小高');
ok($zip->set_number('2994615')->is_valid_number, '千葉県いすみ市岬町井沢');
ok($zip->set_number('2994616')->is_valid_number, '千葉県いすみ市岬町長者');
ok($zip->set_number('2994621')->is_valid_number, '千葉県いすみ市岬町東中滝');
ok($zip->set_number('2994622')->is_valid_number, '千葉県いすみ市岬町押日');
ok($zip->set_number('2994623')->is_valid_number, '千葉県いすみ市岬町中滝');
ok($zip->set_number('2994624')->is_valid_number, '千葉県いすみ市岬町鴨根');
ok($zip->set_number('2994625')->is_valid_number, '千葉県いすみ市岬町嘉谷');
ok($zip->set_number('2995100')->is_valid_number, '千葉県夷隅郡御宿町以下に掲載がない場合');
ok($zip->set_number('2995101')->is_valid_number, '千葉県夷隅郡御宿町高山田');
ok($zip->set_number('2995102')->is_valid_number, '千葉県夷隅郡御宿町久保');
ok($zip->set_number('2995103')->is_valid_number, '千葉県夷隅郡御宿町新町');
ok($zip->set_number('2995104')->is_valid_number, '千葉県夷隅郡御宿町六軒町');
ok($zip->set_number('2995105')->is_valid_number, '千葉県夷隅郡御宿町岩和田');
ok($zip->set_number('2995106')->is_valid_number, '千葉県夷隅郡御宿町須賀');
ok($zip->set_number('2995107')->is_valid_number, '千葉県夷隅郡御宿町浜');
ok($zip->set_number('2995111')->is_valid_number, '千葉県夷隅郡御宿町上布施');
ok($zip->set_number('2995112')->is_valid_number, '千葉県夷隅郡御宿町御宿台');
ok($zip->set_number('2995113')->is_valid_number, '千葉県夷隅郡御宿町七本');
ok($zip->set_number('2995114')->is_valid_number, '千葉県夷隅郡御宿町実谷');
ok($zip->set_number('2995200')->is_valid_number, '千葉県勝浦市以下に掲載がない場合');
ok($zip->set_number('2995201')->is_valid_number, '千葉県勝浦市市野郷');
ok($zip->set_number('2995202')->is_valid_number, '千葉県勝浦市市野川');
ok($zip->set_number('2995203')->is_valid_number, '千葉県勝浦市花里');
ok($zip->set_number('2995204')->is_valid_number, '千葉県勝浦市中倉');
ok($zip->set_number('2995205')->is_valid_number, '千葉県勝浦市杉戸');
ok($zip->set_number('2995206')->is_valid_number, '千葉県勝浦市佐野');
ok($zip->set_number('2995211')->is_valid_number, '千葉県勝浦市松野');
ok($zip->set_number('2995212')->is_valid_number, '千葉県勝浦市蟹田');
ok($zip->set_number('2995213')->is_valid_number, '千葉県勝浦市芳賀');
ok($zip->set_number('2995214')->is_valid_number, '千葉県勝浦市白木');
ok($zip->set_number('2995215')->is_valid_number, '千葉県勝浦市白井久保');
ok($zip->set_number('2995216')->is_valid_number, '千葉県勝浦市宿戸');
ok($zip->set_number('2995217')->is_valid_number, '千葉県勝浦市大楠');
ok($zip->set_number('2995218')->is_valid_number, '千葉県勝浦市小羽戸');
ok($zip->set_number('2995219')->is_valid_number, '千葉県勝浦市小松野');
ok($zip->set_number('2995221')->is_valid_number, '千葉県勝浦市平田');
ok($zip->set_number('2995222')->is_valid_number, '千葉県勝浦市関谷');
ok($zip->set_number('2995223')->is_valid_number, '千葉県勝浦市部原');
ok($zip->set_number('2995224')->is_valid_number, '千葉県勝浦市新官');
ok($zip->set_number('2995225')->is_valid_number, '千葉県勝浦市墨名');
ok($zip->set_number('2995226')->is_valid_number, '千葉県勝浦市串浜');
ok($zip->set_number('2995227')->is_valid_number, '千葉県勝浦市中谷');
ok($zip->set_number('2995228')->is_valid_number, '千葉県勝浦市新戸');
ok($zip->set_number('2995231')->is_valid_number, '千葉県勝浦市沢倉');
ok($zip->set_number('2995232')->is_valid_number, '千葉県勝浦市川津');
ok($zip->set_number('2995233')->is_valid_number, '千葉県勝浦市浜勝浦');
ok($zip->set_number('2995234')->is_valid_number, '千葉県勝浦市勝浦');
ok($zip->set_number('2995235')->is_valid_number, '千葉県勝浦市出水');
ok($zip->set_number('2995241')->is_valid_number, '千葉県勝浦市松部');
ok($zip->set_number('2995242')->is_valid_number, '千葉県勝浦市吉尾');
ok($zip->set_number('2995243')->is_valid_number, '千葉県勝浦市鵜原');
ok($zip->set_number('2995244')->is_valid_number, '千葉県勝浦市守谷');
ok($zip->set_number('2995245')->is_valid_number, '千葉県勝浦市興津');
ok($zip->set_number('2995246')->is_valid_number, '千葉県勝浦市興津久保山台');
ok($zip->set_number('2995251')->is_valid_number, '千葉県勝浦市大森上植野入会地');
ok($zip->set_number('2995252')->is_valid_number, '千葉県勝浦市上植野');
ok($zip->set_number('2995253')->is_valid_number, '千葉県勝浦市名木');
ok($zip->set_number('2995254')->is_valid_number, '千葉県勝浦市台宿');
ok($zip->set_number('2995255')->is_valid_number, '千葉県勝浦市浜行川');
ok($zip->set_number('2995256')->is_valid_number, '千葉県勝浦市大沢');
ok($zip->set_number('2995261')->is_valid_number, '千葉県勝浦市大森');
ok($zip->set_number('2995262')->is_valid_number, '千葉県勝浦市中里');
ok($zip->set_number('2995263')->is_valid_number, '千葉県勝浦市赤羽根');
ok($zip->set_number('2995264')->is_valid_number, '千葉県勝浦市中島');
ok($zip->set_number('2995265')->is_valid_number, '千葉県勝浦市植野');
ok($zip->set_number('2995266')->is_valid_number, '千葉県勝浦市上野');
ok($zip->set_number('2995267')->is_valid_number, '千葉県勝浦市植野元宮田');
ok($zip->set_number('2995271')->is_valid_number, '千葉県勝浦市法花');
ok($zip->set_number('2995272')->is_valid_number, '千葉県勝浦市貝掛');
ok($zip->set_number('2995273')->is_valid_number, '千葉県勝浦市荒川');
ok($zip->set_number('2995274')->is_valid_number, '千葉県勝浦市南山田');
ok($zip->set_number('2995501')->is_valid_number, '千葉県鴨川市小湊');
ok($zip->set_number('2995502')->is_valid_number, '千葉県鴨川市内浦');
ok($zip->set_number('2995503')->is_valid_number, '千葉県鴨川市天津');
ok($zip->set_number('2995504')->is_valid_number, '千葉県鴨川市浜荻');
ok($zip->set_number('2995505')->is_valid_number, '千葉県鴨川市清澄');
ok($zip->set_number('2995506')->is_valid_number, '千葉県鴨川市四方木');
ok($zip->set_number('3000000')->is_valid_number, '茨城県土浦市以下に掲載がない場合');
ok($zip->set_number('3000001')->is_valid_number, '茨城県土浦市今泉');
ok($zip->set_number('3000002')->is_valid_number, '茨城県土浦市粟野町');
ok($zip->set_number('3000003')->is_valid_number, '茨城県土浦市紫ケ丘');
ok($zip->set_number('3000004')->is_valid_number, '茨城県土浦市小山崎');
ok($zip->set_number('3000005')->is_valid_number, '茨城県土浦市中貫');
ok($zip->set_number('3000006')->is_valid_number, '茨城県土浦市東中貫町');
ok($zip->set_number('3000007')->is_valid_number, '茨城県土浦市板谷');
ok($zip->set_number('3000008')->is_valid_number, '茨城県土浦市笠師町');
ok($zip->set_number('3000009')->is_valid_number, '茨城県土浦市中都町');
ok($zip->set_number('3000011')->is_valid_number, '茨城県土浦市神立中央');
ok($zip->set_number('3000012')->is_valid_number, '茨城県土浦市神立東');
ok($zip->set_number('3000013')->is_valid_number, '茨城県土浦市神立町');
ok($zip->set_number('3000014')->is_valid_number, '茨城県土浦市西神立');
ok($zip->set_number('3000015')->is_valid_number, '茨城県土浦市北神立町');
ok($zip->set_number('3000016')->is_valid_number, '茨城県土浦市中神立町');
ok($zip->set_number('3000021')->is_valid_number, '茨城県土浦市菅谷町');
ok($zip->set_number('3000022')->is_valid_number, '茨城県土浦市白鳥町');
ok($zip->set_number('3000023')->is_valid_number, '茨城県土浦市沖宿町');
ok($zip->set_number('3000024')->is_valid_number, '茨城県土浦市田村町');
ok($zip->set_number('3000025')->is_valid_number, '茨城県土浦市手野町');
ok($zip->set_number('3000026')->is_valid_number, '茨城県土浦市木田余');
ok($zip->set_number('3000027')->is_valid_number, '茨城県土浦市木田余東台');
ok($zip->set_number('3000028')->is_valid_number, '茨城県土浦市おおつ野');
ok($zip->set_number('3000031')->is_valid_number, '茨城県土浦市東崎町');
ok($zip->set_number('3000032')->is_valid_number, '茨城県土浦市湖北');
ok($zip->set_number('3000033')->is_valid_number, '茨城県土浦市川口');
ok($zip->set_number('3000034')->is_valid_number, '茨城県土浦市港町');
ok($zip->set_number('3000035')->is_valid_number, '茨城県土浦市有明町');
ok($zip->set_number('3000036')->is_valid_number, '茨城県土浦市大和町');
ok($zip->set_number('3000037')->is_valid_number, '茨城県土浦市桜町');
ok($zip->set_number('3000038')->is_valid_number, '茨城県土浦市大町');
ok($zip->set_number('3000041')->is_valid_number, '茨城県土浦市立田町');
ok($zip->set_number('3000042')->is_valid_number, '茨城県土浦市城北町');
ok($zip->set_number('3000043')->is_valid_number, '茨城県土浦市中央');
ok($zip->set_number('3000044')->is_valid_number, '茨城県土浦市大手町');
ok($zip->set_number('3000045')->is_valid_number, '茨城県土浦市文京町');
ok($zip->set_number('3000046')->is_valid_number, '茨城県土浦市千束町');
ok($zip->set_number('3000047')->is_valid_number, '茨城県土浦市生田町');
ok($zip->set_number('3000048')->is_valid_number, '茨城県土浦市田中');
ok($zip->set_number('3000049')->is_valid_number, '茨城県土浦市田中町');
ok($zip->set_number('3000051')->is_valid_number, '茨城県土浦市真鍋');
ok($zip->set_number('3000052')->is_valid_number, '茨城県土浦市東真鍋町');
ok($zip->set_number('3000053')->is_valid_number, '茨城県土浦市真鍋新町');
ok($zip->set_number('3000054')->is_valid_number, '茨城県土浦市西真鍋町');
ok($zip->set_number('3000055')->is_valid_number, '茨城県土浦市殿里');
ok($zip->set_number('3000056')->is_valid_number, '茨城県土浦市木田余西台');
ok($zip->set_number('3000061')->is_valid_number, '茨城県土浦市並木');
ok($zip->set_number('3000062')->is_valid_number, '茨城県土浦市都和');
ok($zip->set_number('3000063')->is_valid_number, '茨城県土浦市若松町');
ok($zip->set_number('3000064')->is_valid_number, '茨城県土浦市東若松町');
ok($zip->set_number('3000065')->is_valid_number, '茨城県土浦市常名');
ok($zip->set_number('3000066')->is_valid_number, '茨城県土浦市虫掛');
ok($zip->set_number('3000067')->is_valid_number, '茨城県土浦市東都和');
ok($zip->set_number('3000068')->is_valid_number, '茨城県土浦市西並木町');
ok($zip->set_number('3000069')->is_valid_number, '茨城県土浦市東並木町');
ok($zip->set_number('3000121')->is_valid_number, '茨城県かすみがうら市宍倉');
ok($zip->set_number('3000122')->is_valid_number, '茨城県かすみがうら市西成井');
ok($zip->set_number('3000123')->is_valid_number, '茨城県かすみがうら市上軽部');
ok($zip->set_number('3000124')->is_valid_number, '茨城県かすみがうら市大和田');
ok($zip->set_number('3000125')->is_valid_number, '茨城県かすみがうら市三ツ木');
ok($zip->set_number('3000126')->is_valid_number, '茨城県かすみがうら市南根本');
ok($zip->set_number('3000127')->is_valid_number, '茨城県かすみがうら市上大堤');
ok($zip->set_number('3000131')->is_valid_number, '茨城県かすみがうら市下大堤');
ok($zip->set_number('3000132')->is_valid_number, '茨城県かすみがうら市男神');
ok($zip->set_number('3000133')->is_valid_number, '茨城県かすみがうら市中台');
ok($zip->set_number('3000134')->is_valid_number, '茨城県かすみがうら市深谷');
ok($zip->set_number('3000135')->is_valid_number, '茨城県かすみがうら市加茂');
ok($zip->set_number('3000136')->is_valid_number, '茨城県かすみがうら市戸崎');
ok($zip->set_number('3000201')->is_valid_number, '茨城県かすみがうら市柏崎');
ok($zip->set_number('3000202')->is_valid_number, '茨城県かすみがうら市田伏');
ok($zip->set_number('3000203')->is_valid_number, '茨城県かすみがうら市岩坪');
ok($zip->set_number('3000204')->is_valid_number, '茨城県かすみがうら市下軽部');
ok($zip->set_number('3000205')->is_valid_number, '茨城県かすみがうら市安食');
ok($zip->set_number('3000211')->is_valid_number, '茨城県かすみがうら市志戸崎');
ok($zip->set_number('3000212')->is_valid_number, '茨城県かすみがうら市有河');
ok($zip->set_number('3000213')->is_valid_number, '茨城県かすみがうら市牛渡');
ok($zip->set_number('3000214')->is_valid_number, '茨城県かすみがうら市坂');
ok($zip->set_number('3000300')->is_valid_number, '茨城県稲敷郡阿見町以下に掲載がない場合');
ok($zip->set_number('3000301')->is_valid_number, '茨城県稲敷郡阿見町青宿');
ok($zip->set_number('3000302')->is_valid_number, '茨城県稲敷郡阿見町廻戸');
ok($zip->set_number('3000303')->is_valid_number, '茨城県稲敷郡阿見町大室');
ok($zip->set_number('3000304')->is_valid_number, '茨城県稲敷郡阿見町掛馬');
ok($zip->set_number('3000305')->is_valid_number, '茨城県稲敷郡阿見町竹来');
ok($zip->set_number('3000306')->is_valid_number, '茨城県稲敷郡阿見町曙');
ok($zip->set_number('3000311')->is_valid_number, '茨城県稲敷郡阿見町島津');
ok($zip->set_number('3000312')->is_valid_number, '茨城県稲敷郡阿見町南平台');
ok($zip->set_number('3000313')->is_valid_number, '茨城県稲敷郡阿見町石川');
ok($zip->set_number('3000314')->is_valid_number, '茨城県稲敷郡阿見町追原');
ok($zip->set_number('3000315')->is_valid_number, '茨城県稲敷郡阿見町香澄の里');
ok($zip->set_number('3000321')->is_valid_number, '茨城県稲敷郡阿見町塙');
ok($zip->set_number('3000322')->is_valid_number, '茨城県稲敷郡阿見町君島');
ok($zip->set_number('3000323')->is_valid_number, '茨城県稲敷郡阿見町大形');
ok($zip->set_number('3000324')->is_valid_number, '茨城県稲敷郡阿見町飯倉');
ok($zip->set_number('3000325')->is_valid_number, '茨城県稲敷郡阿見町上条');
ok($zip->set_number('3000326')->is_valid_number, '茨城県稲敷郡阿見町星の里');
ok($zip->set_number('3000331')->is_valid_number, '茨城県稲敷郡阿見町阿見');
ok($zip->set_number('3000332')->is_valid_number, '茨城県稲敷郡阿見町中央');
ok($zip->set_number('3000333')->is_valid_number, '茨城県稲敷郡阿見町若栗');
ok($zip->set_number('3000334')->is_valid_number, '茨城県稲敷郡阿見町鈴木');
ok($zip->set_number('3000335')->is_valid_number, '茨城県稲敷郡阿見町岡崎');
ok($zip->set_number('3000336')->is_valid_number, '茨城県稲敷郡阿見町西郷');
ok($zip->set_number('3000337')->is_valid_number, '茨城県稲敷郡阿見町中郷');
ok($zip->set_number('3000341')->is_valid_number, '茨城県稲敷郡阿見町うずら野');
ok($zip->set_number('3000400')->is_valid_number, '茨城県稲敷郡美浦村以下に掲載がない場合');
ok($zip->set_number('3000401')->is_valid_number, '茨城県稲敷郡美浦村馬掛');
ok($zip->set_number('3000402')->is_valid_number, '茨城県稲敷郡美浦村大山');
ok($zip->set_number('3000403')->is_valid_number, '茨城県稲敷郡美浦村馬見山');
ok($zip->set_number('3000404')->is_valid_number, '茨城県稲敷郡美浦村土浦');
ok($zip->set_number('3000405')->is_valid_number, '茨城県稲敷郡美浦村間野');
ok($zip->set_number('3000406')->is_valid_number, '茨城県稲敷郡美浦村山内');
ok($zip->set_number('3000407')->is_valid_number, '茨城県稲敷郡美浦村八井田');
ok($zip->set_number('3000408')->is_valid_number, '茨城県稲敷郡美浦村根火');
ok($zip->set_number('3000409')->is_valid_number, '茨城県稲敷郡美浦村牛込');
ok($zip->set_number('3000410')->is_valid_number, '茨城県稲敷郡美浦村みどり台');
ok($zip->set_number('3000411')->is_valid_number, '茨城県稲敷郡美浦村太田');
ok($zip->set_number('3000412')->is_valid_number, '茨城県稲敷郡美浦村宮地');
ok($zip->set_number('3000413')->is_valid_number, '茨城県稲敷郡美浦村大谷');
ok($zip->set_number('3000414')->is_valid_number, '茨城県稲敷郡美浦村信太');
ok($zip->set_number('3000415')->is_valid_number, '茨城県稲敷郡美浦村美駒');
ok($zip->set_number('3000416')->is_valid_number, '茨城県稲敷郡美浦村大塚');
ok($zip->set_number('3000417')->is_valid_number, '茨城県稲敷郡美浦村谷中');
ok($zip->set_number('3000418')->is_valid_number, '茨城県稲敷郡美浦村花見塚');
ok($zip->set_number('3000419')->is_valid_number, '茨城県稲敷郡美浦村山王');
ok($zip->set_number('3000420')->is_valid_number, '茨城県稲敷郡美浦村郷中');
ok($zip->set_number('3000421')->is_valid_number, '茨城県稲敷郡美浦村木原');
ok($zip->set_number('3000422')->is_valid_number, '茨城県稲敷郡美浦村大須賀津');
ok($zip->set_number('3000423')->is_valid_number, '茨城県稲敷郡美浦村茂呂');
ok($zip->set_number('3000424')->is_valid_number, '茨城県稲敷郡美浦村受領');
ok($zip->set_number('3000425')->is_valid_number, '茨城県稲敷郡美浦村興津');
ok($zip->set_number('3000426')->is_valid_number, '茨城県稲敷郡美浦村土屋');
ok($zip->set_number('3000427')->is_valid_number, '茨城県稲敷郡美浦村布佐');
ok($zip->set_number('3000428')->is_valid_number, '茨城県稲敷郡美浦村舟子');
ok($zip->set_number('3000431')->is_valid_number, '茨城県稲敷郡美浦村本橋');
ok($zip->set_number('3000432')->is_valid_number, '茨城県稲敷郡美浦村定光');
ok($zip->set_number('3000433')->is_valid_number, '茨城県稲敷郡美浦村木');
ok($zip->set_number('3000434')->is_valid_number, '茨城県稲敷郡美浦村堀田');
ok($zip->set_number('3000435')->is_valid_number, '茨城県稲敷郡美浦村中野内');
ok($zip->set_number('3000436')->is_valid_number, '茨城県稲敷郡美浦村根本');
ok($zip->set_number('3000437')->is_valid_number, '茨城県稲敷郡美浦村見晴');
ok($zip->set_number('3000500')->is_valid_number, '茨城県稲敷市以下に掲載がない場合');
ok($zip->set_number('3000501')->is_valid_number, '茨城県稲敷市鳩崎');
ok($zip->set_number('3000502')->is_valid_number, '茨城県稲敷市信太古渡');
ok($zip->set_number('3000503')->is_valid_number, '茨城県稲敷市稲波');
ok($zip->set_number('3000504')->is_valid_number, '茨城県稲敷市江戸崎甲');
ok($zip->set_number('3000505')->is_valid_number, '茨城県稲敷市村田');
ok($zip->set_number('3000506')->is_valid_number, '茨城県稲敷市沼田');
ok($zip->set_number('3000507')->is_valid_number, '茨城県稲敷市犬塚');
ok($zip->set_number('3000508')->is_valid_number, '茨城県稲敷市佐倉');
ok($zip->set_number('3000509')->is_valid_number, '茨城県稲敷市江戸崎乙');
ok($zip->set_number('3000511')->is_valid_number, '茨城県稲敷市高田');
ok($zip->set_number('3000512')->is_valid_number, '茨城県稲敷市椎塚');
ok($zip->set_number('3000513')->is_valid_number, '茨城県稲敷市桑山');
ok($zip->set_number('3000514')->is_valid_number, '茨城県稲敷市駒塚');
ok($zip->set_number('3000515')->is_valid_number, '茨城県稲敷市南ケ丘');
ok($zip->set_number('3000521')->is_valid_number, '茨城県稲敷市月出里');
ok($zip->set_number('3000522')->is_valid_number, '茨城県稲敷市蒲ケ山');
ok($zip->set_number('3000523')->is_valid_number, '茨城県稲敷市時崎');
ok($zip->set_number('3000524')->is_valid_number, '茨城県稲敷市小羽賀');
ok($zip->set_number('3000525')->is_valid_number, '茨城県稲敷市羽賀');
ok($zip->set_number('3000526')->is_valid_number, '茨城県稲敷市松山');
ok($zip->set_number('3000527')->is_valid_number, '茨城県稲敷市下君山');
ok($zip->set_number('3000528')->is_valid_number, '茨城県稲敷市上君山');
ok($zip->set_number('3000529')->is_valid_number, '茨城県稲敷市江戸崎みらい');
ok($zip->set_number('3000601')->is_valid_number, '茨城県稲敷市下須田');
ok($zip->set_number('3000602')->is_valid_number, '茨城県稲敷市阿波崎');
ok($zip->set_number('3000603')->is_valid_number, '茨城県稲敷市伊佐部');
ok($zip->set_number('3000604')->is_valid_number, '茨城県稲敷市釜井');
ok($zip->set_number('3000605')->is_valid_number, '茨城県稲敷市幸田');
ok($zip->set_number('3000606')->is_valid_number, '茨城県稲敷市脇川');
ok($zip->set_number('3000607')->is_valid_number, '茨城県稲敷市光葉');
ok($zip->set_number('3000611')->is_valid_number, '茨城県稲敷市中島');
ok($zip->set_number('3000612')->is_valid_number, '茨城県稲敷市市崎');
ok($zip->set_number('3000613')->is_valid_number, '茨城県稲敷市新橋');
ok($zip->set_number('3000614')->is_valid_number, '茨城県稲敷市清水');
ok($zip->set_number('3000615')->is_valid_number, '茨城県稲敷市町田');
ok($zip->set_number('3000616')->is_valid_number, '茨城県稲敷市東大沼');
ok($zip->set_number('3000617')->is_valid_number, '茨城県稲敷市福田');
ok($zip->set_number('3000621')->is_valid_number, '茨城県稲敷市阿波');
ok($zip->set_number('3000622')->is_valid_number, '茨城県稲敷市神宮寺');
ok($zip->set_number('3000623')->is_valid_number, '茨城県稲敷市四箇');
ok($zip->set_number('3000624')->is_valid_number, '茨城県稲敷市南山来');
ok($zip->set_number('3000625')->is_valid_number, '茨城県稲敷市須賀津');
ok($zip->set_number('3000626')->is_valid_number, '茨城県稲敷市甘田');
ok($zip->set_number('3000631')->is_valid_number, '茨城県稲敷市三次');
ok($zip->set_number('3000632')->is_valid_number, '茨城県稲敷市飯出');
ok($zip->set_number('3000633')->is_valid_number, '茨城県稲敷市岡飯出');
ok($zip->set_number('3000634')->is_valid_number, '茨城県稲敷市柏木');
ok($zip->set_number('3000635')->is_valid_number, '茨城県稲敷市堀之内');
ok($zip->set_number('3000636')->is_valid_number, '茨城県稲敷市羽生');
ok($zip->set_number('3000637')->is_valid_number, '茨城県稲敷市柏木古渡');
ok($zip->set_number('3000638')->is_valid_number, '茨城県稲敷市古渡');
ok($zip->set_number('3000641')->is_valid_number, '茨城県稲敷市浮島');
ok($zip->set_number('3000642')->is_valid_number, '茨城県稲敷市下馬渡');
ok($zip->set_number('3000643')->is_valid_number, '茨城県稲敷市上馬渡');
ok($zip->set_number('3000721')->is_valid_number, '茨城県稲敷市大島');
ok($zip->set_number('3000722')->is_valid_number, '茨城県稲敷市三島');
ok($zip->set_number('3000723')->is_valid_number, '茨城県稲敷市境島');
ok($zip->set_number('3000724')->is_valid_number, '茨城県稲敷市八筋川');
ok($zip->set_number('3000725')->is_valid_number, '茨城県稲敷市佐原下手');
ok($zip->set_number('3000726')->is_valid_number, '茨城県稲敷市西代');
ok($zip->set_number('3000727')->is_valid_number, '茨城県稲敷市飯島');
ok($zip->set_number('3000731')->is_valid_number, '茨城県稲敷市本新');
ok($zip->set_number('3000732')->is_valid_number, '茨城県稲敷市上之島');
ok($zip->set_number('3000733')->is_valid_number, '茨城県稲敷市石納');
ok($zip->set_number('3000734')->is_valid_number, '茨城県稲敷市結佐');
ok($zip->set_number('3000735')->is_valid_number, '茨城県稲敷市六角');
ok($zip->set_number('3000736')->is_valid_number, '茨城県稲敷市八千石');
ok($zip->set_number('3000737')->is_valid_number, '茨城県稲敷市上須田');
ok($zip->set_number('3000741')->is_valid_number, '茨城県稲敷市手賀組新田');
ok($zip->set_number('3000742')->is_valid_number, '茨城県稲敷市四ッ谷');
ok($zip->set_number('3000743')->is_valid_number, '茨城県稲敷市曲渕');
ok($zip->set_number('3000744')->is_valid_number, '茨城県稲敷市押砂');
ok($zip->set_number('3000745')->is_valid_number, '茨城県稲敷市橋向');
ok($zip->set_number('3000746')->is_valid_number, '茨城県稲敷市神崎本宿');
ok($zip->set_number('3000747')->is_valid_number, '茨城県稲敷市余津谷');
ok($zip->set_number('3000748')->is_valid_number, '茨城県稲敷市清久島');
ok($zip->set_number('3000749')->is_valid_number, '茨城県稲敷市佐原組新田');
ok($zip->set_number('3000801')->is_valid_number, '茨城県土浦市矢作');
ok($zip->set_number('3000802')->is_valid_number, '茨城県土浦市飯田');
ok($zip->set_number('3000803')->is_valid_number, '茨城県土浦市佐野子');
ok($zip->set_number('3000804')->is_valid_number, '茨城県土浦市粕毛');
ok($zip->set_number('3000805')->is_valid_number, '茨城県土浦市宍塚');
ok($zip->set_number('3000810')->is_valid_number, '茨城県土浦市永国台');
ok($zip->set_number('3000811')->is_valid_number, '茨城県土浦市上高津');
ok($zip->set_number('3000812')->is_valid_number, '茨城県土浦市下高津');
ok($zip->set_number('3000813')->is_valid_number, '茨城県土浦市富士崎');
ok($zip->set_number('3000814')->is_valid_number, '茨城県土浦市国分町');
ok($zip->set_number('3000815')->is_valid_number, '茨城県土浦市中高津');
ok($zip->set_number('3000816')->is_valid_number, '茨城県土浦市永国東町');
ok($zip->set_number('3000817')->is_valid_number, '茨城県土浦市永国');
ok($zip->set_number('3000818')->is_valid_number, '茨城県土浦市天川');
ok($zip->set_number('3000819')->is_valid_number, '茨城県土浦市上高津新町');
ok($zip->set_number('3000821')->is_valid_number, '茨城県土浦市蓮河原新町');
ok($zip->set_number('3000822')->is_valid_number, '茨城県土浦市蓮河原町');
ok($zip->set_number('3000823')->is_valid_number, '茨城県土浦市小松');
ok($zip->set_number('3000824')->is_valid_number, '茨城県土浦市千鳥ケ丘町');
ok($zip->set_number('3000825')->is_valid_number, '茨城県土浦市霞ケ岡町');
ok($zip->set_number('3000826')->is_valid_number, '茨城県土浦市小松ケ丘町');
ok($zip->set_number('3000831')->is_valid_number, '茨城県土浦市小岩田');
ok($zip->set_number('3000832')->is_valid_number, '茨城県土浦市桜ケ丘町');
ok($zip->set_number('3000833')->is_valid_number, '茨城県土浦市小岩田西');
ok($zip->set_number('3000834')->is_valid_number, '茨城県土浦市小岩田東');
ok($zip->set_number('3000835')->is_valid_number, '茨城県土浦市大岩田');
ok($zip->set_number('3000836')->is_valid_number, '茨城県土浦市烏山');
ok($zip->set_number('3000837')->is_valid_number, '茨城県土浦市右籾');
ok($zip->set_number('3000838')->is_valid_number, '茨城県土浦市摩利山新田');
ok($zip->set_number('3000839')->is_valid_number, '茨城県土浦市滝田');
ok($zip->set_number('3000841')->is_valid_number, '茨城県土浦市中');
ok($zip->set_number('3000842')->is_valid_number, '茨城県土浦市西根南');
ok($zip->set_number('3000843')->is_valid_number, '茨城県土浦市中村南');
ok($zip->set_number('3000844')->is_valid_number, '茨城県土浦市乙戸');
ok($zip->set_number('3000845')->is_valid_number, '茨城県土浦市乙戸南');
ok($zip->set_number('3000846')->is_valid_number, '茨城県土浦市小山田');
ok($zip->set_number('3000847')->is_valid_number, '茨城県土浦市卸町');
ok($zip->set_number('3000848')->is_valid_number, '茨城県土浦市西根西');
ok($zip->set_number('3000849')->is_valid_number, '茨城県土浦市中村西根');
ok($zip->set_number('3000850')->is_valid_number, '茨城県土浦市中村東');
ok($zip->set_number('3000871')->is_valid_number, '茨城県土浦市荒川沖東');
ok($zip->set_number('3000872')->is_valid_number, '茨城県土浦市沖新田');
ok($zip->set_number('3000873')->is_valid_number, '茨城県土浦市荒川沖');
ok($zip->set_number('3000874')->is_valid_number, '茨城県土浦市荒川沖西');
ok($zip->set_number('3000875')->is_valid_number, '茨城県土浦市中荒川沖町');
ok($zip->set_number('3000876')->is_valid_number, '茨城県土浦市北荒川沖町');
ok($zip->set_number('3000877')->is_valid_number, '茨城県土浦市荒川本郷');
ok($zip->set_number('3001151')->is_valid_number, '茨城県稲敷郡阿見町荒川沖');
ok($zip->set_number('3001152')->is_valid_number, '茨城県稲敷郡阿見町荒川本郷');
ok($zip->set_number('3001153')->is_valid_number, '茨城県稲敷郡阿見町実穀');
ok($zip->set_number('3001154')->is_valid_number, '茨城県稲敷郡阿見町上長');
ok($zip->set_number('3001155')->is_valid_number, '茨城県稲敷郡阿見町吉原');
ok($zip->set_number('3001156')->is_valid_number, '茨城県稲敷郡阿見町福田');
ok($zip->set_number('3001157')->is_valid_number, '茨城県稲敷郡阿見町小池');
ok($zip->set_number('3001158')->is_valid_number, '茨城県稲敷郡阿見町住吉');
ok($zip->set_number('3001159')->is_valid_number, '茨城県稲敷郡阿見町本郷');
ok($zip->set_number('3001161')->is_valid_number, '茨城県稲敷郡阿見町よしわら');
ok($zip->set_number('3001200')->is_valid_number, '茨城県牛久市以下に掲載がない場合');
ok($zip->set_number('3001201')->is_valid_number, '茨城県牛久市東猯穴町');
ok($zip->set_number('3001202')->is_valid_number, '茨城県牛久市中根町');
ok($zip->set_number('3001203')->is_valid_number, '茨城県牛久市下根町');
ok($zip->set_number('3001204')->is_valid_number, '茨城県牛久市岡見町');
ok($zip->set_number('3001205')->is_valid_number, '茨城県牛久市東大和田町');
ok($zip->set_number('3001206')->is_valid_number, '茨城県牛久市ひたち野西');
ok($zip->set_number('3001207')->is_valid_number, '茨城県牛久市ひたち野東');
ok($zip->set_number('3001211')->is_valid_number, '茨城県牛久市柏田町');
ok($zip->set_number('3001212')->is_valid_number, '茨城県牛久市結束町');
ok($zip->set_number('3001213')->is_valid_number, '茨城県牛久市上太田町');
ok($zip->set_number('3001214')->is_valid_number, '茨城県牛久市女化町');
ok($zip->set_number('3001215')->is_valid_number, '茨城県牛久市遠山町');
ok($zip->set_number('3001216')->is_valid_number, '茨城県牛久市神谷');
ok($zip->set_number('3001217')->is_valid_number, '茨城県牛久市さくら台');
ok($zip->set_number('3001221')->is_valid_number, '茨城県牛久市牛久町');
ok($zip->set_number('3001222')->is_valid_number, '茨城県牛久市南');
ok($zip->set_number('3001223')->is_valid_number, '茨城県牛久市城中町');
ok($zip->set_number('3001224')->is_valid_number, '茨城県牛久市庄兵衛新田町');
ok($zip->set_number('3001225')->is_valid_number, '茨城県牛久市新地町');
ok($zip->set_number('3001231')->is_valid_number, '茨城県牛久市猪子町');
ok($zip->set_number('3001232')->is_valid_number, '茨城県牛久市上柏田');
ok($zip->set_number('3001233')->is_valid_number, '茨城県牛久市栄町');
ok($zip->set_number('3001234')->is_valid_number, '茨城県牛久市中央');
ok($zip->set_number('3001235')->is_valid_number, '茨城県牛久市刈谷町');
ok($zip->set_number('3001236')->is_valid_number, '茨城県牛久市田宮町');
ok($zip->set_number('3001237')->is_valid_number, '茨城県牛久市田宮');
ok($zip->set_number('3001240')->is_valid_number, '茨城県つくば市池の台(その他)');
ok($zip->set_number('3001241')->is_valid_number, '茨城県つくば市牧園');
ok($zip->set_number('3001242')->is_valid_number, '茨城県つくば市樋の沢');
ok($zip->set_number('3001243')->is_valid_number, '茨城県つくば市大井');
ok($zip->set_number('3001244')->is_valid_number, '茨城県つくば市松の里(その他)');
ok($zip->set_number('3001245')->is_valid_number, '茨城県つくば市高崎');
ok($zip->set_number('3001246')->is_valid_number, '茨城県つくば市菅間');
ok($zip->set_number('3001247')->is_valid_number, '茨城県つくば市西の沢(その他)');
ok($zip->set_number('3001248')->is_valid_number, '茨城県つくば市若栗');
ok($zip->set_number('3001249')->is_valid_number, '茨城県つくば市若葉');
ok($zip->set_number('3001251')->is_valid_number, '茨城県つくば市城山');
ok($zip->set_number('3001252')->is_valid_number, '茨城県つくば市高見原');
ok($zip->set_number('3001253')->is_valid_number, '茨城県つくば市天宝喜');
ok($zip->set_number('3001254')->is_valid_number, '茨城県つくば市宝陽台');
ok($zip->set_number('3001255')->is_valid_number, '茨城県つくば市小茎');
ok($zip->set_number('3001256')->is_valid_number, '茨城県つくば市森の里');
ok($zip->set_number('3001257')->is_valid_number, '茨城県つくば市明神');
ok($zip->set_number('3001258')->is_valid_number, '茨城県つくば市六斗');
ok($zip->set_number('3001259')->is_valid_number, '茨城県つくば市稲荷原');
ok($zip->set_number('3001260')->is_valid_number, '茨城県つくば市西大井');
ok($zip->set_number('3001261')->is_valid_number, '茨城県つくば市あしび野');
ok($zip->set_number('3001262')->is_valid_number, '茨城県つくば市九万坪');
ok($zip->set_number('3001263')->is_valid_number, '茨城県つくば市富士見台');
ok($zip->set_number('3001264')->is_valid_number, '茨城県つくば市泊崎');
ok($zip->set_number('3001265')->is_valid_number, '茨城県つくば市細見');
ok($zip->set_number('3001266')->is_valid_number, '茨城県つくば市自由ケ丘');
ok($zip->set_number('3001267')->is_valid_number, '茨城県つくば市大舟戸');
ok($zip->set_number('3001268')->is_valid_number, '茨城県つくば市中山');
ok($zip->set_number('3001269')->is_valid_number, '茨城県つくば市池向');
ok($zip->set_number('3001271')->is_valid_number, '茨城県つくば市桜が丘');
ok($zip->set_number('3001272')->is_valid_number, '茨城県つくば市茎崎');
ok($zip->set_number('3001273')->is_valid_number, '茨城県つくば市下岩崎');
ok($zip->set_number('3001274')->is_valid_number, '茨城県つくば市上岩崎');
ok($zip->set_number('3001275')->is_valid_number, '茨城県つくば市梅ケ丘');
ok($zip->set_number('3001276')->is_valid_number, '茨城県つくば市小山');
ok($zip->set_number('3001277')->is_valid_number, '茨城県つくば市駒込');
ok($zip->set_number('3001278')->is_valid_number, '茨城県つくば市房内');
ok($zip->set_number('3001281')->is_valid_number, '茨城県牛久市桂町');
ok($zip->set_number('3001282')->is_valid_number, '茨城県牛久市井ノ岡町');
ok($zip->set_number('3001283')->is_valid_number, '茨城県牛久市奥原町');
ok($zip->set_number('3001284')->is_valid_number, '茨城県牛久市島田町');
ok($zip->set_number('3001285')->is_valid_number, '茨城県牛久市正直町');
ok($zip->set_number('3001286')->is_valid_number, '茨城県牛久市小坂町');
ok($zip->set_number('3001287')->is_valid_number, '茨城県牛久市福田町');
ok($zip->set_number('3001288')->is_valid_number, '茨城県牛久市久野町');
ok($zip->set_number('3001300')->is_valid_number, '茨城県稲敷郡河内町以下に掲載がない場合');
ok($zip->set_number('3001311')->is_valid_number, '茨城県稲敷郡河内町庄布川');
ok($zip->set_number('3001312')->is_valid_number, '茨城県稲敷郡河内町長竿');
ok($zip->set_number('3001313')->is_valid_number, '茨城県稲敷郡河内町田川(4905-1)');
ok($zip->set_number('3001314')->is_valid_number, '茨城県稲敷郡河内町下町歩');
ok($zip->set_number('3001315')->is_valid_number, '茨城県稲敷郡河内町十里');
ok($zip->set_number('3001316')->is_valid_number, '茨城県稲敷郡河内町布鎌');
ok($zip->set_number('3001321')->is_valid_number, '茨城県稲敷郡河内町羽子騎');
ok($zip->set_number('3001322')->is_valid_number, '茨城県稲敷郡河内町古河林');
ok($zip->set_number('3001323')->is_valid_number, '茨城県稲敷郡河内町手栗');
ok($zip->set_number('3001324')->is_valid_number, '茨城県稲敷郡河内町源清田');
ok($zip->set_number('3001325')->is_valid_number, '茨城県稲敷郡河内町平三郎');
ok($zip->set_number('3001326')->is_valid_number, '茨城県稲敷郡河内町宮淵');
ok($zip->set_number('3001327')->is_valid_number, '茨城県稲敷郡河内町猿島');
ok($zip->set_number('3001331')->is_valid_number, '茨城県稲敷郡河内町生板');
ok($zip->set_number('3001332')->is_valid_number, '茨城県稲敷郡河内町幸谷');
ok($zip->set_number('3001333')->is_valid_number, '茨城県稲敷郡河内町角崎町歩');
ok($zip->set_number('3001334')->is_valid_number, '茨城県稲敷郡河内町小林町歩');
ok($zip->set_number('3001335')->is_valid_number, '茨城県稲敷郡河内町生板鍋子新田');
ok($zip->set_number('3001336')->is_valid_number, '茨城県稲敷郡河内町大徳鍋子新田');
ok($zip->set_number('3001337')->is_valid_number, '茨城県稲敷郡河内町竜ケ崎町歩');
ok($zip->set_number('3001401')->is_valid_number, '茨城県稲敷郡河内町十三間戸');
ok($zip->set_number('3001402')->is_valid_number, '茨城県稲敷郡河内町平川');
ok($zip->set_number('3001403')->is_valid_number, '茨城県稲敷郡河内町金江津');
ok($zip->set_number('3001404')->is_valid_number, '茨城県稲敷郡河内町片巻');
ok($zip->set_number('3001405')->is_valid_number, '茨城県稲敷郡河内町田川(その他)');
ok($zip->set_number('3001406')->is_valid_number, '茨城県稲敷郡河内町下加納');
ok($zip->set_number('3001411')->is_valid_number, '茨城県稲敷市伊佐津');
ok($zip->set_number('3001412')->is_valid_number, '茨城県稲敷市柴崎');
ok($zip->set_number('3001413')->is_valid_number, '茨城県稲敷市伊崎');
ok($zip->set_number('3001414')->is_valid_number, '茨城県稲敷市戌渡');
ok($zip->set_number('3001415')->is_valid_number, '茨城県稲敷市中山');
ok($zip->set_number('3001416')->is_valid_number, '茨城県稲敷市角崎');
ok($zip->set_number('3001417')->is_valid_number, '茨城県稲敷市狸穴');
ok($zip->set_number('3001421')->is_valid_number, '茨城県稲敷市堀川');
ok($zip->set_number('3001422')->is_valid_number, '茨城県稲敷市南太田');
ok($zip->set_number('3001423')->is_valid_number, '茨城県稲敷市太田');
ok($zip->set_number('3001424')->is_valid_number, '茨城県稲敷市下太田');
ok($zip->set_number('3001425')->is_valid_number, '茨城県稲敷市小野');
ok($zip->set_number('3001426')->is_valid_number, '茨城県稲敷市寺内');
ok($zip->set_number('3001427')->is_valid_number, '茨城県稲敷市羽賀浦');
ok($zip->set_number('3001501')->is_valid_number, '茨城県取手市双葉');
ok($zip->set_number('3001502')->is_valid_number, '茨城県取手市新川');
ok($zip->set_number('3001503')->is_valid_number, '茨城県取手市大曲');
ok($zip->set_number('3001504')->is_valid_number, '茨城県取手市萱場');
ok($zip->set_number('3001505')->is_valid_number, '茨城県取手市下萱場');
ok($zip->set_number('3001506')->is_valid_number, '茨城県取手市上萱場');
ok($zip->set_number('3001507')->is_valid_number, '茨城県取手市浜田');
ok($zip->set_number('3001508')->is_valid_number, '茨城県取手市紫水');
ok($zip->set_number('3001511')->is_valid_number, '茨城県取手市椚木');
ok($zip->set_number('3001512')->is_valid_number, '茨城県取手市藤代');
ok($zip->set_number('3001513')->is_valid_number, '茨城県取手市片町');
ok($zip->set_number('3001514')->is_valid_number, '茨城県取手市宮和田');
ok($zip->set_number('3001515')->is_valid_number, '茨城県取手市平野');
ok($zip->set_number('3001516')->is_valid_number, '茨城県取手市藤代南');
ok($zip->set_number('3001521')->is_valid_number, '茨城県取手市押切');
ok($zip->set_number('3001522')->is_valid_number, '茨城県取手市高須');
ok($zip->set_number('3001523')->is_valid_number, '茨城県取手市大留');
ok($zip->set_number('3001524')->is_valid_number, '茨城県取手市神浦');
ok($zip->set_number('3001525')->is_valid_number, '茨城県取手市桜が丘');
ok($zip->set_number('3001531')->is_valid_number, '茨城県取手市小浮気');
ok($zip->set_number('3001532')->is_valid_number, '茨城県取手市谷中');
ok($zip->set_number('3001533')->is_valid_number, '茨城県取手市中田');
ok($zip->set_number('3001534')->is_valid_number, '茨城県取手市渋沼');
ok($zip->set_number('3001535')->is_valid_number, '茨城県取手市清水');
ok($zip->set_number('3001536')->is_valid_number, '茨城県取手市光風台');
ok($zip->set_number('3001537')->is_valid_number, '茨城県取手市毛有');
ok($zip->set_number('3001538')->is_valid_number, '茨城県取手市米田');
ok($zip->set_number('3001539')->is_valid_number, '茨城県取手市小泉');
ok($zip->set_number('3001541')->is_valid_number, '茨城県取手市配松');
ok($zip->set_number('3001542')->is_valid_number, '茨城県取手市神住');
ok($zip->set_number('3001543')->is_valid_number, '茨城県取手市中内');
ok($zip->set_number('3001544')->is_valid_number, '茨城県取手市山王');
ok($zip->set_number('3001545')->is_valid_number, '茨城県取手市和田');
ok($zip->set_number('3001546')->is_valid_number, '茨城県取手市岡');
ok($zip->set_number('3001600')->is_valid_number, '茨城県北相馬郡利根町以下に掲載がない場合');
ok($zip->set_number('3001601')->is_valid_number, '茨城県北相馬郡利根町大房');
ok($zip->set_number('3001602')->is_valid_number, '茨城県北相馬郡利根町押戸');
ok($zip->set_number('3001603')->is_valid_number, '茨城県北相馬郡利根町奥山');
ok($zip->set_number('3001604')->is_valid_number, '茨城県北相馬郡利根町横須賀');
ok($zip->set_number('3001605')->is_valid_number, '茨城県北相馬郡利根町大平');
ok($zip->set_number('3001606')->is_valid_number, '茨城県北相馬郡利根町もえぎ野台');
ok($zip->set_number('3001611')->is_valid_number, '茨城県北相馬郡利根町惣新田');
ok($zip->set_number('3001612')->is_valid_number, '茨城県北相馬郡利根町加納新田');
ok($zip->set_number('3001613')->is_valid_number, '茨城県北相馬郡利根町東奥山新田');
ok($zip->set_number('3001614')->is_valid_number, '茨城県北相馬郡利根町立崎');
ok($zip->set_number('3001615')->is_valid_number, '茨城県北相馬郡利根町中谷');
ok($zip->set_number('3001616')->is_valid_number, '茨城県北相馬郡利根町立木');
ok($zip->set_number('3001621')->is_valid_number, '茨城県北相馬郡利根町福木');
ok($zip->set_number('3001622')->is_valid_number, '茨城県北相馬郡利根町布川');
ok($zip->set_number('3001623')->is_valid_number, '茨城県北相馬郡利根町八幡台');
ok($zip->set_number('3001624')->is_valid_number, '茨城県北相馬郡利根町中田切');
ok($zip->set_number('3001625')->is_valid_number, '茨城県北相馬郡利根町羽中');
ok($zip->set_number('3001626')->is_valid_number, '茨城県北相馬郡利根町四季の丘');
ok($zip->set_number('3001631')->is_valid_number, '茨城県北相馬郡利根町早尾');
ok($zip->set_number('3001632')->is_valid_number, '茨城県北相馬郡利根町下曽根');
ok($zip->set_number('3001633')->is_valid_number, '茨城県北相馬郡利根町下井');
ok($zip->set_number('3001634')->is_valid_number, '茨城県北相馬郡利根町押付新田');
ok($zip->set_number('3001635')->is_valid_number, '茨城県北相馬郡利根町上曽根');
ok($zip->set_number('3001636')->is_valid_number, '茨城県北相馬郡利根町羽根野');
ok($zip->set_number('3002300')->is_valid_number, '茨城県つくばみらい市以下に掲載がない場合');
ok($zip->set_number('3002301')->is_valid_number, '茨城県つくばみらい市高岡');
ok($zip->set_number('3002302')->is_valid_number, '茨城県つくばみらい市狸穴');
ok($zip->set_number('3002303')->is_valid_number, '茨城県つくばみらい市大和田');
ok($zip->set_number('3002304')->is_valid_number, '茨城県つくばみらい市武兵衛新田');
ok($zip->set_number('3002305')->is_valid_number, '茨城県つくばみらい市重右衛門新田');
ok($zip->set_number('3002306')->is_valid_number, '茨城県つくばみらい市南太田');
ok($zip->set_number('3002307')->is_valid_number, '茨城県つくばみらい市板橋');
ok($zip->set_number('3002308')->is_valid_number, '茨城県つくばみらい市伊奈東');
ok($zip->set_number('3002311')->is_valid_number, '茨城県つくばみらい市野堀');
ok($zip->set_number('3002312')->is_valid_number, '茨城県つくばみらい市神生');
ok($zip->set_number('3002313')->is_valid_number, '茨城県つくばみらい市東栗山');
ok($zip->set_number('3002314')->is_valid_number, '茨城県つくばみらい市城中');
ok($zip->set_number('3002315')->is_valid_number, '茨城県つくばみらい市足高');
ok($zip->set_number('3002321')->is_valid_number, '茨城県つくばみらい市戸茂');
ok($zip->set_number('3002322')->is_valid_number, '茨城県つくばみらい市戸崎');
ok($zip->set_number('3002323')->is_valid_number, '茨城県つくばみらい市伊丹');
ok($zip->set_number('3002324')->is_valid_number, '茨城県つくばみらい市下島');
ok($zip->set_number('3002325')->is_valid_number, '茨城県つくばみらい市中島');
ok($zip->set_number('3002326')->is_valid_number, '茨城県つくばみらい市上島');
ok($zip->set_number('3002327')->is_valid_number, '茨城県つくばみらい市福原');
ok($zip->set_number('3002331')->is_valid_number, '茨城県つくばみらい市神住新田');
ok($zip->set_number('3002332')->is_valid_number, '茨城県つくばみらい市山王新田');
ok($zip->set_number('3002333')->is_valid_number, '茨城県つくばみらい市下平柳');
ok($zip->set_number('3002334')->is_valid_number, '茨城県つくばみらい市中平柳');
ok($zip->set_number('3002335')->is_valid_number, '茨城県つくばみらい市上平柳');
ok($zip->set_number('3002336')->is_valid_number, '茨城県つくばみらい市山谷');
ok($zip->set_number('3002337')->is_valid_number, '茨城県つくばみらい市谷井田');
ok($zip->set_number('3002341')->is_valid_number, '茨城県つくばみらい市福田');
ok($zip->set_number('3002342')->is_valid_number, '茨城県つくばみらい市弥柳');
ok($zip->set_number('3002343')->is_valid_number, '茨城県つくばみらい市狸渕');
ok($zip->set_number('3002344')->is_valid_number, '茨城県つくばみらい市長渡呂新田');
ok($zip->set_number('3002345')->is_valid_number, '茨城県つくばみらい市長渡呂');
ok($zip->set_number('3002346')->is_valid_number, '茨城県つくばみらい市青木');
ok($zip->set_number('3002347')->is_valid_number, '茨城県つくばみらい市豊体');
ok($zip->set_number('3002348')->is_valid_number, '茨城県つくばみらい市青古新田');
ok($zip->set_number('3002351')->is_valid_number, '茨城県つくばみらい市善助新田');
ok($zip->set_number('3002352')->is_valid_number, '茨城県つくばみらい市小島新田');
ok($zip->set_number('3002353')->is_valid_number, '茨城県つくばみらい市小張');
ok($zip->set_number('3002354')->is_valid_number, '茨城県つくばみらい市新戸');
ok($zip->set_number('3002355')->is_valid_number, '茨城県つくばみらい市市野深');
ok($zip->set_number('3002356')->is_valid_number, '茨城県つくばみらい市奉社');
ok($zip->set_number('3002357')->is_valid_number, '茨城県つくばみらい市谷口');
ok($zip->set_number('3002358')->is_valid_number, '茨城県つくばみらい市陽光台');
ok($zip->set_number('3002359')->is_valid_number, '茨城県つくばみらい市紫峰ヶ丘');
ok($zip->set_number('3002401')->is_valid_number, '茨城県つくばみらい市台');
ok($zip->set_number('3002402')->is_valid_number, '茨城県つくばみらい市坂野新田');
ok($zip->set_number('3002403')->is_valid_number, '茨城県つくばみらい市中原');
ok($zip->set_number('3002404')->is_valid_number, '茨城県つくばみらい市南');
ok($zip->set_number('3002405')->is_valid_number, '茨城県つくばみらい市仁左衛門新田');
ok($zip->set_number('3002406')->is_valid_number, '茨城県つくばみらい市福岡');
ok($zip->set_number('3002407')->is_valid_number, '茨城県つくばみらい市北山');
ok($zip->set_number('3002408')->is_valid_number, '茨城県つくばみらい市福岡工業団地');
ok($zip->set_number('3002411')->is_valid_number, '茨城県つくばみらい市押砂');
ok($zip->set_number('3002412')->is_valid_number, '茨城県つくばみらい市日川');
ok($zip->set_number('3002413')->is_valid_number, '茨城県つくばみらい市田村');
ok($zip->set_number('3002414')->is_valid_number, '茨城県つくばみらい市真木');
ok($zip->set_number('3002415')->is_valid_number, '茨城県つくばみらい市西楢戸');
ok($zip->set_number('3002416')->is_valid_number, '茨城県つくばみらい市東楢戸');
ok($zip->set_number('3002417')->is_valid_number, '茨城県つくばみらい市富士見ヶ丘');
ok($zip->set_number('3002421')->is_valid_number, '茨城県つくばみらい市西丸山');
ok($zip->set_number('3002422')->is_valid_number, '茨城県つくばみらい市古川');
ok($zip->set_number('3002423')->is_valid_number, '茨城県つくばみらい市成瀬');
ok($zip->set_number('3002424')->is_valid_number, '茨城県つくばみらい市加藤');
ok($zip->set_number('3002425')->is_valid_number, '茨城県つくばみらい市川崎');
ok($zip->set_number('3002426')->is_valid_number, '茨城県つくばみらい市宮戸');
ok($zip->set_number('3002431')->is_valid_number, '茨城県つくばみらい市上小目');
ok($zip->set_number('3002432')->is_valid_number, '茨城県つくばみらい市鬼長');
ok($zip->set_number('3002433')->is_valid_number, '茨城県つくばみらい市下小目');
ok($zip->set_number('3002434')->is_valid_number, '茨城県つくばみらい市平沼');
ok($zip->set_number('3002435')->is_valid_number, '茨城県つくばみらい市筒戸');
ok($zip->set_number('3002436')->is_valid_number, '茨城県つくばみらい市絹の台');
ok($zip->set_number('3002441')->is_valid_number, '茨城県つくばみらい市寺畑');
ok($zip->set_number('3002442')->is_valid_number, '茨城県つくばみらい市西ノ台');
ok($zip->set_number('3002443')->is_valid_number, '茨城県つくばみらい市西ノ台南');
ok($zip->set_number('3002444')->is_valid_number, '茨城県つくばみらい市杉下');
ok($zip->set_number('3002445')->is_valid_number, '茨城県つくばみらい市小絹');
ok($zip->set_number('3002446')->is_valid_number, '茨城県つくばみらい市細代');
ok($zip->set_number('3002451')->is_valid_number, '茨城県つくばみらい市箕輪');
ok($zip->set_number('3002452')->is_valid_number, '茨城県つくばみらい市樛木');
ok($zip->set_number('3002453')->is_valid_number, '茨城県つくばみらい市上長沼');
ok($zip->set_number('3002454')->is_valid_number, '茨城県つくばみらい市下長沼');
ok($zip->set_number('3002455')->is_valid_number, '茨城県つくばみらい市十和');
ok($zip->set_number('3002456')->is_valid_number, '茨城県つくばみらい市北袋');
ok($zip->set_number('3002501')->is_valid_number, '茨城県常総市福二町');
ok($zip->set_number('3002502')->is_valid_number, '茨城県常総市上蛇町');
ok($zip->set_number('3002503')->is_valid_number, '茨城県常総市川崎町');
ok($zip->set_number('3002504')->is_valid_number, '茨城県常総市沖新田町');
ok($zip->set_number('3002505')->is_valid_number, '茨城県常総市中妻町');
ok($zip->set_number('3002506')->is_valid_number, '茨城県常総市三坂町');
ok($zip->set_number('3002507')->is_valid_number, '茨城県常総市三坂新田町');
ok($zip->set_number('3002508')->is_valid_number, '茨城県常総市むすびまち');
ok($zip->set_number('3002511')->is_valid_number, '茨城県常総市花島町');
ok($zip->set_number('3002512')->is_valid_number, '茨城県常総市大輪町');
ok($zip->set_number('3002513')->is_valid_number, '茨城県常総市羽生町');
ok($zip->set_number('3002521')->is_valid_number, '茨城県常総市大生郷町');
ok($zip->set_number('3002522')->is_valid_number, '茨城県常総市横曽根新田町');
ok($zip->set_number('3002523')->is_valid_number, '茨城県常総市笹塚新田町');
ok($zip->set_number('3002524')->is_valid_number, '茨城県常総市五郎兵衛新田町');
ok($zip->set_number('3002525')->is_valid_number, '茨城県常総市伊左衛門新田町');
ok($zip->set_number('3002526')->is_valid_number, '茨城県常総市大生郷新田町');
ok($zip->set_number('3002611')->is_valid_number, '茨城県つくば市大久保');
ok($zip->set_number('3002612')->is_valid_number, '茨城県つくば市大砂');
ok($zip->set_number('3002613')->is_valid_number, '茨城県つくば市西高野');
ok($zip->set_number('3002614')->is_valid_number, '茨城県つくば市上里');
ok($zip->set_number('3002615')->is_valid_number, '茨城県つくば市田倉');
ok($zip->set_number('3002616')->is_valid_number, '茨城県つくば市五人受');
ok($zip->set_number('3002617')->is_valid_number, '茨城県つくば市吉沼');
ok($zip->set_number('3002621')->is_valid_number, '茨城県つくば市南原(その他)');
ok($zip->set_number('3002622')->is_valid_number, '茨城県つくば市要');
ok($zip->set_number('3002623')->is_valid_number, '茨城県つくば市本沢');
ok($zip->set_number('3002624')->is_valid_number, '茨城県つくば市西沢');
ok($zip->set_number('3002631')->is_valid_number, '茨城県つくば市沼崎');
ok($zip->set_number('3002632')->is_valid_number, '茨城県つくば市旭(その他)');
ok($zip->set_number('3002633')->is_valid_number, '茨城県つくば市遠東');
ok($zip->set_number('3002634')->is_valid_number, '茨城県つくば市中東原新田');
ok($zip->set_number('3002635')->is_valid_number, '茨城県つくば市東光台');
ok($zip->set_number('3002636')->is_valid_number, '茨城県つくば市土田');
ok($zip->set_number('3002637')->is_valid_number, '茨城県つくば市酒丸');
ok($zip->set_number('3002638')->is_valid_number, '茨城県つくば市百家');
ok($zip->set_number('3002639')->is_valid_number, '茨城県つくば市中東');
ok($zip->set_number('3002641')->is_valid_number, '茨城県つくば市今鹿島');
ok($zip->set_number('3002642')->is_valid_number, '茨城県つくば市高野');
ok($zip->set_number('3002643')->is_valid_number, '茨城県つくば市野畑');
ok($zip->set_number('3002644')->is_valid_number, '茨城県つくば市木俣');
ok($zip->set_number('3002645')->is_valid_number, '茨城県つくば市上郷');
ok($zip->set_number('3002646')->is_valid_number, '茨城県つくば市緑ケ原');
ok($zip->set_number('3002647')->is_valid_number, '茨城県つくば市手子生');
ok($zip->set_number('3002648')->is_valid_number, '茨城県つくば市豊里の杜');
ok($zip->set_number('3002651')->is_valid_number, '茨城県つくば市鬼ケ窪');
ok($zip->set_number('3002652')->is_valid_number, '茨城県つくば市高田');
ok($zip->set_number('3002653')->is_valid_number, '茨城県つくば市面野井');
ok($zip->set_number('3002654')->is_valid_number, '茨城県つくば市水堀');
ok($zip->set_number('3002655')->is_valid_number, '茨城県つくば市島名');
ok($zip->set_number('3002656')->is_valid_number, '茨城県つくば市真瀬');
ok($zip->set_number('3002657')->is_valid_number, '茨城県つくば市香取台');
ok($zip->set_number('3002658')->is_valid_number, '茨城県つくば市諏訪');
ok($zip->set_number('3002659')->is_valid_number, '茨城県つくば市万博公園西');
ok($zip->set_number('3002661')->is_valid_number, '茨城県つくば市上河原崎');
ok($zip->set_number('3002662')->is_valid_number, '茨城県つくば市下河原崎');
ok($zip->set_number('3002663')->is_valid_number, '茨城県つくば市鍋沼新田');
ok($zip->set_number('3002664')->is_valid_number, '茨城県つくば市高良田');
ok($zip->set_number('3002665')->is_valid_number, '茨城県つくば市高須賀');
ok($zip->set_number('3002666')->is_valid_number, '茨城県つくば市下別府');
ok($zip->set_number('3002667')->is_valid_number, '茨城県つくば市中別府');
ok($zip->set_number('3002668')->is_valid_number, '茨城県つくば市かみかわ');
ok($zip->set_number('3002669')->is_valid_number, '茨城県つくば市高山');
ok($zip->set_number('3002701')->is_valid_number, '茨城県常総市若宮戸');
ok($zip->set_number('3002702')->is_valid_number, '茨城県常総市原宿');
ok($zip->set_number('3002703')->is_valid_number, '茨城県常総市小保川');
ok($zip->set_number('3002704')->is_valid_number, '茨城県常総市舘方');
ok($zip->set_number('3002705')->is_valid_number, '茨城県常総市豊田');
ok($zip->set_number('3002706')->is_valid_number, '茨城県常総市新石下');
ok($zip->set_number('3002707')->is_valid_number, '茨城県常総市本石下');
ok($zip->set_number('3002711')->is_valid_number, '茨城県常総市本豊田');
ok($zip->set_number('3002712')->is_valid_number, '茨城県常総市曲田');
ok($zip->set_number('3002713')->is_valid_number, '茨城県常総市収納谷');
ok($zip->set_number('3002714')->is_valid_number, '茨城県常総市平内');
ok($zip->set_number('3002715')->is_valid_number, '茨城県常総市山口');
ok($zip->set_number('3002716')->is_valid_number, '茨城県常総市大房');
ok($zip->set_number('3002717')->is_valid_number, '茨城県常総市東野原');
ok($zip->set_number('3002721')->is_valid_number, '茨城県常総市篠山');
ok($zip->set_number('3002722')->is_valid_number, '茨城県常総市蔵持');
ok($zip->set_number('3002723')->is_valid_number, '茨城県常総市蔵持新田');
ok($zip->set_number('3002724')->is_valid_number, '茨城県常総市古間木');
ok($zip->set_number('3002725')->is_valid_number, '茨城県常総市古間木沼新田');
ok($zip->set_number('3002726')->is_valid_number, '茨城県常総市中沼');
ok($zip->set_number('3002727')->is_valid_number, '茨城県常総市大沢');
ok($zip->set_number('3002731')->is_valid_number, '茨城県常総市古間木新田');
ok($zip->set_number('3002732')->is_valid_number, '茨城県常総市鴻野山新田');
ok($zip->set_number('3002733')->is_valid_number, '茨城県常総市馬場新田');
ok($zip->set_number('3002734')->is_valid_number, '茨城県常総市栗山新田');
ok($zip->set_number('3002735')->is_valid_number, '茨城県常総市左平太新田');
ok($zip->set_number('3002736')->is_valid_number, '茨城県常総市孫兵ヱ新田');
ok($zip->set_number('3002741')->is_valid_number, '茨城県常総市国生');
ok($zip->set_number('3002742')->is_valid_number, '茨城県常総市向石下');
ok($zip->set_number('3002743')->is_valid_number, '茨城県常総市岡田');
ok($zip->set_number('3002744')->is_valid_number, '茨城県常総市杉山');
ok($zip->set_number('3002745')->is_valid_number, '茨城県常総市大沢新田');
ok($zip->set_number('3002746')->is_valid_number, '茨城県常総市鴻野山');
ok($zip->set_number('3002747')->is_valid_number, '茨城県常総市崎房');
ok($zip->set_number('3002748')->is_valid_number, '茨城県常総市馬場');
ok($zip->set_number('3003251')->is_valid_number, '茨城県つくば市佐');
ok($zip->set_number('3003252')->is_valid_number, '茨城県つくば市若森');
ok($zip->set_number('3003253')->is_valid_number, '茨城県つくば市大曽根');
ok($zip->set_number('3003254')->is_valid_number, '茨城県つくば市鹿島台');
ok($zip->set_number('3003255')->is_valid_number, '茨城県つくば市玉取');
ok($zip->set_number('3003256')->is_valid_number, '茨城県つくば市大穂(その他)');
ok($zip->set_number('3003257')->is_valid_number, '茨城県つくば市筑穂');
ok($zip->set_number('3003261')->is_valid_number, '茨城県つくば市花畑(その他)');
ok($zip->set_number('3003262')->is_valid_number, '茨城県つくば市蓮沼');
ok($zip->set_number('3003263')->is_valid_number, '茨城県つくば市立原(その他)');
ok($zip->set_number('3003264')->is_valid_number, '茨城県つくば市篠崎');
ok($zip->set_number('3003265')->is_valid_number, '茨城県つくば市長高野');
ok($zip->set_number('3003266')->is_valid_number, '茨城県つくば市北原');
ok($zip->set_number('3003267')->is_valid_number, '茨城県つくば市前野');
ok($zip->set_number('3003500')->is_valid_number, '茨城県結城郡八千代町以下に掲載がない場合');
ok($zip->set_number('3003501')->is_valid_number, '茨城県結城郡八千代町塩本');
ok($zip->set_number('3003502')->is_valid_number, '茨城県結城郡八千代町下山川');
ok($zip->set_number('3003503')->is_valid_number, '茨城県結城郡八千代町粕礼');
ok($zip->set_number('3003504')->is_valid_number, '茨城県結城郡八千代町西大山');
ok($zip->set_number('3003505')->is_valid_number, '茨城県結城郡八千代町佐野');
ok($zip->set_number('3003506')->is_valid_number, '茨城県結城郡八千代町成田');
ok($zip->set_number('3003511')->is_valid_number, '茨城県結城郡八千代町瀬戸井');
ok($zip->set_number('3003512')->is_valid_number, '茨城県結城郡八千代町小屋');
ok($zip->set_number('3003513')->is_valid_number, '茨城県結城郡八千代町久下田');
ok($zip->set_number('3003514')->is_valid_number, '茨城県結城郡八千代町大里');
ok($zip->set_number('3003515')->is_valid_number, '茨城県結城郡八千代町大渡戸');
ok($zip->set_number('3003516')->is_valid_number, '茨城県結城郡八千代町高崎');
ok($zip->set_number('3003517')->is_valid_number, '茨城県結城郡八千代町坪井');
ok($zip->set_number('3003518')->is_valid_number, '茨城県結城郡八千代町野爪');
ok($zip->set_number('3003519')->is_valid_number, '茨城県結城郡八千代町新井');
ok($zip->set_number('3003521')->is_valid_number, '茨城県結城郡八千代町川尻');
ok($zip->set_number('3003522')->is_valid_number, '茨城県結城郡八千代町袋');
ok($zip->set_number('3003523')->is_valid_number, '茨城県結城郡八千代町八町');
ok($zip->set_number('3003524')->is_valid_number, '茨城県結城郡八千代町兵庫');
ok($zip->set_number('3003525')->is_valid_number, '茨城県結城郡八千代町沼森');
ok($zip->set_number('3003526')->is_valid_number, '茨城県結城郡八千代町貝谷');
ok($zip->set_number('3003527')->is_valid_number, '茨城県結城郡八千代町東原');
ok($zip->set_number('3003531')->is_valid_number, '茨城県結城郡八千代町今里');
ok($zip->set_number('3003532')->is_valid_number, '茨城県結城郡八千代町本郷');
ok($zip->set_number('3003533')->is_valid_number, '茨城県結城郡八千代町片角');
ok($zip->set_number('3003534')->is_valid_number, '茨城県結城郡八千代町太田');
ok($zip->set_number('3003535')->is_valid_number, '茨城県結城郡八千代町粟野');
ok($zip->set_number('3003536')->is_valid_number, '茨城県結城郡八千代町中野');
ok($zip->set_number('3003537')->is_valid_number, '茨城県結城郡八千代町苅橋');
ok($zip->set_number('3003538')->is_valid_number, '茨城県結城郡八千代町東大山');
ok($zip->set_number('3003539')->is_valid_number, '茨城県結城郡八千代町仁江戸');
ok($zip->set_number('3003541')->is_valid_number, '茨城県結城郡八千代町新地');
ok($zip->set_number('3003542')->is_valid_number, '茨城県結城郡八千代町福岡');
ok($zip->set_number('3003543')->is_valid_number, '茨城県結城郡八千代町新地新田');
ok($zip->set_number('3003544')->is_valid_number, '茨城県結城郡八千代町若');
ok($zip->set_number('3003545')->is_valid_number, '茨城県結城郡八千代町東蕗田');
ok($zip->set_number('3003551')->is_valid_number, '茨城県結城郡八千代町栗山');
ok($zip->set_number('3003552')->is_valid_number, '茨城県結城郡八千代町大間木');
ok($zip->set_number('3003553')->is_valid_number, '茨城県結城郡八千代町蕗田');
ok($zip->set_number('3003554')->is_valid_number, '茨城県結城郡八千代町尾崎');
ok($zip->set_number('3003555')->is_valid_number, '茨城県結城郡八千代町芦ケ谷');
ok($zip->set_number('3003556')->is_valid_number, '茨城県結城郡八千代町芦ケ谷新田');
ok($zip->set_number('3003561')->is_valid_number, '茨城県結城郡八千代町平塚');
ok($zip->set_number('3003562')->is_valid_number, '茨城県結城郡八千代町磯');
ok($zip->set_number('3003563')->is_valid_number, '茨城県結城郡八千代町村貫');
ok($zip->set_number('3003564')->is_valid_number, '茨城県結城郡八千代町水口');
ok($zip->set_number('3003565')->is_valid_number, '茨城県結城郡八千代町松本');
ok($zip->set_number('3003571')->is_valid_number, '茨城県結城郡八千代町大戸新田');
ok($zip->set_number('3003572')->is_valid_number, '茨城県結城郡八千代町菅谷');
ok($zip->set_number('3004101')->is_valid_number, '茨城県土浦市永井');
ok($zip->set_number('3004102')->is_valid_number, '茨城県土浦市本郷');
ok($zip->set_number('3004103')->is_valid_number, '茨城県土浦市大志戸');
ok($zip->set_number('3004104')->is_valid_number, '茨城県土浦市沢辺');
ok($zip->set_number('3004105')->is_valid_number, '茨城県土浦市田宮');
ok($zip->set_number('3004106')->is_valid_number, '茨城県土浦市小高');
ok($zip->set_number('3004107')->is_valid_number, '茨城県土浦市東城寺');
ok($zip->set_number('3004108')->is_valid_number, '茨城県土浦市小野');
ok($zip->set_number('3004111')->is_valid_number, '茨城県土浦市大畑');
ok($zip->set_number('3004112')->is_valid_number, '茨城県土浦市桃園');
ok($zip->set_number('3004113')->is_valid_number, '茨城県土浦市下坂田');
ok($zip->set_number('3004114')->is_valid_number, '茨城県土浦市上坂田');
ok($zip->set_number('3004115')->is_valid_number, '茨城県土浦市藤沢');
ok($zip->set_number('3004116')->is_valid_number, '茨城県土浦市藤沢新田');
ok($zip->set_number('3004117')->is_valid_number, '茨城県土浦市高岡');
ok($zip->set_number('3004118')->is_valid_number, '茨城県土浦市田土部');
ok($zip->set_number('3004201')->is_valid_number, '茨城県つくば市寺具');
ok($zip->set_number('3004202')->is_valid_number, '茨城県つくば市高野原新田');
ok($zip->set_number('3004203')->is_valid_number, '茨城県つくば市明石');
ok($zip->set_number('3004204')->is_valid_number, '茨城県つくば市作谷');
ok($zip->set_number('3004205')->is_valid_number, '茨城県つくば市安食');
ok($zip->set_number('3004211')->is_valid_number, '茨城県つくば市臼井');
ok($zip->set_number('3004212')->is_valid_number, '茨城県つくば市神郡');
ok($zip->set_number('3004213')->is_valid_number, '茨城県つくば市平沢');
ok($zip->set_number('3004214')->is_valid_number, '茨城県つくば市山口');
ok($zip->set_number('3004215')->is_valid_number, '茨城県つくば市小沢');
ok($zip->set_number('3004216')->is_valid_number, '茨城県つくば市漆所');
ok($zip->set_number('3004217')->is_valid_number, '茨城県つくば市杉木');
ok($zip->set_number('3004218')->is_valid_number, '茨城県つくば市大貫');
ok($zip->set_number('3004221')->is_valid_number, '茨城県つくば市大形');
ok($zip->set_number('3004222')->is_valid_number, '茨城県つくば市下大島');
ok($zip->set_number('3004223')->is_valid_number, '茨城県つくば市小田');
ok($zip->set_number('3004224')->is_valid_number, '茨城県つくば市小和田');
ok($zip->set_number('3004231')->is_valid_number, '茨城県つくば市北条');
ok($zip->set_number('3004232')->is_valid_number, '茨城県つくば市北太田');
ok($zip->set_number('3004233')->is_valid_number, '茨城県つくば市君島');
ok($zip->set_number('3004234')->is_valid_number, '茨城県つくば市山木');
ok($zip->set_number('3004235')->is_valid_number, '茨城県つくば市泉');
ok($zip->set_number('3004236')->is_valid_number, '茨城県つくば市小泉');
ok($zip->set_number('3004241')->is_valid_number, '茨城県つくば市上菅間');
ok($zip->set_number('3004242')->is_valid_number, '茨城県つくば市中菅間');
ok($zip->set_number('3004243')->is_valid_number, '茨城県つくば市池田');
ok($zip->set_number('3004244')->is_valid_number, '茨城県つくば市田中');
ok($zip->set_number('3004245')->is_valid_number, '茨城県つくば市水守');
ok($zip->set_number('3004246')->is_valid_number, '茨城県つくば市上沢');
ok($zip->set_number('3004247')->is_valid_number, '茨城県つくば市和台');
ok($zip->set_number('3004248')->is_valid_number, '茨城県つくば市磯部');
ok($zip->set_number('3004249')->is_valid_number, '茨城県つくば市洞下');
ok($zip->set_number('3004251')->is_valid_number, '茨城県つくば市田水山');
ok($zip->set_number('3004351')->is_valid_number, '茨城県つくば市上大島');
ok($zip->set_number('3004352')->is_valid_number, '茨城県つくば市筑波');
ok($zip->set_number('3004353')->is_valid_number, '茨城県つくば市沼田');
ok($zip->set_number('3004354')->is_valid_number, '茨城県つくば市国松');
ok($zip->set_number('3004401')->is_valid_number, '茨城県桜川市真壁町上小幡');
ok($zip->set_number('3004402')->is_valid_number, '茨城県桜川市真壁町下小幡');
ok($zip->set_number('3004403')->is_valid_number, '茨城県桜川市真壁町長岡');
ok($zip->set_number('3004404')->is_valid_number, '茨城県桜川市真壁町白井');
ok($zip->set_number('3004405')->is_valid_number, '茨城県桜川市真壁町桜井');
ok($zip->set_number('3004406')->is_valid_number, '茨城県桜川市真壁町山尾');
ok($zip->set_number('3004407')->is_valid_number, '茨城県桜川市真壁町古城');
ok($zip->set_number('3004408')->is_valid_number, '茨城県桜川市真壁町真壁');
ok($zip->set_number('3004411')->is_valid_number, '茨城県桜川市真壁町田');
ok($zip->set_number('3004412')->is_valid_number, '茨城県桜川市真壁町羽鳥');
ok($zip->set_number('3004413')->is_valid_number, '茨城県桜川市真壁町酒寄');
ok($zip->set_number('3004414')->is_valid_number, '茨城県桜川市真壁町椎尾');
ok($zip->set_number('3004415')->is_valid_number, '茨城県桜川市真壁町東山田');
ok($zip->set_number('3004416')->is_valid_number, '茨城県桜川市真壁町伊佐々');
ok($zip->set_number('3004417')->is_valid_number, '茨城県桜川市真壁町飯塚');
ok($zip->set_number('3004421')->is_valid_number, '茨城県桜川市真壁町原方');
ok($zip->set_number('3004422')->is_valid_number, '茨城県桜川市真壁町亀熊');
ok($zip->set_number('3004423')->is_valid_number, '茨城県桜川市真壁町塙世');
ok($zip->set_number('3004424')->is_valid_number, '茨城県桜川市真壁町源法寺');
ok($zip->set_number('3004425')->is_valid_number, '茨城県桜川市真壁町細芝');
ok($zip->set_number('3004426')->is_valid_number, '茨城県桜川市真壁町下谷貝');
ok($zip->set_number('3004427')->is_valid_number, '茨城県桜川市真壁町上谷貝');
ok($zip->set_number('3004428')->is_valid_number, '茨城県桜川市真壁町大塚新田');
ok($zip->set_number('3004429')->is_valid_number, '茨城県桜川市真壁町東矢貝');
ok($zip->set_number('3004501')->is_valid_number, '茨城県筑西市猫島');
ok($zip->set_number('3004502')->is_valid_number, '茨城県筑西市上西郷谷');
ok($zip->set_number('3004503')->is_valid_number, '茨城県筑西市宮後');
ok($zip->set_number('3004504')->is_valid_number, '茨城県筑西市宮山');
ok($zip->set_number('3004505')->is_valid_number, '茨城県筑西市田宿');
ok($zip->set_number('3004506')->is_valid_number, '茨城県筑西市鍋山');
ok($zip->set_number('3004507')->is_valid_number, '茨城県筑西市内淀');
ok($zip->set_number('3004511')->is_valid_number, '茨城県筑西市押尾');
ok($zip->set_number('3004512')->is_valid_number, '茨城県筑西市有田');
ok($zip->set_number('3004513')->is_valid_number, '茨城県筑西市中根');
ok($zip->set_number('3004514')->is_valid_number, '茨城県筑西市山王堂');
ok($zip->set_number('3004515')->is_valid_number, '茨城県筑西市倉持');
ok($zip->set_number('3004516')->is_valid_number, '茨城県筑西市新井新田');
ok($zip->set_number('3004517')->is_valid_number, '茨城県筑西市海老ケ島');
ok($zip->set_number('3004521')->is_valid_number, '茨城県筑西市東石田');
ok($zip->set_number('3004522')->is_valid_number, '茨城県筑西市向上野');
ok($zip->set_number('3004523')->is_valid_number, '茨城県筑西市赤浜');
ok($zip->set_number('3004524')->is_valid_number, '茨城県筑西市中上野');
ok($zip->set_number('3004525')->is_valid_number, '茨城県筑西市寺上野');
ok($zip->set_number('3004531')->is_valid_number, '茨城県筑西市築地');
ok($zip->set_number('3004532')->is_valid_number, '茨城県筑西市鷺島');
ok($zip->set_number('3004533')->is_valid_number, '茨城県筑西市成井');
ok($zip->set_number('3004534')->is_valid_number, '茨城県筑西市高津');
ok($zip->set_number('3004535')->is_valid_number, '茨城県筑西市谷原');
ok($zip->set_number('3004536')->is_valid_number, '茨城県筑西市東保末');
ok($zip->set_number('3004537')->is_valid_number, '茨城県筑西市大林');
ok($zip->set_number('3004538')->is_valid_number, '茨城県筑西市海老江');
ok($zip->set_number('3004541')->is_valid_number, '茨城県筑西市松原');
ok($zip->set_number('3004542')->is_valid_number, '茨城県筑西市吉田');
ok($zip->set_number('3004543')->is_valid_number, '茨城県筑西市竹垣');
ok($zip->set_number('3004544')->is_valid_number, '茨城県筑西市古内');
ok($zip->set_number('3004545')->is_valid_number, '茨城県筑西市下川中子');
ok($zip->set_number('3004546')->is_valid_number, '茨城県筑西市村田');
ok($zip->set_number('3010000')->is_valid_number, '茨城県龍ケ崎市以下に掲載がない場合');
ok($zip->set_number('3010001')->is_valid_number, '茨城県龍ケ崎市久保台');
ok($zip->set_number('3010002')->is_valid_number, '茨城県龍ケ崎市中根台');
ok($zip->set_number('3010003')->is_valid_number, '茨城県龍ケ崎市平台');
ok($zip->set_number('3010004')->is_valid_number, '茨城県龍ケ崎市馴馬町');
ok($zip->set_number('3010005')->is_valid_number, '茨城県龍ケ崎市川原代町');
ok($zip->set_number('3010006')->is_valid_number, '茨城県龍ケ崎市門倉新田町');
ok($zip->set_number('3010007')->is_valid_number, '茨城県龍ケ崎市馴柴町');
ok($zip->set_number('3010011')->is_valid_number, '茨城県龍ケ崎市横町');
ok($zip->set_number('3010012')->is_valid_number, '茨城県龍ケ崎市上町');
ok($zip->set_number('3010013')->is_valid_number, '茨城県龍ケ崎市水門');
ok($zip->set_number('3010014')->is_valid_number, '茨城県龍ケ崎市須藤堀町');
ok($zip->set_number('3010015')->is_valid_number, '茨城県龍ケ崎市長沖町');
ok($zip->set_number('3010016')->is_valid_number, '茨城県龍ケ崎市長沖新田町');
ok($zip->set_number('3010017')->is_valid_number, '茨城県龍ケ崎市姫宮町');
ok($zip->set_number('3010018')->is_valid_number, '茨城県龍ケ崎市米町');
ok($zip->set_number('3010021')->is_valid_number, '茨城県龍ケ崎市北方町');
ok($zip->set_number('3010022')->is_valid_number, '茨城県龍ケ崎市南が丘');
ok($zip->set_number('3010023')->is_valid_number, '茨城県龍ケ崎市羽黒町');
ok($zip->set_number('3010024')->is_valid_number, '茨城県龍ケ崎市豊田町');
ok($zip->set_number('3010025')->is_valid_number, '茨城県龍ケ崎市大留町');
ok($zip->set_number('3010026')->is_valid_number, '茨城県龍ケ崎市高須町');
ok($zip->set_number('3010031')->is_valid_number, '茨城県龍ケ崎市庄兵衛新田町');
ok($zip->set_number('3010032')->is_valid_number, '茨城県龍ケ崎市佐貫');
ok($zip->set_number('3010033')->is_valid_number, '茨城県龍ケ崎市佐貫町');
ok($zip->set_number('3010034')->is_valid_number, '茨城県龍ケ崎市小通幸谷町');
ok($zip->set_number('3010035')->is_valid_number, '茨城県龍ケ崎市稗柄町');
ok($zip->set_number('3010041')->is_valid_number, '茨城県龍ケ崎市若柴町');
ok($zip->set_number('3010042')->is_valid_number, '茨城県龍ケ崎市長山');
ok($zip->set_number('3010043')->is_valid_number, '茨城県龍ケ崎市松葉');
ok($zip->set_number('3010044')->is_valid_number, '茨城県龍ケ崎市小柴');
ok($zip->set_number('3010045')->is_valid_number, '茨城県龍ケ崎市稲荷新田町');
ok($zip->set_number('3010046')->is_valid_number, '茨城県龍ケ崎市入地町');
ok($zip->set_number('3010047')->is_valid_number, '茨城県龍ケ崎市南中島町');
ok($zip->set_number('3010048')->is_valid_number, '茨城県龍ケ崎市川崎町');
ok($zip->set_number('3010801')->is_valid_number, '茨城県龍ケ崎市板橋町');
ok($zip->set_number('3010802')->is_valid_number, '茨城県龍ケ崎市高作町');
ok($zip->set_number('3010803')->is_valid_number, '茨城県龍ケ崎市塗戸町');
ok($zip->set_number('3010804')->is_valid_number, '茨城県龍ケ崎市長峰町');
ok($zip->set_number('3010805')->is_valid_number, '茨城県龍ケ崎市薄倉町');
ok($zip->set_number('3010806')->is_valid_number, '茨城県龍ケ崎市半田町');
ok($zip->set_number('3010811')->is_valid_number, '茨城県龍ケ崎市宮渕町');
ok($zip->set_number('3010812')->is_valid_number, '茨城県龍ケ崎市佐沼町');
ok($zip->set_number('3010813')->is_valid_number, '茨城県龍ケ崎市新町');
ok($zip->set_number('3010814')->is_valid_number, '茨城県龍ケ崎市高砂');
ok($zip->set_number('3010815')->is_valid_number, '茨城県龍ケ崎市直鮒');
ok($zip->set_number('3010816')->is_valid_number, '茨城県龍ケ崎市大徳町');
ok($zip->set_number('3010817')->is_valid_number, '茨城県龍ケ崎市上大徳新町');
ok($zip->set_number('3010821')->is_valid_number, '茨城県龍ケ崎市東町');
ok($zip->set_number('3010822')->is_valid_number, '茨城県龍ケ崎市光順田');
ok($zip->set_number('3010823')->is_valid_number, '茨城県龍ケ崎市砂町');
ok($zip->set_number('3010824')->is_valid_number, '茨城県龍ケ崎市下町');
ok($zip->set_number('3010825')->is_valid_number, '茨城県龍ケ崎市川余郷');
ok($zip->set_number('3010826')->is_valid_number, '茨城県龍ケ崎市栄町');
ok($zip->set_number('3010831')->is_valid_number, '茨城県龍ケ崎市野原町');
ok($zip->set_number('3010832')->is_valid_number, '茨城県龍ケ崎市緑町');
ok($zip->set_number('3010833')->is_valid_number, '茨城県龍ケ崎市城下');
ok($zip->set_number('3010834')->is_valid_number, '茨城県龍ケ崎市古城');
ok($zip->set_number('3010835')->is_valid_number, '茨城県龍ケ崎市田町');
ok($zip->set_number('3010836')->is_valid_number, '茨城県龍ケ崎市寺後');
ok($zip->set_number('3010837')->is_valid_number, '茨城県龍ケ崎市根町');
ok($zip->set_number('3010838')->is_valid_number, '茨城県龍ケ崎市愛戸町');
ok($zip->set_number('3010839')->is_valid_number, '茨城県龍ケ崎市出し山町');
ok($zip->set_number('3010841')->is_valid_number, '茨城県龍ケ崎市白羽');
ok($zip->set_number('3010842')->is_valid_number, '茨城県龍ケ崎市八代町');
ok($zip->set_number('3010843')->is_valid_number, '茨城県龍ケ崎市羽原町');
ok($zip->set_number('3010844')->is_valid_number, '茨城県龍ケ崎市平畑');
ok($zip->set_number('3010845')->is_valid_number, '茨城県龍ケ崎市奈戸岡');
ok($zip->set_number('3010846')->is_valid_number, '茨城県龍ケ崎市別所町');
ok($zip->set_number('3010847')->is_valid_number, '茨城県龍ケ崎市城ノ内');
ok($zip->set_number('3010851')->is_valid_number, '茨城県龍ケ崎市大塚町');
ok($zip->set_number('3010852')->is_valid_number, '茨城県龍ケ崎市向陽台');
ok($zip->set_number('3010853')->is_valid_number, '茨城県龍ケ崎市松ケ丘');
ok($zip->set_number('3010854')->is_valid_number, '茨城県龍ケ崎市中里');
ok($zip->set_number('3010855')->is_valid_number, '茨城県龍ケ崎市藤ケ丘');
ok($zip->set_number('3010856')->is_valid_number, '茨城県龍ケ崎市貝原塚町');
ok($zip->set_number('3010857')->is_valid_number, '茨城県龍ケ崎市泉町');
ok($zip->set_number('3010901')->is_valid_number, '茨城県稲敷市下根本');
ok($zip->set_number('3010902')->is_valid_number, '茨城県稲敷市上根本');
ok($zip->set_number('3020000')->is_valid_number, '茨城県取手市以下に掲載がない場合');
ok($zip->set_number('3020001')->is_valid_number, '茨城県取手市小文間');
ok($zip->set_number('3020002')->is_valid_number, '茨城県取手市長兵衛新田');
ok($zip->set_number('3020003')->is_valid_number, '茨城県取手市小堀');
ok($zip->set_number('3020004')->is_valid_number, '茨城県取手市取手');
ok($zip->set_number('3020005')->is_valid_number, '茨城県取手市東');
ok($zip->set_number('3020006')->is_valid_number, '茨城県取手市青柳');
ok($zip->set_number('3020007')->is_valid_number, '茨城県取手市吉田');
ok($zip->set_number('3020011')->is_valid_number, '茨城県取手市井野');
ok($zip->set_number('3020012')->is_valid_number, '茨城県取手市井野団地');
ok($zip->set_number('3020013')->is_valid_number, '茨城県取手市台宿');
ok($zip->set_number('3020014')->is_valid_number, '茨城県取手市中央町');
ok($zip->set_number('3020015')->is_valid_number, '茨城県取手市井野台');
ok($zip->set_number('3020016')->is_valid_number, '茨城県取手市中原町');
ok($zip->set_number('3020017')->is_valid_number, '茨城県取手市桑原');
ok($zip->set_number('3020021')->is_valid_number, '茨城県取手市寺田');
ok($zip->set_number('3020022')->is_valid_number, '茨城県取手市本郷');
ok($zip->set_number('3020023')->is_valid_number, '茨城県取手市白山');
ok($zip->set_number('3020024')->is_valid_number, '茨城県取手市新町');
ok($zip->set_number('3020025')->is_valid_number, '茨城県取手市西');
ok($zip->set_number('3020026')->is_valid_number, '茨城県取手市稲');
ok($zip->set_number('3020027')->is_valid_number, '茨城県取手市駒場');
ok($zip->set_number('3020031')->is_valid_number, '茨城県取手市新取手');
ok($zip->set_number('3020032')->is_valid_number, '茨城県取手市野々井');
ok($zip->set_number('3020033')->is_valid_number, '茨城県取手市米ノ井');
ok($zip->set_number('3020034')->is_valid_number, '茨城県取手市戸頭');
ok($zip->set_number('3020035')->is_valid_number, '茨城県取手市上高井');
ok($zip->set_number('3020036')->is_valid_number, '茨城県取手市貝塚');
ok($zip->set_number('3020037')->is_valid_number, '茨城県取手市市之代');
ok($zip->set_number('3020038')->is_valid_number, '茨城県取手市下高井');
ok($zip->set_number('3020039')->is_valid_number, '茨城県取手市ゆめみ野');
ok($zip->set_number('3020100')->is_valid_number, '茨城県守谷市以下に掲載がない場合');
ok($zip->set_number('3020101')->is_valid_number, '茨城県守谷市板戸井');
ok($zip->set_number('3020102')->is_valid_number, '茨城県守谷市松前台');
ok($zip->set_number('3020103')->is_valid_number, '茨城県守谷市大山新田');
ok($zip->set_number('3020104')->is_valid_number, '茨城県守谷市久保ケ丘');
ok($zip->set_number('3020105')->is_valid_number, '茨城県守谷市薬師台');
ok($zip->set_number('3020106')->is_valid_number, '茨城県守谷市緑');
ok($zip->set_number('3020107')->is_valid_number, '茨城県守谷市大木');
ok($zip->set_number('3020108')->is_valid_number, '茨城県守谷市松並');
ok($zip->set_number('3020109')->is_valid_number, '茨城県守谷市本町');
ok($zip->set_number('3020110')->is_valid_number, '茨城県守谷市百合ケ丘');
ok($zip->set_number('3020111')->is_valid_number, '茨城県守谷市赤法花');
ok($zip->set_number('3020112')->is_valid_number, '茨城県守谷市同地');
ok($zip->set_number('3020115')->is_valid_number, '茨城県守谷市中央');
ok($zip->set_number('3020116')->is_valid_number, '茨城県守谷市大柏');
ok($zip->set_number('3020117')->is_valid_number, '茨城県守谷市野木崎');
ok($zip->set_number('3020118')->is_valid_number, '茨城県守谷市立沢');
ok($zip->set_number('3020119')->is_valid_number, '茨城県守谷市御所ケ丘');
ok($zip->set_number('3020121')->is_valid_number, '茨城県守谷市みずき野');
ok($zip->set_number('3020122')->is_valid_number, '茨城県守谷市小山');
ok($zip->set_number('3020123')->is_valid_number, '茨城県守谷市乙子');
ok($zip->set_number('3020124')->is_valid_number, '茨城県守谷市美園');
ok($zip->set_number('3020125')->is_valid_number, '茨城県守谷市高野');
ok($zip->set_number('3020126')->is_valid_number, '茨城県守谷市鈴塚');
ok($zip->set_number('3020127')->is_valid_number, '茨城県守谷市松ケ丘');
ok($zip->set_number('3020128')->is_valid_number, '茨城県守谷市けやき台');
ok($zip->set_number('3020131')->is_valid_number, '茨城県守谷市ひがし野');
ok($zip->set_number('3020132')->is_valid_number, '茨城県守谷市松並青葉');
ok($zip->set_number('3030000')->is_valid_number, '茨城県常総市以下に掲載がない場合');
ok($zip->set_number('3030001')->is_valid_number, '茨城県常総市中山町');
ok($zip->set_number('3030002')->is_valid_number, '茨城県常総市相野谷町');
ok($zip->set_number('3030003')->is_valid_number, '茨城県常総市水海道橋本町');
ok($zip->set_number('3030004')->is_valid_number, '茨城県常総市水海道元町');
ok($zip->set_number('3030005')->is_valid_number, '茨城県常総市水海道森下町');
ok($zip->set_number('3030006')->is_valid_number, '茨城県常総市小山戸町');
ok($zip->set_number('3030011')->is_valid_number, '茨城県常総市東町');
ok($zip->set_number('3030012')->is_valid_number, '茨城県常総市大崎町');
ok($zip->set_number('3030013')->is_valid_number, '茨城県常総市箕輪町');
ok($zip->set_number('3030014')->is_valid_number, '茨城県常総市兵町');
ok($zip->set_number('3030015')->is_valid_number, '茨城県常総市長助町');
ok($zip->set_number('3030016')->is_valid_number, '茨城県常総市新井木町');
ok($zip->set_number('3030017')->is_valid_number, '茨城県常総市平町');
ok($zip->set_number('3030018')->is_valid_number, '茨城県常総市十花町');
ok($zip->set_number('3030021')->is_valid_number, '茨城県常総市水海道諏訪町');
ok($zip->set_number('3030022')->is_valid_number, '茨城県常総市水海道淵頭町');
ok($zip->set_number('3030023')->is_valid_number, '茨城県常総市水海道宝町');
ok($zip->set_number('3030024')->is_valid_number, '茨城県常総市水海道栄町');
ok($zip->set_number('3030025')->is_valid_number, '茨城県常総市水海道亀岡町');
ok($zip->set_number('3030026')->is_valid_number, '茨城県常総市水海道本町');
ok($zip->set_number('3030031')->is_valid_number, '茨城県常総市水海道山田町');
ok($zip->set_number('3030032')->is_valid_number, '茨城県常総市水海道川又町');
ok($zip->set_number('3030033')->is_valid_number, '茨城県常総市水海道高野町');
ok($zip->set_number('3030034')->is_valid_number, '茨城県常総市水海道天満町');
ok($zip->set_number('3030041')->is_valid_number, '茨城県常総市豊岡町');
ok($zip->set_number('3030042')->is_valid_number, '茨城県常総市坂手町');
ok($zip->set_number('3030043')->is_valid_number, '茨城県常総市内守谷町');
ok($zip->set_number('3030044')->is_valid_number, '茨城県常総市菅生町');
ok($zip->set_number('3030045')->is_valid_number, '茨城県常総市大塚戸町');
ok($zip->set_number('3030046')->is_valid_number, '茨城県常総市内守谷町きぬの里');
ok($zip->set_number('3040000')->is_valid_number, '茨城県下妻市以下に掲載がない場合');
ok($zip->set_number('3040001')->is_valid_number, '茨城県下妻市平方');
ok($zip->set_number('3040002')->is_valid_number, '茨城県下妻市江');
ok($zip->set_number('3040003')->is_valid_number, '茨城県下妻市関本下');
ok($zip->set_number('3040004')->is_valid_number, '茨城県下妻市大木');
ok($zip->set_number('3040005')->is_valid_number, '茨城県下妻市半谷');
ok($zip->set_number('3040006')->is_valid_number, '茨城県下妻市柴');
ok($zip->set_number('3040007')->is_valid_number, '茨城県下妻市黒駒');
ok($zip->set_number('3040011')->is_valid_number, '茨城県下妻市神明');
ok($zip->set_number('3040012')->is_valid_number, '茨城県下妻市若柳');
ok($zip->set_number('3040013')->is_valid_number, '茨城県下妻市下宮');
ok($zip->set_number('3040014')->is_valid_number, '茨城県下妻市中郷');
ok($zip->set_number('3040015')->is_valid_number, '茨城県下妻市下田');
ok($zip->set_number('3040016')->is_valid_number, '茨城県下妻市数須');
ok($zip->set_number('3040017')->is_valid_number, '茨城県下妻市筑波島');
ok($zip->set_number('3040018')->is_valid_number, '茨城県下妻市平川戸');
ok($zip->set_number('3040021')->is_valid_number, '茨城県下妻市北大宝');
ok($zip->set_number('3040022')->is_valid_number, '茨城県下妻市大宝');
ok($zip->set_number('3040023')->is_valid_number, '茨城県下妻市大串');
ok($zip->set_number('3040024')->is_valid_number, '茨城県下妻市坂本新田');
ok($zip->set_number('3040025')->is_valid_number, '茨城県下妻市大木新田');
ok($zip->set_number('3040026')->is_valid_number, '茨城県下妻市平沼');
ok($zip->set_number('3040027')->is_valid_number, '茨城県下妻市福田');
ok($zip->set_number('3040028')->is_valid_number, '茨城県下妻市下木戸');
ok($zip->set_number('3040031')->is_valid_number, '茨城県下妻市高道祖');
ok($zip->set_number('3040032')->is_valid_number, '茨城県下妻市比毛');
ok($zip->set_number('3040033')->is_valid_number, '茨城県下妻市堀篭');
ok($zip->set_number('3040034')->is_valid_number, '茨城県下妻市坂井');
ok($zip->set_number('3040035')->is_valid_number, '茨城県下妻市横根');
ok($zip->set_number('3040041')->is_valid_number, '茨城県下妻市古沢');
ok($zip->set_number('3040042')->is_valid_number, '茨城県下妻市袋畑');
ok($zip->set_number('3040043')->is_valid_number, '茨城県下妻市谷田部');
ok($zip->set_number('3040044')->is_valid_number, '茨城県下妻市柳原');
ok($zip->set_number('3040045')->is_valid_number, '茨城県下妻市山尻');
ok($zip->set_number('3040046')->is_valid_number, '茨城県下妻市樋橋');
ok($zip->set_number('3040047')->is_valid_number, '茨城県下妻市肘谷');
ok($zip->set_number('3040048')->is_valid_number, '茨城県下妻市加養');
ok($zip->set_number('3040049')->is_valid_number, '茨城県下妻市新堀');
ok($zip->set_number('3040050')->is_valid_number, '茨城県下妻市亀崎');
ok($zip->set_number('3040051')->is_valid_number, '茨城県下妻市小島');
ok($zip->set_number('3040052')->is_valid_number, '茨城県下妻市二本紀');
ok($zip->set_number('3040053')->is_valid_number, '茨城県下妻市今泉');
ok($zip->set_number('3040054')->is_valid_number, '茨城県下妻市中居指');
ok($zip->set_number('3040055')->is_valid_number, '茨城県下妻市砂沼新田');
ok($zip->set_number('3040056')->is_valid_number, '茨城県下妻市長塚');
ok($zip->set_number('3040057')->is_valid_number, '茨城県下妻市石の宮');
ok($zip->set_number('3040061')->is_valid_number, '茨城県下妻市下妻丙');
ok($zip->set_number('3040062')->is_valid_number, '茨城県下妻市下妻戊');
ok($zip->set_number('3040063')->is_valid_number, '茨城県下妻市小野子町');
ok($zip->set_number('3040064')->is_valid_number, '茨城県下妻市本城町');
ok($zip->set_number('3040065')->is_valid_number, '茨城県下妻市本宿町');
ok($zip->set_number('3040066')->is_valid_number, '茨城県下妻市下妻甲');
ok($zip->set_number('3040067')->is_valid_number, '茨城県下妻市下妻乙');
ok($zip->set_number('3040068')->is_valid_number, '茨城県下妻市下妻丁');
ok($zip->set_number('3040069')->is_valid_number, '茨城県下妻市田町');
ok($zip->set_number('3040071')->is_valid_number, '茨城県下妻市尻手');
ok($zip->set_number('3040072')->is_valid_number, '茨城県下妻市渋井');
ok($zip->set_number('3040073')->is_valid_number, '茨城県下妻市桐ケ瀬');
ok($zip->set_number('3040074')->is_valid_number, '茨城県下妻市赤須');
ok($zip->set_number('3040075')->is_valid_number, '茨城県下妻市南原');
ok($zip->set_number('3040076')->is_valid_number, '茨城県下妻市前河原');
ok($zip->set_number('3040801')->is_valid_number, '茨城県下妻市大園木');
ok($zip->set_number('3040802')->is_valid_number, '茨城県下妻市鯨');
ok($zip->set_number('3040803')->is_valid_number, '茨城県下妻市伊古立');
ok($zip->set_number('3040804')->is_valid_number, '茨城県下妻市長萱');
ok($zip->set_number('3040805')->is_valid_number, '茨城県下妻市唐崎');
ok($zip->set_number('3040806')->is_valid_number, '茨城県下妻市見田');
ok($zip->set_number('3040811')->is_valid_number, '茨城県下妻市下栗');
ok($zip->set_number('3040812')->is_valid_number, '茨城県下妻市田下');
ok($zip->set_number('3040813')->is_valid_number, '茨城県下妻市本宗道');
ok($zip->set_number('3040814')->is_valid_number, '茨城県下妻市宗道');
ok($zip->set_number('3040815')->is_valid_number, '茨城県下妻市渋田');
ok($zip->set_number('3040816')->is_valid_number, '茨城県下妻市原');
ok($zip->set_number('3040817')->is_valid_number, '茨城県下妻市羽子');
ok($zip->set_number('3040818')->is_valid_number, '茨城県下妻市鬼怒');
ok($zip->set_number('3040819')->is_valid_number, '茨城県下妻市鎌庭');
ok($zip->set_number('3040821')->is_valid_number, '茨城県下妻市別府');
ok($zip->set_number('3040822')->is_valid_number, '茨城県下妻市皆葉');
ok($zip->set_number('3040823')->is_valid_number, '茨城県下妻市五箇');
ok($zip->set_number('3040824')->is_valid_number, '茨城県下妻市村岡');
ok($zip->set_number('3050000')->is_valid_number, '茨城県つくば市以下に掲載がない場合');
ok($zip->set_number('3050001')->is_valid_number, '茨城県つくば市栗原');
ok($zip->set_number('3050002')->is_valid_number, '茨城県つくば市上野');
ok($zip->set_number('3050003')->is_valid_number, '茨城県つくば市桜');
ok($zip->set_number('3050004')->is_valid_number, '茨城県つくば市柴崎');
ok($zip->set_number('3050005')->is_valid_number, '茨城県つくば市天久保');
ok($zip->set_number('3050006')->is_valid_number, '茨城県つくば市天王台');
ok($zip->set_number('3050007')->is_valid_number, '茨城県つくば市春風台');
ok($zip->set_number('3050008')->is_valid_number, '茨城県つくば市流星台');
ok($zip->set_number('3050011')->is_valid_number, '茨城県つくば市上境');
ok($zip->set_number('3050012')->is_valid_number, '茨城県つくば市中根');
ok($zip->set_number('3050013')->is_valid_number, '茨城県つくば市栄');
ok($zip->set_number('3050014')->is_valid_number, '茨城県つくば市松栄');
ok($zip->set_number('3050015')->is_valid_number, '茨城県つくば市松塚');
ok($zip->set_number('3050016')->is_valid_number, '茨城県つくば市大');
ok($zip->set_number('3050017')->is_valid_number, '茨城県つくば市横町');
ok($zip->set_number('3050018')->is_valid_number, '茨城県つくば市金田');
ok($zip->set_number('3050019')->is_valid_number, '茨城県つくば市さくらの森');
ok($zip->set_number('3050021')->is_valid_number, '茨城県つくば市古来');
ok($zip->set_number('3050022')->is_valid_number, '茨城県つくば市吉瀬');
ok($zip->set_number('3050023')->is_valid_number, '茨城県つくば市上ノ室');
ok($zip->set_number('3050024')->is_valid_number, '茨城県つくば市倉掛');
ok($zip->set_number('3050025')->is_valid_number, '茨城県つくば市花室');
ok($zip->set_number('3050026')->is_valid_number, '茨城県つくば市岡村新田');
ok($zip->set_number('3050027')->is_valid_number, '茨城県つくば市東岡');
ok($zip->set_number('3050028')->is_valid_number, '茨城県つくば市妻木');
ok($zip->set_number('3050029')->is_valid_number, '茨城県つくば市花園');
ok($zip->set_number('3050031')->is_valid_number, '茨城県つくば市吾妻');
ok($zip->set_number('3050032')->is_valid_number, '茨城県つくば市竹園');
ok($zip->set_number('3050033')->is_valid_number, '茨城県つくば市東新井');
ok($zip->set_number('3050034')->is_valid_number, '茨城県つくば市小野崎');
ok($zip->set_number('3050035')->is_valid_number, '茨城県つくば市松代');
ok($zip->set_number('3050036')->is_valid_number, '茨城県つくば市西郷');
ok($zip->set_number('3050041')->is_valid_number, '茨城県つくば市上広岡');
ok($zip->set_number('3050042')->is_valid_number, '茨城県つくば市下広岡');
ok($zip->set_number('3050043')->is_valid_number, '茨城県つくば市大角豆');
ok($zip->set_number('3050044')->is_valid_number, '茨城県つくば市並木');
ok($zip->set_number('3050045')->is_valid_number, '茨城県つくば市梅園');
ok($zip->set_number('3050046')->is_valid_number, '茨城県つくば市東');
ok($zip->set_number('3050047')->is_valid_number, '茨城県つくば市千現');
ok($zip->set_number('3050051')->is_valid_number, '茨城県つくば市二の宮');
ok($zip->set_number('3050052')->is_valid_number, '茨城県つくば市長峰');
ok($zip->set_number('3050053')->is_valid_number, '茨城県つくば市小野川');
ok($zip->set_number('3050054')->is_valid_number, '茨城県つくば市西大沼');
ok($zip->set_number('3050055')->is_valid_number, '茨城県つくば市上原');
ok($zip->set_number('3050056')->is_valid_number, '茨城県つくば市松野木');
ok($zip->set_number('3050061')->is_valid_number, '茨城県つくば市稲荷前');
ok($zip->set_number('3050062')->is_valid_number, '茨城県つくば市赤塚');
ok($zip->set_number('3050063')->is_valid_number, '茨城県つくば市下原');
ok($zip->set_number('3050064')->is_valid_number, '茨城県つくば市梶内');
ok($zip->set_number('3050065')->is_valid_number, '茨城県つくば市南中妻');
ok($zip->set_number('3050066')->is_valid_number, '茨城県つくば市北中妻');
ok($zip->set_number('3050067')->is_valid_number, '茨城県つくば市館野');
ok($zip->set_number('3050068')->is_valid_number, '茨城県つくば市中内');
ok($zip->set_number('3050071')->is_valid_number, '茨城県つくば市稲岡');
ok($zip->set_number('3050072')->is_valid_number, '茨城県つくば市北中島');
ok($zip->set_number('3050073')->is_valid_number, '茨城県つくば市市之台');
ok($zip->set_number('3050074')->is_valid_number, '茨城県つくば市高野台');
ok($zip->set_number('3050075')->is_valid_number, '茨城県つくば市下横場');
ok($zip->set_number('3050076')->is_valid_number, '茨城県つくば市新牧田');
ok($zip->set_number('3050077')->is_valid_number, '茨城県つくば市鷹野原');
ok($zip->set_number('3050801')->is_valid_number, '茨城県つくば市大穂(1-1)');
ok($zip->set_number('3050802')->is_valid_number, '茨城県つくば市立原(1、2、3)');
ok($zip->set_number('3050803')->is_valid_number, '茨城県つくば市南原(2)');
ok($zip->set_number('3050804')->is_valid_number, '茨城県つくば市旭(1)');
ok($zip->set_number('3050805')->is_valid_number, '茨城県つくば市花畑(1-7-1)');
ok($zip->set_number('3050811')->is_valid_number, '茨城県つくば市北郷');
ok($zip->set_number('3050812')->is_valid_number, '茨城県つくば市東平塚');
ok($zip->set_number('3050813')->is_valid_number, '茨城県つくば市下平塚');
ok($zip->set_number('3050814')->is_valid_number, '茨城県つくば市西平塚');
ok($zip->set_number('3050815')->is_valid_number, '茨城県つくば市西原');
ok($zip->set_number('3050816')->is_valid_number, '茨城県つくば市学園の森');
ok($zip->set_number('3050817')->is_valid_number, '茨城県つくば市研究学園');
ok($zip->set_number('3050818')->is_valid_number, '茨城県つくば市学園南');
ok($zip->set_number('3050821')->is_valid_number, '茨城県つくば市春日');
ok($zip->set_number('3050822')->is_valid_number, '茨城県つくば市苅間');
ok($zip->set_number('3050823')->is_valid_number, '茨城県つくば市原');
ok($zip->set_number('3050824')->is_valid_number, '茨城県つくば市葛城根崎');
ok($zip->set_number('3050831')->is_valid_number, '茨城県つくば市西大橋');
ok($zip->set_number('3050832')->is_valid_number, '茨城県つくば市西岡');
ok($zip->set_number('3050833')->is_valid_number, '茨城県つくば市島');
ok($zip->set_number('3050834')->is_valid_number, '茨城県つくば市手代木');
ok($zip->set_number('3050835')->is_valid_number, '茨城県つくば市新井');
ok($zip->set_number('3050836')->is_valid_number, '茨城県つくば市山中');
ok($zip->set_number('3050841')->is_valid_number, '茨城県つくば市御幸が丘');
ok($zip->set_number('3050842')->is_valid_number, '茨城県つくば市柳橋');
ok($zip->set_number('3050843')->is_valid_number, '茨城県つくば市八幡台');
ok($zip->set_number('3050844')->is_valid_number, '茨城県つくば市小白硲');
ok($zip->set_number('3050845')->is_valid_number, '茨城県つくば市大白硲');
ok($zip->set_number('3050846')->is_valid_number, '茨城県つくば市平');
ok($zip->set_number('3050847')->is_valid_number, '茨城県つくば市陣場');
ok($zip->set_number('3050851')->is_valid_number, '茨城県つくば市大わし');
ok($zip->set_number('3050852')->is_valid_number, '茨城県つくば市藤本');
ok($zip->set_number('3050853')->is_valid_number, '茨城県つくば市榎戸');
ok($zip->set_number('3050854')->is_valid_number, '茨城県つくば市上横場');
ok($zip->set_number('3050855')->is_valid_number, '茨城県つくば市今泉');
ok($zip->set_number('3050856')->is_valid_number, '茨城県つくば市観音台');
ok($zip->set_number('3050857')->is_valid_number, '茨城県つくば市羽成');
ok($zip->set_number('3050861')->is_valid_number, '茨城県つくば市谷田部');
ok($zip->set_number('3050862')->is_valid_number, '茨城県つくば市東丸山');
ok($zip->set_number('3050863')->is_valid_number, '茨城県つくば市緑が丘');
ok($zip->set_number('3050864')->is_valid_number, '茨城県つくば市境松');
ok($zip->set_number('3050865')->is_valid_number, '茨城県つくば市根崎');
ok($zip->set_number('3050866')->is_valid_number, '茨城県つくば市古館');
ok($zip->set_number('3050867')->is_valid_number, '茨城県つくば市境田');
ok($zip->set_number('3050868')->is_valid_number, '茨城県つくば市台町');
ok($zip->set_number('3050871')->is_valid_number, '茨城県つくば市上萱丸');
ok($zip->set_number('3050872')->is_valid_number, '茨城県つくば市下萱丸');
ok($zip->set_number('3050873')->is_valid_number, '茨城県つくば市中野');
ok($zip->set_number('3050874')->is_valid_number, '茨城県つくば市飯田');
ok($zip->set_number('3050875')->is_valid_number, '茨城県つくば市花島新田');
ok($zip->set_number('3050876')->is_valid_number, '茨城県つくば市西栗山');
ok($zip->set_number('3050877')->is_valid_number, '茨城県つくば市片田');
ok($zip->set_number('3050881')->is_valid_number, '茨城県つくば市みどりの');
ok($zip->set_number('3050882')->is_valid_number, '茨城県つくば市みどりの中央');
ok($zip->set_number('3050883')->is_valid_number, '茨城県つくば市みどりの東');
ok($zip->set_number('3050884')->is_valid_number, '茨城県つくば市みどりの南');
ok($zip->set_number('3050901')->is_valid_number, '茨城県つくば市池の台(2)');
ok($zip->set_number('3050902')->is_valid_number, '茨城県つくば市西の沢(畜産試験場圃場)');
ok($zip->set_number('3050903')->is_valid_number, '茨城県つくば市松の里(1)');
ok($zip->set_number('3060000')->is_valid_number, '茨城県古河市以下に掲載がない場合');
ok($zip->set_number('3060001')->is_valid_number, '茨城県古河市静町');
ok($zip->set_number('3060002')->is_valid_number, '茨城県古河市三杉町');
ok($zip->set_number('3060003')->is_valid_number, '茨城県古河市緑町');
ok($zip->set_number('3060004')->is_valid_number, '茨城県古河市雷電町');
ok($zip->set_number('3060005')->is_valid_number, '茨城県古河市北町');
ok($zip->set_number('3060006')->is_valid_number, '茨城県古河市平和町');
ok($zip->set_number('3060007')->is_valid_number, '茨城県古河市常盤町');
ok($zip->set_number('3060011')->is_valid_number, '茨城県古河市東');
ok($zip->set_number('3060012')->is_valid_number, '茨城県古河市旭町');
ok($zip->set_number('3060013')->is_valid_number, '茨城県古河市東本町');
ok($zip->set_number('3060014')->is_valid_number, '茨城県古河市下山町');
ok($zip->set_number('3060015')->is_valid_number, '茨城県古河市南町');
ok($zip->set_number('3060016')->is_valid_number, '茨城県古河市古河');
ok($zip->set_number('3060021')->is_valid_number, '茨城県古河市松並');
ok($zip->set_number('3060022')->is_valid_number, '茨城県古河市横山町');
ok($zip->set_number('3060023')->is_valid_number, '茨城県古河市本町');
ok($zip->set_number('3060024')->is_valid_number, '茨城県古河市幸町');
ok($zip->set_number('3060025')->is_valid_number, '茨城県古河市原町');
ok($zip->set_number('3060026')->is_valid_number, '茨城県古河市原');
ok($zip->set_number('3060031')->is_valid_number, '茨城県古河市宮前町');
ok($zip->set_number('3060032')->is_valid_number, '茨城県古河市大手町');
ok($zip->set_number('3060033')->is_valid_number, '茨城県古河市中央町');
ok($zip->set_number('3060034')->is_valid_number, '茨城県古河市長谷町');
ok($zip->set_number('3060035')->is_valid_number, '茨城県古河市長谷');
ok($zip->set_number('3060036')->is_valid_number, '茨城県古河市桜町');
ok($zip->set_number('3060037')->is_valid_number, '茨城県古河市錦町');
ok($zip->set_number('3060038')->is_valid_number, '茨城県古河市西町');
ok($zip->set_number('3060041')->is_valid_number, '茨城県古河市鴻巣');
ok($zip->set_number('3060042')->is_valid_number, '茨城県古河市三和');
ok($zip->set_number('3060043')->is_valid_number, '茨城県古河市鳥喰');
ok($zip->set_number('3060044')->is_valid_number, '茨城県古河市新久田');
ok($zip->set_number('3060045')->is_valid_number, '茨城県古河市駒ケ崎');
ok($zip->set_number('3060046')->is_valid_number, '茨城県古河市牧野地');
ok($zip->set_number('3060047')->is_valid_number, '茨城県古河市立崎');
ok($zip->set_number('3060051')->is_valid_number, '茨城県古河市茶屋新田');
ok($zip->set_number('3060052')->is_valid_number, '茨城県古河市大山');
ok($zip->set_number('3060053')->is_valid_number, '茨城県古河市中田');
ok($zip->set_number('3060054')->is_valid_number, '茨城県古河市中田新田');
ok($zip->set_number('3060055')->is_valid_number, '茨城県古河市けやき平');
ok($zip->set_number('3060056')->is_valid_number, '茨城県古河市坂間');
ok($zip->set_number('3060101')->is_valid_number, '茨城県古河市尾崎');
ok($zip->set_number('3060103')->is_valid_number, '茨城県古河市長左エ門新田');
ok($zip->set_number('3060104')->is_valid_number, '茨城県古河市恩名');
ok($zip->set_number('3060105')->is_valid_number, '茨城県古河市江口');
ok($zip->set_number('3060106')->is_valid_number, '茨城県古河市北間中橋');
ok($zip->set_number('3060107')->is_valid_number, '茨城県古河市東間中橋');
ok($zip->set_number('3060108')->is_valid_number, '茨城県古河市南間中橋');
ok($zip->set_number('3060109')->is_valid_number, '茨城県古河市西間中橋');
ok($zip->set_number('3060110')->is_valid_number, '茨城県古河市名崎');
ok($zip->set_number('3060111')->is_valid_number, '茨城県古河市大和田');
ok($zip->set_number('3060112')->is_valid_number, '茨城県古河市東山田');
ok($zip->set_number('3060113')->is_valid_number, '茨城県古河市谷貝');
ok($zip->set_number('3060114')->is_valid_number, '茨城県古河市山田');
ok($zip->set_number('3060115')->is_valid_number, '茨城県古河市北山田');
ok($zip->set_number('3060116')->is_valid_number, '茨城県古河市新和田');
ok($zip->set_number('3060121')->is_valid_number, '茨城県古河市駒込');
ok($zip->set_number('3060122')->is_valid_number, '茨城県古河市上和田');
ok($zip->set_number('3060123')->is_valid_number, '茨城県古河市五部');
ok($zip->set_number('3060124')->is_valid_number, '茨城県古河市東諸川');
ok($zip->set_number('3060125')->is_valid_number, '茨城県古河市仁連');
ok($zip->set_number('3060126')->is_valid_number, '茨城県古河市諸川');
ok($zip->set_number('3060127')->is_valid_number, '茨城県古河市下片田');
ok($zip->set_number('3060128')->is_valid_number, '茨城県古河市上片田');
ok($zip->set_number('3060201')->is_valid_number, '茨城県古河市上大野');
ok($zip->set_number('3060202')->is_valid_number, '茨城県古河市稲宮');
ok($zip->set_number('3060203')->is_valid_number, '茨城県古河市柳橋');
ok($zip->set_number('3060204')->is_valid_number, '茨城県古河市下大野');
ok($zip->set_number('3060205')->is_valid_number, '茨城県古河市関戸');
ok($zip->set_number('3060206')->is_valid_number, '茨城県古河市丘里');
ok($zip->set_number('3060211')->is_valid_number, '茨城県古河市葛生');
ok($zip->set_number('3060212')->is_valid_number, '茨城県古河市久能');
ok($zip->set_number('3060213')->is_valid_number, '茨城県古河市北利根');
ok($zip->set_number('3060214')->is_valid_number, '茨城県古河市高野');
ok($zip->set_number('3060215')->is_valid_number, '茨城県古河市水海');
ok($zip->set_number('3060216')->is_valid_number, '茨城県古河市前林');
ok($zip->set_number('3060221')->is_valid_number, '茨城県古河市駒羽根');
ok($zip->set_number('3060222')->is_valid_number, '茨城県古河市釈迦');
ok($zip->set_number('3060223')->is_valid_number, '茨城県古河市上砂井');
ok($zip->set_number('3060224')->is_valid_number, '茨城県古河市砂井新田');
ok($zip->set_number('3060225')->is_valid_number, '茨城県古河市磯部');
ok($zip->set_number('3060226')->is_valid_number, '茨城県古河市女沼');
ok($zip->set_number('3060231')->is_valid_number, '茨城県古河市小堤');
ok($zip->set_number('3060232')->is_valid_number, '茨城県古河市東牛谷');
ok($zip->set_number('3060233')->is_valid_number, '茨城県古河市西牛谷');
ok($zip->set_number('3060234')->is_valid_number, '茨城県古河市上辺見');
ok($zip->set_number('3060235')->is_valid_number, '茨城県古河市下辺見');
ok($zip->set_number('3060236')->is_valid_number, '茨城県古河市大堤');
ok($zip->set_number('3060300')->is_valid_number, '茨城県猿島郡五霞町以下に掲載がない場合');
ok($zip->set_number('3060301')->is_valid_number, '茨城県猿島郡五霞町山王山');
ok($zip->set_number('3060302')->is_valid_number, '茨城県猿島郡五霞町山王');
ok($zip->set_number('3060303')->is_valid_number, '茨城県猿島郡五霞町江川');
ok($zip->set_number('3060304')->is_valid_number, '茨城県猿島郡五霞町幸主');
ok($zip->set_number('3060305')->is_valid_number, '茨城県猿島郡五霞町冬木');
ok($zip->set_number('3060306')->is_valid_number, '茨城県猿島郡五霞町原宿台');
ok($zip->set_number('3060307')->is_valid_number, '茨城県猿島郡五霞町小福田');
ok($zip->set_number('3060308')->is_valid_number, '茨城県猿島郡五霞町ごかみらい');
ok($zip->set_number('3060311')->is_valid_number, '茨城県猿島郡五霞町大福田');
ok($zip->set_number('3060312')->is_valid_number, '茨城県猿島郡五霞町新幸谷');
ok($zip->set_number('3060313')->is_valid_number, '茨城県猿島郡五霞町元栗橋');
ok($zip->set_number('3060314')->is_valid_number, '茨城県猿島郡五霞町川妻');
ok($zip->set_number('3060315')->is_valid_number, '茨城県猿島郡五霞町小手指');
ok($zip->set_number('3060316')->is_valid_number, '茨城県猿島郡五霞町釈迦');
ok($zip->set_number('3060317')->is_valid_number, '茨城県猿島郡五霞町前林');
ok($zip->set_number('3060400')->is_valid_number, '茨城県猿島郡境町以下に掲載がない場合');
ok($zip->set_number('3060401')->is_valid_number, '茨城県猿島郡境町志鳥');
ok($zip->set_number('3060402')->is_valid_number, '茨城県猿島郡境町猿山');
ok($zip->set_number('3060403')->is_valid_number, '茨城県猿島郡境町蛇池');
ok($zip->set_number('3060404')->is_valid_number, '茨城県猿島郡境町長井戸');
ok($zip->set_number('3060405')->is_valid_number, '茨城県猿島郡境町塚崎');
ok($zip->set_number('3060406')->is_valid_number, '茨城県猿島郡境町横塚');
ok($zip->set_number('3060407')->is_valid_number, '茨城県猿島郡境町稲尾');
ok($zip->set_number('3060408')->is_valid_number, '茨城県猿島郡境町みらい平');
ok($zip->set_number('3060411')->is_valid_number, '茨城県猿島郡境町下砂井');
ok($zip->set_number('3060412')->is_valid_number, '茨城県猿島郡境町栗山');
ok($zip->set_number('3060413')->is_valid_number, '茨城県猿島郡境町山崎');
ok($zip->set_number('3060414')->is_valid_number, '茨城県猿島郡境町内門');
ok($zip->set_number('3060415')->is_valid_number, '茨城県猿島郡境町大歩');
ok($zip->set_number('3060416')->is_valid_number, '茨城県猿島郡境町伏木');
ok($zip->set_number('3060417')->is_valid_number, '茨城県猿島郡境町若林');
ok($zip->set_number('3060421')->is_valid_number, '茨城県猿島郡境町染谷');
ok($zip->set_number('3060422')->is_valid_number, '茨城県猿島郡境町一ノ谷');
ok($zip->set_number('3060423')->is_valid_number, '茨城県猿島郡境町百戸');
ok($zip->set_number('3060424')->is_valid_number, '茨城県猿島郡境町桐ケ作');
ok($zip->set_number('3060425')->is_valid_number, '茨城県猿島郡境町新田戸');
ok($zip->set_number('3060426')->is_valid_number, '茨城県猿島郡境町金岡');
ok($zip->set_number('3060427')->is_valid_number, '茨城県猿島郡境町浦向');
ok($zip->set_number('3060431')->is_valid_number, '茨城県猿島郡境町西泉田');
ok($zip->set_number('3060432')->is_valid_number, '茨城県猿島郡境町下小橋');
ok($zip->set_number('3060433')->is_valid_number, '茨城県猿島郡境町境町の次に番地がくる場合');
ok($zip->set_number('3060434')->is_valid_number, '茨城県猿島郡境町上小橋');
ok($zip->set_number('3060435')->is_valid_number, '茨城県猿島郡境町陽光台');
ok($zip->set_number('3060501')->is_valid_number, '茨城県坂東市逆井');
ok($zip->set_number('3060502')->is_valid_number, '茨城県坂東市山');
ok($zip->set_number('3060503')->is_valid_number, '茨城県坂東市生子新田');
ok($zip->set_number('3060504')->is_valid_number, '茨城県坂東市生子');
ok($zip->set_number('3060505')->is_valid_number, '茨城県坂東市菅谷');
ok($zip->set_number('3060511')->is_valid_number, '茨城県坂東市孫兵エ新田');
ok($zip->set_number('3060512')->is_valid_number, '茨城県坂東市左平太新田');
ok($zip->set_number('3060513')->is_valid_number, '茨城県坂東市栗山新田');
ok($zip->set_number('3060514')->is_valid_number, '茨城県坂東市内野山');
ok($zip->set_number('3060515')->is_valid_number, '茨城県坂東市沓掛');
ok($zip->set_number('3060600')->is_valid_number, '茨城県坂東市以下に掲載がない場合');
ok($zip->set_number('3060601')->is_valid_number, '茨城県坂東市大馬新田');
ok($zip->set_number('3060602')->is_valid_number, '茨城県坂東市平八新田');
ok($zip->set_number('3060603')->is_valid_number, '茨城県坂東市勘助新田');
ok($zip->set_number('3060604')->is_valid_number, '茨城県坂東市幸田新田');
ok($zip->set_number('3060605')->is_valid_number, '茨城県坂東市馬立');
ok($zip->set_number('3060606')->is_valid_number, '茨城県坂東市幸田');
ok($zip->set_number('3060607')->is_valid_number, '茨城県坂東市弓田');
ok($zip->set_number('3060608')->is_valid_number, '茨城県坂東市幸神平');
ok($zip->set_number('3060611')->is_valid_number, '茨城県坂東市神田山新田');
ok($zip->set_number('3060612')->is_valid_number, '茨城県坂東市猫実新田');
ok($zip->set_number('3060613')->is_valid_number, '茨城県坂東市大口新田');
ok($zip->set_number('3060614')->is_valid_number, '茨城県坂東市庄右衛門新田');
ok($zip->set_number('3060615')->is_valid_number, '茨城県坂東市大口');
ok($zip->set_number('3060616')->is_valid_number, '茨城県坂東市猫実');
ok($zip->set_number('3060617')->is_valid_number, '茨城県坂東市神田山');
ok($zip->set_number('3060621')->is_valid_number, '茨城県坂東市大谷口');
ok($zip->set_number('3060622')->is_valid_number, '茨城県坂東市大崎');
ok($zip->set_number('3060623')->is_valid_number, '茨城県坂東市法師戸');
ok($zip->set_number('3060624')->is_valid_number, '茨城県坂東市矢作');
ok($zip->set_number('3060625')->is_valid_number, '茨城県坂東市莚打');
ok($zip->set_number('3060626')->is_valid_number, '茨城県坂東市小山');
ok($zip->set_number('3060631')->is_valid_number, '茨城県坂東市岩井');
ok($zip->set_number('3060632')->is_valid_number, '茨城県坂東市辺田');
ok($zip->set_number('3060633')->is_valid_number, '茨城県坂東市下出島');
ok($zip->set_number('3060634')->is_valid_number, '茨城県坂東市中里');
ok($zip->set_number('3060635')->is_valid_number, '茨城県坂東市小泉');
ok($zip->set_number('3060636')->is_valid_number, '茨城県坂東市桐木');
ok($zip->set_number('3060637')->is_valid_number, '茨城県坂東市みどり町');
ok($zip->set_number('3060641')->is_valid_number, '茨城県坂東市鵠戸');
ok($zip->set_number('3060642')->is_valid_number, '茨城県坂東市長谷');
ok($zip->set_number('3060643')->is_valid_number, '茨城県坂東市木間ケ瀬');
ok($zip->set_number('3060644')->is_valid_number, '茨城県坂東市古布内');
ok($zip->set_number('3060645')->is_valid_number, '茨城県坂東市長須');
ok($zip->set_number('3060651')->is_valid_number, '茨城県坂東市半谷');
ok($zip->set_number('3060652')->is_valid_number, '茨城県坂東市冨田');
ok($zip->set_number('3060653')->is_valid_number, '茨城県坂東市駒跿');
ok($zip->set_number('3060654')->is_valid_number, '茨城県坂東市上出島');
ok($zip->set_number('3060655')->is_valid_number, '茨城県坂東市みむら');
ok($zip->set_number('3060656')->is_valid_number, '茨城県坂東市寺久');
ok($zip->set_number('3060657')->is_valid_number, '茨城県坂東市借宿');
ok($zip->set_number('3060658')->is_valid_number, '茨城県坂東市緑の里');
ok($zip->set_number('3070000')->is_valid_number, '茨城県結城市以下に掲載がない場合');
ok($zip->set_number('3070001')->is_valid_number, '茨城県結城市結城');
ok($zip->set_number('3070002')->is_valid_number, '茨城県結城市大谷瀬');
ok($zip->set_number('3070003')->is_valid_number, '茨城県結城市富士見町');
ok($zip->set_number('3070004')->is_valid_number, '茨城県結城市みどり町');
ok($zip->set_number('3070005')->is_valid_number, '茨城県結城市川木谷');
ok($zip->set_number('3070006')->is_valid_number, '茨城県結城市五助');
ok($zip->set_number('3070007')->is_valid_number, '茨城県結城市小田林');
ok($zip->set_number('3070008')->is_valid_number, '茨城県結城市下り松');
ok($zip->set_number('3070011')->is_valid_number, '茨城県結城市小森');
ok($zip->set_number('3070012')->is_valid_number, '茨城県結城市久保田');
ok($zip->set_number('3070013')->is_valid_number, '茨城県結城市中');
ok($zip->set_number('3070014')->is_valid_number, '茨城県結城市林');
ok($zip->set_number('3070015')->is_valid_number, '茨城県結城市鹿窪');
ok($zip->set_number('3070016')->is_valid_number, '茨城県結城市新堤仲通り');
ok($zip->set_number('3070017')->is_valid_number, '茨城県結城市若宮');
ok($zip->set_number('3070018')->is_valid_number, '茨城県結城市若宮西');
ok($zip->set_number('3070021')->is_valid_number, '茨城県結城市上山川');
ok($zip->set_number('3070022')->is_valid_number, '茨城県結城市矢畑');
ok($zip->set_number('3070023')->is_valid_number, '茨城県結城市山王');
ok($zip->set_number('3070024')->is_valid_number, '茨城県結城市水海道');
ok($zip->set_number('3070025')->is_valid_number, '茨城県結城市浜野辺');
ok($zip->set_number('3070026')->is_valid_number, '茨城県結城市芳賀崎');
ok($zip->set_number('3070027')->is_valid_number, '茨城県結城市粕礼');
ok($zip->set_number('3070028')->is_valid_number, '茨城県結城市今宿');
ok($zip->set_number('3070029')->is_valid_number, '茨城県結城市新矢畑');
ok($zip->set_number('3070031')->is_valid_number, '茨城県結城市大木');
ok($zip->set_number('3070032')->is_valid_number, '茨城県結城市古宿新田');
ok($zip->set_number('3070033')->is_valid_number, '茨城県結城市山川新宿');
ok($zip->set_number('3070034')->is_valid_number, '茨城県結城市新宿新田');
ok($zip->set_number('3070035')->is_valid_number, '茨城県結城市善右ヱ門新田');
ok($zip->set_number('3070036')->is_valid_number, '茨城県結城市北南茂呂');
ok($zip->set_number('3070037')->is_valid_number, '茨城県結城市東茂呂');
ok($zip->set_number('3070038')->is_valid_number, '茨城県結城市七五三場');
ok($zip->set_number('3070041')->is_valid_number, '茨城県結城市江川大町');
ok($zip->set_number('3070042')->is_valid_number, '茨城県結城市江川新宿');
ok($zip->set_number('3070043')->is_valid_number, '茨城県結城市武井');
ok($zip->set_number('3070044')->is_valid_number, '茨城県結城市田間');
ok($zip->set_number('3070045')->is_valid_number, '茨城県結城市上成');
ok($zip->set_number('3070046')->is_valid_number, '茨城県結城市結城作');
ok($zip->set_number('3070051')->is_valid_number, '茨城県結城市国府町');
ok($zip->set_number('3070052')->is_valid_number, '茨城県結城市中央町');
ok($zip->set_number('3070053')->is_valid_number, '茨城県結城市新福寺');
ok($zip->set_number('3070054')->is_valid_number, '茨城県結城市城南町');
ok($zip->set_number('3070055')->is_valid_number, '茨城県結城市大橋町');
ok($zip->set_number('3080000')->is_valid_number, '茨城県筑西市以下に掲載がない場合');
ok($zip->set_number('3080001')->is_valid_number, '茨城県筑西市樋口');
ok($zip->set_number('3080002')->is_valid_number, '茨城県筑西市落合');
ok($zip->set_number('3080003')->is_valid_number, '茨城県筑西市蒔田');
ok($zip->set_number('3080004')->is_valid_number, '茨城県筑西市国府田');
ok($zip->set_number('3080005')->is_valid_number, '茨城県筑西市中舘');
ok($zip->set_number('3080006')->is_valid_number, '茨城県筑西市谷部');
ok($zip->set_number('3080007')->is_valid_number, '茨城県筑西市折本');
ok($zip->set_number('3080008')->is_valid_number, '茨城県筑西市八丁台');
ok($zip->set_number('3080011')->is_valid_number, '茨城県筑西市下高田');
ok($zip->set_number('3080012')->is_valid_number, '茨城県筑西市奥田');
ok($zip->set_number('3080013')->is_valid_number, '茨城県筑西市八田');
ok($zip->set_number('3080014')->is_valid_number, '茨城県筑西市羽方');
ok($zip->set_number('3080015')->is_valid_number, '茨城県筑西市大関');
ok($zip->set_number('3080016')->is_valid_number, '茨城県筑西市野');
ok($zip->set_number('3080017')->is_valid_number, '茨城県筑西市上中山');
ok($zip->set_number('3080021')->is_valid_number, '茨城県筑西市甲');
ok($zip->set_number('3080031')->is_valid_number, '茨城県筑西市丙');
ok($zip->set_number('3080041')->is_valid_number, '茨城県筑西市乙');
ok($zip->set_number('3080042')->is_valid_number, '茨城県筑西市みどり町');
ok($zip->set_number('3080051')->is_valid_number, '茨城県筑西市岡芹');
ok($zip->set_number('3080052')->is_valid_number, '茨城県筑西市菅谷');
ok($zip->set_number('3080053')->is_valid_number, '茨城県筑西市外塚');
ok($zip->set_number('3080054')->is_valid_number, '茨城県筑西市西谷貝');
ok($zip->set_number('3080055')->is_valid_number, '茨城県筑西市石原田');
ok($zip->set_number('3080056')->is_valid_number, '茨城県筑西市谷中');
ok($zip->set_number('3080061')->is_valid_number, '茨城県筑西市栗島');
ok($zip->set_number('3080062')->is_valid_number, '茨城県筑西市西大島');
ok($zip->set_number('3080063')->is_valid_number, '茨城県筑西市神分');
ok($zip->set_number('3080064')->is_valid_number, '茨城県筑西市飯島');
ok($zip->set_number('3080065')->is_valid_number, '茨城県筑西市笹塚');
ok($zip->set_number('3080066')->is_valid_number, '茨城県筑西市下平塚');
ok($zip->set_number('3080067')->is_valid_number, '茨城県筑西市上平塚');
ok($zip->set_number('3080071')->is_valid_number, '茨城県筑西市口戸');
ok($zip->set_number('3080072')->is_valid_number, '茨城県筑西市柴山');
ok($zip->set_number('3080073')->is_valid_number, '茨城県筑西市林');
ok($zip->set_number('3080074')->is_valid_number, '茨城県筑西市筑瀬');
ok($zip->set_number('3080075')->is_valid_number, '茨城県筑西市石塔');
ok($zip->set_number('3080076')->is_valid_number, '茨城県筑西市泉');
ok($zip->set_number('3080077')->is_valid_number, '茨城県筑西市子思儀');
ok($zip->set_number('3080101')->is_valid_number, '茨城県筑西市井上');
ok($zip->set_number('3080102')->is_valid_number, '茨城県筑西市黒子');
ok($zip->set_number('3080103')->is_valid_number, '茨城県筑西市辻');
ok($zip->set_number('3080104')->is_valid_number, '茨城県筑西市木戸');
ok($zip->set_number('3080105')->is_valid_number, '茨城県筑西市西保末');
ok($zip->set_number('3080106')->is_valid_number, '茨城県筑西市稲荷');
ok($zip->set_number('3080107')->is_valid_number, '茨城県筑西市梶内');
ok($zip->set_number('3080108')->is_valid_number, '茨城県筑西市中村新田');
ok($zip->set_number('3080111')->is_valid_number, '茨城県筑西市舟生');
ok($zip->set_number('3080112')->is_valid_number, '茨城県筑西市藤ケ谷');
ok($zip->set_number('3080113')->is_valid_number, '茨城県筑西市関舘');
ok($zip->set_number('3080114')->is_valid_number, '茨城県筑西市花田');
ok($zip->set_number('3080115')->is_valid_number, '茨城県筑西市花橋');
ok($zip->set_number('3080116')->is_valid_number, '茨城県筑西市板橋');
ok($zip->set_number('3080117')->is_valid_number, '茨城県筑西市犬塚');
ok($zip->set_number('3080121')->is_valid_number, '茨城県筑西市船玉');
ok($zip->set_number('3080122')->is_valid_number, '茨城県筑西市関本上');
ok($zip->set_number('3080123')->is_valid_number, '茨城県筑西市関本上中');
ok($zip->set_number('3080124')->is_valid_number, '茨城県筑西市関本肥土');
ok($zip->set_number('3080125')->is_valid_number, '茨城県筑西市関本分中');
ok($zip->set_number('3080126')->is_valid_number, '茨城県筑西市関本中');
ok($zip->set_number('3080127')->is_valid_number, '茨城県筑西市関本下');
ok($zip->set_number('3080128')->is_valid_number, '茨城県筑西市江');
ok($zip->set_number('3080129')->is_valid_number, '茨城県筑西市上野');
ok($zip->set_number('3080801')->is_valid_number, '茨城県筑西市川澄');
ok($zip->set_number('3080802')->is_valid_number, '茨城県筑西市横島');
ok($zip->set_number('3080803')->is_valid_number, '茨城県筑西市直井');
ok($zip->set_number('3080804')->is_valid_number, '茨城県筑西市金丸');
ok($zip->set_number('3080805')->is_valid_number, '茨城県筑西市稲野辺');
ok($zip->set_number('3080806')->is_valid_number, '茨城県筑西市小林');
ok($zip->set_number('3080807')->is_valid_number, '茨城県筑西市高島');
ok($zip->set_number('3080811')->is_valid_number, '茨城県筑西市茂田');
ok($zip->set_number('3080812')->is_valid_number, '茨城県筑西市深見');
ok($zip->set_number('3080813')->is_valid_number, '茨城県筑西市大塚');
ok($zip->set_number('3080814')->is_valid_number, '茨城県筑西市川連');
ok($zip->set_number('3080815')->is_valid_number, '茨城県筑西市上川中子');
ok($zip->set_number('3080816')->is_valid_number, '茨城県筑西市徳持');
ok($zip->set_number('3080821')->is_valid_number, '茨城県筑西市成田');
ok($zip->set_number('3080822')->is_valid_number, '茨城県筑西市塚原');
ok($zip->set_number('3080823')->is_valid_number, '茨城県筑西市島');
ok($zip->set_number('3080824')->is_valid_number, '茨城県筑西市蕨');
ok($zip->set_number('3080825')->is_valid_number, '茨城県筑西市下中山');
ok($zip->set_number('3080826')->is_valid_number, '茨城県筑西市下岡崎');
ok($zip->set_number('3080827')->is_valid_number, '茨城県筑西市市野辺');
ok($zip->set_number('3080831')->is_valid_number, '茨城県筑西市東榎生');
ok($zip->set_number('3080832')->is_valid_number, '茨城県筑西市西榎生');
ok($zip->set_number('3080833')->is_valid_number, '茨城県筑西市野田');
ok($zip->set_number('3080834')->is_valid_number, '茨城県筑西市西石田');
ok($zip->set_number('3080835')->is_valid_number, '茨城県筑西市飯田');
ok($zip->set_number('3080836')->is_valid_number, '茨城県筑西市旭ケ丘');
ok($zip->set_number('3080837')->is_valid_number, '茨城県筑西市嘉家佐和');
ok($zip->set_number('3080838')->is_valid_number, '茨城県筑西市榎生');
ok($zip->set_number('3080841')->is_valid_number, '茨城県筑西市二木成');
ok($zip->set_number('3080842')->is_valid_number, '茨城県筑西市一本松');
ok($zip->set_number('3080843')->is_valid_number, '茨城県筑西市野殿');
ok($zip->set_number('3080844')->is_valid_number, '茨城県筑西市下野殿');
ok($zip->set_number('3080845')->is_valid_number, '茨城県筑西市西方');
ok($zip->set_number('3080846')->is_valid_number, '茨城県筑西市布川');
ok($zip->set_number('3080847')->is_valid_number, '茨城県筑西市玉戸');
ok($zip->set_number('3080848')->is_valid_number, '茨城県筑西市幸町');
ok($zip->set_number('3080851')->is_valid_number, '茨城県筑西市下江連');
ok($zip->set_number('3080852')->is_valid_number, '茨城県筑西市大谷');
ok($zip->set_number('3080853')->is_valid_number, '茨城県筑西市伊讃美');
ok($zip->set_number('3080854')->is_valid_number, '茨城県筑西市女方');
ok($zip->set_number('3080855')->is_valid_number, '茨城県筑西市下川島');
ok($zip->set_number('3080856')->is_valid_number, '茨城県筑西市伊佐山');
ok($zip->set_number('3080857')->is_valid_number, '茨城県筑西市小川');
ok($zip->set_number('3080861')->is_valid_number, '茨城県筑西市森添島');
ok($zip->set_number('3080862')->is_valid_number, '茨城県筑西市小塙');
ok($zip->set_number('3080863')->is_valid_number, '茨城県筑西市灰塚');
ok($zip->set_number('3080864')->is_valid_number, '茨城県筑西市掉ケ島');
ok($zip->set_number('3080865')->is_valid_number, '茨城県筑西市山崎');
ok($zip->set_number('3080866')->is_valid_number, '茨城県筑西市五所宮');
ok($zip->set_number('3080867')->is_valid_number, '茨城県筑西市西山田');
ok($zip->set_number('3091101')->is_valid_number, '茨城県筑西市小栗');
ok($zip->set_number('3091102')->is_valid_number, '茨城県筑西市蓬田');
ok($zip->set_number('3091103')->is_valid_number, '茨城県筑西市久地楽');
ok($zip->set_number('3091104')->is_valid_number, '茨城県筑西市古郡');
ok($zip->set_number('3091105')->is_valid_number, '茨城県筑西市三郷');
ok($zip->set_number('3091106')->is_valid_number, '茨城県筑西市新治');
ok($zip->set_number('3091107')->is_valid_number, '茨城県筑西市門井');
ok($zip->set_number('3091108')->is_valid_number, '茨城県筑西市井出蛯沢');
ok($zip->set_number('3091111')->is_valid_number, '茨城県筑西市上星谷');
ok($zip->set_number('3091112')->is_valid_number, '茨城県筑西市八幡');
ok($zip->set_number('3091113')->is_valid_number, '茨城県筑西市柳');
ok($zip->set_number('3091114')->is_valid_number, '茨城県筑西市細田');
ok($zip->set_number('3091115')->is_valid_number, '茨城県筑西市蓮沼');
ok($zip->set_number('3091116')->is_valid_number, '茨城県筑西市横塚');
ok($zip->set_number('3091117')->is_valid_number, '茨城県筑西市向川澄');
ok($zip->set_number('3091121')->is_valid_number, '茨城県筑西市谷永島');
ok($zip->set_number('3091122')->is_valid_number, '茨城県筑西市下星谷');
ok($zip->set_number('3091123')->is_valid_number, '茨城県筑西市下郷谷');
ok($zip->set_number('3091124')->is_valid_number, '茨城県筑西市知行');
ok($zip->set_number('3091125')->is_valid_number, '茨城県筑西市大島');
ok($zip->set_number('3091126')->is_valid_number, '茨城県筑西市清水');
ok($zip->set_number('3091127')->is_valid_number, '茨城県筑西市桑山');
ok($zip->set_number('3091200')->is_valid_number, '茨城県桜川市以下に掲載がない場合');
ok($zip->set_number('3091201')->is_valid_number, '茨城県桜川市大泉');
ok($zip->set_number('3091202')->is_valid_number, '茨城県桜川市飯淵');
ok($zip->set_number('3091203')->is_valid_number, '茨城県桜川市富岡');
ok($zip->set_number('3091204')->is_valid_number, '茨城県桜川市久原');
ok($zip->set_number('3091205')->is_valid_number, '茨城県桜川市堤上');
ok($zip->set_number('3091211')->is_valid_number, '茨城県桜川市岩瀬');
ok($zip->set_number('3091212')->is_valid_number, '茨城県桜川市富士見台');
ok($zip->set_number('3091213')->is_valid_number, '茨城県桜川市西桜川');
ok($zip->set_number('3091214')->is_valid_number, '茨城県桜川市東桜川');
ok($zip->set_number('3091215')->is_valid_number, '茨城県桜川市御領');
ok($zip->set_number('3091216')->is_valid_number, '茨城県桜川市明日香');
ok($zip->set_number('3091217')->is_valid_number, '茨城県桜川市犬田');
ok($zip->set_number('3091221')->is_valid_number, '茨城県桜川市西飯岡');
ok($zip->set_number('3091222')->is_valid_number, '茨城県桜川市長方');
ok($zip->set_number('3091223')->is_valid_number, '茨城県桜川市鍬田');
ok($zip->set_number('3091224')->is_valid_number, '茨城県桜川市中泉');
ok($zip->set_number('3091225')->is_valid_number, '茨城県桜川市下泉');
ok($zip->set_number('3091226')->is_valid_number, '茨城県桜川市上野原地新田');
ok($zip->set_number('3091227')->is_valid_number, '茨城県桜川市本郷');
ok($zip->set_number('3091231')->is_valid_number, '茨城県桜川市本木');
ok($zip->set_number('3091232')->is_valid_number, '茨城県桜川市大曽根');
ok($zip->set_number('3091233')->is_valid_number, '茨城県桜川市東飯田');
ok($zip->set_number('3091234')->is_valid_number, '茨城県桜川市阿部田');
ok($zip->set_number('3091241')->is_valid_number, '茨城県桜川市青木');
ok($zip->set_number('3091242')->is_valid_number, '茨城県桜川市羽田');
ok($zip->set_number('3091243')->is_valid_number, '茨城県桜川市高久');
ok($zip->set_number('3091244')->is_valid_number, '茨城県桜川市大国玉');
ok($zip->set_number('3091245')->is_valid_number, '茨城県桜川市金敷');
ok($zip->set_number('3091246')->is_valid_number, '茨城県桜川市高森');
ok($zip->set_number('3091331')->is_valid_number, '茨城県桜川市平澤');
ok($zip->set_number('3091332')->is_valid_number, '茨城県桜川市池亀');
ok($zip->set_number('3091333')->is_valid_number, '茨城県桜川市山口');
ok($zip->set_number('3091334')->is_valid_number, '茨城県桜川市坂本');
ok($zip->set_number('3091335')->is_valid_number, '茨城県桜川市大月');
ok($zip->set_number('3091336')->is_valid_number, '茨城県桜川市小塩');
ok($zip->set_number('3091337')->is_valid_number, '茨城県桜川市福崎');
ok($zip->set_number('3091341')->is_valid_number, '茨城県桜川市門毛');
ok($zip->set_number('3091342')->is_valid_number, '茨城県桜川市間中');
ok($zip->set_number('3091343')->is_valid_number, '茨城県桜川市亀岡');
ok($zip->set_number('3091344')->is_valid_number, '茨城県桜川市南飯田');
ok($zip->set_number('3091345')->is_valid_number, '茨城県桜川市入野');
ok($zip->set_number('3091346')->is_valid_number, '茨城県桜川市中里');
ok($zip->set_number('3091347')->is_valid_number, '茨城県桜川市富谷');
ok($zip->set_number('3091451')->is_valid_number, '茨城県桜川市西小塙');
ok($zip->set_number('3091452')->is_valid_number, '茨城県桜川市加茂部');
ok($zip->set_number('3091453')->is_valid_number, '茨城県桜川市友部');
ok($zip->set_number('3091454')->is_valid_number, '茨城県桜川市上城');
ok($zip->set_number('3091455')->is_valid_number, '茨城県桜川市水戸');
ok($zip->set_number('3091456')->is_valid_number, '茨城県桜川市青柳');
ok($zip->set_number('3091457')->is_valid_number, '茨城県桜川市磯部');
ok($zip->set_number('3091458')->is_valid_number, '茨城県桜川市稲');
ok($zip->set_number('3091461')->is_valid_number, '茨城県桜川市松田');
ok($zip->set_number('3091462')->is_valid_number, '茨城県桜川市曽根');
ok($zip->set_number('3091463')->is_valid_number, '茨城県桜川市高幡');
ok($zip->set_number('3091464')->is_valid_number, '茨城県桜川市今泉');
ok($zip->set_number('3091465')->is_valid_number, '茨城県桜川市木植');
ok($zip->set_number('3091466')->is_valid_number, '茨城県桜川市猿田');
ok($zip->set_number('3091600')->is_valid_number, '茨城県笠間市以下に掲載がない場合');
ok($zip->set_number('3091601')->is_valid_number, '茨城県笠間市大橋');
ok($zip->set_number('3091602')->is_valid_number, '茨城県笠間市池野辺');
ok($zip->set_number('3091603')->is_valid_number, '茨城県笠間市福田');
ok($zip->set_number('3091604')->is_valid_number, '茨城県笠間市大渕');
ok($zip->set_number('3091605')->is_valid_number, '茨城県笠間市飯田');
ok($zip->set_number('3091606')->is_valid_number, '茨城県笠間市日沢');
ok($zip->set_number('3091607')->is_valid_number, '茨城県笠間市石寺');
ok($zip->set_number('3091611')->is_valid_number, '茨城県笠間市笠間');
ok($zip->set_number('3091612')->is_valid_number, '茨城県笠間市日草場');
ok($zip->set_number('3091613')->is_valid_number, '茨城県笠間市石井');
ok($zip->set_number('3091614')->is_valid_number, '茨城県笠間市寺崎');
ok($zip->set_number('3091615')->is_valid_number, '茨城県笠間市金井');
ok($zip->set_number('3091616')->is_valid_number, '茨城県笠間市赤坂');
ok($zip->set_number('3091621')->is_valid_number, '茨城県笠間市手越');
ok($zip->set_number('3091622')->is_valid_number, '茨城県笠間市南吉原');
ok($zip->set_number('3091623')->is_valid_number, '茨城県笠間市上加賀田');
ok($zip->set_number('3091624')->is_valid_number, '茨城県笠間市北吉原');
ok($zip->set_number('3091625')->is_valid_number, '茨城県笠間市来栖');
ok($zip->set_number('3091626')->is_valid_number, '茨城県笠間市下市毛');
ok($zip->set_number('3091631')->is_valid_number, '茨城県笠間市箱田');
ok($zip->set_number('3091632')->is_valid_number, '茨城県笠間市飯合');
ok($zip->set_number('3091633')->is_valid_number, '茨城県笠間市本戸');
ok($zip->set_number('3091634')->is_valid_number, '茨城県笠間市福原');
ok($zip->set_number('3091635')->is_valid_number, '茨城県笠間市稲田');
ok($zip->set_number('3091636')->is_valid_number, '茨城県笠間市大郷戸');
ok($zip->set_number('3091637')->is_valid_number, '茨城県笠間市片庭');
ok($zip->set_number('3091701')->is_valid_number, '茨城県笠間市小原');
ok($zip->set_number('3091702')->is_valid_number, '茨城県笠間市五平');
ok($zip->set_number('3091703')->is_valid_number, '茨城県笠間市鯉淵');
ok($zip->set_number('3091704')->is_valid_number, '茨城県笠間市美原');
ok($zip->set_number('3091705')->is_valid_number, '茨城県笠間市東平');
ok($zip->set_number('3091706')->is_valid_number, '茨城県笠間市鴻巣');
ok($zip->set_number('3091711')->is_valid_number, '茨城県笠間市随分附');
ok($zip->set_number('3091712')->is_valid_number, '茨城県笠間市長兎路');
ok($zip->set_number('3091713')->is_valid_number, '茨城県笠間市柏井');
ok($zip->set_number('3091714')->is_valid_number, '茨城県笠間市仁古田');
ok($zip->set_number('3091715')->is_valid_number, '茨城県笠間市湯崎');
ok($zip->set_number('3091716')->is_valid_number, '茨城県笠間市住吉');
ok($zip->set_number('3091717')->is_valid_number, '茨城県笠間市旭町');
ok($zip->set_number('3091721')->is_valid_number, '茨城県笠間市橋爪');
ok($zip->set_number('3091722')->is_valid_number, '茨城県笠間市平町');
ok($zip->set_number('3091723')->is_valid_number, '茨城県笠間市矢野下');
ok($zip->set_number('3091724')->is_valid_number, '茨城県笠間市大古山');
ok($zip->set_number('3091725')->is_valid_number, '茨城県笠間市南小泉');
ok($zip->set_number('3091726')->is_valid_number, '茨城県笠間市下加賀田');
ok($zip->set_number('3091731')->is_valid_number, '茨城県笠間市上市原');
ok($zip->set_number('3091732')->is_valid_number, '茨城県笠間市中市原');
ok($zip->set_number('3091733')->is_valid_number, '茨城県笠間市下市原');
ok($zip->set_number('3091734')->is_valid_number, '茨城県笠間市南友部');
ok($zip->set_number('3091735')->is_valid_number, '茨城県笠間市友部駅前');
ok($zip->set_number('3091736')->is_valid_number, '茨城県笠間市八雲');
ok($zip->set_number('3091737')->is_valid_number, '茨城県笠間市中央');
ok($zip->set_number('3091738')->is_valid_number, '茨城県笠間市大田町');
ok($zip->set_number('3100000')->is_valid_number, '茨城県水戸市以下に掲載がない場合');
ok($zip->set_number('3100001')->is_valid_number, '茨城県水戸市上河内町');
ok($zip->set_number('3100002')->is_valid_number, '茨城県水戸市中河内町');
ok($zip->set_number('3100003')->is_valid_number, '茨城県水戸市柳河町');
ok($zip->set_number('3100004')->is_valid_number, '茨城県水戸市青柳町');
ok($zip->set_number('3100005')->is_valid_number, '茨城県水戸市水府町');
ok($zip->set_number('3100011')->is_valid_number, '茨城県水戸市三の丸');
ok($zip->set_number('3100012')->is_valid_number, '茨城県水戸市城東');
ok($zip->set_number('3100013')->is_valid_number, '茨城県水戸市若宮');
ok($zip->set_number('3100014')->is_valid_number, '茨城県水戸市若宮町');
ok($zip->set_number('3100015')->is_valid_number, '茨城県水戸市宮町');
ok($zip->set_number('3100021')->is_valid_number, '茨城県水戸市南町');
ok($zip->set_number('3100022')->is_valid_number, '茨城県水戸市梅香');
ok($zip->set_number('3100023')->is_valid_number, '茨城県水戸市下梅香');
ok($zip->set_number('3100024')->is_valid_number, '茨城県水戸市備前町');
ok($zip->set_number('3100025')->is_valid_number, '茨城県水戸市天王町');
ok($zip->set_number('3100026')->is_valid_number, '茨城県水戸市泉町');
ok($zip->set_number('3100031')->is_valid_number, '茨城県水戸市大工町');
ok($zip->set_number('3100032')->is_valid_number, '茨城県水戸市元山町');
ok($zip->set_number('3100033')->is_valid_number, '茨城県水戸市常磐町');
ok($zip->set_number('3100034')->is_valid_number, '茨城県水戸市緑町');
ok($zip->set_number('3100035')->is_valid_number, '茨城県水戸市東原');
ok($zip->set_number('3100036')->is_valid_number, '茨城県水戸市新荘');
ok($zip->set_number('3100041')->is_valid_number, '茨城県水戸市上水戸');
ok($zip->set_number('3100042')->is_valid_number, '茨城県水戸市自由が丘');
ok($zip->set_number('3100043')->is_valid_number, '茨城県水戸市松が丘');
ok($zip->set_number('3100044')->is_valid_number, '茨城県水戸市西原');
ok($zip->set_number('3100045')->is_valid_number, '茨城県水戸市新原');
ok($zip->set_number('3100046')->is_valid_number, '茨城県水戸市曙町');
ok($zip->set_number('3100051')->is_valid_number, '茨城県水戸市ちとせ');
ok($zip->set_number('3100052')->is_valid_number, '茨城県水戸市松本町');
ok($zip->set_number('3100053')->is_valid_number, '茨城県水戸市末広町');
ok($zip->set_number('3100054')->is_valid_number, '茨城県水戸市愛宕町');
ok($zip->set_number('3100055')->is_valid_number, '茨城県水戸市袴塚');
ok($zip->set_number('3100056')->is_valid_number, '茨城県水戸市文京');
ok($zip->set_number('3100061')->is_valid_number, '茨城県水戸市北見町');
ok($zip->set_number('3100062')->is_valid_number, '茨城県水戸市大町');
ok($zip->set_number('3100063')->is_valid_number, '茨城県水戸市五軒町');
ok($zip->set_number('3100064')->is_valid_number, '茨城県水戸市栄町');
ok($zip->set_number('3100065')->is_valid_number, '茨城県水戸市八幡町');
ok($zip->set_number('3100066')->is_valid_number, '茨城県水戸市金町');
ok($zip->set_number('3100067')->is_valid_number, '茨城県水戸市根本');
ok($zip->set_number('3100068')->is_valid_number, '茨城県水戸市根本町');
ok($zip->set_number('3100801')->is_valid_number, '茨城県水戸市桜川');
ok($zip->set_number('3100802')->is_valid_number, '茨城県水戸市柵町');
ok($zip->set_number('3100803')->is_valid_number, '茨城県水戸市城南');
ok($zip->set_number('3100804')->is_valid_number, '茨城県水戸市白梅');
ok($zip->set_number('3100805')->is_valid_number, '茨城県水戸市中央');
ok($zip->set_number('3100811')->is_valid_number, '茨城県水戸市東桜川');
ok($zip->set_number('3100812')->is_valid_number, '茨城県水戸市浜田');
ok($zip->set_number('3100813')->is_valid_number, '茨城県水戸市浜田町');
ok($zip->set_number('3100814')->is_valid_number, '茨城県水戸市瓦谷');
ok($zip->set_number('3100815')->is_valid_number, '茨城県水戸市本町');
ok($zip->set_number('3100816')->is_valid_number, '茨城県水戸市紺屋町');
ok($zip->set_number('3100817')->is_valid_number, '茨城県水戸市柳町');
ok($zip->set_number('3100818')->is_valid_number, '茨城県水戸市東台');
ok($zip->set_number('3100821')->is_valid_number, '茨城県水戸市中大野');
ok($zip->set_number('3100822')->is_valid_number, '茨城県水戸市圷大野');
ok($zip->set_number('3100823')->is_valid_number, '茨城県水戸市東大野');
ok($zip->set_number('3100824')->is_valid_number, '茨城県水戸市西大野');
ok($zip->set_number('3100825')->is_valid_number, '茨城県水戸市谷田町');
ok($zip->set_number('3100826')->is_valid_number, '茨城県水戸市渋井町');
ok($zip->set_number('3100827')->is_valid_number, '茨城県水戸市吉沼町');
ok($zip->set_number('3100831')->is_valid_number, '茨城県水戸市朝日町');
ok($zip->set_number('3100832')->is_valid_number, '茨城県水戸市吉田');
ok($zip->set_number('3100833')->is_valid_number, '茨城県水戸市藤柄町');
ok($zip->set_number('3100834')->is_valid_number, '茨城県水戸市宮内町');
ok($zip->set_number('3100835')->is_valid_number, '茨城県水戸市元台町');
ok($zip->set_number('3100836')->is_valid_number, '茨城県水戸市元吉田町');
ok($zip->set_number('3100841')->is_valid_number, '茨城県水戸市酒門町');
ok($zip->set_number('3100842')->is_valid_number, '茨城県水戸市けやき台');
ok($zip->set_number('3100843')->is_valid_number, '茨城県水戸市元石川町');
ok($zip->set_number('3100844')->is_valid_number, '茨城県水戸市住吉町');
ok($zip->set_number('3100845')->is_valid_number, '茨城県水戸市吉沢町');
ok($zip->set_number('3100846')->is_valid_number, '茨城県水戸市東野町');
ok($zip->set_number('3100847')->is_valid_number, '茨城県水戸市米沢町');
ok($zip->set_number('3100851')->is_valid_number, '茨城県水戸市千波町');
ok($zip->set_number('3100852')->is_valid_number, '茨城県水戸市笠原町');
ok($zip->set_number('3100853')->is_valid_number, '茨城県水戸市平須町');
ok($zip->set_number('3100901')->is_valid_number, '茨城県水戸市田野町');
ok($zip->set_number('3100902')->is_valid_number, '茨城県水戸市渡里町');
ok($zip->set_number('3100903')->is_valid_number, '茨城県水戸市堀町');
ok($zip->set_number('3100904')->is_valid_number, '茨城県水戸市石川町');
ok($zip->set_number('3100905')->is_valid_number, '茨城県水戸市石川');
ok($zip->set_number('3100911')->is_valid_number, '茨城県水戸市見和');
ok($zip->set_number('3100912')->is_valid_number, '茨城県水戸市見川');
ok($zip->set_number('3100913')->is_valid_number, '茨城県水戸市見川町');
ok($zip->set_number('3100914')->is_valid_number, '茨城県水戸市小吹町');
ok($zip->set_number('3110100')->is_valid_number, '茨城県那珂市以下に掲載がない場合');
ok($zip->set_number('3110101')->is_valid_number, '茨城県那珂市本米崎');
ok($zip->set_number('3110102')->is_valid_number, '茨城県那珂市向山');
ok($zip->set_number('3110103')->is_valid_number, '茨城県那珂市横堀');
ok($zip->set_number('3110104')->is_valid_number, '茨城県那珂市堤');
ok($zip->set_number('3110105')->is_valid_number, '茨城県那珂市菅谷');
ok($zip->set_number('3110106')->is_valid_number, '茨城県那珂市杉');
ok($zip->set_number('3110107')->is_valid_number, '茨城県那珂市額田南郷');
ok($zip->set_number('3110108')->is_valid_number, '茨城県那珂市額田北郷');
ok($zip->set_number('3110109')->is_valid_number, '茨城県那珂市額田東郷');
ok($zip->set_number('3110110')->is_valid_number, '茨城県那珂市竹ノ内');
ok($zip->set_number('3110111')->is_valid_number, '茨城県那珂市後台');
ok($zip->set_number('3110112')->is_valid_number, '茨城県那珂市津田');
ok($zip->set_number('3110113')->is_valid_number, '茨城県那珂市中台');
ok($zip->set_number('3110114')->is_valid_number, '茨城県那珂市東木倉');
ok($zip->set_number('3110115')->is_valid_number, '茨城県那珂市西木倉');
ok($zip->set_number('3110116')->is_valid_number, '茨城県那珂市上河内');
ok($zip->set_number('3110117')->is_valid_number, '茨城県那珂市豊喰');
ok($zip->set_number('3110118')->is_valid_number, '茨城県那珂市福田');
ok($zip->set_number('3110121')->is_valid_number, '茨城県那珂市戸崎');
ok($zip->set_number('3110122')->is_valid_number, '茨城県那珂市戸');
ok($zip->set_number('3110123')->is_valid_number, '茨城県那珂市上国井');
ok($zip->set_number('3110124')->is_valid_number, '茨城県那珂市田崎');
ok($zip->set_number('3110125')->is_valid_number, '茨城県那珂市大内');
ok($zip->set_number('3110126')->is_valid_number, '茨城県那珂市下江戸');
ok($zip->set_number('3110131')->is_valid_number, '茨城県那珂市北酒出');
ok($zip->set_number('3110132')->is_valid_number, '茨城県那珂市南酒出');
ok($zip->set_number('3110133')->is_valid_number, '茨城県那珂市鴻巣');
ok($zip->set_number('3110134')->is_valid_number, '茨城県那珂市飯田');
ok($zip->set_number('3110135')->is_valid_number, '茨城県那珂市鹿島');
ok($zip->set_number('3110136')->is_valid_number, '茨城県那珂市門部');
ok($zip->set_number('3110301')->is_valid_number, '茨城県常陸太田市河内西町');
ok($zip->set_number('3110311')->is_valid_number, '茨城県常陸太田市町屋町');
ok($zip->set_number('3110312')->is_valid_number, '茨城県常陸太田市西河内下町');
ok($zip->set_number('3110313')->is_valid_number, '茨城県常陸太田市西河内中町');
ok($zip->set_number('3110314')->is_valid_number, '茨城県常陸太田市西河内上町');
ok($zip->set_number('3110321')->is_valid_number, '茨城県常陸太田市春友町');
ok($zip->set_number('3110322')->is_valid_number, '茨城県常陸太田市常福地町');
ok($zip->set_number('3110323')->is_valid_number, '茨城県常陸太田市茅根町');
ok($zip->set_number('3110324')->is_valid_number, '茨城県常陸太田市白羽町');
ok($zip->set_number('3110325')->is_valid_number, '茨城県常陸太田市里野宮町');
ok($zip->set_number('3110401')->is_valid_number, '茨城県日立市中深荻町');
ok($zip->set_number('3110402')->is_valid_number, '茨城県日立市入四間町');
ok($zip->set_number('3110403')->is_valid_number, '茨城県日立市東河内町');
ok($zip->set_number('3110404')->is_valid_number, '茨城県日立市下深荻町');
ok($zip->set_number('3110501')->is_valid_number, '茨城県常陸太田市里川町');
ok($zip->set_number('3110502')->is_valid_number, '茨城県常陸太田市徳田町');
ok($zip->set_number('3110503')->is_valid_number, '茨城県常陸太田市小妻町');
ok($zip->set_number('3110504')->is_valid_number, '茨城県常陸太田市小中町');
ok($zip->set_number('3110505')->is_valid_number, '茨城県常陸太田市大中町');
ok($zip->set_number('3110506')->is_valid_number, '茨城県常陸太田市折橋町');
ok($zip->set_number('3110507')->is_valid_number, '茨城県常陸太田市小菅町');
ok($zip->set_number('3110508')->is_valid_number, '茨城県常陸太田市大菅町');
ok($zip->set_number('3110509')->is_valid_number, '茨城県常陸太田市上深荻町');
ok($zip->set_number('3111111')->is_valid_number, '茨城県水戸市小泉町');
ok($zip->set_number('3111112')->is_valid_number, '茨城県水戸市川又町');
ok($zip->set_number('3111113')->is_valid_number, '茨城県水戸市平戸町');
ok($zip->set_number('3111114')->is_valid_number, '茨城県水戸市塩崎町');
ok($zip->set_number('3111115')->is_valid_number, '茨城県水戸市大串町');
ok($zip->set_number('3111121')->is_valid_number, '茨城県水戸市島田町');
ok($zip->set_number('3111122')->is_valid_number, '茨城県水戸市秋成町');
ok($zip->set_number('3111123')->is_valid_number, '茨城県水戸市下入野町');
ok($zip->set_number('3111124')->is_valid_number, '茨城県水戸市森戸町');
ok($zip->set_number('3111125')->is_valid_number, '茨城県水戸市大場町');
ok($zip->set_number('3111131')->is_valid_number, '茨城県水戸市下大野町');
ok($zip->set_number('3111132')->is_valid_number, '茨城県水戸市東前町');
ok($zip->set_number('3111133')->is_valid_number, '茨城県水戸市栗崎町');
ok($zip->set_number('3111134')->is_valid_number, '茨城県水戸市百合が丘町');
ok($zip->set_number('3111135')->is_valid_number, '茨城県水戸市六反田町');
ok($zip->set_number('3111136')->is_valid_number, '茨城県水戸市東前');
ok($zip->set_number('3111201')->is_valid_number, '茨城県ひたちなか市阿字ケ浦町');
ok($zip->set_number('3111202')->is_valid_number, '茨城県ひたちなか市磯崎町');
ok($zip->set_number('3111203')->is_valid_number, '茨城県ひたちなか市平磯町');
ok($zip->set_number('3111204')->is_valid_number, '茨城県ひたちなか市平磯遠原町');
ok($zip->set_number('3111205')->is_valid_number, '茨城県ひたちなか市十三奉行');
ok($zip->set_number('3111206')->is_valid_number, '茨城県ひたちなか市西十三奉行');
ok($zip->set_number('3111207')->is_valid_number, '茨城県ひたちなか市烏ケ台');
ok($zip->set_number('3111211')->is_valid_number, '茨城県ひたちなか市沢メキ');
ok($zip->set_number('3111212')->is_valid_number, '茨城県ひたちなか市殿山町');
ok($zip->set_number('3111213')->is_valid_number, '茨城県ひたちなか市牛久保');
ok($zip->set_number('3111214')->is_valid_number, '茨城県ひたちなか市和田町');
ok($zip->set_number('3111215')->is_valid_number, '茨城県ひたちなか市東本町');
ok($zip->set_number('3111216')->is_valid_number, '茨城県ひたちなか市湊泉町');
ok($zip->set_number('3111217')->is_valid_number, '茨城県ひたちなか市富士ノ下');
ok($zip->set_number('3111218')->is_valid_number, '茨城県ひたちなか市富士ノ上');
ok($zip->set_number('3111221')->is_valid_number, '茨城県ひたちなか市湊本町');
ok($zip->set_number('3111222')->is_valid_number, '茨城県ひたちなか市海門町');
ok($zip->set_number('3111223')->is_valid_number, '茨城県ひたちなか市栄町');
ok($zip->set_number('3111224')->is_valid_number, '茨城県ひたちなか市山ノ上町');
ok($zip->set_number('3111225')->is_valid_number, '茨城県ひたちなか市釈迦町');
ok($zip->set_number('3111226')->is_valid_number, '茨城県ひたちなか市幸町');
ok($zip->set_number('3111227')->is_valid_number, '茨城県ひたちなか市洞下町');
ok($zip->set_number('3111228')->is_valid_number, '茨城県ひたちなか市八幡町');
ok($zip->set_number('3111229')->is_valid_number, '茨城県ひたちなか市湊中央');
ok($zip->set_number('3111231')->is_valid_number, '茨城県ひたちなか市柳沢');
ok($zip->set_number('3111232')->is_valid_number, '茨城県ひたちなか市柳が丘');
ok($zip->set_number('3111233')->is_valid_number, '茨城県ひたちなか市堀川');
ok($zip->set_number('3111234')->is_valid_number, '茨城県ひたちなか市峰後');
ok($zip->set_number('3111235')->is_valid_number, '茨城県ひたちなか市田中後');
ok($zip->set_number('3111236')->is_valid_number, '茨城県ひたちなか市国神前');
ok($zip->set_number('3111237')->is_valid_number, '茨城県ひたちなか市関戸');
ok($zip->set_number('3111238')->is_valid_number, '茨城県ひたちなか市美田多町');
ok($zip->set_number('3111241')->is_valid_number, '茨城県ひたちなか市赤坂');
ok($zip->set_number('3111242')->is_valid_number, '茨城県ひたちなか市西赤坂');
ok($zip->set_number('3111243')->is_valid_number, '茨城県ひたちなか市北神敷台');
ok($zip->set_number('3111244')->is_valid_number, '茨城県ひたちなか市南神敷台');
ok($zip->set_number('3111245')->is_valid_number, '茨城県ひたちなか市館山');
ok($zip->set_number('3111246')->is_valid_number, '茨城県ひたちなか市相金町');
ok($zip->set_number('3111247')->is_valid_number, '茨城県ひたちなか市四十発句');
ok($zip->set_number('3111248')->is_valid_number, '茨城県ひたちなか市田宮原');
ok($zip->set_number('3111251')->is_valid_number, '茨城県ひたちなか市山崎');
ok($zip->set_number('3111252')->is_valid_number, '茨城県ひたちなか市部田野');
ok($zip->set_number('3111253')->is_valid_number, '茨城県ひたちなか市小谷金');
ok($zip->set_number('3111254')->is_valid_number, '茨城県ひたちなか市新堤');
ok($zip->set_number('3111255')->is_valid_number, '茨城県ひたちなか市雨沢谷津');
ok($zip->set_number('3111261')->is_valid_number, '茨城県ひたちなか市鶴代');
ok($zip->set_number('3111262')->is_valid_number, '茨城県ひたちなか市道メキ');
ok($zip->set_number('3111263')->is_valid_number, '茨城県ひたちなか市和尚塚');
ok($zip->set_number('3111264')->is_valid_number, '茨城県ひたちなか市浅井内');
ok($zip->set_number('3111265')->is_valid_number, '茨城県ひたちなか市狢谷津');
ok($zip->set_number('3111266')->is_valid_number, '茨城県ひたちなか市船窪');
ok($zip->set_number('3111267')->is_valid_number, '茨城県ひたちなか市廻り目');
ok($zip->set_number('3111268')->is_valid_number, '茨城県ひたちなか市湊中原');
ok($zip->set_number('3111300')->is_valid_number, '茨城県東茨城郡大洗町以下に掲載がない場合');
ok($zip->set_number('3111301')->is_valid_number, '茨城県東茨城郡大洗町磯浜町');
ok($zip->set_number('3111302')->is_valid_number, '茨城県東茨城郡大洗町磯道');
ok($zip->set_number('3111303')->is_valid_number, '茨城県東茨城郡大洗町東光台');
ok($zip->set_number('3111304')->is_valid_number, '茨城県東茨城郡大洗町和銅');
ok($zip->set_number('3111305')->is_valid_number, '茨城県東茨城郡大洗町港中央');
ok($zip->set_number('3111306')->is_valid_number, '茨城県東茨城郡大洗町五反田');
ok($zip->set_number('3111307')->is_valid_number, '茨城県東茨城郡大洗町桜道');
ok($zip->set_number('3111311')->is_valid_number, '茨城県東茨城郡大洗町大貫町');
ok($zip->set_number('3111312')->is_valid_number, '茨城県東茨城郡大洗町神山町');
ok($zip->set_number('3111313')->is_valid_number, '茨城県東茨城郡大洗町成田町');
ok($zip->set_number('3111401')->is_valid_number, '茨城県鉾田市箕輪');
ok($zip->set_number('3111402')->is_valid_number, '茨城県鉾田市下太田');
ok($zip->set_number('3111403')->is_valid_number, '茨城県鉾田市上釜');
ok($zip->set_number('3111404')->is_valid_number, '茨城県鉾田市沢尻');
ok($zip->set_number('3111405')->is_valid_number, '茨城県鉾田市上太田');
ok($zip->set_number('3111406')->is_valid_number, '茨城県鉾田市田崎');
ok($zip->set_number('3111411')->is_valid_number, '茨城県鉾田市荒地');
ok($zip->set_number('3111412')->is_valid_number, '茨城県鉾田市玉田');
ok($zip->set_number('3111413')->is_valid_number, '茨城県鉾田市冷水');
ok($zip->set_number('3111414')->is_valid_number, '茨城県鉾田市子生');
ok($zip->set_number('3111415')->is_valid_number, '茨城県鉾田市造谷');
ok($zip->set_number('3111416')->is_valid_number, '茨城県鉾田市鹿田');
ok($zip->set_number('3111421')->is_valid_number, '茨城県鉾田市勝下新田');
ok($zip->set_number('3111422')->is_valid_number, '茨城県鉾田市勝下');
ok($zip->set_number('3111423')->is_valid_number, '茨城県鉾田市滝浜');
ok($zip->set_number('3111424')->is_valid_number, '茨城県鉾田市柏熊新田');
ok($zip->set_number('3111425')->is_valid_number, '茨城県鉾田市湯坪');
ok($zip->set_number('3111426')->is_valid_number, '茨城県鉾田市樅山');
ok($zip->set_number('3111427')->is_valid_number, '茨城県鉾田市常磐');
ok($zip->set_number('3111500')->is_valid_number, '茨城県鉾田市以下に掲載がない場合');
ok($zip->set_number('3111501')->is_valid_number, '茨城県鉾田市舟木');
ok($zip->set_number('3111502')->is_valid_number, '茨城県鉾田市大戸');
ok($zip->set_number('3111503')->is_valid_number, '茨城県鉾田市徳宿');
ok($zip->set_number('3111504')->is_valid_number, '茨城県鉾田市安房');
ok($zip->set_number('3111505')->is_valid_number, '茨城県鉾田市駒木根');
ok($zip->set_number('3111506')->is_valid_number, '茨城県鉾田市秋山');
ok($zip->set_number('3111511')->is_valid_number, '茨城県鉾田市柏熊');
ok($zip->set_number('3111512')->is_valid_number, '茨城県鉾田市白塚');
ok($zip->set_number('3111513')->is_valid_number, '茨城県鉾田市大竹');
ok($zip->set_number('3111514')->is_valid_number, '茨城県鉾田市安塚');
ok($zip->set_number('3111515')->is_valid_number, '茨城県鉾田市烟田');
ok($zip->set_number('3111516')->is_valid_number, '茨城県鉾田市新鉾田');
ok($zip->set_number('3111517')->is_valid_number, '茨城県鉾田市鉾田');
ok($zip->set_number('3111518')->is_valid_number, '茨城県鉾田市新鉾田西');
ok($zip->set_number('3111521')->is_valid_number, '茨城県鉾田市飯名');
ok($zip->set_number('3111522')->is_valid_number, '茨城県鉾田市塔ケ崎');
ok($zip->set_number('3111523')->is_valid_number, '茨城県鉾田市串挽');
ok($zip->set_number('3111524')->is_valid_number, '茨城県鉾田市高田');
ok($zip->set_number('3111525')->is_valid_number, '茨城県鉾田市野友');
ok($zip->set_number('3111526')->is_valid_number, '茨城県鉾田市半原');
ok($zip->set_number('3111527')->is_valid_number, '茨城県鉾田市借宿');
ok($zip->set_number('3111528')->is_valid_number, '茨城県鉾田市当間');
ok($zip->set_number('3111531')->is_valid_number, '茨城県鉾田市菅野谷');
ok($zip->set_number('3111532')->is_valid_number, '茨城県鉾田市上冨田');
ok($zip->set_number('3111533')->is_valid_number, '茨城県鉾田市下冨田');
ok($zip->set_number('3111534')->is_valid_number, '茨城県鉾田市鳥栖');
ok($zip->set_number('3111535')->is_valid_number, '茨城県鉾田市青柳');
ok($zip->set_number('3111536')->is_valid_number, '茨城県鉾田市大和田');
ok($zip->set_number('3111537')->is_valid_number, '茨城県鉾田市紅葉');
ok($zip->set_number('3111701')->is_valid_number, '茨城県行方市長野江');
ok($zip->set_number('3111702')->is_valid_number, '茨城県行方市三和');
ok($zip->set_number('3111703')->is_valid_number, '茨城県行方市成田');
ok($zip->set_number('3111704')->is_valid_number, '茨城県行方市山田');
ok($zip->set_number('3111705')->is_valid_number, '茨城県行方市内宿');
ok($zip->set_number('3111711')->is_valid_number, '茨城県行方市吉川');
ok($zip->set_number('3111712')->is_valid_number, '茨城県行方市繁昌');
ok($zip->set_number('3111713')->is_valid_number, '茨城県行方市中根');
ok($zip->set_number('3111714')->is_valid_number, '茨城県行方市南高岡');
ok($zip->set_number('3111715')->is_valid_number, '茨城県行方市小幡');
ok($zip->set_number('3111716')->is_valid_number, '茨城県行方市北高岡');
ok($zip->set_number('3111721')->is_valid_number, '茨城県行方市両宿');
ok($zip->set_number('3111722')->is_valid_number, '茨城県行方市次木');
ok($zip->set_number('3111723')->is_valid_number, '茨城県行方市行戸');
ok($zip->set_number('3111724')->is_valid_number, '茨城県行方市小貫');
ok($zip->set_number('3112101')->is_valid_number, '茨城県鉾田市青山');
ok($zip->set_number('3112102')->is_valid_number, '茨城県鉾田市台濁沢');
ok($zip->set_number('3112103')->is_valid_number, '茨城県鉾田市汲上');
ok($zip->set_number('3112104')->is_valid_number, '茨城県鉾田市梶山');
ok($zip->set_number('3112105')->is_valid_number, '茨城県鉾田市二重作');
ok($zip->set_number('3112111')->is_valid_number, '茨城県鉾田市上沢');
ok($zip->set_number('3112112')->is_valid_number, '茨城県鉾田市飯島');
ok($zip->set_number('3112113')->is_valid_number, '茨城県鉾田市上幡木');
ok($zip->set_number('3112114')->is_valid_number, '茨城県鉾田市江川');
ok($zip->set_number('3112115')->is_valid_number, '茨城県鉾田市中居');
ok($zip->set_number('3112116')->is_valid_number, '茨城県鉾田市札');
ok($zip->set_number('3112117')->is_valid_number, '茨城県鉾田市大蔵');
ok($zip->set_number('3112118')->is_valid_number, '茨城県鉾田市阿玉');
ok($zip->set_number('3112201')->is_valid_number, '茨城県鹿嶋市大小志崎');
ok($zip->set_number('3112202')->is_valid_number, '茨城県鹿嶋市武井釜');
ok($zip->set_number('3112203')->is_valid_number, '茨城県鹿嶋市浜津賀');
ok($zip->set_number('3112204')->is_valid_number, '茨城県鹿嶋市荒井');
ok($zip->set_number('3112205')->is_valid_number, '茨城県鹿嶋市津賀');
ok($zip->set_number('3112206')->is_valid_number, '茨城県鹿嶋市武井');
ok($zip->set_number('3112207')->is_valid_number, '茨城県鹿嶋市志崎');
ok($zip->set_number('3112211')->is_valid_number, '茨城県鹿嶋市青塚');
ok($zip->set_number('3112212')->is_valid_number, '茨城県鹿嶋市角折');
ok($zip->set_number('3112213')->is_valid_number, '茨城県鹿嶋市中');
ok($zip->set_number('3112214')->is_valid_number, '茨城県鹿嶋市棚木');
ok($zip->set_number('3112215')->is_valid_number, '茨城県鹿嶋市和');
ok($zip->set_number('3112221')->is_valid_number, '茨城県鹿嶋市荒野');
ok($zip->set_number('3112222')->is_valid_number, '茨城県鹿嶋市小山');
ok($zip->set_number('3112223')->is_valid_number, '茨城県鹿嶋市林');
ok($zip->set_number('3112224')->is_valid_number, '茨城県鹿嶋市奈良毛');
ok($zip->set_number('3112400')->is_valid_number, '茨城県潮来市以下に掲載がない場合');
ok($zip->set_number('3112401')->is_valid_number, '茨城県潮来市大賀');
ok($zip->set_number('3112402')->is_valid_number, '茨城県潮来市大生');
ok($zip->set_number('3112403')->is_valid_number, '茨城県潮来市釜谷');
ok($zip->set_number('3112404')->is_valid_number, '茨城県潮来市水原');
ok($zip->set_number('3112405')->is_valid_number, '茨城県潮来市築地');
ok($zip->set_number('3112406')->is_valid_number, '茨城県潮来市新宮');
ok($zip->set_number('3112407')->is_valid_number, '茨城県潮来市下田');
ok($zip->set_number('3112408')->is_valid_number, '茨城県潮来市洲崎');
ok($zip->set_number('3112409')->is_valid_number, '茨城県潮来市延方東');
ok($zip->set_number('3112410')->is_valid_number, '茨城県潮来市延方西');
ok($zip->set_number('3112412')->is_valid_number, '茨城県潮来市宮前');
ok($zip->set_number('3112415')->is_valid_number, '茨城県潮来市延方');
ok($zip->set_number('3112416')->is_valid_number, '茨城県潮来市前川');
ok($zip->set_number('3112417')->is_valid_number, '茨城県潮来市米島');
ok($zip->set_number('3112418')->is_valid_number, '茨城県潮来市徳島');
ok($zip->set_number('3112419')->is_valid_number, '茨城県潮来市福島');
ok($zip->set_number('3112421')->is_valid_number, '茨城県潮来市辻');
ok($zip->set_number('3112422')->is_valid_number, '茨城県潮来市大洲');
ok($zip->set_number('3112423')->is_valid_number, '茨城県潮来市日の出');
ok($zip->set_number('3112424')->is_valid_number, '茨城県潮来市潮来');
ok($zip->set_number('3112425')->is_valid_number, '茨城県潮来市あやめ');
ok($zip->set_number('3112426')->is_valid_number, '茨城県潮来市大塚野');
ok($zip->set_number('3112431')->is_valid_number, '茨城県潮来市清水');
ok($zip->set_number('3112432')->is_valid_number, '茨城県潮来市茂木');
ok($zip->set_number('3112433')->is_valid_number, '茨城県潮来市堀之内');
ok($zip->set_number('3112434')->is_valid_number, '茨城県潮来市島須');
ok($zip->set_number('3112435')->is_valid_number, '茨城県潮来市上戸');
ok($zip->set_number('3112436')->is_valid_number, '茨城県潮来市牛堀');
ok($zip->set_number('3112437')->is_valid_number, '茨城県潮来市永山');
ok($zip->set_number('3112440')->is_valid_number, '茨城県潮来市川尾');
ok($zip->set_number('3112441')->is_valid_number, '茨城県潮来市大山');
ok($zip->set_number('3112442')->is_valid_number, '茨城県潮来市小泉');
ok($zip->set_number('3112443')->is_valid_number, '茨城県潮来市新宮南');
ok($zip->set_number('3112444')->is_valid_number, '茨城県潮来市小泉南');
ok($zip->set_number('3112445')->is_valid_number, '茨城県潮来市曲松南');
ok($zip->set_number('3112446')->is_valid_number, '茨城県潮来市須賀南');
ok($zip->set_number('3112447')->is_valid_number, '茨城県潮来市曲松');
ok($zip->set_number('3112448')->is_valid_number, '茨城県潮来市須賀');
ok($zip->set_number('3112449')->is_valid_number, '茨城県潮来市古高');
ok($zip->set_number('3113100')->is_valid_number, '茨城県東茨城郡茨城町以下に掲載がない場合');
ok($zip->set_number('3113101')->is_valid_number, '茨城県東茨城郡茨城町南川又');
ok($zip->set_number('3113102')->is_valid_number, '茨城県東茨城郡茨城町南栗崎');
ok($zip->set_number('3113103')->is_valid_number, '茨城県東茨城郡茨城町野曽');
ok($zip->set_number('3113104')->is_valid_number, '茨城県東茨城郡茨城町駒渡');
ok($zip->set_number('3113105')->is_valid_number, '茨城県東茨城郡茨城町蕎麦原');
ok($zip->set_number('3113106')->is_valid_number, '茨城県東茨城郡茨城町越安');
ok($zip->set_number('3113107')->is_valid_number, '茨城県東茨城郡茨城町小鶴');
ok($zip->set_number('3113108')->is_valid_number, '茨城県東茨城郡茨城町中央工業団地');
ok($zip->set_number('3113111')->is_valid_number, '茨城県東茨城郡茨城町馬渡');
ok($zip->set_number('3113112')->is_valid_number, '茨城県東茨城郡茨城町常井');
ok($zip->set_number('3113113')->is_valid_number, '茨城県東茨城郡茨城町近藤');
ok($zip->set_number('3113114')->is_valid_number, '茨城県東茨城郡茨城町大戸');
ok($zip->set_number('3113115')->is_valid_number, '茨城県東茨城郡茨城町前田');
ok($zip->set_number('3113116')->is_valid_number, '茨城県東茨城郡茨城町長岡');
ok($zip->set_number('3113117')->is_valid_number, '茨城県東茨城郡茨城町桜の郷');
ok($zip->set_number('3113121')->is_valid_number, '茨城県東茨城郡茨城町谷田部');
ok($zip->set_number('3113122')->is_valid_number, '茨城県東茨城郡茨城町上石崎');
ok($zip->set_number('3113123')->is_valid_number, '茨城県東茨城郡茨城町若宮');
ok($zip->set_number('3113124')->is_valid_number, '茨城県東茨城郡茨城町中石崎');
ok($zip->set_number('3113125')->is_valid_number, '茨城県東茨城郡茨城町下石崎');
ok($zip->set_number('3113131')->is_valid_number, '茨城県東茨城郡茨城町小堤');
ok($zip->set_number('3113132')->is_valid_number, '茨城県東茨城郡茨城町駒場');
ok($zip->set_number('3113133')->is_valid_number, '茨城県東茨城郡茨城町南島田');
ok($zip->set_number('3113134')->is_valid_number, '茨城県東茨城郡茨城町神宿');
ok($zip->set_number('3113135')->is_valid_number, '茨城県東茨城郡茨城町海老沢');
ok($zip->set_number('3113136')->is_valid_number, '茨城県東茨城郡茨城町宮ケ崎');
ok($zip->set_number('3113137')->is_valid_number, '茨城県東茨城郡茨城町網掛');
ok($zip->set_number('3113138')->is_valid_number, '茨城県東茨城郡茨城町城之内');
ok($zip->set_number('3113141')->is_valid_number, '茨城県東茨城郡茨城町神谷');
ok($zip->set_number('3113142')->is_valid_number, '茨城県東茨城郡茨城町鳥羽田');
ok($zip->set_number('3113143')->is_valid_number, '茨城県東茨城郡茨城町生井沢');
ok($zip->set_number('3113144')->is_valid_number, '茨城県東茨城郡茨城町下雨ケ谷');
ok($zip->set_number('3113145')->is_valid_number, '茨城県東茨城郡茨城町上雨ケ谷');
ok($zip->set_number('3113146')->is_valid_number, '茨城県東茨城郡茨城町下座');
ok($zip->set_number('3113147')->is_valid_number, '茨城県東茨城郡茨城町秋葉');
ok($zip->set_number('3113151')->is_valid_number, '茨城県東茨城郡茨城町木部');
ok($zip->set_number('3113152')->is_valid_number, '茨城県東茨城郡茨城町飯沼');
ok($zip->set_number('3113153')->is_valid_number, '茨城県東茨城郡茨城町上飯沼');
ok($zip->set_number('3113154')->is_valid_number, '茨城県東茨城郡茨城町下飯沼');
ok($zip->set_number('3113155')->is_valid_number, '茨城県東茨城郡茨城町下土師');
ok($zip->set_number('3113156')->is_valid_number, '茨城県東茨城郡茨城町奥谷');
ok($zip->set_number('3113157')->is_valid_number, '茨城県東茨城郡茨城町小幡');
ok($zip->set_number('3113401')->is_valid_number, '茨城県小美玉市世楽');
ok($zip->set_number('3113402')->is_valid_number, '茨城県小美玉市佐才');
ok($zip->set_number('3113403')->is_valid_number, '茨城県小美玉市上吉影');
ok($zip->set_number('3113404')->is_valid_number, '茨城県小美玉市飯前');
ok($zip->set_number('3113405')->is_valid_number, '茨城県小美玉市上合');
ok($zip->set_number('3113406')->is_valid_number, '茨城県小美玉市下吉影');
ok($zip->set_number('3113411')->is_valid_number, '茨城県小美玉市野田');
ok($zip->set_number('3113412')->is_valid_number, '茨城県小美玉市川戸');
ok($zip->set_number('3113413')->is_valid_number, '茨城県小美玉市山野');
ok($zip->set_number('3113414')->is_valid_number, '茨城県小美玉市外之内');
ok($zip->set_number('3113415')->is_valid_number, '茨城県小美玉市百里');
ok($zip->set_number('3113416')->is_valid_number, '茨城県小美玉市与沢');
ok($zip->set_number('3113417')->is_valid_number, '茨城県小美玉市倉数');
ok($zip->set_number('3113421')->is_valid_number, '茨城県小美玉市宮田');
ok($zip->set_number('3113422')->is_valid_number, '茨城県小美玉市中延');
ok($zip->set_number('3113423')->is_valid_number, '茨城県小美玉市小川');
ok($zip->set_number('3113424')->is_valid_number, '茨城県小美玉市幡谷');
ok($zip->set_number('3113425')->is_valid_number, '茨城県小美玉市小塙');
ok($zip->set_number('3113426')->is_valid_number, '茨城県小美玉市下馬場');
ok($zip->set_number('3113431')->is_valid_number, '茨城県小美玉市川中子');
ok($zip->set_number('3113432')->is_valid_number, '茨城県小美玉市下玉里');
ok($zip->set_number('3113433')->is_valid_number, '茨城県小美玉市高崎');
ok($zip->set_number('3113434')->is_valid_number, '茨城県小美玉市栗又四ケ');
ok($zip->set_number('3113435')->is_valid_number, '茨城県小美玉市田木谷');
ok($zip->set_number('3113436')->is_valid_number, '茨城県小美玉市上玉里');
ok($zip->set_number('3113437')->is_valid_number, '茨城県小美玉市東田中');
ok($zip->set_number('3113501')->is_valid_number, '茨城県行方市芹沢');
ok($zip->set_number('3113502')->is_valid_number, '茨城県行方市若海');
ok($zip->set_number('3113503')->is_valid_number, '茨城県行方市捻木');
ok($zip->set_number('3113504')->is_valid_number, '茨城県行方市谷島');
ok($zip->set_number('3113505')->is_valid_number, '茨城県行方市浜');
ok($zip->set_number('3113506')->is_valid_number, '茨城県行方市八木蒔');
ok($zip->set_number('3113507')->is_valid_number, '茨城県行方市羽生');
ok($zip->set_number('3113508')->is_valid_number, '茨城県行方市沖洲');
ok($zip->set_number('3113511')->is_valid_number, '茨城県行方市玉造乙');
ok($zip->set_number('3113512')->is_valid_number, '茨城県行方市玉造甲');
ok($zip->set_number('3113513')->is_valid_number, '茨城県行方市手賀');
ok($zip->set_number('3113514')->is_valid_number, '茨城県行方市西蓮寺');
ok($zip->set_number('3113515')->is_valid_number, '茨城県行方市井上');
ok($zip->set_number('3113516')->is_valid_number, '茨城県行方市井上藤井');
ok($zip->set_number('3113517')->is_valid_number, '茨城県行方市藤井');
ok($zip->set_number('3113518')->is_valid_number, '茨城県行方市荒宿');
ok($zip->set_number('3113800')->is_valid_number, '茨城県行方市以下に掲載がない場合');
ok($zip->set_number('3113801')->is_valid_number, '茨城県行方市行方');
ok($zip->set_number('3113802')->is_valid_number, '茨城県行方市於下');
ok($zip->set_number('3113803')->is_valid_number, '茨城県行方市井貝');
ok($zip->set_number('3113804')->is_valid_number, '茨城県行方市小高');
ok($zip->set_number('3113805')->is_valid_number, '茨城県行方市橋門');
ok($zip->set_number('3113806')->is_valid_number, '茨城県行方市船子');
ok($zip->set_number('3113807')->is_valid_number, '茨城県行方市五町田');
ok($zip->set_number('3113811')->is_valid_number, '茨城県行方市四鹿');
ok($zip->set_number('3113812')->is_valid_number, '茨城県行方市杉平');
ok($zip->set_number('3113813')->is_valid_number, '茨城県行方市籠田');
ok($zip->set_number('3113814')->is_valid_number, '茨城県行方市天掛');
ok($zip->set_number('3113815')->is_valid_number, '茨城県行方市新宮');
ok($zip->set_number('3113816')->is_valid_number, '茨城県行方市小牧');
ok($zip->set_number('3113817')->is_valid_number, '茨城県行方市板峰');
ok($zip->set_number('3113821')->is_valid_number, '茨城県行方市蔵川');
ok($zip->set_number('3113822')->is_valid_number, '茨城県行方市岡');
ok($zip->set_number('3113823')->is_valid_number, '茨城県行方市白浜');
ok($zip->set_number('3113824')->is_valid_number, '茨城県行方市宇崎');
ok($zip->set_number('3113825')->is_valid_number, '茨城県行方市根小屋');
ok($zip->set_number('3113826')->is_valid_number, '茨城県行方市矢幡');
ok($zip->set_number('3113827')->is_valid_number, '茨城県行方市石神');
ok($zip->set_number('3113831')->is_valid_number, '茨城県行方市青沼');
ok($zip->set_number('3113832')->is_valid_number, '茨城県行方市麻生');
ok($zip->set_number('3113833')->is_valid_number, '茨城県行方市富田');
ok($zip->set_number('3113834')->is_valid_number, '茨城県行方市粗毛');
ok($zip->set_number('3113835')->is_valid_number, '茨城県行方市島並');
ok($zip->set_number('3113836')->is_valid_number, '茨城県行方市南');
ok($zip->set_number('3114141')->is_valid_number, '茨城県水戸市赤塚');
ok($zip->set_number('3114142')->is_valid_number, '茨城県水戸市東赤塚');
ok($zip->set_number('3114143')->is_valid_number, '茨城県水戸市大塚町');
ok($zip->set_number('3114144')->is_valid_number, '茨城県水戸市開江町');
ok($zip->set_number('3114145')->is_valid_number, '茨城県水戸市双葉台');
ok($zip->set_number('3114146')->is_valid_number, '茨城県水戸市中丸町');
ok($zip->set_number('3114151')->is_valid_number, '茨城県水戸市姫子');
ok($zip->set_number('3114152')->is_valid_number, '茨城県水戸市河和田');
ok($zip->set_number('3114153')->is_valid_number, '茨城県水戸市河和田町');
ok($zip->set_number('3114154')->is_valid_number, '茨城県水戸市萱場町');
ok($zip->set_number('3114155')->is_valid_number, '茨城県水戸市飯島町');
ok($zip->set_number('3114161')->is_valid_number, '茨城県水戸市全隈町');
ok($zip->set_number('3114162')->is_valid_number, '茨城県水戸市金谷町');
ok($zip->set_number('3114163')->is_valid_number, '茨城県水戸市加倉井町');
ok($zip->set_number('3114164')->is_valid_number, '茨城県水戸市谷津町');
ok($zip->set_number('3114165')->is_valid_number, '茨城県水戸市木葉下町');
ok($zip->set_number('3114201')->is_valid_number, '茨城県水戸市藤井町');
ok($zip->set_number('3114202')->is_valid_number, '茨城県水戸市岩根町');
ok($zip->set_number('3114203')->is_valid_number, '茨城県水戸市上国井町');
ok($zip->set_number('3114204')->is_valid_number, '茨城県水戸市田谷町');
ok($zip->set_number('3114205')->is_valid_number, '茨城県水戸市下国井町');
ok($zip->set_number('3114206')->is_valid_number, '茨城県水戸市飯富町');
ok($zip->set_number('3114207')->is_valid_number, '茨城県水戸市成沢町');
ok($zip->set_number('3114208')->is_valid_number, '茨城県水戸市藤が原');
ok($zip->set_number('3114300')->is_valid_number, '茨城県東茨城郡城里町以下に掲載がない場合');
ok($zip->set_number('3114301')->is_valid_number, '茨城県東茨城郡城里町上泉');
ok($zip->set_number('3114302')->is_valid_number, '茨城県東茨城郡城里町那珂西');
ok($zip->set_number('3114303')->is_valid_number, '茨城県東茨城郡城里町石塚');
ok($zip->set_number('3114304')->is_valid_number, '茨城県東茨城郡城里町下青山');
ok($zip->set_number('3114305')->is_valid_number, '茨城県東茨城郡城里町上青山');
ok($zip->set_number('3114306')->is_valid_number, '茨城県東茨城郡城里町春園');
ok($zip->set_number('3114311')->is_valid_number, '茨城県東茨城郡城里町増井');
ok($zip->set_number('3114312')->is_valid_number, '茨城県東茨城郡城里町磯野');
ok($zip->set_number('3114313')->is_valid_number, '茨城県東茨城郡城里町上入野');
ok($zip->set_number('3114314')->is_valid_number, '茨城県東茨城郡城里町下古内');
ok($zip->set_number('3114315')->is_valid_number, '茨城県東茨城郡城里町上古内');
ok($zip->set_number('3114316')->is_valid_number, '茨城県東茨城郡城里町小坂');
ok($zip->set_number('3114317')->is_valid_number, '茨城県東茨城郡城里町勝見沢');
ok($zip->set_number('3114321')->is_valid_number, '茨城県東茨城郡城里町粟');
ok($zip->set_number('3114322')->is_valid_number, '茨城県東茨城郡城里町下圷');
ok($zip->set_number('3114323')->is_valid_number, '茨城県東茨城郡城里町上圷');
ok($zip->set_number('3114324')->is_valid_number, '茨城県東茨城郡城里町高久');
ok($zip->set_number('3114325')->is_valid_number, '茨城県東茨城郡城里町北方');
ok($zip->set_number('3114331')->is_valid_number, '茨城県東茨城郡城里町岩船');
ok($zip->set_number('3114332')->is_valid_number, '茨城県東茨城郡城里町高根台');
ok($zip->set_number('3114333')->is_valid_number, '茨城県東茨城郡城里町高根');
ok($zip->set_number('3114334')->is_valid_number, '茨城県東茨城郡城里町孫根');
ok($zip->set_number('3114335')->is_valid_number, '茨城県東茨城郡城里町錫高野');
ok($zip->set_number('3114341')->is_valid_number, '茨城県東茨城郡城里町御前山');
ok($zip->set_number('3114342')->is_valid_number, '茨城県東茨城郡城里町上阿野沢');
ok($zip->set_number('3114343')->is_valid_number, '茨城県東茨城郡城里町下阿野沢');
ok($zip->set_number('3114344')->is_valid_number, '茨城県東茨城郡城里町阿波山');
ok($zip->set_number('3114401')->is_valid_number, '茨城県東茨城郡城里町塩子');
ok($zip->set_number('3114402')->is_valid_number, '茨城県東茨城郡城里町小勝');
ok($zip->set_number('3114403')->is_valid_number, '茨城県東茨城郡城里町大網');
ok($zip->set_number('3114404')->is_valid_number, '茨城県東茨城郡城里町真端');
ok($zip->set_number('3114405')->is_valid_number, '茨城県東茨城郡城里町上赤沢');
ok($zip->set_number('3114406')->is_valid_number, '茨城県東茨城郡城里町下赤沢');
ok($zip->set_number('3114407')->is_valid_number, '茨城県東茨城郡城里町徳蔵');
ok($zip->set_number('3114411')->is_valid_number, '栃木県芳賀郡茂木町桧山(道木橋)');
ok($zip->set_number('3114501')->is_valid_number, '茨城県常陸大宮市門井');
ok($zip->set_number('3114502')->is_valid_number, '茨城県常陸大宮市野口平');
ok($zip->set_number('3114503')->is_valid_number, '茨城県常陸大宮市野口');
ok($zip->set_number('3114611')->is_valid_number, '茨城県常陸大宮市秋田');
ok($zip->set_number('3114612')->is_valid_number, '茨城県常陸大宮市中居');
ok($zip->set_number('3114613')->is_valid_number, '茨城県常陸大宮市長倉');
ok($zip->set_number('3114614')->is_valid_number, '茨城県常陸大宮市金井');
ok($zip->set_number('3114615')->is_valid_number, '茨城県常陸大宮市下伊勢畑');
ok($zip->set_number('3114616')->is_valid_number, '茨城県常陸大宮市桧山');
ok($zip->set_number('3114617')->is_valid_number, '茨城県常陸大宮市上伊勢畑');
ok($zip->set_number('3114618')->is_valid_number, '茨城県常陸大宮市野田');
ok($zip->set_number('3120000')->is_valid_number, '茨城県ひたちなか市以下に掲載がない場合');
ok($zip->set_number('3120001')->is_valid_number, '茨城県ひたちなか市佐和');
ok($zip->set_number('3120002')->is_valid_number, '茨城県ひたちなか市高野');
ok($zip->set_number('3120003')->is_valid_number, '茨城県ひたちなか市足崎');
ok($zip->set_number('3120004')->is_valid_number, '茨城県ひたちなか市長砂');
ok($zip->set_number('3120005')->is_valid_number, '茨城県ひたちなか市新光町');
ok($zip->set_number('3120006')->is_valid_number, '茨城県ひたちなか市前浜');
ok($zip->set_number('3120007')->is_valid_number, '茨城県ひたちなか市小貫山');
ok($zip->set_number('3120011')->is_valid_number, '茨城県ひたちなか市中根');
ok($zip->set_number('3120012')->is_valid_number, '茨城県ひたちなか市馬渡');
ok($zip->set_number('3120013')->is_valid_number, '茨城県ひたちなか市上野');
ok($zip->set_number('3120014')->is_valid_number, '茨城県ひたちなか市後野');
ok($zip->set_number('3120015')->is_valid_number, '茨城県ひたちなか市小砂町');
ok($zip->set_number('3120016')->is_valid_number, '茨城県ひたちなか市松戸町');
ok($zip->set_number('3120017')->is_valid_number, '茨城県ひたちなか市長堀町');
ok($zip->set_number('3120018')->is_valid_number, '茨城県ひたちなか市笹野町');
ok($zip->set_number('3120021')->is_valid_number, '茨城県ひたちなか市三反田');
ok($zip->set_number('3120022')->is_valid_number, '茨城県ひたちなか市金上');
ok($zip->set_number('3120023')->is_valid_number, '茨城県ひたちなか市大平');
ok($zip->set_number('3120024')->is_valid_number, '茨城県ひたちなか市勝倉');
ok($zip->set_number('3120025')->is_valid_number, '茨城県ひたちなか市武田');
ok($zip->set_number('3120026')->is_valid_number, '茨城県ひたちなか市勝田本町');
ok($zip->set_number('3120027')->is_valid_number, '茨城県ひたちなか市勝田中原町');
ok($zip->set_number('3120031')->is_valid_number, '茨城県ひたちなか市後台');
ok($zip->set_number('3120032')->is_valid_number, '茨城県ひたちなか市津田');
ok($zip->set_number('3120033')->is_valid_number, '茨城県ひたちなか市市毛');
ok($zip->set_number('3120034')->is_valid_number, '茨城県ひたちなか市堀口');
ok($zip->set_number('3120035')->is_valid_number, '茨城県ひたちなか市枝川');
ok($zip->set_number('3120036')->is_valid_number, '茨城県ひたちなか市津田東');
ok($zip->set_number('3120041')->is_valid_number, '茨城県ひたちなか市西大島');
ok($zip->set_number('3120042')->is_valid_number, '茨城県ひたちなか市東大島');
ok($zip->set_number('3120043')->is_valid_number, '茨城県ひたちなか市共栄町');
ok($zip->set_number('3120044')->is_valid_number, '茨城県ひたちなか市元町');
ok($zip->set_number('3120045')->is_valid_number, '茨城県ひたちなか市勝田中央');
ok($zip->set_number('3120046')->is_valid_number, '茨城県ひたちなか市勝田泉町');
ok($zip->set_number('3120047')->is_valid_number, '茨城県ひたちなか市表町');
ok($zip->set_number('3120048')->is_valid_number, '茨城県ひたちなか市春日町');
ok($zip->set_number('3120051')->is_valid_number, '茨城県ひたちなか市堂端');
ok($zip->set_number('3120052')->is_valid_number, '茨城県ひたちなか市東石川');
ok($zip->set_number('3120053')->is_valid_number, '茨城県ひたちなか市外野');
ok($zip->set_number('3120054')->is_valid_number, '茨城県ひたちなか市はしかべ');
ok($zip->set_number('3120055')->is_valid_number, '茨城県ひたちなか市大成町');
ok($zip->set_number('3120056')->is_valid_number, '茨城県ひたちなか市青葉町');
ok($zip->set_number('3120057')->is_valid_number, '茨城県ひたちなか市石川町');
ok($zip->set_number('3120058')->is_valid_number, '茨城県ひたちなか市西光地');
ok($zip->set_number('3120061')->is_valid_number, '茨城県ひたちなか市稲田');
ok($zip->set_number('3120062')->is_valid_number, '茨城県ひたちなか市高場');
ok($zip->set_number('3120063')->is_valid_number, '茨城県ひたちなか市田彦');
ok($zip->set_number('3130000')->is_valid_number, '茨城県常陸太田市以下に掲載がない場合');
ok($zip->set_number('3130001')->is_valid_number, '茨城県常陸太田市上大門町');
ok($zip->set_number('3130002')->is_valid_number, '茨城県常陸太田市下大門町');
ok($zip->set_number('3130003')->is_valid_number, '茨城県常陸太田市瑞龍町');
ok($zip->set_number('3130004')->is_valid_number, '茨城県常陸太田市馬場町');
ok($zip->set_number('3130005')->is_valid_number, '茨城県常陸太田市栄町');
ok($zip->set_number('3130006')->is_valid_number, '茨城県常陸太田市宮本町');
ok($zip->set_number('3130007')->is_valid_number, '茨城県常陸太田市新宿町');
ok($zip->set_number('3130008')->is_valid_number, '茨城県常陸太田市増井町');
ok($zip->set_number('3130011')->is_valid_number, '茨城県常陸太田市西宮町');
ok($zip->set_number('3130012')->is_valid_number, '茨城県常陸太田市三才町');
ok($zip->set_number('3130013')->is_valid_number, '茨城県常陸太田市山下町');
ok($zip->set_number('3130014')->is_valid_number, '茨城県常陸太田市木崎二町');
ok($zip->set_number('3130015')->is_valid_number, '茨城県常陸太田市木崎一町');
ok($zip->set_number('3130016')->is_valid_number, '茨城県常陸太田市金井町');
ok($zip->set_number('3130021')->is_valid_number, '茨城県常陸太田市大森町');
ok($zip->set_number('3130022')->is_valid_number, '茨城県常陸太田市真弓町');
ok($zip->set_number('3130023')->is_valid_number, '茨城県常陸太田市亀作町');
ok($zip->set_number('3130024')->is_valid_number, '茨城県常陸太田市高貫町');
ok($zip->set_number('3130025')->is_valid_number, '茨城県常陸太田市幡町');
ok($zip->set_number('3130026')->is_valid_number, '茨城県常陸太田市田渡町');
ok($zip->set_number('3130027')->is_valid_number, '茨城県常陸太田市長谷町');
ok($zip->set_number('3130031')->is_valid_number, '茨城県常陸太田市岡田町');
ok($zip->set_number('3130032')->is_valid_number, '茨城県常陸太田市沢目町');
ok($zip->set_number('3130033')->is_valid_number, '茨城県常陸太田市小目町');
ok($zip->set_number('3130034')->is_valid_number, '茨城県常陸太田市上土木内町');
ok($zip->set_number('3130035')->is_valid_number, '茨城県常陸太田市堅磐町');
ok($zip->set_number('3130036')->is_valid_number, '茨城県常陸太田市落合町');
ok($zip->set_number('3130037')->is_valid_number, '茨城県常陸太田市内田町');
ok($zip->set_number('3130038')->is_valid_number, '茨城県常陸太田市小沢町');
ok($zip->set_number('3130041')->is_valid_number, '茨城県常陸太田市稲木町');
ok($zip->set_number('3130042')->is_valid_number, '茨城県常陸太田市磯部町');
ok($zip->set_number('3130043')->is_valid_number, '茨城県常陸太田市谷河原町');
ok($zip->set_number('3130044')->is_valid_number, '茨城県常陸太田市下河合町');
ok($zip->set_number('3130045')->is_valid_number, '茨城県常陸太田市粟原町');
ok($zip->set_number('3130046')->is_valid_number, '茨城県常陸太田市上河合町');
ok($zip->set_number('3130047')->is_valid_number, '茨城県常陸太田市島町');
ok($zip->set_number('3130048')->is_valid_number, '茨城県常陸太田市藤田町');
ok($zip->set_number('3130049')->is_valid_number, '茨城県常陸太田市天神林町');
ok($zip->set_number('3130051')->is_valid_number, '茨城県常陸太田市東一町');
ok($zip->set_number('3130052')->is_valid_number, '茨城県常陸太田市東二町');
ok($zip->set_number('3130053')->is_valid_number, '茨城県常陸太田市東三町');
ok($zip->set_number('3130054')->is_valid_number, '茨城県常陸太田市西三町');
ok($zip->set_number('3130055')->is_valid_number, '茨城県常陸太田市西二町');
ok($zip->set_number('3130056')->is_valid_number, '茨城県常陸太田市西一町');
ok($zip->set_number('3130061')->is_valid_number, '茨城県常陸太田市中城町');
ok($zip->set_number('3130062')->is_valid_number, '茨城県常陸太田市塙町');
ok($zip->set_number('3130063')->is_valid_number, '茨城県常陸太田市内堀町');
ok($zip->set_number('3130064')->is_valid_number, '茨城県常陸太田市寿町');
ok($zip->set_number('3130101')->is_valid_number, '茨城県常陸太田市上宮河内町');
ok($zip->set_number('3130102')->is_valid_number, '茨城県常陸太田市赤土町');
ok($zip->set_number('3130103')->is_valid_number, '茨城県常陸太田市下宮河内町');
ok($zip->set_number('3130104')->is_valid_number, '茨城県常陸太田市上利員町');
ok($zip->set_number('3130105')->is_valid_number, '茨城県常陸太田市中利員町');
ok($zip->set_number('3130106')->is_valid_number, '茨城県常陸太田市下利員町');
ok($zip->set_number('3130111')->is_valid_number, '茨城県常陸太田市千寿町');
ok($zip->set_number('3130112')->is_valid_number, '茨城県常陸太田市岩手町');
ok($zip->set_number('3130113')->is_valid_number, '茨城県常陸太田市高柿町');
ok($zip->set_number('3130114')->is_valid_number, '茨城県常陸太田市箕町');
ok($zip->set_number('3130115')->is_valid_number, '茨城県常陸太田市竹合町');
ok($zip->set_number('3130116')->is_valid_number, '茨城県常陸太田市大方町');
ok($zip->set_number('3130117')->is_valid_number, '茨城県常陸太田市宮の郷町');
ok($zip->set_number('3130121')->is_valid_number, '茨城県常陸太田市芦間町');
ok($zip->set_number('3130122')->is_valid_number, '茨城県常陸太田市玉造町');
ok($zip->set_number('3130123')->is_valid_number, '茨城県常陸太田市久米町');
ok($zip->set_number('3130124')->is_valid_number, '茨城県常陸太田市大平町');
ok($zip->set_number('3130125')->is_valid_number, '茨城県常陸太田市大里町');
ok($zip->set_number('3130126')->is_valid_number, '茨城県常陸太田市薬谷町');
ok($zip->set_number('3130131')->is_valid_number, '茨城県常陸太田市花房町');
ok($zip->set_number('3130132')->is_valid_number, '茨城県常陸太田市新地町');
ok($zip->set_number('3130133')->is_valid_number, '茨城県常陸太田市松栄町');
ok($zip->set_number('3130134')->is_valid_number, '茨城県常陸太田市中野町');
ok($zip->set_number('3130135')->is_valid_number, '茨城県常陸太田市小島町');
ok($zip->set_number('3130211')->is_valid_number, '茨城県常陸太田市東染町');
ok($zip->set_number('3130212')->is_valid_number, '茨城県常陸太田市中染町');
ok($zip->set_number('3130213')->is_valid_number, '茨城県常陸太田市町田町');
ok($zip->set_number('3130214')->is_valid_number, '茨城県常陸太田市和久町');
ok($zip->set_number('3130215')->is_valid_number, '茨城県常陸太田市西染町');
ok($zip->set_number('3130221')->is_valid_number, '茨城県常陸太田市国安町');
ok($zip->set_number('3130222')->is_valid_number, '茨城県常陸太田市松平町');
ok($zip->set_number('3130223')->is_valid_number, '茨城県常陸太田市和田町');
ok($zip->set_number('3130224')->is_valid_number, '茨城県常陸太田市東連地町');
ok($zip->set_number('3130225')->is_valid_number, '茨城県常陸太田市棚谷町');
ok($zip->set_number('3130351')->is_valid_number, '茨城県常陸太田市天下野町');
ok($zip->set_number('3130352')->is_valid_number, '茨城県常陸太田市下高倉町');
ok($zip->set_number('3130353')->is_valid_number, '茨城県常陸太田市上高倉町');
ok($zip->set_number('3140000')->is_valid_number, '茨城県鹿嶋市以下に掲載がない場合');
ok($zip->set_number('3140001')->is_valid_number, '茨城県鹿嶋市清水');
ok($zip->set_number('3140002')->is_valid_number, '茨城県鹿嶋市明石');
ok($zip->set_number('3140003')->is_valid_number, '茨城県鹿嶋市小宮作');
ok($zip->set_number('3140004')->is_valid_number, '茨城県鹿嶋市下津');
ok($zip->set_number('3140005')->is_valid_number, '茨城県鹿嶋市高天原');
ok($zip->set_number('3140006')->is_valid_number, '茨城県鹿嶋市宮津台');
ok($zip->set_number('3140007')->is_valid_number, '茨城県鹿嶋市神向寺');
ok($zip->set_number('3140011')->is_valid_number, '茨城県鹿嶋市港ケ丘');
ok($zip->set_number('3140012')->is_valid_number, '茨城県鹿嶋市平井');
ok($zip->set_number('3140013')->is_valid_number, '茨城県鹿嶋市新浜');
ok($zip->set_number('3140014')->is_valid_number, '茨城県鹿嶋市光');
ok($zip->set_number('3140015')->is_valid_number, '茨城県鹿嶋市泉川');
ok($zip->set_number('3140016')->is_valid_number, '茨城県鹿嶋市国末');
ok($zip->set_number('3140017')->is_valid_number, '茨城県鹿嶋市旭ケ丘');
ok($zip->set_number('3140018')->is_valid_number, '茨城県鹿嶋市平井東');
ok($zip->set_number('3140021')->is_valid_number, '茨城県鹿嶋市粟生');
ok($zip->set_number('3140022')->is_valid_number, '茨城県鹿嶋市長栖');
ok($zip->set_number('3140023')->is_valid_number, '茨城県鹿嶋市谷原');
ok($zip->set_number('3140024')->is_valid_number, '茨城県鹿嶋市鰐川');
ok($zip->set_number('3140025')->is_valid_number, '茨城県鹿嶋市下塙');
ok($zip->set_number('3140026')->is_valid_number, '茨城県鹿嶋市木滝佐田谷原入会');
ok($zip->set_number('3140027')->is_valid_number, '茨城県鹿嶋市佐田');
ok($zip->set_number('3140028')->is_valid_number, '茨城県鹿嶋市木滝');
ok($zip->set_number('3140030')->is_valid_number, '茨城県鹿嶋市厨');
ok($zip->set_number('3140031')->is_valid_number, '茨城県鹿嶋市宮中');
ok($zip->set_number('3140032')->is_valid_number, '茨城県鹿嶋市宮下');
ok($zip->set_number('3140033')->is_valid_number, '茨城県鹿嶋市鉢形台');
ok($zip->set_number('3140034')->is_valid_number, '茨城県鹿嶋市鉢形');
ok($zip->set_number('3140035')->is_valid_number, '茨城県鹿嶋市根三田');
ok($zip->set_number('3140036')->is_valid_number, '茨城県鹿嶋市大船津');
ok($zip->set_number('3140037')->is_valid_number, '茨城県鹿嶋市神野');
ok($zip->set_number('3140038')->is_valid_number, '茨城県鹿嶋市城山');
ok($zip->set_number('3140039')->is_valid_number, '茨城県鹿嶋市緑ヶ丘');
ok($zip->set_number('3140041')->is_valid_number, '茨城県鹿嶋市沼尾');
ok($zip->set_number('3140042')->is_valid_number, '茨城県鹿嶋市田野辺');
ok($zip->set_number('3140043')->is_valid_number, '茨城県鹿嶋市田谷');
ok($zip->set_number('3140044')->is_valid_number, '茨城県鹿嶋市猿田');
ok($zip->set_number('3140045')->is_valid_number, '茨城県鹿嶋市山之上');
ok($zip->set_number('3140046')->is_valid_number, '茨城県鹿嶋市爪木');
ok($zip->set_number('3140047')->is_valid_number, '茨城県鹿嶋市須賀');
ok($zip->set_number('3140048')->is_valid_number, '茨城県鹿嶋市田谷沼');
ok($zip->set_number('3140051')->is_valid_number, '茨城県神栖市光');
ok($zip->set_number('3140052')->is_valid_number, '茨城県神栖市居切(1901、1909-16、1909-20)');
ok($zip->set_number('3140100')->is_valid_number, '茨城県神栖市以下に掲載がない場合');
ok($zip->set_number('3140101')->is_valid_number, '茨城県神栖市北浜');
ok($zip->set_number('3140102')->is_valid_number, '茨城県神栖市東和田');
ok($zip->set_number('3140103')->is_valid_number, '茨城県神栖市東深芝');
ok($zip->set_number('3140111')->is_valid_number, '茨城県神栖市南浜');
ok($zip->set_number('3140112')->is_valid_number, '茨城県神栖市知手中央');
ok($zip->set_number('3140113')->is_valid_number, '茨城県神栖市横瀬');
ok($zip->set_number('3140114')->is_valid_number, '茨城県神栖市日川');
ok($zip->set_number('3140115')->is_valid_number, '茨城県神栖市知手');
ok($zip->set_number('3140116')->is_valid_number, '茨城県神栖市奥野谷');
ok($zip->set_number('3140121')->is_valid_number, '茨城県神栖市溝口');
ok($zip->set_number('3140122')->is_valid_number, '茨城県神栖市萩原');
ok($zip->set_number('3140123')->is_valid_number, '茨城県神栖市芝崎');
ok($zip->set_number('3140124')->is_valid_number, '茨城県神栖市石神');
ok($zip->set_number('3140125')->is_valid_number, '茨城県神栖市高浜');
ok($zip->set_number('3140126')->is_valid_number, '茨城県神栖市田畑');
ok($zip->set_number('3140127')->is_valid_number, '茨城県神栖市木崎');
ok($zip->set_number('3140128')->is_valid_number, '茨城県神栖市大野原中央');
ok($zip->set_number('3140131')->is_valid_number, '茨城県神栖市下幡木');
ok($zip->set_number('3140132')->is_valid_number, '茨城県神栖市筒井');
ok($zip->set_number('3140133')->is_valid_number, '茨城県神栖市息栖');
ok($zip->set_number('3140134')->is_valid_number, '茨城県神栖市賀');
ok($zip->set_number('3140135')->is_valid_number, '茨城県神栖市堀割');
ok($zip->set_number('3140141')->is_valid_number, '茨城県神栖市居切(その他)');
ok($zip->set_number('3140142')->is_valid_number, '茨城県神栖市深芝南');
ok($zip->set_number('3140143')->is_valid_number, '茨城県神栖市神栖');
ok($zip->set_number('3140144')->is_valid_number, '茨城県神栖市大野原');
ok($zip->set_number('3140145')->is_valid_number, '茨城県神栖市平泉外12入会');
ok($zip->set_number('3140145')->is_valid_number, '茨城県神栖市平泉東');
ok($zip->set_number('3140146')->is_valid_number, '茨城県神栖市平泉');
ok($zip->set_number('3140147')->is_valid_number, '茨城県神栖市鰐川');
ok($zip->set_number('3140148')->is_valid_number, '茨城県神栖市深芝');
ok($zip->set_number('3140252')->is_valid_number, '茨城県神栖市柳川');
ok($zip->set_number('3140253')->is_valid_number, '茨城県神栖市須田');
ok($zip->set_number('3140254')->is_valid_number, '茨城県神栖市太田');
ok($zip->set_number('3140255')->is_valid_number, '茨城県神栖市砂山');
ok($zip->set_number('3140256')->is_valid_number, '茨城県神栖市若松中央');
ok($zip->set_number('3140257')->is_valid_number, '茨城県神栖市太田新町');
ok($zip->set_number('3140258')->is_valid_number, '茨城県神栖市柳川中央');
ok($zip->set_number('3140341')->is_valid_number, '茨城県神栖市矢田部');
ok($zip->set_number('3140342')->is_valid_number, '茨城県神栖市土合北');
ok($zip->set_number('3140343')->is_valid_number, '茨城県神栖市土合本町');
ok($zip->set_number('3140344')->is_valid_number, '茨城県神栖市土合東');
ok($zip->set_number('3140345')->is_valid_number, '茨城県神栖市土合南');
ok($zip->set_number('3140346')->is_valid_number, '茨城県神栖市土合西');
ok($zip->set_number('3140347')->is_valid_number, '茨城県神栖市土合中央');
ok($zip->set_number('3140407')->is_valid_number, '茨城県神栖市波崎新港');
ok($zip->set_number('3140408')->is_valid_number, '茨城県神栖市波崎');
ok($zip->set_number('3150000')->is_valid_number, '茨城県石岡市以下に掲載がない場合');
ok($zip->set_number('3150000')->is_valid_number, '茨城県かすみがうら市以下に掲載がない場合');
ok($zip->set_number('3150001')->is_valid_number, '茨城県石岡市石岡');
ok($zip->set_number('3150002')->is_valid_number, '茨城県石岡市柏原');
ok($zip->set_number('3150003')->is_valid_number, '茨城県石岡市谷向町');
ok($zip->set_number('3150004')->is_valid_number, '茨城県石岡市柏原町');
ok($zip->set_number('3150005')->is_valid_number, '茨城県石岡市鹿の子');
ok($zip->set_number('3150006')->is_valid_number, '茨城県石岡市並木');
ok($zip->set_number('3150007')->is_valid_number, '茨城県石岡市染谷');
ok($zip->set_number('3150008')->is_valid_number, '茨城県石岡市村上');
ok($zip->set_number('3150009')->is_valid_number, '茨城県石岡市大砂');
ok($zip->set_number('3150010')->is_valid_number, '茨城県石岡市碁石沢');
ok($zip->set_number('3150011')->is_valid_number, '茨城県石岡市正上内');
ok($zip->set_number('3150012')->is_valid_number, '茨城県石岡市北府中');
ok($zip->set_number('3150013')->is_valid_number, '茨城県石岡市府中');
ok($zip->set_number('3150014')->is_valid_number, '茨城県石岡市国府');
ok($zip->set_number('3150015')->is_valid_number, '茨城県石岡市貝地');
ok($zip->set_number('3150016')->is_valid_number, '茨城県石岡市総社');
ok($zip->set_number('3150017')->is_valid_number, '茨城県石岡市若宮');
ok($zip->set_number('3150018')->is_valid_number, '茨城県石岡市若松');
ok($zip->set_number('3150019')->is_valid_number, '茨城県石岡市栄松');
ok($zip->set_number('3150021')->is_valid_number, '茨城県石岡市荒金');
ok($zip->set_number('3150022')->is_valid_number, '茨城県石岡市行里川');
ok($zip->set_number('3150023')->is_valid_number, '茨城県石岡市東府中');
ok($zip->set_number('3150024')->is_valid_number, '茨城県石岡市八軒台');
ok($zip->set_number('3150025')->is_valid_number, '茨城県石岡市泉町');
ok($zip->set_number('3150026')->is_valid_number, '茨城県石岡市杉の井');
ok($zip->set_number('3150027')->is_valid_number, '茨城県石岡市杉並');
ok($zip->set_number('3150028')->is_valid_number, '茨城県石岡市半ノ木');
ok($zip->set_number('3150029')->is_valid_number, '茨城県石岡市根当');
ok($zip->set_number('3150030')->is_valid_number, '茨城県石岡市池の台');
ok($zip->set_number('3150031')->is_valid_number, '茨城県石岡市東大橋');
ok($zip->set_number('3150032')->is_valid_number, '茨城県石岡市小井戸');
ok($zip->set_number('3150033')->is_valid_number, '茨城県石岡市東光台');
ok($zip->set_number('3150034')->is_valid_number, '茨城県石岡市東田中');
ok($zip->set_number('3150035')->is_valid_number, '茨城県石岡市南台');
ok($zip->set_number('3150036')->is_valid_number, '茨城県石岡市大谷津');
ok($zip->set_number('3150037')->is_valid_number, '茨城県石岡市東石岡');
ok($zip->set_number('3150038')->is_valid_number, '茨城県石岡市旭台');
ok($zip->set_number('3150041')->is_valid_number, '茨城県石岡市田島');
ok($zip->set_number('3150042')->is_valid_number, '茨城県石岡市茨城');
ok($zip->set_number('3150043')->is_valid_number, '茨城県石岡市中津川');
ok($zip->set_number('3150044')->is_valid_number, '茨城県石岡市北根本');
ok($zip->set_number('3150045')->is_valid_number, '茨城県石岡市高浜');
ok($zip->set_number('3150046')->is_valid_number, '茨城県石岡市石川');
ok($zip->set_number('3150047')->is_valid_number, '茨城県石岡市井関');
ok($zip->set_number('3150048')->is_valid_number, '茨城県石岡市三村');
ok($zip->set_number('3150051')->is_valid_number, '茨城県かすみがうら市新治');
ok($zip->set_number('3150052')->is_valid_number, '茨城県かすみがうら市下稲吉');
ok($zip->set_number('3150053')->is_valid_number, '茨城県かすみがうら市稲吉東');
ok($zip->set_number('3150054')->is_valid_number, '茨城県かすみがうら市稲吉');
ok($zip->set_number('3150055')->is_valid_number, '茨城県かすみがうら市稲吉南');
ok($zip->set_number('3150056')->is_valid_number, '茨城県かすみがうら市上稲吉');
ok($zip->set_number('3150057')->is_valid_number, '茨城県かすみがうら市上土田');
ok($zip->set_number('3150058')->is_valid_number, '茨城県かすみがうら市下土田');
ok($zip->set_number('3150061')->is_valid_number, '茨城県かすみがうら市五反田');
ok($zip->set_number('3150062')->is_valid_number, '茨城県かすみがうら市横堀');
ok($zip->set_number('3150063')->is_valid_number, '茨城県かすみがうら市飯田');
ok($zip->set_number('3150064')->is_valid_number, '茨城県かすみがうら市大峰');
ok($zip->set_number('3150065')->is_valid_number, '茨城県かすみがうら市上佐谷');
ok($zip->set_number('3150066')->is_valid_number, '茨城県かすみがうら市中佐谷');
ok($zip->set_number('3150067')->is_valid_number, '茨城県かすみがうら市下佐谷');
ok($zip->set_number('3150068')->is_valid_number, '茨城県かすみがうら市山本');
ok($zip->set_number('3150069')->is_valid_number, '茨城県かすみがうら市雪入');
ok($zip->set_number('3150071')->is_valid_number, '茨城県かすみがうら市市川');
ok($zip->set_number('3150072')->is_valid_number, '茨城県かすみがうら市東野寺');
ok($zip->set_number('3150073')->is_valid_number, '茨城県かすみがうら市西野寺');
ok($zip->set_number('3150074')->is_valid_number, '茨城県かすみがうら市下志筑');
ok($zip->set_number('3150075')->is_valid_number, '茨城県かすみがうら市中志筑');
ok($zip->set_number('3150076')->is_valid_number, '茨城県かすみがうら市上志筑');
ok($zip->set_number('3150077')->is_valid_number, '茨城県かすみがうら市高倉');
ok($zip->set_number('3150078')->is_valid_number, '茨城県かすみがうら市粟田');
ok($zip->set_number('3150101')->is_valid_number, '茨城県石岡市大増');
ok($zip->set_number('3150102')->is_valid_number, '茨城県石岡市太田');
ok($zip->set_number('3150103')->is_valid_number, '茨城県石岡市中戸');
ok($zip->set_number('3150104')->is_valid_number, '茨城県石岡市小見');
ok($zip->set_number('3150105')->is_valid_number, '茨城県石岡市大塚');
ok($zip->set_number('3150111')->is_valid_number, '茨城県石岡市瓦谷');
ok($zip->set_number('3150112')->is_valid_number, '茨城県石岡市部原');
ok($zip->set_number('3150113')->is_valid_number, '茨城県石岡市片岡');
ok($zip->set_number('3150114')->is_valid_number, '茨城県石岡市嘉良寿理');
ok($zip->set_number('3150115')->is_valid_number, '茨城県石岡市浦須');
ok($zip->set_number('3150116')->is_valid_number, '茨城県石岡市柿岡');
ok($zip->set_number('3150117')->is_valid_number, '茨城県石岡市佐久');
ok($zip->set_number('3150118')->is_valid_number, '茨城県石岡市野田');
ok($zip->set_number('3150121')->is_valid_number, '茨城県石岡市真家');
ok($zip->set_number('3150122')->is_valid_number, '茨城県石岡市東成井');
ok($zip->set_number('3150123')->is_valid_number, '茨城県石岡市宮ケ崎');
ok($zip->set_number('3150124')->is_valid_number, '茨城県石岡市柴間');
ok($zip->set_number('3150125')->is_valid_number, '茨城県石岡市山崎');
ok($zip->set_number('3150131')->is_valid_number, '茨城県石岡市下林');
ok($zip->set_number('3150132')->is_valid_number, '茨城県石岡市根小屋');
ok($zip->set_number('3150133')->is_valid_number, '茨城県石岡市半田');
ok($zip->set_number('3150134')->is_valid_number, '茨城県石岡市川又');
ok($zip->set_number('3150135')->is_valid_number, '茨城県石岡市加生野');
ok($zip->set_number('3150136')->is_valid_number, '茨城県石岡市片野');
ok($zip->set_number('3150137')->is_valid_number, '茨城県石岡市金指');
ok($zip->set_number('3150138')->is_valid_number, '茨城県石岡市上林');
ok($zip->set_number('3150141')->is_valid_number, '茨城県石岡市月岡');
ok($zip->set_number('3150142')->is_valid_number, '茨城県石岡市弓弦');
ok($zip->set_number('3150143')->is_valid_number, '茨城県石岡市柴内');
ok($zip->set_number('3150144')->is_valid_number, '茨城県石岡市小野越');
ok($zip->set_number('3150145')->is_valid_number, '茨城県石岡市仏生寺');
ok($zip->set_number('3150146')->is_valid_number, '茨城県石岡市菖蒲沢');
ok($zip->set_number('3150147')->is_valid_number, '茨城県石岡市辻');
ok($zip->set_number('3150148')->is_valid_number, '茨城県石岡市青田');
ok($zip->set_number('3150151')->is_valid_number, '茨城県石岡市須釜');
ok($zip->set_number('3150152')->is_valid_number, '茨城県石岡市細谷');
ok($zip->set_number('3150153')->is_valid_number, '茨城県石岡市下青柳');
ok($zip->set_number('3150154')->is_valid_number, '茨城県石岡市上青柳');
ok($zip->set_number('3150155')->is_valid_number, '茨城県石岡市小幡');
ok($zip->set_number('3150156')->is_valid_number, '茨城県石岡市吉生');
ok($zip->set_number('3150157')->is_valid_number, '茨城県石岡市上曽');
ok($zip->set_number('3150161')->is_valid_number, '茨城県石岡市小塙');
ok($zip->set_number('3150162')->is_valid_number, '茨城県石岡市宇治会');
ok($zip->set_number('3150163')->is_valid_number, '茨城県石岡市鯨岡');
ok($zip->set_number('3150164')->is_valid_number, '茨城県石岡市小屋');
ok($zip->set_number('3150165')->is_valid_number, '茨城県石岡市小倉');
ok($zip->set_number('3150166')->is_valid_number, '茨城県石岡市小山田');
ok($zip->set_number('3150167')->is_valid_number, '茨城県石岡市龍明');
ok($zip->set_number('3160001')->is_valid_number, '茨城県日立市諏訪町');
ok($zip->set_number('3160002')->is_valid_number, '茨城県日立市桜川町');
ok($zip->set_number('3160003')->is_valid_number, '茨城県日立市多賀町');
ok($zip->set_number('3160004')->is_valid_number, '茨城県日立市東多賀町');
ok($zip->set_number('3160005')->is_valid_number, '茨城県日立市河原子町');
ok($zip->set_number('3160006')->is_valid_number, '茨城県日立市末広町');
ok($zip->set_number('3160007')->is_valid_number, '茨城県日立市中丸町');
ok($zip->set_number('3160011')->is_valid_number, '茨城県日立市塙山町');
ok($zip->set_number('3160012')->is_valid_number, '茨城県日立市大久保町');
ok($zip->set_number('3160013')->is_valid_number, '茨城県日立市千石町');
ok($zip->set_number('3160014')->is_valid_number, '茨城県日立市東金沢町');
ok($zip->set_number('3160015')->is_valid_number, '茨城県日立市金沢町');
ok($zip->set_number('3160021')->is_valid_number, '茨城県日立市台原町');
ok($zip->set_number('3160022')->is_valid_number, '茨城県日立市大沼町');
ok($zip->set_number('3160023')->is_valid_number, '茨城県日立市東大沼町');
ok($zip->set_number('3160024')->is_valid_number, '茨城県日立市水木町');
ok($zip->set_number('3160025')->is_valid_number, '茨城県日立市森山町');
ok($zip->set_number('3160026')->is_valid_number, '茨城県日立市みかの原町');
ok($zip->set_number('3160031')->is_valid_number, '茨城県日立市成沢町');
ok($zip->set_number('3160032')->is_valid_number, '茨城県日立市西成沢町');
ok($zip->set_number('3160033')->is_valid_number, '茨城県日立市中成沢町');
ok($zip->set_number('3160034')->is_valid_number, '茨城県日立市東成沢町');
ok($zip->set_number('3160035')->is_valid_number, '茨城県日立市国分町');
ok($zip->set_number('3160036')->is_valid_number, '茨城県日立市鮎川町');
ok($zip->set_number('3170000')->is_valid_number, '茨城県日立市以下に掲載がない場合');
ok($zip->set_number('3170051')->is_valid_number, '茨城県日立市滑川本町');
ok($zip->set_number('3170052')->is_valid_number, '茨城県日立市東滑川町');
ok($zip->set_number('3170053')->is_valid_number, '茨城県日立市滑川町');
ok($zip->set_number('3170054')->is_valid_number, '茨城県日立市本宮町');
ok($zip->set_number('3170055')->is_valid_number, '茨城県日立市宮田町');
ok($zip->set_number('3170056')->is_valid_number, '茨城県日立市白銀町');
ok($zip->set_number('3170061')->is_valid_number, '茨城県日立市東町');
ok($zip->set_number('3170062')->is_valid_number, '茨城県日立市平和町');
ok($zip->set_number('3170063')->is_valid_number, '茨城県日立市若葉町');
ok($zip->set_number('3170064')->is_valid_number, '茨城県日立市神峰町');
ok($zip->set_number('3170065')->is_valid_number, '茨城県日立市助川町');
ok($zip->set_number('3170066')->is_valid_number, '茨城県日立市高鈴町');
ok($zip->set_number('3170071')->is_valid_number, '茨城県日立市鹿島町');
ok($zip->set_number('3170072')->is_valid_number, '茨城県日立市弁天町');
ok($zip->set_number('3170073')->is_valid_number, '茨城県日立市幸町');
ok($zip->set_number('3170074')->is_valid_number, '茨城県日立市旭町');
ok($zip->set_number('3170075')->is_valid_number, '茨城県日立市相賀町');
ok($zip->set_number('3170076')->is_valid_number, '茨城県日立市会瀬町');
ok($zip->set_number('3170077')->is_valid_number, '茨城県日立市城南町');
ok($zip->set_number('3180000')->is_valid_number, '茨城県高萩市以下に掲載がない場合');
ok($zip->set_number('3180001')->is_valid_number, '茨城県高萩市赤浜');
ok($zip->set_number('3180002')->is_valid_number, '茨城県高萩市高戸');
ok($zip->set_number('3180003')->is_valid_number, '茨城県高萩市下手綱');
ok($zip->set_number('3180004')->is_valid_number, '茨城県高萩市上手綱');
ok($zip->set_number('3180005')->is_valid_number, '茨城県高萩市望海');
ok($zip->set_number('3180011')->is_valid_number, '茨城県高萩市肥前町');
ok($zip->set_number('3180012')->is_valid_number, '茨城県高萩市有明町');
ok($zip->set_number('3180013')->is_valid_number, '茨城県高萩市高浜町');
ok($zip->set_number('3180014')->is_valid_number, '茨城県高萩市東本町');
ok($zip->set_number('3180021')->is_valid_number, '茨城県高萩市安良川');
ok($zip->set_number('3180022')->is_valid_number, '茨城県高萩市石滝');
ok($zip->set_number('3180023')->is_valid_number, '茨城県高萩市島名');
ok($zip->set_number('3180024')->is_valid_number, '茨城県高萩市秋山');
ok($zip->set_number('3180025')->is_valid_number, '茨城県高萩市福平');
ok($zip->set_number('3180031')->is_valid_number, '茨城県高萩市春日町');
ok($zip->set_number('3180032')->is_valid_number, '茨城県高萩市大和町');
ok($zip->set_number('3180033')->is_valid_number, '茨城県高萩市本町');
ok($zip->set_number('3180034')->is_valid_number, '茨城県高萩市高萩');
ok($zip->set_number('3180101')->is_valid_number, '茨城県高萩市横川');
ok($zip->set_number('3180102')->is_valid_number, '茨城県高萩市若栗');
ok($zip->set_number('3180103')->is_valid_number, '茨城県高萩市大能');
ok($zip->set_number('3180104')->is_valid_number, '茨城県高萩市中戸川');
ok($zip->set_number('3180105')->is_valid_number, '茨城県高萩市上君田');
ok($zip->set_number('3180106')->is_valid_number, '茨城県高萩市下君田');
ok($zip->set_number('3190100')->is_valid_number, '茨城県小美玉市以下に掲載がない場合');
ok($zip->set_number('3190101')->is_valid_number, '茨城県小美玉市橋場美');
ok($zip->set_number('3190102')->is_valid_number, '茨城県小美玉市西郷地');
ok($zip->set_number('3190103')->is_valid_number, '茨城県小美玉市柴高');
ok($zip->set_number('3190104')->is_valid_number, '茨城県小美玉市三箇');
ok($zip->set_number('3190105')->is_valid_number, '茨城県小美玉市鶴田');
ok($zip->set_number('3190106')->is_valid_number, '茨城県小美玉市堅倉');
ok($zip->set_number('3190107')->is_valid_number, '茨城県小美玉市小岩戸');
ok($zip->set_number('3190108')->is_valid_number, '茨城県小美玉市先後');
ok($zip->set_number('3190111')->is_valid_number, '茨城県小美玉市中野谷');
ok($zip->set_number('3190112')->is_valid_number, '茨城県小美玉市竹原下郷');
ok($zip->set_number('3190113')->is_valid_number, '茨城県小美玉市竹原');
ok($zip->set_number('3190114')->is_valid_number, '茨城県小美玉市竹原中郷');
ok($zip->set_number('3190115')->is_valid_number, '茨城県小美玉市上馬場');
ok($zip->set_number('3190116')->is_valid_number, '茨城県小美玉市中台');
ok($zip->set_number('3190121')->is_valid_number, '茨城県小美玉市羽刈');
ok($zip->set_number('3190122')->is_valid_number, '茨城県小美玉市江戸');
ok($zip->set_number('3190123')->is_valid_number, '茨城県小美玉市羽鳥');
ok($zip->set_number('3190124')->is_valid_number, '茨城県小美玉市花野井');
ok($zip->set_number('3190125')->is_valid_number, '茨城県小美玉市小曽納');
ok($zip->set_number('3190126')->is_valid_number, '茨城県小美玉市大谷');
ok($zip->set_number('3190131')->is_valid_number, '茨城県小美玉市寺崎');
ok($zip->set_number('3190132')->is_valid_number, '茨城県小美玉市部室');
ok($zip->set_number('3190133')->is_valid_number, '茨城県小美玉市張星');
ok($zip->set_number('3190134')->is_valid_number, '茨城県小美玉市納場');
ok($zip->set_number('3190135')->is_valid_number, '茨城県小美玉市高田');
ok($zip->set_number('3190136')->is_valid_number, '茨城県小美玉市手堤');
ok($zip->set_number('3190137')->is_valid_number, '茨城県小美玉市大笹');
ok($zip->set_number('3190201')->is_valid_number, '茨城県笠間市上郷');
ok($zip->set_number('3190202')->is_valid_number, '茨城県笠間市下郷');
ok($zip->set_number('3190203')->is_valid_number, '茨城県笠間市吉岡');
ok($zip->set_number('3190204')->is_valid_number, '茨城県笠間市土師');
ok($zip->set_number('3190205')->is_valid_number, '茨城県笠間市押辺');
ok($zip->set_number('3190206')->is_valid_number, '茨城県笠間市安居');
ok($zip->set_number('3190207')->is_valid_number, '茨城県笠間市福島');
ok($zip->set_number('3190208')->is_valid_number, '茨城県笠間市市野谷');
ok($zip->set_number('3190209')->is_valid_number, '茨城県笠間市泉');
ok($zip->set_number('3190211')->is_valid_number, '茨城県笠間市泉市野谷入会地');
ok($zip->set_number('3190301')->is_valid_number, '茨城県水戸市田島町');
ok($zip->set_number('3190302')->is_valid_number, '茨城県水戸市三野輪町');
ok($zip->set_number('3190303')->is_valid_number, '茨城県水戸市黒磯町');
ok($zip->set_number('3190304')->is_valid_number, '茨城県水戸市有賀町');
ok($zip->set_number('3190305')->is_valid_number, '茨城県水戸市中原町');
ok($zip->set_number('3190306')->is_valid_number, '茨城県水戸市杉崎町');
ok($zip->set_number('3190307')->is_valid_number, '茨城県水戸市小原町');
ok($zip->set_number('3190311')->is_valid_number, '茨城県水戸市牛伏町');
ok($zip->set_number('3190312')->is_valid_number, '茨城県水戸市大足町');
ok($zip->set_number('3190313')->is_valid_number, '茨城県水戸市筑地町');
ok($zip->set_number('3190314')->is_valid_number, '茨城県水戸市赤尾関町');
ok($zip->set_number('3190315')->is_valid_number, '茨城県水戸市内原町');
ok($zip->set_number('3190316')->is_valid_number, '茨城県水戸市三湯町');
ok($zip->set_number('3190317')->is_valid_number, '茨城県水戸市内原');
ok($zip->set_number('3190321')->is_valid_number, '茨城県水戸市高田町');
ok($zip->set_number('3190322')->is_valid_number, '茨城県水戸市下野町');
ok($zip->set_number('3190323')->is_valid_number, '茨城県水戸市鯉淵町');
ok($zip->set_number('3190324')->is_valid_number, '茨城県水戸市五平町');
ok($zip->set_number('3190325')->is_valid_number, '茨城県水戸市小林町');
ok($zip->set_number('3191100')->is_valid_number, '茨城県那珂郡東海村以下に掲載がない場合');
ok($zip->set_number('3191101')->is_valid_number, '茨城県那珂郡東海村石神外宿');
ok($zip->set_number('3191102')->is_valid_number, '茨城県那珂郡東海村石神内宿');
ok($zip->set_number('3191103')->is_valid_number, '茨城県那珂郡東海村竹瓦');
ok($zip->set_number('3191104')->is_valid_number, '茨城県那珂郡東海村亀下');
ok($zip->set_number('3191105')->is_valid_number, '茨城県那珂郡東海村豊岡');
ok($zip->set_number('3191106')->is_valid_number, '茨城県那珂郡東海村白方');
ok($zip->set_number('3191107')->is_valid_number, '茨城県那珂郡東海村豊白');
ok($zip->set_number('3191108')->is_valid_number, '茨城県那珂郡東海村村松北');
ok($zip->set_number('3191109')->is_valid_number, '茨城県那珂郡東海村白方中央');
ok($zip->set_number('3191111')->is_valid_number, '茨城県那珂郡東海村舟石川');
ok($zip->set_number('3191112')->is_valid_number, '茨城県那珂郡東海村村松');
ok($zip->set_number('3191113')->is_valid_number, '茨城県那珂郡東海村照沼');
ok($zip->set_number('3191114')->is_valid_number, '茨城県那珂郡東海村須和間');
ok($zip->set_number('3191115')->is_valid_number, '茨城県那珂郡東海村船場');
ok($zip->set_number('3191116')->is_valid_number, '茨城県那珂郡東海村舟石川駅西');
ok($zip->set_number('3191117')->is_valid_number, '茨城県那珂郡東海村東海');
ok($zip->set_number('3191118')->is_valid_number, '茨城県那珂郡東海村舟石川駅東');
ok($zip->set_number('3191119')->is_valid_number, '茨城県那珂郡東海村大山台');
ok($zip->set_number('3191221')->is_valid_number, '茨城県日立市大みか町');
ok($zip->set_number('3191222')->is_valid_number, '茨城県日立市久慈町');
ok($zip->set_number('3191223')->is_valid_number, '茨城県日立市みなと町');
ok($zip->set_number('3191224')->is_valid_number, '茨城県日立市南高野町');
ok($zip->set_number('3191225')->is_valid_number, '茨城県日立市石名坂町');
ok($zip->set_number('3191231')->is_valid_number, '茨城県日立市留町');
ok($zip->set_number('3191232')->is_valid_number, '茨城県日立市下土木内町');
ok($zip->set_number('3191233')->is_valid_number, '茨城県日立市神田町');
ok($zip->set_number('3191234')->is_valid_number, '茨城県日立市大和田町');
ok($zip->set_number('3191235')->is_valid_number, '茨城県日立市茂宮町');
ok($zip->set_number('3191301')->is_valid_number, '茨城県日立市十王町伊師');
ok($zip->set_number('3191302')->is_valid_number, '茨城県日立市十王町伊師本郷');
ok($zip->set_number('3191303')->is_valid_number, '茨城県日立市十王町友部東');
ok($zip->set_number('3191304')->is_valid_number, '茨城県日立市十王町友部');
ok($zip->set_number('3191305')->is_valid_number, '茨城県日立市十王町高原');
ok($zip->set_number('3191306')->is_valid_number, '茨城県日立市十王町黒坂');
ok($zip->set_number('3191307')->is_valid_number, '茨城県日立市十王町山部');
ok($zip->set_number('3191308')->is_valid_number, '茨城県日立市十王町城の丘');
ok($zip->set_number('3191411')->is_valid_number, '茨城県日立市川尻町');
ok($zip->set_number('3191412')->is_valid_number, '茨城県日立市折笠町');
ok($zip->set_number('3191413')->is_valid_number, '茨城県日立市小木津町');
ok($zip->set_number('3191414')->is_valid_number, '茨城県日立市日高町');
ok($zip->set_number('3191415')->is_valid_number, '茨城県日立市相田町');
ok($zip->set_number('3191416')->is_valid_number, '茨城県日立市田尻町');
ok($zip->set_number('3191417')->is_valid_number, '茨城県日立市かみあい町');
ok($zip->set_number('3191418')->is_valid_number, '茨城県日立市砂沢町');
ok($zip->set_number('3191500')->is_valid_number, '茨城県北茨城市以下に掲載がない場合');
ok($zip->set_number('3191531')->is_valid_number, '茨城県北茨城市華川町花園');
ok($zip->set_number('3191532')->is_valid_number, '茨城県北茨城市華川町上小津田');
ok($zip->set_number('3191533')->is_valid_number, '茨城県北茨城市華川町下小津田');
ok($zip->set_number('3191534')->is_valid_number, '茨城県北茨城市華川町車');
ok($zip->set_number('3191535')->is_valid_number, '茨城県北茨城市華川町臼場');
ok($zip->set_number('3191536')->is_valid_number, '茨城県北茨城市華川町中妻');
ok($zip->set_number('3191537')->is_valid_number, '茨城県北茨城市華川町下相田');
ok($zip->set_number('3191538')->is_valid_number, '茨城県北茨城市華川町小豆畑');
ok($zip->set_number('3191541')->is_valid_number, '茨城県北茨城市磯原町磯原');
ok($zip->set_number('3191542')->is_valid_number, '茨城県北茨城市磯原町本町');
ok($zip->set_number('3191543')->is_valid_number, '茨城県北茨城市磯原町豊田');
ok($zip->set_number('3191544')->is_valid_number, '茨城県北茨城市磯原町上相田');
ok($zip->set_number('3191545')->is_valid_number, '茨城県北茨城市磯原町木皿');
ok($zip->set_number('3191546')->is_valid_number, '茨城県北茨城市磯原町大塚');
ok($zip->set_number('3191547')->is_valid_number, '茨城県北茨城市磯原町内野');
ok($zip->set_number('3191551')->is_valid_number, '茨城県北茨城市中郷町下桜井');
ok($zip->set_number('3191552')->is_valid_number, '茨城県北茨城市中郷町足洗');
ok($zip->set_number('3191553')->is_valid_number, '茨城県北茨城市中郷町汐見ケ丘');
ok($zip->set_number('3191554')->is_valid_number, '茨城県北茨城市中郷町粟野');
ok($zip->set_number('3191555')->is_valid_number, '茨城県北茨城市中郷町小野矢指');
ok($zip->set_number('3191556')->is_valid_number, '茨城県北茨城市中郷町日棚');
ok($zip->set_number('3191557')->is_valid_number, '茨城県北茨城市中郷町松井');
ok($zip->set_number('3191558')->is_valid_number, '茨城県北茨城市中郷町石岡');
ok($zip->set_number('3191559')->is_valid_number, '茨城県北茨城市中郷町上桜井');
ok($zip->set_number('3191701')->is_valid_number, '茨城県北茨城市平潟町');
ok($zip->set_number('3191702')->is_valid_number, '茨城県北茨城市大津町');
ok($zip->set_number('3191703')->is_valid_number, '茨城県北茨城市大津町五浦');
ok($zip->set_number('3191704')->is_valid_number, '茨城県北茨城市大津町北町');
ok($zip->set_number('3191711')->is_valid_number, '茨城県北茨城市関南町関本下');
ok($zip->set_number('3191712')->is_valid_number, '茨城県北茨城市関南町里根川');
ok($zip->set_number('3191713')->is_valid_number, '茨城県北茨城市関南町仁井田');
ok($zip->set_number('3191714')->is_valid_number, '茨城県北茨城市関南町神岡上');
ok($zip->set_number('3191715')->is_valid_number, '茨城県北茨城市関南町神岡下');
ok($zip->set_number('3191721')->is_valid_number, '茨城県北茨城市関本町関本上');
ok($zip->set_number('3191722')->is_valid_number, '茨城県北茨城市関本町福田');
ok($zip->set_number('3191723')->is_valid_number, '茨城県北茨城市関本町関本中');
ok($zip->set_number('3191724')->is_valid_number, '茨城県北茨城市関本町八反');
ok($zip->set_number('3191725')->is_valid_number, '茨城県北茨城市関本町富士ケ丘');
ok($zip->set_number('3191726')->is_valid_number, '茨城県北茨城市関本町才丸');
ok($zip->set_number('3191727')->is_valid_number, '茨城県北茨城市関本町小川');
ok($zip->set_number('3192102')->is_valid_number, '茨城県那珂市瓜連');
ok($zip->set_number('3192103')->is_valid_number, '茨城県那珂市中里');
ok($zip->set_number('3192104')->is_valid_number, '茨城県那珂市平野');
ok($zip->set_number('3192105')->is_valid_number, '茨城県那珂市古徳');
ok($zip->set_number('3192106')->is_valid_number, '茨城県那珂市静');
ok($zip->set_number('3192107')->is_valid_number, '茨城県那珂市下大賀');
ok($zip->set_number('3192131')->is_valid_number, '茨城県常陸大宮市下村田');
ok($zip->set_number('3192132')->is_valid_number, '茨城県常陸大宮市小場');
ok($zip->set_number('3192133')->is_valid_number, '茨城県常陸大宮市小野');
ok($zip->set_number('3192134')->is_valid_number, '茨城県常陸大宮市工業団地');
ok($zip->set_number('3192135')->is_valid_number, '茨城県常陸大宮市石沢');
ok($zip->set_number('3192136')->is_valid_number, '茨城県常陸大宮市上村田');
ok($zip->set_number('3192141')->is_valid_number, '茨城県常陸大宮市下岩瀬');
ok($zip->set_number('3192142')->is_valid_number, '茨城県常陸大宮市上岩瀬');
ok($zip->set_number('3192143')->is_valid_number, '茨城県常陸大宮市根本');
ok($zip->set_number('3192144')->is_valid_number, '茨城県常陸大宮市泉');
ok($zip->set_number('3192145')->is_valid_number, '茨城県常陸大宮市宇留野');
ok($zip->set_number('3192200')->is_valid_number, '茨城県常陸大宮市以下に掲載がない場合');
ok($zip->set_number('3192201')->is_valid_number, '茨城県常陸大宮市辰ノ口');
ok($zip->set_number('3192202')->is_valid_number, '茨城県常陸大宮市塩原');
ok($zip->set_number('3192203')->is_valid_number, '茨城県常陸大宮市小倉');
ok($zip->set_number('3192204')->is_valid_number, '茨城県常陸大宮市富岡');
ok($zip->set_number('3192205')->is_valid_number, '茨城県常陸大宮市宮の郷');
ok($zip->set_number('3192211')->is_valid_number, '茨城県常陸大宮市岩崎');
ok($zip->set_number('3192212')->is_valid_number, '茨城県常陸大宮市上大賀');
ok($zip->set_number('3192213')->is_valid_number, '茨城県常陸大宮市小祝');
ok($zip->set_number('3192214')->is_valid_number, '茨城県常陸大宮市鷹巣');
ok($zip->set_number('3192221')->is_valid_number, '茨城県常陸大宮市八田');
ok($zip->set_number('3192222')->is_valid_number, '茨城県常陸大宮市若林');
ok($zip->set_number('3192223')->is_valid_number, '茨城県常陸大宮市三美');
ok($zip->set_number('3192224')->is_valid_number, '茨城県常陸大宮市東野');
ok($zip->set_number('3192225')->is_valid_number, '茨城県常陸大宮市西塩子');
ok($zip->set_number('3192226')->is_valid_number, '茨城県常陸大宮市北塩子');
ok($zip->set_number('3192227')->is_valid_number, '茨城県常陸大宮市照田(917~1490番地)');
ok($zip->set_number('3192251')->is_valid_number, '茨城県常陸大宮市姥賀町');
ok($zip->set_number('3192252')->is_valid_number, '茨城県常陸大宮市東富町');
ok($zip->set_number('3192253')->is_valid_number, '茨城県常陸大宮市高渡町');
ok($zip->set_number('3192254')->is_valid_number, '茨城県常陸大宮市北町');
ok($zip->set_number('3192255')->is_valid_number, '茨城県常陸大宮市野中町');
ok($zip->set_number('3192256')->is_valid_number, '茨城県常陸大宮市田子内町');
ok($zip->set_number('3192261')->is_valid_number, '茨城県常陸大宮市上町');
ok($zip->set_number('3192262')->is_valid_number, '茨城県常陸大宮市下町');
ok($zip->set_number('3192263')->is_valid_number, '茨城県常陸大宮市南町');
ok($zip->set_number('3192264')->is_valid_number, '茨城県常陸大宮市栄町');
ok($zip->set_number('3192265')->is_valid_number, '茨城県常陸大宮市中富町');
ok($zip->set_number('3192266')->is_valid_number, '茨城県常陸大宮市抽ケ台町');
ok($zip->set_number('3192401')->is_valid_number, '茨城県常陸大宮市上小瀬');
ok($zip->set_number('3192402')->is_valid_number, '茨城県常陸大宮市下小瀬');
ok($zip->set_number('3192403')->is_valid_number, '茨城県常陸大宮市那賀');
ok($zip->set_number('3192404')->is_valid_number, '茨城県常陸大宮市国長');
ok($zip->set_number('3192405')->is_valid_number, '茨城県常陸大宮市小玉');
ok($zip->set_number('3192411')->is_valid_number, '茨城県常陸大宮市小舟');
ok($zip->set_number('3192412')->is_valid_number, '茨城県常陸大宮市小瀬沢');
ok($zip->set_number('3192413')->is_valid_number, '茨城県常陸大宮市松之草');
ok($zip->set_number('3192414')->is_valid_number, '茨城県常陸大宮市吉丸');
ok($zip->set_number('3192415')->is_valid_number, '茨城県常陸大宮市入本郷');
ok($zip->set_number('3192416')->is_valid_number, '茨城県常陸大宮市千田');
ok($zip->set_number('3192417')->is_valid_number, '茨城県常陸大宮市油河内');
ok($zip->set_number('3192418')->is_valid_number, '茨城県常陸大宮市大岩');
ok($zip->set_number('3192511')->is_valid_number, '茨城県常陸大宮市上檜沢');
ok($zip->set_number('3192512')->is_valid_number, '茨城県常陸大宮市下檜沢');
ok($zip->set_number('3192513')->is_valid_number, '茨城県常陸大宮市氷之沢');
ok($zip->set_number('3192601')->is_valid_number, '茨城県常陸大宮市高部');
ok($zip->set_number('3192602')->is_valid_number, '茨城県常陸大宮市小田野');
ok($zip->set_number('3192603')->is_valid_number, '茨城県常陸大宮市鷲子');
ok($zip->set_number('3193101')->is_valid_number, '茨城県常陸大宮市久隆');
ok($zip->set_number('3193102')->is_valid_number, '茨城県常陸大宮市盛金');
ok($zip->set_number('3193103')->is_valid_number, '茨城県常陸大宮市家和楽');
ok($zip->set_number('3193104')->is_valid_number, '茨城県常陸大宮市北富田');
ok($zip->set_number('3193105')->is_valid_number, '茨城県常陸大宮市諸沢');
ok($zip->set_number('3193106')->is_valid_number, '茨城県常陸大宮市西野内');
ok($zip->set_number('3193107')->is_valid_number, '茨城県常陸大宮市舟生');
ok($zip->set_number('3193111')->is_valid_number, '茨城県常陸大宮市山方');
ok($zip->set_number('3193112')->is_valid_number, '茨城県常陸大宮市小貫');
ok($zip->set_number('3193113')->is_valid_number, '茨城県常陸大宮市照山');
ok($zip->set_number('3193114')->is_valid_number, '茨城県常陸大宮市野上');
ok($zip->set_number('3193115')->is_valid_number, '茨城県常陸大宮市照田(その他)');
ok($zip->set_number('3193116')->is_valid_number, '茨城県常陸大宮市長田');
ok($zip->set_number('3193117')->is_valid_number, '茨城県常陸大宮市長沢');
ok($zip->set_number('3193361')->is_valid_number, '茨城県久慈郡大子町頃藤');
ok($zip->set_number('3193362')->is_valid_number, '茨城県久慈郡大子町西金');
ok($zip->set_number('3193363')->is_valid_number, '茨城県久慈郡大子町北富田');
ok($zip->set_number('3193364')->is_valid_number, '茨城県久慈郡大子町盛金');
ok($zip->set_number('3193365')->is_valid_number, '茨城県久慈郡大子町栃原');
ok($zip->set_number('3193366')->is_valid_number, '茨城県久慈郡大子町大沢');
ok($zip->set_number('3193500')->is_valid_number, '茨城県久慈郡大子町以下に掲載がない場合');
ok($zip->set_number('3193511')->is_valid_number, '茨城県久慈郡大子町高柴');
ok($zip->set_number('3193512')->is_valid_number, '茨城県久慈郡大子町小生瀬');
ok($zip->set_number('3193513')->is_valid_number, '茨城県久慈郡大子町大生瀬');
ok($zip->set_number('3193514')->is_valid_number, '茨城県久慈郡大子町外大野');
ok($zip->set_number('3193515')->is_valid_number, '茨城県久慈郡大子町内大野');
ok($zip->set_number('3193521')->is_valid_number, '茨城県久慈郡大子町北田気');
ok($zip->set_number('3193522')->is_valid_number, '茨城県久慈郡大子町久野瀬');
ok($zip->set_number('3193523')->is_valid_number, '茨城県久慈郡大子町袋田');
ok($zip->set_number('3193524')->is_valid_number, '茨城県久慈郡大子町下津原');
ok($zip->set_number('3193525')->is_valid_number, '茨城県久慈郡大子町南田気');
ok($zip->set_number('3193526')->is_valid_number, '茨城県久慈郡大子町大子');
ok($zip->set_number('3193531')->is_valid_number, '茨城県久慈郡大子町上岡');
ok($zip->set_number('3193532')->is_valid_number, '茨城県久慈郡大子町山田');
ok($zip->set_number('3193533')->is_valid_number, '茨城県久慈郡大子町下金沢');
ok($zip->set_number('3193534')->is_valid_number, '茨城県久慈郡大子町相川');
ok($zip->set_number('3193535')->is_valid_number, '茨城県久慈郡大子町上金沢');
ok($zip->set_number('3193536')->is_valid_number, '茨城県久慈郡大子町田野沢');
ok($zip->set_number('3193537')->is_valid_number, '茨城県久慈郡大子町塙');
ok($zip->set_number('3193538')->is_valid_number, '茨城県久慈郡大子町芦野倉');
ok($zip->set_number('3193541')->is_valid_number, '茨城県久慈郡大子町浅川');
ok($zip->set_number('3193542')->is_valid_number, '茨城県久慈郡大子町初原');
ok($zip->set_number('3193543')->is_valid_number, '茨城県久慈郡大子町左貫');
ok($zip->set_number('3193544')->is_valid_number, '茨城県久慈郡大子町槇野地');
ok($zip->set_number('3193551')->is_valid_number, '茨城県久慈郡大子町池田');
ok($zip->set_number('3193552')->is_valid_number, '茨城県久慈郡大子町矢田');
ok($zip->set_number('3193553')->is_valid_number, '茨城県久慈郡大子町冥賀');
ok($zip->set_number('3193554')->is_valid_number, '茨城県久慈郡大子町高田');
ok($zip->set_number('3193555')->is_valid_number, '茨城県久慈郡大子町下野宮');
ok($zip->set_number('3193556')->is_valid_number, '茨城県久慈郡大子町川山');
ok($zip->set_number('3193701')->is_valid_number, '茨城県久慈郡大子町北吉沢');
ok($zip->set_number('3193702')->is_valid_number, '茨城県久慈郡大子町町付');
ok($zip->set_number('3193703')->is_valid_number, '茨城県久慈郡大子町上郷');
ok($zip->set_number('3193704')->is_valid_number, '茨城県久慈郡大子町上野宮');
ok($zip->set_number('3193705')->is_valid_number, '茨城県久慈郡大子町中郷');
ok($zip->set_number('3200001')->is_valid_number, '栃木県宇都宮市横山町');
ok($zip->set_number('3200002')->is_valid_number, '栃木県宇都宮市瓦谷町');
ok($zip->set_number('3200003')->is_valid_number, '栃木県宇都宮市豊郷台');
ok($zip->set_number('3200004')->is_valid_number, '栃木県宇都宮市長岡町');
ok($zip->set_number('3200005')->is_valid_number, '栃木県宇都宮市横山');
ok($zip->set_number('3200011')->is_valid_number, '栃木県宇都宮市富士見が丘');
ok($zip->set_number('3200012')->is_valid_number, '栃木県宇都宮市山本');
ok($zip->set_number('3200013')->is_valid_number, '栃木県宇都宮市上大曽町');
ok($zip->set_number('3200014')->is_valid_number, '栃木県宇都宮市大曽');
ok($zip->set_number('3200015')->is_valid_number, '栃木県宇都宮市八幡台');
ok($zip->set_number('3200016')->is_valid_number, '栃木県宇都宮市山本町');
ok($zip->set_number('3200017')->is_valid_number, '栃木県宇都宮市戸祭台');
ok($zip->set_number('3200021')->is_valid_number, '栃木県宇都宮市東塙田');
ok($zip->set_number('3200022')->is_valid_number, '栃木県宇都宮市千波町');
ok($zip->set_number('3200023')->is_valid_number, '栃木県宇都宮市仲町');
ok($zip->set_number('3200024')->is_valid_number, '栃木県宇都宮市栄町');
ok($zip->set_number('3200025')->is_valid_number, '栃木県宇都宮市宮町');
ok($zip->set_number('3200026')->is_valid_number, '栃木県宇都宮市馬場通り');
ok($zip->set_number('3200027')->is_valid_number, '栃木県宇都宮市塙田');
ok($zip->set_number('3200031')->is_valid_number, '栃木県宇都宮市戸祭元町');
ok($zip->set_number('3200032')->is_valid_number, '栃木県宇都宮市昭和');
ok($zip->set_number('3200033')->is_valid_number, '栃木県宇都宮市本町');
ok($zip->set_number('3200034')->is_valid_number, '栃木県宇都宮市泉町');
ok($zip->set_number('3200035')->is_valid_number, '栃木県宇都宮市伝馬町');
ok($zip->set_number('3200036')->is_valid_number, '栃木県宇都宮市小幡');
ok($zip->set_number('3200037')->is_valid_number, '栃木県宇都宮市清住');
ok($zip->set_number('3200038')->is_valid_number, '栃木県宇都宮市星が丘');
ok($zip->set_number('3200041')->is_valid_number, '栃木県宇都宮市松原');
ok($zip->set_number('3200042')->is_valid_number, '栃木県宇都宮市材木町');
ok($zip->set_number('3200043')->is_valid_number, '栃木県宇都宮市桜');
ok($zip->set_number('3200044')->is_valid_number, '栃木県宇都宮市南一の沢町');
ok($zip->set_number('3200045')->is_valid_number, '栃木県宇都宮市中一の沢町');
ok($zip->set_number('3200046')->is_valid_number, '栃木県宇都宮市西一の沢町');
ok($zip->set_number('3200047')->is_valid_number, '栃木県宇都宮市一の沢');
ok($zip->set_number('3200048')->is_valid_number, '栃木県宇都宮市北一の沢町');
ok($zip->set_number('3200049')->is_valid_number, '栃木県宇都宮市一ノ沢町');
ok($zip->set_number('3200051')->is_valid_number, '栃木県宇都宮市上戸祭町');
ok($zip->set_number('3200052')->is_valid_number, '栃木県宇都宮市中戸祭町');
ok($zip->set_number('3200053')->is_valid_number, '栃木県宇都宮市戸祭町');
ok($zip->set_number('3200054')->is_valid_number, '栃木県宇都宮市東戸祭');
ok($zip->set_number('3200055')->is_valid_number, '栃木県宇都宮市下戸祭');
ok($zip->set_number('3200056')->is_valid_number, '栃木県宇都宮市戸祭');
ok($zip->set_number('3200057')->is_valid_number, '栃木県宇都宮市中戸祭');
ok($zip->set_number('3200058')->is_valid_number, '栃木県宇都宮市上戸祭');
ok($zip->set_number('3200061')->is_valid_number, '栃木県宇都宮市宝木町');
ok($zip->set_number('3200062')->is_valid_number, '栃木県宇都宮市東宝木町');
ok($zip->set_number('3200063')->is_valid_number, '栃木県宇都宮市陽西町');
ok($zip->set_number('3200064')->is_valid_number, '栃木県宇都宮市西の宮');
ok($zip->set_number('3200065')->is_valid_number, '栃木県宇都宮市駒生町');
ok($zip->set_number('3200066')->is_valid_number, '栃木県宇都宮市駒生');
ok($zip->set_number('3200071')->is_valid_number, '栃木県宇都宮市野沢町');
ok($zip->set_number('3200072')->is_valid_number, '栃木県宇都宮市若草');
ok($zip->set_number('3200073')->is_valid_number, '栃木県宇都宮市細谷');
ok($zip->set_number('3200074')->is_valid_number, '栃木県宇都宮市細谷町');
ok($zip->set_number('3200075')->is_valid_number, '栃木県宇都宮市宝木本町');
ok($zip->set_number('3200801')->is_valid_number, '栃木県宇都宮市池上町');
ok($zip->set_number('3200802')->is_valid_number, '栃木県宇都宮市江野町');
ok($zip->set_number('3200803')->is_valid_number, '栃木県宇都宮市曲師町');
ok($zip->set_number('3200804')->is_valid_number, '栃木県宇都宮市二荒町');
ok($zip->set_number('3200805')->is_valid_number, '栃木県宇都宮市中央本町');
ok($zip->set_number('3200806')->is_valid_number, '栃木県宇都宮市中央');
ok($zip->set_number('3200807')->is_valid_number, '栃木県宇都宮市松が峰');
ok($zip->set_number('3200808')->is_valid_number, '栃木県宇都宮市宮園町');
ok($zip->set_number('3200811')->is_valid_number, '栃木県宇都宮市大通り');
ok($zip->set_number('3200812')->is_valid_number, '栃木県宇都宮市一番町');
ok($zip->set_number('3200813')->is_valid_number, '栃木県宇都宮市二番町');
ok($zip->set_number('3200814')->is_valid_number, '栃木県宇都宮市三番町');
ok($zip->set_number('3200815')->is_valid_number, '栃木県宇都宮市中河原町');
ok($zip->set_number('3200816')->is_valid_number, '栃木県宇都宮市天神');
ok($zip->set_number('3200817')->is_valid_number, '栃木県宇都宮市本丸町');
ok($zip->set_number('3200818')->is_valid_number, '栃木県宇都宮市旭');
ok($zip->set_number('3200821')->is_valid_number, '栃木県宇都宮市一条');
ok($zip->set_number('3200822')->is_valid_number, '栃木県宇都宮市河原町');
ok($zip->set_number('3200823')->is_valid_number, '栃木県宇都宮市御蔵町');
ok($zip->set_number('3200824')->is_valid_number, '栃木県宇都宮市下河原');
ok($zip->set_number('3200825')->is_valid_number, '栃木県宇都宮市下河原町');
ok($zip->set_number('3200826')->is_valid_number, '栃木県宇都宮市西原町');
ok($zip->set_number('3200827')->is_valid_number, '栃木県宇都宮市花房');
ok($zip->set_number('3200828')->is_valid_number, '栃木県宇都宮市花房本町');
ok($zip->set_number('3200831')->is_valid_number, '栃木県宇都宮市新町');
ok($zip->set_number('3200832')->is_valid_number, '栃木県宇都宮市日の出');
ok($zip->set_number('3200833')->is_valid_number, '栃木県宇都宮市不動前');
ok($zip->set_number('3200834')->is_valid_number, '栃木県宇都宮市陽南');
ok($zip->set_number('3200835')->is_valid_number, '栃木県宇都宮市宮原');
ok($zip->set_number('3200836')->is_valid_number, '栃木県宇都宮市大和(3丁目)');
ok($zip->set_number('3200837')->is_valid_number, '栃木県宇都宮市弥生');
ok($zip->set_number('3200838')->is_valid_number, '栃木県宇都宮市吉野');
ok($zip->set_number('3200841')->is_valid_number, '栃木県宇都宮市六道町');
ok($zip->set_number('3200842')->is_valid_number, '栃木県宇都宮市京町');
ok($zip->set_number('3200843')->is_valid_number, '栃木県宇都宮市花園町');
ok($zip->set_number('3200844')->is_valid_number, '栃木県宇都宮市菊水町');
ok($zip->set_number('3200845')->is_valid_number, '栃木県宇都宮市明保野町');
ok($zip->set_number('3200846')->is_valid_number, '栃木県宇都宮市滝の原');
ok($zip->set_number('3200847')->is_valid_number, '栃木県宇都宮市滝谷町');
ok($zip->set_number('3200848')->is_valid_number, '栃木県宇都宮市幸町');
ok($zip->set_number('3200851')->is_valid_number, '栃木県宇都宮市鶴田町');
ok($zip->set_number('3200852')->is_valid_number, '栃木県宇都宮市下砥上町');
ok($zip->set_number('3200853')->is_valid_number, '栃木県宇都宮市下欠町');
ok($zip->set_number('3200854')->is_valid_number, '栃木県宇都宮市鷺の谷町');
ok($zip->set_number('3200855')->is_valid_number, '栃木県宇都宮市上欠町');
ok($zip->set_number('3200856')->is_valid_number, '栃木県宇都宮市砥上町');
ok($zip->set_number('3200857')->is_valid_number, '栃木県宇都宮市鶴田');
ok($zip->set_number('3200861')->is_valid_number, '栃木県宇都宮市西');
ok($zip->set_number('3200862')->is_valid_number, '栃木県宇都宮市西原');
ok($zip->set_number('3200863')->is_valid_number, '栃木県宇都宮市操町');
ok($zip->set_number('3200864')->is_valid_number, '栃木県宇都宮市住吉町');
ok($zip->set_number('3200865')->is_valid_number, '栃木県宇都宮市睦町');
ok($zip->set_number('3200866')->is_valid_number, '栃木県宇都宮市西大寛');
ok($zip->set_number('3200867')->is_valid_number, '栃木県宇都宮市大寛');
ok($zip->set_number('3210000')->is_valid_number, '栃木県宇都宮市以下に掲載がない場合');
ok($zip->set_number('3210101')->is_valid_number, '栃木県宇都宮市江曽島本町');
ok($zip->set_number('3210102')->is_valid_number, '栃木県宇都宮市江曽島町');
ok($zip->set_number('3210103')->is_valid_number, '栃木県宇都宮市台新田町');
ok($zip->set_number('3210104')->is_valid_number, '栃木県宇都宮市台新田');
ok($zip->set_number('3210105')->is_valid_number, '栃木県宇都宮市横田新町');
ok($zip->set_number('3210106')->is_valid_number, '栃木県宇都宮市上横田町');
ok($zip->set_number('3210107')->is_valid_number, '栃木県宇都宮市江曽島');
ok($zip->set_number('3210108')->is_valid_number, '栃木県宇都宮市春日町');
ok($zip->set_number('3210111')->is_valid_number, '栃木県宇都宮市川田町');
ok($zip->set_number('3210112')->is_valid_number, '栃木県宇都宮市屋板町');
ok($zip->set_number('3210113')->is_valid_number, '栃木県宇都宮市砂田町');
ok($zip->set_number('3210114')->is_valid_number, '栃木県宇都宮市中島町');
ok($zip->set_number('3210115')->is_valid_number, '栃木県宇都宮市上御田町');
ok($zip->set_number('3210116')->is_valid_number, '栃木県宇都宮市東横田町');
ok($zip->set_number('3210117')->is_valid_number, '栃木県宇都宮市城南');
ok($zip->set_number('3210118')->is_valid_number, '栃木県宇都宮市インターパーク');
ok($zip->set_number('3210121')->is_valid_number, '栃木県宇都宮市雀宮町');
ok($zip->set_number('3210122')->is_valid_number, '栃木県宇都宮市下反町町');
ok($zip->set_number('3210123')->is_valid_number, '栃木県宇都宮市東谷町');
ok($zip->set_number('3210124')->is_valid_number, '栃木県宇都宮市下横田町');
ok($zip->set_number('3210125')->is_valid_number, '栃木県宇都宮市御田長島町');
ok($zip->set_number('3210126')->is_valid_number, '栃木県宇都宮市茂原町');
ok($zip->set_number('3210127')->is_valid_number, '栃木県宇都宮市羽牛田町');
ok($zip->set_number('3210131')->is_valid_number, '栃木県宇都宮市宮の内');
ok($zip->set_number('3210132')->is_valid_number, '栃木県宇都宮市雀の宮');
ok($zip->set_number('3210133')->is_valid_number, '栃木県宇都宮市新富町');
ok($zip->set_number('3210134')->is_valid_number, '栃木県宇都宮市高砂町');
ok($zip->set_number('3210135')->is_valid_number, '栃木県宇都宮市五代');
ok($zip->set_number('3210136')->is_valid_number, '栃木県宇都宮市みどり野町');
ok($zip->set_number('3210137')->is_valid_number, '栃木県宇都宮市針ケ谷');
ok($zip->set_number('3210138')->is_valid_number, '栃木県宇都宮市兵庫塚');
ok($zip->set_number('3210139')->is_valid_number, '栃木県宇都宮市若松原');
ok($zip->set_number('3210141')->is_valid_number, '栃木県宇都宮市さつき');
ok($zip->set_number('3210142')->is_valid_number, '栃木県宇都宮市南町');
ok($zip->set_number('3210143')->is_valid_number, '栃木県宇都宮市南高砂町');
ok($zip->set_number('3210144')->is_valid_number, '栃木県宇都宮市末広');
ok($zip->set_number('3210145')->is_valid_number, '栃木県宇都宮市茂原');
ok($zip->set_number('3210146')->is_valid_number, '栃木県宇都宮市富士見町');
ok($zip->set_number('3210147')->is_valid_number, '栃木県宇都宮市針ケ谷町');
ok($zip->set_number('3210151')->is_valid_number, '栃木県宇都宮市西川田町');
ok($zip->set_number('3210152')->is_valid_number, '栃木県宇都宮市西川田');
ok($zip->set_number('3210153')->is_valid_number, '栃木県宇都宮市北若松原');
ok($zip->set_number('3210154')->is_valid_number, '栃木県宇都宮市西川田東町');
ok($zip->set_number('3210155')->is_valid_number, '栃木県宇都宮市西川田南');
ok($zip->set_number('3210156')->is_valid_number, '栃木県宇都宮市兵庫塚町');
ok($zip->set_number('3210157')->is_valid_number, '栃木県宇都宮市幕田町');
ok($zip->set_number('3210158')->is_valid_number, '栃木県宇都宮市西川田本町');
ok($zip->set_number('3210161')->is_valid_number, '栃木県宇都宮市大塚町');
ok($zip->set_number('3210162')->is_valid_number, '栃木県宇都宮市大和(1、2丁目)');
ok($zip->set_number('3210163')->is_valid_number, '栃木県宇都宮市宮本町');
ok($zip->set_number('3210164')->is_valid_number, '栃木県宇都宮市双葉');
ok($zip->set_number('3210165')->is_valid_number, '栃木県宇都宮市緑');
ok($zip->set_number('3210166')->is_valid_number, '栃木県宇都宮市今宮');
ok($zip->set_number('3210167')->is_valid_number, '栃木県宇都宮市東浦町');
ok($zip->set_number('3210168')->is_valid_number, '栃木県宇都宮市東原町');
ok($zip->set_number('3210169')->is_valid_number, '栃木県宇都宮市八千代');
ok($zip->set_number('3210200')->is_valid_number, '栃木県下都賀郡壬生町以下に掲載がない場合');
ok($zip->set_number('3210201')->is_valid_number, '栃木県下都賀郡壬生町安塚');
ok($zip->set_number('3210202')->is_valid_number, '栃木県下都賀郡壬生町おもちゃのまち');
ok($zip->set_number('3210203')->is_valid_number, '栃木県下都賀郡壬生町幸町');
ok($zip->set_number('3210204')->is_valid_number, '栃木県下都賀郡壬生町緑町');
ok($zip->set_number('3210205')->is_valid_number, '栃木県下都賀郡壬生町若草町');
ok($zip->set_number('3210206')->is_valid_number, '栃木県下都賀郡壬生町あけぼの町');
ok($zip->set_number('3210207')->is_valid_number, '栃木県下都賀郡壬生町北小林');
ok($zip->set_number('3210211')->is_valid_number, '栃木県下都賀郡壬生町国谷');
ok($zip->set_number('3210212')->is_valid_number, '栃木県下都賀郡壬生町寿町');
ok($zip->set_number('3210213')->is_valid_number, '栃木県下都賀郡壬生町いずみ町');
ok($zip->set_number('3210214')->is_valid_number, '栃木県下都賀郡壬生町壬生甲');
ok($zip->set_number('3210215')->is_valid_number, '栃木県下都賀郡壬生町壬生乙');
ok($zip->set_number('3210216')->is_valid_number, '栃木県下都賀郡壬生町壬生丁');
ok($zip->set_number('3210217')->is_valid_number, '栃木県下都賀郡壬生町至宝');
ok($zip->set_number('3210218')->is_valid_number, '栃木県下都賀郡壬生町落合');
ok($zip->set_number('3210219')->is_valid_number, '栃木県下都賀郡壬生町福和田');
ok($zip->set_number('3210221')->is_valid_number, '栃木県下都賀郡壬生町藤井');
ok($zip->set_number('3210222')->is_valid_number, '栃木県下都賀郡壬生町駅東町');
ok($zip->set_number('3210223')->is_valid_number, '栃木県下都賀郡壬生町元町');
ok($zip->set_number('3210224')->is_valid_number, '栃木県下都賀郡壬生町表町');
ok($zip->set_number('3210225')->is_valid_number, '栃木県下都賀郡壬生町本丸');
ok($zip->set_number('3210226')->is_valid_number, '栃木県下都賀郡壬生町中央町');
ok($zip->set_number('3210227')->is_valid_number, '栃木県下都賀郡壬生町通町');
ok($zip->set_number('3210228')->is_valid_number, '栃木県下都賀郡壬生町大師町');
ok($zip->set_number('3210231')->is_valid_number, '栃木県下都賀郡壬生町上田');
ok($zip->set_number('3210232')->is_valid_number, '栃木県下都賀郡壬生町中泉');
ok($zip->set_number('3210233')->is_valid_number, '栃木県下都賀郡壬生町助谷');
ok($zip->set_number('3210234')->is_valid_number, '栃木県下都賀郡壬生町羽生田');
ok($zip->set_number('3210235')->is_valid_number, '栃木県下都賀郡壬生町七ツ石');
ok($zip->set_number('3210236')->is_valid_number, '栃木県下都賀郡壬生町上稲葉');
ok($zip->set_number('3210237')->is_valid_number, '栃木県下都賀郡壬生町下稲葉');
ok($zip->set_number('3210238')->is_valid_number, '栃木県下都賀郡壬生町みぶ羽生田産業団地');
ok($zip->set_number('3210341')->is_valid_number, '栃木県宇都宮市古賀志町');
ok($zip->set_number('3210342')->is_valid_number, '栃木県宇都宮市福岡町');
ok($zip->set_number('3210343')->is_valid_number, '栃木県宇都宮市田下町');
ok($zip->set_number('3210344')->is_valid_number, '栃木県宇都宮市田野町');
ok($zip->set_number('3210345')->is_valid_number, '栃木県宇都宮市大谷町');
ok($zip->set_number('3210346')->is_valid_number, '栃木県宇都宮市下荒針町');
ok($zip->set_number('3210347')->is_valid_number, '栃木県宇都宮市飯田町');
ok($zip->set_number('3210401')->is_valid_number, '栃木県宇都宮市上小倉町');
ok($zip->set_number('3210402')->is_valid_number, '栃木県宇都宮市今里町');
ok($zip->set_number('3210403')->is_valid_number, '栃木県宇都宮市下小倉町');
ok($zip->set_number('3210404')->is_valid_number, '栃木県宇都宮市芦沼町');
ok($zip->set_number('3210405')->is_valid_number, '栃木県宇都宮市上田町');
ok($zip->set_number('3210406')->is_valid_number, '栃木県宇都宮市金田町');
ok($zip->set_number('3210407')->is_valid_number, '栃木県宇都宮市松田新田町');
ok($zip->set_number('3210411')->is_valid_number, '栃木県宇都宮市宮山田町');
ok($zip->set_number('3210412')->is_valid_number, '栃木県宇都宮市関白町');
ok($zip->set_number('3210413')->is_valid_number, '栃木県宇都宮市松風台');
ok($zip->set_number('3210414')->is_valid_number, '栃木県宇都宮市中里町');
ok($zip->set_number('3210415')->is_valid_number, '栃木県宇都宮市免ノ内町');
ok($zip->set_number('3210416')->is_valid_number, '栃木県宇都宮市高松町');
ok($zip->set_number('3210417')->is_valid_number, '栃木県宇都宮市冬室町');
ok($zip->set_number('3210501')->is_valid_number, '栃木県那須烏山市志鳥');
ok($zip->set_number('3210502')->is_valid_number, '栃木県那須烏山市熊田');
ok($zip->set_number('3210503')->is_valid_number, '栃木県那須烏山市月次');
ok($zip->set_number('3210504')->is_valid_number, '栃木県那須烏山市下川井');
ok($zip->set_number('3210505')->is_valid_number, '栃木県那須烏山市上川井');
ok($zip->set_number('3210511')->is_valid_number, '栃木県那須烏山市小河原');
ok($zip->set_number('3210512')->is_valid_number, '栃木県那須烏山市高瀬');
ok($zip->set_number('3210513')->is_valid_number, '栃木県那須烏山市小塙');
ok($zip->set_number('3210514')->is_valid_number, '栃木県那須烏山市森田');
ok($zip->set_number('3210515')->is_valid_number, '栃木県那須烏山市曲田');
ok($zip->set_number('3210516')->is_valid_number, '栃木県那須烏山市大里');
ok($zip->set_number('3210517')->is_valid_number, '栃木県那須烏山市東原');
ok($zip->set_number('3210521')->is_valid_number, '栃木県那須烏山市岩子');
ok($zip->set_number('3210522')->is_valid_number, '栃木県那須烏山市大金');
ok($zip->set_number('3210523')->is_valid_number, '栃木県那須烏山市曲畑');
ok($zip->set_number('3210524')->is_valid_number, '栃木県那須烏山市八ケ代');
ok($zip->set_number('3210525')->is_valid_number, '栃木県那須烏山市福岡');
ok($zip->set_number('3210526')->is_valid_number, '栃木県那須烏山市田野倉');
ok($zip->set_number('3210527')->is_valid_number, '栃木県那須烏山市宇井');
ok($zip->set_number('3210528')->is_valid_number, '栃木県那須烏山市小倉');
ok($zip->set_number('3210531')->is_valid_number, '栃木県那須烏山市三箇');
ok($zip->set_number('3210532')->is_valid_number, '栃木県那須烏山市藤田');
ok($zip->set_number('3210533')->is_valid_number, '栃木県那須烏山市南大和久');
ok($zip->set_number('3210534')->is_valid_number, '栃木県那須烏山市鴻野山');
ok($zip->set_number('3210535')->is_valid_number, '栃木県那須烏山市小白井');
ok($zip->set_number('3210600')->is_valid_number, '栃木県那須烏山市以下に掲載がない場合');
ok($zip->set_number('3210601')->is_valid_number, '栃木県那須烏山市白久');
ok($zip->set_number('3210602')->is_valid_number, '栃木県那須烏山市大桶');
ok($zip->set_number('3210603')->is_valid_number, '栃木県那須烏山市谷浅見');
ok($zip->set_number('3210604')->is_valid_number, '栃木県那須烏山市中山');
ok($zip->set_number('3210605')->is_valid_number, '栃木県那須烏山市滝田');
ok($zip->set_number('3210611')->is_valid_number, '栃木県那須烏山市興野');
ok($zip->set_number('3210612')->is_valid_number, '栃木県那須烏山市大沢');
ok($zip->set_number('3210613')->is_valid_number, '栃木県那須烏山市大木須');
ok($zip->set_number('3210614')->is_valid_number, '栃木県那須烏山市小木須');
ok($zip->set_number('3210615')->is_valid_number, '栃木県那須烏山市小原沢');
ok($zip->set_number('3210616')->is_valid_number, '栃木県那須烏山市下境');
ok($zip->set_number('3210617')->is_valid_number, '栃木県那須烏山市上境');
ok($zip->set_number('3210618')->is_valid_number, '栃木県那須烏山市横枕');
ok($zip->set_number('3210621')->is_valid_number, '栃木県那須烏山市中央');
ok($zip->set_number('3210622')->is_valid_number, '栃木県那須烏山市城東');
ok($zip->set_number('3210623')->is_valid_number, '栃木県那須烏山市表');
ok($zip->set_number('3210624')->is_valid_number, '栃木県那須烏山市旭');
ok($zip->set_number('3210625')->is_valid_number, '栃木県那須烏山市宮原');
ok($zip->set_number('3210626')->is_valid_number, '栃木県那須烏山市初音');
ok($zip->set_number('3210627')->is_valid_number, '栃木県那須烏山市南');
ok($zip->set_number('3210628')->is_valid_number, '栃木県那須烏山市金井');
ok($zip->set_number('3210629')->is_valid_number, '栃木県那須烏山市愛宕台');
ok($zip->set_number('3210631')->is_valid_number, '栃木県那須烏山市城山');
ok($zip->set_number('3210632')->is_valid_number, '栃木県那須烏山市神長');
ok($zip->set_number('3210633')->is_valid_number, '栃木県那須烏山市滝');
ok($zip->set_number('3210634')->is_valid_number, '栃木県那須烏山市野上');
ok($zip->set_number('3210635')->is_valid_number, '栃木県那須烏山市向田');
ok($zip->set_number('3210636')->is_valid_number, '栃木県那須烏山市落合');
ok($zip->set_number('3210901')->is_valid_number, '栃木県宇都宮市平出町');
ok($zip->set_number('3210902')->is_valid_number, '栃木県宇都宮市柳田町');
ok($zip->set_number('3210903')->is_valid_number, '栃木県宇都宮市下平出町');
ok($zip->set_number('3210904')->is_valid_number, '栃木県宇都宮市陽東');
ok($zip->set_number('3210905')->is_valid_number, '栃木県宇都宮市平出工業団地');
ok($zip->set_number('3210906')->is_valid_number, '栃木県宇都宮市中久保');
ok($zip->set_number('3210911')->is_valid_number, '栃木県宇都宮市問屋町');
ok($zip->set_number('3210912')->is_valid_number, '栃木県宇都宮市石井町');
ok($zip->set_number('3210913')->is_valid_number, '栃木県宇都宮市上桑島町');
ok($zip->set_number('3210914')->is_valid_number, '栃木県宇都宮市下桑島町');
ok($zip->set_number('3210915')->is_valid_number, '栃木県宇都宮市東刑部町');
ok($zip->set_number('3210916')->is_valid_number, '栃木県宇都宮市東木代町');
ok($zip->set_number('3210917')->is_valid_number, '栃木県宇都宮市西刑部町');
ok($zip->set_number('3210918')->is_valid_number, '栃木県宇都宮市平塚町');
ok($zip->set_number('3210921')->is_valid_number, '栃木県宇都宮市瑞穂');
ok($zip->set_number('3210922')->is_valid_number, '栃木県宇都宮市さるやま町');
ok($zip->set_number('3210923')->is_valid_number, '栃木県宇都宮市下栗町');
ok($zip->set_number('3210924')->is_valid_number, '栃木県宇都宮市下栗');
ok($zip->set_number('3210925')->is_valid_number, '栃木県宇都宮市東簗瀬');
ok($zip->set_number('3210931')->is_valid_number, '栃木県宇都宮市平松町');
ok($zip->set_number('3210932')->is_valid_number, '栃木県宇都宮市平松本町');
ok($zip->set_number('3210933')->is_valid_number, '栃木県宇都宮市簗瀬町');
ok($zip->set_number('3210934')->is_valid_number, '栃木県宇都宮市簗瀬');
ok($zip->set_number('3210935')->is_valid_number, '栃木県宇都宮市城東');
ok($zip->set_number('3210941')->is_valid_number, '栃木県宇都宮市東今泉');
ok($zip->set_number('3210942')->is_valid_number, '栃木県宇都宮市峰');
ok($zip->set_number('3210943')->is_valid_number, '栃木県宇都宮市峰町');
ok($zip->set_number('3210944')->is_valid_number, '栃木県宇都宮市東峰町');
ok($zip->set_number('3210945')->is_valid_number, '栃木県宇都宮市宿郷');
ok($zip->set_number('3210951')->is_valid_number, '栃木県宇都宮市越戸');
ok($zip->set_number('3210951')->is_valid_number, '栃木県宇都宮市越戸町');
ok($zip->set_number('3210952')->is_valid_number, '栃木県宇都宮市泉が丘');
ok($zip->set_number('3210953')->is_valid_number, '栃木県宇都宮市東宿郷');
ok($zip->set_number('3210954')->is_valid_number, '栃木県宇都宮市元今泉');
ok($zip->set_number('3210961')->is_valid_number, '栃木県宇都宮市今泉新町');
ok($zip->set_number('3210962')->is_valid_number, '栃木県宇都宮市今泉町');
ok($zip->set_number('3210963')->is_valid_number, '栃木県宇都宮市南大通り');
ok($zip->set_number('3210964')->is_valid_number, '栃木県宇都宮市駅前通り');
ok($zip->set_number('3210965')->is_valid_number, '栃木県宇都宮市川向町');
ok($zip->set_number('3210966')->is_valid_number, '栃木県宇都宮市今泉');
ok($zip->set_number('3210967')->is_valid_number, '栃木県宇都宮市錦');
ok($zip->set_number('3210968')->is_valid_number, '栃木県宇都宮市中今泉');
ok($zip->set_number('3210969')->is_valid_number, '栃木県宇都宮市宮みらい');
ok($zip->set_number('3210971')->is_valid_number, '栃木県宇都宮市海道町');
ok($zip->set_number('3210972')->is_valid_number, '栃木県宇都宮市下川俣町');
ok($zip->set_number('3210973')->is_valid_number, '栃木県宇都宮市岩曽町');
ok($zip->set_number('3210974')->is_valid_number, '栃木県宇都宮市竹林町');
ok($zip->set_number('3210975')->is_valid_number, '栃木県宇都宮市関堀町');
ok($zip->set_number('3210976')->is_valid_number, '栃木県宇都宮市岩本町');
ok($zip->set_number('3210977')->is_valid_number, '栃木県宇都宮市川俣町');
ok($zip->set_number('3210981')->is_valid_number, '栃木県宇都宮市上野町');
ok($zip->set_number('3210982')->is_valid_number, '栃木県宇都宮市御幸ケ原町');
ok($zip->set_number('3210983')->is_valid_number, '栃木県宇都宮市御幸本町');
ok($zip->set_number('3210984')->is_valid_number, '栃木県宇都宮市御幸町');
ok($zip->set_number('3210985')->is_valid_number, '栃木県宇都宮市東町');
ok($zip->set_number('3211101')->is_valid_number, '栃木県日光市明神');
ok($zip->set_number('3211102')->is_valid_number, '栃木県日光市板橋');
ok($zip->set_number('3211103')->is_valid_number, '栃木県日光市手岡');
ok($zip->set_number('3211104')->is_valid_number, '栃木県日光市岩崎');
ok($zip->set_number('3211105')->is_valid_number, '栃木県日光市文挾町');
ok($zip->set_number('3211106')->is_valid_number, '栃木県日光市小倉');
ok($zip->set_number('3211107')->is_valid_number, '栃木県日光市小代');
ok($zip->set_number('3211108')->is_valid_number, '栃木県日光市長畑');
ok($zip->set_number('3211111')->is_valid_number, '栃木県鹿沼市板荷');
ok($zip->set_number('3211200')->is_valid_number, '栃木県日光市以下に掲載がない場合');
ok($zip->set_number('3211261')->is_valid_number, '栃木県日光市今市');
ok($zip->set_number('3211262')->is_valid_number, '栃木県日光市平ケ崎');
ok($zip->set_number('3211263')->is_valid_number, '栃木県日光市瀬川');
ok($zip->set_number('3211264')->is_valid_number, '栃木県日光市瀬尾');
ok($zip->set_number('3211265')->is_valid_number, '栃木県日光市小百(その他)');
ok($zip->set_number('3211266')->is_valid_number, '栃木県日光市中央町');
ok($zip->set_number('3211271')->is_valid_number, '栃木県日光市並木町');
ok($zip->set_number('3211272')->is_valid_number, '栃木県日光市今市本町');
ok($zip->set_number('3211273')->is_valid_number, '栃木県日光市吉沢');
ok($zip->set_number('3211274')->is_valid_number, '栃木県日光市土沢');
ok($zip->set_number('3211275')->is_valid_number, '栃木県日光市室瀬');
ok($zip->set_number('3211276')->is_valid_number, '栃木県日光市下の内');
ok($zip->set_number('3211277')->is_valid_number, '栃木県日光市千本木');
ok($zip->set_number('3211351')->is_valid_number, '栃木県日光市東小来川');
ok($zip->set_number('3211352')->is_valid_number, '栃木県日光市宮小来川');
ok($zip->set_number('3211353')->is_valid_number, '栃木県日光市南小来川');
ok($zip->set_number('3211354')->is_valid_number, '栃木県日光市中小来川');
ok($zip->set_number('3211355')->is_valid_number, '栃木県日光市西小来川');
ok($zip->set_number('3211356')->is_valid_number, '栃木県日光市滝ケ原');
ok($zip->set_number('3211401')->is_valid_number, '栃木県日光市上鉢石町');
ok($zip->set_number('3211402')->is_valid_number, '栃木県日光市中鉢石町');
ok($zip->set_number('3211403')->is_valid_number, '栃木県日光市下鉢石町');
ok($zip->set_number('3211404')->is_valid_number, '栃木県日光市御幸町');
ok($zip->set_number('3211405')->is_valid_number, '栃木県日光市石屋町');
ok($zip->set_number('3211406')->is_valid_number, '栃木県日光市松原町');
ok($zip->set_number('3211407')->is_valid_number, '栃木県日光市若杉町');
ok($zip->set_number('3211411')->is_valid_number, '栃木県日光市稲荷町');
ok($zip->set_number('3211412')->is_valid_number, '栃木県日光市東和町');
ok($zip->set_number('3211413')->is_valid_number, '栃木県日光市相生町');
ok($zip->set_number('3211414')->is_valid_number, '栃木県日光市萩垣面');
ok($zip->set_number('3211415')->is_valid_number, '栃木県日光市日光');
ok($zip->set_number('3211421')->is_valid_number, '栃木県日光市所野');
ok($zip->set_number('3211422')->is_valid_number, '栃木県日光市宝殿');
ok($zip->set_number('3211423')->is_valid_number, '栃木県日光市七里');
ok($zip->set_number('3211424')->is_valid_number, '栃木県日光市野口');
ok($zip->set_number('3211425')->is_valid_number, '栃木県日光市和泉');
ok($zip->set_number('3211426')->is_valid_number, '栃木県日光市山久保');
ok($zip->set_number('3211431')->is_valid_number, '栃木県日光市山内');
ok($zip->set_number('3211432')->is_valid_number, '栃木県日光市安川町');
ok($zip->set_number('3211433')->is_valid_number, '栃木県日光市匠町');
ok($zip->set_number('3211434')->is_valid_number, '栃木県日光市本町');
ok($zip->set_number('3211435')->is_valid_number, '栃木県日光市花石町');
ok($zip->set_number('3211436')->is_valid_number, '栃木県日光市久次良町');
ok($zip->set_number('3211441')->is_valid_number, '栃木県日光市清滝安良沢町');
ok($zip->set_number('3211442')->is_valid_number, '栃木県日光市清滝丹勢町');
ok($zip->set_number('3211443')->is_valid_number, '栃木県日光市清滝桜ケ丘町');
ok($zip->set_number('3211444')->is_valid_number, '栃木県日光市清滝');
ok($zip->set_number('3211445')->is_valid_number, '栃木県日光市細尾町');
ok($zip->set_number('3211446')->is_valid_number, '栃木県日光市清滝中安戸町');
ok($zip->set_number('3211447')->is_valid_number, '栃木県日光市清滝和の代町');
ok($zip->set_number('3211448')->is_valid_number, '栃木県日光市清滝新細尾町');
ok($zip->set_number('3211449')->is_valid_number, '栃木県日光市丹勢');
ok($zip->set_number('3211501')->is_valid_number, '栃木県日光市足尾町愛宕下');
ok($zip->set_number('3211502')->is_valid_number, '栃木県日光市足尾町赤倉');
ok($zip->set_number('3211503')->is_valid_number, '栃木県日光市足尾町深沢');
ok($zip->set_number('3211504')->is_valid_number, '栃木県日光市足尾町上間藤');
ok($zip->set_number('3211505')->is_valid_number, '栃木県日光市足尾町上の平');
ok($zip->set_number('3211506')->is_valid_number, '栃木県日光市足尾町下間藤');
ok($zip->set_number('3211507')->is_valid_number, '栃木県日光市足尾町南橋');
ok($zip->set_number('3211508')->is_valid_number, '栃木県日光市足尾町本山');
ok($zip->set_number('3211511')->is_valid_number, '栃木県日光市足尾町');
ok($zip->set_number('3211512')->is_valid_number, '栃木県日光市足尾町掛水');
ok($zip->set_number('3211513')->is_valid_number, '栃木県日光市足尾町向原');
ok($zip->set_number('3211514')->is_valid_number, '栃木県日光市足尾町通洞');
ok($zip->set_number('3211515')->is_valid_number, '栃木県日光市足尾町砂畑');
ok($zip->set_number('3211521')->is_valid_number, '栃木県日光市足尾町遠下');
ok($zip->set_number('3211522')->is_valid_number, '栃木県日光市足尾町中才');
ok($zip->set_number('3211523')->is_valid_number, '栃木県日光市足尾町松原');
ok($zip->set_number('3211524')->is_valid_number, '栃木県日光市足尾町赤沢');
ok($zip->set_number('3211661')->is_valid_number, '栃木県日光市中宮祠');
ok($zip->set_number('3211662')->is_valid_number, '栃木県日光市湯元');
ok($zip->set_number('3212101')->is_valid_number, '栃木県宇都宮市飯山町');
ok($zip->set_number('3212102')->is_valid_number, '栃木県宇都宮市篠井町');
ok($zip->set_number('3212103')->is_valid_number, '栃木県宇都宮市石那田町');
ok($zip->set_number('3212104')->is_valid_number, '栃木県宇都宮市上小池町');
ok($zip->set_number('3212105')->is_valid_number, '栃木県宇都宮市下小池町');
ok($zip->set_number('3212111')->is_valid_number, '栃木県宇都宮市大網町');
ok($zip->set_number('3212112')->is_valid_number, '栃木県宇都宮市上横倉町');
ok($zip->set_number('3212113')->is_valid_number, '栃木県宇都宮市下横倉町');
ok($zip->set_number('3212114')->is_valid_number, '栃木県宇都宮市下金井町');
ok($zip->set_number('3212115')->is_valid_number, '栃木県宇都宮市上金井町');
ok($zip->set_number('3212116')->is_valid_number, '栃木県宇都宮市徳次郎町');
ok($zip->set_number('3212117')->is_valid_number, '栃木県宇都宮市岩原町');
ok($zip->set_number('3212118')->is_valid_number, '栃木県宇都宮市新里町');
ok($zip->set_number('3212331')->is_valid_number, '栃木県日光市針貝');
ok($zip->set_number('3212332')->is_valid_number, '栃木県日光市大室');
ok($zip->set_number('3212333')->is_valid_number, '栃木県日光市薄井沢');
ok($zip->set_number('3212334')->is_valid_number, '栃木県日光市水無');
ok($zip->set_number('3212335')->is_valid_number, '栃木県日光市森友');
ok($zip->set_number('3212336')->is_valid_number, '栃木県日光市荊沢');
ok($zip->set_number('3212341')->is_valid_number, '栃木県日光市大沢町');
ok($zip->set_number('3212342')->is_valid_number, '栃木県日光市根室');
ok($zip->set_number('3212343')->is_valid_number, '栃木県日光市山口');
ok($zip->set_number('3212344')->is_valid_number, '栃木県日光市猪倉');
ok($zip->set_number('3212345')->is_valid_number, '栃木県日光市木和田島');
ok($zip->set_number('3212351')->is_valid_number, '栃木県日光市塩野室町');
ok($zip->set_number('3212352')->is_valid_number, '栃木県日光市小林');
ok($zip->set_number('3212353')->is_valid_number, '栃木県日光市沓掛');
ok($zip->set_number('3212354')->is_valid_number, '栃木県日光市嘉多蔵');
ok($zip->set_number('3212355')->is_valid_number, '栃木県日光市沢又');
ok($zip->set_number('3212356')->is_valid_number, '栃木県日光市矢野口');
ok($zip->set_number('3212401')->is_valid_number, '栃木県日光市川室');
ok($zip->set_number('3212402')->is_valid_number, '栃木県日光市大渡');
ok($zip->set_number('3212403')->is_valid_number, '栃木県日光市町谷');
ok($zip->set_number('3212404')->is_valid_number, '栃木県日光市轟');
ok($zip->set_number('3212405')->is_valid_number, '栃木県日光市芹沼');
ok($zip->set_number('3212411')->is_valid_number, '栃木県日光市大桑町');
ok($zip->set_number('3212412')->is_valid_number, '栃木県日光市倉ケ崎');
ok($zip->set_number('3212413')->is_valid_number, '栃木県日光市倉ケ崎新田');
ok($zip->set_number('3212414')->is_valid_number, '栃木県日光市豊田');
ok($zip->set_number('3212421')->is_valid_number, '栃木県日光市栗原');
ok($zip->set_number('3212422')->is_valid_number, '栃木県日光市高柴');
ok($zip->set_number('3212423')->is_valid_number, '栃木県日光市原宿');
ok($zip->set_number('3212424')->is_valid_number, '栃木県日光市小百(鳥屋下)');
ok($zip->set_number('3212425')->is_valid_number, '栃木県日光市小百(楢原)');
ok($zip->set_number('3212426')->is_valid_number, '栃木県日光市小百(筒置)');
ok($zip->set_number('3212427')->is_valid_number, '栃木県日光市佐下部');
ok($zip->set_number('3212501')->is_valid_number, '栃木県塩谷郡塩谷町上寺島(1653、1661、1678、1694番地)');
ok($zip->set_number('3212521')->is_valid_number, '栃木県日光市藤原(その他)');
ok($zip->set_number('3212522')->is_valid_number, '栃木県日光市鬼怒川温泉大原');
ok($zip->set_number('3212523')->is_valid_number, '栃木県日光市高徳');
ok($zip->set_number('3212524')->is_valid_number, '栃木県日光市柄倉');
ok($zip->set_number('3212525')->is_valid_number, '栃木県日光市小佐越');
ok($zip->set_number('3212526')->is_valid_number, '栃木県日光市鬼怒川温泉滝');
ok($zip->set_number('3212601')->is_valid_number, '栃木県日光市湯西川');
ok($zip->set_number('3212602')->is_valid_number, '栃木県日光市一ツ石');
ok($zip->set_number('3212603')->is_valid_number, '栃木県日光市西川');
ok($zip->set_number('3212604')->is_valid_number, '栃木県日光市赤下');
ok($zip->set_number('3212611')->is_valid_number, '栃木県日光市川治温泉川治');
ok($zip->set_number('3212612')->is_valid_number, '栃木県日光市川治温泉高原');
ok($zip->set_number('3212613')->is_valid_number, '栃木県日光市藤原(1047~1268及び下平)');
ok($zip->set_number('3212614')->is_valid_number, '栃木県日光市川治温泉滝');
ok($zip->set_number('3212615')->is_valid_number, '栃木県日光市五十里(東山)');
ok($zip->set_number('3212616')->is_valid_number, '栃木県日光市高原');
ok($zip->set_number('3212711')->is_valid_number, '栃木県日光市日向');
ok($zip->set_number('3212712')->is_valid_number, '栃木県日光市日蔭');
ok($zip->set_number('3212713')->is_valid_number, '栃木県日光市黒部');
ok($zip->set_number('3212714')->is_valid_number, '栃木県日光市土呂部');
ok($zip->set_number('3212715')->is_valid_number, '栃木県日光市上栗山');
ok($zip->set_number('3212716')->is_valid_number, '栃木県日光市野門');
ok($zip->set_number('3212717')->is_valid_number, '栃木県日光市川俣');
ok($zip->set_number('3212718')->is_valid_number, '栃木県日光市若間');
ok($zip->set_number('3212801')->is_valid_number, '栃木県日光市横川');
ok($zip->set_number('3212802')->is_valid_number, '栃木県日光市上三依');
ok($zip->set_number('3212803')->is_valid_number, '栃木県日光市中三依');
ok($zip->set_number('3212804')->is_valid_number, '栃木県日光市芹沢');
ok($zip->set_number('3212805')->is_valid_number, '栃木県日光市独鈷沢');
ok($zip->set_number('3212806')->is_valid_number, '栃木県日光市五十里(その他)');
ok($zip->set_number('3213221')->is_valid_number, '栃木県宇都宮市板戸町');
ok($zip->set_number('3213222')->is_valid_number, '栃木県宇都宮市野高谷町');
ok($zip->set_number('3213223')->is_valid_number, '栃木県宇都宮市清原台');
ok($zip->set_number('3213224')->is_valid_number, '栃木県宇都宮市刈沼町');
ok($zip->set_number('3213225')->is_valid_number, '栃木県宇都宮市満美穴町');
ok($zip->set_number('3213226')->is_valid_number, '栃木県宇都宮市ゆいの杜');
ok($zip->set_number('3213231')->is_valid_number, '栃木県宇都宮市清原工業団地');
ok($zip->set_number('3213232')->is_valid_number, '栃木県宇都宮市氷室町');
ok($zip->set_number('3213233')->is_valid_number, '栃木県宇都宮市上籠谷町');
ok($zip->set_number('3213234')->is_valid_number, '栃木県宇都宮市桑島町');
ok($zip->set_number('3213235')->is_valid_number, '栃木県宇都宮市鐺山町');
ok($zip->set_number('3213236')->is_valid_number, '栃木県宇都宮市竹下町');
ok($zip->set_number('3213237')->is_valid_number, '栃木県宇都宮市道場宿町');
ok($zip->set_number('3213300')->is_valid_number, '栃木県芳賀郡芳賀町以下に掲載がない場合');
ok($zip->set_number('3213301')->is_valid_number, '栃木県芳賀郡芳賀町給部');
ok($zip->set_number('3213302')->is_valid_number, '栃木県芳賀郡芳賀町上稲毛田');
ok($zip->set_number('3213303')->is_valid_number, '栃木県芳賀郡芳賀町稲毛田');
ok($zip->set_number('3213304')->is_valid_number, '栃木県芳賀郡芳賀町祖母井');
ok($zip->set_number('3213305')->is_valid_number, '栃木県芳賀郡芳賀町芳志戸');
ok($zip->set_number('3213306')->is_valid_number, '栃木県芳賀郡芳賀町八ツ木');
ok($zip->set_number('3213307')->is_valid_number, '栃木県芳賀郡芳賀町祖母井南');
ok($zip->set_number('3213311')->is_valid_number, '栃木県芳賀郡芳賀町上延生');
ok($zip->set_number('3213312')->is_valid_number, '栃木県芳賀郡芳賀町下延生');
ok($zip->set_number('3213313')->is_valid_number, '栃木県芳賀郡芳賀町東高橋');
ok($zip->set_number('3213314')->is_valid_number, '栃木県芳賀郡芳賀町打越新田');
ok($zip->set_number('3213315')->is_valid_number, '栃木県芳賀郡芳賀町西高橋');
ok($zip->set_number('3213316')->is_valid_number, '栃木県芳賀郡芳賀町与能');
ok($zip->set_number('3213321')->is_valid_number, '栃木県芳賀郡芳賀町下高根沢');
ok($zip->set_number('3213322')->is_valid_number, '栃木県芳賀郡芳賀町東水沼');
ok($zip->set_number('3213323')->is_valid_number, '栃木県芳賀郡芳賀町北長島');
ok($zip->set_number('3213324')->is_valid_number, '栃木県芳賀郡芳賀町西水沼');
ok($zip->set_number('3213325')->is_valid_number, '栃木県芳賀郡芳賀町芳賀台');
ok($zip->set_number('3213400')->is_valid_number, '栃木県芳賀郡市貝町以下に掲載がない場合');
ok($zip->set_number('3213401')->is_valid_number, '栃木県芳賀郡市貝町竹内');
ok($zip->set_number('3213402')->is_valid_number, '栃木県芳賀郡市貝町見上');
ok($zip->set_number('3213403')->is_valid_number, '栃木県芳賀郡市貝町羽仏');
ok($zip->set_number('3213404')->is_valid_number, '栃木県芳賀郡市貝町続谷');
ok($zip->set_number('3213405')->is_valid_number, '栃木県芳賀郡市貝町大谷津');
ok($zip->set_number('3213406')->is_valid_number, '栃木県芳賀郡市貝町塩田');
ok($zip->set_number('3213411')->is_valid_number, '栃木県芳賀郡市貝町刈生田');
ok($zip->set_number('3213412')->is_valid_number, '栃木県芳賀郡市貝町田野辺');
ok($zip->set_number('3213413')->is_valid_number, '栃木県芳賀郡市貝町文谷');
ok($zip->set_number('3213414')->is_valid_number, '栃木県芳賀郡市貝町椎谷');
ok($zip->set_number('3213415')->is_valid_number, '栃木県芳賀郡市貝町杉山');
ok($zip->set_number('3213421')->is_valid_number, '栃木県芳賀郡市貝町笹原田');
ok($zip->set_number('3213422')->is_valid_number, '栃木県芳賀郡市貝町石下');
ok($zip->set_number('3213423')->is_valid_number, '栃木県芳賀郡市貝町市塙');
ok($zip->set_number('3213424')->is_valid_number, '栃木県芳賀郡市貝町上根');
ok($zip->set_number('3213425')->is_valid_number, '栃木県芳賀郡市貝町多田羅');
ok($zip->set_number('3213426')->is_valid_number, '栃木県芳賀郡市貝町赤羽');
ok($zip->set_number('3213500')->is_valid_number, '栃木県芳賀郡茂木町以下に掲載がない場合');
ok($zip->set_number('3213531')->is_valid_number, '栃木県芳賀郡茂木町茂木');
ok($zip->set_number('3213532')->is_valid_number, '栃木県芳賀郡茂木町三坂');
ok($zip->set_number('3213533')->is_valid_number, '栃木県芳賀郡茂木町桧山(その他)');
ok($zip->set_number('3213534')->is_valid_number, '栃木県芳賀郡茂木町青梅');
ok($zip->set_number('3213535')->is_valid_number, '栃木県芳賀郡茂木町鮎田');
ok($zip->set_number('3213536')->is_valid_number, '栃木県芳賀郡茂木町神井');
ok($zip->set_number('3213541')->is_valid_number, '栃木県芳賀郡茂木町烏生田');
ok($zip->set_number('3213542')->is_valid_number, '栃木県芳賀郡茂木町九石');
ok($zip->set_number('3213543')->is_valid_number, '栃木県芳賀郡茂木町上後郷');
ok($zip->set_number('3213544')->is_valid_number, '栃木県芳賀郡茂木町坂井');
ok($zip->set_number('3213545')->is_valid_number, '栃木県芳賀郡茂木町下菅又');
ok($zip->set_number('3213546')->is_valid_number, '栃木県芳賀郡茂木町上菅又');
ok($zip->set_number('3213547')->is_valid_number, '栃木県芳賀郡茂木町千本');
ok($zip->set_number('3213551')->is_valid_number, '栃木県芳賀郡茂木町生井');
ok($zip->set_number('3213552')->is_valid_number, '栃木県芳賀郡茂木町竹原');
ok($zip->set_number('3213553')->is_valid_number, '栃木県芳賀郡茂木町大畑');
ok($zip->set_number('3213554')->is_valid_number, '栃木県芳賀郡茂木町大瀬');
ok($zip->set_number('3213555')->is_valid_number, '栃木県芳賀郡茂木町所草');
ok($zip->set_number('3213556')->is_valid_number, '栃木県芳賀郡茂木町町田');
ok($zip->set_number('3213557')->is_valid_number, '栃木県芳賀郡茂木町黒田');
ok($zip->set_number('3213561')->is_valid_number, '栃木県芳賀郡茂木町後郷');
ok($zip->set_number('3213562')->is_valid_number, '栃木県芳賀郡茂木町馬門');
ok($zip->set_number('3213563')->is_valid_number, '栃木県芳賀郡茂木町林');
ok($zip->set_number('3213564')->is_valid_number, '栃木県芳賀郡茂木町増井');
ok($zip->set_number('3213565')->is_valid_number, '栃木県芳賀郡茂木町塩田');
ok($zip->set_number('3213566')->is_valid_number, '栃木県芳賀郡茂木町小井戸');
ok($zip->set_number('3213621')->is_valid_number, '栃木県芳賀郡茂木町天子');
ok($zip->set_number('3213622')->is_valid_number, '栃木県芳賀郡茂木町北高岡');
ok($zip->set_number('3213623')->is_valid_number, '栃木県芳賀郡茂木町木幡');
ok($zip->set_number('3213624')->is_valid_number, '栃木県芳賀郡茂木町小山');
ok($zip->set_number('3213625')->is_valid_number, '栃木県芳賀郡茂木町福手');
ok($zip->set_number('3213626')->is_valid_number, '栃木県芳賀郡茂木町飯');
ok($zip->set_number('3213627')->is_valid_number, '栃木県芳賀郡茂木町小貫');
ok($zip->set_number('3213628')->is_valid_number, '栃木県芳賀郡茂木町深沢');
ok($zip->set_number('3213701')->is_valid_number, '栃木県芳賀郡茂木町山内');
ok($zip->set_number('3213702')->is_valid_number, '栃木県芳賀郡茂木町飯野');
ok($zip->set_number('3213703')->is_valid_number, '栃木県芳賀郡茂木町河井');
ok($zip->set_number('3213704')->is_valid_number, '栃木県芳賀郡茂木町牧野');
ok($zip->set_number('3213705')->is_valid_number, '栃木県芳賀郡茂木町入郷');
ok($zip->set_number('3213706')->is_valid_number, '栃木県芳賀郡茂木町河又');
ok($zip->set_number('3213707')->is_valid_number, '栃木県芳賀郡茂木町小深');
ok($zip->set_number('3214101')->is_valid_number, '栃木県芳賀郡益子町小宅');
ok($zip->set_number('3214102')->is_valid_number, '栃木県芳賀郡益子町芦沼');
ok($zip->set_number('3214103')->is_valid_number, '栃木県芳賀郡益子町大平');
ok($zip->set_number('3214104')->is_valid_number, '栃木県芳賀郡益子町大沢');
ok($zip->set_number('3214105')->is_valid_number, '栃木県芳賀郡益子町北中');
ok($zip->set_number('3214106')->is_valid_number, '栃木県芳賀郡益子町七井');
ok($zip->set_number('3214107')->is_valid_number, '栃木県芳賀郡益子町七井中央');
ok($zip->set_number('3214200')->is_valid_number, '栃木県芳賀郡益子町以下に掲載がない場合');
ok($zip->set_number('3214211')->is_valid_number, '栃木県芳賀郡益子町下大羽');
ok($zip->set_number('3214212')->is_valid_number, '栃木県芳賀郡益子町上大羽');
ok($zip->set_number('3214213')->is_valid_number, '栃木県芳賀郡益子町山本');
ok($zip->set_number('3214214')->is_valid_number, '栃木県芳賀郡益子町前沢');
ok($zip->set_number('3214215')->is_valid_number, '栃木県芳賀郡益子町生田目');
ok($zip->set_number('3214216')->is_valid_number, '栃木県芳賀郡益子町塙');
ok($zip->set_number('3214217')->is_valid_number, '栃木県芳賀郡益子町益子');
ok($zip->set_number('3214218')->is_valid_number, '栃木県芳賀郡益子町城内坂');
ok($zip->set_number('3214221')->is_valid_number, '栃木県芳賀郡益子町大郷戸');
ok($zip->set_number('3214222')->is_valid_number, '栃木県芳賀郡益子町小泉');
ok($zip->set_number('3214223')->is_valid_number, '栃木県芳賀郡益子町梅ケ内');
ok($zip->set_number('3214224')->is_valid_number, '栃木県芳賀郡益子町本沼');
ok($zip->set_number('3214225')->is_valid_number, '栃木県芳賀郡益子町長堤');
ok($zip->set_number('3214226')->is_valid_number, '栃木県芳賀郡益子町上山');
ok($zip->set_number('3214227')->is_valid_number, '栃木県芳賀郡益子町東田井');
ok($zip->set_number('3214300')->is_valid_number, '栃木県真岡市以下に掲載がない場合');
ok($zip->set_number('3214301')->is_valid_number, '栃木県真岡市西田井');
ok($zip->set_number('3214302')->is_valid_number, '栃木県真岡市鶴田');
ok($zip->set_number('3214303')->is_valid_number, '栃木県真岡市八條');
ok($zip->set_number('3214304')->is_valid_number, '栃木県真岡市東郷');
ok($zip->set_number('3214305')->is_valid_number, '栃木県真岡市荒町');
ok($zip->set_number('3214306')->is_valid_number, '栃木県真岡市台町');
ok($zip->set_number('3214307')->is_valid_number, '栃木県真岡市西郷');
ok($zip->set_number('3214308')->is_valid_number, '栃木県真岡市中郷');
ok($zip->set_number('3214309')->is_valid_number, '栃木県真岡市東光寺');
ok($zip->set_number('3214311')->is_valid_number, '栃木県真岡市根本');
ok($zip->set_number('3214312')->is_valid_number, '栃木県真岡市青谷');
ok($zip->set_number('3214313')->is_valid_number, '栃木県真岡市須釜');
ok($zip->set_number('3214314')->is_valid_number, '栃木県真岡市南高岡');
ok($zip->set_number('3214315')->is_valid_number, '栃木県真岡市道祖土');
ok($zip->set_number('3214316')->is_valid_number, '栃木県真岡市君島');
ok($zip->set_number('3214321')->is_valid_number, '栃木県真岡市小林');
ok($zip->set_number('3214322')->is_valid_number, '栃木県真岡市東大島');
ok($zip->set_number('3214323')->is_valid_number, '栃木県真岡市東沼');
ok($zip->set_number('3214324')->is_valid_number, '栃木県真岡市西沼');
ok($zip->set_number('3214325')->is_valid_number, '栃木県真岡市田町');
ok($zip->set_number('3214326')->is_valid_number, '栃木県真岡市島');
ok($zip->set_number('3214331')->is_valid_number, '栃木県真岡市白布ケ丘');
ok($zip->set_number('3214332')->is_valid_number, '栃木県真岡市大谷新町');
ok($zip->set_number('3214333')->is_valid_number, '栃木県真岡市大谷本町');
ok($zip->set_number('3214334')->is_valid_number, '栃木県真岡市八木岡');
ok($zip->set_number('3214335')->is_valid_number, '栃木県真岡市下高間木');
ok($zip->set_number('3214336')->is_valid_number, '栃木県真岡市西高間木');
ok($zip->set_number('3214337')->is_valid_number, '栃木県真岡市上高間木');
ok($zip->set_number('3214338')->is_valid_number, '栃木県真岡市大谷台町');
ok($zip->set_number('3214341')->is_valid_number, '栃木県真岡市高勢町');
ok($zip->set_number('3214342')->is_valid_number, '栃木県真岡市伊勢崎');
ok($zip->set_number('3214343')->is_valid_number, '栃木県真岡市小橋');
ok($zip->set_number('3214344')->is_valid_number, '栃木県真岡市茅堤');
ok($zip->set_number('3214345')->is_valid_number, '栃木県真岡市寺内');
ok($zip->set_number('3214346')->is_valid_number, '栃木県真岡市松山町');
ok($zip->set_number('3214347')->is_valid_number, '栃木県真岡市加倉');
ok($zip->set_number('3214351')->is_valid_number, '栃木県真岡市中');
ok($zip->set_number('3214352')->is_valid_number, '栃木県真岡市若旅(その他)');
ok($zip->set_number('3214353')->is_valid_number, '栃木県真岡市粕田');
ok($zip->set_number('3214354')->is_valid_number, '栃木県真岡市寺分');
ok($zip->set_number('3214355')->is_valid_number, '栃木県真岡市上大沼');
ok($zip->set_number('3214356')->is_valid_number, '栃木県真岡市大沼');
ok($zip->set_number('3214357')->is_valid_number, '栃木県真岡市下大沼');
ok($zip->set_number('3214361')->is_valid_number, '栃木県真岡市並木町');
ok($zip->set_number('3214362')->is_valid_number, '栃木県真岡市熊倉町');
ok($zip->set_number('3214363')->is_valid_number, '栃木県真岡市亀山');
ok($zip->set_number('3214364')->is_valid_number, '栃木県真岡市長田');
ok($zip->set_number('3214365')->is_valid_number, '栃木県真岡市柳林');
ok($zip->set_number('3214366')->is_valid_number, '栃木県真岡市勝瓜');
ok($zip->set_number('3214367')->is_valid_number, '栃木県真岡市鬼怒ケ丘');
ok($zip->set_number('3214368')->is_valid_number, '栃木県真岡市寺久保');
ok($zip->set_number('3214369')->is_valid_number, '栃木県真岡市熊倉');
ok($zip->set_number('3214401')->is_valid_number, '栃木県真岡市赤羽');
ok($zip->set_number('3214402')->is_valid_number, '栃木県真岡市清水');
ok($zip->set_number('3214403')->is_valid_number, '栃木県真岡市原町');
ok($zip->set_number('3214404')->is_valid_number, '栃木県真岡市田島');
ok($zip->set_number('3214405')->is_valid_number, '栃木県真岡市飯貝');
ok($zip->set_number('3214406')->is_valid_number, '栃木県真岡市京泉');
ok($zip->set_number('3214411')->is_valid_number, '栃木県真岡市上大田和');
ok($zip->set_number('3214412')->is_valid_number, '栃木県真岡市堀内');
ok($zip->set_number('3214413')->is_valid_number, '栃木県真岡市下大田和');
ok($zip->set_number('3214414')->is_valid_number, '栃木県真岡市下鷺谷');
ok($zip->set_number('3214415')->is_valid_number, '栃木県真岡市下籠谷');
ok($zip->set_number('3214416')->is_valid_number, '栃木県真岡市上鷺谷');
ok($zip->set_number('3214501')->is_valid_number, '栃木県真岡市横田');
ok($zip->set_number('3214502')->is_valid_number, '栃木県真岡市物井');
ok($zip->set_number('3214503')->is_valid_number, '栃木県真岡市桑ノ川');
ok($zip->set_number('3214504')->is_valid_number, '栃木県真岡市鹿');
ok($zip->set_number('3214505')->is_valid_number, '栃木県真岡市沖');
ok($zip->set_number('3214506')->is_valid_number, '栃木県真岡市大根田');
ok($zip->set_number('3214507')->is_valid_number, '栃木県真岡市石島');
ok($zip->set_number('3214508')->is_valid_number, '栃木県真岡市大和田');
ok($zip->set_number('3214511')->is_valid_number, '栃木県真岡市高田');
ok($zip->set_number('3214512')->is_valid_number, '栃木県真岡市阿部岡');
ok($zip->set_number('3214513')->is_valid_number, '栃木県真岡市三谷');
ok($zip->set_number('3214514')->is_valid_number, '栃木県真岡市水戸部');
ok($zip->set_number('3214515')->is_valid_number, '栃木県真岡市反町');
ok($zip->set_number('3214516')->is_valid_number, '栃木県真岡市根小屋');
ok($zip->set_number('3214517')->is_valid_number, '栃木県真岡市阿部品');
ok($zip->set_number('3214521')->is_valid_number, '栃木県真岡市久下田');
ok($zip->set_number('3214522')->is_valid_number, '栃木県真岡市久下田西');
ok($zip->set_number('3214523')->is_valid_number, '栃木県真岡市さくら');
ok($zip->set_number('3214531')->is_valid_number, '栃木県真岡市青田');
ok($zip->set_number('3214532')->is_valid_number, '栃木県真岡市長島');
ok($zip->set_number('3214533')->is_valid_number, '栃木県真岡市程島');
ok($zip->set_number('3214534')->is_valid_number, '栃木県真岡市境');
ok($zip->set_number('3214535')->is_valid_number, '栃木県真岡市古山');
ok($zip->set_number('3214536')->is_valid_number, '栃木県真岡市上江連');
ok($zip->set_number('3214537')->is_valid_number, '栃木県真岡市西大島');
ok($zip->set_number('3214538')->is_valid_number, '栃木県真岡市鷲巣');
ok($zip->set_number('3214539')->is_valid_number, '栃木県真岡市長沼');
ok($zip->set_number('3214541')->is_valid_number, '栃木県真岡市上谷貝');
ok($zip->set_number('3214542')->is_valid_number, '栃木県真岡市上大曽');
ok($zip->set_number('3214543')->is_valid_number, '栃木県真岡市下大曽');
ok($zip->set_number('3214544')->is_valid_number, '栃木県真岡市堀込');
ok($zip->set_number('3214545')->is_valid_number, '栃木県真岡市大道泉');
ok($zip->set_number('3214546')->is_valid_number, '栃木県真岡市砂ケ原');
ok($zip->set_number('3214547')->is_valid_number, '栃木県真岡市谷貝新田');
ok($zip->set_number('3214551')->is_valid_number, '栃木県真岡市若旅(五丁歩)');
ok($zip->set_number('3220000')->is_valid_number, '栃木県鹿沼市以下に掲載がない場合');
ok($zip->set_number('3220001')->is_valid_number, '栃木県鹿沼市栃窪');
ok($zip->set_number('3220002')->is_valid_number, '栃木県鹿沼市千渡');
ok($zip->set_number('3220003')->is_valid_number, '栃木県鹿沼市仁神堂町');
ok($zip->set_number('3220004')->is_valid_number, '栃木県鹿沼市下武子町');
ok($zip->set_number('3220005')->is_valid_number, '栃木県鹿沼市御成橋町');
ok($zip->set_number('3220006')->is_valid_number, '栃木県鹿沼市富岡');
ok($zip->set_number('3220007')->is_valid_number, '栃木県鹿沼市武子');
ok($zip->set_number('3220008')->is_valid_number, '栃木県鹿沼市古賀志町');
ok($zip->set_number('3220009')->is_valid_number, '栃木県鹿沼市高谷');
ok($zip->set_number('3220011')->is_valid_number, '栃木県鹿沼市白桑田');
ok($zip->set_number('3220012')->is_valid_number, '栃木県鹿沼市松原');
ok($zip->set_number('3220013')->is_valid_number, '栃木県鹿沼市深津');
ok($zip->set_number('3220014')->is_valid_number, '栃木県鹿沼市さつき町');
ok($zip->set_number('3220015')->is_valid_number, '栃木県鹿沼市上石川');
ok($zip->set_number('3220016')->is_valid_number, '栃木県鹿沼市流通センター');
ok($zip->set_number('3220017')->is_valid_number, '栃木県鹿沼市下石川');
ok($zip->set_number('3220018')->is_valid_number, '栃木県鹿沼市池ノ森');
ok($zip->set_number('3220021')->is_valid_number, '栃木県鹿沼市上野町');
ok($zip->set_number('3220022')->is_valid_number, '栃木県鹿沼市東町');
ok($zip->set_number('3220023')->is_valid_number, '栃木県鹿沼市幸町');
ok($zip->set_number('3220024')->is_valid_number, '栃木県鹿沼市晃望台');
ok($zip->set_number('3220025')->is_valid_number, '栃木県鹿沼市緑町');
ok($zip->set_number('3220026')->is_valid_number, '栃木県鹿沼市茂呂');
ok($zip->set_number('3220027')->is_valid_number, '栃木県鹿沼市貝島町');
ok($zip->set_number('3220028')->is_valid_number, '栃木県鹿沼市栄町');
ok($zip->set_number('3220029')->is_valid_number, '栃木県鹿沼市西茂呂');
ok($zip->set_number('3220031')->is_valid_number, '栃木県鹿沼市睦町');
ok($zip->set_number('3220032')->is_valid_number, '栃木県鹿沼市府所本町');
ok($zip->set_number('3220033')->is_valid_number, '栃木県鹿沼市府所町');
ok($zip->set_number('3220034')->is_valid_number, '栃木県鹿沼市府中町');
ok($zip->set_number('3220035')->is_valid_number, '栃木県鹿沼市朝日町');
ok($zip->set_number('3220036')->is_valid_number, '栃木県鹿沼市下田町');
ok($zip->set_number('3220037')->is_valid_number, '栃木県鹿沼市中田町');
ok($zip->set_number('3220038')->is_valid_number, '栃木県鹿沼市末広町');
ok($zip->set_number('3220039')->is_valid_number, '栃木県鹿沼市東末広町');
ok($zip->set_number('3220041')->is_valid_number, '栃木県鹿沼市三幸町');
ok($zip->set_number('3220042')->is_valid_number, '栃木県鹿沼市蓬莱町');
ok($zip->set_number('3220043')->is_valid_number, '栃木県鹿沼市万町');
ok($zip->set_number('3220044')->is_valid_number, '栃木県鹿沼市鳥居跡町');
ok($zip->set_number('3220045')->is_valid_number, '栃木県鹿沼市上殿町');
ok($zip->set_number('3220046')->is_valid_number, '栃木県鹿沼市樅山町');
ok($zip->set_number('3220047')->is_valid_number, '栃木県鹿沼市酒野谷');
ok($zip->set_number('3220048')->is_valid_number, '栃木県鹿沼市村井町');
ok($zip->set_number('3220049')->is_valid_number, '栃木県鹿沼市花岡町');
ok($zip->set_number('3220051')->is_valid_number, '栃木県鹿沼市久保町');
ok($zip->set_number('3220052')->is_valid_number, '栃木県鹿沼市銀座');
ok($zip->set_number('3220053')->is_valid_number, '栃木県鹿沼市仲町');
ok($zip->set_number('3220054')->is_valid_number, '栃木県鹿沼市下横町');
ok($zip->set_number('3220055')->is_valid_number, '栃木県鹿沼市石橋町');
ok($zip->set_number('3220056')->is_valid_number, '栃木県鹿沼市下材木町');
ok($zip->set_number('3220057')->is_valid_number, '栃木県鹿沼市寺町');
ok($zip->set_number('3220058')->is_valid_number, '栃木県鹿沼市麻苧町');
ok($zip->set_number('3220061')->is_valid_number, '栃木県鹿沼市千手町');
ok($zip->set_number('3220062')->is_valid_number, '栃木県鹿沼市泉町');
ok($zip->set_number('3220063')->is_valid_number, '栃木県鹿沼市戸張町');
ok($zip->set_number('3220064')->is_valid_number, '栃木県鹿沼市文化橋町');
ok($zip->set_number('3220065')->is_valid_number, '栃木県鹿沼市上材木町');
ok($zip->set_number('3220066')->is_valid_number, '栃木県鹿沼市上田町');
ok($zip->set_number('3220067')->is_valid_number, '栃木県鹿沼市天神町');
ok($zip->set_number('3220068')->is_valid_number, '栃木県鹿沼市今宮町');
ok($zip->set_number('3220069')->is_valid_number, '栃木県鹿沼市坂田山');
ok($zip->set_number('3220071')->is_valid_number, '栃木県鹿沼市見野');
ok($zip->set_number('3220072')->is_valid_number, '栃木県鹿沼市玉田町');
ok($zip->set_number('3220073')->is_valid_number, '栃木県鹿沼市西鹿沼町');
ok($zip->set_number('3220074')->is_valid_number, '栃木県鹿沼市日吉町');
ok($zip->set_number('3220075')->is_valid_number, '栃木県鹿沼市下日向');
ok($zip->set_number('3220076')->is_valid_number, '栃木県鹿沼市上日向');
ok($zip->set_number('3220077')->is_valid_number, '栃木県鹿沼市深岩');
ok($zip->set_number('3220078')->is_valid_number, '栃木県鹿沼市笹原田');
ok($zip->set_number('3220079')->is_valid_number, '栃木県鹿沼市下遠部');
ok($zip->set_number('3220101')->is_valid_number, '栃木県鹿沼市草久');
ok($zip->set_number('3220102')->is_valid_number, '栃木県鹿沼市上大久保');
ok($zip->set_number('3220103')->is_valid_number, '栃木県鹿沼市下大久保');
ok($zip->set_number('3220251')->is_valid_number, '栃木県鹿沼市野尻');
ok($zip->set_number('3220252')->is_valid_number, '栃木県鹿沼市加園');
ok($zip->set_number('3220253')->is_valid_number, '栃木県鹿沼市下久我');
ok($zip->set_number('3220254')->is_valid_number, '栃木県鹿沼市上久我');
ok($zip->set_number('3220255')->is_valid_number, '栃木県鹿沼市引田');
ok($zip->set_number('3220256')->is_valid_number, '栃木県鹿沼市下沢');
ok($zip->set_number('3220301')->is_valid_number, '栃木県鹿沼市北半田');
ok($zip->set_number('3220302')->is_valid_number, '栃木県鹿沼市深程');
ok($zip->set_number('3220303')->is_valid_number, '栃木県鹿沼市久野');
ok($zip->set_number('3220304')->is_valid_number, '栃木県鹿沼市柏木');
ok($zip->set_number('3220305')->is_valid_number, '栃木県鹿沼市口粟野');
ok($zip->set_number('3220306')->is_valid_number, '栃木県鹿沼市中粟野');
ok($zip->set_number('3220307')->is_valid_number, '栃木県鹿沼市入粟野');
ok($zip->set_number('3220341')->is_valid_number, '栃木県鹿沼市下南摩町');
ok($zip->set_number('3220342')->is_valid_number, '栃木県鹿沼市油田町');
ok($zip->set_number('3220343')->is_valid_number, '栃木県鹿沼市佐目町');
ok($zip->set_number('3220344')->is_valid_number, '栃木県鹿沼市西沢町');
ok($zip->set_number('3220345')->is_valid_number, '栃木県鹿沼市旭が丘');
ok($zip->set_number('3220346')->is_valid_number, '栃木県鹿沼市上南摩町');
ok($zip->set_number('3220421')->is_valid_number, '栃木県鹿沼市下粕尾');
ok($zip->set_number('3220422')->is_valid_number, '栃木県鹿沼市中粕尾');
ok($zip->set_number('3220423')->is_valid_number, '栃木県鹿沼市上粕尾');
ok($zip->set_number('3220521')->is_valid_number, '栃木県鹿沼市日光奈良部町');
ok($zip->set_number('3220522')->is_valid_number, '栃木県鹿沼市上奈良部町');
ok($zip->set_number('3220523')->is_valid_number, '栃木県鹿沼市下奈良部町');
ok($zip->set_number('3220524')->is_valid_number, '栃木県鹿沼市みなみ町');
ok($zip->set_number('3220525')->is_valid_number, '栃木県鹿沼市大和田町');
ok($zip->set_number('3220526')->is_valid_number, '栃木県鹿沼市楡木町');
ok($zip->set_number('3220527')->is_valid_number, '栃木県鹿沼市塩山町');
ok($zip->set_number('3220528')->is_valid_number, '栃木県鹿沼市奈佐原町');
ok($zip->set_number('3220531')->is_valid_number, '栃木県鹿沼市南上野町');
ok($zip->set_number('3220532')->is_valid_number, '栃木県鹿沼市藤江町');
ok($zip->set_number('3220533')->is_valid_number, '栃木県鹿沼市北赤塚町');
ok($zip->set_number('3220534')->is_valid_number, '栃木県鹿沼市亀和田町');
ok($zip->set_number('3220535')->is_valid_number, '栃木県鹿沼市野沢町');
ok($zip->set_number('3220536')->is_valid_number, '栃木県鹿沼市磯町');
ok($zip->set_number('3220601')->is_valid_number, '栃木県栃木市西方町金崎');
ok($zip->set_number('3220602')->is_valid_number, '栃木県栃木市西方町金井');
ok($zip->set_number('3220603')->is_valid_number, '栃木県栃木市西方町本郷');
ok($zip->set_number('3220604')->is_valid_number, '栃木県栃木市西方町元');
ok($zip->set_number('3220605')->is_valid_number, '栃木県栃木市西方町真名子');
ok($zip->set_number('3220606')->is_valid_number, '栃木県栃木市西方町本城');
ok($zip->set_number('3230000')->is_valid_number, '栃木県小山市以下に掲載がない場合');
ok($zip->set_number('3230001')->is_valid_number, '栃木県小山市小宅');
ok($zip->set_number('3230002')->is_valid_number, '栃木県小山市黒本');
ok($zip->set_number('3230003')->is_valid_number, '栃木県小山市東島田');
ok($zip->set_number('3230004')->is_valid_number, '栃木県小山市島田');
ok($zip->set_number('3230005')->is_valid_number, '栃木県小山市渋井');
ok($zip->set_number('3230006')->is_valid_number, '栃木県小山市荒川');
ok($zip->set_number('3230007')->is_valid_number, '栃木県小山市松沼');
ok($zip->set_number('3230008')->is_valid_number, '栃木県小山市小薬');
ok($zip->set_number('3230009')->is_valid_number, '栃木県小山市大本');
ok($zip->set_number('3230011')->is_valid_number, '栃木県小山市南半田');
ok($zip->set_number('3230012')->is_valid_number, '栃木県小山市羽川');
ok($zip->set_number('3230013')->is_valid_number, '栃木県小山市荒井');
ok($zip->set_number('3230014')->is_valid_number, '栃木県小山市喜沢');
ok($zip->set_number('3230015')->is_valid_number, '栃木県小山市三拝川岸');
ok($zip->set_number('3230016')->is_valid_number, '栃木県小山市扶桑');
ok($zip->set_number('3230017')->is_valid_number, '栃木県小山市飯塚');
ok($zip->set_number('3230021')->is_valid_number, '栃木県小山市稲葉郷');
ok($zip->set_number('3230022')->is_valid_number, '栃木県小山市駅東通り');
ok($zip->set_number('3230023')->is_valid_number, '栃木県小山市中央町');
ok($zip->set_number('3230024')->is_valid_number, '栃木県小山市宮本町');
ok($zip->set_number('3230025')->is_valid_number, '栃木県小山市城山町');
ok($zip->set_number('3230026')->is_valid_number, '栃木県小山市本郷町');
ok($zip->set_number('3230027')->is_valid_number, '栃木県小山市花垣町');
ok($zip->set_number('3230028')->is_valid_number, '栃木県小山市若木町');
ok($zip->set_number('3230029')->is_valid_number, '栃木県小山市城北');
ok($zip->set_number('3230031')->is_valid_number, '栃木県小山市八幡町');
ok($zip->set_number('3230032')->is_valid_number, '栃木県小山市天神町');
ok($zip->set_number('3230033')->is_valid_number, '栃木県小山市神明町');
ok($zip->set_number('3230034')->is_valid_number, '栃木県小山市神鳥谷(丁目)');
ok($zip->set_number('3230041')->is_valid_number, '栃木県小山市大行寺');
ok($zip->set_number('3230042')->is_valid_number, '栃木県小山市外城');
ok($zip->set_number('3230043')->is_valid_number, '栃木県小山市塩沢');
ok($zip->set_number('3230044')->is_valid_number, '栃木県小山市間中');
ok($zip->set_number('3230045')->is_valid_number, '栃木県小山市石ノ上');
ok($zip->set_number('3230046')->is_valid_number, '栃木県小山市萩島');
ok($zip->set_number('3230051')->is_valid_number, '栃木県小山市生駒');
ok($zip->set_number('3230052')->is_valid_number, '栃木県小山市下河原田');
ok($zip->set_number('3230053')->is_valid_number, '栃木県小山市小袋');
ok($zip->set_number('3230054')->is_valid_number, '栃木県小山市井岡');
ok($zip->set_number('3230055')->is_valid_number, '栃木県小山市下泉');
ok($zip->set_number('3230056')->is_valid_number, '栃木県小山市上泉');
ok($zip->set_number('3230057')->is_valid_number, '栃木県小山市南小林');
ok($zip->set_number('3230058')->is_valid_number, '栃木県小山市大川島');
ok($zip->set_number('3230061')->is_valid_number, '栃木県小山市卒島');
ok($zip->set_number('3230062')->is_valid_number, '栃木県小山市立木');
ok($zip->set_number('3230063')->is_valid_number, '栃木県小山市上石塚');
ok($zip->set_number('3230064')->is_valid_number, '栃木県小山市下石塚');
ok($zip->set_number('3230065')->is_valid_number, '栃木県小山市下国府塚');
ok($zip->set_number('3230066')->is_valid_number, '栃木県小山市上国府塚');
ok($zip->set_number('3230067')->is_valid_number, '栃木県小山市今里');
ok($zip->set_number('3230068')->is_valid_number, '栃木県小山市下初田');
ok($zip->set_number('3230069')->is_valid_number, '栃木県小山市上初田');
ok($zip->set_number('3230101')->is_valid_number, '栃木県下野市三王山');
ok($zip->set_number('3230102')->is_valid_number, '栃木県下野市上吉田');
ok($zip->set_number('3230103')->is_valid_number, '栃木県下野市上川島');
ok($zip->set_number('3230104')->is_valid_number, '栃木県下野市中川島');
ok($zip->set_number('3230105')->is_valid_number, '栃木県下野市本吉田');
ok($zip->set_number('3230106')->is_valid_number, '栃木県下野市下吉田');
ok($zip->set_number('3230107')->is_valid_number, '栃木県下野市別当河原');
ok($zip->set_number('3230111')->is_valid_number, '栃木県下野市磯部');
ok($zip->set_number('3230112')->is_valid_number, '栃木県下野市東根');
ok($zip->set_number('3230113')->is_valid_number, '栃木県下野市上坪山');
ok($zip->set_number('3230114')->is_valid_number, '栃木県下野市絹板');
ok($zip->set_number('3230115')->is_valid_number, '栃木県下野市下坪山');
ok($zip->set_number('3230116')->is_valid_number, '栃木県下野市花田');
ok($zip->set_number('3230151')->is_valid_number, '栃木県小山市田川');
ok($zip->set_number('3230152')->is_valid_number, '栃木県小山市延島');
ok($zip->set_number('3230153')->is_valid_number, '栃木県小山市延島新田');
ok($zip->set_number('3230154')->is_valid_number, '栃木県小山市高椅');
ok($zip->set_number('3230155')->is_valid_number, '栃木県小山市福良');
ok($zip->set_number('3230156')->is_valid_number, '栃木県小山市中島');
ok($zip->set_number('3230157')->is_valid_number, '栃木県小山市中河原');
ok($zip->set_number('3230158')->is_valid_number, '栃木県小山市梁');
ok($zip->set_number('3230801')->is_valid_number, '栃木県小山市鉢形');
ok($zip->set_number('3230802')->is_valid_number, '栃木県小山市東山田');
ok($zip->set_number('3230803')->is_valid_number, '栃木県小山市北飯田');
ok($zip->set_number('3230804')->is_valid_number, '栃木県小山市萱橋');
ok($zip->set_number('3230805')->is_valid_number, '栃木県小山市向野');
ok($zip->set_number('3230806')->is_valid_number, '栃木県小山市中久喜');
ok($zip->set_number('3230807')->is_valid_number, '栃木県小山市城東');
ok($zip->set_number('3230808')->is_valid_number, '栃木県小山市出井');
ok($zip->set_number('3230811')->is_valid_number, '栃木県小山市犬塚');
ok($zip->set_number('3230812')->is_valid_number, '栃木県小山市土塔');
ok($zip->set_number('3230813')->is_valid_number, '栃木県小山市横倉');
ok($zip->set_number('3230814')->is_valid_number, '栃木県小山市田間');
ok($zip->set_number('3230815')->is_valid_number, '栃木県小山市武井');
ok($zip->set_number('3230816')->is_valid_number, '栃木県小山市南和泉');
ok($zip->set_number('3230817')->is_valid_number, '栃木県小山市東野田');
ok($zip->set_number('3230818')->is_valid_number, '栃木県小山市塚崎');
ok($zip->set_number('3230819')->is_valid_number, '栃木県小山市横倉新田');
ok($zip->set_number('3230820')->is_valid_number, '栃木県小山市西城南');
ok($zip->set_number('3230821')->is_valid_number, '栃木県小山市三峯');
ok($zip->set_number('3230822')->is_valid_number, '栃木県小山市駅南町');
ok($zip->set_number('3230823')->is_valid_number, '栃木県小山市向原新田');
ok($zip->set_number('3230824')->is_valid_number, '栃木県小山市雨ケ谷新田');
ok($zip->set_number('3230825')->is_valid_number, '栃木県小山市小山');
ok($zip->set_number('3230826')->is_valid_number, '栃木県小山市雨ケ谷');
ok($zip->set_number('3230827')->is_valid_number, '栃木県小山市神鳥谷(番地)');
ok($zip->set_number('3230828')->is_valid_number, '栃木県小山市神山');
ok($zip->set_number('3230829')->is_valid_number, '栃木県小山市東城南');
ok($zip->set_number('3230831')->is_valid_number, '栃木県小山市雨ケ谷町');
ok($zip->set_number('3231101')->is_valid_number, '栃木県栃木市藤岡町大前');
ok($zip->set_number('3231102')->is_valid_number, '栃木県栃木市藤岡町赤麻');
ok($zip->set_number('3231103')->is_valid_number, '栃木県栃木市藤岡町内野');
ok($zip->set_number('3231104')->is_valid_number, '栃木県栃木市藤岡町藤岡');
ok($zip->set_number('3231105')->is_valid_number, '栃木県栃木市藤岡町甲');
ok($zip->set_number('3231106')->is_valid_number, '栃木県栃木市藤岡町都賀');
ok($zip->set_number('3231107')->is_valid_number, '栃木県栃木市藤岡町大田和');
ok($zip->set_number('3231108')->is_valid_number, '栃木県栃木市藤岡町太田');
ok($zip->set_number('3240000')->is_valid_number, '栃木県大田原市以下に掲載がない場合');
ok($zip->set_number('3240001')->is_valid_number, '栃木県大田原市乙連沢');
ok($zip->set_number('3240002')->is_valid_number, '栃木県大田原市羽田');
ok($zip->set_number('3240003')->is_valid_number, '栃木県大田原市小滝');
ok($zip->set_number('3240004')->is_valid_number, '栃木県大田原市富池');
ok($zip->set_number('3240005')->is_valid_number, '栃木県大田原市練貫');
ok($zip->set_number('3240006')->is_valid_number, '栃木県大田原市市野沢');
ok($zip->set_number('3240011')->is_valid_number, '栃木県大田原市北金丸');
ok($zip->set_number('3240012')->is_valid_number, '栃木県大田原市南金丸');
ok($zip->set_number('3240013')->is_valid_number, '栃木県大田原市鹿畑');
ok($zip->set_number('3240014')->is_valid_number, '栃木県大田原市倉骨');
ok($zip->set_number('3240015')->is_valid_number, '栃木県大田原市赤瀬');
ok($zip->set_number('3240016')->is_valid_number, '栃木県大田原市北大和久');
ok($zip->set_number('3240017')->is_valid_number, '栃木県大田原市奥沢');
ok($zip->set_number('3240018')->is_valid_number, '栃木県大田原市上奥沢');
ok($zip->set_number('3240021')->is_valid_number, '栃木県大田原市若草');
ok($zip->set_number('3240022')->is_valid_number, '栃木県大田原市宇田川');
ok($zip->set_number('3240023')->is_valid_number, '栃木県大田原市花園');
ok($zip->set_number('3240024')->is_valid_number, '栃木県大田原市福原');
ok($zip->set_number('3240025')->is_valid_number, '栃木県大田原市大神');
ok($zip->set_number('3240026')->is_valid_number, '栃木県大田原市滝岡');
ok($zip->set_number('3240027')->is_valid_number, '栃木県大田原市荻野目');
ok($zip->set_number('3240028')->is_valid_number, '栃木県大田原市富士見');
ok($zip->set_number('3240031')->is_valid_number, '栃木県大田原市藤沢');
ok($zip->set_number('3240032')->is_valid_number, '栃木県大田原市佐久山');
ok($zip->set_number('3240033')->is_valid_number, '栃木県大田原市滝沢');
ok($zip->set_number('3240034')->is_valid_number, '栃木県大田原市平沢');
ok($zip->set_number('3240035')->is_valid_number, '栃木県大田原市薄葉');
ok($zip->set_number('3240036')->is_valid_number, '栃木県大田原市下石上');
ok($zip->set_number('3240037')->is_valid_number, '栃木県大田原市上石上');
ok($zip->set_number('3240038')->is_valid_number, '栃木県大田原市野崎');
ok($zip->set_number('3240041')->is_valid_number, '栃木県大田原市本町');
ok($zip->set_number('3240042')->is_valid_number, '栃木県大田原市末広');
ok($zip->set_number('3240043')->is_valid_number, '栃木県大田原市浅香');
ok($zip->set_number('3240044')->is_valid_number, '栃木県大田原市親園');
ok($zip->set_number('3240045')->is_valid_number, '栃木県大田原市実取');
ok($zip->set_number('3240046')->is_valid_number, '栃木県大田原市加治屋');
ok($zip->set_number('3240047')->is_valid_number, '栃木県大田原市美原');
ok($zip->set_number('3240051')->is_valid_number, '栃木県大田原市山の手');
ok($zip->set_number('3240052')->is_valid_number, '栃木県大田原市城山');
ok($zip->set_number('3240053')->is_valid_number, '栃木県大田原市元町');
ok($zip->set_number('3240054')->is_valid_number, '栃木県大田原市若松町');
ok($zip->set_number('3240055')->is_valid_number, '栃木県大田原市新富町');
ok($zip->set_number('3240056')->is_valid_number, '栃木県大田原市中央');
ok($zip->set_number('3240057')->is_valid_number, '栃木県大田原市住吉町');
ok($zip->set_number('3240058')->is_valid_number, '栃木県大田原市紫塚');
ok($zip->set_number('3240061')->is_valid_number, '栃木県大田原市荒井');
ok($zip->set_number('3240062')->is_valid_number, '栃木県大田原市中田原');
ok($zip->set_number('3240063')->is_valid_number, '栃木県大田原市町島');
ok($zip->set_number('3240064')->is_valid_number, '栃木県大田原市今泉');
ok($zip->set_number('3240065')->is_valid_number, '栃木県大田原市岡');
ok($zip->set_number('3240066')->is_valid_number, '栃木県大田原市戸野内');
ok($zip->set_number('3240201')->is_valid_number, '栃木県大田原市両郷');
ok($zip->set_number('3240202')->is_valid_number, '栃木県大田原市木佐美');
ok($zip->set_number('3240203')->is_valid_number, '栃木県大田原市寺宿');
ok($zip->set_number('3240204')->is_valid_number, '栃木県大田原市大久保');
ok($zip->set_number('3240205')->is_valid_number, '栃木県大田原市久野又');
ok($zip->set_number('3240206')->is_valid_number, '栃木県大田原市中野内');
ok($zip->set_number('3240207')->is_valid_number, '栃木県大田原市河原');
ok($zip->set_number('3240208')->is_valid_number, '栃木県大田原市川田');
ok($zip->set_number('3240211')->is_valid_number, '栃木県大田原市須賀川');
ok($zip->set_number('3240212')->is_valid_number, '栃木県大田原市須佐木');
ok($zip->set_number('3240213')->is_valid_number, '栃木県大田原市雲岩寺');
ok($zip->set_number('3240214')->is_valid_number, '栃木県大田原市川上');
ok($zip->set_number('3240215')->is_valid_number, '栃木県大田原市南方');
ok($zip->set_number('3240221')->is_valid_number, '栃木県大田原市亀久');
ok($zip->set_number('3240222')->is_valid_number, '栃木県大田原市矢倉');
ok($zip->set_number('3240223')->is_valid_number, '栃木県大田原市片田');
ok($zip->set_number('3240224')->is_valid_number, '栃木県大田原市北滝');
ok($zip->set_number('3240231')->is_valid_number, '栃木県大田原市北野上');
ok($zip->set_number('3240232')->is_valid_number, '栃木県大田原市八塩');
ok($zip->set_number('3240233')->is_valid_number, '栃木県大田原市黒羽田町');
ok($zip->set_number('3240234')->is_valid_number, '栃木県大田原市前田');
ok($zip->set_number('3240235')->is_valid_number, '栃木県大田原市堀之内');
ok($zip->set_number('3240236')->is_valid_number, '栃木県大田原市大輪');
ok($zip->set_number('3240241')->is_valid_number, '栃木県大田原市黒羽向町');
ok($zip->set_number('3240242')->is_valid_number, '栃木県大田原市大豆田');
ok($zip->set_number('3240243')->is_valid_number, '栃木県大田原市余瀬');
ok($zip->set_number('3240244')->is_valid_number, '栃木県大田原市蜂巣');
ok($zip->set_number('3240245')->is_valid_number, '栃木県大田原市桧木沢');
ok($zip->set_number('3240246')->is_valid_number, '栃木県大田原市寒井');
ok($zip->set_number('3240401')->is_valid_number, '栃木県大田原市狭原');
ok($zip->set_number('3240402')->is_valid_number, '栃木県大田原市小船渡');
ok($zip->set_number('3240403')->is_valid_number, '栃木県大田原市湯津上');
ok($zip->set_number('3240404')->is_valid_number, '栃木県大田原市佐良土');
ok($zip->set_number('3240405')->is_valid_number, '栃木県大田原市中の原');
ok($zip->set_number('3240411')->is_valid_number, '栃木県大田原市蛭畑');
ok($zip->set_number('3240412')->is_valid_number, '栃木県大田原市蛭田');
ok($zip->set_number('3240413')->is_valid_number, '栃木県大田原市新宿');
ok($zip->set_number('3240414')->is_valid_number, '栃木県大田原市片府田');
ok($zip->set_number('3240415')->is_valid_number, '栃木県大田原市品川');
ok($zip->set_number('3240501')->is_valid_number, '栃木県那須郡那珂川町小川');
ok($zip->set_number('3240502')->is_valid_number, '栃木県那須郡那珂川町三輪');
ok($zip->set_number('3240503')->is_valid_number, '栃木県那須郡那珂川町恩田');
ok($zip->set_number('3240504')->is_valid_number, '栃木県那須郡那珂川町薬利');
ok($zip->set_number('3240505')->is_valid_number, '栃木県那須郡那珂川町芳井');
ok($zip->set_number('3240506')->is_valid_number, '栃木県那須郡那珂川町浄法寺');
ok($zip->set_number('3240511')->is_valid_number, '栃木県那須郡那珂川町吉田');
ok($zip->set_number('3240512')->is_valid_number, '栃木県那須郡那珂川町谷田');
ok($zip->set_number('3240513')->is_valid_number, '栃木県那須郡那珂川町白久');
ok($zip->set_number('3240514')->is_valid_number, '栃木県那須郡那珂川町高岡');
ok($zip->set_number('3240515')->is_valid_number, '栃木県那須郡那珂川町片平');
ok($zip->set_number('3240516')->is_valid_number, '栃木県那須郡那珂川町東戸田');
ok($zip->set_number('3240600')->is_valid_number, '栃木県那須郡那珂川町以下に掲載がない場合');
ok($zip->set_number('3240601')->is_valid_number, '栃木県那須郡那珂川町大山田上郷');
ok($zip->set_number('3240602')->is_valid_number, '栃木県那須郡那珂川町大山田下郷');
ok($zip->set_number('3240603')->is_valid_number, '栃木県那須郡那珂川町谷川');
ok($zip->set_number('3240604')->is_valid_number, '栃木県那須郡那珂川町盛泉');
ok($zip->set_number('3240605')->is_valid_number, '栃木県那須郡那珂川町大内');
ok($zip->set_number('3240606')->is_valid_number, '栃木県那須郡那珂川町大那地');
ok($zip->set_number('3240607')->is_valid_number, '栃木県那須郡那珂川町矢又');
ok($zip->set_number('3240608')->is_valid_number, '栃木県那須郡那珂川町健武');
ok($zip->set_number('3240611')->is_valid_number, '栃木県那須郡那珂川町小砂');
ok($zip->set_number('3240612')->is_valid_number, '栃木県那須郡那珂川町和見');
ok($zip->set_number('3240613')->is_valid_number, '栃木県那須郡那珂川町馬頭');
ok($zip->set_number('3240614')->is_valid_number, '栃木県那須郡那珂川町久那瀬');
ok($zip->set_number('3240615')->is_valid_number, '栃木県那須郡那珂川町松野');
ok($zip->set_number('3240616')->is_valid_number, '栃木県那須郡那珂川町富山');
ok($zip->set_number('3240617')->is_valid_number, '栃木県那須郡那珂川町北向田');
ok($zip->set_number('3240618')->is_valid_number, '栃木県那須郡那珂川町小口');
ok($zip->set_number('3250000')->is_valid_number, '栃木県那須塩原市以下に掲載がない場合');
ok($zip->set_number('3250001')->is_valid_number, '栃木県那須郡那須町高久甲(その他)');
ok($zip->set_number('3250002')->is_valid_number, '栃木県那須郡那須町高久丙(穂積、山梨子)');
ok($zip->set_number('3250003')->is_valid_number, '栃木県那須郡那須町寺子乙(720番地)');
ok($zip->set_number('3250011')->is_valid_number, '栃木県那須塩原市寺子');
ok($zip->set_number('3250012')->is_valid_number, '栃木県那須塩原市越堀');
ok($zip->set_number('3250013')->is_valid_number, '栃木県那須塩原市鍋掛');
ok($zip->set_number('3250014')->is_valid_number, '栃木県那須塩原市野間');
ok($zip->set_number('3250015')->is_valid_number, '栃木県那須塩原市原町');
ok($zip->set_number('3250016')->is_valid_number, '栃木県那須塩原市東栄');
ok($zip->set_number('3250017')->is_valid_number, '栃木県那須塩原市黒磯');
ok($zip->set_number('3250021')->is_valid_number, '栃木県那須塩原市安藤町');
ok($zip->set_number('3250022')->is_valid_number, '栃木県那須塩原市東豊浦');
ok($zip->set_number('3250023')->is_valid_number, '栃木県那須塩原市豊浦');
ok($zip->set_number('3250024')->is_valid_number, '栃木県那須塩原市渡辺');
ok($zip->set_number('3250025')->is_valid_number, '栃木県那須塩原市下厚崎');
ok($zip->set_number('3250026')->is_valid_number, '栃木県那須塩原市上厚崎');
ok($zip->set_number('3250027')->is_valid_number, '栃木県那須塩原市共墾社');
ok($zip->set_number('3250031')->is_valid_number, '栃木県那須塩原市並木町');
ok($zip->set_number('3250032')->is_valid_number, '栃木県那須塩原市若草町');
ok($zip->set_number('3250033')->is_valid_number, '栃木県那須塩原市埼玉');
ok($zip->set_number('3250034')->is_valid_number, '栃木県那須塩原市東原');
ok($zip->set_number('3250035')->is_valid_number, '栃木県那須塩原市小結');
ok($zip->set_number('3250036')->is_valid_number, '栃木県那須塩原市鳥野目');
ok($zip->set_number('3250037')->is_valid_number, '栃木県那須塩原市美原町');
ok($zip->set_number('3250038')->is_valid_number, '栃木県那須塩原市豊浦北町');
ok($zip->set_number('3250039')->is_valid_number, '栃木県那須塩原市北栄町');
ok($zip->set_number('3250041')->is_valid_number, '栃木県那須塩原市東大和町');
ok($zip->set_number('3250042')->is_valid_number, '栃木県那須塩原市桜町');
ok($zip->set_number('3250043')->is_valid_number, '栃木県那須塩原市橋本町');
ok($zip->set_number('3250044')->is_valid_number, '栃木県那須塩原市弥生町');
ok($zip->set_number('3250045')->is_valid_number, '栃木県那須塩原市高砂町');
ok($zip->set_number('3250046')->is_valid_number, '栃木県那須塩原市大黒町');
ok($zip->set_number('3250047')->is_valid_number, '栃木県那須塩原市若葉町');
ok($zip->set_number('3250048')->is_valid_number, '栃木県那須塩原市材木町');
ok($zip->set_number('3250051')->is_valid_number, '栃木県那須塩原市豊町');
ok($zip->set_number('3250052')->is_valid_number, '栃木県那須塩原市中央町');
ok($zip->set_number('3250053')->is_valid_number, '栃木県那須塩原市本郷町');
ok($zip->set_number('3250054')->is_valid_number, '栃木県那須塩原市新朝日');
ok($zip->set_number('3250055')->is_valid_number, '栃木県那須塩原市宮町');
ok($zip->set_number('3250056')->is_valid_number, '栃木県那須塩原市本町');
ok($zip->set_number('3250057')->is_valid_number, '栃木県那須塩原市黒磯幸町');
ok($zip->set_number('3250058')->is_valid_number, '栃木県那須塩原市錦町');
ok($zip->set_number('3250061')->is_valid_number, '栃木県那須塩原市末広町');
ok($zip->set_number('3250062')->is_valid_number, '栃木県那須塩原市住吉町');
ok($zip->set_number('3250063')->is_valid_number, '栃木県那須塩原市豊浦中町');
ok($zip->set_number('3250064')->is_valid_number, '栃木県那須塩原市豊浦町');
ok($zip->set_number('3250065')->is_valid_number, '栃木県那須塩原市豊浦南町');
ok($zip->set_number('3250066')->is_valid_number, '栃木県那須塩原市新緑町');
ok($zip->set_number('3250067')->is_valid_number, '栃木県那須塩原市清住町');
ok($zip->set_number('3250071')->is_valid_number, '栃木県那須塩原市新町');
ok($zip->set_number('3250072')->is_valid_number, '栃木県那須塩原市豊住町');
ok($zip->set_number('3250073')->is_valid_number, '栃木県那須塩原市阿波町');
ok($zip->set_number('3250074')->is_valid_number, '栃木県那須塩原市松浦町');
ok($zip->set_number('3250075')->is_valid_number, '栃木県那須塩原市春日町');
ok($zip->set_number('3250076')->is_valid_number, '栃木県那須塩原市西新町');
ok($zip->set_number('3250101')->is_valid_number, '栃木県那須塩原市西岩崎');
ok($zip->set_number('3250102')->is_valid_number, '栃木県那須塩原市亀山');
ok($zip->set_number('3250103')->is_valid_number, '栃木県那須塩原市青木');
ok($zip->set_number('3250104')->is_valid_number, '栃木県那須塩原市鹿野崎新田');
ok($zip->set_number('3250105')->is_valid_number, '栃木県那須塩原市箕輪');
ok($zip->set_number('3250106')->is_valid_number, '栃木県那須塩原市洞島');
ok($zip->set_number('3250107')->is_valid_number, '栃木県那須塩原市高林');
ok($zip->set_number('3250108')->is_valid_number, '栃木県那須塩原市箭坪');
ok($zip->set_number('3250111')->is_valid_number, '栃木県那須塩原市板室');
ok($zip->set_number('3250112')->is_valid_number, '栃木県那須塩原市油井');
ok($zip->set_number('3250113')->is_valid_number, '栃木県那須塩原市細竹');
ok($zip->set_number('3250114')->is_valid_number, '栃木県那須塩原市戸田');
ok($zip->set_number('3250115')->is_valid_number, '栃木県那須塩原市百村');
ok($zip->set_number('3250116')->is_valid_number, '栃木県那須塩原市木綿畑');
ok($zip->set_number('3250117')->is_valid_number, '栃木県那須塩原市湯宮');
ok($zip->set_number('3250118')->is_valid_number, '栃木県那須塩原市鴫内');
ok($zip->set_number('3250301')->is_valid_number, '栃木県那須郡那須町湯本');
ok($zip->set_number('3250302')->is_valid_number, '栃木県那須郡那須町高久丙(その他)');
ok($zip->set_number('3250303')->is_valid_number, '栃木県那須郡那須町高久乙');
ok($zip->set_number('3250304')->is_valid_number, '栃木県那須郡那須町高久甲(2888、4595、5235~6019、6021~6112、');
ok($zip->set_number('3250304')->is_valid_number, '栃木県那須郡那須町6114~6141、6328、6437、6438)');
ok($zip->set_number('3260000')->is_valid_number, '栃木県足利市以下に掲載がない場合');
ok($zip->set_number('3260001')->is_valid_number, '栃木県足利市名草上町');
ok($zip->set_number('3260002')->is_valid_number, '栃木県足利市名草中町');
ok($zip->set_number('3260003')->is_valid_number, '栃木県足利市名草下町');
ok($zip->set_number('3260004')->is_valid_number, '栃木県足利市樺崎町');
ok($zip->set_number('3260005')->is_valid_number, '栃木県足利市大月町');
ok($zip->set_number('3260006')->is_valid_number, '栃木県足利市利保町');
ok($zip->set_number('3260007')->is_valid_number, '栃木県足利市菅田町');
ok($zip->set_number('3260011')->is_valid_number, '栃木県足利市大沼田町');
ok($zip->set_number('3260012')->is_valid_number, '栃木県足利市大久保町');
ok($zip->set_number('3260013')->is_valid_number, '栃木県足利市川崎町');
ok($zip->set_number('3260014')->is_valid_number, '栃木県足利市鵤木町');
ok($zip->set_number('3260015')->is_valid_number, '栃木県足利市八椚町');
ok($zip->set_number('3260016')->is_valid_number, '栃木県足利市毛野新町');
ok($zip->set_number('3260021')->is_valid_number, '栃木県足利市山川町');
ok($zip->set_number('3260022')->is_valid_number, '栃木県足利市常見町');
ok($zip->set_number('3260023')->is_valid_number, '栃木県足利市猿田町');
ok($zip->set_number('3260024')->is_valid_number, '栃木県足利市若草町');
ok($zip->set_number('3260025')->is_valid_number, '栃木県足利市寿町');
ok($zip->set_number('3260026')->is_valid_number, '栃木県足利市常盤町');
ok($zip->set_number('3260027')->is_valid_number, '栃木県足利市宮北町');
ok($zip->set_number('3260031')->is_valid_number, '栃木県足利市末広町');
ok($zip->set_number('3260032')->is_valid_number, '栃木県足利市真砂町');
ok($zip->set_number('3260033')->is_valid_number, '栃木県足利市花園町');
ok($zip->set_number('3260034')->is_valid_number, '栃木県足利市久松町');
ok($zip->set_number('3260035')->is_valid_number, '栃木県足利市芳町');
ok($zip->set_number('3260036')->is_valid_number, '栃木県足利市弥生町');
ok($zip->set_number('3260037')->is_valid_number, '栃木県足利市富士見町');
ok($zip->set_number('3260041')->is_valid_number, '栃木県足利市助戸新山町');
ok($zip->set_number('3260042')->is_valid_number, '栃木県足利市助戸東山町');
ok($zip->set_number('3260043')->is_valid_number, '栃木県足利市助戸仲町');
ok($zip->set_number('3260044')->is_valid_number, '栃木県足利市助戸');
ok($zip->set_number('3260045')->is_valid_number, '栃木県足利市千歳町');
ok($zip->set_number('3260046')->is_valid_number, '栃木県足利市岩井町');
ok($zip->set_number('3260047')->is_valid_number, '栃木県足利市錦町');
ok($zip->set_number('3260048')->is_valid_number, '栃木県足利市助戸大橋町');
ok($zip->set_number('3260051')->is_valid_number, '栃木県足利市大橋町');
ok($zip->set_number('3260052')->is_valid_number, '栃木県足利市相生町');
ok($zip->set_number('3260053')->is_valid_number, '栃木県足利市伊勢町');
ok($zip->set_number('3260054')->is_valid_number, '栃木県足利市伊勢南町');
ok($zip->set_number('3260055')->is_valid_number, '栃木県足利市永楽町');
ok($zip->set_number('3260056')->is_valid_number, '栃木県足利市大町');
ok($zip->set_number('3260057')->is_valid_number, '栃木県足利市丸山町');
ok($zip->set_number('3260058')->is_valid_number, '栃木県足利市元学町');
ok($zip->set_number('3260061')->is_valid_number, '栃木県足利市田島町');
ok($zip->set_number('3260062')->is_valid_number, '栃木県足利市赤松台');
ok($zip->set_number('3260063')->is_valid_number, '栃木県足利市新山町');
ok($zip->set_number('3260064')->is_valid_number, '栃木県足利市東砂原後町');
ok($zip->set_number('3260065')->is_valid_number, '栃木県足利市西砂原後町');
ok($zip->set_number('3260066')->is_valid_number, '栃木県足利市田所町');
ok($zip->set_number('3260067')->is_valid_number, '栃木県足利市江川町');
ok($zip->set_number('3260068')->is_valid_number, '栃木県足利市月谷町');
ok($zip->set_number('3260101')->is_valid_number, '栃木県足利市松田町');
ok($zip->set_number('3260102')->is_valid_number, '栃木県足利市板倉町');
ok($zip->set_number('3260103')->is_valid_number, '栃木県足利市粟谷町');
ok($zip->set_number('3260141')->is_valid_number, '栃木県足利市小俣町');
ok($zip->set_number('3260142')->is_valid_number, '栃木県足利市小俣南町');
ok($zip->set_number('3260143')->is_valid_number, '栃木県足利市葉鹿町');
ok($zip->set_number('3260144')->is_valid_number, '栃木県足利市葉鹿南町');
ok($zip->set_number('3260321')->is_valid_number, '栃木県足利市梁田町');
ok($zip->set_number('3260322')->is_valid_number, '栃木県足利市野田町');
ok($zip->set_number('3260323')->is_valid_number, '栃木県足利市瑞穂野町');
ok($zip->set_number('3260324')->is_valid_number, '栃木県足利市久保田町');
ok($zip->set_number('3260325')->is_valid_number, '栃木県足利市高松町');
ok($zip->set_number('3260326')->is_valid_number, '栃木県足利市小曽根町');
ok($zip->set_number('3260327')->is_valid_number, '栃木県足利市羽刈町');
ok($zip->set_number('3260328')->is_valid_number, '栃木県足利市県町');
ok($zip->set_number('3260331')->is_valid_number, '栃木県足利市福富町');
ok($zip->set_number('3260332')->is_valid_number, '栃木県足利市福富新町');
ok($zip->set_number('3260333')->is_valid_number, '栃木県足利市問屋町');
ok($zip->set_number('3260334')->is_valid_number, '栃木県足利市下渋垂町');
ok($zip->set_number('3260335')->is_valid_number, '栃木県足利市上渋垂町');
ok($zip->set_number('3260336')->is_valid_number, '栃木県足利市百頭町');
ok($zip->set_number('3260337')->is_valid_number, '栃木県足利市島田町');
ok($zip->set_number('3260338')->is_valid_number, '栃木県足利市福居町');
ok($zip->set_number('3260801')->is_valid_number, '栃木県足利市有楽町');
ok($zip->set_number('3260802')->is_valid_number, '栃木県足利市旭町');
ok($zip->set_number('3260803')->is_valid_number, '栃木県足利市家富町');
ok($zip->set_number('3260804')->is_valid_number, '栃木県足利市雪輪町');
ok($zip->set_number('3260805')->is_valid_number, '栃木県足利市巴町');
ok($zip->set_number('3260806')->is_valid_number, '栃木県足利市柳原町');
ok($zip->set_number('3260807')->is_valid_number, '栃木県足利市大正町');
ok($zip->set_number('3260808')->is_valid_number, '栃木県足利市本城');
ok($zip->set_number('3260811')->is_valid_number, '栃木県足利市井草町');
ok($zip->set_number('3260812')->is_valid_number, '栃木県足利市大門通');
ok($zip->set_number('3260813')->is_valid_number, '栃木県足利市昌平町');
ok($zip->set_number('3260814')->is_valid_number, '栃木県足利市通');
ok($zip->set_number('3260815')->is_valid_number, '栃木県足利市栄町');
ok($zip->set_number('3260816')->is_valid_number, '栃木県足利市緑町');
ok($zip->set_number('3260817')->is_valid_number, '栃木県足利市西宮町');
ok($zip->set_number('3260821')->is_valid_number, '栃木県足利市南町');
ok($zip->set_number('3260822')->is_valid_number, '栃木県足利市田中町');
ok($zip->set_number('3260823')->is_valid_number, '栃木県足利市朝倉町');
ok($zip->set_number('3260824')->is_valid_number, '栃木県足利市八幡町');
ok($zip->set_number('3260825')->is_valid_number, '栃木県足利市中川町');
ok($zip->set_number('3260826')->is_valid_number, '栃木県足利市借宿町');
ok($zip->set_number('3260831')->is_valid_number, '栃木県足利市堀込町');
ok($zip->set_number('3260832')->is_valid_number, '栃木県足利市荒金町');
ok($zip->set_number('3260833')->is_valid_number, '栃木県足利市藤本町');
ok($zip->set_number('3260834')->is_valid_number, '栃木県足利市新宿町');
ok($zip->set_number('3260835')->is_valid_number, '栃木県足利市里矢場町');
ok($zip->set_number('3260836')->is_valid_number, '栃木県足利市南大町');
ok($zip->set_number('3260837')->is_valid_number, '栃木県足利市西新井町');
ok($zip->set_number('3260841')->is_valid_number, '栃木県足利市大岩町');
ok($zip->set_number('3260842')->is_valid_number, '栃木県足利市今福町');
ok($zip->set_number('3260843')->is_valid_number, '栃木県足利市五十部町');
ok($zip->set_number('3260844')->is_valid_number, '栃木県足利市鹿島町');
ok($zip->set_number('3260845')->is_valid_number, '栃木県足利市大前町');
ok($zip->set_number('3260846')->is_valid_number, '栃木県足利市山下町');
ok($zip->set_number('3270000')->is_valid_number, '栃木県佐野市以下に掲載がない場合');
ok($zip->set_number('3270001')->is_valid_number, '栃木県佐野市小中町');
ok($zip->set_number('3270002')->is_valid_number, '栃木県佐野市並木町');
ok($zip->set_number('3270003')->is_valid_number, '栃木県佐野市大橋町');
ok($zip->set_number('3270004')->is_valid_number, '栃木県佐野市赤坂町');
ok($zip->set_number('3270005')->is_valid_number, '栃木県佐野市七軒町');
ok($zip->set_number('3270006')->is_valid_number, '栃木県佐野市上台町');
ok($zip->set_number('3270007')->is_valid_number, '栃木県佐野市金吹町');
ok($zip->set_number('3270011')->is_valid_number, '栃木県佐野市朝日町');
ok($zip->set_number('3270012')->is_valid_number, '栃木県佐野市大蔵町');
ok($zip->set_number('3270013')->is_valid_number, '栃木県佐野市本町');
ok($zip->set_number('3270014')->is_valid_number, '栃木県佐野市天明町');
ok($zip->set_number('3270015')->is_valid_number, '栃木県佐野市金井上町');
ok($zip->set_number('3270016')->is_valid_number, '栃木県佐野市大祝町');
ok($zip->set_number('3270017')->is_valid_number, '栃木県佐野市大町');
ok($zip->set_number('3270021')->is_valid_number, '栃木県佐野市伊賀町');
ok($zip->set_number('3270022')->is_valid_number, '栃木県佐野市高砂町');
ok($zip->set_number('3270023')->is_valid_number, '栃木県佐野市相生町');
ok($zip->set_number('3270024')->is_valid_number, '栃木県佐野市亀井町');
ok($zip->set_number('3270025')->is_valid_number, '栃木県佐野市金屋下町');
ok($zip->set_number('3270026')->is_valid_number, '栃木県佐野市金屋仲町');
ok($zip->set_number('3270027')->is_valid_number, '栃木県佐野市大和町');
ok($zip->set_number('3270028')->is_valid_number, '栃木県佐野市万町');
ok($zip->set_number('3270031')->is_valid_number, '栃木県佐野市田島町');
ok($zip->set_number('3270032')->is_valid_number, '栃木県佐野市庚申塚町');
ok($zip->set_number('3270033')->is_valid_number, '栃木県佐野市大古屋町');
ok($zip->set_number('3270034')->is_valid_number, '栃木県佐野市伊保内町');
ok($zip->set_number('3270035')->is_valid_number, '栃木県佐野市船津川町');
ok($zip->set_number('3270041')->is_valid_number, '栃木県佐野市免鳥町');
ok($zip->set_number('3270042')->is_valid_number, '栃木県佐野市上羽田町');
ok($zip->set_number('3270043')->is_valid_number, '栃木県佐野市君田町');
ok($zip->set_number('3270044')->is_valid_number, '栃木県佐野市下羽田町');
ok($zip->set_number('3270045')->is_valid_number, '栃木県佐野市高橋町');
ok($zip->set_number('3270046')->is_valid_number, '栃木県佐野市村上町');
ok($zip->set_number('3270101')->is_valid_number, '栃木県佐野市寺久保町');
ok($zip->set_number('3270102')->is_valid_number, '栃木県佐野市出流原町');
ok($zip->set_number('3270103')->is_valid_number, '栃木県佐野市石塚町');
ok($zip->set_number('3270104')->is_valid_number, '栃木県佐野市赤見町');
ok($zip->set_number('3270231')->is_valid_number, '栃木県佐野市飛駒町');
ok($zip->set_number('3270301')->is_valid_number, '栃木県佐野市作原町');
ok($zip->set_number('3270302')->is_valid_number, '栃木県佐野市白岩町');
ok($zip->set_number('3270303')->is_valid_number, '栃木県佐野市長谷場町');
ok($zip->set_number('3270304')->is_valid_number, '栃木県佐野市御神楽町');
ok($zip->set_number('3270305')->is_valid_number, '栃木県佐野市船越町');
ok($zip->set_number('3270306')->is_valid_number, '栃木県佐野市戸室町');
ok($zip->set_number('3270307')->is_valid_number, '栃木県佐野市岩崎町');
ok($zip->set_number('3270311')->is_valid_number, '栃木県佐野市多田町');
ok($zip->set_number('3270312')->is_valid_number, '栃木県佐野市栃本町');
ok($zip->set_number('3270313')->is_valid_number, '栃木県佐野市吉水町');
ok($zip->set_number('3270314')->is_valid_number, '栃木県佐野市新吉水町');
ok($zip->set_number('3270315')->is_valid_number, '栃木県佐野市吉水駅前');
ok($zip->set_number('3270316')->is_valid_number, '栃木県佐野市小見町');
ok($zip->set_number('3270317')->is_valid_number, '栃木県佐野市田沼町');
ok($zip->set_number('3270318')->is_valid_number, '栃木県佐野市山越町');
ok($zip->set_number('3270321')->is_valid_number, '栃木県佐野市閑馬町');
ok($zip->set_number('3270322')->is_valid_number, '栃木県佐野市梅園町');
ok($zip->set_number('3270323')->is_valid_number, '栃木県佐野市戸奈良町');
ok($zip->set_number('3270324')->is_valid_number, '栃木県佐野市山形町');
ok($zip->set_number('3270325')->is_valid_number, '栃木県佐野市下彦間町');
ok($zip->set_number('3270501')->is_valid_number, '栃木県佐野市葛生東');
ok($zip->set_number('3270502')->is_valid_number, '栃木県佐野市築地町');
ok($zip->set_number('3270503')->is_valid_number, '栃木県佐野市富士見町');
ok($zip->set_number('3270504')->is_valid_number, '栃木県佐野市中町');
ok($zip->set_number('3270505')->is_valid_number, '栃木県佐野市山菅町');
ok($zip->set_number('3270507')->is_valid_number, '栃木県佐野市葛生西');
ok($zip->set_number('3270508')->is_valid_number, '栃木県佐野市鉢木町');
ok($zip->set_number('3270509')->is_valid_number, '栃木県佐野市宮下町');
ok($zip->set_number('3270511')->is_valid_number, '栃木県佐野市会沢町');
ok($zip->set_number('3270512')->is_valid_number, '栃木県佐野市豊代町');
ok($zip->set_number('3270513')->is_valid_number, '栃木県佐野市牧町');
ok($zip->set_number('3270514')->is_valid_number, '栃木県佐野市仙波町(その他)');
ok($zip->set_number('3270515')->is_valid_number, '栃木県佐野市柿平町');
ok($zip->set_number('3270516')->is_valid_number, '栃木県佐野市水木町');
ok($zip->set_number('3270517')->is_valid_number, '栃木県佐野市秋山町');
ok($zip->set_number('3270523')->is_valid_number, '栃木県佐野市嘉多山町');
ok($zip->set_number('3270524')->is_valid_number, '栃木県佐野市長坂町');
ok($zip->set_number('3270525')->is_valid_number, '栃木県佐野市あくと町');
ok($zip->set_number('3270801')->is_valid_number, '栃木県佐野市富士町');
ok($zip->set_number('3270802')->is_valid_number, '栃木県佐野市韮川町');
ok($zip->set_number('3270803')->is_valid_number, '栃木県佐野市犬伏新町');
ok($zip->set_number('3270804')->is_valid_number, '栃木県佐野市犬伏下町');
ok($zip->set_number('3270805')->is_valid_number, '栃木県佐野市犬伏中町');
ok($zip->set_number('3270806')->is_valid_number, '栃木県佐野市犬伏上町');
ok($zip->set_number('3270807')->is_valid_number, '栃木県佐野市大栗町');
ok($zip->set_number('3270811')->is_valid_number, '栃木県佐野市関川町');
ok($zip->set_number('3270812')->is_valid_number, '栃木県佐野市町谷町');
ok($zip->set_number('3270813')->is_valid_number, '栃木県佐野市黒袴町');
ok($zip->set_number('3270814')->is_valid_number, '栃木県佐野市西浦町');
ok($zip->set_number('3270815')->is_valid_number, '栃木県佐野市鐙塚町');
ok($zip->set_number('3270816')->is_valid_number, '栃木県佐野市栄町');
ok($zip->set_number('3270817')->is_valid_number, '栃木県佐野市伊勢山町');
ok($zip->set_number('3270818')->is_valid_number, '栃木県佐野市米山南町');
ok($zip->set_number('3270821')->is_valid_number, '栃木県佐野市高萩町');
ok($zip->set_number('3270822')->is_valid_number, '栃木県佐野市越名町');
ok($zip->set_number('3270823')->is_valid_number, '栃木県佐野市高山町');
ok($zip->set_number('3270824')->is_valid_number, '栃木県佐野市馬門町');
ok($zip->set_number('3270825')->is_valid_number, '栃木県佐野市飯田町');
ok($zip->set_number('3270826')->is_valid_number, '栃木県佐野市茂呂山町');
ok($zip->set_number('3270827')->is_valid_number, '栃木県佐野市北茂呂町');
ok($zip->set_number('3270831')->is_valid_number, '栃木県佐野市浅沼町');
ok($zip->set_number('3270832')->is_valid_number, '栃木県佐野市植上町');
ok($zip->set_number('3270833')->is_valid_number, '栃木県佐野市若宮上町');
ok($zip->set_number('3270834')->is_valid_number, '栃木県佐野市若宮下町');
ok($zip->set_number('3270835')->is_valid_number, '栃木県佐野市植下町');
ok($zip->set_number('3270836')->is_valid_number, '栃木県佐野市寺中町');
ok($zip->set_number('3270837')->is_valid_number, '栃木県佐野市植野町');
ok($zip->set_number('3270841')->is_valid_number, '栃木県佐野市田之入町');
ok($zip->set_number('3270842')->is_valid_number, '栃木県佐野市奈良渕町');
ok($zip->set_number('3270843')->is_valid_number, '栃木県佐野市堀米町');
ok($zip->set_number('3270844')->is_valid_number, '栃木県佐野市富岡町');
ok($zip->set_number('3270845')->is_valid_number, '栃木県佐野市久保町');
ok($zip->set_number('3270846')->is_valid_number, '栃木県佐野市若松町');
ok($zip->set_number('3270847')->is_valid_number, '栃木県佐野市天神町');
ok($zip->set_number('3280000')->is_valid_number, '栃木県栃木市以下に掲載がない場合');
ok($zip->set_number('3280001')->is_valid_number, '栃木県栃木市柳原町');
ok($zip->set_number('3280002')->is_valid_number, '栃木県栃木市惣社町');
ok($zip->set_number('3280003')->is_valid_number, '栃木県栃木市大光寺町');
ok($zip->set_number('3280004')->is_valid_number, '栃木県栃木市田村町');
ok($zip->set_number('3280005')->is_valid_number, '栃木県栃木市寄居町');
ok($zip->set_number('3280006')->is_valid_number, '栃木県栃木市国府町');
ok($zip->set_number('3280007')->is_valid_number, '栃木県栃木市大塚町');
ok($zip->set_number('3280011')->is_valid_number, '栃木県栃木市大宮町');
ok($zip->set_number('3280012')->is_valid_number, '栃木県栃木市平柳町');
ok($zip->set_number('3280013')->is_valid_number, '栃木県栃木市昭和町');
ok($zip->set_number('3280014')->is_valid_number, '栃木県栃木市泉町');
ok($zip->set_number('3280015')->is_valid_number, '栃木県栃木市万町');
ok($zip->set_number('3280016')->is_valid_number, '栃木県栃木市入舟町');
ok($zip->set_number('3280017')->is_valid_number, '栃木県栃木市錦町');
ok($zip->set_number('3280021')->is_valid_number, '栃木県栃木市久保田町');
ok($zip->set_number('3280022')->is_valid_number, '栃木県栃木市宮田町');
ok($zip->set_number('3280023')->is_valid_number, '栃木県栃木市高谷町');
ok($zip->set_number('3280024')->is_valid_number, '栃木県栃木市樋ノ口町');
ok($zip->set_number('3280025')->is_valid_number, '栃木県栃木市仲仕上町');
ok($zip->set_number('3280026')->is_valid_number, '栃木県栃木市藤田町');
ok($zip->set_number('3280027')->is_valid_number, '栃木県栃木市今泉町');
ok($zip->set_number('3280031')->is_valid_number, '栃木県栃木市日ノ出町');
ok($zip->set_number('3280032')->is_valid_number, '栃木県栃木市神田町');
ok($zip->set_number('3280033')->is_valid_number, '栃木県栃木市城内町');
ok($zip->set_number('3280034')->is_valid_number, '栃木県栃木市本町');
ok($zip->set_number('3280035')->is_valid_number, '栃木県栃木市旭町');
ok($zip->set_number('3280036')->is_valid_number, '栃木県栃木市室町');
ok($zip->set_number('3280037')->is_valid_number, '栃木県栃木市倭町');
ok($zip->set_number('3280041')->is_valid_number, '栃木県栃木市河合町');
ok($zip->set_number('3280042')->is_valid_number, '栃木県栃木市沼和田町');
ok($zip->set_number('3280043')->is_valid_number, '栃木県栃木市境町');
ok($zip->set_number('3280044')->is_valid_number, '栃木県栃木市富士見町');
ok($zip->set_number('3280045')->is_valid_number, '栃木県栃木市湊町');
ok($zip->set_number('3280051')->is_valid_number, '栃木県栃木市柳橋町');
ok($zip->set_number('3280052')->is_valid_number, '栃木県栃木市祝町');
ok($zip->set_number('3280053')->is_valid_number, '栃木県栃木市片柳町');
ok($zip->set_number('3280054')->is_valid_number, '栃木県栃木市平井町');
ok($zip->set_number('3280061')->is_valid_number, '栃木県栃木市新井町');
ok($zip->set_number('3280062')->is_valid_number, '栃木県栃木市泉川町');
ok($zip->set_number('3280063')->is_valid_number, '栃木県栃木市岩出町');
ok($zip->set_number('3280064')->is_valid_number, '栃木県栃木市志鳥町');
ok($zip->set_number('3280065')->is_valid_number, '栃木県栃木市小野口町');
ok($zip->set_number('3280066')->is_valid_number, '栃木県栃木市柏倉町');
ok($zip->set_number('3280067')->is_valid_number, '栃木県栃木市皆川城内町');
ok($zip->set_number('3280068')->is_valid_number, '栃木県栃木市大皆川町');
ok($zip->set_number('3280071')->is_valid_number, '栃木県栃木市大町');
ok($zip->set_number('3280072')->is_valid_number, '栃木県栃木市嘉右衛門町');
ok($zip->set_number('3280073')->is_valid_number, '栃木県栃木市小平町');
ok($zip->set_number('3280074')->is_valid_number, '栃木県栃木市薗部町');
ok($zip->set_number('3280075')->is_valid_number, '栃木県栃木市箱森町');
ok($zip->set_number('3280101')->is_valid_number, '栃木県栃木市都賀町大柿');
ok($zip->set_number('3280102')->is_valid_number, '栃木県栃木市都賀町富張');
ok($zip->set_number('3280103')->is_valid_number, '栃木県栃木市都賀町原宿');
ok($zip->set_number('3280104')->is_valid_number, '栃木県栃木市都賀町木');
ok($zip->set_number('3280105')->is_valid_number, '栃木県栃木市都賀町臼久保');
ok($zip->set_number('3280106')->is_valid_number, '栃木県栃木市都賀町大橋');
ok($zip->set_number('3280107')->is_valid_number, '栃木県栃木市都賀町深沢');
ok($zip->set_number('3280111')->is_valid_number, '栃木県栃木市都賀町家中');
ok($zip->set_number('3280112')->is_valid_number, '栃木県栃木市都賀町平川');
ok($zip->set_number('3280113')->is_valid_number, '栃木県栃木市都賀町合戦場');
ok($zip->set_number('3280114')->is_valid_number, '栃木県栃木市都賀町升塚');
ok($zip->set_number('3280121')->is_valid_number, '栃木県栃木市細堀町');
ok($zip->set_number('3280122')->is_valid_number, '栃木県栃木市木野地町');
ok($zip->set_number('3280123')->is_valid_number, '栃木県栃木市川原田町');
ok($zip->set_number('3280124')->is_valid_number, '栃木県栃木市野中町');
ok($zip->set_number('3280125')->is_valid_number, '栃木県栃木市吹上町');
ok($zip->set_number('3280131')->is_valid_number, '栃木県栃木市梓町');
ok($zip->set_number('3280132')->is_valid_number, '栃木県栃木市仲方町');
ok($zip->set_number('3280133')->is_valid_number, '栃木県栃木市大森町');
ok($zip->set_number('3280134')->is_valid_number, '栃木県栃木市宮町');
ok($zip->set_number('3280135')->is_valid_number, '栃木県栃木市千塚町');
ok($zip->set_number('3280201')->is_valid_number, '栃木県栃木市星野町');
ok($zip->set_number('3280202')->is_valid_number, '栃木県栃木市大久保町');
ok($zip->set_number('3280203')->is_valid_number, '栃木県栃木市尻内町');
ok($zip->set_number('3280204')->is_valid_number, '栃木県栃木市梅沢町');
ok($zip->set_number('3280205')->is_valid_number, '栃木県栃木市鍋山町');
ok($zip->set_number('3280206')->is_valid_number, '栃木県栃木市出流町');
ok($zip->set_number('3280211')->is_valid_number, '栃木県鹿沼市上永野');
ok($zip->set_number('3280212')->is_valid_number, '栃木県鹿沼市下永野');
ok($zip->set_number('3280221')->is_valid_number, '栃木県佐野市仙波町(坂東、松ケ坂)');
ok($zip->set_number('3290100')->is_valid_number, '栃木県下都賀郡野木町以下に掲載がない場合');
ok($zip->set_number('3290101')->is_valid_number, '栃木県下都賀郡野木町友沼');
ok($zip->set_number('3290102')->is_valid_number, '栃木県下都賀郡野木町潤島');
ok($zip->set_number('3290103')->is_valid_number, '栃木県下都賀郡野木町若林');
ok($zip->set_number('3290104')->is_valid_number, '栃木県下都賀郡野木町佐川野');
ok($zip->set_number('3290105')->is_valid_number, '栃木県下都賀郡野木町川田');
ok($zip->set_number('3290111')->is_valid_number, '栃木県下都賀郡野木町丸林');
ok($zip->set_number('3290112')->is_valid_number, '栃木県下都賀郡野木町南赤塚');
ok($zip->set_number('3290113')->is_valid_number, '栃木県下都賀郡野木町中谷');
ok($zip->set_number('3290114')->is_valid_number, '栃木県下都賀郡野木町野木');
ok($zip->set_number('3290115')->is_valid_number, '栃木県下都賀郡野木町野渡');
ok($zip->set_number('3290201')->is_valid_number, '栃木県小山市粟宮');
ok($zip->set_number('3290202')->is_valid_number, '栃木県小山市千駄塚');
ok($zip->set_number('3290203')->is_valid_number, '栃木県小山市西黒田');
ok($zip->set_number('3290204')->is_valid_number, '栃木県小山市東黒田');
ok($zip->set_number('3290205')->is_valid_number, '栃木県小山市間々田');
ok($zip->set_number('3290206')->is_valid_number, '栃木県小山市東間々田');
ok($zip->set_number('3290207')->is_valid_number, '栃木県小山市美しが丘');
ok($zip->set_number('3290211')->is_valid_number, '栃木県小山市暁');
ok($zip->set_number('3290212')->is_valid_number, '栃木県小山市平和');
ok($zip->set_number('3290213')->is_valid_number, '栃木県小山市南飯田');
ok($zip->set_number('3290214')->is_valid_number, '栃木県小山市乙女');
ok($zip->set_number('3290215')->is_valid_number, '栃木県小山市網戸');
ok($zip->set_number('3290216')->is_valid_number, '栃木県小山市楢木');
ok($zip->set_number('3290217')->is_valid_number, '栃木県小山市南乙女');
ok($zip->set_number('3290221')->is_valid_number, '栃木県小山市生良');
ok($zip->set_number('3290222')->is_valid_number, '栃木県小山市上生井');
ok($zip->set_number('3290223')->is_valid_number, '栃木県小山市下生井');
ok($zip->set_number('3290224')->is_valid_number, '栃木県小山市白鳥');
ok($zip->set_number('3290225')->is_valid_number, '栃木県小山市迫間田');
ok($zip->set_number('3290226')->is_valid_number, '栃木県小山市寒川');
ok($zip->set_number('3290227')->is_valid_number, '栃木県小山市中里');
ok($zip->set_number('3290228')->is_valid_number, '栃木県小山市押切');
ok($zip->set_number('3290229')->is_valid_number, '栃木県小山市鏡');
ok($zip->set_number('3290311')->is_valid_number, '栃木県栃木市藤岡町富吉');
ok($zip->set_number('3290312')->is_valid_number, '栃木県栃木市藤岡町蛭沼');
ok($zip->set_number('3290313')->is_valid_number, '栃木県栃木市藤岡町緑川');
ok($zip->set_number('3290314')->is_valid_number, '栃木県栃木市藤岡町新波');
ok($zip->set_number('3290315')->is_valid_number, '栃木県栃木市藤岡町部屋');
ok($zip->set_number('3290316')->is_valid_number, '栃木県栃木市藤岡町石川');
ok($zip->set_number('3290317')->is_valid_number, '栃木県栃木市藤岡町帯刀');
ok($zip->set_number('3290318')->is_valid_number, '栃木県栃木市藤岡町西前原');
ok($zip->set_number('3290319')->is_valid_number, '栃木県栃木市藤岡町中根');
ok($zip->set_number('3290400')->is_valid_number, '栃木県下野市以下に掲載がない場合');
ok($zip->set_number('3290401')->is_valid_number, '栃木県下野市箕輪');
ok($zip->set_number('3290402')->is_valid_number, '栃木県下野市笹原');
ok($zip->set_number('3290403')->is_valid_number, '栃木県下野市医大前');
ok($zip->set_number('3290411')->is_valid_number, '栃木県下野市烏ケ森');
ok($zip->set_number('3290412')->is_valid_number, '栃木県下野市柴');
ok($zip->set_number('3290413')->is_valid_number, '栃木県下野市駅東');
ok($zip->set_number('3290414')->is_valid_number, '栃木県下野市小金井');
ok($zip->set_number('3290415')->is_valid_number, '栃木県下野市川中子');
ok($zip->set_number('3290417')->is_valid_number, '栃木県下野市国分寺');
ok($zip->set_number('3290418')->is_valid_number, '栃木県下野市紫');
ok($zip->set_number('3290421')->is_valid_number, '栃木県下野市成田');
ok($zip->set_number('3290422')->is_valid_number, '栃木県下野市町田');
ok($zip->set_number('3290423')->is_valid_number, '栃木県下野市谷地賀');
ok($zip->set_number('3290424')->is_valid_number, '栃木県下野市下文狹');
ok($zip->set_number('3290425')->is_valid_number, '栃木県下野市田中');
ok($zip->set_number('3290431')->is_valid_number, '栃木県下野市薬師寺');
ok($zip->set_number('3290432')->is_valid_number, '栃木県下野市仁良川');
ok($zip->set_number('3290433')->is_valid_number, '栃木県下野市緑');
ok($zip->set_number('3290434')->is_valid_number, '栃木県下野市祇園');
ok($zip->set_number('3290501')->is_valid_number, '栃木県下野市上古山');
ok($zip->set_number('3290502')->is_valid_number, '栃木県下野市下古山');
ok($zip->set_number('3290503')->is_valid_number, '栃木県下野市下長田');
ok($zip->set_number('3290504')->is_valid_number, '栃木県下野市上台');
ok($zip->set_number('3290505')->is_valid_number, '栃木県下野市細谷');
ok($zip->set_number('3290506')->is_valid_number, '栃木県下野市橋本');
ok($zip->set_number('3290507')->is_valid_number, '栃木県下野市文教');
ok($zip->set_number('3290511')->is_valid_number, '栃木県下野市石橋');
ok($zip->set_number('3290512')->is_valid_number, '栃木県下野市下石橋');
ok($zip->set_number('3290513')->is_valid_number, '栃木県下野市下大領');
ok($zip->set_number('3290514')->is_valid_number, '栃木県下野市東前原');
ok($zip->set_number('3290515')->is_valid_number, '栃木県下野市中大領');
ok($zip->set_number('3290516')->is_valid_number, '栃木県下野市大光寺');
ok($zip->set_number('3290517')->is_valid_number, '栃木県下野市上大領');
ok($zip->set_number('3290518')->is_valid_number, '栃木県下野市花の木');
ok($zip->set_number('3290519')->is_valid_number, '栃木県下野市大松山');
ok($zip->set_number('3290521')->is_valid_number, '栃木県河内郡上三川町石田');
ok($zip->set_number('3290522')->is_valid_number, '栃木県河内郡上三川町川中子');
ok($zip->set_number('3290523')->is_valid_number, '栃木県河内郡上三川町梁');
ok($zip->set_number('3290524')->is_valid_number, '栃木県河内郡上三川町多功');
ok($zip->set_number('3290525')->is_valid_number, '栃木県河内郡上三川町大山');
ok($zip->set_number('3290526')->is_valid_number, '栃木県河内郡上三川町鞘堂');
ok($zip->set_number('3290527')->is_valid_number, '栃木県河内郡上三川町上神主');
ok($zip->set_number('3290528')->is_valid_number, '栃木県河内郡上三川町ゆうきが丘');
ok($zip->set_number('3290529')->is_valid_number, '栃木県河内郡上三川町下神主');
ok($zip->set_number('3290530')->is_valid_number, '栃木県河内郡上三川町天神町');
ok($zip->set_number('3290600')->is_valid_number, '栃木県河内郡上三川町以下に掲載がない場合');
ok($zip->set_number('3290601')->is_valid_number, '栃木県河内郡上三川町上文挾');
ok($zip->set_number('3290602')->is_valid_number, '栃木県河内郡上三川町東汗');
ok($zip->set_number('3290603')->is_valid_number, '栃木県河内郡上三川町東蓼沼');
ok($zip->set_number('3290604')->is_valid_number, '栃木県河内郡上三川町上郷');
ok($zip->set_number('3290605')->is_valid_number, '栃木県河内郡上三川町西蓼沼');
ok($zip->set_number('3290606')->is_valid_number, '栃木県河内郡上三川町磯岡');
ok($zip->set_number('3290607')->is_valid_number, '栃木県河内郡上三川町西汗');
ok($zip->set_number('3290608')->is_valid_number, '栃木県河内郡上三川町西木代');
ok($zip->set_number('3290611')->is_valid_number, '栃木県河内郡上三川町上三川');
ok($zip->set_number('3290612')->is_valid_number, '栃木県河内郡上三川町三本木');
ok($zip->set_number('3290613')->is_valid_number, '栃木県河内郡上三川町坂上');
ok($zip->set_number('3290614')->is_valid_number, '栃木県河内郡上三川町五分一');
ok($zip->set_number('3290615')->is_valid_number, '栃木県河内郡上三川町三村');
ok($zip->set_number('3290616')->is_valid_number, '栃木県河内郡上三川町下蒲生');
ok($zip->set_number('3290617')->is_valid_number, '栃木県河内郡上三川町上蒲生');
ok($zip->set_number('3290618')->is_valid_number, '栃木県河内郡上三川町しらさぎ');
ok($zip->set_number('3291101')->is_valid_number, '栃木県宇都宮市下ケ橋町');
ok($zip->set_number('3291102')->is_valid_number, '栃木県宇都宮市白沢町');
ok($zip->set_number('3291103')->is_valid_number, '栃木県宇都宮市東岡本町');
ok($zip->set_number('3291104')->is_valid_number, '栃木県宇都宮市下岡本町');
ok($zip->set_number('3291105')->is_valid_number, '栃木県宇都宮市中岡本町');
ok($zip->set_number('3291106')->is_valid_number, '栃木県宇都宮市上大塚町');
ok($zip->set_number('3291107')->is_valid_number, '栃木県宇都宮市長峰町');
ok($zip->set_number('3291108')->is_valid_number, '栃木県宇都宮市古田町');
ok($zip->set_number('3291111')->is_valid_number, '栃木県宇都宮市逆面町');
ok($zip->set_number('3291112')->is_valid_number, '栃木県宇都宮市上田原町');
ok($zip->set_number('3291113')->is_valid_number, '栃木県宇都宮市相野沢町');
ok($zip->set_number('3291114')->is_valid_number, '栃木県宇都宮市宝井町');
ok($zip->set_number('3291115')->is_valid_number, '栃木県宇都宮市下田原町');
ok($zip->set_number('3291116')->is_valid_number, '栃木県宇都宮市立伏町');
ok($zip->set_number('3291117')->is_valid_number, '栃木県宇都宮市叶谷町');
ok($zip->set_number('3291200')->is_valid_number, '栃木県塩谷郡高根沢町以下に掲載がない場合');
ok($zip->set_number('3291201')->is_valid_number, '栃木県塩谷郡高根沢町柿木沢');
ok($zip->set_number('3291202')->is_valid_number, '栃木県塩谷郡高根沢町狭間田');
ok($zip->set_number('3291203')->is_valid_number, '栃木県塩谷郡高根沢町伏久');
ok($zip->set_number('3291204')->is_valid_number, '栃木県塩谷郡高根沢町文挾');
ok($zip->set_number('3291205')->is_valid_number, '栃木県塩谷郡高根沢町飯室');
ok($zip->set_number('3291206')->is_valid_number, '栃木県塩谷郡高根沢町平田');
ok($zip->set_number('3291207')->is_valid_number, '栃木県塩谷郡高根沢町花岡');
ok($zip->set_number('3291211')->is_valid_number, '栃木県塩谷郡高根沢町亀梨');
ok($zip->set_number('3291212')->is_valid_number, '栃木県塩谷郡高根沢町上柏崎');
ok($zip->set_number('3291213')->is_valid_number, '栃木県塩谷郡高根沢町下柏崎');
ok($zip->set_number('3291214')->is_valid_number, '栃木県塩谷郡高根沢町中柏崎');
ok($zip->set_number('3291215')->is_valid_number, '栃木県塩谷郡高根沢町給部');
ok($zip->set_number('3291216')->is_valid_number, '栃木県塩谷郡高根沢町桑窪');
ok($zip->set_number('3291217')->is_valid_number, '栃木県塩谷郡高根沢町太田');
ok($zip->set_number('3291221')->is_valid_number, '栃木県塩谷郡高根沢町西高谷');
ok($zip->set_number('3291222')->is_valid_number, '栃木県塩谷郡高根沢町寺渡戸');
ok($zip->set_number('3291223')->is_valid_number, '栃木県塩谷郡高根沢町栗ケ島');
ok($zip->set_number('3291224')->is_valid_number, '栃木県塩谷郡高根沢町上高根沢');
ok($zip->set_number('3291225')->is_valid_number, '栃木県塩谷郡高根沢町石末');
ok($zip->set_number('3291226')->is_valid_number, '栃木県塩谷郡高根沢町大谷');
ok($zip->set_number('3291231')->is_valid_number, '栃木県塩谷郡高根沢町宝石台');
ok($zip->set_number('3291232')->is_valid_number, '栃木県塩谷郡高根沢町光陽台');
ok($zip->set_number('3291233')->is_valid_number, '栃木県塩谷郡高根沢町宝積寺');
ok($zip->set_number('3291234')->is_valid_number, '栃木県塩谷郡高根沢町中阿久津');
ok($zip->set_number('3291235')->is_valid_number, '栃木県塩谷郡高根沢町上阿久津');
ok($zip->set_number('3291300')->is_valid_number, '栃木県さくら市以下に掲載がない場合');
ok($zip->set_number('3291301')->is_valid_number, '栃木県さくら市箱森新田');
ok($zip->set_number('3291302')->is_valid_number, '栃木県さくら市松山新田');
ok($zip->set_number('3291303')->is_valid_number, '栃木県さくら市松山');
ok($zip->set_number('3291304')->is_valid_number, '栃木県さくら市鍛冶ケ沢');
ok($zip->set_number('3291305')->is_valid_number, '栃木県さくら市狹間田');
ok($zip->set_number('3291306')->is_valid_number, '栃木県さくら市上野');
ok($zip->set_number('3291311')->is_valid_number, '栃木県さくら市氏家');
ok($zip->set_number('3291312')->is_valid_number, '栃木県さくら市櫻野');
ok($zip->set_number('3291313')->is_valid_number, '栃木県さくら市柿木沢新田');
ok($zip->set_number('3291314')->is_valid_number, '栃木県さくら市柿木沢');
ok($zip->set_number('3291315')->is_valid_number, '栃木県さくら市氏家新田');
ok($zip->set_number('3291316')->is_valid_number, '栃木県さくら市上阿久津');
ok($zip->set_number('3291321')->is_valid_number, '栃木県さくら市馬場');
ok($zip->set_number('3291322')->is_valid_number, '栃木県さくら市北草川');
ok($zip->set_number('3291323')->is_valid_number, '栃木県さくら市卯の里');
ok($zip->set_number('3291324')->is_valid_number, '栃木県さくら市草川');
ok($zip->set_number('3291325')->is_valid_number, '栃木県さくら市大中');
ok($zip->set_number('3291326')->is_valid_number, '栃木県さくら市向河原');
ok($zip->set_number('3291327')->is_valid_number, '栃木県さくら市富野岡');
ok($zip->set_number('3291331')->is_valid_number, '栃木県さくら市松島');
ok($zip->set_number('3291332')->is_valid_number, '栃木県さくら市蒲須坂');
ok($zip->set_number('3291333')->is_valid_number, '栃木県さくら市長久保');
ok($zip->set_number('3291334')->is_valid_number, '栃木県さくら市押上');
ok($zip->set_number('3291401')->is_valid_number, '栃木県さくら市上河戸');
ok($zip->set_number('3291402')->is_valid_number, '栃木県さくら市下河戸');
ok($zip->set_number('3291403')->is_valid_number, '栃木県さくら市穂積');
ok($zip->set_number('3291404')->is_valid_number, '栃木県さくら市鹿子畑');
ok($zip->set_number('3291405')->is_valid_number, '栃木県さくら市金枝');
ok($zip->set_number('3291406')->is_valid_number, '栃木県さくら市南和田');
ok($zip->set_number('3291411')->is_valid_number, '栃木県さくら市鷲宿');
ok($zip->set_number('3291412')->is_valid_number, '栃木県さくら市喜連川');
ok($zip->set_number('3291413')->is_valid_number, '栃木県さくら市葛城');
ok($zip->set_number('3291414')->is_valid_number, '栃木県さくら市早乙女');
ok($zip->set_number('3291415')->is_valid_number, '栃木県さくら市小入');
ok($zip->set_number('3291416')->is_valid_number, '栃木県さくら市桜ケ丘');
ok($zip->set_number('3291417')->is_valid_number, '栃木県さくら市フィオーレ喜連川');
ok($zip->set_number('3291571')->is_valid_number, '栃木県矢板市片岡');
ok($zip->set_number('3291572')->is_valid_number, '栃木県矢板市安沢');
ok($zip->set_number('3291573')->is_valid_number, '栃木県矢板市越畑');
ok($zip->set_number('3291574')->is_valid_number, '栃木県矢板市乙畑');
ok($zip->set_number('3291575')->is_valid_number, '栃木県矢板市大槻');
ok($zip->set_number('3291576')->is_valid_number, '栃木県矢板市石関');
ok($zip->set_number('3291577')->is_valid_number, '栃木県矢板市玉田');
ok($zip->set_number('3291578')->is_valid_number, '栃木県矢板市山苗代');
ok($zip->set_number('3291579')->is_valid_number, '栃木県矢板市こぶし台');
ok($zip->set_number('3292100')->is_valid_number, '栃木県矢板市以下に掲載がない場合');
ok($zip->set_number('3292121')->is_valid_number, '栃木県矢板市荒井');
ok($zip->set_number('3292122')->is_valid_number, '栃木県矢板市針生');
ok($zip->set_number('3292123')->is_valid_number, '栃木県矢板市上町');
ok($zip->set_number('3292124')->is_valid_number, '栃木県矢板市下太田');
ok($zip->set_number('3292131')->is_valid_number, '栃木県矢板市土屋');
ok($zip->set_number('3292132')->is_valid_number, '栃木県矢板市沢');
ok($zip->set_number('3292133')->is_valid_number, '栃木県矢板市豊田');
ok($zip->set_number('3292134')->is_valid_number, '栃木県矢板市成田');
ok($zip->set_number('3292135')->is_valid_number, '栃木県矢板市中');
ok($zip->set_number('3292136')->is_valid_number, '栃木県矢板市東町');
ok($zip->set_number('3292141')->is_valid_number, '栃木県矢板市早川町');
ok($zip->set_number('3292142')->is_valid_number, '栃木県矢板市木幡');
ok($zip->set_number('3292143')->is_valid_number, '栃木県矢板市境林');
ok($zip->set_number('3292144')->is_valid_number, '栃木県矢板市川崎反町');
ok($zip->set_number('3292145')->is_valid_number, '栃木県矢板市富田');
ok($zip->set_number('3292151')->is_valid_number, '栃木県矢板市幸岡');
ok($zip->set_number('3292152')->is_valid_number, '栃木県矢板市館ノ川');
ok($zip->set_number('3292153')->is_valid_number, '栃木県矢板市高塩');
ok($zip->set_number('3292154')->is_valid_number, '栃木県矢板市倉掛');
ok($zip->set_number('3292155')->is_valid_number, '栃木県矢板市片俣');
ok($zip->set_number('3292156')->is_valid_number, '栃木県矢板市塩田');
ok($zip->set_number('3292161')->is_valid_number, '栃木県矢板市扇町');
ok($zip->set_number('3292162')->is_valid_number, '栃木県矢板市末広町');
ok($zip->set_number('3292163')->is_valid_number, '栃木県矢板市鹿島町');
ok($zip->set_number('3292164')->is_valid_number, '栃木県矢板市本町');
ok($zip->set_number('3292165')->is_valid_number, '栃木県矢板市矢板');
ok($zip->set_number('3292200')->is_valid_number, '栃木県塩谷郡塩谷町以下に掲載がない場合');
ok($zip->set_number('3292211')->is_valid_number, '栃木県塩谷郡塩谷町鳥羽新田');
ok($zip->set_number('3292212')->is_valid_number, '栃木県塩谷郡塩谷町喜佐見');
ok($zip->set_number('3292213')->is_valid_number, '栃木県塩谷郡塩谷町熊ノ木');
ok($zip->set_number('3292214')->is_valid_number, '栃木県塩谷郡塩谷町東房');
ok($zip->set_number('3292215')->is_valid_number, '栃木県塩谷郡塩谷町下寺島');
ok($zip->set_number('3292216')->is_valid_number, '栃木県塩谷郡塩谷町上寺島(その他)');
ok($zip->set_number('3292221')->is_valid_number, '栃木県塩谷郡塩谷町玉生');
ok($zip->set_number('3292222')->is_valid_number, '栃木県塩谷郡塩谷町道下');
ok($zip->set_number('3292223')->is_valid_number, '栃木県塩谷郡塩谷町原荻野目');
ok($zip->set_number('3292224')->is_valid_number, '栃木県塩谷郡塩谷町金枝');
ok($zip->set_number('3292225')->is_valid_number, '栃木県塩谷郡塩谷町飯岡');
ok($zip->set_number('3292226')->is_valid_number, '栃木県塩谷郡塩谷町芦場新田');
ok($zip->set_number('3292331')->is_valid_number, '栃木県塩谷郡塩谷町田所');
ok($zip->set_number('3292332')->is_valid_number, '栃木県塩谷郡塩谷町大宮');
ok($zip->set_number('3292333')->is_valid_number, '栃木県塩谷郡塩谷町肘内');
ok($zip->set_number('3292334')->is_valid_number, '栃木県塩谷郡塩谷町大久保');
ok($zip->set_number('3292335')->is_valid_number, '栃木県塩谷郡塩谷町上平');
ok($zip->set_number('3292336')->is_valid_number, '栃木県塩谷郡塩谷町風見');
ok($zip->set_number('3292337')->is_valid_number, '栃木県塩谷郡塩谷町泉');
ok($zip->set_number('3292338')->is_valid_number, '栃木県塩谷郡塩谷町風見山田');
ok($zip->set_number('3292339')->is_valid_number, '栃木県塩谷郡塩谷町上沢');
ok($zip->set_number('3292441')->is_valid_number, '栃木県塩谷郡塩谷町船生');
ok($zip->set_number('3292442')->is_valid_number, '栃木県塩谷郡塩谷町佐貫');
ok($zip->set_number('3292501')->is_valid_number, '栃木県矢板市上伊佐野');
ok($zip->set_number('3292502')->is_valid_number, '栃木県矢板市下伊佐野');
ok($zip->set_number('3292503')->is_valid_number, '栃木県矢板市田野原');
ok($zip->set_number('3292504')->is_valid_number, '栃木県矢板市泉');
ok($zip->set_number('3292505')->is_valid_number, '栃木県矢板市立足');
ok($zip->set_number('3292506')->is_valid_number, '栃木県矢板市平野');
ok($zip->set_number('3292511')->is_valid_number, '栃木県矢板市山田');
ok($zip->set_number('3292512')->is_valid_number, '栃木県矢板市東泉');
ok($zip->set_number('3292513')->is_valid_number, '栃木県矢板市上太田');
ok($zip->set_number('3292514')->is_valid_number, '栃木県矢板市長井');
ok($zip->set_number('3292701')->is_valid_number, '栃木県那須塩原市関根');
ok($zip->set_number('3292702')->is_valid_number, '栃木県那須塩原市東関根');
ok($zip->set_number('3292703')->is_valid_number, '栃木県那須塩原市槻沢');
ok($zip->set_number('3292704')->is_valid_number, '栃木県那須塩原市新南');
ok($zip->set_number('3292705')->is_valid_number, '栃木県那須塩原市南郷屋');
ok($zip->set_number('3292706')->is_valid_number, '栃木県那須塩原市睦');
ok($zip->set_number('3292707')->is_valid_number, '栃木県那須塩原市高柳');
ok($zip->set_number('3292711')->is_valid_number, '栃木県那須塩原市石林');
ok($zip->set_number('3292712')->is_valid_number, '栃木県那須塩原市下永田');
ok($zip->set_number('3292713')->is_valid_number, '栃木県那須塩原市緑');
ok($zip->set_number('3292721')->is_valid_number, '栃木県那須塩原市東町');
ok($zip->set_number('3292722')->is_valid_number, '栃木県那須塩原市西朝日町');
ok($zip->set_number('3292723')->is_valid_number, '栃木県那須塩原市南町');
ok($zip->set_number('3292724')->is_valid_number, '栃木県那須塩原市西幸町');
ok($zip->set_number('3292725')->is_valid_number, '栃木県那須塩原市あたご町');
ok($zip->set_number('3292726')->is_valid_number, '栃木県那須塩原市扇町');
ok($zip->set_number('3292727')->is_valid_number, '栃木県那須塩原市永田町');
ok($zip->set_number('3292728')->is_valid_number, '栃木県那須塩原市西栄町');
ok($zip->set_number('3292731')->is_valid_number, '栃木県那須塩原市二つ室');
ok($zip->set_number('3292732')->is_valid_number, '栃木県那須塩原市一区町');
ok($zip->set_number('3292733')->is_valid_number, '栃木県那須塩原市二区町');
ok($zip->set_number('3292734')->is_valid_number, '栃木県那須塩原市北二つ室');
ok($zip->set_number('3292735')->is_valid_number, '栃木県那須塩原市太夫塚');
ok($zip->set_number('3292741')->is_valid_number, '栃木県那須塩原市北赤田');
ok($zip->set_number('3292742')->is_valid_number, '栃木県那須塩原市東赤田');
ok($zip->set_number('3292743')->is_valid_number, '栃木県那須塩原市南赤田');
ok($zip->set_number('3292744')->is_valid_number, '栃木県那須塩原市西赤田');
ok($zip->set_number('3292745')->is_valid_number, '栃木県那須塩原市三区町');
ok($zip->set_number('3292746')->is_valid_number, '栃木県那須塩原市四区町');
ok($zip->set_number('3292747')->is_valid_number, '栃木県那須塩原市千本松');
ok($zip->set_number('3292748')->is_valid_number, '栃木県那須塩原市上赤田');
ok($zip->set_number('3292751')->is_valid_number, '栃木県那須塩原市東三島');
ok($zip->set_number('3292752')->is_valid_number, '栃木県那須塩原市三島');
ok($zip->set_number('3292753')->is_valid_number, '栃木県那須塩原市五軒町');
ok($zip->set_number('3292754')->is_valid_number, '栃木県那須塩原市西大和');
ok($zip->set_number('3292755')->is_valid_number, '栃木県那須塩原市西原町');
ok($zip->set_number('3292756')->is_valid_number, '栃木県那須塩原市西三島');
ok($zip->set_number('3292761')->is_valid_number, '栃木県那須塩原市東遅沢');
ok($zip->set_number('3292762')->is_valid_number, '栃木県那須塩原市西富山');
ok($zip->set_number('3292763')->is_valid_number, '栃木県那須塩原市井口');
ok($zip->set_number('3292764')->is_valid_number, '栃木県那須塩原市西遅沢');
ok($zip->set_number('3292801')->is_valid_number, '栃木県那須塩原市関谷');
ok($zip->set_number('3292802')->is_valid_number, '栃木県那須塩原市蟇沼');
ok($zip->set_number('3292803')->is_valid_number, '栃木県那須塩原市遅野沢');
ok($zip->set_number('3292804')->is_valid_number, '栃木県那須塩原市折戸');
ok($zip->set_number('3292805')->is_valid_number, '栃木県那須塩原市上横林');
ok($zip->set_number('3292806')->is_valid_number, '栃木県那須塩原市横林');
ok($zip->set_number('3292807')->is_valid_number, '栃木県那須塩原市接骨木');
ok($zip->set_number('3292811')->is_valid_number, '栃木県那須塩原市下田野');
ok($zip->set_number('3292812')->is_valid_number, '栃木県那須塩原市金沢');
ok($zip->set_number('3292813')->is_valid_number, '栃木県那須塩原市高阿津');
ok($zip->set_number('3292814')->is_valid_number, '栃木県那須塩原市上大貫');
ok($zip->set_number('3292815')->is_valid_number, '栃木県那須塩原市下大貫');
ok($zip->set_number('3292816')->is_valid_number, '栃木県那須塩原市宇都野');
ok($zip->set_number('3292921')->is_valid_number, '栃木県那須塩原市塩原');
ok($zip->set_number('3292922')->is_valid_number, '栃木県那須塩原市湯本塩原');
ok($zip->set_number('3292923')->is_valid_number, '栃木県那須塩原市上塩原');
ok($zip->set_number('3292924')->is_valid_number, '栃木県那須塩原市中塩原');
ok($zip->set_number('3293121')->is_valid_number, '栃木県那須塩原市鹿野崎');
ok($zip->set_number('3293122')->is_valid_number, '栃木県那須塩原市塩野崎');
ok($zip->set_number('3293123')->is_valid_number, '栃木県那須塩原市塩野崎新田');
ok($zip->set_number('3293124')->is_valid_number, '栃木県那須塩原市波立');
ok($zip->set_number('3293125')->is_valid_number, '栃木県那須塩原市無栗屋');
ok($zip->set_number('3293126')->is_valid_number, '栃木県那須塩原市中内');
ok($zip->set_number('3293127')->is_valid_number, '栃木県那須塩原市上郷屋');
ok($zip->set_number('3293131')->is_valid_number, '栃木県那須塩原市唐杉');
ok($zip->set_number('3293132')->is_valid_number, '栃木県那須塩原市北弥六');
ok($zip->set_number('3293133')->is_valid_number, '栃木県那須塩原市沓掛');
ok($zip->set_number('3293134')->is_valid_number, '栃木県那須塩原市上大塚新田');
ok($zip->set_number('3293135')->is_valid_number, '栃木県那須塩原市前弥六');
ok($zip->set_number('3293136')->is_valid_number, '栃木県那須塩原市前弥六南町');
ok($zip->set_number('3293141')->is_valid_number, '栃木県那須塩原市山中新田');
ok($zip->set_number('3293142')->is_valid_number, '栃木県那須塩原市佐野');
ok($zip->set_number('3293143')->is_valid_number, '栃木県那須塩原市三本木');
ok($zip->set_number('3293144')->is_valid_number, '栃木県那須塩原市沼野田和');
ok($zip->set_number('3293145')->is_valid_number, '栃木県那須塩原市木曾畑中');
ok($zip->set_number('3293146')->is_valid_number, '栃木県那須塩原市下中野');
ok($zip->set_number('3293147')->is_valid_number, '栃木県那須塩原市東小屋');
ok($zip->set_number('3293151')->is_valid_number, '栃木県那須塩原市北和田');
ok($zip->set_number('3293152')->is_valid_number, '栃木県那須塩原市島方');
ok($zip->set_number('3293153')->is_valid_number, '栃木県那須塩原市大原間');
ok($zip->set_number('3293154')->is_valid_number, '栃木県那須塩原市上中野');
ok($zip->set_number('3293155')->is_valid_number, '栃木県那須塩原市笹沼');
ok($zip->set_number('3293156')->is_valid_number, '栃木県那須塩原市方京');
ok($zip->set_number('3293157')->is_valid_number, '栃木県那須塩原市大原間西');
ok($zip->set_number('3293200')->is_valid_number, '栃木県那須郡那須町以下に掲載がない場合');
ok($zip->set_number('3293211')->is_valid_number, '栃木県那須郡那須町豊原甲');
ok($zip->set_number('3293212')->is_valid_number, '栃木県那須郡那須町富岡');
ok($zip->set_number('3293213')->is_valid_number, '栃木県那須郡那須町豊原');
ok($zip->set_number('3293214')->is_valid_number, '栃木県那須郡那須町横岡(1563、1660、1670、1728、1736、174');
ok($zip->set_number('3293214')->is_valid_number, '栃木県那須郡那須町8、1767-4番地)');
ok($zip->set_number('3293215')->is_valid_number, '栃木県那須郡那須町寺子乙(その他)');
ok($zip->set_number('3293221')->is_valid_number, '栃木県那須郡那須町漆塚');
ok($zip->set_number('3293222')->is_valid_number, '栃木県那須郡那須町寺子丙');
ok($zip->set_number('3293223')->is_valid_number, '栃木県那須郡那須町大島');
ok($zip->set_number('3293224')->is_valid_number, '栃木県那須郡那須町豊原乙');
ok($zip->set_number('3293225')->is_valid_number, '栃木県那須郡那須町豊原丙');
ok($zip->set_number('3293431')->is_valid_number, '栃木県那須郡那須町大畑');
ok($zip->set_number('3293432')->is_valid_number, '栃木県那須郡那須町梓');
ok($zip->set_number('3293433')->is_valid_number, '栃木県那須郡那須町大和須');
ok($zip->set_number('3293434')->is_valid_number, '栃木県那須郡那須町梁瀬');
ok($zip->set_number('3293435')->is_valid_number, '栃木県那須郡那須町睦家');
ok($zip->set_number('3293436')->is_valid_number, '栃木県那須郡那須町伊王野');
ok($zip->set_number('3293437')->is_valid_number, '栃木県那須郡那須町蓑沢');
ok($zip->set_number('3293441')->is_valid_number, '栃木県那須郡那須町寄居');
ok($zip->set_number('3293442')->is_valid_number, '栃木県那須郡那須町横岡(その他)');
ok($zip->set_number('3293443')->is_valid_number, '栃木県那須郡那須町芦野');
ok($zip->set_number('3293444')->is_valid_number, '栃木県那須郡那須町寺子(70~180番地)');
ok($zip->set_number('3293445')->is_valid_number, '栃木県那須郡那須町東岩崎');
ok($zip->set_number('3293446')->is_valid_number, '栃木県那須郡那須町沼野井');
ok($zip->set_number('3293447')->is_valid_number, '栃木県那須郡那須町稲沢');
ok($zip->set_number('3294211')->is_valid_number, '栃木県足利市西場町');
ok($zip->set_number('3294212')->is_valid_number, '栃木県足利市稲岡町');
ok($zip->set_number('3294213')->is_valid_number, '栃木県足利市寺岡町');
ok($zip->set_number('3294214')->is_valid_number, '栃木県足利市多田木町');
ok($zip->set_number('3294215')->is_valid_number, '栃木県足利市奥戸町');
ok($zip->set_number('3294216')->is_valid_number, '栃木県足利市迫間町');
ok($zip->set_number('3294217')->is_valid_number, '栃木県足利市駒場町');
ok($zip->set_number('3294301')->is_valid_number, '栃木県栃木市岩舟町鷲巣');
ok($zip->set_number('3294302')->is_valid_number, '栃木県栃木市岩舟町五十畑');
ok($zip->set_number('3294303')->is_valid_number, '栃木県栃木市岩舟町和泉');
ok($zip->set_number('3294304')->is_valid_number, '栃木県栃木市岩舟町静和');
ok($zip->set_number('3294305')->is_valid_number, '栃木県栃木市岩舟町静戸');
ok($zip->set_number('3294306')->is_valid_number, '栃木県栃木市岩舟町曲ケ島');
ok($zip->set_number('3294307')->is_valid_number, '栃木県栃木市岩舟町静');
ok($zip->set_number('3294308')->is_valid_number, '栃木県栃木市岩舟町下津原');
ok($zip->set_number('3294309')->is_valid_number, '栃木県栃木市岩舟町畳岡');
ok($zip->set_number('3294311')->is_valid_number, '栃木県栃木市岩舟町古江');
ok($zip->set_number('3294312')->is_valid_number, '栃木県栃木市岩舟町下岡');
ok($zip->set_number('3294313')->is_valid_number, '栃木県栃木市岩舟町上岡');
ok($zip->set_number('3294314')->is_valid_number, '栃木県栃木市岩舟町小野寺');
ok($zip->set_number('3294315')->is_valid_number, '栃木県栃木市岩舟町三谷');
ok($zip->set_number('3294316')->is_valid_number, '栃木県栃木市岩舟町新里');
ok($zip->set_number('3294401')->is_valid_number, '栃木県栃木市大平町牛久');
ok($zip->set_number('3294402')->is_valid_number, '栃木県栃木市大平町土与');
ok($zip->set_number('3294403')->is_valid_number, '栃木県栃木市大平町蔵井');
ok($zip->set_number('3294404')->is_valid_number, '栃木県栃木市大平町富田');
ok($zip->set_number('3294405')->is_valid_number, '栃木県栃木市大平町西山田');
ok($zip->set_number('3294406')->is_valid_number, '栃木県栃木市大平町下皆川');
ok($zip->set_number('3294407')->is_valid_number, '栃木県栃木市大平町川連');
ok($zip->set_number('3294411')->is_valid_number, '栃木県栃木市大平町横堀');
ok($zip->set_number('3294412')->is_valid_number, '栃木県栃木市大平町北武井');
ok($zip->set_number('3294413')->is_valid_number, '栃木県栃木市大平町上高島');
ok($zip->set_number('3294414')->is_valid_number, '栃木県栃木市大平町下高島');
ok($zip->set_number('3294415')->is_valid_number, '栃木県栃木市大平町真弓');
ok($zip->set_number('3294421')->is_valid_number, '栃木県栃木市大平町西野田');
ok($zip->set_number('3294422')->is_valid_number, '栃木県栃木市大平町榎本');
ok($zip->set_number('3294423')->is_valid_number, '栃木県栃木市大平町西水代');
ok($zip->set_number('3294424')->is_valid_number, '栃木県栃木市大平町伯仲');
ok($zip->set_number('3294425')->is_valid_number, '栃木県栃木市大平町新');
ok($zip->set_number('3300000')->is_valid_number, '埼玉県さいたま市中央区以下に掲載がない場合');
ok($zip->set_number('3300000')->is_valid_number, '埼玉県さいたま市浦和区以下に掲載がない場合');
ok($zip->set_number('3300041')->is_valid_number, '埼玉県さいたま市浦和区三崎');
ok($zip->set_number('3300042')->is_valid_number, '埼玉県さいたま市浦和区木崎');
ok($zip->set_number('3300043')->is_valid_number, '埼玉県さいたま市浦和区大東');
ok($zip->set_number('3300044')->is_valid_number, '埼玉県さいたま市浦和区瀬ヶ崎');
ok($zip->set_number('3300045')->is_valid_number, '埼玉県さいたま市浦和区皇山町');
ok($zip->set_number('3300046')->is_valid_number, '埼玉県さいたま市浦和区大原');
ok($zip->set_number('3300051')->is_valid_number, '埼玉県さいたま市浦和区駒場');
ok($zip->set_number('3300052')->is_valid_number, '埼玉県さいたま市浦和区本太');
ok($zip->set_number('3300053')->is_valid_number, '埼玉県さいたま市浦和区前地');
ok($zip->set_number('3300054')->is_valid_number, '埼玉県さいたま市浦和区東岸町');
ok($zip->set_number('3300055')->is_valid_number, '埼玉県さいたま市浦和区東高砂町');
ok($zip->set_number('3300056')->is_valid_number, '埼玉県さいたま市浦和区東仲町');
ok($zip->set_number('3300061')->is_valid_number, '埼玉県さいたま市浦和区常盤');
ok($zip->set_number('3300062')->is_valid_number, '埼玉県さいたま市浦和区仲町');
ok($zip->set_number('3300063')->is_valid_number, '埼玉県さいたま市浦和区高砂');
ok($zip->set_number('3300064')->is_valid_number, '埼玉県さいたま市浦和区岸町');
ok($zip->set_number('3300065')->is_valid_number, '埼玉県さいたま市浦和区神明');
ok($zip->set_number('3300071')->is_valid_number, '埼玉県さいたま市浦和区上木崎');
ok($zip->set_number('3300072')->is_valid_number, '埼玉県さいたま市浦和区領家');
ok($zip->set_number('3300073')->is_valid_number, '埼玉県さいたま市浦和区元町');
ok($zip->set_number('3300074')->is_valid_number, '埼玉県さいたま市浦和区北浦和');
ok($zip->set_number('3300075')->is_valid_number, '埼玉県さいたま市浦和区針ヶ谷');
ok($zip->set_number('3300081')->is_valid_number, '埼玉県さいたま市中央区新都心(次のビルを除く)');
ok($zip->set_number('3300800')->is_valid_number, '埼玉県さいたま市大宮区以下に掲載がない場合');
ok($zip->set_number('3300801')->is_valid_number, '埼玉県さいたま市大宮区土手町');
ok($zip->set_number('3300802')->is_valid_number, '埼玉県さいたま市大宮区宮町');
ok($zip->set_number('3300803')->is_valid_number, '埼玉県さいたま市大宮区高鼻町');
ok($zip->set_number('3300804')->is_valid_number, '埼玉県さいたま市大宮区堀の内町');
ok($zip->set_number('3300805')->is_valid_number, '埼玉県さいたま市大宮区寿能町');
ok($zip->set_number('3300834')->is_valid_number, '埼玉県さいたま市大宮区天沼町');
ok($zip->set_number('3300835')->is_valid_number, '埼玉県さいたま市大宮区北袋町');
ok($zip->set_number('3300836')->is_valid_number, '埼玉県さいたま市大宮区大原');
ok($zip->set_number('3300841')->is_valid_number, '埼玉県さいたま市大宮区東町');
ok($zip->set_number('3300842')->is_valid_number, '埼玉県さいたま市大宮区浅間町');
ok($zip->set_number('3300843')->is_valid_number, '埼玉県さいたま市大宮区吉敷町');
ok($zip->set_number('3300844')->is_valid_number, '埼玉県さいたま市大宮区下町');
ok($zip->set_number('3300845')->is_valid_number, '埼玉県さいたま市大宮区仲町');
ok($zip->set_number('3300846')->is_valid_number, '埼玉県さいたま市大宮区大門町');
ok($zip->set_number('3300851')->is_valid_number, '埼玉県さいたま市大宮区櫛引町');
ok($zip->set_number('3300852')->is_valid_number, '埼玉県さいたま市大宮区大成町');
ok($zip->set_number('3300853')->is_valid_number, '埼玉県さいたま市大宮区錦町');
ok($zip->set_number('3300854')->is_valid_number, '埼玉県さいたま市大宮区桜木町');
ok($zip->set_number('3300855')->is_valid_number, '埼玉県さいたま市大宮区上小町');
ok($zip->set_number('3300856')->is_valid_number, '埼玉県さいたま市大宮区三橋');
ok($zip->set_number('3306001')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(1階)');
ok($zip->set_number('3306002')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(2階)');
ok($zip->set_number('3306003')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(3階)');
ok($zip->set_number('3306004')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(4階)');
ok($zip->set_number('3306005')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(5階)');
ok($zip->set_number('3306006')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(6階)');
ok($zip->set_number('3306007')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(7階)');
ok($zip->set_number('3306008')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(8階)');
ok($zip->set_number('3306009')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(9階)');
ok($zip->set_number('3306010')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(10階)');
ok($zip->set_number('3306011')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(11階)');
ok($zip->set_number('3306012')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(12階)');
ok($zip->set_number('3306013')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(13階)');
ok($zip->set_number('3306014')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(14階)');
ok($zip->set_number('3306015')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(15階)');
ok($zip->set_number('3306016')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(16階)');
ok($zip->set_number('3306017')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(17階)');
ok($zip->set_number('3306018')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(18階)');
ok($zip->set_number('3306019')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(19階)');
ok($zip->set_number('3306020')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(20階)');
ok($zip->set_number('3306021')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(21階)');
ok($zip->set_number('3306022')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(22階)');
ok($zip->set_number('3306023')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(23階)');
ok($zip->set_number('3306024')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(24階)');
ok($zip->set_number('3306025')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(25階)');
ok($zip->set_number('3306026')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(26階)');
ok($zip->set_number('3306027')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(27階)');
ok($zip->set_number('3306028')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(28階)');
ok($zip->set_number('3306029')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(29階)');
ok($zip->set_number('3306030')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(30階)');
ok($zip->set_number('3306031')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(31階)');
ok($zip->set_number('3306032')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(32階)');
ok($zip->set_number('3306033')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(33階)');
ok($zip->set_number('3306034')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(34階)');
ok($zip->set_number('3306035')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(35階)');
ok($zip->set_number('3306090')->is_valid_number, '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル(地階・階層不明)');
ok($zip->set_number('3310000')->is_valid_number, '埼玉県さいたま市西区以下に掲載がない場合');
ok($zip->set_number('3310045')->is_valid_number, '埼玉県さいたま市西区内野本郷');
ok($zip->set_number('3310046')->is_valid_number, '埼玉県さいたま市西区宮前町');
ok($zip->set_number('3310047')->is_valid_number, '埼玉県さいたま市西区指扇');
ok($zip->set_number('3310048')->is_valid_number, '埼玉県さいたま市西区清河寺');
ok($zip->set_number('3310049')->is_valid_number, '埼玉県さいたま市西区西新井');
ok($zip->set_number('3310052')->is_valid_number, '埼玉県さいたま市西区三橋');
ok($zip->set_number('3310053')->is_valid_number, '埼玉県さいたま市西区植田谷本');
ok($zip->set_number('3310054')->is_valid_number, '埼玉県さいたま市西区島根');
ok($zip->set_number('3310055')->is_valid_number, '埼玉県さいたま市西区昭和');
ok($zip->set_number('3310056')->is_valid_number, '埼玉県さいたま市西区三条町');
ok($zip->set_number('3310057')->is_valid_number, '埼玉県さいたま市西区中野林');
ok($zip->set_number('3310058')->is_valid_number, '埼玉県さいたま市西区飯田');
ok($zip->set_number('3310059')->is_valid_number, '埼玉県さいたま市西区水判土');
ok($zip->set_number('3310060')->is_valid_number, '埼玉県さいたま市西区塚本町');
ok($zip->set_number('3310061')->is_valid_number, '埼玉県さいたま市西区西遊馬');
ok($zip->set_number('3310062')->is_valid_number, '埼玉県さいたま市西区土屋');
ok($zip->set_number('3310063')->is_valid_number, '埼玉県さいたま市西区プラザ');
ok($zip->set_number('3310064')->is_valid_number, '埼玉県さいたま市西区佐知川');
ok($zip->set_number('3310065')->is_valid_number, '埼玉県さいたま市西区二ツ宮');
ok($zip->set_number('3310066')->is_valid_number, '埼玉県さいたま市西区塚本');
ok($zip->set_number('3310067')->is_valid_number, '埼玉県さいたま市西区植田谷本村新田');
ok($zip->set_number('3310068')->is_valid_number, '埼玉県さいたま市西区飯田新田');
ok($zip->set_number('3310069')->is_valid_number, '埼玉県さいたま市西区湯木町');
ok($zip->set_number('3310071')->is_valid_number, '埼玉県さいたま市西区高木');
ok($zip->set_number('3310072')->is_valid_number, '埼玉県さいたま市西区平方領々家');
ok($zip->set_number('3310073')->is_valid_number, '埼玉県さいたま市西区指扇領別所');
ok($zip->set_number('3310074')->is_valid_number, '埼玉県さいたま市西区宝来');
ok($zip->set_number('3310075')->is_valid_number, '埼玉県さいたま市西区峰岸');
ok($zip->set_number('3310076')->is_valid_number, '埼玉県さいたま市西区指扇領辻');
ok($zip->set_number('3310077')->is_valid_number, '埼玉県さいたま市西区中釘');
ok($zip->set_number('3310078')->is_valid_number, '埼玉県さいたま市西区西大宮');
ok($zip->set_number('3310800')->is_valid_number, '埼玉県さいたま市北区以下に掲載がない場合');
ok($zip->set_number('3310801')->is_valid_number, '埼玉県さいたま市北区今羽町');
ok($zip->set_number('3310802')->is_valid_number, '埼玉県さいたま市北区本郷町');
ok($zip->set_number('3310803')->is_valid_number, '埼玉県さいたま市北区見沼');
ok($zip->set_number('3310804')->is_valid_number, '埼玉県さいたま市北区土呂町');
ok($zip->set_number('3310805')->is_valid_number, '埼玉県さいたま市北区盆栽町');
ok($zip->set_number('3310811')->is_valid_number, '埼玉県さいたま市北区吉野町');
ok($zip->set_number('3310812')->is_valid_number, '埼玉県さいたま市北区宮原町');
ok($zip->set_number('3310813')->is_valid_number, '埼玉県さいたま市北区植竹町');
ok($zip->set_number('3310814')->is_valid_number, '埼玉県さいたま市北区東大成町');
ok($zip->set_number('3310815')->is_valid_number, '埼玉県さいたま市北区大成町');
ok($zip->set_number('3310821')->is_valid_number, '埼玉県さいたま市北区別所町');
ok($zip->set_number('3310822')->is_valid_number, '埼玉県さいたま市北区奈良町');
ok($zip->set_number('3310823')->is_valid_number, '埼玉県さいたま市北区日進町');
ok($zip->set_number('3310824')->is_valid_number, '埼玉県さいたま市北区上加');
ok($zip->set_number('3310825')->is_valid_number, '埼玉県さいたま市北区櫛引町');
ok($zip->set_number('3320000')->is_valid_number, '埼玉県川口市以下に掲載がない場合');
ok($zip->set_number('3320001')->is_valid_number, '埼玉県川口市朝日');
ok($zip->set_number('3320002')->is_valid_number, '埼玉県川口市弥平');
ok($zip->set_number('3320003')->is_valid_number, '埼玉県川口市東領家');
ok($zip->set_number('3320004')->is_valid_number, '埼玉県川口市領家');
ok($zip->set_number('3320005')->is_valid_number, '埼玉県川口市新井町');
ok($zip->set_number('3320006')->is_valid_number, '埼玉県川口市末広');
ok($zip->set_number('3320007')->is_valid_number, '埼玉県川口市河原町');
ok($zip->set_number('3320011')->is_valid_number, '埼玉県川口市元郷');
ok($zip->set_number('3320012')->is_valid_number, '埼玉県川口市本町');
ok($zip->set_number('3320013')->is_valid_number, '埼玉県川口市舟戸町');
ok($zip->set_number('3320014')->is_valid_number, '埼玉県川口市金山町');
ok($zip->set_number('3320015')->is_valid_number, '埼玉県川口市川口');
ok($zip->set_number('3320016')->is_valid_number, '埼玉県川口市幸町');
ok($zip->set_number('3320017')->is_valid_number, '埼玉県川口市栄町');
ok($zip->set_number('3320021')->is_valid_number, '埼玉県川口市西川口');
ok($zip->set_number('3320022')->is_valid_number, '埼玉県川口市仲町');
ok($zip->set_number('3320023')->is_valid_number, '埼玉県川口市飯塚');
ok($zip->set_number('3320024')->is_valid_number, '埼玉県川口市飯原町');
ok($zip->set_number('3320025')->is_valid_number, '埼玉県川口市原町');
ok($zip->set_number('3320026')->is_valid_number, '埼玉県川口市南町');
ok($zip->set_number('3320027')->is_valid_number, '埼玉県川口市緑町');
ok($zip->set_number('3320028')->is_valid_number, '埼玉県川口市宮町');
ok($zip->set_number('3320029')->is_valid_number, '埼玉県川口市荒川町');
ok($zip->set_number('3320031')->is_valid_number, '埼玉県川口市青木');
ok($zip->set_number('3320032')->is_valid_number, '埼玉県川口市中青木');
ok($zip->set_number('3320033')->is_valid_number, '埼玉県川口市並木元町');
ok($zip->set_number('3320034')->is_valid_number, '埼玉県川口市並木');
ok($zip->set_number('3320035')->is_valid_number, '埼玉県川口市西青木');
ok($zip->set_number('3330801')->is_valid_number, '埼玉県川口市東川口');
ok($zip->set_number('3330802')->is_valid_number, '埼玉県川口市戸塚東');
ok($zip->set_number('3330803')->is_valid_number, '埼玉県川口市藤兵衛新田');
ok($zip->set_number('3330804')->is_valid_number, '埼玉県川口市久左衛門新田');
ok($zip->set_number('3330805')->is_valid_number, '埼玉県川口市戸塚鋏町');
ok($zip->set_number('3330806')->is_valid_number, '埼玉県川口市戸塚境町');
ok($zip->set_number('3330807')->is_valid_number, '埼玉県川口市長蔵');
ok($zip->set_number('3330808')->is_valid_number, '埼玉県川口市長蔵新田');
ok($zip->set_number('3330811')->is_valid_number, '埼玉県川口市戸塚');
ok($zip->set_number('3330812')->is_valid_number, '埼玉県川口市安行西立野');
ok($zip->set_number('3330813')->is_valid_number, '埼玉県川口市西立野');
ok($zip->set_number('3330814')->is_valid_number, '埼玉県川口市行衛');
ok($zip->set_number('3330815')->is_valid_number, '埼玉県川口市北原台');
ok($zip->set_number('3330816')->is_valid_number, '埼玉県川口市差間');
ok($zip->set_number('3330817')->is_valid_number, '埼玉県川口市戸塚南');
ok($zip->set_number('3330821')->is_valid_number, '埼玉県川口市東内野');
ok($zip->set_number('3330822')->is_valid_number, '埼玉県川口市源左衛門新田');
ok($zip->set_number('3330823')->is_valid_number, '埼玉県川口市石神');
ok($zip->set_number('3330824')->is_valid_number, '埼玉県川口市赤芝新田');
ok($zip->set_number('3330825')->is_valid_number, '埼玉県川口市赤山');
ok($zip->set_number('3330826')->is_valid_number, '埼玉県川口市新井宿');
ok($zip->set_number('3330831')->is_valid_number, '埼玉県川口市木曽呂');
ok($zip->set_number('3330832')->is_valid_number, '埼玉県川口市神戸');
ok($zip->set_number('3330833')->is_valid_number, '埼玉県川口市西新井宿');
ok($zip->set_number('3330834')->is_valid_number, '埼玉県川口市安行領根岸');
ok($zip->set_number('3330835')->is_valid_number, '埼玉県川口市道合');
ok($zip->set_number('3330836')->is_valid_number, '埼玉県川口市安行領在家');
ok($zip->set_number('3330841')->is_valid_number, '埼玉県川口市前川町');
ok($zip->set_number('3330842')->is_valid_number, '埼玉県川口市前川');
ok($zip->set_number('3330843')->is_valid_number, '埼玉県川口市前上町');
ok($zip->set_number('3330844')->is_valid_number, '埼玉県川口市上青木');
ok($zip->set_number('3330845')->is_valid_number, '埼玉県川口市上青木西');
ok($zip->set_number('3330846')->is_valid_number, '埼玉県川口市南前川');
ok($zip->set_number('3330847')->is_valid_number, '埼玉県川口市芝中田');
ok($zip->set_number('3330848')->is_valid_number, '埼玉県川口市芝下');
ok($zip->set_number('3330849')->is_valid_number, '埼玉県川口市本前川');
ok($zip->set_number('3330851')->is_valid_number, '埼玉県川口市芝新町');
ok($zip->set_number('3330852')->is_valid_number, '埼玉県川口市芝樋ノ爪');
ok($zip->set_number('3330853')->is_valid_number, '埼玉県川口市芝園町');
ok($zip->set_number('3330854')->is_valid_number, '埼玉県川口市芝富士');
ok($zip->set_number('3330855')->is_valid_number, '埼玉県川口市芝西');
ok($zip->set_number('3330856')->is_valid_number, '埼玉県川口市芝塚原');
ok($zip->set_number('3330857')->is_valid_number, '埼玉県川口市小谷場');
ok($zip->set_number('3330861')->is_valid_number, '埼玉県川口市柳崎');
ok($zip->set_number('3330862')->is_valid_number, '埼玉県川口市北園町');
ok($zip->set_number('3330863')->is_valid_number, '埼玉県川口市在家町');
ok($zip->set_number('3330864')->is_valid_number, '埼玉県川口市柳根町');
ok($zip->set_number('3330865')->is_valid_number, '埼玉県川口市伊刈');
ok($zip->set_number('3330866')->is_valid_number, '埼玉県川口市芝');
ok($zip->set_number('3330867')->is_valid_number, '埼玉県川口市芝東町');
ok($zip->set_number('3330868')->is_valid_number, '埼玉県川口市芝高木');
ok($zip->set_number('3330869')->is_valid_number, '埼玉県川口市芝宮根町');
ok($zip->set_number('3340001')->is_valid_number, '埼玉県川口市桜町');
ok($zip->set_number('3340002')->is_valid_number, '埼玉県川口市鳩ヶ谷本町');
ok($zip->set_number('3340003')->is_valid_number, '埼玉県川口市坂下町');
ok($zip->set_number('3340004')->is_valid_number, '埼玉県川口市辻');
ok($zip->set_number('3340005')->is_valid_number, '埼玉県川口市里');
ok($zip->set_number('3340011')->is_valid_number, '埼玉県川口市三ツ和');
ok($zip->set_number('3340012')->is_valid_number, '埼玉県川口市八幡木');
ok($zip->set_number('3340013')->is_valid_number, '埼玉県川口市南鳩ヶ谷');
ok($zip->set_number('3340014')->is_valid_number, '埼玉県川口市前田');
ok($zip->set_number('3340015')->is_valid_number, '埼玉県川口市鳩ヶ谷緑町');
ok($zip->set_number('3340051')->is_valid_number, '埼玉県川口市安行藤八');
ok($zip->set_number('3340052')->is_valid_number, '埼玉県川口市安行出羽');
ok($zip->set_number('3340053')->is_valid_number, '埼玉県川口市安行吉蔵');
ok($zip->set_number('3340054')->is_valid_number, '埼玉県川口市安行北谷');
ok($zip->set_number('3340055')->is_valid_number, '埼玉県川口市安行小山');
ok($zip->set_number('3340056')->is_valid_number, '埼玉県川口市峯');
ok($zip->set_number('3340057')->is_valid_number, '埼玉県川口市安行原');
ok($zip->set_number('3340058')->is_valid_number, '埼玉県川口市安行領家');
ok($zip->set_number('3340059')->is_valid_number, '埼玉県川口市安行');
ok($zip->set_number('3340061')->is_valid_number, '埼玉県川口市新堀');
ok($zip->set_number('3340062')->is_valid_number, '埼玉県川口市榛松');
ok($zip->set_number('3340063')->is_valid_number, '埼玉県川口市東本郷');
ok($zip->set_number('3340064')->is_valid_number, '埼玉県川口市蓮沼');
ok($zip->set_number('3340065')->is_valid_number, '埼玉県川口市前野宿');
ok($zip->set_number('3340066')->is_valid_number, '埼玉県川口市東貝塚');
ok($zip->set_number('3340067')->is_valid_number, '埼玉県川口市大竹');
ok($zip->set_number('3340068')->is_valid_number, '埼玉県川口市新堀町');
ok($zip->set_number('3340071')->is_valid_number, '埼玉県川口市安行慈林');
ok($zip->set_number('3340072')->is_valid_number, '埼玉県川口市安行吉岡');
ok($zip->set_number('3340073')->is_valid_number, '埼玉県川口市赤井');
ok($zip->set_number('3340074')->is_valid_number, '埼玉県川口市江戸');
ok($zip->set_number('3340075')->is_valid_number, '埼玉県川口市江戸袋');
ok($zip->set_number('3340076')->is_valid_number, '埼玉県川口市本蓮');
ok($zip->set_number('3350000')->is_valid_number, '埼玉県蕨市以下に掲載がない場合');
ok($zip->set_number('3350000')->is_valid_number, '埼玉県戸田市以下に掲載がない場合');
ok($zip->set_number('3350001')->is_valid_number, '埼玉県蕨市北町');
ok($zip->set_number('3350002')->is_valid_number, '埼玉県蕨市塚越');
ok($zip->set_number('3350003')->is_valid_number, '埼玉県蕨市南町');
ok($zip->set_number('3350004')->is_valid_number, '埼玉県蕨市中央');
ok($zip->set_number('3350005')->is_valid_number, '埼玉県蕨市錦町');
ok($zip->set_number('3350011')->is_valid_number, '埼玉県戸田市下戸田');
ok($zip->set_number('3350012')->is_valid_number, '埼玉県戸田市中町');
ok($zip->set_number('3350013')->is_valid_number, '埼玉県戸田市喜沢');
ok($zip->set_number('3350014')->is_valid_number, '埼玉県戸田市喜沢南');
ok($zip->set_number('3350015')->is_valid_number, '埼玉県戸田市川岸');
ok($zip->set_number('3350016')->is_valid_number, '埼玉県戸田市下前');
ok($zip->set_number('3350021')->is_valid_number, '埼玉県戸田市新曽');
ok($zip->set_number('3350022')->is_valid_number, '埼玉県戸田市上戸田');
ok($zip->set_number('3350023')->is_valid_number, '埼玉県戸田市本町');
ok($zip->set_number('3350024')->is_valid_number, '埼玉県戸田市戸田公園');
ok($zip->set_number('3350025')->is_valid_number, '埼玉県戸田市南町');
ok($zip->set_number('3350026')->is_valid_number, '埼玉県戸田市新曽南');
ok($zip->set_number('3350027')->is_valid_number, '埼玉県戸田市氷川町');
ok($zip->set_number('3350031')->is_valid_number, '埼玉県戸田市美女木');
ok($zip->set_number('3350032')->is_valid_number, '埼玉県戸田市美女木東');
ok($zip->set_number('3350033')->is_valid_number, '埼玉県戸田市笹目北町');
ok($zip->set_number('3350034')->is_valid_number, '埼玉県戸田市笹目');
ok($zip->set_number('3350035')->is_valid_number, '埼玉県戸田市笹目南町');
ok($zip->set_number('3350036')->is_valid_number, '埼玉県戸田市早瀬');
ok($zip->set_number('3350037')->is_valid_number, '埼玉県戸田市下笹目');
ok($zip->set_number('3350038')->is_valid_number, '埼玉県戸田市美女木北');
ok($zip->set_number('3360000')->is_valid_number, '埼玉県さいたま市南区以下に掲載がない場合');
ok($zip->set_number('3360015')->is_valid_number, '埼玉県さいたま市南区太田窪');
ok($zip->set_number('3360016')->is_valid_number, '埼玉県さいたま市南区大谷場');
ok($zip->set_number('3360017')->is_valid_number, '埼玉県さいたま市南区南浦和');
ok($zip->set_number('3360018')->is_valid_number, '埼玉県さいたま市南区南本町');
ok($zip->set_number('3360021')->is_valid_number, '埼玉県さいたま市南区別所');
ok($zip->set_number('3360022')->is_valid_number, '埼玉県さいたま市南区白幡');
ok($zip->set_number('3360023')->is_valid_number, '埼玉県さいたま市南区神明');
ok($zip->set_number('3360024')->is_valid_number, '埼玉県さいたま市南区根岸');
ok($zip->set_number('3360025')->is_valid_number, '埼玉県さいたま市南区文蔵');
ok($zip->set_number('3360026')->is_valid_number, '埼玉県さいたま市南区辻');
ok($zip->set_number('3360027')->is_valid_number, '埼玉県さいたま市南区沼影');
ok($zip->set_number('3360031')->is_valid_number, '埼玉県さいたま市南区鹿手袋');
ok($zip->set_number('3360032')->is_valid_number, '埼玉県さいたま市南区四谷');
ok($zip->set_number('3360033')->is_valid_number, '埼玉県さいたま市南区曲本');
ok($zip->set_number('3360034')->is_valid_number, '埼玉県さいたま市南区内谷');
ok($zip->set_number('3360035')->is_valid_number, '埼玉県さいたま市南区松本');
ok($zip->set_number('3360036')->is_valid_number, '埼玉県さいたま市南区堤外');
ok($zip->set_number('3360038')->is_valid_number, '埼玉県さいたま市南区関');
ok($zip->set_number('3360041')->is_valid_number, '埼玉県さいたま市南区広ヶ谷戸');
ok($zip->set_number('3360042')->is_valid_number, '埼玉県さいたま市南区大谷口');
ok($zip->set_number('3360043')->is_valid_number, '埼玉県さいたま市南区円正寺');
ok($zip->set_number('3360900')->is_valid_number, '埼玉県さいたま市緑区以下に掲載がない場合');
ok($zip->set_number('3360903')->is_valid_number, '埼玉県さいたま市緑区山崎');
ok($zip->set_number('3360905')->is_valid_number, '埼玉県さいたま市緑区大道');
ok($zip->set_number('3360906')->is_valid_number, '埼玉県さいたま市緑区三浦');
ok($zip->set_number('3360907')->is_valid_number, '埼玉県さいたま市緑区道祖土');
ok($zip->set_number('3360911')->is_valid_number, '埼玉県さいたま市緑区三室');
ok($zip->set_number('3360912')->is_valid_number, '埼玉県さいたま市緑区馬場');
ok($zip->set_number('3360913')->is_valid_number, '埼玉県さいたま市緑区新宿');
ok($zip->set_number('3360914')->is_valid_number, '埼玉県さいたま市緑区宮後');
ok($zip->set_number('3360915')->is_valid_number, '埼玉県さいたま市緑区見沼');
ok($zip->set_number('3360916')->is_valid_number, '埼玉県さいたま市緑区宮本');
ok($zip->set_number('3360917')->is_valid_number, '埼玉県さいたま市緑区芝原');
ok($zip->set_number('3360918')->is_valid_number, '埼玉県さいたま市緑区松木');
ok($zip->set_number('3360922')->is_valid_number, '埼玉県さいたま市緑区大牧');
ok($zip->set_number('3360923')->is_valid_number, '埼玉県さいたま市緑区大間木');
ok($zip->set_number('3360924')->is_valid_number, '埼玉県さいたま市緑区蓮見新田');
ok($zip->set_number('3360925')->is_valid_number, '埼玉県さいたま市緑区下山口新田');
ok($zip->set_number('3360926')->is_valid_number, '埼玉県さいたま市緑区東浦和');
ok($zip->set_number('3360931')->is_valid_number, '埼玉県さいたま市緑区原山');
ok($zip->set_number('3360932')->is_valid_number, '埼玉県さいたま市緑区中尾');
ok($zip->set_number('3360934')->is_valid_number, '埼玉県さいたま市緑区大谷口');
ok($zip->set_number('3360936')->is_valid_number, '埼玉県さいたま市緑区太田窪');
ok($zip->set_number('3360961')->is_valid_number, '埼玉県さいたま市緑区玄蕃新田');
ok($zip->set_number('3360962')->is_valid_number, '埼玉県さいたま市緑区下野田');
ok($zip->set_number('3360963')->is_valid_number, '埼玉県さいたま市緑区大門');
ok($zip->set_number('3360964')->is_valid_number, '埼玉県さいたま市緑区東大門');
ok($zip->set_number('3360965')->is_valid_number, '埼玉県さいたま市緑区間宮');
ok($zip->set_number('3360966')->is_valid_number, '埼玉県さいたま市緑区北原');
ok($zip->set_number('3360967')->is_valid_number, '埼玉県さいたま市緑区美園');
ok($zip->set_number('3360971')->is_valid_number, '埼玉県さいたま市緑区高畑');
ok($zip->set_number('3360972')->is_valid_number, '埼玉県さいたま市緑区中野田');
ok($zip->set_number('3360973')->is_valid_number, '埼玉県さいたま市緑区南部領辻');
ok($zip->set_number('3360974')->is_valid_number, '埼玉県さいたま市緑区大崎');
ok($zip->set_number('3360975')->is_valid_number, '埼玉県さいたま市緑区代山');
ok($zip->set_number('3360976')->is_valid_number, '埼玉県さいたま市緑区寺山');
ok($zip->set_number('3360977')->is_valid_number, '埼玉県さいたま市緑区上野田');
ok($zip->set_number('3370000')->is_valid_number, '埼玉県さいたま市見沼区以下に掲載がない場合');
ok($zip->set_number('3370001')->is_valid_number, '埼玉県さいたま市見沼区丸ヶ崎');
ok($zip->set_number('3370002')->is_valid_number, '埼玉県さいたま市見沼区春野');
ok($zip->set_number('3370003')->is_valid_number, '埼玉県さいたま市見沼区深作');
ok($zip->set_number('3370004')->is_valid_number, '埼玉県さいたま市見沼区卸町');
ok($zip->set_number('3370005')->is_valid_number, '埼玉県さいたま市見沼区小深作');
ok($zip->set_number('3370006')->is_valid_number, '埼玉県さいたま市見沼区島町');
ok($zip->set_number('3370007')->is_valid_number, '埼玉県さいたま市見沼区丸ヶ崎町');
ok($zip->set_number('3370008')->is_valid_number, '埼玉県さいたま市見沼区春岡');
ok($zip->set_number('3370011')->is_valid_number, '埼玉県さいたま市見沼区宮ヶ谷塔');
ok($zip->set_number('3370012')->is_valid_number, '埼玉県さいたま市見沼区東宮下');
ok($zip->set_number('3370013')->is_valid_number, '埼玉県さいたま市見沼区新堤');
ok($zip->set_number('3370014')->is_valid_number, '埼玉県さいたま市見沼区大谷');
ok($zip->set_number('3370015')->is_valid_number, '埼玉県さいたま市見沼区蓮沼');
ok($zip->set_number('3370016')->is_valid_number, '埼玉県さいたま市見沼区東門前');
ok($zip->set_number('3370017')->is_valid_number, '埼玉県さいたま市見沼区風渡野');
ok($zip->set_number('3370021')->is_valid_number, '埼玉県さいたま市見沼区膝子');
ok($zip->set_number('3370022')->is_valid_number, '埼玉県さいたま市見沼区加田屋');
ok($zip->set_number('3370023')->is_valid_number, '埼玉県さいたま市見沼区片柳東');
ok($zip->set_number('3370024')->is_valid_number, '埼玉県さいたま市見沼区片柳');
ok($zip->set_number('3370025')->is_valid_number, '埼玉県さいたま市見沼区山');
ok($zip->set_number('3370026')->is_valid_number, '埼玉県さいたま市見沼区染谷');
ok($zip->set_number('3370027')->is_valid_number, '埼玉県さいたま市見沼区加田屋新田');
ok($zip->set_number('3370031')->is_valid_number, '埼玉県さいたま市見沼区笹丸');
ok($zip->set_number('3370032')->is_valid_number, '埼玉県さいたま市見沼区東新井');
ok($zip->set_number('3370033')->is_valid_number, '埼玉県さいたま市見沼区御蔵');
ok($zip->set_number('3370034')->is_valid_number, '埼玉県さいたま市見沼区西山村新田');
ok($zip->set_number('3370035')->is_valid_number, '埼玉県さいたま市見沼区西山新田');
ok($zip->set_number('3370036')->is_valid_number, '埼玉県さいたま市見沼区見山');
ok($zip->set_number('3370041')->is_valid_number, '埼玉県さいたま市見沼区南中丸');
ok($zip->set_number('3370042')->is_valid_number, '埼玉県さいたま市見沼区南中野');
ok($zip->set_number('3370043')->is_valid_number, '埼玉県さいたま市見沼区中川');
ok($zip->set_number('3370044')->is_valid_number, '埼玉県さいたま市見沼区上山口新田');
ok($zip->set_number('3370045')->is_valid_number, '埼玉県さいたま市見沼区新右ェ門新田');
ok($zip->set_number('3370051')->is_valid_number, '埼玉県さいたま市見沼区東大宮');
ok($zip->set_number('3370052')->is_valid_number, '埼玉県さいたま市見沼区堀崎町');
ok($zip->set_number('3370053')->is_valid_number, '埼玉県さいたま市見沼区大和田町');
ok($zip->set_number('3370054')->is_valid_number, '埼玉県さいたま市見沼区砂町');
ok($zip->set_number('3380001')->is_valid_number, '埼玉県さいたま市中央区上落合');
ok($zip->set_number('3380002')->is_valid_number, '埼玉県さいたま市中央区下落合');
ok($zip->set_number('3380003')->is_valid_number, '埼玉県さいたま市中央区本町東');
ok($zip->set_number('3380004')->is_valid_number, '埼玉県さいたま市中央区本町西');
ok($zip->set_number('3380005')->is_valid_number, '埼玉県さいたま市中央区桜丘');
ok($zip->set_number('3380006')->is_valid_number, '埼玉県さいたま市中央区八王子');
ok($zip->set_number('3380007')->is_valid_number, '埼玉県さいたま市中央区円阿弥');
ok($zip->set_number('3380011')->is_valid_number, '埼玉県さいたま市中央区新中里');
ok($zip->set_number('3380012')->is_valid_number, '埼玉県さいたま市中央区大戸');
ok($zip->set_number('3380013')->is_valid_number, '埼玉県さいたま市中央区鈴谷');
ok($zip->set_number('3380014')->is_valid_number, '埼玉県さいたま市中央区上峰');
ok($zip->set_number('3380800')->is_valid_number, '埼玉県さいたま市桜区以下に掲載がない場合');
ok($zip->set_number('3380811')->is_valid_number, '埼玉県さいたま市桜区白鍬');
ok($zip->set_number('3380812')->is_valid_number, '埼玉県さいたま市桜区神田');
ok($zip->set_number('3380813')->is_valid_number, '埼玉県さいたま市桜区在家');
ok($zip->set_number('3380814')->is_valid_number, '埼玉県さいたま市桜区宿');
ok($zip->set_number('3380815')->is_valid_number, '埼玉県さいたま市桜区五関');
ok($zip->set_number('3380816')->is_valid_number, '埼玉県さいたま市桜区塚本');
ok($zip->set_number('3380817')->is_valid_number, '埼玉県さいたま市桜区昭和');
ok($zip->set_number('3380821')->is_valid_number, '埼玉県さいたま市桜区山久保');
ok($zip->set_number('3380822')->is_valid_number, '埼玉県さいたま市桜区中島');
ok($zip->set_number('3380823')->is_valid_number, '埼玉県さいたま市桜区栄和');
ok($zip->set_number('3380824')->is_valid_number, '埼玉県さいたま市桜区上大久保');
ok($zip->set_number('3380825')->is_valid_number, '埼玉県さいたま市桜区下大久保');
ok($zip->set_number('3380826')->is_valid_number, '埼玉県さいたま市桜区大久保領家');
ok($zip->set_number('3380831')->is_valid_number, '埼玉県さいたま市桜区南元宿');
ok($zip->set_number('3380832')->is_valid_number, '埼玉県さいたま市桜区西堀');
ok($zip->set_number('3380833')->is_valid_number, '埼玉県さいたま市桜区桜田');
ok($zip->set_number('3380834')->is_valid_number, '埼玉県さいたま市桜区新開');
ok($zip->set_number('3380835')->is_valid_number, '埼玉県さいたま市桜区道場');
ok($zip->set_number('3380836')->is_valid_number, '埼玉県さいたま市桜区町谷');
ok($zip->set_number('3380837')->is_valid_number, '埼玉県さいたま市桜区田島');
ok($zip->set_number('3390000')->is_valid_number, '埼玉県さいたま市岩槻区以下に掲載がない場合');
ok($zip->set_number('3390001')->is_valid_number, '埼玉県さいたま市岩槻区鹿室');
ok($zip->set_number('3390002')->is_valid_number, '埼玉県さいたま市岩槻区裏慈恩寺');
ok($zip->set_number('3390003')->is_valid_number, '埼玉県さいたま市岩槻区小溝');
ok($zip->set_number('3390004')->is_valid_number, '埼玉県さいたま市岩槻区徳力');
ok($zip->set_number('3390005')->is_valid_number, '埼玉県さいたま市岩槻区東岩槻');
ok($zip->set_number('3390006')->is_valid_number, '埼玉県さいたま市岩槻区上里');
ok($zip->set_number('3390007')->is_valid_number, '埼玉県さいたま市岩槻区諏訪');
ok($zip->set_number('3390008')->is_valid_number, '埼玉県さいたま市岩槻区表慈恩寺');
ok($zip->set_number('3390009')->is_valid_number, '埼玉県さいたま市岩槻区慈恩寺');
ok($zip->set_number('3390011')->is_valid_number, '埼玉県さいたま市岩槻区長宮');
ok($zip->set_number('3390012')->is_valid_number, '埼玉県さいたま市岩槻区増長');
ok($zip->set_number('3390013')->is_valid_number, '埼玉県さいたま市岩槻区大口');
ok($zip->set_number('3390014')->is_valid_number, '埼玉県さいたま市岩槻区大戸');
ok($zip->set_number('3390015')->is_valid_number, '埼玉県さいたま市岩槻区大谷');
ok($zip->set_number('3390016')->is_valid_number, '埼玉県さいたま市岩槻区新方須賀');
ok($zip->set_number('3390017')->is_valid_number, '埼玉県さいたま市岩槻区大森');
ok($zip->set_number('3390018')->is_valid_number, '埼玉県さいたま市岩槻区大野島');
ok($zip->set_number('3390021')->is_valid_number, '埼玉県さいたま市岩槻区末田');
ok($zip->set_number('3390022')->is_valid_number, '埼玉県さいたま市岩槻区高曽根');
ok($zip->set_number('3390023')->is_valid_number, '埼玉県さいたま市岩槻区野孫');
ok($zip->set_number('3390024')->is_valid_number, '埼玉県さいたま市岩槻区釣上');
ok($zip->set_number('3390025')->is_valid_number, '埼玉県さいたま市岩槻区釣上新田');
ok($zip->set_number('3390026')->is_valid_number, '埼玉県さいたま市岩槻区尾ヶ崎新田');
ok($zip->set_number('3390027')->is_valid_number, '埼玉県さいたま市岩槻区尾ヶ崎');
ok($zip->set_number('3390028')->is_valid_number, '埼玉県さいたま市岩槻区美園東');
ok($zip->set_number('3390031')->is_valid_number, '埼玉県さいたま市岩槻区飯塚');
ok($zip->set_number('3390032')->is_valid_number, '埼玉県さいたま市岩槻区南下新井');
ok($zip->set_number('3390033')->is_valid_number, '埼玉県さいたま市岩槻区黒谷');
ok($zip->set_number('3390034')->is_valid_number, '埼玉県さいたま市岩槻区笹久保');
ok($zip->set_number('3390035')->is_valid_number, '埼玉県さいたま市岩槻区笹久保新田');
ok($zip->set_number('3390036')->is_valid_number, '埼玉県さいたま市岩槻区横根');
ok($zip->set_number('3390037')->is_valid_number, '埼玉県さいたま市岩槻区浮谷');
ok($zip->set_number('3390041')->is_valid_number, '埼玉県さいたま市岩槻区村国');
ok($zip->set_number('3390042')->is_valid_number, '埼玉県さいたま市岩槻区府内');
ok($zip->set_number('3390043')->is_valid_number, '埼玉県さいたま市岩槻区城南');
ok($zip->set_number('3390044')->is_valid_number, '埼玉県さいたま市岩槻区真福寺');
ok($zip->set_number('3390045')->is_valid_number, '埼玉県さいたま市岩槻区柏崎');
ok($zip->set_number('3390046')->is_valid_number, '埼玉県さいたま市岩槻区谷下');
ok($zip->set_number('3390047')->is_valid_number, '埼玉県さいたま市岩槻区原町');
ok($zip->set_number('3390051')->is_valid_number, '埼玉県さいたま市岩槻区南平野');
ok($zip->set_number('3390052')->is_valid_number, '埼玉県さいたま市岩槻区太田');
ok($zip->set_number('3390053')->is_valid_number, '埼玉県さいたま市岩槻区城町');
ok($zip->set_number('3390054')->is_valid_number, '埼玉県さいたま市岩槻区仲町');
ok($zip->set_number('3390055')->is_valid_number, '埼玉県さいたま市岩槻区東町');
ok($zip->set_number('3390056')->is_valid_number, '埼玉県さいたま市岩槻区加倉');
ok($zip->set_number('3390057')->is_valid_number, '埼玉県さいたま市岩槻区本町');
ok($zip->set_number('3390058')->is_valid_number, '埼玉県さいたま市岩槻区本丸');
ok($zip->set_number('3390061')->is_valid_number, '埼玉県さいたま市岩槻区岩槻');
ok($zip->set_number('3390062')->is_valid_number, '埼玉県さいたま市岩槻区南辻');
ok($zip->set_number('3390063')->is_valid_number, '埼玉県さいたま市岩槻区美幸町');
ok($zip->set_number('3390064')->is_valid_number, '埼玉県さいたま市岩槻区日の出町');
ok($zip->set_number('3390065')->is_valid_number, '埼玉県さいたま市岩槻区宮町');
ok($zip->set_number('3390066')->is_valid_number, '埼玉県さいたま市岩槻区愛宕町');
ok($zip->set_number('3390067')->is_valid_number, '埼玉県さいたま市岩槻区西町');
ok($zip->set_number('3390068')->is_valid_number, '埼玉県さいたま市岩槻区並木');
ok($zip->set_number('3390069')->is_valid_number, '埼玉県さいたま市岩槻区箕輪');
ok($zip->set_number('3390071')->is_valid_number, '埼玉県さいたま市岩槻区相野原');
ok($zip->set_number('3390072')->is_valid_number, '埼玉県さいたま市岩槻区古ヶ場');
ok($zip->set_number('3390073')->is_valid_number, '埼玉県さいたま市岩槻区上野');
ok($zip->set_number('3390074')->is_valid_number, '埼玉県さいたま市岩槻区本宿');
ok($zip->set_number('3390075')->is_valid_number, '埼玉県さいたま市岩槻区金重');
ok($zip->set_number('3390076')->is_valid_number, '埼玉県さいたま市岩槻区平林寺');
ok($zip->set_number('3390077')->is_valid_number, '埼玉県さいたま市岩槻区馬込');
ok($zip->set_number('3390078')->is_valid_number, '埼玉県さいたま市岩槻区掛');
ok($zip->set_number('3390081')->is_valid_number, '埼玉県さいたま市岩槻区西原');
ok($zip->set_number('3390082')->is_valid_number, '埼玉県さいたま市岩槻区西原台');
ok($zip->set_number('3400000')->is_valid_number, '埼玉県草加市以下に掲載がない場合');
ok($zip->set_number('3400001')->is_valid_number, '埼玉県草加市柿木町');
ok($zip->set_number('3400002')->is_valid_number, '埼玉県草加市青柳');
ok($zip->set_number('3400003')->is_valid_number, '埼玉県草加市稲荷');
ok($zip->set_number('3400004')->is_valid_number, '埼玉県草加市弁天');
ok($zip->set_number('3400005')->is_valid_number, '埼玉県草加市中根');
ok($zip->set_number('3400006')->is_valid_number, '埼玉県草加市八幡町');
ok($zip->set_number('3400007')->is_valid_number, '埼玉県草加市青柳町');
ok($zip->set_number('3400011')->is_valid_number, '埼玉県草加市栄町');
ok($zip->set_number('3400012')->is_valid_number, '埼玉県草加市神明');
ok($zip->set_number('3400013')->is_valid_number, '埼玉県草加市松江');
ok($zip->set_number('3400014')->is_valid_number, '埼玉県草加市住吉');
ok($zip->set_number('3400015')->is_valid_number, '埼玉県草加市高砂');
ok($zip->set_number('3400016')->is_valid_number, '埼玉県草加市中央');
ok($zip->set_number('3400017')->is_valid_number, '埼玉県草加市吉町');
ok($zip->set_number('3400021')->is_valid_number, '埼玉県草加市手代');
ok($zip->set_number('3400022')->is_valid_number, '埼玉県草加市瀬崎');
ok($zip->set_number('3400023')->is_valid_number, '埼玉県草加市谷塚町');
ok($zip->set_number('3400024')->is_valid_number, '埼玉県草加市谷塚上町');
ok($zip->set_number('3400025')->is_valid_number, '埼玉県草加市谷塚仲町');
ok($zip->set_number('3400026')->is_valid_number, '埼玉県草加市両新田東町');
ok($zip->set_number('3400027')->is_valid_number, '埼玉県草加市両新田西町');
ok($zip->set_number('3400028')->is_valid_number, '埼玉県草加市谷塚');
ok($zip->set_number('3400031')->is_valid_number, '埼玉県草加市新里町');
ok($zip->set_number('3400032')->is_valid_number, '埼玉県草加市遊馬町');
ok($zip->set_number('3400033')->is_valid_number, '埼玉県草加市柳島町');
ok($zip->set_number('3400034')->is_valid_number, '埼玉県草加市氷川町');
ok($zip->set_number('3400035')->is_valid_number, '埼玉県草加市西町');
ok($zip->set_number('3400036')->is_valid_number, '埼玉県草加市苗塚町');
ok($zip->set_number('3400041')->is_valid_number, '埼玉県草加市松原');
ok($zip->set_number('3400042')->is_valid_number, '埼玉県草加市学園町');
ok($zip->set_number('3400043')->is_valid_number, '埼玉県草加市草加');
ok($zip->set_number('3400044')->is_valid_number, '埼玉県草加市花栗');
ok($zip->set_number('3400045')->is_valid_number, '埼玉県草加市小山');
ok($zip->set_number('3400046')->is_valid_number, '埼玉県草加市北谷');
ok($zip->set_number('3400047')->is_valid_number, '埼玉県草加市北谷町');
ok($zip->set_number('3400048')->is_valid_number, '埼玉県草加市原町');
ok($zip->set_number('3400051')->is_valid_number, '埼玉県草加市長栄');
ok($zip->set_number('3400052')->is_valid_number, '埼玉県草加市金明町');
ok($zip->set_number('3400053')->is_valid_number, '埼玉県草加市旭町');
ok($zip->set_number('3400054')->is_valid_number, '埼玉県草加市新善町');
ok($zip->set_number('3400055')->is_valid_number, '埼玉県草加市清門');
ok($zip->set_number('3400056')->is_valid_number, '埼玉県草加市新栄');
ok($zip->set_number('3400100')->is_valid_number, '埼玉県幸手市以下に掲載がない場合');
ok($zip->set_number('3400101')->is_valid_number, '埼玉県幸手市外国府間');
ok($zip->set_number('3400102')->is_valid_number, '埼玉県幸手市高須賀');
ok($zip->set_number('3400103')->is_valid_number, '埼玉県幸手市内国府間');
ok($zip->set_number('3400104')->is_valid_number, '埼玉県幸手市円藤内');
ok($zip->set_number('3400105')->is_valid_number, '埼玉県幸手市松石');
ok($zip->set_number('3400111')->is_valid_number, '埼玉県幸手市北');
ok($zip->set_number('3400112')->is_valid_number, '埼玉県幸手市権現堂');
ok($zip->set_number('3400113')->is_valid_number, '埼玉県幸手市幸手');
ok($zip->set_number('3400114')->is_valid_number, '埼玉県幸手市東');
ok($zip->set_number('3400115')->is_valid_number, '埼玉県幸手市中');
ok($zip->set_number('3400116')->is_valid_number, '埼玉県幸手市西');
ok($zip->set_number('3400121')->is_valid_number, '埼玉県幸手市上吉羽');
ok($zip->set_number('3400122')->is_valid_number, '埼玉県幸手市神明内');
ok($zip->set_number('3400123')->is_valid_number, '埼玉県幸手市木立');
ok($zip->set_number('3400124')->is_valid_number, '埼玉県幸手市上宇和田');
ok($zip->set_number('3400125')->is_valid_number, '埼玉県幸手市下宇和田');
ok($zip->set_number('3400126')->is_valid_number, '埼玉県幸手市下吉羽');
ok($zip->set_number('3400131')->is_valid_number, '埼玉県幸手市西関宿');
ok($zip->set_number('3400132')->is_valid_number, '埼玉県幸手市中島');
ok($zip->set_number('3400133')->is_valid_number, '埼玉県幸手市惣新田');
ok($zip->set_number('3400134')->is_valid_number, '埼玉県幸手市花島');
ok($zip->set_number('3400135')->is_valid_number, '埼玉県幸手市槇野地');
ok($zip->set_number('3400136')->is_valid_number, '埼玉県幸手市細野');
ok($zip->set_number('3400141')->is_valid_number, '埼玉県幸手市平野');
ok($zip->set_number('3400142')->is_valid_number, '埼玉県幸手市中野');
ok($zip->set_number('3400143')->is_valid_number, '埼玉県幸手市長間');
ok($zip->set_number('3400144')->is_valid_number, '埼玉県幸手市戸島');
ok($zip->set_number('3400145')->is_valid_number, '埼玉県幸手市平須賀');
ok($zip->set_number('3400146')->is_valid_number, '埼玉県幸手市神扇');
ok($zip->set_number('3400151')->is_valid_number, '埼玉県幸手市緑台');
ok($zip->set_number('3400152')->is_valid_number, '埼玉県幸手市天神島');
ok($zip->set_number('3400153')->is_valid_number, '埼玉県幸手市吉野');
ok($zip->set_number('3400154')->is_valid_number, '埼玉県幸手市栄');
ok($zip->set_number('3400155')->is_valid_number, '埼玉県幸手市上高野');
ok($zip->set_number('3400156')->is_valid_number, '埼玉県幸手市南');
ok($zip->set_number('3400161')->is_valid_number, '埼玉県幸手市千塚');
ok($zip->set_number('3400162')->is_valid_number, '埼玉県幸手市下川崎');
ok($zip->set_number('3400163')->is_valid_number, '埼玉県幸手市中川崎');
ok($zip->set_number('3400164')->is_valid_number, '埼玉県幸手市香日向');
ok($zip->set_number('3400201')->is_valid_number, '埼玉県久喜市八甫');
ok($zip->set_number('3400202')->is_valid_number, '埼玉県久喜市東大輪');
ok($zip->set_number('3400203')->is_valid_number, '埼玉県久喜市桜田');
ok($zip->set_number('3400204')->is_valid_number, '埼玉県久喜市上川崎');
ok($zip->set_number('3400205')->is_valid_number, '埼玉県久喜市外野');
ok($zip->set_number('3400206')->is_valid_number, '埼玉県久喜市西大輪');
ok($zip->set_number('3400211')->is_valid_number, '埼玉県久喜市上内');
ok($zip->set_number('3400212')->is_valid_number, '埼玉県久喜市久本寺');
ok($zip->set_number('3400213')->is_valid_number, '埼玉県久喜市中妻');
ok($zip->set_number('3400214')->is_valid_number, '埼玉県久喜市葛梅');
ok($zip->set_number('3400215')->is_valid_number, '埼玉県久喜市栄');
ok($zip->set_number('3400216')->is_valid_number, '埼玉県久喜市鷲宮中央');
ok($zip->set_number('3400217')->is_valid_number, '埼玉県久喜市鷲宮');
ok($zip->set_number('3400218')->is_valid_number, '埼玉県久喜市砂原');
ok($zip->set_number('3400800')->is_valid_number, '埼玉県八潮市以下に掲載がない場合');
ok($zip->set_number('3400801')->is_valid_number, '埼玉県八潮市八條');
ok($zip->set_number('3400802')->is_valid_number, '埼玉県八潮市鶴ケ曽根');
ok($zip->set_number('3400803')->is_valid_number, '埼玉県八潮市上馬場');
ok($zip->set_number('3400804')->is_valid_number, '埼玉県八潮市小作田');
ok($zip->set_number('3400805')->is_valid_number, '埼玉県八潮市松之木');
ok($zip->set_number('3400806')->is_valid_number, '埼玉県八潮市伊草');
ok($zip->set_number('3400807')->is_valid_number, '埼玉県八潮市新町');
ok($zip->set_number('3400808')->is_valid_number, '埼玉県八潮市緑町');
ok($zip->set_number('3400811')->is_valid_number, '埼玉県八潮市二丁目');
ok($zip->set_number('3400812')->is_valid_number, '埼玉県八潮市中馬場');
ok($zip->set_number('3400813')->is_valid_number, '埼玉県八潮市木曽根');
ok($zip->set_number('3400814')->is_valid_number, '埼玉県八潮市南川崎');
ok($zip->set_number('3400815')->is_valid_number, '埼玉県八潮市八潮');
ok($zip->set_number('3400816')->is_valid_number, '埼玉県八潮市中央');
ok($zip->set_number('3400821')->is_valid_number, '埼玉県八潮市伊勢野');
ok($zip->set_number('3400822')->is_valid_number, '埼玉県八潮市大瀬');
ok($zip->set_number('3400823')->is_valid_number, '埼玉県八潮市古新田');
ok($zip->set_number('3400824')->is_valid_number, '埼玉県八潮市垳');
ok($zip->set_number('3400825')->is_valid_number, '埼玉県八潮市大原');
ok($zip->set_number('3400826')->is_valid_number, '埼玉県八潮市茜町');
ok($zip->set_number('3400831')->is_valid_number, '埼玉県八潮市南後谷');
ok($zip->set_number('3400832')->is_valid_number, '埼玉県八潮市柳之宮');
ok($zip->set_number('3400833')->is_valid_number, '埼玉県八潮市西袋');
ok($zip->set_number('3400834')->is_valid_number, '埼玉県八潮市大曽根');
ok($zip->set_number('3400835')->is_valid_number, '埼玉県八潮市浮塚');
ok($zip->set_number('3410000')->is_valid_number, '埼玉県三郷市以下に掲載がない場合');
ok($zip->set_number('3410001')->is_valid_number, '埼玉県三郷市彦糸');
ok($zip->set_number('3410002')->is_valid_number, '埼玉県三郷市彦音');
ok($zip->set_number('3410003')->is_valid_number, '埼玉県三郷市彦成');
ok($zip->set_number('3410004')->is_valid_number, '埼玉県三郷市上彦名');
ok($zip->set_number('3410005')->is_valid_number, '埼玉県三郷市彦川戸');
ok($zip->set_number('3410006')->is_valid_number, '埼玉県三郷市上彦川戸');
ok($zip->set_number('3410007')->is_valid_number, '埼玉県三郷市下彦川戸');
ok($zip->set_number('3410008')->is_valid_number, '埼玉県三郷市駒形');
ok($zip->set_number('3410009')->is_valid_number, '埼玉県三郷市新三郷ららシティ');
ok($zip->set_number('3410011')->is_valid_number, '埼玉県三郷市采女');
ok($zip->set_number('3410012')->is_valid_number, '埼玉県三郷市半田');
ok($zip->set_number('3410013')->is_valid_number, '埼玉県三郷市小谷堀');
ok($zip->set_number('3410014')->is_valid_number, '埼玉県三郷市後谷');
ok($zip->set_number('3410015')->is_valid_number, '埼玉県三郷市前間');
ok($zip->set_number('3410016')->is_valid_number, '埼玉県三郷市田中新田');
ok($zip->set_number('3410017')->is_valid_number, '埼玉県三郷市丹後');
ok($zip->set_number('3410018')->is_valid_number, '埼玉県三郷市早稲田');
ok($zip->set_number('3410021')->is_valid_number, '埼玉県三郷市さつき平');
ok($zip->set_number('3410022')->is_valid_number, '埼玉県三郷市大広戸');
ok($zip->set_number('3410023')->is_valid_number, '埼玉県三郷市仁蔵');
ok($zip->set_number('3410024')->is_valid_number, '埼玉県三郷市三郷');
ok($zip->set_number('3410025')->is_valid_number, '埼玉県三郷市茂田井');
ok($zip->set_number('3410026')->is_valid_number, '埼玉県三郷市幸房');
ok($zip->set_number('3410027')->is_valid_number, '埼玉県三郷市笹塚');
ok($zip->set_number('3410028')->is_valid_number, '埼玉県三郷市南蓮沼');
ok($zip->set_number('3410031')->is_valid_number, '埼玉県三郷市岩野木');
ok($zip->set_number('3410032')->is_valid_number, '埼玉県三郷市谷中');
ok($zip->set_number('3410033')->is_valid_number, '埼玉県三郷市市助');
ok($zip->set_number('3410034')->is_valid_number, '埼玉県三郷市新和');
ok($zip->set_number('3410035')->is_valid_number, '埼玉県三郷市鷹野');
ok($zip->set_number('3410036')->is_valid_number, '埼玉県三郷市東町');
ok($zip->set_number('3410037')->is_valid_number, '埼玉県三郷市高州');
ok($zip->set_number('3410038')->is_valid_number, '埼玉県三郷市中央');
ok($zip->set_number('3410041')->is_valid_number, '埼玉県三郷市花和田');
ok($zip->set_number('3410042')->is_valid_number, '埼玉県三郷市谷口');
ok($zip->set_number('3410043')->is_valid_number, '埼玉県三郷市栄');
ok($zip->set_number('3410044')->is_valid_number, '埼玉県三郷市戸ケ崎');
ok($zip->set_number('3410045')->is_valid_number, '埼玉県三郷市寄巻');
ok($zip->set_number('3410046')->is_valid_number, '埼玉県三郷市鎌倉');
ok($zip->set_number('3410050')->is_valid_number, '埼玉県三郷市ピアラシティ');
ok($zip->set_number('3410051')->is_valid_number, '埼玉県三郷市天神');
ok($zip->set_number('3410052')->is_valid_number, '埼玉県三郷市彦野');
ok($zip->set_number('3410053')->is_valid_number, '埼玉県三郷市彦倉');
ok($zip->set_number('3410054')->is_valid_number, '埼玉県三郷市泉');
ok($zip->set_number('3410055')->is_valid_number, '埼玉県三郷市上口');
ok($zip->set_number('3410056')->is_valid_number, '埼玉県三郷市番匠免');
ok($zip->set_number('3410057')->is_valid_number, '埼玉県三郷市彦沢');
ok($zip->set_number('3410058')->is_valid_number, '埼玉県三郷市彦江');
ok($zip->set_number('3410059')->is_valid_number, '埼玉県三郷市インター南');
ok($zip->set_number('3420000')->is_valid_number, '埼玉県吉川市以下に掲載がない場合');
ok($zip->set_number('3420001')->is_valid_number, '埼玉県吉川市上内川');
ok($zip->set_number('3420002')->is_valid_number, '埼玉県吉川市下内川');
ok($zip->set_number('3420003')->is_valid_number, '埼玉県吉川市八子新田');
ok($zip->set_number('3420004')->is_valid_number, '埼玉県吉川市鍋小路');
ok($zip->set_number('3420005')->is_valid_number, '埼玉県吉川市川藤');
ok($zip->set_number('3420006')->is_valid_number, '埼玉県吉川市南広島');
ok($zip->set_number('3420007')->is_valid_number, '埼玉県吉川市拾壱軒');
ok($zip->set_number('3420008')->is_valid_number, '埼玉県吉川市旭');
ok($zip->set_number('3420011')->is_valid_number, '埼玉県吉川市深井新田');
ok($zip->set_number('3420012')->is_valid_number, '埼玉県吉川市平方新田');
ok($zip->set_number('3420013')->is_valid_number, '埼玉県吉川市吉屋');
ok($zip->set_number('3420014')->is_valid_number, '埼玉県吉川市関新田');
ok($zip->set_number('3420015')->is_valid_number, '埼玉県吉川市中井');
ok($zip->set_number('3420016')->is_valid_number, '埼玉県吉川市会野谷');
ok($zip->set_number('3420017')->is_valid_number, '埼玉県吉川市上笹塚');
ok($zip->set_number('3420021')->is_valid_number, '埼玉県吉川市鹿見塚');
ok($zip->set_number('3420022')->is_valid_number, '埼玉県吉川市加藤');
ok($zip->set_number('3420023')->is_valid_number, '埼玉県吉川市皿沼');
ok($zip->set_number('3420024')->is_valid_number, '埼玉県吉川市半割');
ok($zip->set_number('3420025')->is_valid_number, '埼玉県吉川市飯島');
ok($zip->set_number('3420026')->is_valid_number, '埼玉県吉川市土場');
ok($zip->set_number('3420027')->is_valid_number, '埼玉県吉川市三輪野江');
ok($zip->set_number('3420031')->is_valid_number, '埼玉県吉川市中島');
ok($zip->set_number('3420032')->is_valid_number, '埼玉県吉川市二ツ沼');
ok($zip->set_number('3420033')->is_valid_number, '埼玉県吉川市中曽根');
ok($zip->set_number('3420034')->is_valid_number, '埼玉県吉川市道庭');
ok($zip->set_number('3420035')->is_valid_number, '埼玉県吉川市高久');
ok($zip->set_number('3420036')->is_valid_number, '埼玉県吉川市高富');
ok($zip->set_number('3420037')->is_valid_number, '埼玉県吉川市富新田');
ok($zip->set_number('3420038')->is_valid_number, '埼玉県吉川市美南');
ok($zip->set_number('3420041')->is_valid_number, '埼玉県吉川市保');
ok($zip->set_number('3420042')->is_valid_number, '埼玉県吉川市中野');
ok($zip->set_number('3420043')->is_valid_number, '埼玉県吉川市小松川');
ok($zip->set_number('3420044')->is_valid_number, '埼玉県吉川市木売新田');
ok($zip->set_number('3420045')->is_valid_number, '埼玉県吉川市木売');
ok($zip->set_number('3420046')->is_valid_number, '埼玉県吉川市共保');
ok($zip->set_number('3420047')->is_valid_number, '埼玉県吉川市中川台');
ok($zip->set_number('3420050')->is_valid_number, '埼玉県吉川市栄町');
ok($zip->set_number('3420051')->is_valid_number, '埼玉県吉川市川野');
ok($zip->set_number('3420052')->is_valid_number, '埼玉県吉川市川富');
ok($zip->set_number('3420053')->is_valid_number, '埼玉県吉川市関');
ok($zip->set_number('3420054')->is_valid_number, '埼玉県吉川市吉川団地');
ok($zip->set_number('3420055')->is_valid_number, '埼玉県吉川市吉川');
ok($zip->set_number('3420056')->is_valid_number, '埼玉県吉川市平沼');
ok($zip->set_number('3420057')->is_valid_number, '埼玉県吉川市須賀');
ok($zip->set_number('3420058')->is_valid_number, '埼玉県吉川市きよみ野');
ok($zip->set_number('3420059')->is_valid_number, '埼玉県吉川市新栄');
ok($zip->set_number('3420061')->is_valid_number, '埼玉県吉川市中央');
ok($zip->set_number('3430000')->is_valid_number, '埼玉県越谷市以下に掲載がない場合');
ok($zip->set_number('3430001')->is_valid_number, '埼玉県越谷市平方南町');
ok($zip->set_number('3430002')->is_valid_number, '埼玉県越谷市平方');
ok($zip->set_number('3430003')->is_valid_number, '埼玉県越谷市船渡');
ok($zip->set_number('3430004')->is_valid_number, '埼玉県越谷市大松');
ok($zip->set_number('3430005')->is_valid_number, '埼玉県越谷市大杉');
ok($zip->set_number('3430006')->is_valid_number, '埼玉県越谷市北川崎');
ok($zip->set_number('3430007')->is_valid_number, '埼玉県越谷市向畑');
ok($zip->set_number('3430008')->is_valid_number, '埼玉県越谷市大吉');
ok($zip->set_number('3430011')->is_valid_number, '埼玉県越谷市増林');
ok($zip->set_number('3430012')->is_valid_number, '埼玉県越谷市増森');
ok($zip->set_number('3430013')->is_valid_number, '埼玉県越谷市中島');
ok($zip->set_number('3430014')->is_valid_number, '埼玉県越谷市宮前');
ok($zip->set_number('3430015')->is_valid_number, '埼玉県越谷市花田');
ok($zip->set_number('3430021')->is_valid_number, '埼玉県越谷市大林');
ok($zip->set_number('3430022')->is_valid_number, '埼玉県越谷市東大沢');
ok($zip->set_number('3430023')->is_valid_number, '埼玉県越谷市東越谷');
ok($zip->set_number('3430024')->is_valid_number, '埼玉県越谷市越ケ谷(番地)');
ok($zip->set_number('3430025')->is_valid_number, '埼玉県越谷市大沢');
ok($zip->set_number('3430026')->is_valid_number, '埼玉県越谷市北越谷');
ok($zip->set_number('3430027')->is_valid_number, '埼玉県越谷市大房');
ok($zip->set_number('3430031')->is_valid_number, '埼玉県越谷市大里');
ok($zip->set_number('3430032')->is_valid_number, '埼玉県越谷市袋山');
ok($zip->set_number('3430033')->is_valid_number, '埼玉県越谷市恩間');
ok($zip->set_number('3430034')->is_valid_number, '埼玉県越谷市大竹');
ok($zip->set_number('3430035')->is_valid_number, '埼玉県越谷市大道');
ok($zip->set_number('3430036')->is_valid_number, '埼玉県越谷市三野宮');
ok($zip->set_number('3430037')->is_valid_number, '埼玉県越谷市恩間新田');
ok($zip->set_number('3430041')->is_valid_number, '埼玉県越谷市千間台西');
ok($zip->set_number('3430042')->is_valid_number, '埼玉県越谷市千間台東');
ok($zip->set_number('3430043')->is_valid_number, '埼玉県越谷市上間久里');
ok($zip->set_number('3430044')->is_valid_number, '埼玉県越谷市大泊');
ok($zip->set_number('3430045')->is_valid_number, '埼玉県越谷市下間久里');
ok($zip->set_number('3430046')->is_valid_number, '埼玉県越谷市弥栄町');
ok($zip->set_number('3430047')->is_valid_number, '埼玉県越谷市弥十郎');
ok($zip->set_number('3430100')->is_valid_number, '埼玉県北葛飾郡松伏町以下に掲載がない場合');
ok($zip->set_number('3430101')->is_valid_number, '埼玉県北葛飾郡松伏町魚沼');
ok($zip->set_number('3430102')->is_valid_number, '埼玉県北葛飾郡松伏町築比地');
ok($zip->set_number('3430103')->is_valid_number, '埼玉県北葛飾郡松伏町金杉');
ok($zip->set_number('3430104')->is_valid_number, '埼玉県北葛飾郡松伏町田島東');
ok($zip->set_number('3430105')->is_valid_number, '埼玉県北葛飾郡松伏町田島');
ok($zip->set_number('3430106')->is_valid_number, '埼玉県北葛飾郡松伏町大川戸');
ok($zip->set_number('3430107')->is_valid_number, '埼玉県北葛飾郡松伏町田島南');
ok($zip->set_number('3430111')->is_valid_number, '埼玉県北葛飾郡松伏町松伏');
ok($zip->set_number('3430112')->is_valid_number, '埼玉県北葛飾郡松伏町松葉');
ok($zip->set_number('3430113')->is_valid_number, '埼玉県北葛飾郡松伏町ゆめみ野');
ok($zip->set_number('3430114')->is_valid_number, '埼玉県北葛飾郡松伏町ゆめみ野東');
ok($zip->set_number('3430115')->is_valid_number, '埼玉県北葛飾郡松伏町上赤岩');
ok($zip->set_number('3430116')->is_valid_number, '埼玉県北葛飾郡松伏町下赤岩');
ok($zip->set_number('3430117')->is_valid_number, '埼玉県北葛飾郡松伏町田中');
ok($zip->set_number('3430801')->is_valid_number, '埼玉県越谷市野島');
ok($zip->set_number('3430802')->is_valid_number, '埼玉県越谷市小曽川');
ok($zip->set_number('3430803')->is_valid_number, '埼玉県越谷市砂原');
ok($zip->set_number('3430804')->is_valid_number, '埼玉県越谷市南荻島');
ok($zip->set_number('3430805')->is_valid_number, '埼玉県越谷市神明町');
ok($zip->set_number('3430806')->is_valid_number, '埼玉県越谷市宮本町');
ok($zip->set_number('3430807')->is_valid_number, '埼玉県越谷市赤山町');
ok($zip->set_number('3430808')->is_valid_number, '埼玉県越谷市赤山本町');
ok($zip->set_number('3430811')->is_valid_number, '埼玉県越谷市御殿町');
ok($zip->set_number('3430812')->is_valid_number, '埼玉県越谷市柳町');
ok($zip->set_number('3430813')->is_valid_number, '埼玉県越谷市越ケ谷(丁目)');
ok($zip->set_number('3430814')->is_valid_number, '埼玉県越谷市東柳田町');
ok($zip->set_number('3430815')->is_valid_number, '埼玉県越谷市元柳田町');
ok($zip->set_number('3430816')->is_valid_number, '埼玉県越谷市弥生町');
ok($zip->set_number('3430817')->is_valid_number, '埼玉県越谷市中町');
ok($zip->set_number('3430818')->is_valid_number, '埼玉県越谷市越ケ谷本町');
ok($zip->set_number('3430821')->is_valid_number, '埼玉県越谷市瓦曽根');
ok($zip->set_number('3430822')->is_valid_number, '埼玉県越谷市西方');
ok($zip->set_number('3430823')->is_valid_number, '埼玉県越谷市相模町');
ok($zip->set_number('3430824')->is_valid_number, '埼玉県越谷市流通団地');
ok($zip->set_number('3430825')->is_valid_number, '埼玉県越谷市大成町');
ok($zip->set_number('3430826')->is_valid_number, '埼玉県越谷市東町');
ok($zip->set_number('3430827')->is_valid_number, '埼玉県越谷市川柳町');
ok($zip->set_number('3430828')->is_valid_number, '埼玉県越谷市レイクタウン');
ok($zip->set_number('3430831')->is_valid_number, '埼玉県越谷市伊原');
ok($zip->set_number('3430832')->is_valid_number, '埼玉県越谷市南町');
ok($zip->set_number('3430833')->is_valid_number, '埼玉県越谷市蒲生南町');
ok($zip->set_number('3430834')->is_valid_number, '埼玉県越谷市蒲生愛宕町');
ok($zip->set_number('3430835')->is_valid_number, '埼玉県越谷市蒲生西町');
ok($zip->set_number('3430836')->is_valid_number, '埼玉県越谷市蒲生寿町');
ok($zip->set_number('3430837')->is_valid_number, '埼玉県越谷市蒲生本町');
ok($zip->set_number('3430838')->is_valid_number, '埼玉県越谷市蒲生');
ok($zip->set_number('3430841')->is_valid_number, '埼玉県越谷市蒲生東町');
ok($zip->set_number('3430842')->is_valid_number, '埼玉県越谷市蒲生旭町');
ok($zip->set_number('3430843')->is_valid_number, '埼玉県越谷市蒲生茜町');
ok($zip->set_number('3430844')->is_valid_number, '埼玉県越谷市大間野町');
ok($zip->set_number('3430845')->is_valid_number, '埼玉県越谷市南越谷');
ok($zip->set_number('3430846')->is_valid_number, '埼玉県越谷市登戸町');
ok($zip->set_number('3430851')->is_valid_number, '埼玉県越谷市七左町');
ok($zip->set_number('3430852')->is_valid_number, '埼玉県越谷市新川町');
ok($zip->set_number('3430853')->is_valid_number, '埼玉県越谷市長島');
ok($zip->set_number('3430854')->is_valid_number, '埼玉県越谷市北後谷');
ok($zip->set_number('3430855')->is_valid_number, '埼玉県越谷市西新井');
ok($zip->set_number('3430856')->is_valid_number, '埼玉県越谷市谷中町');
ok($zip->set_number('3430857')->is_valid_number, '埼玉県越谷市新越谷');
ok($zip->set_number('3440000')->is_valid_number, '埼玉県春日部市以下に掲載がない場合');
ok($zip->set_number('3440001')->is_valid_number, '埼玉県春日部市不動院野');
ok($zip->set_number('3440002')->is_valid_number, '埼玉県春日部市樋籠');
ok($zip->set_number('3440003')->is_valid_number, '埼玉県春日部市新川');
ok($zip->set_number('3440004')->is_valid_number, '埼玉県春日部市牛島');
ok($zip->set_number('3440005')->is_valid_number, '埼玉県春日部市樋堀');
ok($zip->set_number('3440006')->is_valid_number, '埼玉県春日部市八丁目');
ok($zip->set_number('3440007')->is_valid_number, '埼玉県春日部市小渕');
ok($zip->set_number('3440011')->is_valid_number, '埼玉県春日部市藤塚');
ok($zip->set_number('3440012')->is_valid_number, '埼玉県春日部市六軒町');
ok($zip->set_number('3440013')->is_valid_number, '埼玉県春日部市銚子口');
ok($zip->set_number('3440014')->is_valid_number, '埼玉県春日部市豊野町');
ok($zip->set_number('3440015')->is_valid_number, '埼玉県春日部市赤沼');
ok($zip->set_number('3440016')->is_valid_number, '埼玉県春日部市本田町');
ok($zip->set_number('3440021')->is_valid_number, '埼玉県春日部市大場');
ok($zip->set_number('3440022')->is_valid_number, '埼玉県春日部市大畑');
ok($zip->set_number('3440023')->is_valid_number, '埼玉県春日部市大枝');
ok($zip->set_number('3440024')->is_valid_number, '埼玉県春日部市千間');
ok($zip->set_number('3440025')->is_valid_number, '埼玉県春日部市増田新田');
ok($zip->set_number('3440026')->is_valid_number, '埼玉県春日部市武里中野');
ok($zip->set_number('3440031')->is_valid_number, '埼玉県春日部市一ノ割');
ok($zip->set_number('3440032')->is_valid_number, '埼玉県春日部市備後東');
ok($zip->set_number('3440033')->is_valid_number, '埼玉県春日部市備後西');
ok($zip->set_number('3440034')->is_valid_number, '埼玉県春日部市薄谷');
ok($zip->set_number('3440035')->is_valid_number, '埼玉県春日部市谷原新田');
ok($zip->set_number('3440036')->is_valid_number, '埼玉県春日部市下大増新田');
ok($zip->set_number('3440037')->is_valid_number, '埼玉県春日部市上大増新田');
ok($zip->set_number('3440038')->is_valid_number, '埼玉県春日部市大沼');
ok($zip->set_number('3440041')->is_valid_number, '埼玉県春日部市増富');
ok($zip->set_number('3440042')->is_valid_number, '埼玉県春日部市増戸');
ok($zip->set_number('3440043')->is_valid_number, '埼玉県春日部市下蛭田');
ok($zip->set_number('3440044')->is_valid_number, '埼玉県春日部市花積');
ok($zip->set_number('3440045')->is_valid_number, '埼玉県春日部市道口蛭田');
ok($zip->set_number('3440046')->is_valid_number, '埼玉県春日部市上蛭田');
ok($zip->set_number('3440047')->is_valid_number, '埼玉県春日部市道順川戸');
ok($zip->set_number('3440048')->is_valid_number, '埼玉県春日部市南中曽根');
ok($zip->set_number('3440051')->is_valid_number, '埼玉県春日部市内牧');
ok($zip->set_number('3440052')->is_valid_number, '埼玉県春日部市梅田');
ok($zip->set_number('3440053')->is_valid_number, '埼玉県春日部市梅田本町');
ok($zip->set_number('3440054')->is_valid_number, '埼玉県春日部市浜川戸');
ok($zip->set_number('3440055')->is_valid_number, '埼玉県春日部市八木崎町');
ok($zip->set_number('3440056')->is_valid_number, '埼玉県春日部市新方袋');
ok($zip->set_number('3440057')->is_valid_number, '埼玉県春日部市南栄町');
ok($zip->set_number('3440058')->is_valid_number, '埼玉県春日部市栄町');
ok($zip->set_number('3440059')->is_valid_number, '埼玉県春日部市西八木崎');
ok($zip->set_number('3440061')->is_valid_number, '埼玉県春日部市粕壁');
ok($zip->set_number('3440062')->is_valid_number, '埼玉県春日部市粕壁東');
ok($zip->set_number('3440063')->is_valid_number, '埼玉県春日部市緑町');
ok($zip->set_number('3440064')->is_valid_number, '埼玉県春日部市南');
ok($zip->set_number('3440065')->is_valid_number, '埼玉県春日部市谷原');
ok($zip->set_number('3440066')->is_valid_number, '埼玉県春日部市豊町');
ok($zip->set_number('3440067')->is_valid_number, '埼玉県春日部市中央');
ok($zip->set_number('3440101')->is_valid_number, '埼玉県春日部市西親野井');
ok($zip->set_number('3440102')->is_valid_number, '埼玉県春日部市西宝珠花');
ok($zip->set_number('3440103')->is_valid_number, '埼玉県春日部市上吉妻');
ok($zip->set_number('3440104')->is_valid_number, '埼玉県春日部市下吉妻');
ok($zip->set_number('3440105')->is_valid_number, '埼玉県春日部市小平');
ok($zip->set_number('3440106')->is_valid_number, '埼玉県春日部市木崎');
ok($zip->set_number('3440107')->is_valid_number, '埼玉県春日部市塚崎');
ok($zip->set_number('3440111')->is_valid_number, '埼玉県春日部市上金崎');
ok($zip->set_number('3440112')->is_valid_number, '埼玉県春日部市西金野井');
ok($zip->set_number('3440113')->is_valid_number, '埼玉県春日部市新宿新田');
ok($zip->set_number('3440114')->is_valid_number, '埼玉県春日部市東中野');
ok($zip->set_number('3440115')->is_valid_number, '埼玉県春日部市米島');
ok($zip->set_number('3440116')->is_valid_number, '埼玉県春日部市大衾');
ok($zip->set_number('3440117')->is_valid_number, '埼玉県春日部市金崎');
ok($zip->set_number('3440121')->is_valid_number, '埼玉県春日部市上柳');
ok($zip->set_number('3440122')->is_valid_number, '埼玉県春日部市下柳');
ok($zip->set_number('3440123')->is_valid_number, '埼玉県春日部市永沼');
ok($zip->set_number('3440124')->is_valid_number, '埼玉県春日部市米崎');
ok($zip->set_number('3440125')->is_valid_number, '埼玉県春日部市飯沼');
ok($zip->set_number('3440126')->is_valid_number, '埼玉県春日部市赤崎');
ok($zip->set_number('3440127')->is_valid_number, '埼玉県春日部市水角');
ok($zip->set_number('3440131')->is_valid_number, '埼玉県春日部市芦橋');
ok($zip->set_number('3440132')->is_valid_number, '埼玉県春日部市神間');
ok($zip->set_number('3440133')->is_valid_number, '埼玉県春日部市椚');
ok($zip->set_number('3440134')->is_valid_number, '埼玉県春日部市立野');
ok($zip->set_number('3440135')->is_valid_number, '埼玉県春日部市榎');
ok($zip->set_number('3440136')->is_valid_number, '埼玉県春日部市倉常');
ok($zip->set_number('3450000')->is_valid_number, '埼玉県南埼玉郡宮代町以下に掲載がない場合');
ok($zip->set_number('3450000')->is_valid_number, '埼玉県北葛飾郡杉戸町以下に掲載がない場合');
ok($zip->set_number('3450001')->is_valid_number, '埼玉県北葛飾郡杉戸町木津内');
ok($zip->set_number('3450002')->is_valid_number, '埼玉県北葛飾郡杉戸町鷲巣');
ok($zip->set_number('3450003')->is_valid_number, '埼玉県北葛飾郡杉戸町木野川');
ok($zip->set_number('3450004')->is_valid_number, '埼玉県北葛飾郡杉戸町宮前');
ok($zip->set_number('3450005')->is_valid_number, '埼玉県北葛飾郡杉戸町目沼');
ok($zip->set_number('3450011')->is_valid_number, '埼玉県北葛飾郡杉戸町屏風');
ok($zip->set_number('3450012')->is_valid_number, '埼玉県北葛飾郡杉戸町深輪');
ok($zip->set_number('3450013')->is_valid_number, '埼玉県北葛飾郡杉戸町椿');
ok($zip->set_number('3450014')->is_valid_number, '埼玉県北葛飾郡杉戸町才羽');
ok($zip->set_number('3450015')->is_valid_number, '埼玉県北葛飾郡杉戸町並塚');
ok($zip->set_number('3450021')->is_valid_number, '埼玉県北葛飾郡杉戸町北蓮沼');
ok($zip->set_number('3450022')->is_valid_number, '埼玉県北葛飾郡杉戸町大塚');
ok($zip->set_number('3450023')->is_valid_number, '埼玉県北葛飾郡杉戸町本郷');
ok($zip->set_number('3450024')->is_valid_number, '埼玉県北葛飾郡杉戸町堤根');
ok($zip->set_number('3450025')->is_valid_number, '埼玉県北葛飾郡杉戸町清地');
ok($zip->set_number('3450031')->is_valid_number, '埼玉県北葛飾郡杉戸町遠野');
ok($zip->set_number('3450032')->is_valid_number, '埼玉県北葛飾郡杉戸町広戸沼');
ok($zip->set_number('3450033')->is_valid_number, '埼玉県北葛飾郡杉戸町佐左エ門');
ok($zip->set_number('3450034')->is_valid_number, '埼玉県北葛飾郡杉戸町倉松');
ok($zip->set_number('3450035')->is_valid_number, '埼玉県北葛飾郡杉戸町内田');
ok($zip->set_number('3450036')->is_valid_number, '埼玉県北葛飾郡杉戸町杉戸');
ok($zip->set_number('3450037')->is_valid_number, '埼玉県北葛飾郡杉戸町本島');
ok($zip->set_number('3450041')->is_valid_number, '埼玉県北葛飾郡杉戸町茨島');
ok($zip->set_number('3450042')->is_valid_number, '埼玉県北葛飾郡杉戸町大島');
ok($zip->set_number('3450043')->is_valid_number, '埼玉県北葛飾郡杉戸町下高野');
ok($zip->set_number('3450044')->is_valid_number, '埼玉県北葛飾郡杉戸町下野');
ok($zip->set_number('3450045')->is_valid_number, '埼玉県北葛飾郡杉戸町高野台西');
ok($zip->set_number('3450046')->is_valid_number, '埼玉県北葛飾郡杉戸町高野台南');
ok($zip->set_number('3450047')->is_valid_number, '埼玉県北葛飾郡杉戸町高野台東');
ok($zip->set_number('3450801')->is_valid_number, '埼玉県南埼玉郡宮代町百間');
ok($zip->set_number('3450802')->is_valid_number, '埼玉県南埼玉郡宮代町中島');
ok($zip->set_number('3450803')->is_valid_number, '埼玉県南埼玉郡宮代町宮東');
ok($zip->set_number('3450804')->is_valid_number, '埼玉県南埼玉郡宮代町川端');
ok($zip->set_number('3450811')->is_valid_number, '埼玉県南埼玉郡宮代町道佛');
ok($zip->set_number('3450812')->is_valid_number, '埼玉県南埼玉郡宮代町姫宮');
ok($zip->set_number('3450813')->is_valid_number, '埼玉県南埼玉郡宮代町東姫宮');
ok($zip->set_number('3450814')->is_valid_number, '埼玉県南埼玉郡宮代町東');
ok($zip->set_number('3450815')->is_valid_number, '埼玉県南埼玉郡宮代町中');
ok($zip->set_number('3450816')->is_valid_number, '埼玉県南埼玉郡宮代町金原');
ok($zip->set_number('3450817')->is_valid_number, '埼玉県南埼玉郡宮代町西原');
ok($zip->set_number('3450821')->is_valid_number, '埼玉県南埼玉郡宮代町中央');
ok($zip->set_number('3450822')->is_valid_number, '埼玉県南埼玉郡宮代町笠原');
ok($zip->set_number('3450823')->is_valid_number, '埼玉県南埼玉郡宮代町宮代');
ok($zip->set_number('3450824')->is_valid_number, '埼玉県南埼玉郡宮代町山崎');
ok($zip->set_number('3450825')->is_valid_number, '埼玉県南埼玉郡宮代町逆井');
ok($zip->set_number('3450826')->is_valid_number, '埼玉県南埼玉郡宮代町学園台');
ok($zip->set_number('3450827')->is_valid_number, '埼玉県南埼玉郡宮代町本田');
ok($zip->set_number('3450831')->is_valid_number, '埼玉県南埼玉郡宮代町須賀');
ok($zip->set_number('3450832')->is_valid_number, '埼玉県南埼玉郡宮代町東粂原');
ok($zip->set_number('3450833')->is_valid_number, '埼玉県南埼玉郡宮代町西粂原');
ok($zip->set_number('3450834')->is_valid_number, '埼玉県南埼玉郡宮代町国納');
ok($zip->set_number('3450835')->is_valid_number, '埼玉県南埼玉郡宮代町宮代台');
ok($zip->set_number('3450836')->is_valid_number, '埼玉県南埼玉郡宮代町和戸');
ok($zip->set_number('3450837')->is_valid_number, '埼玉県南埼玉郡宮代町和戸横町');
ok($zip->set_number('3460000')->is_valid_number, '埼玉県久喜市以下に掲載がない場合');
ok($zip->set_number('3460001')->is_valid_number, '埼玉県久喜市古久喜');
ok($zip->set_number('3460002')->is_valid_number, '埼玉県久喜市野久喜');
ok($zip->set_number('3460003')->is_valid_number, '埼玉県久喜市久喜中央');
ok($zip->set_number('3460004')->is_valid_number, '埼玉県久喜市南');
ok($zip->set_number('3460005')->is_valid_number, '埼玉県久喜市本町');
ok($zip->set_number('3460006')->is_valid_number, '埼玉県久喜市上町');
ok($zip->set_number('3460007')->is_valid_number, '埼玉県久喜市久喜北');
ok($zip->set_number('3460011')->is_valid_number, '埼玉県久喜市青毛');
ok($zip->set_number('3460012')->is_valid_number, '埼玉県久喜市栗原');
ok($zip->set_number('3460013')->is_valid_number, '埼玉県久喜市青葉');
ok($zip->set_number('3460014')->is_valid_number, '埼玉県久喜市吉羽');
ok($zip->set_number('3460015')->is_valid_number, '埼玉県久喜市西');
ok($zip->set_number('3460016')->is_valid_number, '埼玉県久喜市久喜東');
ok($zip->set_number('3460021')->is_valid_number, '埼玉県久喜市上早見');
ok($zip->set_number('3460022')->is_valid_number, '埼玉県久喜市下早見');
ok($zip->set_number('3460023')->is_valid_number, '埼玉県久喜市太田袋');
ok($zip->set_number('3460024')->is_valid_number, '埼玉県久喜市北青柳');
ok($zip->set_number('3460025')->is_valid_number, '埼玉県久喜市樋ノ口');
ok($zip->set_number('3460026')->is_valid_number, '埼玉県久喜市原');
ok($zip->set_number('3460027')->is_valid_number, '埼玉県久喜市除堀');
ok($zip->set_number('3460028')->is_valid_number, '埼玉県久喜市河原井町');
ok($zip->set_number('3460029')->is_valid_number, '埼玉県久喜市江面');
ok($zip->set_number('3460031')->is_valid_number, '埼玉県久喜市久喜本');
ok($zip->set_number('3460032')->is_valid_number, '埼玉県久喜市久喜新');
ok($zip->set_number('3460033')->is_valid_number, '埼玉県久喜市下清久');
ok($zip->set_number('3460034')->is_valid_number, '埼玉県久喜市所久喜');
ok($zip->set_number('3460035')->is_valid_number, '埼玉県久喜市清久町');
ok($zip->set_number('3460036')->is_valid_number, '埼玉県久喜市北中曽根');
ok($zip->set_number('3460037')->is_valid_number, '埼玉県久喜市六万部');
ok($zip->set_number('3460038')->is_valid_number, '埼玉県久喜市上清久');
ok($zip->set_number('3460101')->is_valid_number, '埼玉県久喜市菖蒲町昭和沼');
ok($zip->set_number('3460102')->is_valid_number, '埼玉県久喜市菖蒲町河原井');
ok($zip->set_number('3460103')->is_valid_number, '埼玉県久喜市菖蒲町台');
ok($zip->set_number('3460104')->is_valid_number, '埼玉県久喜市菖蒲町三箇');
ok($zip->set_number('3460105')->is_valid_number, '埼玉県久喜市菖蒲町新堀');
ok($zip->set_number('3460106')->is_valid_number, '埼玉県久喜市菖蒲町菖蒲');
ok($zip->set_number('3460111')->is_valid_number, '埼玉県久喜市菖蒲町上大崎');
ok($zip->set_number('3460112')->is_valid_number, '埼玉県久喜市菖蒲町柴山枝郷');
ok($zip->set_number('3460113')->is_valid_number, '埼玉県久喜市菖蒲町下栢間');
ok($zip->set_number('3460114')->is_valid_number, '埼玉県久喜市菖蒲町上栢間');
ok($zip->set_number('3460115')->is_valid_number, '埼玉県久喜市菖蒲町小林');
ok($zip->set_number('3470000')->is_valid_number, '埼玉県加須市以下に掲載がない場合');
ok($zip->set_number('3470001')->is_valid_number, '埼玉県加須市大越');
ok($zip->set_number('3470002')->is_valid_number, '埼玉県加須市外野');
ok($zip->set_number('3470003')->is_valid_number, '埼玉県加須市上樋遣川');
ok($zip->set_number('3470004')->is_valid_number, '埼玉県加須市古川');
ok($zip->set_number('3470005')->is_valid_number, '埼玉県加須市下樋遣川');
ok($zip->set_number('3470006')->is_valid_number, '埼玉県加須市上三俣');
ok($zip->set_number('3470007')->is_valid_number, '埼玉県加須市下三俣');
ok($zip->set_number('3470008')->is_valid_number, '埼玉県加須市中樋遣川');
ok($zip->set_number('3470009')->is_valid_number, '埼玉県加須市三俣');
ok($zip->set_number('3470010')->is_valid_number, '埼玉県加須市大桑');
ok($zip->set_number('3470011')->is_valid_number, '埼玉県加須市北小浜');
ok($zip->set_number('3470012')->is_valid_number, '埼玉県加須市多門寺');
ok($zip->set_number('3470013')->is_valid_number, '埼玉県加須市北篠崎');
ok($zip->set_number('3470014')->is_valid_number, '埼玉県加須市川口');
ok($zip->set_number('3470015')->is_valid_number, '埼玉県加須市南大桑');
ok($zip->set_number('3470016')->is_valid_number, '埼玉県加須市花崎北');
ok($zip->set_number('3470017')->is_valid_number, '埼玉県加須市南篠崎');
ok($zip->set_number('3470018')->is_valid_number, '埼玉県加須市浜町');
ok($zip->set_number('3470019')->is_valid_number, '埼玉県加須市鳩山町');
ok($zip->set_number('3470021')->is_valid_number, '埼玉県加須市船越');
ok($zip->set_number('3470022')->is_valid_number, '埼玉県加須市水深');
ok($zip->set_number('3470023')->is_valid_number, '埼玉県加須市北辻');
ok($zip->set_number('3470024')->is_valid_number, '埼玉県加須市今鉾');
ok($zip->set_number('3470025')->is_valid_number, '埼玉県加須市割目');
ok($zip->set_number('3470026')->is_valid_number, '埼玉県加須市油井ケ島');
ok($zip->set_number('3470027')->is_valid_number, '埼玉県加須市大室');
ok($zip->set_number('3470028')->is_valid_number, '埼玉県加須市南小浜');
ok($zip->set_number('3470031')->is_valid_number, '埼玉県加須市南町');
ok($zip->set_number('3470032')->is_valid_number, '埼玉県加須市花崎');
ok($zip->set_number('3470033')->is_valid_number, '埼玉県加須市下高柳');
ok($zip->set_number('3470034')->is_valid_number, '埼玉県加須市常泉');
ok($zip->set_number('3470041')->is_valid_number, '埼玉県加須市串作');
ok($zip->set_number('3470042')->is_valid_number, '埼玉県加須市志多見');
ok($zip->set_number('3470043')->is_valid_number, '埼玉県加須市馬内');
ok($zip->set_number('3470044')->is_valid_number, '埼玉県加須市礼羽');
ok($zip->set_number('3470045')->is_valid_number, '埼玉県加須市富士見町');
ok($zip->set_number('3470046')->is_valid_number, '埼玉県加須市平永');
ok($zip->set_number('3470047')->is_valid_number, '埼玉県加須市阿良川');
ok($zip->set_number('3470051')->is_valid_number, '埼玉県加須市戸川');
ok($zip->set_number('3470052')->is_valid_number, '埼玉県加須市町屋新田');
ok($zip->set_number('3470053')->is_valid_number, '埼玉県加須市下谷');
ok($zip->set_number('3470054')->is_valid_number, '埼玉県加須市不動岡');
ok($zip->set_number('3470055')->is_valid_number, '埼玉県加須市中央');
ok($zip->set_number('3470056')->is_valid_number, '埼玉県加須市土手');
ok($zip->set_number('3470057')->is_valid_number, '埼玉県加須市愛宕');
ok($zip->set_number('3470058')->is_valid_number, '埼玉県加須市岡古井');
ok($zip->set_number('3470061')->is_valid_number, '埼玉県加須市諏訪');
ok($zip->set_number('3470062')->is_valid_number, '埼玉県加須市睦町');
ok($zip->set_number('3470063')->is_valid_number, '埼玉県加須市久下');
ok($zip->set_number('3470064')->is_valid_number, '埼玉県加須市東栄');
ok($zip->set_number('3470065')->is_valid_number, '埼玉県加須市元町');
ok($zip->set_number('3470066')->is_valid_number, '埼玉県加須市本町');
ok($zip->set_number('3470067')->is_valid_number, '埼玉県加須市向川岸町');
ok($zip->set_number('3470068')->is_valid_number, '埼玉県加須市大門町');
ok($zip->set_number('3470101')->is_valid_number, '埼玉県加須市上高柳');
ok($zip->set_number('3470102')->is_valid_number, '埼玉県加須市日出安');
ok($zip->set_number('3470103')->is_valid_number, '埼玉県加須市牛重');
ok($zip->set_number('3470104')->is_valid_number, '埼玉県加須市根古屋');
ok($zip->set_number('3470105')->is_valid_number, '埼玉県加須市騎西');
ok($zip->set_number('3470106')->is_valid_number, '埼玉県加須市外川');
ok($zip->set_number('3470107')->is_valid_number, '埼玉県加須市正能');
ok($zip->set_number('3470108')->is_valid_number, '埼玉県加須市戸崎');
ok($zip->set_number('3470111')->is_valid_number, '埼玉県加須市鴻茎');
ok($zip->set_number('3470112')->is_valid_number, '埼玉県加須市芋茎');
ok($zip->set_number('3470113')->is_valid_number, '埼玉県加須市下種足');
ok($zip->set_number('3470114')->is_valid_number, '埼玉県加須市中種足');
ok($zip->set_number('3470115')->is_valid_number, '埼玉県加須市上種足');
ok($zip->set_number('3470116')->is_valid_number, '埼玉県加須市戸室');
ok($zip->set_number('3470117')->is_valid_number, '埼玉県加須市西ノ谷');
ok($zip->set_number('3470121')->is_valid_number, '埼玉県加須市道地');
ok($zip->set_number('3470122')->is_valid_number, '埼玉県加須市内田ケ谷');
ok($zip->set_number('3470123')->is_valid_number, '埼玉県加須市下崎');
ok($zip->set_number('3470124')->is_valid_number, '埼玉県加須市中ノ目');
ok($zip->set_number('3470125')->is_valid_number, '埼玉県加須市上崎');
ok($zip->set_number('3470126')->is_valid_number, '埼玉県加須市外田ケ谷');
ok($zip->set_number('3480000')->is_valid_number, '埼玉県羽生市以下に掲載がない場合');
ok($zip->set_number('3480001')->is_valid_number, '埼玉県羽生市堤');
ok($zip->set_number('3480002')->is_valid_number, '埼玉県羽生市名');
ok($zip->set_number('3480003')->is_valid_number, '埼玉県羽生市常木');
ok($zip->set_number('3480004')->is_valid_number, '埼玉県羽生市弥勒');
ok($zip->set_number('3480005')->is_valid_number, '埼玉県羽生市上村君');
ok($zip->set_number('3480006')->is_valid_number, '埼玉県羽生市下村君');
ok($zip->set_number('3480011')->is_valid_number, '埼玉県羽生市三田ケ谷');
ok($zip->set_number('3480012')->is_valid_number, '埼玉県羽生市与兵エ新田');
ok($zip->set_number('3480013')->is_valid_number, '埼玉県羽生市日野手新田');
ok($zip->set_number('3480014')->is_valid_number, '埼玉県羽生市喜右エ門新田');
ok($zip->set_number('3480015')->is_valid_number, '埼玉県羽生市北荻島');
ok($zip->set_number('3480016')->is_valid_number, '埼玉県羽生市大沼');
ok($zip->set_number('3480017')->is_valid_number, '埼玉県羽生市今泉');
ok($zip->set_number('3480021')->is_valid_number, '埼玉県羽生市中手子林');
ok($zip->set_number('3480022')->is_valid_number, '埼玉県羽生市下手子林');
ok($zip->set_number('3480023')->is_valid_number, '埼玉県羽生市町屋');
ok($zip->set_number('3480024')->is_valid_number, '埼玉県羽生市神戸');
ok($zip->set_number('3480025')->is_valid_number, '埼玉県羽生市上手子林');
ok($zip->set_number('3480026')->is_valid_number, '埼玉県羽生市下羽生');
ok($zip->set_number('3480027')->is_valid_number, '埼玉県羽生市上羽生');
ok($zip->set_number('3480028')->is_valid_number, '埼玉県羽生市北袋');
ok($zip->set_number('3480031')->is_valid_number, '埼玉県羽生市加羽ケ崎');
ok($zip->set_number('3480032')->is_valid_number, '埼玉県羽生市秀安');
ok($zip->set_number('3480033')->is_valid_number, '埼玉県羽生市須影');
ok($zip->set_number('3480034')->is_valid_number, '埼玉県羽生市下川崎');
ok($zip->set_number('3480035')->is_valid_number, '埼玉県羽生市上川崎');
ok($zip->set_number('3480036')->is_valid_number, '埼玉県羽生市砂山');
ok($zip->set_number('3480037')->is_valid_number, '埼玉県羽生市小松');
ok($zip->set_number('3480038')->is_valid_number, '埼玉県羽生市小松台');
ok($zip->set_number('3480039')->is_valid_number, '埼玉県羽生市川崎');
ok($zip->set_number('3480041')->is_valid_number, '埼玉県羽生市上新郷');
ok($zip->set_number('3480042')->is_valid_number, '埼玉県羽生市小須賀');
ok($zip->set_number('3480043')->is_valid_number, '埼玉県羽生市桑崎');
ok($zip->set_number('3480044')->is_valid_number, '埼玉県羽生市上岩瀬');
ok($zip->set_number('3480045')->is_valid_number, '埼玉県羽生市下岩瀬');
ok($zip->set_number('3480046')->is_valid_number, '埼玉県羽生市中岩瀬');
ok($zip->set_number('3480047')->is_valid_number, '埼玉県羽生市下新郷');
ok($zip->set_number('3480048')->is_valid_number, '埼玉県羽生市下新田');
ok($zip->set_number('3480051')->is_valid_number, '埼玉県羽生市本川俣');
ok($zip->set_number('3480052')->is_valid_number, '埼玉県羽生市東');
ok($zip->set_number('3480053')->is_valid_number, '埼玉県羽生市南');
ok($zip->set_number('3480054')->is_valid_number, '埼玉県羽生市西');
ok($zip->set_number('3480055')->is_valid_number, '埼玉県羽生市羽生');
ok($zip->set_number('3480056')->is_valid_number, '埼玉県羽生市上川俣');
ok($zip->set_number('3480057')->is_valid_number, '埼玉県羽生市北');
ok($zip->set_number('3480058')->is_valid_number, '埼玉県羽生市中央');
ok($zip->set_number('3480061')->is_valid_number, '埼玉県羽生市稲子');
ok($zip->set_number('3480062')->is_valid_number, '埼玉県羽生市尾崎');
ok($zip->set_number('3480063')->is_valid_number, '埼玉県羽生市発戸');
ok($zip->set_number('3480064')->is_valid_number, '埼玉県羽生市藤井上組');
ok($zip->set_number('3480065')->is_valid_number, '埼玉県羽生市藤井下組');
ok($zip->set_number('3480071')->is_valid_number, '埼玉県羽生市南羽生');
ok($zip->set_number('3490100')->is_valid_number, '埼玉県蓮田市以下に掲載がない場合');
ok($zip->set_number('3490101')->is_valid_number, '埼玉県蓮田市黒浜');
ok($zip->set_number('3490102')->is_valid_number, '埼玉県蓮田市江ケ崎');
ok($zip->set_number('3490103')->is_valid_number, '埼玉県蓮田市笹山');
ok($zip->set_number('3490104')->is_valid_number, '埼玉県蓮田市緑町');
ok($zip->set_number('3490105')->is_valid_number, '埼玉県蓮田市藤ノ木');
ok($zip->set_number('3490111')->is_valid_number, '埼玉県蓮田市東');
ok($zip->set_number('3490112')->is_valid_number, '埼玉県蓮田市川島');
ok($zip->set_number('3490113')->is_valid_number, '埼玉県蓮田市桜台');
ok($zip->set_number('3490114')->is_valid_number, '埼玉県蓮田市馬込');
ok($zip->set_number('3490115')->is_valid_number, '埼玉県蓮田市蓮田');
ok($zip->set_number('3490121')->is_valid_number, '埼玉県蓮田市関山');
ok($zip->set_number('3490122')->is_valid_number, '埼玉県蓮田市上');
ok($zip->set_number('3490123')->is_valid_number, '埼玉県蓮田市本町');
ok($zip->set_number('3490124')->is_valid_number, '埼玉県蓮田市末広');
ok($zip->set_number('3490125')->is_valid_number, '埼玉県蓮田市御前橋');
ok($zip->set_number('3490126')->is_valid_number, '埼玉県蓮田市綾瀬');
ok($zip->set_number('3490127')->is_valid_number, '埼玉県蓮田市見沼町');
ok($zip->set_number('3490128')->is_valid_number, '埼玉県蓮田市山ノ内');
ok($zip->set_number('3490131')->is_valid_number, '埼玉県蓮田市根金');
ok($zip->set_number('3490132')->is_valid_number, '埼玉県蓮田市貝塚');
ok($zip->set_number('3490133')->is_valid_number, '埼玉県蓮田市閏戸');
ok($zip->set_number('3490134')->is_valid_number, '埼玉県蓮田市駒崎');
ok($zip->set_number('3490135')->is_valid_number, '埼玉県蓮田市井沼');
ok($zip->set_number('3490136')->is_valid_number, '埼玉県蓮田市上平野');
ok($zip->set_number('3490137')->is_valid_number, '埼玉県蓮田市高虫');
ok($zip->set_number('3490141')->is_valid_number, '埼玉県蓮田市西新宿');
ok($zip->set_number('3490142')->is_valid_number, '埼玉県蓮田市南新宿');
ok($zip->set_number('3490143')->is_valid_number, '埼玉県蓮田市城');
ok($zip->set_number('3490144')->is_valid_number, '埼玉県蓮田市椿山');
ok($zip->set_number('3490145')->is_valid_number, '埼玉県蓮田市西城');
ok($zip->set_number('3490200')->is_valid_number, '埼玉県白岡市以下に掲載がない場合');
ok($zip->set_number('3490201')->is_valid_number, '埼玉県白岡市柴山');
ok($zip->set_number('3490202')->is_valid_number, '埼玉県白岡市荒井新田');
ok($zip->set_number('3490203')->is_valid_number, '埼玉県白岡市下大崎');
ok($zip->set_number('3490204')->is_valid_number, '埼玉県白岡市篠津');
ok($zip->set_number('3490205')->is_valid_number, '埼玉県白岡市西');
ok($zip->set_number('3490211')->is_valid_number, '埼玉県白岡市野牛');
ok($zip->set_number('3490212')->is_valid_number, '埼玉県白岡市新白岡');
ok($zip->set_number('3490213')->is_valid_number, '埼玉県白岡市高岩');
ok($zip->set_number('3490214')->is_valid_number, '埼玉県白岡市寺塚');
ok($zip->set_number('3490215')->is_valid_number, '埼玉県白岡市千駄野');
ok($zip->set_number('3490216')->is_valid_number, '埼玉県白岡市実ケ谷');
ok($zip->set_number('3490217')->is_valid_number, '埼玉県白岡市小久喜');
ok($zip->set_number('3490218')->is_valid_number, '埼玉県白岡市白岡');
ok($zip->set_number('3490219')->is_valid_number, '埼玉県白岡市白岡東');
ok($zip->set_number('3490221')->is_valid_number, '埼玉県白岡市上野田');
ok($zip->set_number('3490222')->is_valid_number, '埼玉県白岡市爪田ケ谷');
ok($zip->set_number('3490223')->is_valid_number, '埼玉県白岡市下野田');
ok($zip->set_number('3490224')->is_valid_number, '埼玉県白岡市彦兵衛');
ok($zip->set_number('3490225')->is_valid_number, '埼玉県白岡市太田新井');
ok($zip->set_number('3490226')->is_valid_number, '埼玉県白岡市岡泉');
ok($zip->set_number('3491101')->is_valid_number, '埼玉県久喜市栗橋北');
ok($zip->set_number('3491102')->is_valid_number, '埼玉県久喜市栗橋中央');
ok($zip->set_number('3491103')->is_valid_number, '埼玉県久喜市栗橋東');
ok($zip->set_number('3491104')->is_valid_number, '埼玉県久喜市栗橋');
ok($zip->set_number('3491105')->is_valid_number, '埼玉県久喜市小右衛門');
ok($zip->set_number('3491106')->is_valid_number, '埼玉県久喜市緑');
ok($zip->set_number('3491111')->is_valid_number, '埼玉県久喜市北広島');
ok($zip->set_number('3491112')->is_valid_number, '埼玉県久喜市中里');
ok($zip->set_number('3491113')->is_valid_number, '埼玉県久喜市狐塚');
ok($zip->set_number('3491114')->is_valid_number, '埼玉県久喜市河原代');
ok($zip->set_number('3491115')->is_valid_number, '埼玉県久喜市新井');
ok($zip->set_number('3491116')->is_valid_number, '埼玉県久喜市島川');
ok($zip->set_number('3491117')->is_valid_number, '埼玉県久喜市南栗橋');
ok($zip->set_number('3491121')->is_valid_number, '埼玉県久喜市伊坂');
ok($zip->set_number('3491122')->is_valid_number, '埼玉県久喜市松永');
ok($zip->set_number('3491123')->is_valid_number, '埼玉県久喜市間鎌');
ok($zip->set_number('3491124')->is_valid_number, '埼玉県久喜市佐間');
ok($zip->set_number('3491125')->is_valid_number, '埼玉県久喜市高柳');
ok($zip->set_number('3491126')->is_valid_number, '埼玉県久喜市伊坂北');
ok($zip->set_number('3491127')->is_valid_number, '埼玉県久喜市伊坂中央');
ok($zip->set_number('3491128')->is_valid_number, '埼玉県久喜市伊坂南');
ok($zip->set_number('3491131')->is_valid_number, '埼玉県加須市中渡');
ok($zip->set_number('3491132')->is_valid_number, '埼玉県加須市旗井');
ok($zip->set_number('3491133')->is_valid_number, '埼玉県加須市琴寄');
ok($zip->set_number('3491134')->is_valid_number, '埼玉県加須市北下新井');
ok($zip->set_number('3491135')->is_valid_number, '埼玉県加須市北平野');
ok($zip->set_number('3491141')->is_valid_number, '埼玉県加須市松永新田');
ok($zip->set_number('3491142')->is_valid_number, '埼玉県加須市杓子木');
ok($zip->set_number('3491143')->is_valid_number, '埼玉県加須市生出');
ok($zip->set_number('3491144')->is_valid_number, '埼玉県加須市阿佐間');
ok($zip->set_number('3491145')->is_valid_number, '埼玉県加須市間口');
ok($zip->set_number('3491146')->is_valid_number, '埼玉県加須市新井新田');
ok($zip->set_number('3491147')->is_valid_number, '埼玉県加須市北大桑');
ok($zip->set_number('3491148')->is_valid_number, '埼玉県加須市豊野台');
ok($zip->set_number('3491151')->is_valid_number, '埼玉県加須市佐波');
ok($zip->set_number('3491152')->is_valid_number, '埼玉県加須市弥兵衛');
ok($zip->set_number('3491153')->is_valid_number, '埼玉県加須市新川通');
ok($zip->set_number('3491154')->is_valid_number, '埼玉県加須市外記新田');
ok($zip->set_number('3491155')->is_valid_number, '埼玉県加須市砂原');
ok($zip->set_number('3491156')->is_valid_number, '埼玉県加須市細間');
ok($zip->set_number('3491157')->is_valid_number, '埼玉県加須市道目');
ok($zip->set_number('3491158')->is_valid_number, '埼玉県加須市新利根');
ok($zip->set_number('3491201')->is_valid_number, '埼玉県加須市柳生');
ok($zip->set_number('3491202')->is_valid_number, '埼玉県加須市小野袋');
ok($zip->set_number('3491203')->is_valid_number, '埼玉県加須市柏戸');
ok($zip->set_number('3491204')->is_valid_number, '埼玉県加須市陽光台');
ok($zip->set_number('3491205')->is_valid_number, '埼玉県加須市向古河');
ok($zip->set_number('3491211')->is_valid_number, '埼玉県加須市飯積');
ok($zip->set_number('3491212')->is_valid_number, '埼玉県加須市麦倉');
ok($zip->set_number('3491213')->is_valid_number, '埼玉県加須市栄');
ok($zip->set_number('3491214')->is_valid_number, '埼玉県加須市駒場');
ok($zip->set_number('3491215')->is_valid_number, '埼玉県加須市伊賀袋');
ok($zip->set_number('3491216')->is_valid_number, '埼玉県加須市本郷');
ok($zip->set_number('3491221')->is_valid_number, '栃木県栃木市藤岡町下宮');
ok($zip->set_number('3500001')->is_valid_number, '埼玉県川越市古谷上');
ok($zip->set_number('3500002')->is_valid_number, '埼玉県川越市古谷本郷');
ok($zip->set_number('3500003')->is_valid_number, '埼玉県川越市八ツ島');
ok($zip->set_number('3500004')->is_valid_number, '埼玉県川越市高島');
ok($zip->set_number('3500011')->is_valid_number, '埼玉県川越市久下戸');
ok($zip->set_number('3500012')->is_valid_number, '埼玉県川越市萱沼');
ok($zip->set_number('3500013')->is_valid_number, '埼玉県川越市渋井');
ok($zip->set_number('3500014')->is_valid_number, '埼玉県川越市古市場');
ok($zip->set_number('3500015')->is_valid_number, '埼玉県川越市今泉');
ok($zip->set_number('3500016')->is_valid_number, '埼玉県川越市木野目');
ok($zip->set_number('3500017')->is_valid_number, '埼玉県川越市牛子');
ok($zip->set_number('3500018')->is_valid_number, '埼玉県川越市藤木町');
ok($zip->set_number('3500021')->is_valid_number, '埼玉県川越市大中居');
ok($zip->set_number('3500022')->is_valid_number, '埼玉県川越市小中居');
ok($zip->set_number('3500023')->is_valid_number, '埼玉県川越市並木');
ok($zip->set_number('3500024')->is_valid_number, '埼玉県川越市並木新町');
ok($zip->set_number('3500025')->is_valid_number, '埼玉県川越市並木西町');
ok($zip->set_number('3500026')->is_valid_number, '埼玉県川越市泉町');
ok($zip->set_number('3500027')->is_valid_number, '埼玉県川越市南田島');
ok($zip->set_number('3500031')->is_valid_number, '埼玉県川越市小仙波');
ok($zip->set_number('3500032')->is_valid_number, '埼玉県川越市大仙波');
ok($zip->set_number('3500033')->is_valid_number, '埼玉県川越市富士見町');
ok($zip->set_number('3500034')->is_valid_number, '埼玉県川越市仙波町');
ok($zip->set_number('3500035')->is_valid_number, '埼玉県川越市西小仙波町');
ok($zip->set_number('3500036')->is_valid_number, '埼玉県川越市小仙波町');
ok($zip->set_number('3500041')->is_valid_number, '埼玉県川越市六軒町');
ok($zip->set_number('3500042')->is_valid_number, '埼玉県川越市中原町');
ok($zip->set_number('3500043')->is_valid_number, '埼玉県川越市新富町');
ok($zip->set_number('3500044')->is_valid_number, '埼玉県川越市通町');
ok($zip->set_number('3500045')->is_valid_number, '埼玉県川越市南通町');
ok($zip->set_number('3500046')->is_valid_number, '埼玉県川越市菅原町');
ok($zip->set_number('3500051')->is_valid_number, '埼玉県川越市志多町');
ok($zip->set_number('3500052')->is_valid_number, '埼玉県川越市宮下町');
ok($zip->set_number('3500053')->is_valid_number, '埼玉県川越市郭町');
ok($zip->set_number('3500054')->is_valid_number, '埼玉県川越市三久保町');
ok($zip->set_number('3500055')->is_valid_number, '埼玉県川越市久保町');
ok($zip->set_number('3500056')->is_valid_number, '埼玉県川越市松江町');
ok($zip->set_number('3500057')->is_valid_number, '埼玉県川越市大手町');
ok($zip->set_number('3500061')->is_valid_number, '埼玉県川越市喜多町');
ok($zip->set_number('3500062')->is_valid_number, '埼玉県川越市元町');
ok($zip->set_number('3500063')->is_valid_number, '埼玉県川越市幸町');
ok($zip->set_number('3500064')->is_valid_number, '埼玉県川越市末広町');
ok($zip->set_number('3500065')->is_valid_number, '埼玉県川越市仲町');
ok($zip->set_number('3500066')->is_valid_number, '埼玉県川越市連雀町');
ok($zip->set_number('3500067')->is_valid_number, '埼玉県川越市三光町');
ok($zip->set_number('3500100')->is_valid_number, '埼玉県比企郡川島町以下に掲載がない場合');
ok($zip->set_number('3500101')->is_valid_number, '埼玉県比企郡川島町梅ノ木');
ok($zip->set_number('3500102')->is_valid_number, '埼玉県比企郡川島町下小見野');
ok($zip->set_number('3500103')->is_valid_number, '埼玉県比企郡川島町松永');
ok($zip->set_number('3500104')->is_valid_number, '埼玉県比企郡川島町芝沼');
ok($zip->set_number('3500105')->is_valid_number, '埼玉県比企郡川島町小見野');
ok($zip->set_number('3500106')->is_valid_number, '埼玉県比企郡川島町上小見野');
ok($zip->set_number('3500107')->is_valid_number, '埼玉県比企郡川島町加胡');
ok($zip->set_number('3500111')->is_valid_number, '埼玉県比企郡川島町谷中');
ok($zip->set_number('3500112')->is_valid_number, '埼玉県比企郡川島町鳥羽井新田');
ok($zip->set_number('3500113')->is_valid_number, '埼玉県比企郡川島町東部');
ok($zip->set_number('3500114')->is_valid_number, '埼玉県比企郡川島町東大塚');
ok($zip->set_number('3500115')->is_valid_number, '埼玉県比企郡川島町一本木');
ok($zip->set_number('3500116')->is_valid_number, '埼玉県比企郡川島町虫塚');
ok($zip->set_number('3500117')->is_valid_number, '埼玉県比企郡川島町鳥羽井');
ok($zip->set_number('3500121')->is_valid_number, '埼玉県比企郡川島町上八ツ林');
ok($zip->set_number('3500122')->is_valid_number, '埼玉県比企郡川島町下八ツ林');
ok($zip->set_number('3500123')->is_valid_number, '埼玉県比企郡川島町畑中');
ok($zip->set_number('3500124')->is_valid_number, '埼玉県比企郡川島町三保谷宿');
ok($zip->set_number('3500125')->is_valid_number, '埼玉県比企郡川島町東野');
ok($zip->set_number('3500126')->is_valid_number, '埼玉県比企郡川島町山ケ谷戸');
ok($zip->set_number('3500127')->is_valid_number, '埼玉県比企郡川島町牛ケ谷戸');
ok($zip->set_number('3500128')->is_valid_number, '埼玉県比企郡川島町白井沼');
ok($zip->set_number('3500131')->is_valid_number, '埼玉県比企郡川島町平沼');
ok($zip->set_number('3500132')->is_valid_number, '埼玉県比企郡川島町紫竹');
ok($zip->set_number('3500133')->is_valid_number, '埼玉県比企郡川島町表');
ok($zip->set_number('3500134')->is_valid_number, '埼玉県比企郡川島町新堀');
ok($zip->set_number('3500135')->is_valid_number, '埼玉県比企郡川島町下狢');
ok($zip->set_number('3500136')->is_valid_number, '埼玉県比企郡川島町上狢');
ok($zip->set_number('3500137')->is_valid_number, '埼玉県比企郡川島町宮前');
ok($zip->set_number('3500138')->is_valid_number, '埼玉県比企郡川島町吉原');
ok($zip->set_number('3500141')->is_valid_number, '埼玉県比企郡川島町出丸下郷');
ok($zip->set_number('3500142')->is_valid_number, '埼玉県比企郡川島町上大屋敷');
ok($zip->set_number('3500143')->is_valid_number, '埼玉県比企郡川島町出丸中郷');
ok($zip->set_number('3500144')->is_valid_number, '埼玉県比企郡川島町下大屋敷');
ok($zip->set_number('3500145')->is_valid_number, '埼玉県比企郡川島町出丸本');
ok($zip->set_number('3500146')->is_valid_number, '埼玉県比企郡川島町曲師');
ok($zip->set_number('3500147')->is_valid_number, '埼玉県比企郡川島町西谷');
ok($zip->set_number('3500151')->is_valid_number, '埼玉県比企郡川島町八幡');
ok($zip->set_number('3500152')->is_valid_number, '埼玉県比企郡川島町上伊草');
ok($zip->set_number('3500153')->is_valid_number, '埼玉県比企郡川島町飯島');
ok($zip->set_number('3500154')->is_valid_number, '埼玉県比企郡川島町安塚');
ok($zip->set_number('3500155')->is_valid_number, '埼玉県比企郡川島町釘無');
ok($zip->set_number('3500156')->is_valid_number, '埼玉県比企郡川島町角泉');
ok($zip->set_number('3500157')->is_valid_number, '埼玉県比企郡川島町下伊草');
ok($zip->set_number('3500158')->is_valid_number, '埼玉県比企郡川島町伊草');
ok($zip->set_number('3500161')->is_valid_number, '埼玉県比企郡川島町長楽');
ok($zip->set_number('3500162')->is_valid_number, '埼玉県比企郡川島町正直');
ok($zip->set_number('3500163')->is_valid_number, '埼玉県比企郡川島町北園部');
ok($zip->set_number('3500164')->is_valid_number, '埼玉県比企郡川島町吹塚');
ok($zip->set_number('3500165')->is_valid_number, '埼玉県比企郡川島町中山');
ok($zip->set_number('3500166')->is_valid_number, '埼玉県比企郡川島町戸守');
ok($zip->set_number('3500167')->is_valid_number, '埼玉県比企郡川島町南園部');
ok($zip->set_number('3500168')->is_valid_number, '埼玉県比企郡川島町かわじま');
ok($zip->set_number('3500200')->is_valid_number, '埼玉県坂戸市以下に掲載がない場合');
ok($zip->set_number('3500201')->is_valid_number, '埼玉県坂戸市赤尾');
ok($zip->set_number('3500202')->is_valid_number, '埼玉県坂戸市小沼');
ok($zip->set_number('3500203')->is_valid_number, '埼玉県坂戸市横沼');
ok($zip->set_number('3500204')->is_valid_number, '埼玉県坂戸市紺屋');
ok($zip->set_number('3500205')->is_valid_number, '埼玉県坂戸市東坂戸');
ok($zip->set_number('3500206')->is_valid_number, '埼玉県坂戸市中小坂');
ok($zip->set_number('3500207')->is_valid_number, '埼玉県坂戸市青木');
ok($zip->set_number('3500208')->is_valid_number, '埼玉県坂戸市戸宮');
ok($zip->set_number('3500209')->is_valid_number, '埼玉県坂戸市塚越');
ok($zip->set_number('3500211')->is_valid_number, '埼玉県坂戸市島田');
ok($zip->set_number('3500212')->is_valid_number, '埼玉県坂戸市石井');
ok($zip->set_number('3500213')->is_valid_number, '埼玉県坂戸市栄');
ok($zip->set_number('3500214')->is_valid_number, '埼玉県坂戸市千代田');
ok($zip->set_number('3500215')->is_valid_number, '埼玉県坂戸市関間');
ok($zip->set_number('3500216')->is_valid_number, '埼玉県坂戸市柳町');
ok($zip->set_number('3500217')->is_valid_number, '埼玉県坂戸市坂戸');
ok($zip->set_number('3500218')->is_valid_number, '埼玉県坂戸市片柳新田');
ok($zip->set_number('3500219')->is_valid_number, '埼玉県坂戸市片柳');
ok($zip->set_number('3500221')->is_valid_number, '埼玉県坂戸市鎌倉町');
ok($zip->set_number('3500222')->is_valid_number, '埼玉県坂戸市清水町');
ok($zip->set_number('3500223')->is_valid_number, '埼玉県坂戸市八幡');
ok($zip->set_number('3500224')->is_valid_number, '埼玉県坂戸市山田町');
ok($zip->set_number('3500225')->is_valid_number, '埼玉県坂戸市日の出町');
ok($zip->set_number('3500226')->is_valid_number, '埼玉県坂戸市本町');
ok($zip->set_number('3500227')->is_valid_number, '埼玉県坂戸市仲町');
ok($zip->set_number('3500228')->is_valid_number, '埼玉県坂戸市元町');
ok($zip->set_number('3500229')->is_valid_number, '埼玉県坂戸市薬師町');
ok($zip->set_number('3500231')->is_valid_number, '埼玉県坂戸市泉町');
ok($zip->set_number('3500232')->is_valid_number, '埼玉県坂戸市中富町');
ok($zip->set_number('3500233')->is_valid_number, '埼玉県坂戸市南町');
ok($zip->set_number('3500234')->is_valid_number, '埼玉県坂戸市緑町');
ok($zip->set_number('3500235')->is_valid_number, '埼玉県坂戸市三光町');
ok($zip->set_number('3500236')->is_valid_number, '埼玉県坂戸市花影町');
ok($zip->set_number('3500237')->is_valid_number, '埼玉県坂戸市浅羽野');
ok($zip->set_number('3500238')->is_valid_number, '埼玉県坂戸市浅羽');
ok($zip->set_number('3500239')->is_valid_number, '埼玉県坂戸市粟生田');
ok($zip->set_number('3500241')->is_valid_number, '埼玉県坂戸市鶴舞');
ok($zip->set_number('3500242')->is_valid_number, '埼玉県坂戸市厚川');
ok($zip->set_number('3500243')->is_valid_number, '埼玉県坂戸市萱方');
ok($zip->set_number('3500244')->is_valid_number, '埼玉県坂戸市森戸');
ok($zip->set_number('3500245')->is_valid_number, '埼玉県坂戸市四日市場');
ok($zip->set_number('3500246')->is_valid_number, '埼玉県坂戸市多和目');
ok($zip->set_number('3500247')->is_valid_number, '埼玉県坂戸市西坂戸');
ok($zip->set_number('3500248')->is_valid_number, '埼玉県坂戸市けやき台');
ok($zip->set_number('3500251')->is_valid_number, '埼玉県坂戸市塚崎');
ok($zip->set_number('3500252')->is_valid_number, '埼玉県坂戸市中里');
ok($zip->set_number('3500253')->is_valid_number, '埼玉県坂戸市北大塚');
ok($zip->set_number('3500254')->is_valid_number, '埼玉県坂戸市欠ノ上');
ok($zip->set_number('3500255')->is_valid_number, '埼玉県坂戸市成願寺');
ok($zip->set_number('3500256')->is_valid_number, '埼玉県坂戸市善能寺');
ok($zip->set_number('3500257')->is_valid_number, '埼玉県坂戸市小山');
ok($zip->set_number('3500258')->is_valid_number, '埼玉県坂戸市北峰');
ok($zip->set_number('3500259')->is_valid_number, '埼玉県坂戸市西インター');
ok($zip->set_number('3500261')->is_valid_number, '埼玉県坂戸市沢木');
ok($zip->set_number('3500262')->is_valid_number, '埼玉県坂戸市新堀');
ok($zip->set_number('3500263')->is_valid_number, '埼玉県坂戸市堀込');
ok($zip->set_number('3500264')->is_valid_number, '埼玉県坂戸市竹之内');
ok($zip->set_number('3500265')->is_valid_number, '埼玉県坂戸市長岡');
ok($zip->set_number('3500266')->is_valid_number, '埼玉県坂戸市北浅羽');
ok($zip->set_number('3500267')->is_valid_number, '埼玉県坂戸市今西');
ok($zip->set_number('3500268')->is_valid_number, '埼玉県坂戸市金田');
ok($zip->set_number('3500269')->is_valid_number, '埼玉県坂戸市にっさい花みず木');
ok($zip->set_number('3500271')->is_valid_number, '埼玉県坂戸市上吉田');
ok($zip->set_number('3500272')->is_valid_number, '埼玉県坂戸市末広町');
ok($zip->set_number('3500273')->is_valid_number, '埼玉県坂戸市芦山町');
ok($zip->set_number('3500274')->is_valid_number, '埼玉県坂戸市溝端町');
ok($zip->set_number('3500275')->is_valid_number, '埼玉県坂戸市伊豆の山町');
ok($zip->set_number('3500276')->is_valid_number, '埼玉県坂戸市戸口');
ok($zip->set_number('3500277')->is_valid_number, '埼玉県坂戸市東和田');
ok($zip->set_number('3500278')->is_valid_number, '埼玉県坂戸市新ケ谷');
ok($zip->set_number('3500300')->is_valid_number, '埼玉県比企郡鳩山町以下に掲載がない場合');
ok($zip->set_number('3500301')->is_valid_number, '埼玉県比企郡鳩山町奥田');
ok($zip->set_number('3500302')->is_valid_number, '埼玉県比企郡鳩山町大橋');
ok($zip->set_number('3500303')->is_valid_number, '埼玉県比企郡鳩山町熊井');
ok($zip->set_number('3500304')->is_valid_number, '埼玉県比企郡鳩山町高野倉');
ok($zip->set_number('3500305')->is_valid_number, '埼玉県比企郡鳩山町泉井');
ok($zip->set_number('3500306')->is_valid_number, '埼玉県比企郡鳩山町竹本');
ok($zip->set_number('3500307')->is_valid_number, '埼玉県比企郡鳩山町須江');
ok($zip->set_number('3500311')->is_valid_number, '埼玉県比企郡鳩山町石坂');
ok($zip->set_number('3500312')->is_valid_number, '埼玉県比企郡鳩山町鳩ケ丘');
ok($zip->set_number('3500313')->is_valid_number, '埼玉県比企郡鳩山町松ケ丘');
ok($zip->set_number('3500314')->is_valid_number, '埼玉県比企郡鳩山町楓ケ丘');
ok($zip->set_number('3500321')->is_valid_number, '埼玉県比企郡鳩山町赤沼');
ok($zip->set_number('3500322')->is_valid_number, '埼玉県比企郡鳩山町今宿');
ok($zip->set_number('3500323')->is_valid_number, '埼玉県比企郡鳩山町小用');
ok($zip->set_number('3500324')->is_valid_number, '埼玉県比企郡鳩山町大豆戸');
ok($zip->set_number('3500400')->is_valid_number, '埼玉県入間郡毛呂山町以下に掲載がない場合');
ok($zip->set_number('3500400')->is_valid_number, '埼玉県入間郡越生町以下に掲載がない場合');
ok($zip->set_number('3500401')->is_valid_number, '埼玉県入間郡越生町古池');
ok($zip->set_number('3500402')->is_valid_number, '埼玉県入間郡越生町鹿下');
ok($zip->set_number('3500403')->is_valid_number, '埼玉県入間郡越生町大谷');
ok($zip->set_number('3500404')->is_valid_number, '埼玉県入間郡越生町成瀬');
ok($zip->set_number('3500405')->is_valid_number, '埼玉県入間郡越生町津久根');
ok($zip->set_number('3500406')->is_valid_number, '埼玉県入間郡越生町堂山');
ok($zip->set_number('3500407')->is_valid_number, '埼玉県入間郡越生町上谷');
ok($zip->set_number('3500411')->is_valid_number, '埼玉県入間郡越生町黒岩');
ok($zip->set_number('3500412')->is_valid_number, '埼玉県入間郡越生町西和田');
ok($zip->set_number('3500413')->is_valid_number, '埼玉県入間郡越生町如意');
ok($zip->set_number('3500414')->is_valid_number, '埼玉県入間郡越生町越生東');
ok($zip->set_number('3500415')->is_valid_number, '埼玉県入間郡越生町上野');
ok($zip->set_number('3500416')->is_valid_number, '埼玉県入間郡越生町越生');
ok($zip->set_number('3500417')->is_valid_number, '埼玉県入間郡越生町上野東');
ok($zip->set_number('3500421')->is_valid_number, '埼玉県入間郡越生町麦原');
ok($zip->set_number('3500422')->is_valid_number, '埼玉県入間郡越生町小杉');
ok($zip->set_number('3500423')->is_valid_number, '埼玉県入間郡越生町大満');
ok($zip->set_number('3500424')->is_valid_number, '埼玉県入間郡越生町黒山');
ok($zip->set_number('3500425')->is_valid_number, '埼玉県入間郡越生町龍ケ谷');
ok($zip->set_number('3500431')->is_valid_number, '埼玉県入間郡毛呂山町苦林');
ok($zip->set_number('3500432')->is_valid_number, '埼玉県入間郡毛呂山町大類');
ok($zip->set_number('3500433')->is_valid_number, '埼玉県入間郡毛呂山町西大久保');
ok($zip->set_number('3500434')->is_valid_number, '埼玉県入間郡毛呂山町市場');
ok($zip->set_number('3500435')->is_valid_number, '埼玉県入間郡毛呂山町下川原');
ok($zip->set_number('3500436')->is_valid_number, '埼玉県入間郡毛呂山町川角');
ok($zip->set_number('3500437')->is_valid_number, '埼玉県入間郡毛呂山町箕和田');
ok($zip->set_number('3500438')->is_valid_number, '埼玉県入間郡毛呂山町西戸');
ok($zip->set_number('3500439')->is_valid_number, '埼玉県入間郡毛呂山町目白台');
ok($zip->set_number('3500441')->is_valid_number, '埼玉県入間郡毛呂山町岩井');
ok($zip->set_number('3500442')->is_valid_number, '埼玉県入間郡毛呂山町前久保');
ok($zip->set_number('3500443')->is_valid_number, '埼玉県入間郡毛呂山町長瀬');
ok($zip->set_number('3500444')->is_valid_number, '埼玉県入間郡毛呂山町旭台');
ok($zip->set_number('3500445')->is_valid_number, '埼玉県入間郡毛呂山町葛貫');
ok($zip->set_number('3500446')->is_valid_number, '埼玉県入間郡毛呂山町小田谷');
ok($zip->set_number('3500451')->is_valid_number, '埼玉県入間郡毛呂山町毛呂本郷');
ok($zip->set_number('3500452')->is_valid_number, '埼玉県入間郡毛呂山町大谷木');
ok($zip->set_number('3500453')->is_valid_number, '埼玉県入間郡毛呂山町宿谷');
ok($zip->set_number('3500454')->is_valid_number, '埼玉県入間郡毛呂山町権現堂');
ok($zip->set_number('3500455')->is_valid_number, '埼玉県入間郡毛呂山町阿諏訪');
ok($zip->set_number('3500456')->is_valid_number, '埼玉県入間郡毛呂山町滝ノ入');
ok($zip->set_number('3500461')->is_valid_number, '埼玉県入間郡毛呂山町中央');
ok($zip->set_number('3500462')->is_valid_number, '埼玉県入間郡毛呂山町若山');
ok($zip->set_number('3500463')->is_valid_number, '埼玉県入間郡毛呂山町前久保南');
ok($zip->set_number('3500464')->is_valid_number, '埼玉県入間郡毛呂山町南台');
ok($zip->set_number('3500465')->is_valid_number, '埼玉県入間郡毛呂山町岩井西');
ok($zip->set_number('3500466')->is_valid_number, '埼玉県入間郡毛呂山町平山');
ok($zip->set_number('3500467')->is_valid_number, '埼玉県入間郡毛呂山町岩井東');
ok($zip->set_number('3500801')->is_valid_number, '埼玉県川越市竹野');
ok($zip->set_number('3500802')->is_valid_number, '埼玉県川越市富士見');
ok($zip->set_number('3500803')->is_valid_number, '埼玉県川越市栄');
ok($zip->set_number('3500804')->is_valid_number, '埼玉県川越市下広谷');
ok($zip->set_number('3500805')->is_valid_number, '埼玉県川越市広谷新町');
ok($zip->set_number('3500806')->is_valid_number, '埼玉県川越市天沼新田');
ok($zip->set_number('3500807')->is_valid_number, '埼玉県川越市吉田');
ok($zip->set_number('3500808')->is_valid_number, '埼玉県川越市吉田新町');
ok($zip->set_number('3500809')->is_valid_number, '埼玉県川越市鯨井新田');
ok($zip->set_number('3500811')->is_valid_number, '埼玉県川越市小堤');
ok($zip->set_number('3500812')->is_valid_number, '埼玉県川越市下小坂');
ok($zip->set_number('3500813')->is_valid_number, '埼玉県川越市平塚新田');
ok($zip->set_number('3500814')->is_valid_number, '埼玉県川越市平塚');
ok($zip->set_number('3500815')->is_valid_number, '埼玉県川越市鯨井');
ok($zip->set_number('3500816')->is_valid_number, '埼玉県川越市上戸');
ok($zip->set_number('3500817')->is_valid_number, '埼玉県川越市上戸新町');
ok($zip->set_number('3500821')->is_valid_number, '埼玉県川越市福田');
ok($zip->set_number('3500822')->is_valid_number, '埼玉県川越市山田');
ok($zip->set_number('3500823')->is_valid_number, '埼玉県川越市神明町');
ok($zip->set_number('3500824')->is_valid_number, '埼玉県川越市石原町');
ok($zip->set_number('3500825')->is_valid_number, '埼玉県川越市月吉町');
ok($zip->set_number('3500826')->is_valid_number, '埼玉県川越市上寺山');
ok($zip->set_number('3500827')->is_valid_number, '埼玉県川越市寺山');
ok($zip->set_number('3500831')->is_valid_number, '埼玉県川越市府川');
ok($zip->set_number('3500832')->is_valid_number, '埼玉県川越市菅間');
ok($zip->set_number('3500833')->is_valid_number, '埼玉県川越市芳野台');
ok($zip->set_number('3500834')->is_valid_number, '埼玉県川越市鹿飼');
ok($zip->set_number('3500835')->is_valid_number, '埼玉県川越市石田本郷');
ok($zip->set_number('3500836')->is_valid_number, '埼玉県川越市谷中');
ok($zip->set_number('3500837')->is_valid_number, '埼玉県川越市石田');
ok($zip->set_number('3500838')->is_valid_number, '埼玉県川越市宮元町');
ok($zip->set_number('3500841')->is_valid_number, '埼玉県川越市御成町');
ok($zip->set_number('3500842')->is_valid_number, '埼玉県川越市北田島');
ok($zip->set_number('3500843')->is_valid_number, '埼玉県川越市東明寺');
ok($zip->set_number('3500844')->is_valid_number, '埼玉県川越市鴨田');
ok($zip->set_number('3500845')->is_valid_number, '埼玉県川越市上老袋');
ok($zip->set_number('3500846')->is_valid_number, '埼玉県川越市中老袋');
ok($zip->set_number('3500847')->is_valid_number, '埼玉県川越市東本宿');
ok($zip->set_number('3500848')->is_valid_number, '埼玉県川越市下老袋');
ok($zip->set_number('3500851')->is_valid_number, '埼玉県川越市氷川町');
ok($zip->set_number('3500852')->is_valid_number, '埼玉県川越市川越');
ok($zip->set_number('3500853')->is_valid_number, '埼玉県川越市城下町');
ok($zip->set_number('3500854')->is_valid_number, '埼玉県川越市寺井');
ok($zip->set_number('3500855')->is_valid_number, '埼玉県川越市伊佐沼');
ok($zip->set_number('3500856')->is_valid_number, '埼玉県川越市問屋町');
ok($zip->set_number('3500857')->is_valid_number, '埼玉県川越市松郷');
ok($zip->set_number('3501100')->is_valid_number, '埼玉県川越市以下に掲載がない場合');
ok($zip->set_number('3501101')->is_valid_number, '埼玉県川越市的場');
ok($zip->set_number('3501102')->is_valid_number, '埼玉県川越市的場北');
ok($zip->set_number('3501103')->is_valid_number, '埼玉県川越市霞ケ関東');
ok($zip->set_number('3501104')->is_valid_number, '埼玉県川越市小ケ谷');
ok($zip->set_number('3501105')->is_valid_number, '埼玉県川越市今成');
ok($zip->set_number('3501106')->is_valid_number, '埼玉県川越市小室');
ok($zip->set_number('3501107')->is_valid_number, '埼玉県川越市的場新町');
ok($zip->set_number('3501108')->is_valid_number, '埼玉県川越市伊勢原町');
ok($zip->set_number('3501109')->is_valid_number, '埼玉県川越市霞ケ関北');
ok($zip->set_number('3501110')->is_valid_number, '埼玉県川越市豊田町');
ok($zip->set_number('3501111')->is_valid_number, '埼玉県川越市野田');
ok($zip->set_number('3501112')->is_valid_number, '埼玉県川越市上野田町');
ok($zip->set_number('3501113')->is_valid_number, '埼玉県川越市田町');
ok($zip->set_number('3501114')->is_valid_number, '埼玉県川越市東田町');
ok($zip->set_number('3501115')->is_valid_number, '埼玉県川越市野田町');
ok($zip->set_number('3501116')->is_valid_number, '埼玉県川越市寿町');
ok($zip->set_number('3501117')->is_valid_number, '埼玉県川越市広栄町');
ok($zip->set_number('3501118')->is_valid_number, '埼玉県川越市豊田本');
ok($zip->set_number('3501119')->is_valid_number, '埼玉県川越市豊田新田');
ok($zip->set_number('3501121')->is_valid_number, '埼玉県川越市脇田新町');
ok($zip->set_number('3501122')->is_valid_number, '埼玉県川越市脇田町');
ok($zip->set_number('3501123')->is_valid_number, '埼玉県川越市脇田本町');
ok($zip->set_number('3501124')->is_valid_number, '埼玉県川越市新宿町');
ok($zip->set_number('3501125')->is_valid_number, '埼玉県川越市新宿');
ok($zip->set_number('3501126')->is_valid_number, '埼玉県川越市旭町');
ok($zip->set_number('3501128')->is_valid_number, '埼玉県川越市大仙波新田');
ok($zip->set_number('3501129')->is_valid_number, '埼玉県川越市大塚');
ok($zip->set_number('3501131')->is_valid_number, '埼玉県川越市岸町');
ok($zip->set_number('3501132')->is_valid_number, '埼玉県川越市岸');
ok($zip->set_number('3501133')->is_valid_number, '埼玉県川越市砂');
ok($zip->set_number('3501134')->is_valid_number, '埼玉県川越市扇河岸');
ok($zip->set_number('3501135')->is_valid_number, '埼玉県川越市上新河岸');
ok($zip->set_number('3501136')->is_valid_number, '埼玉県川越市下新河岸');
ok($zip->set_number('3501137')->is_valid_number, '埼玉県川越市砂新田');
ok($zip->set_number('3501138')->is_valid_number, '埼玉県川越市中台元町');
ok($zip->set_number('3501141')->is_valid_number, '埼玉県川越市寺尾');
ok($zip->set_number('3501142')->is_valid_number, '埼玉県川越市藤間');
ok($zip->set_number('3501143')->is_valid_number, '埼玉県川越市藤原町');
ok($zip->set_number('3501144')->is_valid_number, '埼玉県川越市稲荷町');
ok($zip->set_number('3501145')->is_valid_number, '埼玉県川越市清水町');
ok($zip->set_number('3501146')->is_valid_number, '埼玉県川越市熊野町');
ok($zip->set_number('3501147')->is_valid_number, '埼玉県川越市諏訪町');
ok($zip->set_number('3501150')->is_valid_number, '埼玉県川越市中台南');
ok($zip->set_number('3501151')->is_valid_number, '埼玉県川越市今福');
ok($zip->set_number('3501152')->is_valid_number, '埼玉県川越市砂久保');
ok($zip->set_number('3501153')->is_valid_number, '埼玉県川越市下松原');
ok($zip->set_number('3501154')->is_valid_number, '埼玉県川越市上松原');
ok($zip->set_number('3501155')->is_valid_number, '埼玉県川越市下赤坂');
ok($zip->set_number('3501156')->is_valid_number, '埼玉県川越市中福');
ok($zip->set_number('3501157')->is_valid_number, '埼玉県川越市中福東');
ok($zip->set_number('3501158')->is_valid_number, '埼玉県川越市むさし野南');
ok($zip->set_number('3501159')->is_valid_number, '埼玉県川越市中台');
ok($zip->set_number('3501160')->is_valid_number, '埼玉県川越市日東町');
ok($zip->set_number('3501161')->is_valid_number, '埼玉県川越市大塚新田');
ok($zip->set_number('3501162')->is_valid_number, '埼玉県川越市南大塚');
ok($zip->set_number('3501163')->is_valid_number, '埼玉県川越市四都野台');
ok($zip->set_number('3501164')->is_valid_number, '埼玉県川越市青柳');
ok($zip->set_number('3501165')->is_valid_number, '埼玉県川越市南台');
ok($zip->set_number('3501166')->is_valid_number, '埼玉県川越市藤倉');
ok($zip->set_number('3501167')->is_valid_number, '埼玉県川越市大袋新田');
ok($zip->set_number('3501168')->is_valid_number, '埼玉県川越市大袋');
ok($zip->set_number('3501169')->is_valid_number, '埼玉県川越市山城');
ok($zip->set_number('3501170')->is_valid_number, '埼玉県川越市むさし野');
ok($zip->set_number('3501171')->is_valid_number, '埼玉県川越市池辺');
ok($zip->set_number('3501172')->is_valid_number, '埼玉県川越市増形');
ok($zip->set_number('3501173')->is_valid_number, '埼玉県川越市安比奈新田');
ok($zip->set_number('3501174')->is_valid_number, '埼玉県川越市かすみ野');
ok($zip->set_number('3501175')->is_valid_number, '埼玉県川越市笠幡');
ok($zip->set_number('3501176')->is_valid_number, '埼玉県川越市川鶴');
ok($zip->set_number('3501177')->is_valid_number, '埼玉県川越市かわつる三芳野');
ok($zip->set_number('3501178')->is_valid_number, '埼玉県川越市大塚新町');
ok($zip->set_number('3501179')->is_valid_number, '埼玉県川越市かし野台');
ok($zip->set_number('3501200')->is_valid_number, '埼玉県日高市以下に掲載がない場合');
ok($zip->set_number('3501201')->is_valid_number, '埼玉県日高市田波目');
ok($zip->set_number('3501202')->is_valid_number, '埼玉県日高市駒寺野新田');
ok($zip->set_number('3501203')->is_valid_number, '埼玉県日高市旭ケ丘');
ok($zip->set_number('3501204')->is_valid_number, '埼玉県日高市新堀新田');
ok($zip->set_number('3501205')->is_valid_number, '埼玉県日高市原宿');
ok($zip->set_number('3501206')->is_valid_number, '埼玉県日高市南平沢');
ok($zip->set_number('3501211')->is_valid_number, '埼玉県日高市森戸新田');
ok($zip->set_number('3501212')->is_valid_number, '埼玉県日高市下高萩新田');
ok($zip->set_number('3501213')->is_valid_number, '埼玉県日高市高萩');
ok($zip->set_number('3501214')->is_valid_number, '埼玉県日高市女影新田');
ok($zip->set_number('3501215')->is_valid_number, '埼玉県日高市高萩東');
ok($zip->set_number('3501221')->is_valid_number, '埼玉県日高市下大谷沢');
ok($zip->set_number('3501222')->is_valid_number, '埼玉県日高市大谷沢');
ok($zip->set_number('3501223')->is_valid_number, '埼玉県日高市高富');
ok($zip->set_number('3501224')->is_valid_number, '埼玉県日高市田木');
ok($zip->set_number('3501225')->is_valid_number, '埼玉県日高市馬引沢');
ok($zip->set_number('3501226')->is_valid_number, '埼玉県日高市中沢');
ok($zip->set_number('3501227')->is_valid_number, '埼玉県日高市女影');
ok($zip->set_number('3501231')->is_valid_number, '埼玉県日高市鹿山');
ok($zip->set_number('3501232')->is_valid_number, '埼玉県日高市中鹿山');
ok($zip->set_number('3501233')->is_valid_number, '埼玉県日高市下鹿山');
ok($zip->set_number('3501234')->is_valid_number, '埼玉県日高市上鹿山');
ok($zip->set_number('3501235')->is_valid_number, '埼玉県日高市楡木');
ok($zip->set_number('3501236')->is_valid_number, '埼玉県日高市猿田');
ok($zip->set_number('3501237')->is_valid_number, '埼玉県日高市猿田上ノ台');
ok($zip->set_number('3501241')->is_valid_number, '埼玉県日高市山根');
ok($zip->set_number('3501242')->is_valid_number, '埼玉県日高市北平沢');
ok($zip->set_number('3501243')->is_valid_number, '埼玉県日高市新堀');
ok($zip->set_number('3501244')->is_valid_number, '埼玉県日高市野々宮');
ok($zip->set_number('3501245')->is_valid_number, '埼玉県日高市栗坪');
ok($zip->set_number('3501246')->is_valid_number, '埼玉県日高市梅原');
ok($zip->set_number('3501247')->is_valid_number, '埼玉県日高市高岡');
ok($zip->set_number('3501248')->is_valid_number, '埼玉県日高市四本木');
ok($zip->set_number('3501249')->is_valid_number, '埼玉県日高市高麗川');
ok($zip->set_number('3501251')->is_valid_number, '埼玉県日高市高麗本郷');
ok($zip->set_number('3501252')->is_valid_number, '埼玉県日高市清流');
ok($zip->set_number('3501253')->is_valid_number, '埼玉県日高市台');
ok($zip->set_number('3501254')->is_valid_number, '埼玉県日高市久保');
ok($zip->set_number('3501255')->is_valid_number, '埼玉県日高市武蔵台');
ok($zip->set_number('3501257')->is_valid_number, '埼玉県日高市横手');
ok($zip->set_number('3501300')->is_valid_number, '埼玉県狭山市以下に掲載がない場合');
ok($zip->set_number('3501301')->is_valid_number, '埼玉県狭山市青柳');
ok($zip->set_number('3501302')->is_valid_number, '埼玉県狭山市東三ツ木');
ok($zip->set_number('3501303')->is_valid_number, '埼玉県狭山市沢');
ok($zip->set_number('3501304')->is_valid_number, '埼玉県狭山市狭山台');
ok($zip->set_number('3501305')->is_valid_number, '埼玉県狭山市入間川');
ok($zip->set_number('3501306')->is_valid_number, '埼玉県狭山市富士見');
ok($zip->set_number('3501307')->is_valid_number, '埼玉県狭山市祇園');
ok($zip->set_number('3501308')->is_valid_number, '埼玉県狭山市中央');
ok($zip->set_number('3501311')->is_valid_number, '埼玉県狭山市中新田');
ok($zip->set_number('3501312')->is_valid_number, '埼玉県狭山市堀兼');
ok($zip->set_number('3501313')->is_valid_number, '埼玉県狭山市上赤坂');
ok($zip->set_number('3501314')->is_valid_number, '埼玉県狭山市加佐志');
ok($zip->set_number('3501315')->is_valid_number, '埼玉県狭山市北入曽');
ok($zip->set_number('3501316')->is_valid_number, '埼玉県狭山市南入曽');
ok($zip->set_number('3501317')->is_valid_number, '埼玉県狭山市水野');
ok($zip->set_number('3501319')->is_valid_number, '埼玉県狭山市広瀬');
ok($zip->set_number('3501320')->is_valid_number, '埼玉県狭山市広瀬東');
ok($zip->set_number('3501321')->is_valid_number, '埼玉県狭山市上広瀬');
ok($zip->set_number('3501322')->is_valid_number, '埼玉県狭山市下広瀬');
ok($zip->set_number('3501323')->is_valid_number, '埼玉県狭山市鵜ノ木');
ok($zip->set_number('3501324')->is_valid_number, '埼玉県狭山市稲荷山');
ok($zip->set_number('3501325')->is_valid_number, '埼玉県狭山市根岸');
ok($zip->set_number('3501326')->is_valid_number, '埼玉県狭山市つつじ野');
ok($zip->set_number('3501327')->is_valid_number, '埼玉県狭山市笹井');
ok($zip->set_number('3501328')->is_valid_number, '埼玉県狭山市広瀬台');
ok($zip->set_number('3501331')->is_valid_number, '埼玉県狭山市新狭山');
ok($zip->set_number('3501332')->is_valid_number, '埼玉県狭山市下奥富');
ok($zip->set_number('3501333')->is_valid_number, '埼玉県狭山市上奥富');
ok($zip->set_number('3501334')->is_valid_number, '埼玉県狭山市狭山');
ok($zip->set_number('3501335')->is_valid_number, '埼玉県狭山市柏原');
ok($zip->set_number('3501336')->is_valid_number, '埼玉県狭山市柏原新田');
ok($zip->set_number('3502200')->is_valid_number, '埼玉県鶴ヶ島市以下に掲載がない場合');
ok($zip->set_number('3502201')->is_valid_number, '埼玉県鶴ヶ島市富士見');
ok($zip->set_number('3502202')->is_valid_number, '埼玉県鶴ヶ島市五味ヶ谷');
ok($zip->set_number('3502203')->is_valid_number, '埼玉県鶴ヶ島市上広谷');
ok($zip->set_number('3502204')->is_valid_number, '埼玉県鶴ヶ島市鶴ヶ丘');
ok($zip->set_number('3502205')->is_valid_number, '埼玉県鶴ヶ島市松ヶ丘');
ok($zip->set_number('3502206')->is_valid_number, '埼玉県鶴ヶ島市藤金');
ok($zip->set_number('3502211')->is_valid_number, '埼玉県鶴ヶ島市脚折町');
ok($zip->set_number('3502212')->is_valid_number, '埼玉県鶴ヶ島市共栄町');
ok($zip->set_number('3502213')->is_valid_number, '埼玉県鶴ヶ島市脚折');
ok($zip->set_number('3502214')->is_valid_number, '埼玉県鶴ヶ島市太田ヶ谷');
ok($zip->set_number('3502215')->is_valid_number, '埼玉県鶴ヶ島市南町');
ok($zip->set_number('3502216')->is_valid_number, '埼玉県鶴ヶ島市三ツ木新田');
ok($zip->set_number('3502217')->is_valid_number, '埼玉県鶴ヶ島市三ツ木');
ok($zip->set_number('3502218')->is_valid_number, '埼玉県鶴ヶ島市柳戸町');
ok($zip->set_number('3502219')->is_valid_number, '埼玉県鶴ヶ島市三ツ木新町');
ok($zip->set_number('3502221')->is_valid_number, '埼玉県鶴ヶ島市羽折町');
ok($zip->set_number('3502222')->is_valid_number, '埼玉県鶴ヶ島市下新田');
ok($zip->set_number('3502223')->is_valid_number, '埼玉県鶴ヶ島市高倉');
ok($zip->set_number('3502224')->is_valid_number, '埼玉県鶴ヶ島市町屋');
ok($zip->set_number('3502225')->is_valid_number, '埼玉県鶴ヶ島市上新田');
ok($zip->set_number('3502226')->is_valid_number, '埼玉県鶴ヶ島市中新田');
ok($zip->set_number('3502227')->is_valid_number, '埼玉県鶴ヶ島市新町');
ok($zip->set_number('3510000')->is_valid_number, '埼玉県朝霞市以下に掲載がない場合');
ok($zip->set_number('3510001')->is_valid_number, '埼玉県朝霞市上内間木');
ok($zip->set_number('3510002')->is_valid_number, '埼玉県朝霞市下内間木');
ok($zip->set_number('3510003')->is_valid_number, '埼玉県朝霞市台');
ok($zip->set_number('3510004')->is_valid_number, '埼玉県朝霞市根岸');
ok($zip->set_number('3510005')->is_valid_number, '埼玉県朝霞市根岸台');
ok($zip->set_number('3510006')->is_valid_number, '埼玉県朝霞市仲町');
ok($zip->set_number('3510007')->is_valid_number, '埼玉県朝霞市岡');
ok($zip->set_number('3510011')->is_valid_number, '埼玉県朝霞市本町');
ok($zip->set_number('3510012')->is_valid_number, '埼玉県朝霞市栄町');
ok($zip->set_number('3510013')->is_valid_number, '埼玉県朝霞市膝折');
ok($zip->set_number('3510014')->is_valid_number, '埼玉県朝霞市膝折町');
ok($zip->set_number('3510015')->is_valid_number, '埼玉県朝霞市幸町');
ok($zip->set_number('3510016')->is_valid_number, '埼玉県朝霞市青葉台');
ok($zip->set_number('3510021')->is_valid_number, '埼玉県朝霞市西弁財');
ok($zip->set_number('3510022')->is_valid_number, '埼玉県朝霞市東弁財');
ok($zip->set_number('3510023')->is_valid_number, '埼玉県朝霞市溝沼');
ok($zip->set_number('3510024')->is_valid_number, '埼玉県朝霞市泉水');
ok($zip->set_number('3510025')->is_valid_number, '埼玉県朝霞市三原');
ok($zip->set_number('3510031')->is_valid_number, '埼玉県朝霞市宮戸');
ok($zip->set_number('3510032')->is_valid_number, '埼玉県朝霞市田島');
ok($zip->set_number('3510033')->is_valid_number, '埼玉県朝霞市浜崎');
ok($zip->set_number('3510034')->is_valid_number, '埼玉県朝霞市西原');
ok($zip->set_number('3510035')->is_valid_number, '埼玉県朝霞市朝志ケ丘');
ok($zip->set_number('3510036')->is_valid_number, '埼玉県朝霞市北原');
ok($zip->set_number('3510100')->is_valid_number, '埼玉県和光市以下に掲載がない場合');
ok($zip->set_number('3510101')->is_valid_number, '埼玉県和光市白子');
ok($zip->set_number('3510102')->is_valid_number, '埼玉県和光市諏訪');
ok($zip->set_number('3510103')->is_valid_number, '埼玉県和光市諏訪原団地');
ok($zip->set_number('3510104')->is_valid_number, '埼玉県和光市南');
ok($zip->set_number('3510105')->is_valid_number, '埼玉県和光市西大和団地');
ok($zip->set_number('3510106')->is_valid_number, '埼玉県和光市広沢');
ok($zip->set_number('3510111')->is_valid_number, '埼玉県和光市下新倉');
ok($zip->set_number('3510112')->is_valid_number, '埼玉県和光市丸山台');
ok($zip->set_number('3510113')->is_valid_number, '埼玉県和光市中央');
ok($zip->set_number('3510114')->is_valid_number, '埼玉県和光市本町');
ok($zip->set_number('3510115')->is_valid_number, '埼玉県和光市新倉');
ok($zip->set_number('3510116')->is_valid_number, '埼玉県和光市松ノ木島町');
ok($zip->set_number('3520000')->is_valid_number, '埼玉県新座市以下に掲載がない場合');
ok($zip->set_number('3520001')->is_valid_number, '埼玉県新座市東北');
ok($zip->set_number('3520002')->is_valid_number, '埼玉県新座市東');
ok($zip->set_number('3520003')->is_valid_number, '埼玉県新座市北野');
ok($zip->set_number('3520004')->is_valid_number, '埼玉県新座市大和田');
ok($zip->set_number('3520005')->is_valid_number, '埼玉県新座市中野');
ok($zip->set_number('3520006')->is_valid_number, '埼玉県新座市新座');
ok($zip->set_number('3520011')->is_valid_number, '埼玉県新座市野火止');
ok($zip->set_number('3520012')->is_valid_number, '埼玉県新座市畑中');
ok($zip->set_number('3520013')->is_valid_number, '埼玉県新座市新塚');
ok($zip->set_number('3520014')->is_valid_number, '埼玉県新座市栄');
ok($zip->set_number('3520015')->is_valid_number, '埼玉県新座市池田');
ok($zip->set_number('3520016')->is_valid_number, '埼玉県新座市馬場');
ok($zip->set_number('3520017')->is_valid_number, '埼玉県新座市菅沢');
ok($zip->set_number('3520021')->is_valid_number, '埼玉県新座市あたご');
ok($zip->set_number('3520022')->is_valid_number, '埼玉県新座市本多');
ok($zip->set_number('3520023')->is_valid_number, '埼玉県新座市堀ノ内');
ok($zip->set_number('3520024')->is_valid_number, '埼玉県新座市道場');
ok($zip->set_number('3520025')->is_valid_number, '埼玉県新座市片山');
ok($zip->set_number('3520031')->is_valid_number, '埼玉県新座市西堀');
ok($zip->set_number('3520032')->is_valid_number, '埼玉県新座市新堀');
ok($zip->set_number('3520033')->is_valid_number, '埼玉県新座市石神');
ok($zip->set_number('3520034')->is_valid_number, '埼玉県新座市野寺');
ok($zip->set_number('3520035')->is_valid_number, '埼玉県新座市栗原');
ok($zip->set_number('3530000')->is_valid_number, '埼玉県志木市以下に掲載がない場合');
ok($zip->set_number('3530001')->is_valid_number, '埼玉県志木市上宗岡');
ok($zip->set_number('3530002')->is_valid_number, '埼玉県志木市中宗岡');
ok($zip->set_number('3530003')->is_valid_number, '埼玉県志木市下宗岡');
ok($zip->set_number('3530004')->is_valid_number, '埼玉県志木市本町');
ok($zip->set_number('3530005')->is_valid_number, '埼玉県志木市幸町');
ok($zip->set_number('3530006')->is_valid_number, '埼玉県志木市館');
ok($zip->set_number('3530007')->is_valid_number, '埼玉県志木市柏町');
ok($zip->set_number('3530008')->is_valid_number, '埼玉県志木市宗岡');
ok($zip->set_number('3540000')->is_valid_number, '埼玉県富士見市以下に掲載がない場合');
ok($zip->set_number('3540000')->is_valid_number, '埼玉県入間郡三芳町以下に掲載がない場合');
ok($zip->set_number('3540001')->is_valid_number, '埼玉県富士見市東大久保');
ok($zip->set_number('3540002')->is_valid_number, '埼玉県富士見市上南畑');
ok($zip->set_number('3540003')->is_valid_number, '埼玉県富士見市南畑新田');
ok($zip->set_number('3540004')->is_valid_number, '埼玉県富士見市下南畑');
ok($zip->set_number('3540005')->is_valid_number, '埼玉県富士見市みどり野北');
ok($zip->set_number('3540006')->is_valid_number, '埼玉県富士見市みどり野東');
ok($zip->set_number('3540007')->is_valid_number, '埼玉県富士見市みどり野南');
ok($zip->set_number('3540008')->is_valid_number, '埼玉県富士見市みどり野西');
ok($zip->set_number('3540011')->is_valid_number, '埼玉県富士見市水子');
ok($zip->set_number('3540012')->is_valid_number, '埼玉県富士見市貝塚');
ok($zip->set_number('3540013')->is_valid_number, '埼玉県富士見市水谷東');
ok($zip->set_number('3540014')->is_valid_number, '埼玉県富士見市水谷');
ok($zip->set_number('3540015')->is_valid_number, '埼玉県富士見市東みずほ台');
ok($zip->set_number('3540016')->is_valid_number, '埼玉県富士見市榎町');
ok($zip->set_number('3540017')->is_valid_number, '埼玉県富士見市針ケ谷');
ok($zip->set_number('3540018')->is_valid_number, '埼玉県富士見市西みずほ台');
ok($zip->set_number('3540021')->is_valid_number, '埼玉県富士見市鶴馬');
ok($zip->set_number('3540022')->is_valid_number, '埼玉県富士見市山室');
ok($zip->set_number('3540023')->is_valid_number, '埼玉県富士見市諏訪');
ok($zip->set_number('3540024')->is_valid_number, '埼玉県富士見市鶴瀬東');
ok($zip->set_number('3540025')->is_valid_number, '埼玉県富士見市関沢');
ok($zip->set_number('3540026')->is_valid_number, '埼玉県富士見市鶴瀬西');
ok($zip->set_number('3540031')->is_valid_number, '埼玉県富士見市勝瀬');
ok($zip->set_number('3540032')->is_valid_number, '埼玉県富士見市渡戸');
ok($zip->set_number('3540033')->is_valid_number, '埼玉県富士見市羽沢');
ok($zip->set_number('3540034')->is_valid_number, '埼玉県富士見市上沢');
ok($zip->set_number('3540035')->is_valid_number, '埼玉県富士見市ふじみ野西');
ok($zip->set_number('3540036')->is_valid_number, '埼玉県富士見市ふじみ野東');
ok($zip->set_number('3540041')->is_valid_number, '埼玉県入間郡三芳町藤久保');
ok($zip->set_number('3540042')->is_valid_number, '埼玉県入間郡三芳町みよし台');
ok($zip->set_number('3540043')->is_valid_number, '埼玉県入間郡三芳町竹間沢');
ok($zip->set_number('3540044')->is_valid_number, '埼玉県入間郡三芳町北永井');
ok($zip->set_number('3540045')->is_valid_number, '埼玉県入間郡三芳町上富');
ok($zip->set_number('3540046')->is_valid_number, '埼玉県入間郡三芳町竹間沢東');
ok($zip->set_number('3550000')->is_valid_number, '埼玉県東松山市以下に掲載がない場合');
ok($zip->set_number('3550001')->is_valid_number, '埼玉県東松山市岡');
ok($zip->set_number('3550002')->is_valid_number, '埼玉県東松山市東平');
ok($zip->set_number('3550003')->is_valid_number, '埼玉県東松山市殿山町');
ok($zip->set_number('3550004')->is_valid_number, '埼玉県東松山市沢口町');
ok($zip->set_number('3550005')->is_valid_number, '埼玉県東松山市松山');
ok($zip->set_number('3550006')->is_valid_number, '埼玉県東松山市市ノ川');
ok($zip->set_number('3550007')->is_valid_number, '埼玉県東松山市野田');
ok($zip->set_number('3550008')->is_valid_number, '埼玉県東松山市大谷');
ok($zip->set_number('3550009')->is_valid_number, '埼玉県東松山市仲田町');
ok($zip->set_number('3550010')->is_valid_number, '埼玉県東松山市美原町');
ok($zip->set_number('3550011')->is_valid_number, '埼玉県東松山市加美町');
ok($zip->set_number('3550012')->is_valid_number, '埼玉県東松山市日吉町');
ok($zip->set_number('3550013')->is_valid_number, '埼玉県東松山市小松原町');
ok($zip->set_number('3550014')->is_valid_number, '埼玉県東松山市松本町');
ok($zip->set_number('3550015')->is_valid_number, '埼玉県東松山市本町');
ok($zip->set_number('3550016')->is_valid_number, '埼玉県東松山市材木町');
ok($zip->set_number('3550017')->is_valid_number, '埼玉県東松山市松葉町');
ok($zip->set_number('3550018')->is_valid_number, '埼玉県東松山市松山町');
ok($zip->set_number('3550019')->is_valid_number, '埼玉県東松山市砂田町');
ok($zip->set_number('3550021')->is_valid_number, '埼玉県東松山市神明町');
ok($zip->set_number('3550022')->is_valid_number, '埼玉県東松山市御茶山町');
ok($zip->set_number('3550023')->is_valid_number, '埼玉県東松山市六反町');
ok($zip->set_number('3550024')->is_valid_number, '埼玉県東松山市六軒町');
ok($zip->set_number('3550025')->is_valid_number, '埼玉県東松山市幸町');
ok($zip->set_number('3550026')->is_valid_number, '埼玉県東松山市和泉町');
ok($zip->set_number('3550027')->is_valid_number, '埼玉県東松山市美土里町');
ok($zip->set_number('3550028')->is_valid_number, '埼玉県東松山市箭弓町');
ok($zip->set_number('3550031')->is_valid_number, '埼玉県東松山市五領町');
ok($zip->set_number('3550032')->is_valid_number, '埼玉県東松山市新宿町');
ok($zip->set_number('3550033')->is_valid_number, '埼玉県東松山市山崎町');
ok($zip->set_number('3550034')->is_valid_number, '埼玉県東松山市柏崎');
ok($zip->set_number('3550035')->is_valid_number, '埼玉県東松山市古凍');
ok($zip->set_number('3550036')->is_valid_number, '埼玉県東松山市下野本');
ok($zip->set_number('3550037')->is_valid_number, '埼玉県東松山市若松町');
ok($zip->set_number('3550041')->is_valid_number, '埼玉県東松山市下押垂');
ok($zip->set_number('3550042')->is_valid_number, '埼玉県東松山市今泉');
ok($zip->set_number('3550043')->is_valid_number, '埼玉県東松山市早俣');
ok($zip->set_number('3550044')->is_valid_number, '埼玉県東松山市正代');
ok($zip->set_number('3550045')->is_valid_number, '埼玉県東松山市宮鼻');
ok($zip->set_number('3550046')->is_valid_number, '埼玉県東松山市大黒部');
ok($zip->set_number('3550047')->is_valid_number, '埼玉県東松山市高坂');
ok($zip->set_number('3550048')->is_valid_number, '埼玉県東松山市あずま町');
ok($zip->set_number('3550051')->is_valid_number, '埼玉県東松山市白山台');
ok($zip->set_number('3550052')->is_valid_number, '埼玉県東松山市桜山台');
ok($zip->set_number('3550053')->is_valid_number, '埼玉県東松山市田木');
ok($zip->set_number('3550054')->is_valid_number, '埼玉県東松山市旗立台');
ok($zip->set_number('3550055')->is_valid_number, '埼玉県東松山市松風台');
ok($zip->set_number('3550061')->is_valid_number, '埼玉県東松山市葛袋');
ok($zip->set_number('3550062')->is_valid_number, '埼玉県東松山市西本宿');
ok($zip->set_number('3550063')->is_valid_number, '埼玉県東松山市元宿');
ok($zip->set_number('3550064')->is_valid_number, '埼玉県東松山市毛塚');
ok($zip->set_number('3550065')->is_valid_number, '埼玉県東松山市岩殿');
ok($zip->set_number('3550066')->is_valid_number, '埼玉県東松山市神戸');
ok($zip->set_number('3550067')->is_valid_number, '埼玉県東松山市坂東山');
ok($zip->set_number('3550071')->is_valid_number, '埼玉県東松山市新郷');
ok($zip->set_number('3550072')->is_valid_number, '埼玉県東松山市石橋');
ok($zip->set_number('3550073')->is_valid_number, '埼玉県東松山市上野本');
ok($zip->set_number('3550074')->is_valid_number, '埼玉県東松山市上押垂');
ok($zip->set_number('3550075')->is_valid_number, '埼玉県東松山市下青鳥');
ok($zip->set_number('3550076')->is_valid_number, '埼玉県東松山市下唐子');
ok($zip->set_number('3550077')->is_valid_number, '埼玉県東松山市上唐子');
ok($zip->set_number('3550100')->is_valid_number, '埼玉県比企郡吉見町以下に掲載がない場合');
ok($zip->set_number('3550101')->is_valid_number, '埼玉県比企郡吉見町一ツ木');
ok($zip->set_number('3550102')->is_valid_number, '埼玉県比企郡吉見町明秋');
ok($zip->set_number('3550103')->is_valid_number, '埼玉県比企郡吉見町今泉');
ok($zip->set_number('3550104')->is_valid_number, '埼玉県比企郡吉見町地頭方');
ok($zip->set_number('3550105')->is_valid_number, '埼玉県比企郡吉見町上砂');
ok($zip->set_number('3550106')->is_valid_number, '埼玉県比企郡吉見町中曽根');
ok($zip->set_number('3550110')->is_valid_number, '埼玉県比企郡吉見町東野');
ok($zip->set_number('3550111')->is_valid_number, '埼玉県比企郡吉見町北下砂');
ok($zip->set_number('3550112')->is_valid_number, '埼玉県比企郡吉見町丸貫');
ok($zip->set_number('3550113')->is_valid_number, '埼玉県比企郡吉見町古名新田');
ok($zip->set_number('3550114')->is_valid_number, '埼玉県比企郡吉見町古名');
ok($zip->set_number('3550115')->is_valid_number, '埼玉県比企郡吉見町上銀谷');
ok($zip->set_number('3550116')->is_valid_number, '埼玉県比企郡吉見町下銀谷');
ok($zip->set_number('3550117')->is_valid_number, '埼玉県比企郡吉見町谷口');
ok($zip->set_number('3550118')->is_valid_number, '埼玉県比企郡吉見町下細谷');
ok($zip->set_number('3550119')->is_valid_number, '埼玉県比企郡吉見町中新井');
ok($zip->set_number('3550121')->is_valid_number, '埼玉県比企郡吉見町蓮沼新田');
ok($zip->set_number('3550122')->is_valid_number, '埼玉県比企郡吉見町高尾新田');
ok($zip->set_number('3550123')->is_valid_number, '埼玉県比企郡吉見町須ノ子新田');
ok($zip->set_number('3550124')->is_valid_number, '埼玉県比企郡吉見町久保田新田');
ok($zip->set_number('3550125')->is_valid_number, '埼玉県比企郡吉見町蚊斗谷');
ok($zip->set_number('3550126')->is_valid_number, '埼玉県比企郡吉見町万光寺');
ok($zip->set_number('3550127')->is_valid_number, '埼玉県比企郡吉見町大和田');
ok($zip->set_number('3550131')->is_valid_number, '埼玉県比企郡吉見町荒子');
ok($zip->set_number('3550132')->is_valid_number, '埼玉県比企郡吉見町飯島新田');
ok($zip->set_number('3550133')->is_valid_number, '埼玉県比企郡吉見町江和井');
ok($zip->set_number('3550134')->is_valid_number, '埼玉県比企郡吉見町大串');
ok($zip->set_number('3550135')->is_valid_number, '埼玉県比企郡吉見町前河内');
ok($zip->set_number('3550136')->is_valid_number, '埼玉県比企郡吉見町江綱');
ok($zip->set_number('3550137')->is_valid_number, '埼玉県比企郡吉見町久保田');
ok($zip->set_number('3550151')->is_valid_number, '埼玉県比企郡吉見町御所');
ok($zip->set_number('3550152')->is_valid_number, '埼玉県比企郡吉見町和名');
ok($zip->set_number('3550153')->is_valid_number, '埼玉県比企郡吉見町久米田');
ok($zip->set_number('3550154')->is_valid_number, '埼玉県比企郡吉見町南吉見');
ok($zip->set_number('3550155')->is_valid_number, '埼玉県比企郡吉見町北吉見');
ok($zip->set_number('3550156')->is_valid_number, '埼玉県比企郡吉見町長谷');
ok($zip->set_number('3550157')->is_valid_number, '埼玉県比企郡吉見町西吉見');
ok($zip->set_number('3550161')->is_valid_number, '埼玉県比企郡吉見町山ノ下');
ok($zip->set_number('3550162')->is_valid_number, '埼玉県比企郡吉見町松崎');
ok($zip->set_number('3550163')->is_valid_number, '埼玉県比企郡吉見町本沢');
ok($zip->set_number('3550164')->is_valid_number, '埼玉県比企郡吉見町小新井');
ok($zip->set_number('3550165')->is_valid_number, '埼玉県比企郡吉見町上細谷');
ok($zip->set_number('3550166')->is_valid_number, '埼玉県比企郡吉見町黒岩');
ok($zip->set_number('3550167')->is_valid_number, '埼玉県比企郡吉見町田甲');
ok($zip->set_number('3550200')->is_valid_number, '埼玉県比企郡嵐山町以下に掲載がない場合');
ok($zip->set_number('3550201')->is_valid_number, '埼玉県比企郡嵐山町古里');
ok($zip->set_number('3550202')->is_valid_number, '埼玉県比企郡嵐山町吉田');
ok($zip->set_number('3550203')->is_valid_number, '埼玉県比企郡嵐山町勝田');
ok($zip->set_number('3550204')->is_valid_number, '埼玉県比企郡嵐山町花見台');
ok($zip->set_number('3550205')->is_valid_number, '埼玉県比企郡嵐山町広野');
ok($zip->set_number('3550206')->is_valid_number, '埼玉県比企郡嵐山町越畑');
ok($zip->set_number('3550211')->is_valid_number, '埼玉県比企郡嵐山町杉山');
ok($zip->set_number('3550212')->is_valid_number, '埼玉県比企郡嵐山町太郎丸');
ok($zip->set_number('3550213')->is_valid_number, '埼玉県比企郡嵐山町川島');
ok($zip->set_number('3550214')->is_valid_number, '埼玉県比企郡嵐山町志賀');
ok($zip->set_number('3550215')->is_valid_number, '埼玉県比企郡嵐山町平沢');
ok($zip->set_number('3550216')->is_valid_number, '埼玉県比企郡嵐山町むさし台');
ok($zip->set_number('3550221')->is_valid_number, '埼玉県比企郡嵐山町菅谷');
ok($zip->set_number('3550222')->is_valid_number, '埼玉県比企郡嵐山町大蔵');
ok($zip->set_number('3550223')->is_valid_number, '埼玉県比企郡嵐山町根岸');
ok($zip->set_number('3550224')->is_valid_number, '埼玉県比企郡嵐山町将軍沢');
ok($zip->set_number('3550225')->is_valid_number, '埼玉県比企郡嵐山町鎌形');
ok($zip->set_number('3550226')->is_valid_number, '埼玉県比企郡嵐山町遠山');
ok($zip->set_number('3550227')->is_valid_number, '埼玉県比企郡嵐山町千手堂');
ok($zip->set_number('3550300')->is_valid_number, '埼玉県比企郡小川町以下に掲載がない場合');
ok($zip->set_number('3550300')->is_valid_number, '埼玉県比企郡ときがわ町以下に掲載がない場合');
ok($zip->set_number('3550300')->is_valid_number, '埼玉県秩父郡東秩父村以下に掲載がない場合');
ok($zip->set_number('3550301')->is_valid_number, '埼玉県比企郡小川町西古里');
ok($zip->set_number('3550302')->is_valid_number, '埼玉県比企郡小川町鷹巣');
ok($zip->set_number('3550303')->is_valid_number, '埼玉県比企郡小川町奈良梨');
ok($zip->set_number('3550304')->is_valid_number, '埼玉県比企郡小川町伊勢根');
ok($zip->set_number('3550305')->is_valid_number, '埼玉県比企郡小川町能増');
ok($zip->set_number('3550306')->is_valid_number, '埼玉県比企郡小川町高見');
ok($zip->set_number('3550311')->is_valid_number, '埼玉県比企郡小川町高谷');
ok($zip->set_number('3550312')->is_valid_number, '埼玉県比企郡小川町上横田');
ok($zip->set_number('3550313')->is_valid_number, '埼玉県比企郡小川町下横田');
ok($zip->set_number('3550314')->is_valid_number, '埼玉県比企郡小川町中爪');
ok($zip->set_number('3550315')->is_valid_number, '埼玉県比企郡小川町みどりが丘');
ok($zip->set_number('3550316')->is_valid_number, '埼玉県比企郡小川町角山');
ok($zip->set_number('3550317')->is_valid_number, '埼玉県比企郡小川町原川');
ok($zip->set_number('3550318')->is_valid_number, '埼玉県比企郡小川町ひばり台');
ok($zip->set_number('3550321')->is_valid_number, '埼玉県比企郡小川町小川');
ok($zip->set_number('3550322')->is_valid_number, '埼玉県比企郡小川町東小川');
ok($zip->set_number('3550323')->is_valid_number, '埼玉県比企郡小川町下里');
ok($zip->set_number('3550324')->is_valid_number, '埼玉県比企郡小川町青山');
ok($zip->set_number('3550325')->is_valid_number, '埼玉県比企郡小川町上古寺');
ok($zip->set_number('3550326')->is_valid_number, '埼玉県比企郡小川町下古寺');
ok($zip->set_number('3550327')->is_valid_number, '埼玉県比企郡小川町腰越');
ok($zip->set_number('3550328')->is_valid_number, '埼玉県比企郡小川町大塚');
ok($zip->set_number('3550331')->is_valid_number, '埼玉県比企郡小川町靱負');
ok($zip->set_number('3550332')->is_valid_number, '埼玉県比企郡小川町増尾');
ok($zip->set_number('3550333')->is_valid_number, '埼玉県比企郡小川町飯田');
ok($zip->set_number('3550334')->is_valid_number, '埼玉県比企郡小川町笠原');
ok($zip->set_number('3550335')->is_valid_number, '埼玉県比企郡小川町木部');
ok($zip->set_number('3550336')->is_valid_number, '埼玉県比企郡小川町勝呂');
ok($zip->set_number('3550337')->is_valid_number, '埼玉県比企郡小川町木呂子');
ok($zip->set_number('3550341')->is_valid_number, '埼玉県比企郡ときがわ町田黒');
ok($zip->set_number('3550342')->is_valid_number, '埼玉県比企郡ときがわ町玉川');
ok($zip->set_number('3550343')->is_valid_number, '埼玉県比企郡ときがわ町五明');
ok($zip->set_number('3550344')->is_valid_number, '埼玉県比企郡ときがわ町日影');
ok($zip->set_number('3550351')->is_valid_number, '埼玉県比企郡ときがわ町雲河原');
ok($zip->set_number('3550352')->is_valid_number, '埼玉県比企郡ときがわ町別所');
ok($zip->set_number('3550353')->is_valid_number, '埼玉県比企郡ときがわ町本郷');
ok($zip->set_number('3550354')->is_valid_number, '埼玉県比企郡ときがわ町番匠');
ok($zip->set_number('3550355')->is_valid_number, '埼玉県比企郡ときがわ町馬場');
ok($zip->set_number('3550356')->is_valid_number, '埼玉県比企郡ときがわ町関堀');
ok($zip->set_number('3550357')->is_valid_number, '埼玉県比企郡ときがわ町田中');
ok($zip->set_number('3550358')->is_valid_number, '埼玉県比企郡ときがわ町瀬戸元上');
ok($zip->set_number('3550359')->is_valid_number, '埼玉県比企郡ときがわ町瀬戸元下');
ok($zip->set_number('3550361')->is_valid_number, '埼玉県比企郡ときがわ町桃木');
ok($zip->set_number('3550363')->is_valid_number, '埼玉県比企郡ときがわ町大附');
ok($zip->set_number('3550364')->is_valid_number, '埼玉県比企郡ときがわ町西平');
ok($zip->set_number('3550365')->is_valid_number, '埼玉県比企郡ときがわ町椚平');
ok($zip->set_number('3550366')->is_valid_number, '埼玉県比企郡ときがわ町大野');
ok($zip->set_number('3550371')->is_valid_number, '埼玉県秩父郡東秩父村大内沢');
ok($zip->set_number('3550372')->is_valid_number, '埼玉県秩父郡東秩父村坂本');
ok($zip->set_number('3550373')->is_valid_number, '埼玉県秩父郡東秩父村奥沢');
ok($zip->set_number('3550374')->is_valid_number, '埼玉県秩父郡東秩父村安戸');
ok($zip->set_number('3550375')->is_valid_number, '埼玉県秩父郡東秩父村御堂');
ok($zip->set_number('3550376')->is_valid_number, '埼玉県秩父郡東秩父村皆谷');
ok($zip->set_number('3550377')->is_valid_number, '埼玉県秩父郡東秩父村白石');
ok($zip->set_number('3550800')->is_valid_number, '埼玉県比企郡滑川町以下に掲載がない場合');
ok($zip->set_number('3550801')->is_valid_number, '埼玉県比企郡滑川町土塩');
ok($zip->set_number('3550802')->is_valid_number, '埼玉県比企郡滑川町山田');
ok($zip->set_number('3550803')->is_valid_number, '埼玉県比企郡滑川町福田');
ok($zip->set_number('3550804')->is_valid_number, '埼玉県比企郡滑川町中尾');
ok($zip->set_number('3550805')->is_valid_number, '埼玉県比企郡滑川町水房');
ok($zip->set_number('3550806')->is_valid_number, '埼玉県比企郡滑川町伊古');
ok($zip->set_number('3550807')->is_valid_number, '埼玉県比企郡滑川町和泉');
ok($zip->set_number('3550808')->is_valid_number, '埼玉県比企郡滑川町菅田');
ok($zip->set_number('3550811')->is_valid_number, '埼玉県比企郡滑川町羽尾');
ok($zip->set_number('3550812')->is_valid_number, '埼玉県比企郡滑川町都');
ok($zip->set_number('3550813')->is_valid_number, '埼玉県比企郡滑川町月輪');
ok($zip->set_number('3550814')->is_valid_number, '埼玉県比企郡滑川町みなみ野');
ok($zip->set_number('3550815')->is_valid_number, '埼玉県比企郡滑川町月の輪');
ok($zip->set_number('3560000')->is_valid_number, '埼玉県ふじみ野市以下に掲載がない場合');
ok($zip->set_number('3560001')->is_valid_number, '埼玉県ふじみ野市川崎');
ok($zip->set_number('3560002')->is_valid_number, '埼玉県ふじみ野市清見');
ok($zip->set_number('3560003')->is_valid_number, '埼玉県ふじみ野市大原');
ok($zip->set_number('3560004')->is_valid_number, '埼玉県ふじみ野市上福岡');
ok($zip->set_number('3560005')->is_valid_number, '埼玉県ふじみ野市西');
ok($zip->set_number('3560006')->is_valid_number, '埼玉県ふじみ野市霞ケ丘');
ok($zip->set_number('3560007')->is_valid_number, '埼玉県ふじみ野市北野');
ok($zip->set_number('3560008')->is_valid_number, '埼玉県ふじみ野市元福岡');
ok($zip->set_number('3560011')->is_valid_number, '埼玉県ふじみ野市福岡');
ok($zip->set_number('3560012')->is_valid_number, '埼玉県ふじみ野市滝');
ok($zip->set_number('3560013')->is_valid_number, '埼玉県ふじみ野市中福岡');
ok($zip->set_number('3560014')->is_valid_number, '埼玉県ふじみ野市福岡新田');
ok($zip->set_number('3560015')->is_valid_number, '埼玉県ふじみ野市花ノ木');
ok($zip->set_number('3560016')->is_valid_number, '埼玉県ふじみ野市中丸');
ok($zip->set_number('3560017')->is_valid_number, '埼玉県ふじみ野市上野台');
ok($zip->set_number('3560018')->is_valid_number, '埼玉県ふじみ野市本新田');
ok($zip->set_number('3560019')->is_valid_number, '埼玉県ふじみ野市池上');
ok($zip->set_number('3560020')->is_valid_number, '埼玉県ふじみ野市水宮');
ok($zip->set_number('3560021')->is_valid_number, '埼玉県ふじみ野市上ノ原');
ok($zip->set_number('3560022')->is_valid_number, '埼玉県ふじみ野市長宮');
ok($zip->set_number('3560023')->is_valid_number, '埼玉県ふじみ野市中ノ島');
ok($zip->set_number('3560024')->is_valid_number, '埼玉県ふじみ野市谷田');
ok($zip->set_number('3560025')->is_valid_number, '埼玉県ふじみ野市仲');
ok($zip->set_number('3560026')->is_valid_number, '埼玉県ふじみ野市築地');
ok($zip->set_number('3560027')->is_valid_number, '埼玉県ふじみ野市松山');
ok($zip->set_number('3560028')->is_valid_number, '埼玉県ふじみ野市西原');
ok($zip->set_number('3560029')->is_valid_number, '埼玉県ふじみ野市駒西');
ok($zip->set_number('3560030')->is_valid_number, '埼玉県ふじみ野市新駒林');
ok($zip->set_number('3560031')->is_valid_number, '埼玉県ふじみ野市福岡中央');
ok($zip->set_number('3560032')->is_valid_number, '埼玉県ふじみ野市富士見台');
ok($zip->set_number('3560033')->is_valid_number, '埼玉県ふじみ野市新田');
ok($zip->set_number('3560034')->is_valid_number, '埼玉県ふじみ野市駒林');
ok($zip->set_number('3560035')->is_valid_number, '埼玉県ふじみ野市丸山');
ok($zip->set_number('3560036')->is_valid_number, '埼玉県ふじみ野市南台');
ok($zip->set_number('3560037')->is_valid_number, '埼玉県ふじみ野市福岡武蔵野');
ok($zip->set_number('3560038')->is_valid_number, '埼玉県ふじみ野市駒林元町');
ok($zip->set_number('3560041')->is_valid_number, '埼玉県ふじみ野市鶴ケ舞');
ok($zip->set_number('3560042')->is_valid_number, '埼玉県ふじみ野市東久保');
ok($zip->set_number('3560043')->is_valid_number, '埼玉県ふじみ野市緑ケ丘');
ok($zip->set_number('3560044')->is_valid_number, '埼玉県ふじみ野市西鶴ケ岡');
ok($zip->set_number('3560045')->is_valid_number, '埼玉県ふじみ野市鶴ケ岡');
ok($zip->set_number('3560050')->is_valid_number, '埼玉県ふじみ野市ふじみ野');
ok($zip->set_number('3560051')->is_valid_number, '埼玉県ふじみ野市亀久保');
ok($zip->set_number('3560052')->is_valid_number, '埼玉県ふじみ野市苗間');
ok($zip->set_number('3560053')->is_valid_number, '埼玉県ふじみ野市大井');
ok($zip->set_number('3560054')->is_valid_number, '埼玉県ふじみ野市大井武蔵野');
ok($zip->set_number('3560055')->is_valid_number, '埼玉県ふじみ野市旭');
ok($zip->set_number('3560056')->is_valid_number, '埼玉県ふじみ野市うれし野');
ok($zip->set_number('3560057')->is_valid_number, '埼玉県ふじみ野市市沢');
ok($zip->set_number('3560058')->is_valid_number, '埼玉県ふじみ野市大井中央');
ok($zip->set_number('3560059')->is_valid_number, '埼玉県ふじみ野市桜ケ丘');
ok($zip->set_number('3570000')->is_valid_number, '埼玉県飯能市以下に掲載がない場合');
ok($zip->set_number('3570001')->is_valid_number, '埼玉県飯能市宮沢');
ok($zip->set_number('3570002')->is_valid_number, '埼玉県飯能市中居');
ok($zip->set_number('3570003')->is_valid_number, '埼玉県飯能市青木');
ok($zip->set_number('3570004')->is_valid_number, '埼玉県飯能市新町');
ok($zip->set_number('3570005')->is_valid_number, '埼玉県飯能市原町');
ok($zip->set_number('3570006')->is_valid_number, '埼玉県飯能市中山');
ok($zip->set_number('3570011')->is_valid_number, '埼玉県飯能市川崎');
ok($zip->set_number('3570012')->is_valid_number, '埼玉県飯能市下川崎');
ok($zip->set_number('3570013')->is_valid_number, '埼玉県飯能市芦苅場');
ok($zip->set_number('3570014')->is_valid_number, '埼玉県飯能市平松');
ok($zip->set_number('3570015')->is_valid_number, '埼玉県飯能市小久保');
ok($zip->set_number('3570016')->is_valid_number, '埼玉県飯能市下加治');
ok($zip->set_number('3570021')->is_valid_number, '埼玉県飯能市双柳');
ok($zip->set_number('3570022')->is_valid_number, '埼玉県飯能市新光');
ok($zip->set_number('3570023')->is_valid_number, '埼玉県飯能市岩沢');
ok($zip->set_number('3570024')->is_valid_number, '埼玉県飯能市緑町');
ok($zip->set_number('3570025')->is_valid_number, '埼玉県飯能市栄町');
ok($zip->set_number('3570031')->is_valid_number, '埼玉県飯能市山手町');
ok($zip->set_number('3570032')->is_valid_number, '埼玉県飯能市本町');
ok($zip->set_number('3570033')->is_valid_number, '埼玉県飯能市八幡町');
ok($zip->set_number('3570034')->is_valid_number, '埼玉県飯能市東町');
ok($zip->set_number('3570035')->is_valid_number, '埼玉県飯能市柳町');
ok($zip->set_number('3570036')->is_valid_number, '埼玉県飯能市南町');
ok($zip->set_number('3570037')->is_valid_number, '埼玉県飯能市稲荷町');
ok($zip->set_number('3570038')->is_valid_number, '埼玉県飯能市仲町');
ok($zip->set_number('3570041')->is_valid_number, '埼玉県飯能市美杉台');
ok($zip->set_number('3570042')->is_valid_number, '埼玉県飯能市矢颪');
ok($zip->set_number('3570043')->is_valid_number, '埼玉県飯能市前ケ貫');
ok($zip->set_number('3570044')->is_valid_number, '埼玉県飯能市川寺');
ok($zip->set_number('3570045')->is_valid_number, '埼玉県飯能市笠縫');
ok($zip->set_number('3570046')->is_valid_number, '埼玉県飯能市阿須');
ok($zip->set_number('3570047')->is_valid_number, '埼玉県飯能市落合');
ok($zip->set_number('3570048')->is_valid_number, '埼玉県飯能市岩渕');
ok($zip->set_number('3570049')->is_valid_number, '埼玉県飯能市征矢町');
ok($zip->set_number('3570051')->is_valid_number, '埼玉県飯能市苅生');
ok($zip->set_number('3570052')->is_valid_number, '埼玉県飯能市下畑');
ok($zip->set_number('3570053')->is_valid_number, '埼玉県飯能市上畑');
ok($zip->set_number('3570054')->is_valid_number, '埼玉県飯能市下直竹');
ok($zip->set_number('3570055')->is_valid_number, '埼玉県飯能市上直竹下分');
ok($zip->set_number('3570056')->is_valid_number, '埼玉県飯能市上直竹上分');
ok($zip->set_number('3570061')->is_valid_number, '埼玉県飯能市永田台');
ok($zip->set_number('3570062')->is_valid_number, '埼玉県飯能市永田');
ok($zip->set_number('3570063')->is_valid_number, '埼玉県飯能市飯能');
ok($zip->set_number('3570064')->is_valid_number, '埼玉県飯能市久下');
ok($zip->set_number('3570065')->is_valid_number, '埼玉県飯能市大河原');
ok($zip->set_number('3570066')->is_valid_number, '埼玉県飯能市小岩井');
ok($zip->set_number('3570067')->is_valid_number, '埼玉県飯能市小瀬戸');
ok($zip->set_number('3570068')->is_valid_number, '埼玉県飯能市久須美');
ok($zip->set_number('3570069')->is_valid_number, '埼玉県飯能市茜台');
ok($zip->set_number('3570111')->is_valid_number, '埼玉県飯能市上名栗');
ok($zip->set_number('3570112')->is_valid_number, '埼玉県飯能市下名栗');
ok($zip->set_number('3570121')->is_valid_number, '埼玉県飯能市中藤上郷');
ok($zip->set_number('3570122')->is_valid_number, '埼玉県飯能市中藤中郷');
ok($zip->set_number('3570123')->is_valid_number, '埼玉県飯能市中藤下郷');
ok($zip->set_number('3570124')->is_valid_number, '埼玉県飯能市原市場');
ok($zip->set_number('3570125')->is_valid_number, '埼玉県飯能市上赤工');
ok($zip->set_number('3570126')->is_valid_number, '埼玉県飯能市下赤工');
ok($zip->set_number('3570127')->is_valid_number, '埼玉県飯能市唐竹');
ok($zip->set_number('3570128')->is_valid_number, '埼玉県飯能市赤沢');
ok($zip->set_number('3570201')->is_valid_number, '埼玉県飯能市北川');
ok($zip->set_number('3570202')->is_valid_number, '埼玉県飯能市高山');
ok($zip->set_number('3570203')->is_valid_number, '埼玉県飯能市長沢');
ok($zip->set_number('3570204')->is_valid_number, '埼玉県飯能市虎秀');
ok($zip->set_number('3570205')->is_valid_number, '埼玉県飯能市白子');
ok($zip->set_number('3570206')->is_valid_number, '埼玉県飯能市上長沢');
ok($zip->set_number('3570211')->is_valid_number, '埼玉県飯能市平戸');
ok($zip->set_number('3570212')->is_valid_number, '埼玉県飯能市井上');
ok($zip->set_number('3570213')->is_valid_number, '埼玉県飯能市坂石町分');
ok($zip->set_number('3570214')->is_valid_number, '埼玉県飯能市南');
ok($zip->set_number('3570215')->is_valid_number, '埼玉県飯能市坂石');
ok($zip->set_number('3570216')->is_valid_number, '埼玉県飯能市吾野');
ok($zip->set_number('3570217')->is_valid_number, '埼玉県飯能市南川');
ok($zip->set_number('3570218')->is_valid_number, '埼玉県飯能市坂元');
ok($zip->set_number('3580000')->is_valid_number, '埼玉県入間市以下に掲載がない場合');
ok($zip->set_number('3580001')->is_valid_number, '埼玉県入間市向陽台');
ok($zip->set_number('3580002')->is_valid_number, '埼玉県入間市東町');
ok($zip->set_number('3580003')->is_valid_number, '埼玉県入間市豊岡');
ok($zip->set_number('3580004')->is_valid_number, '埼玉県入間市鍵山');
ok($zip->set_number('3580005')->is_valid_number, '埼玉県入間市宮前町');
ok($zip->set_number('3580006')->is_valid_number, '埼玉県入間市春日町');
ok($zip->set_number('3580007')->is_valid_number, '埼玉県入間市黒須');
ok($zip->set_number('3580008')->is_valid_number, '埼玉県入間市河原町');
ok($zip->set_number('3580011')->is_valid_number, '埼玉県入間市下藤沢');
ok($zip->set_number('3580012')->is_valid_number, '埼玉県入間市東藤沢');
ok($zip->set_number('3580013')->is_valid_number, '埼玉県入間市上藤沢');
ok($zip->set_number('3580014')->is_valid_number, '埼玉県入間市宮寺');
ok($zip->set_number('3580015')->is_valid_number, '埼玉県入間市二本木');
ok($zip->set_number('3580016')->is_valid_number, '埼玉県入間市高根');
ok($zip->set_number('3580017')->is_valid_number, '埼玉県入間市駒形富士山');
ok($zip->set_number('3580021')->is_valid_number, '埼玉県入間市高倉');
ok($zip->set_number('3580022')->is_valid_number, '埼玉県入間市扇町屋');
ok($zip->set_number('3580023')->is_valid_number, '埼玉県入間市扇台');
ok($zip->set_number('3580024')->is_valid_number, '埼玉県入間市久保稲荷');
ok($zip->set_number('3580025')->is_valid_number, '埼玉県入間市善蔵新田');
ok($zip->set_number('3580026')->is_valid_number, '埼玉県入間市小谷田');
ok($zip->set_number('3580027')->is_valid_number, '埼玉県入間市上小谷田');
ok($zip->set_number('3580031')->is_valid_number, '埼玉県入間市新久');
ok($zip->set_number('3580032')->is_valid_number, '埼玉県入間市狭山ケ原');
ok($zip->set_number('3580033')->is_valid_number, '埼玉県入間市狭山台');
ok($zip->set_number('3580034')->is_valid_number, '埼玉県入間市根岸');
ok($zip->set_number('3580035')->is_valid_number, '埼玉県入間市中神');
ok($zip->set_number('3580036')->is_valid_number, '埼玉県入間市花ノ木');
ok($zip->set_number('3580041')->is_valid_number, '埼玉県入間市下谷ケ貫');
ok($zip->set_number('3580042')->is_valid_number, '埼玉県入間市上谷ケ貫');
ok($zip->set_number('3580043')->is_valid_number, '埼玉県入間市西三ツ木');
ok($zip->set_number('3580044')->is_valid_number, '埼玉県入間市三ツ木台');
ok($zip->set_number('3580045')->is_valid_number, '埼玉県入間市寺竹');
ok($zip->set_number('3580046')->is_valid_number, '埼玉県入間市南峯');
ok($zip->set_number('3580047')->is_valid_number, '埼玉県入間市木蓮寺');
ok($zip->set_number('3580048')->is_valid_number, '埼玉県入間市金子中央');
ok($zip->set_number('3580051')->is_valid_number, '埼玉県入間市牛沢町');
ok($zip->set_number('3580052')->is_valid_number, '埼玉県入間市森坂');
ok($zip->set_number('3580053')->is_valid_number, '埼玉県入間市仏子');
ok($zip->set_number('3580054')->is_valid_number, '埼玉県入間市野田');
ok($zip->set_number('3580055')->is_valid_number, '埼玉県入間市新光');
ok($zip->set_number('3590000')->is_valid_number, '埼玉県所沢市以下に掲載がない場合');
ok($zip->set_number('3590001')->is_valid_number, '埼玉県所沢市下富');
ok($zip->set_number('3590002')->is_valid_number, '埼玉県所沢市中富');
ok($zip->set_number('3590003')->is_valid_number, '埼玉県所沢市中富南');
ok($zip->set_number('3590004')->is_valid_number, '埼玉県所沢市北原町');
ok($zip->set_number('3590005')->is_valid_number, '埼玉県所沢市神米金');
ok($zip->set_number('3590006')->is_valid_number, '埼玉県所沢市所沢新町');
ok($zip->set_number('3590007')->is_valid_number, '埼玉県所沢市北岩岡');
ok($zip->set_number('3590011')->is_valid_number, '埼玉県所沢市南永井');
ok($zip->set_number('3590012')->is_valid_number, '埼玉県所沢市坂之下');
ok($zip->set_number('3590013')->is_valid_number, '埼玉県所沢市城');
ok($zip->set_number('3590014')->is_valid_number, '埼玉県所沢市亀ケ谷');
ok($zip->set_number('3590015')->is_valid_number, '埼玉県所沢市日比田');
ok($zip->set_number('3590016')->is_valid_number, '埼玉県所沢市新郷');
ok($zip->set_number('3590021')->is_valid_number, '埼玉県所沢市東所沢');
ok($zip->set_number('3590022')->is_valid_number, '埼玉県所沢市本郷');
ok($zip->set_number('3590023')->is_valid_number, '埼玉県所沢市東所沢和田');
ok($zip->set_number('3590024')->is_valid_number, '埼玉県所沢市下安松');
ok($zip->set_number('3590025')->is_valid_number, '埼玉県所沢市上安松');
ok($zip->set_number('3590026')->is_valid_number, '埼玉県所沢市牛沼');
ok($zip->set_number('3590027')->is_valid_number, '埼玉県所沢市松郷');
ok($zip->set_number('3590031')->is_valid_number, '埼玉県所沢市下新井');
ok($zip->set_number('3590032')->is_valid_number, '埼玉県所沢市若松町');
ok($zip->set_number('3590033')->is_valid_number, '埼玉県所沢市こぶし町');
ok($zip->set_number('3590034')->is_valid_number, '埼玉県所沢市東新井町');
ok($zip->set_number('3590035')->is_valid_number, '埼玉県所沢市西新井町');
ok($zip->set_number('3590036')->is_valid_number, '埼玉県所沢市旭町');
ok($zip->set_number('3590037')->is_valid_number, '埼玉県所沢市くすのき台');
ok($zip->set_number('3590038')->is_valid_number, '埼玉県所沢市北秋津');
ok($zip->set_number('3590041')->is_valid_number, '埼玉県所沢市中新井');
ok($zip->set_number('3590042')->is_valid_number, '埼玉県所沢市並木');
ok($zip->set_number('3590043')->is_valid_number, '埼玉県所沢市弥生町');
ok($zip->set_number('3590044')->is_valid_number, '埼玉県所沢市松葉町');
ok($zip->set_number('3590045')->is_valid_number, '埼玉県所沢市美原町');
ok($zip->set_number('3590046')->is_valid_number, '埼玉県所沢市北所沢町');
ok($zip->set_number('3590047')->is_valid_number, '埼玉県所沢市花園');
ok($zip->set_number('3591101')->is_valid_number, '埼玉県所沢市北中');
ok($zip->set_number('3591102')->is_valid_number, '埼玉県所沢市岩岡町');
ok($zip->set_number('3591103')->is_valid_number, '埼玉県所沢市向陽町');
ok($zip->set_number('3591104')->is_valid_number, '埼玉県所沢市榎町');
ok($zip->set_number('3591105')->is_valid_number, '埼玉県所沢市青葉台');
ok($zip->set_number('3591106')->is_valid_number, '埼玉県所沢市東狭山ケ丘');
ok($zip->set_number('3591111')->is_valid_number, '埼玉県所沢市緑町');
ok($zip->set_number('3591112')->is_valid_number, '埼玉県所沢市泉町');
ok($zip->set_number('3591113')->is_valid_number, '埼玉県所沢市喜多町');
ok($zip->set_number('3591114')->is_valid_number, '埼玉県所沢市北有楽町');
ok($zip->set_number('3591115')->is_valid_number, '埼玉県所沢市御幸町');
ok($zip->set_number('3591116')->is_valid_number, '埼玉県所沢市東町');
ok($zip->set_number('3591117')->is_valid_number, '埼玉県所沢市有楽町');
ok($zip->set_number('3591118')->is_valid_number, '埼玉県所沢市けやき台');
ok($zip->set_number('3591121')->is_valid_number, '埼玉県所沢市元町');
ok($zip->set_number('3591122')->is_valid_number, '埼玉県所沢市寿町');
ok($zip->set_number('3591123')->is_valid_number, '埼玉県所沢市日吉町');
ok($zip->set_number('3591124')->is_valid_number, '埼玉県所沢市東住吉');
ok($zip->set_number('3591125')->is_valid_number, '埼玉県所沢市南住吉');
ok($zip->set_number('3591126')->is_valid_number, '埼玉県所沢市西住吉');
ok($zip->set_number('3591127')->is_valid_number, '埼玉県所沢市星の宮');
ok($zip->set_number('3591128')->is_valid_number, '埼玉県所沢市金山町');
ok($zip->set_number('3591131')->is_valid_number, '埼玉県所沢市久米');
ok($zip->set_number('3591132')->is_valid_number, '埼玉県所沢市松が丘');
ok($zip->set_number('3591133')->is_valid_number, '埼玉県所沢市荒幡');
ok($zip->set_number('3591141')->is_valid_number, '埼玉県所沢市小手指町');
ok($zip->set_number('3591142')->is_valid_number, '埼玉県所沢市上新井');
ok($zip->set_number('3591143')->is_valid_number, '埼玉県所沢市宮本町');
ok($zip->set_number('3591144')->is_valid_number, '埼玉県所沢市西所沢');
ok($zip->set_number('3591145')->is_valid_number, '埼玉県所沢市山口');
ok($zip->set_number('3591146')->is_valid_number, '埼玉県所沢市小手指南');
ok($zip->set_number('3591147')->is_valid_number, '埼玉県所沢市小手指元町');
ok($zip->set_number('3591148')->is_valid_number, '埼玉県所沢市小手指台');
ok($zip->set_number('3591151')->is_valid_number, '埼玉県所沢市若狭');
ok($zip->set_number('3591152')->is_valid_number, '埼玉県所沢市北野');
ok($zip->set_number('3591153')->is_valid_number, '埼玉県所沢市上山口');
ok($zip->set_number('3591154')->is_valid_number, '埼玉県所沢市勝楽寺');
ok($zip->set_number('3591155')->is_valid_number, '埼玉県所沢市北野新町');
ok($zip->set_number('3591156')->is_valid_number, '埼玉県所沢市北野南');
ok($zip->set_number('3591161')->is_valid_number, '埼玉県所沢市狭山ケ丘');
ok($zip->set_number('3591162')->is_valid_number, '埼玉県所沢市和ケ原');
ok($zip->set_number('3591163')->is_valid_number, '埼玉県所沢市西狭山ケ丘');
ok($zip->set_number('3591164')->is_valid_number, '埼玉県所沢市三ケ島');
ok($zip->set_number('3591165')->is_valid_number, '埼玉県所沢市堀之内');
ok($zip->set_number('3591166')->is_valid_number, '埼玉県所沢市糀谷');
ok($zip->set_number('3591167')->is_valid_number, '埼玉県所沢市林');
ok($zip->set_number('3600000')->is_valid_number, '埼玉県熊谷市以下に掲載がない場合');
ok($zip->set_number('3600001')->is_valid_number, '埼玉県熊谷市上中条');
ok($zip->set_number('3600002')->is_valid_number, '埼玉県熊谷市大塚');
ok($zip->set_number('3600003')->is_valid_number, '埼玉県熊谷市下川上');
ok($zip->set_number('3600004')->is_valid_number, '埼玉県熊谷市上川上');
ok($zip->set_number('3600005')->is_valid_number, '埼玉県熊谷市今井');
ok($zip->set_number('3600006')->is_valid_number, '埼玉県熊谷市四方寺');
ok($zip->set_number('3600011')->is_valid_number, '埼玉県熊谷市池上');
ok($zip->set_number('3600012')->is_valid_number, '埼玉県熊谷市上之');
ok($zip->set_number('3600013')->is_valid_number, '埼玉県熊谷市中西');
ok($zip->set_number('3600014')->is_valid_number, '埼玉県熊谷市箱田');
ok($zip->set_number('3600015')->is_valid_number, '埼玉県熊谷市肥塚');
ok($zip->set_number('3600016')->is_valid_number, '埼玉県熊谷市熊谷');
ok($zip->set_number('3600017')->is_valid_number, '埼玉県熊谷市小曽根');
ok($zip->set_number('3600018')->is_valid_number, '埼玉県熊谷市中央');
ok($zip->set_number('3600021')->is_valid_number, '埼玉県熊谷市平戸');
ok($zip->set_number('3600022')->is_valid_number, '埼玉県熊谷市戸出');
ok($zip->set_number('3600023')->is_valid_number, '埼玉県熊谷市佐谷田');
ok($zip->set_number('3600024')->is_valid_number, '埼玉県熊谷市問屋町');
ok($zip->set_number('3600025')->is_valid_number, '埼玉県熊谷市太井');
ok($zip->set_number('3600026')->is_valid_number, '埼玉県熊谷市久下');
ok($zip->set_number('3600027')->is_valid_number, '埼玉県熊谷市新川');
ok($zip->set_number('3600031')->is_valid_number, '埼玉県熊谷市末広');
ok($zip->set_number('3600032')->is_valid_number, '埼玉県熊谷市銀座');
ok($zip->set_number('3600033')->is_valid_number, '埼玉県熊谷市曙町');
ok($zip->set_number('3600034')->is_valid_number, '埼玉県熊谷市万平町');
ok($zip->set_number('3600035')->is_valid_number, '埼玉県熊谷市河原町');
ok($zip->set_number('3600036')->is_valid_number, '埼玉県熊谷市桜木町');
ok($zip->set_number('3600037')->is_valid_number, '埼玉県熊谷市筑波');
ok($zip->set_number('3600041')->is_valid_number, '埼玉県熊谷市宮町');
ok($zip->set_number('3600042')->is_valid_number, '埼玉県熊谷市本町');
ok($zip->set_number('3600043')->is_valid_number, '埼玉県熊谷市星川');
ok($zip->set_number('3600044')->is_valid_number, '埼玉県熊谷市弥生');
ok($zip->set_number('3600045')->is_valid_number, '埼玉県熊谷市宮前町');
ok($zip->set_number('3600046')->is_valid_number, '埼玉県熊谷市鎌倉町');
ok($zip->set_number('3600047')->is_valid_number, '埼玉県熊谷市仲町');
ok($zip->set_number('3600101')->is_valid_number, '埼玉県熊谷市野原');
ok($zip->set_number('3600102')->is_valid_number, '埼玉県熊谷市須賀広');
ok($zip->set_number('3600103')->is_valid_number, '埼玉県熊谷市小江川');
ok($zip->set_number('3600104')->is_valid_number, '埼玉県熊谷市塩');
ok($zip->set_number('3600105')->is_valid_number, '埼玉県熊谷市板井');
ok($zip->set_number('3600106')->is_valid_number, '埼玉県熊谷市柴');
ok($zip->set_number('3600107')->is_valid_number, '埼玉県熊谷市千代');
ok($zip->set_number('3600111')->is_valid_number, '埼玉県熊谷市押切');
ok($zip->set_number('3600112')->is_valid_number, '埼玉県熊谷市樋春');
ok($zip->set_number('3600113')->is_valid_number, '埼玉県熊谷市御正新田');
ok($zip->set_number('3600114')->is_valid_number, '埼玉県熊谷市江南中央');
ok($zip->set_number('3600115')->is_valid_number, '埼玉県熊谷市成沢');
ok($zip->set_number('3600116')->is_valid_number, '埼玉県熊谷市三本');
ok($zip->set_number('3600117')->is_valid_number, '埼玉県熊谷市上新田');
ok($zip->set_number('3600121')->is_valid_number, '埼玉県熊谷市手島');
ok($zip->set_number('3600122')->is_valid_number, '埼玉県熊谷市小泉');
ok($zip->set_number('3600123')->is_valid_number, '埼玉県熊谷市下恩田');
ok($zip->set_number('3600124')->is_valid_number, '埼玉県熊谷市中恩田');
ok($zip->set_number('3600125')->is_valid_number, '埼玉県熊谷市上恩田');
ok($zip->set_number('3600131')->is_valid_number, '埼玉県熊谷市屈戸');
ok($zip->set_number('3600132')->is_valid_number, '埼玉県熊谷市津田新田');
ok($zip->set_number('3600133')->is_valid_number, '埼玉県熊谷市中曽根');
ok($zip->set_number('3600134')->is_valid_number, '埼玉県熊谷市高本');
ok($zip->set_number('3600135')->is_valid_number, '埼玉県熊谷市沼黒');
ok($zip->set_number('3600136')->is_valid_number, '埼玉県熊谷市吉所敷');
ok($zip->set_number('3600161')->is_valid_number, '埼玉県熊谷市万吉');
ok($zip->set_number('3600162')->is_valid_number, '埼玉県熊谷市村岡');
ok($zip->set_number('3600163')->is_valid_number, '埼玉県熊谷市平塚新田');
ok($zip->set_number('3600164')->is_valid_number, '埼玉県熊谷市楊井');
ok($zip->set_number('3600201')->is_valid_number, '埼玉県熊谷市妻沼');
ok($zip->set_number('3600202')->is_valid_number, '埼玉県熊谷市妻沼東');
ok($zip->set_number('3600203')->is_valid_number, '埼玉県熊谷市弥藤吾');
ok($zip->set_number('3600204')->is_valid_number, '埼玉県熊谷市妻沼中央');
ok($zip->set_number('3600211')->is_valid_number, '埼玉県熊谷市善ケ島');
ok($zip->set_number('3600212')->is_valid_number, '埼玉県熊谷市江波');
ok($zip->set_number('3600213')->is_valid_number, '埼玉県熊谷市上須戸');
ok($zip->set_number('3600214')->is_valid_number, '埼玉県熊谷市西城');
ok($zip->set_number('3600215')->is_valid_number, '埼玉県熊谷市田島');
ok($zip->set_number('3600216')->is_valid_number, '埼玉県熊谷市西野');
ok($zip->set_number('3600217')->is_valid_number, '埼玉県熊谷市上根');
ok($zip->set_number('3600218')->is_valid_number, '埼玉県熊谷市八ツ口');
ok($zip->set_number('3600221')->is_valid_number, '埼玉県熊谷市大野');
ok($zip->set_number('3600222')->is_valid_number, '埼玉県熊谷市葛和田');
ok($zip->set_number('3600223')->is_valid_number, '埼玉県熊谷市俵瀬');
ok($zip->set_number('3600224')->is_valid_number, '埼玉県熊谷市日向');
ok($zip->set_number('3600225')->is_valid_number, '埼玉県熊谷市弁財');
ok($zip->set_number('3600231')->is_valid_number, '埼玉県熊谷市飯塚');
ok($zip->set_number('3600232')->is_valid_number, '埼玉県熊谷市道ケ谷戸');
ok($zip->set_number('3600233')->is_valid_number, '埼玉県熊谷市八木田');
ok($zip->set_number('3600234')->is_valid_number, '埼玉県熊谷市上江袋');
ok($zip->set_number('3600235')->is_valid_number, '埼玉県熊谷市原井');
ok($zip->set_number('3600236')->is_valid_number, '埼玉県熊谷市市ノ坪');
ok($zip->set_number('3600237')->is_valid_number, '埼玉県熊谷市永井太田');
ok($zip->set_number('3600238')->is_valid_number, '埼玉県熊谷市妻沼西');
ok($zip->set_number('3600241')->is_valid_number, '埼玉県熊谷市妻沼台');
ok($zip->set_number('3600242')->is_valid_number, '埼玉県熊谷市男沼');
ok($zip->set_number('3600243')->is_valid_number, '埼玉県熊谷市間々田');
ok($zip->set_number('3600244')->is_valid_number, '埼玉県熊谷市出来島');
ok($zip->set_number('3600245')->is_valid_number, '埼玉県熊谷市妻沼小島');
ok($zip->set_number('3600801')->is_valid_number, '埼玉県熊谷市中奈良');
ok($zip->set_number('3600802')->is_valid_number, '埼玉県熊谷市下奈良');
ok($zip->set_number('3600803')->is_valid_number, '埼玉県熊谷市柿沼');
ok($zip->set_number('3600804')->is_valid_number, '埼玉県熊谷市代');
ok($zip->set_number('3600805')->is_valid_number, '埼玉県熊谷市上奈良');
ok($zip->set_number('3600806')->is_valid_number, '埼玉県熊谷市奈良新田');
ok($zip->set_number('3600811')->is_valid_number, '埼玉県熊谷市原島');
ok($zip->set_number('3600812')->is_valid_number, '埼玉県熊谷市大原');
ok($zip->set_number('3600813')->is_valid_number, '埼玉県熊谷市円光');
ok($zip->set_number('3600814')->is_valid_number, '埼玉県熊谷市桜町');
ok($zip->set_number('3600815')->is_valid_number, '埼玉県熊谷市本石');
ok($zip->set_number('3600816')->is_valid_number, '埼玉県熊谷市石原');
ok($zip->set_number('3600817')->is_valid_number, '埼玉県熊谷市新島');
ok($zip->set_number('3600821')->is_valid_number, '埼玉県熊谷市伊勢町');
ok($zip->set_number('3600822')->is_valid_number, '埼玉県熊谷市宮本町');
ok($zip->set_number('3600823')->is_valid_number, '埼玉県熊谷市榎町');
ok($zip->set_number('3600824')->is_valid_number, '埼玉県熊谷市見晴町');
ok($zip->set_number('3600825')->is_valid_number, '埼玉県熊谷市月見町');
ok($zip->set_number('3600826')->is_valid_number, '埼玉県熊谷市赤城町');
ok($zip->set_number('3600831')->is_valid_number, '埼玉県熊谷市久保島');
ok($zip->set_number('3600832')->is_valid_number, '埼玉県熊谷市小島');
ok($zip->set_number('3600833')->is_valid_number, '埼玉県熊谷市広瀬');
ok($zip->set_number('3600834')->is_valid_number, '埼玉県熊谷市瀬南');
ok($zip->set_number('3600835')->is_valid_number, '埼玉県熊谷市大麻生');
ok($zip->set_number('3600836')->is_valid_number, '埼玉県熊谷市武体');
ok($zip->set_number('3600837')->is_valid_number, '埼玉県熊谷市川原明戸');
ok($zip->set_number('3600841')->is_valid_number, '埼玉県熊谷市新堀');
ok($zip->set_number('3600842')->is_valid_number, '埼玉県熊谷市新堀新田');
ok($zip->set_number('3600843')->is_valid_number, '埼玉県熊谷市三ケ尻');
ok($zip->set_number('3600844')->is_valid_number, '埼玉県熊谷市御稜威ケ原');
ok($zip->set_number('3600845')->is_valid_number, '埼玉県熊谷市美土里町');
ok($zip->set_number('3600846')->is_valid_number, '埼玉県熊谷市拾六間');
ok($zip->set_number('3600847')->is_valid_number, '埼玉県熊谷市籠原南');
ok($zip->set_number('3600851')->is_valid_number, '埼玉県熊谷市下増田');
ok($zip->set_number('3600852')->is_valid_number, '埼玉県熊谷市東別府');
ok($zip->set_number('3600853')->is_valid_number, '埼玉県熊谷市玉井');
ok($zip->set_number('3600854')->is_valid_number, '埼玉県熊谷市玉井南');
ok($zip->set_number('3600855')->is_valid_number, '埼玉県熊谷市高柳');
ok($zip->set_number('3600856')->is_valid_number, '埼玉県熊谷市別府');
ok($zip->set_number('3600857')->is_valid_number, '埼玉県熊谷市西別府');
ok($zip->set_number('3610000')->is_valid_number, '埼玉県行田市以下に掲載がない場合');
ok($zip->set_number('3610001')->is_valid_number, '埼玉県行田市北河原');
ok($zip->set_number('3610002')->is_valid_number, '埼玉県行田市酒巻');
ok($zip->set_number('3610003')->is_valid_number, '埼玉県行田市下中条');
ok($zip->set_number('3610004')->is_valid_number, '埼玉県行田市須加');
ok($zip->set_number('3610005')->is_valid_number, '埼玉県行田市斎条');
ok($zip->set_number('3610006')->is_valid_number, '埼玉県行田市白川戸');
ok($zip->set_number('3610007')->is_valid_number, '埼玉県行田市小見');
ok($zip->set_number('3610011')->is_valid_number, '埼玉県行田市荒木');
ok($zip->set_number('3610012')->is_valid_number, '埼玉県行田市下須戸');
ok($zip->set_number('3610013')->is_valid_number, '埼玉県行田市真名板');
ok($zip->set_number('3610014')->is_valid_number, '埼玉県行田市藤間');
ok($zip->set_number('3610015')->is_valid_number, '埼玉県行田市関根');
ok($zip->set_number('3610016')->is_valid_number, '埼玉県行田市藤原町');
ok($zip->set_number('3610017')->is_valid_number, '埼玉県行田市若小玉');
ok($zip->set_number('3610021')->is_valid_number, '埼玉県行田市富士見町');
ok($zip->set_number('3610022')->is_valid_number, '埼玉県行田市桜町');
ok($zip->set_number('3610023')->is_valid_number, '埼玉県行田市長野');
ok($zip->set_number('3610024')->is_valid_number, '埼玉県行田市小針');
ok($zip->set_number('3610025')->is_valid_number, '埼玉県行田市埼玉');
ok($zip->set_number('3610026')->is_valid_number, '埼玉県行田市野');
ok($zip->set_number('3610031')->is_valid_number, '埼玉県行田市緑町');
ok($zip->set_number('3610032')->is_valid_number, '埼玉県行田市佐間');
ok($zip->set_number('3610033')->is_valid_number, '埼玉県行田市渡柳');
ok($zip->set_number('3610034')->is_valid_number, '埼玉県行田市利田');
ok($zip->set_number('3610035')->is_valid_number, '埼玉県行田市堤根');
ok($zip->set_number('3610036')->is_valid_number, '埼玉県行田市樋上');
ok($zip->set_number('3610037')->is_valid_number, '埼玉県行田市下忍');
ok($zip->set_number('3610038')->is_valid_number, '埼玉県行田市前谷');
ok($zip->set_number('3610041')->is_valid_number, '埼玉県行田市棚田町');
ok($zip->set_number('3610042')->is_valid_number, '埼玉県行田市西新町');
ok($zip->set_number('3610043')->is_valid_number, '埼玉県行田市深水町');
ok($zip->set_number('3610044')->is_valid_number, '埼玉県行田市門井町');
ok($zip->set_number('3610045')->is_valid_number, '埼玉県行田市押上町');
ok($zip->set_number('3610046')->is_valid_number, '埼玉県行田市壱里山町');
ok($zip->set_number('3610047')->is_valid_number, '埼玉県行田市清水町');
ok($zip->set_number('3610051')->is_valid_number, '埼玉県行田市矢場');
ok($zip->set_number('3610052')->is_valid_number, '埼玉県行田市本丸');
ok($zip->set_number('3610053')->is_valid_number, '埼玉県行田市水城公園');
ok($zip->set_number('3610054')->is_valid_number, '埼玉県行田市城南');
ok($zip->set_number('3610055')->is_valid_number, '埼玉県行田市駒形');
ok($zip->set_number('3610056')->is_valid_number, '埼玉県行田市持田');
ok($zip->set_number('3610057')->is_valid_number, '埼玉県行田市城西');
ok($zip->set_number('3610061')->is_valid_number, '埼玉県行田市和田');
ok($zip->set_number('3610062')->is_valid_number, '埼玉県行田市谷郷');
ok($zip->set_number('3610063')->is_valid_number, '埼玉県行田市皿尾');
ok($zip->set_number('3610064')->is_valid_number, '埼玉県行田市中里');
ok($zip->set_number('3610065')->is_valid_number, '埼玉県行田市小敷田');
ok($zip->set_number('3610066')->is_valid_number, '埼玉県行田市上池守');
ok($zip->set_number('3610067')->is_valid_number, '埼玉県行田市下池守');
ok($zip->set_number('3610071')->is_valid_number, '埼玉県行田市栄町');
ok($zip->set_number('3610072')->is_valid_number, '埼玉県行田市宮本');
ok($zip->set_number('3610073')->is_valid_number, '埼玉県行田市行田');
ok($zip->set_number('3610074')->is_valid_number, '埼玉県行田市旭町');
ok($zip->set_number('3610075')->is_valid_number, '埼玉県行田市向町');
ok($zip->set_number('3610076')->is_valid_number, '埼玉県行田市天満');
ok($zip->set_number('3610077')->is_valid_number, '埼玉県行田市忍');
ok($zip->set_number('3610078')->is_valid_number, '埼玉県行田市中央');
ok($zip->set_number('3610081')->is_valid_number, '埼玉県行田市犬塚');
ok($zip->set_number('3610082')->is_valid_number, '埼玉県行田市馬見塚');
ok($zip->set_number('3610083')->is_valid_number, '埼玉県行田市中江袋');
ok($zip->set_number('3610084')->is_valid_number, '埼玉県行田市南河原');
ok($zip->set_number('3620000')->is_valid_number, '埼玉県上尾市以下に掲載がない場合');
ok($zip->set_number('3620001')->is_valid_number, '埼玉県上尾市上');
ok($zip->set_number('3620002')->is_valid_number, '埼玉県上尾市南');
ok($zip->set_number('3620003')->is_valid_number, '埼玉県上尾市菅谷');
ok($zip->set_number('3620004')->is_valid_number, '埼玉県上尾市須ケ谷');
ok($zip->set_number('3620005')->is_valid_number, '埼玉県上尾市西門前');
ok($zip->set_number('3620006')->is_valid_number, '埼玉県上尾市錦町');
ok($zip->set_number('3620007')->is_valid_number, '埼玉県上尾市久保');
ok($zip->set_number('3620008')->is_valid_number, '埼玉県上尾市上平中央');
ok($zip->set_number('3620011')->is_valid_number, '埼玉県上尾市平塚');
ok($zip->set_number('3620012')->is_valid_number, '埼玉県上尾市上尾宿');
ok($zip->set_number('3620013')->is_valid_number, '埼玉県上尾市上尾村');
ok($zip->set_number('3620014')->is_valid_number, '埼玉県上尾市本町');
ok($zip->set_number('3620015')->is_valid_number, '埼玉県上尾市緑丘');
ok($zip->set_number('3620016')->is_valid_number, '埼玉県上尾市原新町');
ok($zip->set_number('3620017')->is_valid_number, '埼玉県上尾市二ツ宮');
ok($zip->set_number('3620021')->is_valid_number, '埼玉県上尾市原市');
ok($zip->set_number('3620022')->is_valid_number, '埼玉県上尾市瓦葺');
ok($zip->set_number('3620023')->is_valid_number, '埼玉県上尾市原市中');
ok($zip->set_number('3620024')->is_valid_number, '埼玉県上尾市五番町');
ok($zip->set_number('3620025')->is_valid_number, '埼玉県上尾市上尾下');
ok($zip->set_number('3620026')->is_valid_number, '埼玉県上尾市原市北');
ok($zip->set_number('3620031')->is_valid_number, '埼玉県上尾市東町');
ok($zip->set_number('3620032')->is_valid_number, '埼玉県上尾市日の出');
ok($zip->set_number('3620033')->is_valid_number, '埼玉県上尾市栄町');
ok($zip->set_number('3620034')->is_valid_number, '埼玉県上尾市愛宕');
ok($zip->set_number('3620035')->is_valid_number, '埼玉県上尾市仲町');
ok($zip->set_number('3620036')->is_valid_number, '埼玉県上尾市宮本町');
ok($zip->set_number('3620037')->is_valid_number, '埼玉県上尾市上町');
ok($zip->set_number('3620041')->is_valid_number, '埼玉県上尾市富士見');
ok($zip->set_number('3620042')->is_valid_number, '埼玉県上尾市谷津');
ok($zip->set_number('3620043')->is_valid_number, '埼玉県上尾市西宮下');
ok($zip->set_number('3620044')->is_valid_number, '埼玉県上尾市大谷本郷');
ok($zip->set_number('3620045')->is_valid_number, '埼玉県上尾市向山');
ok($zip->set_number('3620046')->is_valid_number, '埼玉県上尾市壱丁目');
ok($zip->set_number('3620047')->is_valid_number, '埼玉県上尾市今泉');
ok($zip->set_number('3620048')->is_valid_number, '埼玉県上尾市川');
ok($zip->set_number('3620051')->is_valid_number, '埼玉県上尾市地頭方');
ok($zip->set_number('3620052')->is_valid_number, '埼玉県上尾市中新井');
ok($zip->set_number('3620053')->is_valid_number, '埼玉県上尾市戸崎');
ok($zip->set_number('3620054')->is_valid_number, '埼玉県上尾市堤崎');
ok($zip->set_number('3620055')->is_valid_number, '埼玉県上尾市平方領々家');
ok($zip->set_number('3620056')->is_valid_number, '埼玉県上尾市上野本郷');
ok($zip->set_number('3620057')->is_valid_number, '埼玉県上尾市西貝塚');
ok($zip->set_number('3620058')->is_valid_number, '埼玉県上尾市上野');
ok($zip->set_number('3620059')->is_valid_number, '埼玉県上尾市平方');
ok($zip->set_number('3620061')->is_valid_number, '埼玉県上尾市藤波');
ok($zip->set_number('3620062')->is_valid_number, '埼玉県上尾市泉台');
ok($zip->set_number('3620063')->is_valid_number, '埼玉県上尾市小泉');
ok($zip->set_number('3620064')->is_valid_number, '埼玉県上尾市小敷谷');
ok($zip->set_number('3620065')->is_valid_number, '埼玉県上尾市畔吉');
ok($zip->set_number('3620066')->is_valid_number, '埼玉県上尾市領家');
ok($zip->set_number('3620067')->is_valid_number, '埼玉県上尾市中分');
ok($zip->set_number('3620071')->is_valid_number, '埼玉県上尾市井戸木');
ok($zip->set_number('3620072')->is_valid_number, '埼玉県上尾市中妻');
ok($zip->set_number('3620073')->is_valid_number, '埼玉県上尾市浅間台');
ok($zip->set_number('3620074')->is_valid_number, '埼玉県上尾市春日');
ok($zip->set_number('3620075')->is_valid_number, '埼玉県上尾市柏座');
ok($zip->set_number('3620076')->is_valid_number, '埼玉県上尾市弁財');
ok($zip->set_number('3620081')->is_valid_number, '埼玉県上尾市壱丁目北');
ok($zip->set_number('3620082')->is_valid_number, '埼玉県上尾市壱丁目東');
ok($zip->set_number('3620083')->is_valid_number, '埼玉県上尾市壱丁目南');
ok($zip->set_number('3620084')->is_valid_number, '埼玉県上尾市壱丁目西');
ok($zip->set_number('3620800')->is_valid_number, '埼玉県北足立郡伊奈町以下に掲載がない場合');
ok($zip->set_number('3620801')->is_valid_number, '埼玉県北足立郡伊奈町小針内宿');
ok($zip->set_number('3620802')->is_valid_number, '埼玉県北足立郡伊奈町羽貫');
ok($zip->set_number('3620803')->is_valid_number, '埼玉県北足立郡伊奈町大針');
ok($zip->set_number('3620804')->is_valid_number, '埼玉県北足立郡伊奈町本町');
ok($zip->set_number('3620805')->is_valid_number, '埼玉県北足立郡伊奈町栄');
ok($zip->set_number('3620806')->is_valid_number, '埼玉県北足立郡伊奈町小室');
ok($zip->set_number('3620807')->is_valid_number, '埼玉県北足立郡伊奈町寿');
ok($zip->set_number('3620808')->is_valid_number, '埼玉県北足立郡伊奈町小針新宿');
ok($zip->set_number('3620809')->is_valid_number, '埼玉県北足立郡伊奈町中央');
ok($zip->set_number('3620811')->is_valid_number, '埼玉県北足立郡伊奈町西小針');
ok($zip->set_number('3620812')->is_valid_number, '埼玉県北足立郡伊奈町内宿台');
ok($zip->set_number('3620813')->is_valid_number, '埼玉県北足立郡伊奈町学園');
ok($zip->set_number('3630000')->is_valid_number, '埼玉県桶川市以下に掲載がない場合');
ok($zip->set_number('3630001')->is_valid_number, '埼玉県桶川市加納');
ok($zip->set_number('3630002')->is_valid_number, '埼玉県桶川市赤堀');
ok($zip->set_number('3630003')->is_valid_number, '埼玉県桶川市篠津');
ok($zip->set_number('3630004')->is_valid_number, '埼玉県桶川市五町台');
ok($zip->set_number('3630005')->is_valid_number, '埼玉県桶川市舎人新田');
ok($zip->set_number('3630006')->is_valid_number, '埼玉県桶川市倉田');
ok($zip->set_number('3630007')->is_valid_number, '埼玉県桶川市小針領家');
ok($zip->set_number('3630008')->is_valid_number, '埼玉県桶川市坂田');
ok($zip->set_number('3630009')->is_valid_number, '埼玉県桶川市坂田東');
ok($zip->set_number('3630011')->is_valid_number, '埼玉県桶川市北');
ok($zip->set_number('3630012')->is_valid_number, '埼玉県桶川市末広');
ok($zip->set_number('3630013')->is_valid_number, '埼玉県桶川市東');
ok($zip->set_number('3630014')->is_valid_number, '埼玉県桶川市神明');
ok($zip->set_number('3630015')->is_valid_number, '埼玉県桶川市南');
ok($zip->set_number('3630016')->is_valid_number, '埼玉県桶川市寿');
ok($zip->set_number('3630017')->is_valid_number, '埼玉県桶川市西');
ok($zip->set_number('3630018')->is_valid_number, '埼玉県桶川市坂田西');
ok($zip->set_number('3630020')->is_valid_number, '埼玉県桶川市上日出谷南');
ok($zip->set_number('3630021')->is_valid_number, '埼玉県桶川市泉');
ok($zip->set_number('3630022')->is_valid_number, '埼玉県桶川市若宮');
ok($zip->set_number('3630023')->is_valid_number, '埼玉県桶川市朝日');
ok($zip->set_number('3630024')->is_valid_number, '埼玉県桶川市鴨川');
ok($zip->set_number('3630025')->is_valid_number, '埼玉県桶川市下日出谷');
ok($zip->set_number('3630026')->is_valid_number, '埼玉県桶川市上日出谷');
ok($zip->set_number('3630027')->is_valid_number, '埼玉県桶川市川田谷');
ok($zip->set_number('3630028')->is_valid_number, '埼玉県桶川市下日出谷西');
ok($zip->set_number('3630029')->is_valid_number, '埼玉県桶川市下日出谷東');
ok($zip->set_number('3640000')->is_valid_number, '埼玉県北本市以下に掲載がない場合');
ok($zip->set_number('3640001')->is_valid_number, '埼玉県北本市深井');
ok($zip->set_number('3640002')->is_valid_number, '埼玉県北本市宮内');
ok($zip->set_number('3640003')->is_valid_number, '埼玉県北本市古市場');
ok($zip->set_number('3640004')->is_valid_number, '埼玉県北本市山中');
ok($zip->set_number('3640005')->is_valid_number, '埼玉県北本市本宿');
ok($zip->set_number('3640006')->is_valid_number, '埼玉県北本市北本');
ok($zip->set_number('3640007')->is_valid_number, '埼玉県北本市東間');
ok($zip->set_number('3640011')->is_valid_number, '埼玉県北本市朝日');
ok($zip->set_number('3640012')->is_valid_number, '埼玉県北本市北中丸');
ok($zip->set_number('3640013')->is_valid_number, '埼玉県北本市中丸');
ok($zip->set_number('3640014')->is_valid_number, '埼玉県北本市二ツ家');
ok($zip->set_number('3640021')->is_valid_number, '埼玉県北本市北本宿');
ok($zip->set_number('3640022')->is_valid_number, '埼玉県北本市下石戸上');
ok($zip->set_number('3640023')->is_valid_number, '埼玉県北本市下石戸下');
ok($zip->set_number('3640024')->is_valid_number, '埼玉県北本市石戸');
ok($zip->set_number('3640025')->is_valid_number, '埼玉県北本市石戸宿');
ok($zip->set_number('3640026')->is_valid_number, '埼玉県北本市荒井');
ok($zip->set_number('3640027')->is_valid_number, '埼玉県北本市栄');
ok($zip->set_number('3640028')->is_valid_number, '埼玉県北本市下石戸');
ok($zip->set_number('3640031')->is_valid_number, '埼玉県北本市中央');
ok($zip->set_number('3640032')->is_valid_number, '埼玉県北本市緑');
ok($zip->set_number('3640033')->is_valid_number, '埼玉県北本市本町');
ok($zip->set_number('3640034')->is_valid_number, '埼玉県北本市高尾');
ok($zip->set_number('3640035')->is_valid_number, '埼玉県北本市西高尾');
ok($zip->set_number('3650000')->is_valid_number, '埼玉県鴻巣市以下に掲載がない場合');
ok($zip->set_number('3650001')->is_valid_number, '埼玉県鴻巣市赤城台');
ok($zip->set_number('3650002')->is_valid_number, '埼玉県鴻巣市赤城');
ok($zip->set_number('3650003')->is_valid_number, '埼玉県鴻巣市北根');
ok($zip->set_number('3650004')->is_valid_number, '埼玉県鴻巣市関新田');
ok($zip->set_number('3650005')->is_valid_number, '埼玉県鴻巣市広田');
ok($zip->set_number('3650011')->is_valid_number, '埼玉県鴻巣市新井');
ok($zip->set_number('3650012')->is_valid_number, '埼玉県鴻巣市上会下');
ok($zip->set_number('3650013')->is_valid_number, '埼玉県鴻巣市境');
ok($zip->set_number('3650014')->is_valid_number, '埼玉県鴻巣市屈巣');
ok($zip->set_number('3650021')->is_valid_number, '埼玉県鴻巣市安養寺');
ok($zip->set_number('3650022')->is_valid_number, '埼玉県鴻巣市郷地');
ok($zip->set_number('3650023')->is_valid_number, '埼玉県鴻巣市笠原');
ok($zip->set_number('3650024')->is_valid_number, '埼玉県鴻巣市常光');
ok($zip->set_number('3650025')->is_valid_number, '埼玉県鴻巣市下谷');
ok($zip->set_number('3650026')->is_valid_number, '埼玉県鴻巣市西中曽根');
ok($zip->set_number('3650027')->is_valid_number, '埼玉県鴻巣市上谷');
ok($zip->set_number('3650028')->is_valid_number, '埼玉県鴻巣市鴻巣');
ok($zip->set_number('3650031')->is_valid_number, '埼玉県鴻巣市ひばり野');
ok($zip->set_number('3650032')->is_valid_number, '埼玉県鴻巣市中央');
ok($zip->set_number('3650033')->is_valid_number, '埼玉県鴻巣市生出塚');
ok($zip->set_number('3650034')->is_valid_number, '埼玉県鴻巣市上生出塚');
ok($zip->set_number('3650035')->is_valid_number, '埼玉県鴻巣市下生出塚');
ok($zip->set_number('3650036')->is_valid_number, '埼玉県鴻巣市天神');
ok($zip->set_number('3650037')->is_valid_number, '埼玉県鴻巣市人形');
ok($zip->set_number('3650038')->is_valid_number, '埼玉県鴻巣市本町');
ok($zip->set_number('3650039')->is_valid_number, '埼玉県鴻巣市東');
ok($zip->set_number('3650041')->is_valid_number, '埼玉県鴻巣市小松');
ok($zip->set_number('3650042')->is_valid_number, '埼玉県鴻巣市松原');
ok($zip->set_number('3650043')->is_valid_number, '埼玉県鴻巣市原馬室');
ok($zip->set_number('3650044')->is_valid_number, '埼玉県鴻巣市滝馬室');
ok($zip->set_number('3650045')->is_valid_number, '埼玉県鴻巣市氷川町');
ok($zip->set_number('3650046')->is_valid_number, '埼玉県鴻巣市富士見町');
ok($zip->set_number('3650047')->is_valid_number, '埼玉県鴻巣市逆川');
ok($zip->set_number('3650051')->is_valid_number, '埼玉県鴻巣市宮前');
ok($zip->set_number('3650052')->is_valid_number, '埼玉県鴻巣市登戸');
ok($zip->set_number('3650053')->is_valid_number, '埼玉県鴻巣市緑町');
ok($zip->set_number('3650054')->is_valid_number, '埼玉県鴻巣市大間');
ok($zip->set_number('3650055')->is_valid_number, '埼玉県鴻巣市栄町');
ok($zip->set_number('3650056')->is_valid_number, '埼玉県鴻巣市堤町');
ok($zip->set_number('3650057')->is_valid_number, '埼玉県鴻巣市幸町');
ok($zip->set_number('3650058')->is_valid_number, '埼玉県鴻巣市北中野');
ok($zip->set_number('3650059')->is_valid_number, '埼玉県鴻巣市糠田');
ok($zip->set_number('3650061')->is_valid_number, '埼玉県鴻巣市川面');
ok($zip->set_number('3650062')->is_valid_number, '埼玉県鴻巣市箕田');
ok($zip->set_number('3650063')->is_valid_number, '埼玉県鴻巣市稲荷町');
ok($zip->set_number('3650064')->is_valid_number, '埼玉県鴻巣市赤見台');
ok($zip->set_number('3650065')->is_valid_number, '埼玉県鴻巣市中井');
ok($zip->set_number('3650066')->is_valid_number, '埼玉県鴻巣市三ツ木');
ok($zip->set_number('3650067')->is_valid_number, '埼玉県鴻巣市すみれ野');
ok($zip->set_number('3650068')->is_valid_number, '埼玉県鴻巣市愛の町');
ok($zip->set_number('3650071')->is_valid_number, '埼玉県鴻巣市寺谷');
ok($zip->set_number('3650072')->is_valid_number, '埼玉県鴻巣市市ノ縄');
ok($zip->set_number('3650073')->is_valid_number, '埼玉県鴻巣市八幡田');
ok($zip->set_number('3650074')->is_valid_number, '埼玉県鴻巣市神明');
ok($zip->set_number('3650075')->is_valid_number, '埼玉県鴻巣市宮地');
ok($zip->set_number('3650076')->is_valid_number, '埼玉県鴻巣市本宮町');
ok($zip->set_number('3650077')->is_valid_number, '埼玉県鴻巣市雷電');
ok($zip->set_number('3650078')->is_valid_number, '埼玉県鴻巣市加美');
ok($zip->set_number('3660000')->is_valid_number, '埼玉県深谷市以下に掲載がない場合');
ok($zip->set_number('3660001')->is_valid_number, '埼玉県深谷市中瀬');
ok($zip->set_number('3660002')->is_valid_number, '埼玉県深谷市下手計');
ok($zip->set_number('3660003')->is_valid_number, '埼玉県深谷市大塚');
ok($zip->set_number('3660004')->is_valid_number, '埼玉県深谷市上手計');
ok($zip->set_number('3660005')->is_valid_number, '埼玉県深谷市町田');
ok($zip->set_number('3660006')->is_valid_number, '埼玉県深谷市血洗島');
ok($zip->set_number('3660007')->is_valid_number, '埼玉県深谷市南阿賀野');
ok($zip->set_number('3660008')->is_valid_number, '埼玉県深谷市北阿賀野');
ok($zip->set_number('3660009')->is_valid_number, '埼玉県深谷市横瀬');
ok($zip->set_number('3660010')->is_valid_number, '埼玉県深谷市高島');
ok($zip->set_number('3660011')->is_valid_number, '埼玉県深谷市石塚');
ok($zip->set_number('3660012')->is_valid_number, '埼玉県深谷市江原');
ok($zip->set_number('3660013')->is_valid_number, '埼玉県深谷市堀米');
ok($zip->set_number('3660014')->is_valid_number, '埼玉県深谷市藤野木');
ok($zip->set_number('3660015')->is_valid_number, '埼玉県深谷市蓮沼');
ok($zip->set_number('3660016')->is_valid_number, '埼玉県深谷市新井');
ok($zip->set_number('3660017')->is_valid_number, '埼玉県深谷市沼尻');
ok($zip->set_number('3660018')->is_valid_number, '埼玉県深谷市成塚');
ok($zip->set_number('3660019')->is_valid_number, '埼玉県深谷市新戒');
ok($zip->set_number('3660021')->is_valid_number, '埼玉県深谷市上増田');
ok($zip->set_number('3660022')->is_valid_number, '埼玉県深谷市本田ケ谷');
ok($zip->set_number('3660023')->is_valid_number, '埼玉県深谷市宮ケ谷戸');
ok($zip->set_number('3660024')->is_valid_number, '埼玉県深谷市明戸');
ok($zip->set_number('3660025')->is_valid_number, '埼玉県深谷市寿町');
ok($zip->set_number('3660026')->is_valid_number, '埼玉県深谷市稲荷町');
ok($zip->set_number('3660027')->is_valid_number, '埼玉県深谷市天神町');
ok($zip->set_number('3660028')->is_valid_number, '埼玉県深谷市稲荷町北');
ok($zip->set_number('3660029')->is_valid_number, '埼玉県深谷市上敷免');
ok($zip->set_number('3660031')->is_valid_number, '埼玉県深谷市国済寺町');
ok($zip->set_number('3660032')->is_valid_number, '埼玉県深谷市幡羅町');
ok($zip->set_number('3660033')->is_valid_number, '埼玉県深谷市国済寺');
ok($zip->set_number('3660034')->is_valid_number, '埼玉県深谷市常盤町');
ok($zip->set_number('3660035')->is_valid_number, '埼玉県深谷市原郷');
ok($zip->set_number('3660041')->is_valid_number, '埼玉県深谷市東方');
ok($zip->set_number('3660042')->is_valid_number, '埼玉県深谷市東方町');
ok($zip->set_number('3660051')->is_valid_number, '埼玉県深谷市上柴町東');
ok($zip->set_number('3660052')->is_valid_number, '埼玉県深谷市上柴町西');
ok($zip->set_number('3660053')->is_valid_number, '埼玉県深谷市秋元町');
ok($zip->set_number('3660054')->is_valid_number, '埼玉県深谷市緑ケ丘');
ok($zip->set_number('3660061')->is_valid_number, '埼玉県深谷市二ツ小屋');
ok($zip->set_number('3660062')->is_valid_number, '埼玉県深谷市前小屋');
ok($zip->set_number('3660801')->is_valid_number, '埼玉県深谷市上野台');
ok($zip->set_number('3660802')->is_valid_number, '埼玉県深谷市桜ケ丘');
ok($zip->set_number('3660810')->is_valid_number, '埼玉県深谷市宿根');
ok($zip->set_number('3660811')->is_valid_number, '埼玉県深谷市人見');
ok($zip->set_number('3660812')->is_valid_number, '埼玉県深谷市折之口');
ok($zip->set_number('3660813')->is_valid_number, '埼玉県深谷市境');
ok($zip->set_number('3660814')->is_valid_number, '埼玉県深谷市大谷');
ok($zip->set_number('3660815')->is_valid_number, '埼玉県深谷市櫛引');
ok($zip->set_number('3660816')->is_valid_number, '埼玉県深谷市樫合');
ok($zip->set_number('3660817')->is_valid_number, '埼玉県深谷市柏合');
ok($zip->set_number('3660818')->is_valid_number, '埼玉県深谷市萱場');
ok($zip->set_number('3660819')->is_valid_number, '埼玉県深谷市見晴町');
ok($zip->set_number('3660821')->is_valid_number, '埼玉県深谷市田谷');
ok($zip->set_number('3660822')->is_valid_number, '埼玉県深谷市仲町');
ok($zip->set_number('3660823')->is_valid_number, '埼玉県深谷市本住町');
ok($zip->set_number('3660824')->is_valid_number, '埼玉県深谷市西島町(西島)');
ok($zip->set_number('3660825')->is_valid_number, '埼玉県深谷市深谷町');
ok($zip->set_number('3660826')->is_valid_number, '埼玉県深谷市田所町');
ok($zip->set_number('3660827')->is_valid_number, '埼玉県深谷市栄町');
ok($zip->set_number('3660828')->is_valid_number, '埼玉県深谷市東大沼');
ok($zip->set_number('3660829')->is_valid_number, '埼玉県深谷市西大沼');
ok($zip->set_number('3660831')->is_valid_number, '埼玉県深谷市内ケ島');
ok($zip->set_number('3660832')->is_valid_number, '埼玉県深谷市高畑');
ok($zip->set_number('3660833')->is_valid_number, '埼玉県深谷市戸森');
ok($zip->set_number('3660834')->is_valid_number, '埼玉県深谷市曲田(錦町)');
ok($zip->set_number('3660835')->is_valid_number, '埼玉県深谷市谷之');
ok($zip->set_number('3660836')->is_valid_number, '埼玉県深谷市伊勢方');
ok($zip->set_number('3660837')->is_valid_number, '埼玉県深谷市起会');
ok($zip->set_number('3660838')->is_valid_number, '埼玉県深谷市大塚島');
ok($zip->set_number('3660839')->is_valid_number, '埼玉県深谷市矢島');
ok($zip->set_number('3670000')->is_valid_number, '埼玉県本庄市以下に掲載がない場合');
ok($zip->set_number('3670001')->is_valid_number, '埼玉県本庄市下仁手');
ok($zip->set_number('3670002')->is_valid_number, '埼玉県本庄市仁手');
ok($zip->set_number('3670003')->is_valid_number, '埼玉県本庄市台町');
ok($zip->set_number('3670004')->is_valid_number, '埼玉県本庄市本町');
ok($zip->set_number('3670005')->is_valid_number, '埼玉県本庄市久々宇');
ok($zip->set_number('3670006')->is_valid_number, '埼玉県本庄市田中');
ok($zip->set_number('3670007')->is_valid_number, '埼玉県本庄市上仁手');
ok($zip->set_number('3670011')->is_valid_number, '埼玉県本庄市小和瀬');
ok($zip->set_number('3670012')->is_valid_number, '埼玉県本庄市宮戸');
ok($zip->set_number('3670013')->is_valid_number, '埼玉県本庄市滝瀬');
ok($zip->set_number('3670014')->is_valid_number, '埼玉県本庄市堀田');
ok($zip->set_number('3670015')->is_valid_number, '埼玉県本庄市牧西');
ok($zip->set_number('3670016')->is_valid_number, '埼玉県本庄市鵜森');
ok($zip->set_number('3670017')->is_valid_number, '埼玉県本庄市傍示堂');
ok($zip->set_number('3670018')->is_valid_number, '埼玉県本庄市諏訪町');
ok($zip->set_number('3670021')->is_valid_number, '埼玉県本庄市東台');
ok($zip->set_number('3670022')->is_valid_number, '埼玉県本庄市日の出');
ok($zip->set_number('3670023')->is_valid_number, '埼玉県本庄市寿');
ok($zip->set_number('3670024')->is_valid_number, '埼玉県本庄市東五十子');
ok($zip->set_number('3670025')->is_valid_number, '埼玉県本庄市西五十子');
ok($zip->set_number('3670026')->is_valid_number, '埼玉県本庄市朝日町');
ok($zip->set_number('3670027')->is_valid_number, '埼玉県本庄市五十子');
ok($zip->set_number('3670030')->is_valid_number, '埼玉県本庄市早稲田の杜');
ok($zip->set_number('3670031')->is_valid_number, '埼玉県本庄市北堀');
ok($zip->set_number('3670032')->is_valid_number, '埼玉県本庄市栗崎');
ok($zip->set_number('3670033')->is_valid_number, '埼玉県本庄市東富田');
ok($zip->set_number('3670034')->is_valid_number, '埼玉県本庄市四方田');
ok($zip->set_number('3670035')->is_valid_number, '埼玉県本庄市西富田');
ok($zip->set_number('3670036')->is_valid_number, '埼玉県本庄市今井');
ok($zip->set_number('3670037')->is_valid_number, '埼玉県本庄市共栄');
ok($zip->set_number('3670038')->is_valid_number, '埼玉県本庄市いまい台');
ok($zip->set_number('3670039')->is_valid_number, '埼玉県本庄市四季の里');
ok($zip->set_number('3670041')->is_valid_number, '埼玉県本庄市駅南');
ok($zip->set_number('3670042')->is_valid_number, '埼玉県本庄市けや木');
ok($zip->set_number('3670043')->is_valid_number, '埼玉県本庄市緑');
ok($zip->set_number('3670044')->is_valid_number, '埼玉県本庄市見福');
ok($zip->set_number('3670045')->is_valid_number, '埼玉県本庄市柏');
ok($zip->set_number('3670046')->is_valid_number, '埼玉県本庄市栄');
ok($zip->set_number('3670047')->is_valid_number, '埼玉県本庄市前原');
ok($zip->set_number('3670048')->is_valid_number, '埼玉県本庄市南');
ok($zip->set_number('3670051')->is_valid_number, '埼玉県本庄市本庄');
ok($zip->set_number('3670052')->is_valid_number, '埼玉県本庄市銀座');
ok($zip->set_number('3670053')->is_valid_number, '埼玉県本庄市中央');
ok($zip->set_number('3670054')->is_valid_number, '埼玉県本庄市千代田');
ok($zip->set_number('3670055')->is_valid_number, '埼玉県本庄市若泉');
ok($zip->set_number('3670056')->is_valid_number, '埼玉県本庄市照若町');
ok($zip->set_number('3670061')->is_valid_number, '埼玉県本庄市小島');
ok($zip->set_number('3670062')->is_valid_number, '埼玉県本庄市小島南');
ok($zip->set_number('3670063')->is_valid_number, '埼玉県本庄市下野堂');
ok($zip->set_number('3670064')->is_valid_number, '埼玉県本庄市万年寺');
ok($zip->set_number('3670071')->is_valid_number, '埼玉県本庄市山王堂');
ok($zip->set_number('3670072')->is_valid_number, '埼玉県本庄市沼和田');
ok($zip->set_number('3670073')->is_valid_number, '埼玉県本庄市都島');
ok($zip->set_number('3670074')->is_valid_number, '埼玉県本庄市杉山');
ok($zip->set_number('3670075')->is_valid_number, '埼玉県本庄市新井');
ok($zip->set_number('3670100')->is_valid_number, '埼玉県児玉郡美里町以下に掲載がない場合');
ok($zip->set_number('3670101')->is_valid_number, '埼玉県児玉郡美里町小茂田');
ok($zip->set_number('3670102')->is_valid_number, '埼玉県児玉郡美里町関');
ok($zip->set_number('3670103')->is_valid_number, '埼玉県児玉郡美里町阿那志');
ok($zip->set_number('3670104')->is_valid_number, '埼玉県児玉郡美里町根木');
ok($zip->set_number('3670105')->is_valid_number, '埼玉県児玉郡美里町沼上');
ok($zip->set_number('3670106')->is_valid_number, '埼玉県児玉郡美里町南十条');
ok($zip->set_number('3670107')->is_valid_number, '埼玉県児玉郡美里町北十条');
ok($zip->set_number('3670108')->is_valid_number, '埼玉県児玉郡美里町下児玉');
ok($zip->set_number('3670111')->is_valid_number, '埼玉県児玉郡美里町古郡');
ok($zip->set_number('3670112')->is_valid_number, '埼玉県児玉郡美里町木部');
ok($zip->set_number('3670113')->is_valid_number, '埼玉県児玉郡美里町甘粕');
ok($zip->set_number('3670114')->is_valid_number, '埼玉県児玉郡美里町中里');
ok($zip->set_number('3670115')->is_valid_number, '埼玉県児玉郡美里町猪俣');
ok($zip->set_number('3670116')->is_valid_number, '埼玉県児玉郡美里町円良田');
ok($zip->set_number('3670117')->is_valid_number, '埼玉県児玉郡美里町白石');
ok($zip->set_number('3670118')->is_valid_number, '埼玉県児玉郡美里町広木');
ok($zip->set_number('3670119')->is_valid_number, '埼玉県児玉郡美里町駒衣');
ok($zip->set_number('3670200')->is_valid_number, '埼玉県児玉郡神川町以下に掲載がない場合');
ok($zip->set_number('3670201')->is_valid_number, '埼玉県本庄市児玉町高関');
ok($zip->set_number('3670202')->is_valid_number, '埼玉県本庄市児玉町下浅見');
ok($zip->set_number('3670203')->is_valid_number, '埼玉県本庄市児玉町入浅見');
ok($zip->set_number('3670204')->is_valid_number, '埼玉県本庄市児玉町蛭川');
ok($zip->set_number('3670205')->is_valid_number, '埼玉県本庄市児玉町上真下');
ok($zip->set_number('3670206')->is_valid_number, '埼玉県本庄市児玉町共栄');
ok($zip->set_number('3670207')->is_valid_number, '埼玉県本庄市児玉町下真下');
ok($zip->set_number('3670211')->is_valid_number, '埼玉県本庄市児玉町吉田林');
ok($zip->set_number('3670212')->is_valid_number, '埼玉県本庄市児玉町児玉');
ok($zip->set_number('3670213')->is_valid_number, '埼玉県本庄市児玉町秋山');
ok($zip->set_number('3670214')->is_valid_number, '埼玉県本庄市児玉町小平');
ok($zip->set_number('3670215')->is_valid_number, '埼玉県本庄市児玉町長沖');
ok($zip->set_number('3670216')->is_valid_number, '埼玉県本庄市児玉町金屋');
ok($zip->set_number('3670217')->is_valid_number, '埼玉県本庄市児玉町八幡山');
ok($zip->set_number('3670218')->is_valid_number, '埼玉県本庄市児玉町児玉南');
ok($zip->set_number('3670221')->is_valid_number, '埼玉県本庄市児玉町保木野');
ok($zip->set_number('3670222')->is_valid_number, '埼玉県本庄市児玉町田端');
ok($zip->set_number('3670223')->is_valid_number, '埼玉県本庄市児玉町塩谷');
ok($zip->set_number('3670224')->is_valid_number, '埼玉県本庄市児玉町高柳');
ok($zip->set_number('3670225')->is_valid_number, '埼玉県本庄市児玉町飯倉');
ok($zip->set_number('3670226')->is_valid_number, '埼玉県本庄市児玉町宮内');
ok($zip->set_number('3670231')->is_valid_number, '埼玉県児玉郡神川町中新里');
ok($zip->set_number('3670232')->is_valid_number, '埼玉県児玉郡神川町新里');
ok($zip->set_number('3670233')->is_valid_number, '埼玉県児玉郡神川町二ノ宮');
ok($zip->set_number('3670234')->is_valid_number, '埼玉県児玉郡神川町池田');
ok($zip->set_number('3670235')->is_valid_number, '埼玉県児玉郡神川町新宿');
ok($zip->set_number('3670236')->is_valid_number, '埼玉県児玉郡神川町小浜');
ok($zip->set_number('3670237')->is_valid_number, '埼玉県児玉郡神川町貫井');
ok($zip->set_number('3670238')->is_valid_number, '埼玉県児玉郡神川町肥土');
ok($zip->set_number('3670241')->is_valid_number, '埼玉県児玉郡神川町元原');
ok($zip->set_number('3670242')->is_valid_number, '埼玉県児玉郡神川町原新田');
ok($zip->set_number('3670243')->is_valid_number, '埼玉県児玉郡神川町熊野堂');
ok($zip->set_number('3670244')->is_valid_number, '埼玉県児玉郡神川町八日市');
ok($zip->set_number('3670245')->is_valid_number, '埼玉県児玉郡神川町植竹');
ok($zip->set_number('3670246')->is_valid_number, '埼玉県児玉郡神川町関口');
ok($zip->set_number('3670247')->is_valid_number, '埼玉県児玉郡神川町元阿保');
ok($zip->set_number('3670248')->is_valid_number, '埼玉県児玉郡神川町四軒在家');
ok($zip->set_number('3670251')->is_valid_number, '埼玉県本庄市児玉町稲沢');
ok($zip->set_number('3670252')->is_valid_number, '埼玉県本庄市児玉町元田');
ok($zip->set_number('3670253')->is_valid_number, '埼玉県本庄市児玉町河内');
ok($zip->set_number('3670254')->is_valid_number, '埼玉県本庄市児玉町太駄');
ok($zip->set_number('3670301')->is_valid_number, '埼玉県児玉郡神川町渡瀬');
ok($zip->set_number('3670311')->is_valid_number, '埼玉県児玉郡神川町下阿久原');
ok($zip->set_number('3670312')->is_valid_number, '埼玉県児玉郡神川町上阿久原');
ok($zip->set_number('3670313')->is_valid_number, '埼玉県児玉郡神川町矢納');
ok($zip->set_number('3680000')->is_valid_number, '埼玉県秩父市以下に掲載がない場合');
ok($zip->set_number('3680000')->is_valid_number, '埼玉県秩父郡横瀬町以下に掲載がない場合');
ok($zip->set_number('3680001')->is_valid_number, '埼玉県秩父市黒谷');
ok($zip->set_number('3680002')->is_valid_number, '埼玉県秩父市栃谷');
ok($zip->set_number('3680003')->is_valid_number, '埼玉県秩父市定峰');
ok($zip->set_number('3680004')->is_valid_number, '埼玉県秩父市山田');
ok($zip->set_number('3680005')->is_valid_number, '埼玉県秩父市大野原');
ok($zip->set_number('3680011')->is_valid_number, '埼玉県秩父市大畑町');
ok($zip->set_number('3680012')->is_valid_number, '埼玉県秩父市滝の上町');
ok($zip->set_number('3680013')->is_valid_number, '埼玉県秩父市永田町');
ok($zip->set_number('3680014')->is_valid_number, '埼玉県秩父市金室町');
ok($zip->set_number('3680015')->is_valid_number, '埼玉県秩父市柳田町');
ok($zip->set_number('3680016')->is_valid_number, '埼玉県秩父市阿保町');
ok($zip->set_number('3680021')->is_valid_number, '埼玉県秩父市下宮地町');
ok($zip->set_number('3680022')->is_valid_number, '埼玉県秩父市中宮地町');
ok($zip->set_number('3680023')->is_valid_number, '埼玉県秩父市大宮');
ok($zip->set_number('3680024')->is_valid_number, '埼玉県秩父市上宮地町');
ok($zip->set_number('3680025')->is_valid_number, '埼玉県秩父市桜木町');
ok($zip->set_number('3680026')->is_valid_number, '埼玉県秩父市相生町');
ok($zip->set_number('3680031')->is_valid_number, '埼玉県秩父市上野町');
ok($zip->set_number('3680032')->is_valid_number, '埼玉県秩父市熊木町');
ok($zip->set_number('3680033')->is_valid_number, '埼玉県秩父市野坂町');
ok($zip->set_number('3680034')->is_valid_number, '埼玉県秩父市日野田町');
ok($zip->set_number('3680035')->is_valid_number, '埼玉県秩父市上町');
ok($zip->set_number('3680041')->is_valid_number, '埼玉県秩父市番場町');
ok($zip->set_number('3680042')->is_valid_number, '埼玉県秩父市東町');
ok($zip->set_number('3680043')->is_valid_number, '埼玉県秩父市中町');
ok($zip->set_number('3680044')->is_valid_number, '埼玉県秩父市本町');
ok($zip->set_number('3680045')->is_valid_number, '埼玉県秩父市道生町');
ok($zip->set_number('3680046')->is_valid_number, '埼玉県秩父市宮側町');
ok($zip->set_number('3680051')->is_valid_number, '埼玉県秩父市中村町');
ok($zip->set_number('3680052')->is_valid_number, '埼玉県秩父市近戸町');
ok($zip->set_number('3680053')->is_valid_number, '埼玉県秩父市久那');
ok($zip->set_number('3680054')->is_valid_number, '埼玉県秩父市別所');
ok($zip->set_number('3680055')->is_valid_number, '埼玉県秩父市田村');
ok($zip->set_number('3680056')->is_valid_number, '埼玉県秩父市寺尾');
ok($zip->set_number('3680061')->is_valid_number, '埼玉県秩父市小柱');
ok($zip->set_number('3680062')->is_valid_number, '埼玉県秩父市蒔田');
ok($zip->set_number('3680063')->is_valid_number, '埼玉県秩父市伊古田');
ok($zip->set_number('3680064')->is_valid_number, '埼玉県秩父市品沢');
ok($zip->set_number('3680065')->is_valid_number, '埼玉県秩父市太田');
ok($zip->set_number('3680066')->is_valid_number, '埼玉県秩父市堀切');
ok($zip->set_number('3680067')->is_valid_number, '埼玉県秩父市みどりが丘');
ok($zip->set_number('3680071')->is_valid_number, '埼玉県秩父郡横瀬町芦ケ久保');
ok($zip->set_number('3680072')->is_valid_number, '埼玉県秩父郡横瀬町横瀬');
ok($zip->set_number('3680100')->is_valid_number, '埼玉県秩父郡小鹿野町以下に掲載がない場合');
ok($zip->set_number('3680101')->is_valid_number, '埼玉県秩父郡小鹿野町下小鹿野');
ok($zip->set_number('3680102')->is_valid_number, '埼玉県秩父郡小鹿野町長留');
ok($zip->set_number('3680103')->is_valid_number, '埼玉県秩父郡小鹿野町般若');
ok($zip->set_number('3680104')->is_valid_number, '埼玉県秩父郡小鹿野町伊豆沢');
ok($zip->set_number('3680105')->is_valid_number, '埼玉県秩父郡小鹿野町小鹿野');
ok($zip->set_number('3680111')->is_valid_number, '埼玉県秩父郡小鹿野町飯田');
ok($zip->set_number('3680112')->is_valid_number, '埼玉県秩父郡小鹿野町三山');
ok($zip->set_number('3680113')->is_valid_number, '埼玉県秩父郡小鹿野町河原沢');
ok($zip->set_number('3680114')->is_valid_number, '埼玉県秩父郡小鹿野町藤倉');
ok($zip->set_number('3680115')->is_valid_number, '埼玉県秩父郡小鹿野町日尾');
ok($zip->set_number('3680201')->is_valid_number, '埼玉県秩父郡小鹿野町両神薄');
ok($zip->set_number('3680202')->is_valid_number, '埼玉県秩父郡小鹿野町両神小森');
ok($zip->set_number('3690101')->is_valid_number, '埼玉県熊谷市津田');
ok($zip->set_number('3690102')->is_valid_number, '埼玉県熊谷市玉作');
ok($zip->set_number('3690103')->is_valid_number, '埼玉県熊谷市小八林');
ok($zip->set_number('3690104')->is_valid_number, '埼玉県熊谷市冑山');
ok($zip->set_number('3690105')->is_valid_number, '埼玉県熊谷市箕輪');
ok($zip->set_number('3690106')->is_valid_number, '埼玉県熊谷市相上');
ok($zip->set_number('3690107')->is_valid_number, '埼玉県熊谷市向谷');
ok($zip->set_number('3690108')->is_valid_number, '埼玉県熊谷市船木台');
ok($zip->set_number('3690111')->is_valid_number, '埼玉県鴻巣市新宿');
ok($zip->set_number('3690112')->is_valid_number, '埼玉県鴻巣市鎌塚');
ok($zip->set_number('3690113')->is_valid_number, '埼玉県鴻巣市下忍');
ok($zip->set_number('3690114')->is_valid_number, '埼玉県鴻巣市筑波');
ok($zip->set_number('3690115')->is_valid_number, '埼玉県鴻巣市吹上本町');
ok($zip->set_number('3690116')->is_valid_number, '埼玉県鴻巣市北新宿');
ok($zip->set_number('3690121')->is_valid_number, '埼玉県鴻巣市吹上富士見');
ok($zip->set_number('3690122')->is_valid_number, '埼玉県鴻巣市南');
ok($zip->set_number('3690123')->is_valid_number, '埼玉県鴻巣市榎戸');
ok($zip->set_number('3690124')->is_valid_number, '埼玉県鴻巣市荊原');
ok($zip->set_number('3690131')->is_valid_number, '埼玉県鴻巣市袋');
ok($zip->set_number('3690132')->is_valid_number, '埼玉県鴻巣市前砂');
ok($zip->set_number('3690133')->is_valid_number, '埼玉県鴻巣市小谷');
ok($zip->set_number('3690134')->is_valid_number, '埼玉県鴻巣市三町免');
ok($zip->set_number('3690135')->is_valid_number, '埼玉県鴻巣市明用');
ok($zip->set_number('3690136')->is_valid_number, '埼玉県鴻巣市吹上');
ok($zip->set_number('3690137')->is_valid_number, '埼玉県鴻巣市大芦');
ok($zip->set_number('3690201')->is_valid_number, '埼玉県深谷市岡');
ok($zip->set_number('3690202')->is_valid_number, '埼玉県深谷市岡里');
ok($zip->set_number('3690203')->is_valid_number, '埼玉県深谷市普済寺');
ok($zip->set_number('3690211')->is_valid_number, '埼玉県深谷市岡部');
ok($zip->set_number('3690212')->is_valid_number, '埼玉県深谷市櫛挽');
ok($zip->set_number('3690213')->is_valid_number, '埼玉県深谷市針ケ谷');
ok($zip->set_number('3690214')->is_valid_number, '埼玉県深谷市本郷');
ok($zip->set_number('3690215')->is_valid_number, '埼玉県深谷市今泉');
ok($zip->set_number('3690216')->is_valid_number, '埼玉県深谷市山崎');
ok($zip->set_number('3690217')->is_valid_number, '埼玉県深谷市山河');
ok($zip->set_number('3690221')->is_valid_number, '埼玉県深谷市榛沢新田');
ok($zip->set_number('3690222')->is_valid_number, '埼玉県深谷市後榛沢');
ok($zip->set_number('3690223')->is_valid_number, '埼玉県深谷市榛沢');
ok($zip->set_number('3690224')->is_valid_number, '埼玉県深谷市西田');
ok($zip->set_number('3690225')->is_valid_number, '埼玉県深谷市沓掛');
ok($zip->set_number('3690300')->is_valid_number, '埼玉県児玉郡上里町以下に掲載がない場合');
ok($zip->set_number('3690301')->is_valid_number, '埼玉県児玉郡上里町金久保');
ok($zip->set_number('3690302')->is_valid_number, '埼玉県児玉郡上里町黛');
ok($zip->set_number('3690303')->is_valid_number, '埼玉県児玉郡上里町忍保');
ok($zip->set_number('3690304')->is_valid_number, '埼玉県児玉郡上里町八町河原');
ok($zip->set_number('3690305')->is_valid_number, '埼玉県児玉郡上里町神保原町');
ok($zip->set_number('3690306')->is_valid_number, '埼玉県児玉郡上里町七本木');
ok($zip->set_number('3690307')->is_valid_number, '埼玉県児玉郡上里町嘉美');
ok($zip->set_number('3690308')->is_valid_number, '埼玉県児玉郡上里町毘沙吐');
ok($zip->set_number('3690311')->is_valid_number, '埼玉県児玉郡上里町勅使河原');
ok($zip->set_number('3690312')->is_valid_number, '埼玉県児玉郡上里町帯刀');
ok($zip->set_number('3690313')->is_valid_number, '埼玉県児玉郡上里町堤');
ok($zip->set_number('3690314')->is_valid_number, '埼玉県児玉郡上里町三町');
ok($zip->set_number('3690315')->is_valid_number, '埼玉県児玉郡上里町大御堂');
ok($zip->set_number('3690316')->is_valid_number, '埼玉県児玉郡上里町長浜');
ok($zip->set_number('3690317')->is_valid_number, '埼玉県児玉郡上里町五明');
ok($zip->set_number('3690318')->is_valid_number, '埼玉県児玉郡上里町藤木戸');
ok($zip->set_number('3691101')->is_valid_number, '埼玉県深谷市長在家');
ok($zip->set_number('3691102')->is_valid_number, '埼玉県深谷市瀬山');
ok($zip->set_number('3691103')->is_valid_number, '埼玉県深谷市川本明戸');
ok($zip->set_number('3691104')->is_valid_number, '埼玉県深谷市菅沼');
ok($zip->set_number('3691105')->is_valid_number, '埼玉県深谷市本田');
ok($zip->set_number('3691106')->is_valid_number, '埼玉県深谷市白草台');
ok($zip->set_number('3691107')->is_valid_number, '埼玉県深谷市畠山');
ok($zip->set_number('3691108')->is_valid_number, '埼玉県深谷市田中');
ok($zip->set_number('3691109')->is_valid_number, '埼玉県深谷市上原');
ok($zip->set_number('3691111')->is_valid_number, '埼玉県深谷市武川');
ok($zip->set_number('3691200')->is_valid_number, '埼玉県大里郡寄居町以下に掲載がない場合');
ok($zip->set_number('3691201')->is_valid_number, '埼玉県大里郡寄居町用土');
ok($zip->set_number('3691202')->is_valid_number, '埼玉県大里郡寄居町桜沢');
ok($zip->set_number('3691203')->is_valid_number, '埼玉県大里郡寄居町寄居');
ok($zip->set_number('3691204')->is_valid_number, '埼玉県大里郡寄居町藤田');
ok($zip->set_number('3691205')->is_valid_number, '埼玉県大里郡寄居町末野');
ok($zip->set_number('3691211')->is_valid_number, '埼玉県大里郡寄居町赤浜');
ok($zip->set_number('3691212')->is_valid_number, '埼玉県大里郡寄居町西古里');
ok($zip->set_number('3691213')->is_valid_number, '埼玉県大里郡寄居町鷹巣');
ok($zip->set_number('3691214')->is_valid_number, '埼玉県大里郡寄居町今市');
ok($zip->set_number('3691215')->is_valid_number, '埼玉県大里郡寄居町牟礼');
ok($zip->set_number('3691216')->is_valid_number, '埼玉県大里郡寄居町富田');
ok($zip->set_number('3691217')->is_valid_number, '埼玉県大里郡寄居町小園');
ok($zip->set_number('3691221')->is_valid_number, '埼玉県大里郡寄居町保田原');
ok($zip->set_number('3691222')->is_valid_number, '埼玉県大里郡寄居町露梨子');
ok($zip->set_number('3691223')->is_valid_number, '埼玉県大里郡寄居町三ケ山');
ok($zip->set_number('3691224')->is_valid_number, '埼玉県大里郡寄居町鉢形');
ok($zip->set_number('3691225')->is_valid_number, '埼玉県大里郡寄居町西ノ入');
ok($zip->set_number('3691231')->is_valid_number, '埼玉県大里郡寄居町立原');
ok($zip->set_number('3691232')->is_valid_number, '埼玉県大里郡寄居町三品');
ok($zip->set_number('3691233')->is_valid_number, '埼玉県大里郡寄居町秋山');
ok($zip->set_number('3691234')->is_valid_number, '埼玉県大里郡寄居町折原');
ok($zip->set_number('3691235')->is_valid_number, '埼玉県大里郡寄居町風布');
ok($zip->set_number('3691236')->is_valid_number, '埼玉県大里郡寄居町金尾');
ok($zip->set_number('3691241')->is_valid_number, '埼玉県深谷市武蔵野');
ok($zip->set_number('3691242')->is_valid_number, '埼玉県深谷市北根');
ok($zip->set_number('3691243')->is_valid_number, '埼玉県深谷市永田');
ok($zip->set_number('3691244')->is_valid_number, '埼玉県深谷市黒田');
ok($zip->set_number('3691245')->is_valid_number, '埼玉県深谷市荒川');
ok($zip->set_number('3691246')->is_valid_number, '埼玉県深谷市小前田');
ok($zip->set_number('3691247')->is_valid_number, '埼玉県深谷市緑台');
ok($zip->set_number('3691248')->is_valid_number, '埼玉県深谷市花園');
ok($zip->set_number('3691300')->is_valid_number, '埼玉県秩父郡長瀞町以下に掲載がない場合');
ok($zip->set_number('3691301')->is_valid_number, '埼玉県秩父郡長瀞町矢那瀬');
ok($zip->set_number('3691302')->is_valid_number, '埼玉県秩父郡長瀞町野上下郷');
ok($zip->set_number('3691303')->is_valid_number, '埼玉県秩父郡長瀞町中野上');
ok($zip->set_number('3691304')->is_valid_number, '埼玉県秩父郡長瀞町本野上');
ok($zip->set_number('3691305')->is_valid_number, '埼玉県秩父郡長瀞町長瀞');
ok($zip->set_number('3691311')->is_valid_number, '埼玉県秩父郡長瀞町岩田');
ok($zip->set_number('3691312')->is_valid_number, '埼玉県秩父郡長瀞町井戸');
ok($zip->set_number('3691313')->is_valid_number, '埼玉県秩父郡長瀞町風布');
ok($zip->set_number('3691400')->is_valid_number, '埼玉県秩父郡皆野町以下に掲載がない場合');
ok($zip->set_number('3691411')->is_valid_number, '埼玉県秩父郡皆野町三沢');
ok($zip->set_number('3691412')->is_valid_number, '埼玉県秩父郡皆野町皆野');
ok($zip->set_number('3691413')->is_valid_number, '埼玉県秩父郡皆野町下田野');
ok($zip->set_number('3691501')->is_valid_number, '埼玉県秩父市吉田久長');
ok($zip->set_number('3691502')->is_valid_number, '埼玉県秩父市吉田阿熊');
ok($zip->set_number('3691503')->is_valid_number, '埼玉県秩父市下吉田');
ok($zip->set_number('3691504')->is_valid_number, '埼玉県秩父市吉田石間');
ok($zip->set_number('3691505')->is_valid_number, '埼玉県秩父市上吉田');
ok($zip->set_number('3691601')->is_valid_number, '埼玉県秩父郡皆野町金沢');
ok($zip->set_number('3691621')->is_valid_number, '埼玉県秩父郡皆野町金崎');
ok($zip->set_number('3691622')->is_valid_number, '埼玉県秩父郡皆野町国神');
ok($zip->set_number('3691623')->is_valid_number, '埼玉県秩父郡皆野町大淵');
ok($zip->set_number('3691624')->is_valid_number, '埼玉県秩父郡皆野町野巻');
ok($zip->set_number('3691625')->is_valid_number, '埼玉県秩父郡皆野町下日野沢');
ok($zip->set_number('3691626')->is_valid_number, '埼玉県秩父郡皆野町上日野沢');
ok($zip->set_number('3691801')->is_valid_number, '埼玉県秩父市荒川久那');
ok($zip->set_number('3691802')->is_valid_number, '埼玉県秩父市荒川上田野');
ok($zip->set_number('3691803')->is_valid_number, '埼玉県秩父市荒川日野');
ok($zip->set_number('3691804')->is_valid_number, '埼玉県秩父市荒川小野原');
ok($zip->set_number('3691871')->is_valid_number, '埼玉県秩父市下影森');
ok($zip->set_number('3691872')->is_valid_number, '埼玉県秩父市上影森');
ok($zip->set_number('3691873')->is_valid_number, '埼玉県秩父市浦山');
ok($zip->set_number('3691874')->is_valid_number, '埼玉県秩父市和泉町');
ok($zip->set_number('3691901')->is_valid_number, '埼玉県秩父市大滝');
ok($zip->set_number('3691902')->is_valid_number, '埼玉県秩父市三峰');
ok($zip->set_number('3691903')->is_valid_number, '埼玉県秩父市中津川');
ok($zip->set_number('3691911')->is_valid_number, '埼玉県秩父市荒川贄川');
ok($zip->set_number('3691912')->is_valid_number, '埼玉県秩父市荒川白久');
ok($zip->set_number('3700000')->is_valid_number, '群馬県高崎市以下に掲載がない場合');
ok($zip->set_number('3700001')->is_valid_number, '群馬県高崎市中尾町');
ok($zip->set_number('3700002')->is_valid_number, '群馬県高崎市日高町');
ok($zip->set_number('3700003')->is_valid_number, '群馬県高崎市新保田中町');
ok($zip->set_number('3700004')->is_valid_number, '群馬県高崎市井野町');
ok($zip->set_number('3700005')->is_valid_number, '群馬県高崎市浜尻町');
ok($zip->set_number('3700006')->is_valid_number, '群馬県高崎市問屋町');
ok($zip->set_number('3700007')->is_valid_number, '群馬県高崎市問屋町西');
ok($zip->set_number('3700008')->is_valid_number, '群馬県高崎市正観寺町');
ok($zip->set_number('3700011')->is_valid_number, '群馬県高崎市京目町');
ok($zip->set_number('3700012')->is_valid_number, '群馬県高崎市大沢町');
ok($zip->set_number('3700013')->is_valid_number, '群馬県高崎市萩原町');
ok($zip->set_number('3700014')->is_valid_number, '群馬県高崎市元島名町');
ok($zip->set_number('3700015')->is_valid_number, '群馬県高崎市島野町');
ok($zip->set_number('3700016')->is_valid_number, '群馬県高崎市矢島町');
ok($zip->set_number('3700017')->is_valid_number, '群馬県高崎市西島町');
ok($zip->set_number('3700018')->is_valid_number, '群馬県高崎市新保町');
ok($zip->set_number('3700021')->is_valid_number, '群馬県高崎市西横手町');
ok($zip->set_number('3700022')->is_valid_number, '群馬県高崎市宿横手町');
ok($zip->set_number('3700023')->is_valid_number, '群馬県高崎市中島町');
ok($zip->set_number('3700024')->is_valid_number, '群馬県高崎市八幡原町');
ok($zip->set_number('3700025')->is_valid_number, '群馬県高崎市下斉田町');
ok($zip->set_number('3700026')->is_valid_number, '群馬県高崎市下滝町');
ok($zip->set_number('3700027')->is_valid_number, '群馬県高崎市上滝町');
ok($zip->set_number('3700031')->is_valid_number, '群馬県高崎市上大類町');
ok($zip->set_number('3700032')->is_valid_number, '群馬県高崎市宿大類町');
ok($zip->set_number('3700033')->is_valid_number, '群馬県高崎市中大類町');
ok($zip->set_number('3700034')->is_valid_number, '群馬県高崎市下大類町');
ok($zip->set_number('3700035')->is_valid_number, '群馬県高崎市柴崎町');
ok($zip->set_number('3700036')->is_valid_number, '群馬県高崎市南大類町');
ok($zip->set_number('3700041')->is_valid_number, '群馬県高崎市東貝沢町');
ok($zip->set_number('3700042')->is_valid_number, '群馬県高崎市貝沢町');
ok($zip->set_number('3700043')->is_valid_number, '群馬県高崎市高関町');
ok($zip->set_number('3700044')->is_valid_number, '群馬県高崎市岩押町');
ok($zip->set_number('3700045')->is_valid_number, '群馬県高崎市東町');
ok($zip->set_number('3700046')->is_valid_number, '群馬県高崎市江木町');
ok($zip->set_number('3700047')->is_valid_number, '群馬県高崎市高砂町');
ok($zip->set_number('3700048')->is_valid_number, '群馬県高崎市日光町');
ok($zip->set_number('3700051')->is_valid_number, '群馬県高崎市弓町');
ok($zip->set_number('3700052')->is_valid_number, '群馬県高崎市旭町');
ok($zip->set_number('3700053')->is_valid_number, '群馬県高崎市通町');
ok($zip->set_number('3700054')->is_valid_number, '群馬県高崎市真町');
ok($zip->set_number('3700055')->is_valid_number, '群馬県高崎市羅漢町');
ok($zip->set_number('3700056')->is_valid_number, '群馬県高崎市北通町');
ok($zip->set_number('3700057')->is_valid_number, '群馬県高崎市元紺屋町');
ok($zip->set_number('3700058')->is_valid_number, '群馬県高崎市九蔵町');
ok($zip->set_number('3700059')->is_valid_number, '群馬県高崎市椿町');
ok($zip->set_number('3700061')->is_valid_number, '群馬県高崎市天神町');
ok($zip->set_number('3700062')->is_valid_number, '群馬県高崎市稲荷町');
ok($zip->set_number('3700063')->is_valid_number, '群馬県高崎市飯玉町');
ok($zip->set_number('3700064')->is_valid_number, '群馬県高崎市芝塚町');
ok($zip->set_number('3700065')->is_valid_number, '群馬県高崎市末広町');
ok($zip->set_number('3700066')->is_valid_number, '群馬県高崎市山田町');
ok($zip->set_number('3700067')->is_valid_number, '群馬県高崎市請地町');
ok($zip->set_number('3700068')->is_valid_number, '群馬県高崎市昭和町');
ok($zip->set_number('3700069')->is_valid_number, '群馬県高崎市飯塚町');
ok($zip->set_number('3700071')->is_valid_number, '群馬県高崎市小八木町');
ok($zip->set_number('3700072')->is_valid_number, '群馬県高崎市大八木町');
ok($zip->set_number('3700073')->is_valid_number, '群馬県高崎市緑町');
ok($zip->set_number('3700074')->is_valid_number, '群馬県高崎市下小鳥町');
ok($zip->set_number('3700075')->is_valid_number, '群馬県高崎市筑縄町');
ok($zip->set_number('3700076')->is_valid_number, '群馬県高崎市下小塙町');
ok($zip->set_number('3700077')->is_valid_number, '群馬県高崎市上小塙町');
ok($zip->set_number('3700078')->is_valid_number, '群馬県高崎市上小鳥町');
ok($zip->set_number('3700081')->is_valid_number, '群馬県高崎市浜川町');
ok($zip->set_number('3700082')->is_valid_number, '群馬県高崎市北新波町');
ok($zip->set_number('3700083')->is_valid_number, '群馬県高崎市南新波町');
ok($zip->set_number('3700084')->is_valid_number, '群馬県高崎市菊地町');
ok($zip->set_number('3700085')->is_valid_number, '群馬県高崎市我峰町');
ok($zip->set_number('3700086')->is_valid_number, '群馬県高崎市沖町');
ok($zip->set_number('3700087')->is_valid_number, '群馬県高崎市楽間町');
ok($zip->set_number('3700088')->is_valid_number, '群馬県高崎市行力町');
ok($zip->set_number('3700101')->is_valid_number, '群馬県伊勢崎市境東新井');
ok($zip->set_number('3700102')->is_valid_number, '群馬県伊勢崎市境上渕名');
ok($zip->set_number('3700103')->is_valid_number, '群馬県伊勢崎市境下渕名');
ok($zip->set_number('3700104')->is_valid_number, '群馬県伊勢崎市境木島');
ok($zip->set_number('3700105')->is_valid_number, '群馬県伊勢崎市境伊与久');
ok($zip->set_number('3700111')->is_valid_number, '群馬県伊勢崎市境上矢島');
ok($zip->set_number('3700112')->is_valid_number, '群馬県伊勢崎市境西今井');
ok($zip->set_number('3700113')->is_valid_number, '群馬県伊勢崎市境三ツ木');
ok($zip->set_number('3700114')->is_valid_number, '群馬県伊勢崎市境新栄');
ok($zip->set_number('3700115')->is_valid_number, '群馬県伊勢崎市境美原');
ok($zip->set_number('3700116')->is_valid_number, '群馬県伊勢崎市境百々東');
ok($zip->set_number('3700117')->is_valid_number, '群馬県伊勢崎市境百々');
ok($zip->set_number('3700121')->is_valid_number, '群馬県伊勢崎市境女塚');
ok($zip->set_number('3700122')->is_valid_number, '群馬県伊勢崎市境栄');
ok($zip->set_number('3700123')->is_valid_number, '群馬県伊勢崎市境東');
ok($zip->set_number('3700124')->is_valid_number, '群馬県伊勢崎市境');
ok($zip->set_number('3700125')->is_valid_number, '群馬県伊勢崎市境萩原');
ok($zip->set_number('3700126')->is_valid_number, '群馬県伊勢崎市境下武士');
ok($zip->set_number('3700127')->is_valid_number, '群馬県伊勢崎市境上武士');
ok($zip->set_number('3700128')->is_valid_number, '群馬県伊勢崎市境保泉');
ok($zip->set_number('3700131')->is_valid_number, '群馬県伊勢崎市境米岡');
ok($zip->set_number('3700132')->is_valid_number, '群馬県伊勢崎市境平塚');
ok($zip->set_number('3700133')->is_valid_number, '群馬県伊勢崎市境中島');
ok($zip->set_number('3700134')->is_valid_number, '群馬県伊勢崎市境島村');
ok($zip->set_number('3700135')->is_valid_number, '群馬県伊勢崎市境小此木');
ok($zip->set_number('3700301')->is_valid_number, '群馬県太田市新田天良町');
ok($zip->set_number('3700302')->is_valid_number, '群馬県太田市新田小金町');
ok($zip->set_number('3700303')->is_valid_number, '群馬県太田市新田小金井町');
ok($zip->set_number('3700304')->is_valid_number, '群馬県太田市新田市町');
ok($zip->set_number('3700305')->is_valid_number, '群馬県太田市新田多村新田町');
ok($zip->set_number('3700306')->is_valid_number, '群馬県太田市新田市野倉町');
ok($zip->set_number('3700311')->is_valid_number, '群馬県太田市新田瑞木町');
ok($zip->set_number('3700312')->is_valid_number, '群馬県太田市新田村田町');
ok($zip->set_number('3700313')->is_valid_number, '群馬県太田市新田反町町');
ok($zip->set_number('3700314')->is_valid_number, '群馬県太田市新田市野井町');
ok($zip->set_number('3700321')->is_valid_number, '群馬県太田市新田木崎町');
ok($zip->set_number('3700331')->is_valid_number, '群馬県太田市新田赤堀町');
ok($zip->set_number('3700332')->is_valid_number, '群馬県太田市新田中江田町');
ok($zip->set_number('3700333')->is_valid_number, '群馬県太田市新田下江田町');
ok($zip->set_number('3700334')->is_valid_number, '群馬県太田市新田高尾町');
ok($zip->set_number('3700341')->is_valid_number, '群馬県太田市新田金井町');
ok($zip->set_number('3700342')->is_valid_number, '群馬県太田市新田上江田町');
ok($zip->set_number('3700343')->is_valid_number, '群馬県太田市新田下田中町');
ok($zip->set_number('3700344')->is_valid_number, '群馬県太田市新田早川町');
ok($zip->set_number('3700345')->is_valid_number, '群馬県太田市新田花香塚町');
ok($zip->set_number('3700346')->is_valid_number, '群馬県太田市新田上田中町');
ok($zip->set_number('3700347')->is_valid_number, '群馬県太田市新田大根町');
ok($zip->set_number('3700351')->is_valid_number, '群馬県太田市新田大町');
ok($zip->set_number('3700352')->is_valid_number, '群馬県太田市新田嘉祢町');
ok($zip->set_number('3700353')->is_valid_number, '群馬県太田市新田上中町');
ok($zip->set_number('3700354')->is_valid_number, '群馬県太田市新田溜池町');
ok($zip->set_number('3700355')->is_valid_number, '群馬県太田市新田権右衛門町');
ok($zip->set_number('3700356')->is_valid_number, '群馬県太田市新田萩町');
ok($zip->set_number('3700401')->is_valid_number, '群馬県太田市尾島町');
ok($zip->set_number('3700402')->is_valid_number, '群馬県太田市阿久津町');
ok($zip->set_number('3700403')->is_valid_number, '群馬県太田市岩松町');
ok($zip->set_number('3700404')->is_valid_number, '群馬県太田市備前島町');
ok($zip->set_number('3700405')->is_valid_number, '群馬県太田市押切町');
ok($zip->set_number('3700406')->is_valid_number, '群馬県太田市前小屋町');
ok($zip->set_number('3700411')->is_valid_number, '群馬県太田市亀岡町');
ok($zip->set_number('3700412')->is_valid_number, '群馬県太田市太子町');
ok($zip->set_number('3700413')->is_valid_number, '群馬県太田市すずかけ町');
ok($zip->set_number('3700414')->is_valid_number, '群馬県太田市堀口町');
ok($zip->set_number('3700415')->is_valid_number, '群馬県太田市南ケ丘町');
ok($zip->set_number('3700416')->is_valid_number, '群馬県太田市前島町');
ok($zip->set_number('3700417')->is_valid_number, '群馬県太田市二ツ小屋町');
ok($zip->set_number('3700418')->is_valid_number, '群馬県太田市武蔵島町');
ok($zip->set_number('3700421')->is_valid_number, '群馬県太田市粕川町');
ok($zip->set_number('3700422')->is_valid_number, '群馬県太田市安養寺町');
ok($zip->set_number('3700423')->is_valid_number, '群馬県太田市大舘町');
ok($zip->set_number('3700424')->is_valid_number, '群馬県太田市出塚町');
ok($zip->set_number('3700425')->is_valid_number, '群馬県太田市徳川町');
ok($zip->set_number('3700426')->is_valid_number, '群馬県太田市世良田町');
ok($zip->set_number('3700427')->is_valid_number, '群馬県太田市小角田町');
ok($zip->set_number('3700500')->is_valid_number, '群馬県邑楽郡千代田町以下に掲載がない場合');
ok($zip->set_number('3700500')->is_valid_number, '群馬県邑楽郡大泉町以下に掲載がない場合');
ok($zip->set_number('3700501')->is_valid_number, '群馬県邑楽郡千代田町福島');
ok($zip->set_number('3700502')->is_valid_number, '群馬県邑楽郡千代田町鍋谷');
ok($zip->set_number('3700503')->is_valid_number, '群馬県邑楽郡千代田町赤岩');
ok($zip->set_number('3700504')->is_valid_number, '群馬県邑楽郡千代田町舞木');
ok($zip->set_number('3700505')->is_valid_number, '群馬県邑楽郡千代田町新福寺');
ok($zip->set_number('3700506')->is_valid_number, '群馬県邑楽郡千代田町赤岩西');
ok($zip->set_number('3700507')->is_valid_number, '群馬県邑楽郡千代田町舞木東');
ok($zip->set_number('3700511')->is_valid_number, '群馬県邑楽郡大泉町北小泉');
ok($zip->set_number('3700512')->is_valid_number, '群馬県邑楽郡大泉町上小泉');
ok($zip->set_number('3700513')->is_valid_number, '群馬県邑楽郡大泉町東小泉');
ok($zip->set_number('3700514')->is_valid_number, '群馬県邑楽郡大泉町朝日');
ok($zip->set_number('3700515')->is_valid_number, '群馬県邑楽郡大泉町下小泉');
ok($zip->set_number('3700516')->is_valid_number, '群馬県邑楽郡大泉町中央');
ok($zip->set_number('3700517')->is_valid_number, '群馬県邑楽郡大泉町西小泉');
ok($zip->set_number('3700518')->is_valid_number, '群馬県邑楽郡大泉町城之内');
ok($zip->set_number('3700521')->is_valid_number, '群馬県邑楽郡大泉町住吉');
ok($zip->set_number('3700522')->is_valid_number, '群馬県邑楽郡大泉町富士');
ok($zip->set_number('3700523')->is_valid_number, '群馬県邑楽郡大泉町吉田');
ok($zip->set_number('3700524')->is_valid_number, '群馬県邑楽郡大泉町古海');
ok($zip->set_number('3700525')->is_valid_number, '群馬県邑楽郡大泉町日の出');
ok($zip->set_number('3700531')->is_valid_number, '群馬県邑楽郡大泉町いずみ');
ok($zip->set_number('3700532')->is_valid_number, '群馬県邑楽郡大泉町坂田');
ok($zip->set_number('3700533')->is_valid_number, '群馬県邑楽郡大泉町仙石');
ok($zip->set_number('3700534')->is_valid_number, '群馬県邑楽郡大泉町丘山');
ok($zip->set_number('3700535')->is_valid_number, '群馬県邑楽郡大泉町寄木戸');
ok($zip->set_number('3700536')->is_valid_number, '群馬県邑楽郡大泉町古氷');
ok($zip->set_number('3700600')->is_valid_number, '群馬県邑楽郡邑楽町以下に掲載がない場合');
ok($zip->set_number('3700601')->is_valid_number, '群馬県邑楽郡邑楽町鶉');
ok($zip->set_number('3700602')->is_valid_number, '群馬県邑楽郡邑楽町明野');
ok($zip->set_number('3700603')->is_valid_number, '群馬県邑楽郡邑楽町中野');
ok($zip->set_number('3700604')->is_valid_number, '群馬県邑楽郡邑楽町石打');
ok($zip->set_number('3700605')->is_valid_number, '群馬県邑楽郡邑楽町藤川');
ok($zip->set_number('3700606')->is_valid_number, '群馬県邑楽郡邑楽町秋妻');
ok($zip->set_number('3700611')->is_valid_number, '群馬県邑楽郡邑楽町鶉新田');
ok($zip->set_number('3700612')->is_valid_number, '群馬県邑楽郡邑楽町新中野');
ok($zip->set_number('3700613')->is_valid_number, '群馬県邑楽郡邑楽町狸塚');
ok($zip->set_number('3700614')->is_valid_number, '群馬県邑楽郡邑楽町赤堀');
ok($zip->set_number('3700615')->is_valid_number, '群馬県邑楽郡邑楽町篠塚');
ok($zip->set_number('3700616')->is_valid_number, '群馬県邑楽郡邑楽町光善寺');
ok($zip->set_number('3700700')->is_valid_number, '群馬県邑楽郡明和町以下に掲載がない場合');
ok($zip->set_number('3700701')->is_valid_number, '群馬県邑楽郡明和町南大島');
ok($zip->set_number('3700702')->is_valid_number, '群馬県邑楽郡明和町上江黒');
ok($zip->set_number('3700703')->is_valid_number, '群馬県邑楽郡明和町下江黒');
ok($zip->set_number('3700704')->is_valid_number, '群馬県邑楽郡明和町斗合田');
ok($zip->set_number('3700705')->is_valid_number, '群馬県邑楽郡明和町千津井');
ok($zip->set_number('3700706')->is_valid_number, '群馬県邑楽郡明和町江口');
ok($zip->set_number('3700707')->is_valid_number, '群馬県邑楽郡明和町田島');
ok($zip->set_number('3700708')->is_valid_number, '群馬県邑楽郡明和町新里');
ok($zip->set_number('3700711')->is_valid_number, '群馬県邑楽郡明和町入ケ谷');
ok($zip->set_number('3700712')->is_valid_number, '群馬県邑楽郡明和町矢島');
ok($zip->set_number('3700713')->is_valid_number, '群馬県邑楽郡明和町中谷');
ok($zip->set_number('3700714')->is_valid_number, '群馬県邑楽郡明和町梅原');
ok($zip->set_number('3700715')->is_valid_number, '群馬県邑楽郡明和町大佐貫');
ok($zip->set_number('3700716')->is_valid_number, '群馬県邑楽郡明和町川俣');
ok($zip->set_number('3700717')->is_valid_number, '群馬県邑楽郡明和町須賀');
ok($zip->set_number('3700718')->is_valid_number, '群馬県邑楽郡明和町大輪');
ok($zip->set_number('3700721')->is_valid_number, '群馬県邑楽郡千代田町木崎');
ok($zip->set_number('3700722')->is_valid_number, '群馬県邑楽郡千代田町萱野');
ok($zip->set_number('3700723')->is_valid_number, '群馬県邑楽郡千代田町昭和');
ok($zip->set_number('3700724')->is_valid_number, '群馬県邑楽郡千代田町下中森');
ok($zip->set_number('3700725')->is_valid_number, '群馬県邑楽郡千代田町上中森');
ok($zip->set_number('3700726')->is_valid_number, '群馬県邑楽郡千代田町上五箇');
ok($zip->set_number('3700727')->is_valid_number, '群馬県邑楽郡千代田町瀬戸井');
ok($zip->set_number('3700801')->is_valid_number, '群馬県高崎市上並榎町');
ok($zip->set_number('3700802')->is_valid_number, '群馬県高崎市並榎町');
ok($zip->set_number('3700803')->is_valid_number, '群馬県高崎市大橋町');
ok($zip->set_number('3700804')->is_valid_number, '群馬県高崎市住吉町');
ok($zip->set_number('3700805')->is_valid_number, '群馬県高崎市台町');
ok($zip->set_number('3700806')->is_valid_number, '群馬県高崎市上和田町');
ok($zip->set_number('3700807')->is_valid_number, '群馬県高崎市歌川町');
ok($zip->set_number('3700811')->is_valid_number, '群馬県高崎市相生町');
ok($zip->set_number('3700812')->is_valid_number, '群馬県高崎市成田町');
ok($zip->set_number('3700813')->is_valid_number, '群馬県高崎市本町');
ok($zip->set_number('3700814')->is_valid_number, '群馬県高崎市嘉多町');
ok($zip->set_number('3700815')->is_valid_number, '群馬県高崎市柳川町');
ok($zip->set_number('3700816')->is_valid_number, '群馬県高崎市常盤町');
ok($zip->set_number('3700817')->is_valid_number, '群馬県高崎市堰代町');
ok($zip->set_number('3700818')->is_valid_number, '群馬県高崎市赤坂町');
ok($zip->set_number('3700819')->is_valid_number, '群馬県高崎市四ツ屋町');
ok($zip->set_number('3700821')->is_valid_number, '群馬県高崎市新紺屋町');
ok($zip->set_number('3700822')->is_valid_number, '群馬県高崎市寄合町');
ok($zip->set_number('3700823')->is_valid_number, '群馬県高崎市中紺屋町');
ok($zip->set_number('3700824')->is_valid_number, '群馬県高崎市田町');
ok($zip->set_number('3700825')->is_valid_number, '群馬県高崎市白銀町');
ok($zip->set_number('3700826')->is_valid_number, '群馬県高崎市連雀町');
ok($zip->set_number('3700827')->is_valid_number, '群馬県高崎市鞘町');
ok($zip->set_number('3700828')->is_valid_number, '群馬県高崎市宮元町');
ok($zip->set_number('3700829')->is_valid_number, '群馬県高崎市高松町');
ok($zip->set_number('3700831')->is_valid_number, '群馬県高崎市あら町');
ok($zip->set_number('3700832')->is_valid_number, '群馬県高崎市砂賀町');
ok($zip->set_number('3700833')->is_valid_number, '群馬県高崎市新田町');
ok($zip->set_number('3700834')->is_valid_number, '群馬県高崎市南町');
ok($zip->set_number('3700835')->is_valid_number, '群馬県高崎市竜見町');
ok($zip->set_number('3700836')->is_valid_number, '群馬県高崎市若松町');
ok($zip->set_number('3700837')->is_valid_number, '群馬県高崎市下横町');
ok($zip->set_number('3700838')->is_valid_number, '群馬県高崎市鍛冶町');
ok($zip->set_number('3700839')->is_valid_number, '群馬県高崎市檜物町');
ok($zip->set_number('3700841')->is_valid_number, '群馬県高崎市栄町');
ok($zip->set_number('3700842')->is_valid_number, '群馬県高崎市北双葉町');
ok($zip->set_number('3700843')->is_valid_number, '群馬県高崎市双葉町');
ok($zip->set_number('3700844')->is_valid_number, '群馬県高崎市和田多中町');
ok($zip->set_number('3700845')->is_valid_number, '群馬県高崎市新後閑町');
ok($zip->set_number('3700846')->is_valid_number, '群馬県高崎市下和田町');
ok($zip->set_number('3700847')->is_valid_number, '群馬県高崎市和田町');
ok($zip->set_number('3700848')->is_valid_number, '群馬県高崎市鶴見町');
ok($zip->set_number('3700849')->is_valid_number, '群馬県高崎市八島町');
ok($zip->set_number('3700851')->is_valid_number, '群馬県高崎市上中居町');
ok($zip->set_number('3700852')->is_valid_number, '群馬県高崎市中居町');
ok($zip->set_number('3700853')->is_valid_number, '群馬県高崎市下中居町');
ok($zip->set_number('3700854')->is_valid_number, '群馬県高崎市下之城町');
ok($zip->set_number('3700855')->is_valid_number, '群馬県高崎市下佐野町');
ok($zip->set_number('3700856')->is_valid_number, '群馬県高崎市佐野窪町');
ok($zip->set_number('3700857')->is_valid_number, '群馬県高崎市上佐野町');
ok($zip->set_number('3700861')->is_valid_number, '群馬県高崎市八千代町');
ok($zip->set_number('3700862')->is_valid_number, '群馬県高崎市片岡町');
ok($zip->set_number('3700863')->is_valid_number, '群馬県高崎市聖石町');
ok($zip->set_number('3700864')->is_valid_number, '群馬県高崎市石原町');
ok($zip->set_number('3700865')->is_valid_number, '群馬県高崎市寺尾町');
ok($zip->set_number('3700866')->is_valid_number, '群馬県高崎市城山町');
ok($zip->set_number('3700867')->is_valid_number, '群馬県高崎市乗附町');
ok($zip->set_number('3700868')->is_valid_number, '群馬県高崎市鼻高町');
ok($zip->set_number('3700871')->is_valid_number, '群馬県高崎市上豊岡町');
ok($zip->set_number('3700872')->is_valid_number, '群馬県高崎市北久保町');
ok($zip->set_number('3700873')->is_valid_number, '群馬県高崎市下豊岡町');
ok($zip->set_number('3700874')->is_valid_number, '群馬県高崎市中豊岡町');
ok($zip->set_number('3700875')->is_valid_number, '群馬県高崎市藤塚町');
ok($zip->set_number('3700881')->is_valid_number, '群馬県高崎市町屋町');
ok($zip->set_number('3700882')->is_valid_number, '群馬県高崎市金井淵町');
ok($zip->set_number('3700883')->is_valid_number, '群馬県高崎市剣崎町');
ok($zip->set_number('3700884')->is_valid_number, '群馬県高崎市八幡町');
ok($zip->set_number('3700885')->is_valid_number, '群馬県高崎市若田町');
ok($zip->set_number('3700886')->is_valid_number, '群馬県高崎市下大島町');
ok($zip->set_number('3701100')->is_valid_number, '群馬県佐波郡玉村町以下に掲載がない場合');
ok($zip->set_number('3701101')->is_valid_number, '群馬県佐波郡玉村町藤川');
ok($zip->set_number('3701102')->is_valid_number, '群馬県佐波郡玉村町飯塚');
ok($zip->set_number('3701103')->is_valid_number, '群馬県佐波郡玉村町樋越');
ok($zip->set_number('3701104')->is_valid_number, '群馬県佐波郡玉村町上福島');
ok($zip->set_number('3701105')->is_valid_number, '群馬県佐波郡玉村町福島');
ok($zip->set_number('3701111')->is_valid_number, '群馬県佐波郡玉村町南玉');
ok($zip->set_number('3701112')->is_valid_number, '群馬県佐波郡玉村町下之宮');
ok($zip->set_number('3701113')->is_valid_number, '群馬県佐波郡玉村町箱石');
ok($zip->set_number('3701114')->is_valid_number, '群馬県佐波郡玉村町小泉');
ok($zip->set_number('3701115')->is_valid_number, '群馬県佐波郡玉村町五料');
ok($zip->set_number('3701116')->is_valid_number, '群馬県佐波郡玉村町飯倉');
ok($zip->set_number('3701117')->is_valid_number, '群馬県佐波郡玉村町川井');
ok($zip->set_number('3701121')->is_valid_number, '群馬県佐波郡玉村町上飯島');
ok($zip->set_number('3701122')->is_valid_number, '群馬県佐波郡玉村町上茂木');
ok($zip->set_number('3701123')->is_valid_number, '群馬県佐波郡玉村町下茂木');
ok($zip->set_number('3701124')->is_valid_number, '群馬県佐波郡玉村町角渕');
ok($zip->set_number('3701125')->is_valid_number, '群馬県佐波郡玉村町八幡原');
ok($zip->set_number('3701126')->is_valid_number, '群馬県佐波郡玉村町宇貫');
ok($zip->set_number('3701127')->is_valid_number, '群馬県佐波郡玉村町上之手');
ok($zip->set_number('3701128')->is_valid_number, '群馬県佐波郡玉村町後箇');
ok($zip->set_number('3701131')->is_valid_number, '群馬県佐波郡玉村町斎田');
ok($zip->set_number('3701132')->is_valid_number, '群馬県佐波郡玉村町下新田');
ok($zip->set_number('3701133')->is_valid_number, '群馬県佐波郡玉村町上新田');
ok($zip->set_number('3701134')->is_valid_number, '群馬県佐波郡玉村町与六分');
ok($zip->set_number('3701135')->is_valid_number, '群馬県佐波郡玉村町板井');
ok($zip->set_number('3701201')->is_valid_number, '群馬県高崎市倉賀野町');
ok($zip->set_number('3701202')->is_valid_number, '群馬県高崎市宮原町');
ok($zip->set_number('3701203')->is_valid_number, '群馬県高崎市矢中町');
ok($zip->set_number('3701204')->is_valid_number, '群馬県高崎市東中里町');
ok($zip->set_number('3701205')->is_valid_number, '群馬県高崎市栗崎町');
ok($zip->set_number('3701206')->is_valid_number, '群馬県高崎市台新田町');
ok($zip->set_number('3701207')->is_valid_number, '群馬県高崎市綿貫町');
ok($zip->set_number('3701208')->is_valid_number, '群馬県高崎市岩鼻町');
ok($zip->set_number('3701211')->is_valid_number, '群馬県高崎市阿久津町');
ok($zip->set_number('3701212')->is_valid_number, '群馬県高崎市木部町');
ok($zip->set_number('3701213')->is_valid_number, '群馬県高崎市山名町');
ok($zip->set_number('3701214')->is_valid_number, '群馬県高崎市根小屋町');
ok($zip->set_number('3701301')->is_valid_number, '群馬県高崎市新町');
ok($zip->set_number('3701401')->is_valid_number, '群馬県藤岡市鬼石');
ok($zip->set_number('3701402')->is_valid_number, '群馬県藤岡市譲原');
ok($zip->set_number('3701403')->is_valid_number, '群馬県藤岡市保美濃山');
ok($zip->set_number('3701404')->is_valid_number, '群馬県藤岡市坂原');
ok($zip->set_number('3701405')->is_valid_number, '群馬県藤岡市三波川');
ok($zip->set_number('3701406')->is_valid_number, '群馬県藤岡市浄法寺');
ok($zip->set_number('3701501')->is_valid_number, '群馬県多野郡神流町柏木');
ok($zip->set_number('3701502')->is_valid_number, '群馬県多野郡神流町麻生');
ok($zip->set_number('3701503')->is_valid_number, '群馬県多野郡神流町生利');
ok($zip->set_number('3701504')->is_valid_number, '群馬県多野郡神流町万場');
ok($zip->set_number('3701505')->is_valid_number, '群馬県多野郡神流町森戸');
ok($zip->set_number('3701506')->is_valid_number, '群馬県多野郡神流町黒田');
ok($zip->set_number('3701507')->is_valid_number, '埼玉県秩父市吉田太田部');
ok($zip->set_number('3701511')->is_valid_number, '群馬県多野郡神流町相原');
ok($zip->set_number('3701512')->is_valid_number, '群馬県多野郡神流町青梨');
ok($zip->set_number('3701513')->is_valid_number, '群馬県多野郡神流町小平');
ok($zip->set_number('3701514')->is_valid_number, '群馬県多野郡神流町塩沢');
ok($zip->set_number('3701515')->is_valid_number, '群馬県多野郡神流町船子');
ok($zip->set_number('3701600')->is_valid_number, '群馬県多野郡上野村以下に掲載がない場合');
ok($zip->set_number('3701600')->is_valid_number, '群馬県多野郡神流町以下に掲載がない場合');
ok($zip->set_number('3701601')->is_valid_number, '群馬県多野郡神流町魚尾');
ok($zip->set_number('3701602')->is_valid_number, '群馬県多野郡神流町神ケ原');
ok($zip->set_number('3701603')->is_valid_number, '群馬県多野郡神流町平原');
ok($zip->set_number('3701604')->is_valid_number, '群馬県多野郡神流町尾附');
ok($zip->set_number('3701611')->is_valid_number, '群馬県多野郡上野村新羽');
ok($zip->set_number('3701612')->is_valid_number, '群馬県多野郡上野村野栗沢');
ok($zip->set_number('3701613')->is_valid_number, '群馬県多野郡上野村勝山');
ok($zip->set_number('3701614')->is_valid_number, '群馬県多野郡上野村川和');
ok($zip->set_number('3701615')->is_valid_number, '群馬県多野郡上野村乙母');
ok($zip->set_number('3701616')->is_valid_number, '群馬県多野郡上野村乙父');
ok($zip->set_number('3701617')->is_valid_number, '群馬県多野郡上野村楢原');
ok($zip->set_number('3702101')->is_valid_number, '群馬県高崎市吉井町南陽台');
ok($zip->set_number('3702102')->is_valid_number, '群馬県高崎市吉井町小暮');
ok($zip->set_number('3702103')->is_valid_number, '群馬県高崎市吉井町岩井');
ok($zip->set_number('3702104')->is_valid_number, '群馬県高崎市吉井町馬庭');
ok($zip->set_number('3702105')->is_valid_number, '群馬県高崎市吉井町中島');
ok($zip->set_number('3702106')->is_valid_number, '群馬県高崎市吉井町矢田');
ok($zip->set_number('3702107')->is_valid_number, '群馬県高崎市吉井町池');
ok($zip->set_number('3702111')->is_valid_number, '群馬県高崎市吉井町小串');
ok($zip->set_number('3702112')->is_valid_number, '群馬県高崎市吉井町黒熊');
ok($zip->set_number('3702113')->is_valid_number, '群馬県高崎市吉井町深沢');
ok($zip->set_number('3702114')->is_valid_number, '群馬県高崎市吉井町石神');
ok($zip->set_number('3702115')->is_valid_number, '群馬県高崎市吉井町多比良');
ok($zip->set_number('3702116')->is_valid_number, '群馬県高崎市吉井町多胡');
ok($zip->set_number('3702121')->is_valid_number, '群馬県高崎市吉井町下長根');
ok($zip->set_number('3702122')->is_valid_number, '群馬県高崎市吉井町高');
ok($zip->set_number('3702123')->is_valid_number, '群馬県高崎市吉井町神保');
ok($zip->set_number('3702124')->is_valid_number, '群馬県高崎市吉井町塩');
ok($zip->set_number('3702125')->is_valid_number, '群馬県高崎市吉井町大沢');
ok($zip->set_number('3702126')->is_valid_number, '群馬県高崎市吉井町東谷');
ok($zip->set_number('3702127')->is_valid_number, '群馬県高崎市吉井町長根');
ok($zip->set_number('3702128')->is_valid_number, '群馬県高崎市吉井町本郷');
ok($zip->set_number('3702131')->is_valid_number, '群馬県高崎市吉井町岩崎');
ok($zip->set_number('3702132')->is_valid_number, '群馬県高崎市吉井町吉井');
ok($zip->set_number('3702133')->is_valid_number, '群馬県高崎市吉井町吉井川');
ok($zip->set_number('3702134')->is_valid_number, '群馬県高崎市吉井町塩川');
ok($zip->set_number('3702135')->is_valid_number, '群馬県高崎市吉井町片山');
ok($zip->set_number('3702136')->is_valid_number, '群馬県高崎市吉井町小棚');
ok($zip->set_number('3702137')->is_valid_number, '群馬県高崎市吉井町坂口');
ok($zip->set_number('3702138')->is_valid_number, '群馬県高崎市吉井町下奥平');
ok($zip->set_number('3702139')->is_valid_number, '群馬県高崎市吉井町上奥平');
ok($zip->set_number('3702200')->is_valid_number, '群馬県甘楽郡甘楽町以下に掲載がない場合');
ok($zip->set_number('3702201')->is_valid_number, '群馬県甘楽郡甘楽町上野');
ok($zip->set_number('3702202')->is_valid_number, '群馬県甘楽郡甘楽町小幡');
ok($zip->set_number('3702203')->is_valid_number, '群馬県甘楽郡甘楽町轟');
ok($zip->set_number('3702204')->is_valid_number, '群馬県甘楽郡甘楽町秋畑');
ok($zip->set_number('3702205')->is_valid_number, '群馬県甘楽郡甘楽町国峰');
ok($zip->set_number('3702206')->is_valid_number, '群馬県甘楽郡甘楽町善慶寺');
ok($zip->set_number('3702211')->is_valid_number, '群馬県甘楽郡甘楽町小川');
ok($zip->set_number('3702212')->is_valid_number, '群馬県甘楽郡甘楽町福島');
ok($zip->set_number('3702213')->is_valid_number, '群馬県甘楽郡甘楽町白倉');
ok($zip->set_number('3702214')->is_valid_number, '群馬県甘楽郡甘楽町庭谷');
ok($zip->set_number('3702215')->is_valid_number, '群馬県甘楽郡甘楽町造石');
ok($zip->set_number('3702216')->is_valid_number, '群馬県甘楽郡甘楽町金井');
ok($zip->set_number('3702217')->is_valid_number, '群馬県甘楽郡甘楽町天引');
ok($zip->set_number('3702300')->is_valid_number, '群馬県富岡市以下に掲載がない場合');
ok($zip->set_number('3702301')->is_valid_number, '群馬県富岡市桑原');
ok($zip->set_number('3702302')->is_valid_number, '群馬県富岡市小桑原');
ok($zip->set_number('3702303')->is_valid_number, '群馬県富岡市蕨');
ok($zip->set_number('3702304')->is_valid_number, '群馬県富岡市後賀');
ok($zip->set_number('3702305')->is_valid_number, '群馬県富岡市白岩');
ok($zip->set_number('3702306')->is_valid_number, '群馬県富岡市相野田');
ok($zip->set_number('3702307')->is_valid_number, '群馬県富岡市藤木');
ok($zip->set_number('3702311')->is_valid_number, '群馬県富岡市下高尾');
ok($zip->set_number('3702312')->is_valid_number, '群馬県富岡市星田');
ok($zip->set_number('3702313')->is_valid_number, '群馬県富岡市君川');
ok($zip->set_number('3702314')->is_valid_number, '群馬県富岡市田篠');
ok($zip->set_number('3702315')->is_valid_number, '群馬県富岡市曽木');
ok($zip->set_number('3702316')->is_valid_number, '群馬県富岡市富岡');
ok($zip->set_number('3702317')->is_valid_number, '群馬県富岡市上高尾');
ok($zip->set_number('3702321')->is_valid_number, '群馬県富岡市岡本');
ok($zip->set_number('3702322')->is_valid_number, '群馬県富岡市岩染');
ok($zip->set_number('3702323')->is_valid_number, '群馬県富岡市野上');
ok($zip->set_number('3702324')->is_valid_number, '群馬県富岡市南後箇');
ok($zip->set_number('3702331')->is_valid_number, '群馬県富岡市内匠');
ok($zip->set_number('3702332')->is_valid_number, '群馬県富岡市下高瀬');
ok($zip->set_number('3702333')->is_valid_number, '群馬県富岡市中高瀬');
ok($zip->set_number('3702334')->is_valid_number, '群馬県富岡市上高瀬');
ok($zip->set_number('3702335')->is_valid_number, '群馬県富岡市大島');
ok($zip->set_number('3702341')->is_valid_number, '群馬県富岡市下黒岩');
ok($zip->set_number('3702342')->is_valid_number, '群馬県富岡市別保');
ok($zip->set_number('3702343')->is_valid_number, '群馬県富岡市七日市');
ok($zip->set_number('3702344')->is_valid_number, '群馬県富岡市黒川');
ok($zip->set_number('3702345')->is_valid_number, '群馬県富岡市上黒岩');
ok($zip->set_number('3702411')->is_valid_number, '群馬県富岡市妙義町上高田');
ok($zip->set_number('3702412')->is_valid_number, '群馬県富岡市妙義町下高田');
ok($zip->set_number('3702413')->is_valid_number, '群馬県富岡市妙義町八木連');
ok($zip->set_number('3702451')->is_valid_number, '群馬県富岡市宇田');
ok($zip->set_number('3702452')->is_valid_number, '群馬県富岡市一ノ宮');
ok($zip->set_number('3702453')->is_valid_number, '群馬県富岡市宮崎');
ok($zip->set_number('3702454')->is_valid_number, '群馬県富岡市田島');
ok($zip->set_number('3702455')->is_valid_number, '群馬県富岡市神農原');
ok($zip->set_number('3702456')->is_valid_number, '群馬県富岡市上小林');
ok($zip->set_number('3702461')->is_valid_number, '群馬県富岡市上丹生');
ok($zip->set_number('3702462')->is_valid_number, '群馬県富岡市下丹生');
ok($zip->set_number('3702463')->is_valid_number, '群馬県富岡市神成');
ok($zip->set_number('3702464')->is_valid_number, '群馬県富岡市南蛇井');
ok($zip->set_number('3702465')->is_valid_number, '群馬県富岡市中沢');
ok($zip->set_number('3702466')->is_valid_number, '群馬県富岡市蚊沼');
ok($zip->set_number('3702467')->is_valid_number, '群馬県富岡市原');
ok($zip->set_number('3702600')->is_valid_number, '群馬県甘楽郡下仁田町以下に掲載がない場合');
ok($zip->set_number('3702601')->is_valid_number, '群馬県甘楽郡下仁田町下仁田');
ok($zip->set_number('3702602')->is_valid_number, '群馬県甘楽郡下仁田町白山');
ok($zip->set_number('3702603')->is_valid_number, '群馬県甘楽郡下仁田町馬山');
ok($zip->set_number('3702604')->is_valid_number, '群馬県甘楽郡下仁田町吉崎');
ok($zip->set_number('3702605')->is_valid_number, '群馬県甘楽郡下仁田町栗山');
ok($zip->set_number('3702606')->is_valid_number, '群馬県甘楽郡下仁田町川井');
ok($zip->set_number('3702611')->is_valid_number, '群馬県甘楽郡下仁田町青倉');
ok($zip->set_number('3702612')->is_valid_number, '群馬県甘楽郡下仁田町平原');
ok($zip->set_number('3702613')->is_valid_number, '群馬県甘楽郡下仁田町大桑原');
ok($zip->set_number('3702614')->is_valid_number, '群馬県甘楽郡下仁田町風口');
ok($zip->set_number('3702615')->is_valid_number, '群馬県甘楽郡下仁田町宮室');
ok($zip->set_number('3702616')->is_valid_number, '群馬県甘楽郡下仁田町下郷');
ok($zip->set_number('3702621')->is_valid_number, '群馬県甘楽郡下仁田町上小坂');
ok($zip->set_number('3702622')->is_valid_number, '群馬県甘楽郡下仁田町中小坂');
ok($zip->set_number('3702623')->is_valid_number, '群馬県甘楽郡下仁田町下小坂');
ok($zip->set_number('3702624')->is_valid_number, '群馬県甘楽郡下仁田町東野牧');
ok($zip->set_number('3702625')->is_valid_number, '群馬県甘楽郡下仁田町本宿');
ok($zip->set_number('3702626')->is_valid_number, '群馬県甘楽郡下仁田町南野牧');
ok($zip->set_number('3702627')->is_valid_number, '群馬県甘楽郡下仁田町西野牧');
ok($zip->set_number('3702800')->is_valid_number, '群馬県甘楽郡南牧村以下に掲載がない場合');
ok($zip->set_number('3702801')->is_valid_number, '群馬県甘楽郡南牧村大塩沢');
ok($zip->set_number('3702802')->is_valid_number, '群馬県甘楽郡南牧村小沢');
ok($zip->set_number('3702803')->is_valid_number, '群馬県甘楽郡南牧村千原');
ok($zip->set_number('3702804')->is_valid_number, '群馬県甘楽郡南牧村磐戸');
ok($zip->set_number('3702805')->is_valid_number, '群馬県甘楽郡南牧村檜沢');
ok($zip->set_number('3702806')->is_valid_number, '群馬県甘楽郡南牧村大日向');
ok($zip->set_number('3702811')->is_valid_number, '群馬県甘楽郡南牧村六車');
ok($zip->set_number('3702812')->is_valid_number, '群馬県甘楽郡南牧村大仁田');
ok($zip->set_number('3702813')->is_valid_number, '群馬県甘楽郡南牧村砥沢');
ok($zip->set_number('3702814')->is_valid_number, '群馬県甘楽郡南牧村羽沢');
ok($zip->set_number('3702815')->is_valid_number, '群馬県甘楽郡南牧村熊倉');
ok($zip->set_number('3702816')->is_valid_number, '群馬県甘楽郡南牧村星尾');
ok($zip->set_number('3703101')->is_valid_number, '群馬県高崎市箕郷町柏木沢');
ok($zip->set_number('3703102')->is_valid_number, '群馬県高崎市箕郷町生原');
ok($zip->set_number('3703103')->is_valid_number, '群馬県高崎市箕郷町下芝');
ok($zip->set_number('3703104')->is_valid_number, '群馬県高崎市箕郷町上芝');
ok($zip->set_number('3703105')->is_valid_number, '群馬県高崎市箕郷町西明屋');
ok($zip->set_number('3703106')->is_valid_number, '群馬県高崎市箕郷町東明屋');
ok($zip->set_number('3703107')->is_valid_number, '群馬県高崎市箕郷町矢原');
ok($zip->set_number('3703111')->is_valid_number, '群馬県高崎市箕郷町中野');
ok($zip->set_number('3703112')->is_valid_number, '群馬県高崎市箕郷町善地');
ok($zip->set_number('3703113')->is_valid_number, '群馬県高崎市箕郷町松之沢');
ok($zip->set_number('3703114')->is_valid_number, '群馬県高崎市箕郷町金敷平');
ok($zip->set_number('3703115')->is_valid_number, '群馬県高崎市箕郷町富岡');
ok($zip->set_number('3703116')->is_valid_number, '群馬県高崎市箕郷町和田山');
ok($zip->set_number('3703117')->is_valid_number, '群馬県高崎市箕郷町白川');
ok($zip->set_number('3703311')->is_valid_number, '群馬県吾妻郡東吾妻町岡崎(烏帽子「榛名湖畔」)');
ok($zip->set_number('3703321')->is_valid_number, '群馬県吾妻郡東吾妻町泉沢(烏帽子「榛名湖畔」、烏帽子国有林77林班)');
ok($zip->set_number('3703322')->is_valid_number, '群馬県吾妻郡東吾妻町川戸(烏帽子「榛名湖畔」)');
ok($zip->set_number('3703331')->is_valid_number, '群馬県高崎市十文字町');
ok($zip->set_number('3703332')->is_valid_number, '群馬県高崎市白岩町');
ok($zip->set_number('3703333')->is_valid_number, '群馬県高崎市高浜町');
ok($zip->set_number('3703334')->is_valid_number, '群馬県高崎市本郷町');
ok($zip->set_number('3703335')->is_valid_number, '群馬県高崎市上大島町');
ok($zip->set_number('3703336')->is_valid_number, '群馬県高崎市神戸町');
ok($zip->set_number('3703337')->is_valid_number, '群馬県高崎市三ツ子沢町');
ok($zip->set_number('3703338')->is_valid_number, '群馬県高崎市宮沢町');
ok($zip->set_number('3703341')->is_valid_number, '群馬県高崎市榛名山町');
ok($zip->set_number('3703342')->is_valid_number, '群馬県高崎市下室田町');
ok($zip->set_number('3703343')->is_valid_number, '群馬県高崎市下里見町');
ok($zip->set_number('3703344')->is_valid_number, '群馬県高崎市中里見町');
ok($zip->set_number('3703345')->is_valid_number, '群馬県高崎市上里見町');
ok($zip->set_number('3703346')->is_valid_number, '群馬県高崎市上室田町');
ok($zip->set_number('3703347')->is_valid_number, '群馬県高崎市中室田町');
ok($zip->set_number('3703348')->is_valid_number, '群馬県高崎市榛名湖町');
ok($zip->set_number('3703401')->is_valid_number, '群馬県高崎市倉渕町権田');
ok($zip->set_number('3703402')->is_valid_number, '群馬県高崎市倉渕町三ノ倉');
ok($zip->set_number('3703403')->is_valid_number, '群馬県高崎市倉渕町水沼');
ok($zip->set_number('3703404')->is_valid_number, '群馬県高崎市倉渕町岩氷');
ok($zip->set_number('3703405')->is_valid_number, '群馬県高崎市倉渕町川浦');
ok($zip->set_number('3703500')->is_valid_number, '群馬県北群馬郡榛東村以下に掲載がない場合');
ok($zip->set_number('3703501')->is_valid_number, '群馬県北群馬郡榛東村長岡');
ok($zip->set_number('3703502')->is_valid_number, '群馬県北群馬郡榛東村山子田');
ok($zip->set_number('3703503')->is_valid_number, '群馬県北群馬郡榛東村新井');
ok($zip->set_number('3703504')->is_valid_number, '群馬県北群馬郡榛東村広馬場');
ok($zip->set_number('3703505')->is_valid_number, '群馬県北群馬郡榛東村上野原');
ok($zip->set_number('3703511')->is_valid_number, '群馬県高崎市金古町');
ok($zip->set_number('3703512')->is_valid_number, '群馬県高崎市西国分町');
ok($zip->set_number('3703513')->is_valid_number, '群馬県高崎市北原町');
ok($zip->set_number('3703514')->is_valid_number, '群馬県高崎市東国分町');
ok($zip->set_number('3703515')->is_valid_number, '群馬県高崎市塚田町');
ok($zip->set_number('3703516')->is_valid_number, '群馬県高崎市稲荷台町');
ok($zip->set_number('3703517')->is_valid_number, '群馬県高崎市引間町');
ok($zip->set_number('3703518')->is_valid_number, '群馬県高崎市後疋間町');
ok($zip->set_number('3703519')->is_valid_number, '群馬県高崎市冷水町');
ok($zip->set_number('3703521')->is_valid_number, '群馬県高崎市棟高町');
ok($zip->set_number('3703522')->is_valid_number, '群馬県高崎市菅谷町');
ok($zip->set_number('3703523')->is_valid_number, '群馬県高崎市福島町');
ok($zip->set_number('3703524')->is_valid_number, '群馬県高崎市中泉町');
ok($zip->set_number('3703525')->is_valid_number, '群馬県高崎市三ツ寺町');
ok($zip->set_number('3703531')->is_valid_number, '群馬県高崎市足門町');
ok($zip->set_number('3703532')->is_valid_number, '群馬県高崎市中里町');
ok($zip->set_number('3703533')->is_valid_number, '群馬県高崎市保渡田町');
ok($zip->set_number('3703534')->is_valid_number, '群馬県高崎市井出町');
ok($zip->set_number('3703571')->is_valid_number, '群馬県前橋市池端町');
ok($zip->set_number('3703572')->is_valid_number, '群馬県前橋市上青梨子町');
ok($zip->set_number('3703573')->is_valid_number, '群馬県前橋市青梨子町');
ok($zip->set_number('3703574')->is_valid_number, '群馬県前橋市清野町');
ok($zip->set_number('3703600')->is_valid_number, '群馬県北群馬郡吉岡町以下に掲載がない場合');
ok($zip->set_number('3703601')->is_valid_number, '群馬県北群馬郡吉岡町漆原');
ok($zip->set_number('3703602')->is_valid_number, '群馬県北群馬郡吉岡町大久保');
ok($zip->set_number('3703603')->is_valid_number, '群馬県北群馬郡吉岡町陣場');
ok($zip->set_number('3703604')->is_valid_number, '群馬県北群馬郡吉岡町南下');
ok($zip->set_number('3703605')->is_valid_number, '群馬県北群馬郡吉岡町北下');
ok($zip->set_number('3703606')->is_valid_number, '群馬県北群馬郡吉岡町上野田');
ok($zip->set_number('3703607')->is_valid_number, '群馬県北群馬郡吉岡町小倉');
ok($zip->set_number('3703608')->is_valid_number, '群馬県北群馬郡吉岡町下野田');
ok($zip->set_number('3710000')->is_valid_number, '群馬県前橋市以下に掲載がない場合');
ok($zip->set_number('3710001')->is_valid_number, '群馬県前橋市荻窪町');
ok($zip->set_number('3710002')->is_valid_number, '群馬県前橋市江木町');
ok($zip->set_number('3710003')->is_valid_number, '群馬県前橋市堤町');
ok($zip->set_number('3710004')->is_valid_number, '群馬県前橋市亀泉町');
ok($zip->set_number('3710005')->is_valid_number, '群馬県前橋市堀之下町');
ok($zip->set_number('3710006')->is_valid_number, '群馬県前橋市石関町');
ok($zip->set_number('3710007')->is_valid_number, '群馬県前橋市上泉町');
ok($zip->set_number('3710011')->is_valid_number, '群馬県前橋市下沖町');
ok($zip->set_number('3710012')->is_valid_number, '群馬県前橋市東片貝町');
ok($zip->set_number('3710013')->is_valid_number, '群馬県前橋市西片貝町');
ok($zip->set_number('3710014')->is_valid_number, '群馬県前橋市朝日町');
ok($zip->set_number('3710015')->is_valid_number, '群馬県前橋市三河町');
ok($zip->set_number('3710016')->is_valid_number, '群馬県前橋市城東町');
ok($zip->set_number('3710017')->is_valid_number, '群馬県前橋市日吉町');
ok($zip->set_number('3710018')->is_valid_number, '群馬県前橋市三俣町');
ok($zip->set_number('3710021')->is_valid_number, '群馬県前橋市住吉町');
ok($zip->set_number('3710022')->is_valid_number, '群馬県前橋市千代田町');
ok($zip->set_number('3710023')->is_valid_number, '群馬県前橋市本町');
ok($zip->set_number('3710024')->is_valid_number, '群馬県前橋市表町');
ok($zip->set_number('3710025')->is_valid_number, '群馬県前橋市紅雲町');
ok($zip->set_number('3710026')->is_valid_number, '群馬県前橋市大手町');
ok($zip->set_number('3710027')->is_valid_number, '群馬県前橋市平和町');
ok($zip->set_number('3710031')->is_valid_number, '群馬県前橋市下小出町');
ok($zip->set_number('3710032')->is_valid_number, '群馬県前橋市若宮町');
ok($zip->set_number('3710033')->is_valid_number, '群馬県前橋市国領町');
ok($zip->set_number('3710034')->is_valid_number, '群馬県前橋市昭和町');
ok($zip->set_number('3710035')->is_valid_number, '群馬県前橋市岩神町');
ok($zip->set_number('3710036')->is_valid_number, '群馬県前橋市敷島町');
ok($zip->set_number('3710037')->is_valid_number, '群馬県前橋市上小出町');
ok($zip->set_number('3710041')->is_valid_number, '群馬県前橋市川端町');
ok($zip->set_number('3710042')->is_valid_number, '群馬県前橋市日輪寺町');
ok($zip->set_number('3710043')->is_valid_number, '群馬県前橋市南橘町');
ok($zip->set_number('3710044')->is_valid_number, '群馬県前橋市荒牧町');
ok($zip->set_number('3710045')->is_valid_number, '群馬県前橋市緑が丘町');
ok($zip->set_number('3710046')->is_valid_number, '群馬県前橋市川原町');
ok($zip->set_number('3710047')->is_valid_number, '群馬県前橋市関根町');
ok($zip->set_number('3710048')->is_valid_number, '群馬県前橋市田口町');
ok($zip->set_number('3710051')->is_valid_number, '群馬県前橋市上細井町');
ok($zip->set_number('3710052')->is_valid_number, '群馬県前橋市上沖町');
ok($zip->set_number('3710053')->is_valid_number, '群馬県前橋市幸塚町');
ok($zip->set_number('3710054')->is_valid_number, '群馬県前橋市下細井町');
ok($zip->set_number('3710055')->is_valid_number, '群馬県前橋市北代田町');
ok($zip->set_number('3710056')->is_valid_number, '群馬県前橋市青柳町');
ok($zip->set_number('3710057')->is_valid_number, '群馬県前橋市龍蔵寺町');
ok($zip->set_number('3710101')->is_valid_number, '群馬県前橋市富士見町赤城山');
ok($zip->set_number('3710102')->is_valid_number, '群馬県前橋市富士見町皆沢');
ok($zip->set_number('3710103')->is_valid_number, '群馬県前橋市富士見町小暮');
ok($zip->set_number('3710104')->is_valid_number, '群馬県前橋市富士見町時沢');
ok($zip->set_number('3710105')->is_valid_number, '群馬県前橋市富士見町石井');
ok($zip->set_number('3710106')->is_valid_number, '群馬県前橋市富士見町市之木場');
ok($zip->set_number('3710107')->is_valid_number, '群馬県前橋市富士見町山口');
ok($zip->set_number('3710111')->is_valid_number, '群馬県前橋市富士見町米野');
ok($zip->set_number('3710112')->is_valid_number, '群馬県前橋市富士見町引田');
ok($zip->set_number('3710113')->is_valid_number, '群馬県前橋市富士見町漆窪');
ok($zip->set_number('3710114')->is_valid_number, '群馬県前橋市富士見町田島');
ok($zip->set_number('3710115')->is_valid_number, '群馬県前橋市富士見町小沢');
ok($zip->set_number('3710116')->is_valid_number, '群馬県前橋市富士見町原之郷');
ok($zip->set_number('3710117')->is_valid_number, '群馬県前橋市富士見町横室');
ok($zip->set_number('3710121')->is_valid_number, '群馬県前橋市金丸町');
ok($zip->set_number('3710122')->is_valid_number, '群馬県前橋市小坂子町');
ok($zip->set_number('3710123')->is_valid_number, '群馬県前橋市高花台');
ok($zip->set_number('3710124')->is_valid_number, '群馬県前橋市勝沢町');
ok($zip->set_number('3710125')->is_valid_number, '群馬県前橋市嶺町');
ok($zip->set_number('3710131')->is_valid_number, '群馬県前橋市鳥取町');
ok($zip->set_number('3710132')->is_valid_number, '群馬県前橋市五代町');
ok($zip->set_number('3710133')->is_valid_number, '群馬県前橋市端気町');
ok($zip->set_number('3710134')->is_valid_number, '群馬県前橋市小神明町');
ok($zip->set_number('3710201')->is_valid_number, '群馬県前橋市粕川町中之沢');
ok($zip->set_number('3710202')->is_valid_number, '群馬県前橋市粕川町室沢');
ok($zip->set_number('3710203')->is_valid_number, '群馬県前橋市粕川町月田');
ok($zip->set_number('3710204')->is_valid_number, '群馬県前橋市粕川町膳');
ok($zip->set_number('3710205')->is_valid_number, '群馬県前橋市粕川町中');
ok($zip->set_number('3710206')->is_valid_number, '群馬県前橋市粕川町新屋');
ok($zip->set_number('3710207')->is_valid_number, '群馬県前橋市粕川町稲里');
ok($zip->set_number('3710211')->is_valid_number, '群馬県前橋市粕川町上東田面');
ok($zip->set_number('3710212')->is_valid_number, '群馬県前橋市粕川町下東田面');
ok($zip->set_number('3710213')->is_valid_number, '群馬県前橋市粕川町一日市');
ok($zip->set_number('3710214')->is_valid_number, '群馬県前橋市粕川町女渕');
ok($zip->set_number('3710215')->is_valid_number, '群馬県前橋市粕川町深津');
ok($zip->set_number('3710216')->is_valid_number, '群馬県前橋市粕川町込皆戸');
ok($zip->set_number('3710217')->is_valid_number, '群馬県前橋市粕川町西田面');
ok($zip->set_number('3710218')->is_valid_number, '群馬県前橋市粕川町前皆戸');
ok($zip->set_number('3710221')->is_valid_number, '群馬県前橋市樋越町');
ok($zip->set_number('3710222')->is_valid_number, '群馬県前橋市上大屋町');
ok($zip->set_number('3710223')->is_valid_number, '群馬県前橋市大胡町');
ok($zip->set_number('3710224')->is_valid_number, '群馬県前橋市河原浜町');
ok($zip->set_number('3710231')->is_valid_number, '群馬県前橋市堀越町');
ok($zip->set_number('3710232')->is_valid_number, '群馬県前橋市茂木町');
ok($zip->set_number('3710233')->is_valid_number, '群馬県前橋市横沢町');
ok($zip->set_number('3710234')->is_valid_number, '群馬県前橋市東金丸町');
ok($zip->set_number('3710235')->is_valid_number, '群馬県前橋市滝窪町');
ok($zip->set_number('3710241')->is_valid_number, '群馬県前橋市苗ケ島町');
ok($zip->set_number('3710242')->is_valid_number, '群馬県前橋市馬場町');
ok($zip->set_number('3710243')->is_valid_number, '群馬県前橋市大前田町');
ok($zip->set_number('3710244')->is_valid_number, '群馬県前橋市鼻毛石町');
ok($zip->set_number('3710245')->is_valid_number, '群馬県前橋市市之関町');
ok($zip->set_number('3710246')->is_valid_number, '群馬県前橋市柏倉町');
ok($zip->set_number('3710247')->is_valid_number, '群馬県前橋市三夜沢町');
ok($zip->set_number('3710801')->is_valid_number, '群馬県前橋市文京町');
ok($zip->set_number('3710802')->is_valid_number, '群馬県前橋市天川町');
ok($zip->set_number('3710803')->is_valid_number, '群馬県前橋市天川原町');
ok($zip->set_number('3710804')->is_valid_number, '群馬県前橋市六供町');
ok($zip->set_number('3710805')->is_valid_number, '群馬県前橋市南町');
ok($zip->set_number('3710811')->is_valid_number, '群馬県前橋市朝倉町');
ok($zip->set_number('3710812')->is_valid_number, '群馬県前橋市広瀬町');
ok($zip->set_number('3710813')->is_valid_number, '群馬県前橋市後閑町');
ok($zip->set_number('3710814')->is_valid_number, '群馬県前橋市宮地町');
ok($zip->set_number('3710815')->is_valid_number, '群馬県前橋市下佐鳥町');
ok($zip->set_number('3710816')->is_valid_number, '群馬県前橋市上佐鳥町');
ok($zip->set_number('3710817')->is_valid_number, '群馬県前橋市ぬで島町');
ok($zip->set_number('3710821')->is_valid_number, '群馬県前橋市上新田町');
ok($zip->set_number('3710822')->is_valid_number, '群馬県前橋市下新田町');
ok($zip->set_number('3710823')->is_valid_number, '群馬県前橋市川曲町');
ok($zip->set_number('3710824')->is_valid_number, '群馬県前橋市稲荷新田町');
ok($zip->set_number('3710825')->is_valid_number, '群馬県前橋市大利根町');
ok($zip->set_number('3710826')->is_valid_number, '群馬県前橋市青葉町');
ok($zip->set_number('3710831')->is_valid_number, '群馬県前橋市小相木町');
ok($zip->set_number('3710832')->is_valid_number, '群馬県前橋市朝日が丘町');
ok($zip->set_number('3710833')->is_valid_number, '群馬県前橋市光が丘町');
ok($zip->set_number('3710834')->is_valid_number, '群馬県前橋市後家町');
ok($zip->set_number('3710835')->is_valid_number, '群馬県前橋市前箱田町');
ok($zip->set_number('3710836')->is_valid_number, '群馬県前橋市江田町');
ok($zip->set_number('3710837')->is_valid_number, '群馬県前橋市箱田町');
ok($zip->set_number('3710841')->is_valid_number, '群馬県前橋市石倉町');
ok($zip->set_number('3710842')->is_valid_number, '群馬県前橋市下石倉町');
ok($zip->set_number('3710843')->is_valid_number, '群馬県前橋市新前橋町');
ok($zip->set_number('3710844')->is_valid_number, '群馬県前橋市古市町');
ok($zip->set_number('3710845')->is_valid_number, '群馬県前橋市鳥羽町');
ok($zip->set_number('3710846')->is_valid_number, '群馬県前橋市元総社町');
ok($zip->set_number('3710847')->is_valid_number, '群馬県前橋市大友町');
ok($zip->set_number('3710851')->is_valid_number, '群馬県前橋市総社町植野');
ok($zip->set_number('3710852')->is_valid_number, '群馬県前橋市総社町総社');
ok($zip->set_number('3710853')->is_valid_number, '群馬県前橋市総社町');
ok($zip->set_number('3710854')->is_valid_number, '群馬県前橋市大渡町');
ok($zip->set_number('3710855')->is_valid_number, '群馬県前橋市問屋町');
ok($zip->set_number('3710856')->is_valid_number, '群馬県前橋市総社町高井');
ok($zip->set_number('3710857')->is_valid_number, '群馬県前橋市高井町');
ok($zip->set_number('3710858')->is_valid_number, '群馬県前橋市総社町桜が丘');
ok($zip->set_number('3720000')->is_valid_number, '群馬県伊勢崎市以下に掲載がない場合');
ok($zip->set_number('3720001')->is_valid_number, '群馬県伊勢崎市波志江町');
ok($zip->set_number('3720002')->is_valid_number, '群馬県伊勢崎市堤西町');
ok($zip->set_number('3720003')->is_valid_number, '群馬県伊勢崎市華蔵寺町');
ok($zip->set_number('3720004')->is_valid_number, '群馬県伊勢崎市堤下町');
ok($zip->set_number('3720005')->is_valid_number, '群馬県伊勢崎市乾町');
ok($zip->set_number('3720006')->is_valid_number, '群馬県伊勢崎市太田町');
ok($zip->set_number('3720007')->is_valid_number, '群馬県伊勢崎市安堀町');
ok($zip->set_number('3720011')->is_valid_number, '群馬県伊勢崎市三和町');
ok($zip->set_number('3720012')->is_valid_number, '群馬県伊勢崎市豊城町');
ok($zip->set_number('3720013')->is_valid_number, '群馬県伊勢崎市上植木本町');
ok($zip->set_number('3720014')->is_valid_number, '群馬県伊勢崎市昭和町');
ok($zip->set_number('3720015')->is_valid_number, '群馬県伊勢崎市鹿島町');
ok($zip->set_number('3720016')->is_valid_number, '群馬県伊勢崎市本関町');
ok($zip->set_number('3720021')->is_valid_number, '群馬県伊勢崎市上諏訪町');
ok($zip->set_number('3720022')->is_valid_number, '群馬県伊勢崎市日乃出町');
ok($zip->set_number('3720023')->is_valid_number, '群馬県伊勢崎市粕川町');
ok($zip->set_number('3720024')->is_valid_number, '群馬県伊勢崎市下植木町');
ok($zip->set_number('3720025')->is_valid_number, '群馬県伊勢崎市東本町');
ok($zip->set_number('3720026')->is_valid_number, '群馬県伊勢崎市宮前町');
ok($zip->set_number('3720031')->is_valid_number, '群馬県伊勢崎市今泉町');
ok($zip->set_number('3720032')->is_valid_number, '群馬県伊勢崎市北千木町');
ok($zip->set_number('3720033')->is_valid_number, '群馬県伊勢崎市南千木町');
ok($zip->set_number('3720034')->is_valid_number, '群馬県伊勢崎市茂呂町');
ok($zip->set_number('3720036')->is_valid_number, '群馬県伊勢崎市茂呂南町');
ok($zip->set_number('3720037')->is_valid_number, '群馬県伊勢崎市美茂呂町');
ok($zip->set_number('3720038')->is_valid_number, '群馬県伊勢崎市新栄町');
ok($zip->set_number('3720039')->is_valid_number, '群馬県伊勢崎市ひろせ町');
ok($zip->set_number('3720041')->is_valid_number, '群馬県伊勢崎市平和町');
ok($zip->set_number('3720042')->is_valid_number, '群馬県伊勢崎市中央町');
ok($zip->set_number('3720043')->is_valid_number, '群馬県伊勢崎市緑町');
ok($zip->set_number('3720044')->is_valid_number, '群馬県伊勢崎市八坂町');
ok($zip->set_number('3720045')->is_valid_number, '群馬県伊勢崎市上泉町');
ok($zip->set_number('3720046')->is_valid_number, '群馬県伊勢崎市三光町');
ok($zip->set_number('3720047')->is_valid_number, '群馬県伊勢崎市本町');
ok($zip->set_number('3720048')->is_valid_number, '群馬県伊勢崎市大手町');
ok($zip->set_number('3720051')->is_valid_number, '群馬県伊勢崎市八幡町');
ok($zip->set_number('3720052')->is_valid_number, '群馬県伊勢崎市寿町');
ok($zip->set_number('3720053')->is_valid_number, '群馬県伊勢崎市宗高町');
ok($zip->set_number('3720054')->is_valid_number, '群馬県伊勢崎市柳原町');
ok($zip->set_number('3720055')->is_valid_number, '群馬県伊勢崎市曲輪町');
ok($zip->set_number('3720056')->is_valid_number, '群馬県伊勢崎市喜多町');
ok($zip->set_number('3720057')->is_valid_number, '群馬県伊勢崎市末広町');
ok($zip->set_number('3720058')->is_valid_number, '群馬県伊勢崎市西田町');
ok($zip->set_number('3720801')->is_valid_number, '群馬県伊勢崎市宮子町');
ok($zip->set_number('3720802')->is_valid_number, '群馬県伊勢崎市田中島町');
ok($zip->set_number('3720803')->is_valid_number, '群馬県伊勢崎市宮古町');
ok($zip->set_number('3720804')->is_valid_number, '群馬県伊勢崎市稲荷町');
ok($zip->set_number('3720811')->is_valid_number, '群馬県伊勢崎市若葉町');
ok($zip->set_number('3720812')->is_valid_number, '群馬県伊勢崎市連取町');
ok($zip->set_number('3720813')->is_valid_number, '群馬県伊勢崎市韮塚町');
ok($zip->set_number('3720814')->is_valid_number, '群馬県伊勢崎市田中町');
ok($zip->set_number('3720815')->is_valid_number, '群馬県伊勢崎市東上之宮町');
ok($zip->set_number('3720816')->is_valid_number, '群馬県伊勢崎市西上之宮町');
ok($zip->set_number('3720817')->is_valid_number, '群馬県伊勢崎市連取本町');
ok($zip->set_number('3720818')->is_valid_number, '群馬県伊勢崎市連取元町');
ok($zip->set_number('3720821')->is_valid_number, '群馬県伊勢崎市阿弥大寺町');
ok($zip->set_number('3720822')->is_valid_number, '群馬県伊勢崎市中町');
ok($zip->set_number('3720823')->is_valid_number, '群馬県伊勢崎市今井町');
ok($zip->set_number('3720824')->is_valid_number, '群馬県伊勢崎市柴町');
ok($zip->set_number('3720825')->is_valid_number, '群馬県伊勢崎市戸谷塚町');
ok($zip->set_number('3720826')->is_valid_number, '群馬県伊勢崎市福島町');
ok($zip->set_number('3720827')->is_valid_number, '群馬県伊勢崎市八斗島町');
ok($zip->set_number('3720831')->is_valid_number, '群馬県伊勢崎市山王町');
ok($zip->set_number('3720832')->is_valid_number, '群馬県伊勢崎市除ケ町');
ok($zip->set_number('3720833')->is_valid_number, '群馬県伊勢崎市富塚町');
ok($zip->set_number('3720834')->is_valid_number, '群馬県伊勢崎市堀口町');
ok($zip->set_number('3720841')->is_valid_number, '群馬県伊勢崎市大正寺町');
ok($zip->set_number('3720842')->is_valid_number, '群馬県伊勢崎市馬見塚町');
ok($zip->set_number('3720843')->is_valid_number, '群馬県伊勢崎市下道寺町');
ok($zip->set_number('3720844')->is_valid_number, '群馬県伊勢崎市羽黒町');
ok($zip->set_number('3720851')->is_valid_number, '群馬県伊勢崎市上蓮町');
ok($zip->set_number('3720852')->is_valid_number, '群馬県伊勢崎市下蓮町');
ok($zip->set_number('3720853')->is_valid_number, '群馬県伊勢崎市国領町');
ok($zip->set_number('3720854')->is_valid_number, '群馬県伊勢崎市飯島町');
ok($zip->set_number('3720855')->is_valid_number, '群馬県伊勢崎市長沼町');
ok($zip->set_number('3730000')->is_valid_number, '群馬県太田市以下に掲載がない場合');
ok($zip->set_number('3730001')->is_valid_number, '群馬県太田市西長岡町');
ok($zip->set_number('3730002')->is_valid_number, '群馬県太田市菅塩町');
ok($zip->set_number('3730003')->is_valid_number, '群馬県太田市北金井町');
ok($zip->set_number('3730004')->is_valid_number, '群馬県太田市強戸町');
ok($zip->set_number('3730006')->is_valid_number, '群馬県太田市成塚町');
ok($zip->set_number('3730007')->is_valid_number, '群馬県太田市石橋町');
ok($zip->set_number('3730008')->is_valid_number, '群馬県太田市鶴生田町');
ok($zip->set_number('3730011')->is_valid_number, '群馬県太田市只上町');
ok($zip->set_number('3730012')->is_valid_number, '群馬県太田市清原町');
ok($zip->set_number('3730013')->is_valid_number, '群馬県太田市市場町');
ok($zip->set_number('3730014')->is_valid_number, '群馬県太田市植木野町');
ok($zip->set_number('3730015')->is_valid_number, '群馬県太田市東新町');
ok($zip->set_number('3730016')->is_valid_number, '群馬県太田市矢田堀町');
ok($zip->set_number('3730018')->is_valid_number, '群馬県太田市丸山町');
ok($zip->set_number('3730019')->is_valid_number, '群馬県太田市吉沢町');
ok($zip->set_number('3730021')->is_valid_number, '群馬県太田市東今泉町');
ok($zip->set_number('3730022')->is_valid_number, '群馬県太田市東金井町');
ok($zip->set_number('3730023')->is_valid_number, '群馬県太田市富若町');
ok($zip->set_number('3730024')->is_valid_number, '群馬県太田市上小林町');
ok($zip->set_number('3730025')->is_valid_number, '群馬県太田市熊野町');
ok($zip->set_number('3730026')->is_valid_number, '群馬県太田市東本町');
ok($zip->set_number('3730027')->is_valid_number, '群馬県太田市金山町');
ok($zip->set_number('3730028')->is_valid_number, '群馬県太田市スバル町');
ok($zip->set_number('3730029')->is_valid_number, '群馬県太田市韮川町');
ok($zip->set_number('3730031')->is_valid_number, '群馬県太田市脇屋町');
ok($zip->set_number('3730032')->is_valid_number, '群馬県太田市新野町');
ok($zip->set_number('3730033')->is_valid_number, '群馬県太田市西本町');
ok($zip->set_number('3730034')->is_valid_number, '群馬県太田市藤阿久町');
ok($zip->set_number('3730035')->is_valid_number, '群馬県太田市藤久良町');
ok($zip->set_number('3730036')->is_valid_number, '群馬県太田市由良町');
ok($zip->set_number('3730037')->is_valid_number, '群馬県太田市新道町');
ok($zip->set_number('3730038')->is_valid_number, '群馬県太田市城西町');
ok($zip->set_number('3730041')->is_valid_number, '群馬県太田市別所町');
ok($zip->set_number('3730042')->is_valid_number, '群馬県太田市宝町');
ok($zip->set_number('3730043')->is_valid_number, '群馬県太田市西野谷町');
ok($zip->set_number('3730044')->is_valid_number, '群馬県太田市上田島町');
ok($zip->set_number('3730045')->is_valid_number, '群馬県太田市沖野町');
ok($zip->set_number('3730051')->is_valid_number, '群馬県太田市天良町');
ok($zip->set_number('3730052')->is_valid_number, '群馬県太田市寺井町');
ok($zip->set_number('3730053')->is_valid_number, '群馬県太田市鳥山町');
ok($zip->set_number('3730054')->is_valid_number, '群馬県太田市長手町');
ok($zip->set_number('3730055')->is_valid_number, '群馬県太田市大島町');
ok($zip->set_number('3730056')->is_valid_number, '群馬県太田市八幡町');
ok($zip->set_number('3730057')->is_valid_number, '群馬県太田市本町');
ok($zip->set_number('3730061')->is_valid_number, '群馬県太田市鳥山上町');
ok($zip->set_number('3730062')->is_valid_number, '群馬県太田市鳥山中町');
ok($zip->set_number('3730063')->is_valid_number, '群馬県太田市鳥山下町');
ok($zip->set_number('3730071')->is_valid_number, '群馬県太田市原宿町');
ok($zip->set_number('3730072')->is_valid_number, '群馬県太田市高瀬町');
ok($zip->set_number('3730073')->is_valid_number, '群馬県太田市緑町');
ok($zip->set_number('3730074')->is_valid_number, '群馬県太田市上強戸町');
ok($zip->set_number('3730075')->is_valid_number, '群馬県太田市大鷲町');
ok($zip->set_number('3730801')->is_valid_number, '群馬県太田市台之郷町');
ok($zip->set_number('3730802')->is_valid_number, '群馬県太田市矢場新町');
ok($zip->set_number('3730803')->is_valid_number, '群馬県太田市矢場町');
ok($zip->set_number('3730804')->is_valid_number, '群馬県太田市沖之郷町');
ok($zip->set_number('3730805')->is_valid_number, '群馬県太田市八重笠町');
ok($zip->set_number('3730806')->is_valid_number, '群馬県太田市龍舞町');
ok($zip->set_number('3730807')->is_valid_number, '群馬県太田市下小林町');
ok($zip->set_number('3730808')->is_valid_number, '群馬県太田市石原町');
ok($zip->set_number('3730809')->is_valid_number, '群馬県太田市茂木町');
ok($zip->set_number('3730811')->is_valid_number, '群馬県太田市安良岡町');
ok($zip->set_number('3730812')->is_valid_number, '群馬県太田市東長岡町');
ok($zip->set_number('3730813')->is_valid_number, '群馬県太田市内ケ島町');
ok($zip->set_number('3730814')->is_valid_number, '群馬県太田市朝日町');
ok($zip->set_number('3730815')->is_valid_number, '群馬県太田市東別所町');
ok($zip->set_number('3730816')->is_valid_number, '群馬県太田市東矢島町');
ok($zip->set_number('3730817')->is_valid_number, '群馬県太田市飯塚町');
ok($zip->set_number('3730818')->is_valid_number, '群馬県太田市小舞木町');
ok($zip->set_number('3730819')->is_valid_number, '群馬県太田市新島町');
ok($zip->set_number('3730821')->is_valid_number, '群馬県太田市下浜田町');
ok($zip->set_number('3730822')->is_valid_number, '群馬県太田市庄屋町');
ok($zip->set_number('3730823')->is_valid_number, '群馬県太田市西矢島町');
ok($zip->set_number('3730824')->is_valid_number, '群馬県太田市高林寿町');
ok($zip->set_number('3730825')->is_valid_number, '群馬県太田市高林東町');
ok($zip->set_number('3730826')->is_valid_number, '群馬県太田市古戸町');
ok($zip->set_number('3730827')->is_valid_number, '群馬県太田市高林南町');
ok($zip->set_number('3730828')->is_valid_number, '群馬県太田市高林西町');
ok($zip->set_number('3730829')->is_valid_number, '群馬県太田市高林北町');
ok($zip->set_number('3730831')->is_valid_number, '群馬県太田市福沢町');
ok($zip->set_number('3730832')->is_valid_number, '群馬県太田市富沢町');
ok($zip->set_number('3730833')->is_valid_number, '群馬県太田市牛沢町');
ok($zip->set_number('3730841')->is_valid_number, '群馬県太田市岩瀬川町');
ok($zip->set_number('3730842')->is_valid_number, '群馬県太田市細谷町');
ok($zip->set_number('3730843')->is_valid_number, '群馬県太田市米沢町');
ok($zip->set_number('3730844')->is_valid_number, '群馬県太田市下田島町');
ok($zip->set_number('3730845')->is_valid_number, '群馬県太田市泉町');
ok($zip->set_number('3730846')->is_valid_number, '群馬県太田市中根町');
ok($zip->set_number('3730847')->is_valid_number, '群馬県太田市西新町');
ok($zip->set_number('3730851')->is_valid_number, '群馬県太田市飯田町');
ok($zip->set_number('3730852')->is_valid_number, '群馬県太田市新井町');
ok($zip->set_number('3730853')->is_valid_number, '群馬県太田市浜町');
ok($zip->set_number('3730861')->is_valid_number, '群馬県太田市南矢島町');
ok($zip->set_number('3730862')->is_valid_number, '群馬県太田市末広町');
ok($zip->set_number('3740000')->is_valid_number, '群馬県館林市以下に掲載がない場合');
ok($zip->set_number('3740001')->is_valid_number, '群馬県館林市大島町');
ok($zip->set_number('3740002')->is_valid_number, '群馬県館林市田谷町');
ok($zip->set_number('3740003')->is_valid_number, '群馬県館林市四ツ谷町');
ok($zip->set_number('3740004')->is_valid_number, '群馬県館林市楠町');
ok($zip->set_number('3740005')->is_valid_number, '群馬県館林市花山町');
ok($zip->set_number('3740006')->is_valid_number, '群馬県館林市当郷町');
ok($zip->set_number('3740007')->is_valid_number, '群馬県館林市若宮町');
ok($zip->set_number('3740008')->is_valid_number, '群馬県館林市細内町');
ok($zip->set_number('3740009')->is_valid_number, '群馬県館林市千塚町');
ok($zip->set_number('3740011')->is_valid_number, '群馬県館林市羽附町');
ok($zip->set_number('3740012')->is_valid_number, '群馬県館林市羽附旭町');
ok($zip->set_number('3740013')->is_valid_number, '群馬県館林市赤生田町');
ok($zip->set_number('3740014')->is_valid_number, '群馬県館林市赤生田本町');
ok($zip->set_number('3740015')->is_valid_number, '群馬県館林市上赤生田町');
ok($zip->set_number('3740016')->is_valid_number, '群馬県館林市松原');
ok($zip->set_number('3740017')->is_valid_number, '群馬県館林市つつじ町');
ok($zip->set_number('3740018')->is_valid_number, '群馬県館林市城町');
ok($zip->set_number('3740019')->is_valid_number, '群馬県館林市尾曳町');
ok($zip->set_number('3740021')->is_valid_number, '群馬県館林市瀬戸谷町');
ok($zip->set_number('3740022')->is_valid_number, '群馬県館林市加法師町');
ok($zip->set_number('3740023')->is_valid_number, '群馬県館林市大手町');
ok($zip->set_number('3740024')->is_valid_number, '群馬県館林市本町');
ok($zip->set_number('3740025')->is_valid_number, '群馬県館林市緑町');
ok($zip->set_number('3740026')->is_valid_number, '群馬県館林市新宿');
ok($zip->set_number('3740027')->is_valid_number, '群馬県館林市富士見町');
ok($zip->set_number('3740028')->is_valid_number, '群馬県館林市千代田町');
ok($zip->set_number('3740029')->is_valid_number, '群馬県館林市仲町');
ok($zip->set_number('3740031')->is_valid_number, '群馬県館林市東美園町');
ok($zip->set_number('3740032')->is_valid_number, '群馬県館林市南美園町');
ok($zip->set_number('3740033')->is_valid_number, '群馬県館林市堀工町');
ok($zip->set_number('3740034')->is_valid_number, '群馬県館林市分福町');
ok($zip->set_number('3740035')->is_valid_number, '群馬県館林市青柳町');
ok($zip->set_number('3740036')->is_valid_number, '群馬県館林市諏訪町');
ok($zip->set_number('3740037')->is_valid_number, '群馬県館林市小桑原町');
ok($zip->set_number('3740038')->is_valid_number, '群馬県館林市西美園町');
ok($zip->set_number('3740039')->is_valid_number, '群馬県館林市美園町');
ok($zip->set_number('3740041')->is_valid_number, '群馬県館林市富士原町');
ok($zip->set_number('3740042')->is_valid_number, '群馬県館林市近藤町');
ok($zip->set_number('3740043')->is_valid_number, '群馬県館林市苗木町');
ok($zip->set_number('3740044')->is_valid_number, '群馬県館林市下三林町');
ok($zip->set_number('3740045')->is_valid_number, '群馬県館林市入ケ谷町');
ok($zip->set_number('3740046')->is_valid_number, '群馬県館林市上三林町');
ok($zip->set_number('3740047')->is_valid_number, '群馬県館林市野辺町');
ok($zip->set_number('3740051')->is_valid_number, '群馬県館林市新栄町');
ok($zip->set_number('3740052')->is_valid_number, '群馬県館林市栄町');
ok($zip->set_number('3740053')->is_valid_number, '群馬県館林市赤土町');
ok($zip->set_number('3740054')->is_valid_number, '群馬県館林市大谷町');
ok($zip->set_number('3740055')->is_valid_number, '群馬県館林市成島町');
ok($zip->set_number('3740056')->is_valid_number, '群馬県館林市松沼町');
ok($zip->set_number('3740057')->is_valid_number, '群馬県館林市北成島町');
ok($zip->set_number('3740061')->is_valid_number, '群馬県館林市東広内町');
ok($zip->set_number('3740062')->is_valid_number, '群馬県館林市広内町');
ok($zip->set_number('3740063')->is_valid_number, '群馬県館林市朝日町');
ok($zip->set_number('3740064')->is_valid_number, '群馬県館林市代官町');
ok($zip->set_number('3740065')->is_valid_number, '群馬県館林市西本町');
ok($zip->set_number('3740066')->is_valid_number, '群馬県館林市大街道');
ok($zip->set_number('3740067')->is_valid_number, '群馬県館林市岡野町');
ok($zip->set_number('3740068')->is_valid_number, '群馬県館林市台宿町');
ok($zip->set_number('3740069')->is_valid_number, '群馬県館林市坂下町');
ok($zip->set_number('3740071')->is_valid_number, '群馬県館林市下早川田町');
ok($zip->set_number('3740072')->is_valid_number, '群馬県館林市大新田町');
ok($zip->set_number('3740073')->is_valid_number, '群馬県館林市足次町');
ok($zip->set_number('3740074')->is_valid_number, '群馬県館林市高根町');
ok($zip->set_number('3740075')->is_valid_number, '群馬県館林市西高根町');
ok($zip->set_number('3740076')->is_valid_number, '群馬県館林市日向町');
ok($zip->set_number('3740077')->is_valid_number, '群馬県館林市木戸町');
ok($zip->set_number('3740078')->is_valid_number, '群馬県館林市傍示塚町');
ok($zip->set_number('3740079')->is_valid_number, '群馬県館林市上早川田町');
ok($zip->set_number('3740100')->is_valid_number, '群馬県邑楽郡板倉町以下に掲載がない場合');
ok($zip->set_number('3740101')->is_valid_number, '群馬県邑楽郡板倉町除川');
ok($zip->set_number('3740102')->is_valid_number, '群馬県邑楽郡板倉町離');
ok($zip->set_number('3740103')->is_valid_number, '群馬県邑楽郡板倉町細谷');
ok($zip->set_number('3740104')->is_valid_number, '群馬県邑楽郡板倉町大荷場');
ok($zip->set_number('3740105')->is_valid_number, '群馬県邑楽郡板倉町大曲');
ok($zip->set_number('3740106')->is_valid_number, '群馬県邑楽郡板倉町西岡新田');
ok($zip->set_number('3740107')->is_valid_number, '群馬県邑楽郡板倉町西岡');
ok($zip->set_number('3740111')->is_valid_number, '群馬県邑楽郡板倉町海老瀬');
ok($zip->set_number('3740112')->is_valid_number, '群馬県邑楽郡板倉町朝日野');
ok($zip->set_number('3740113')->is_valid_number, '群馬県邑楽郡板倉町泉野');
ok($zip->set_number('3740121')->is_valid_number, '群馬県邑楽郡板倉町下五箇');
ok($zip->set_number('3740122')->is_valid_number, '群馬県邑楽郡板倉町大高嶋');
ok($zip->set_number('3740123')->is_valid_number, '群馬県邑楽郡板倉町飯野');
ok($zip->set_number('3740131')->is_valid_number, '群馬県邑楽郡板倉町大蔵');
ok($zip->set_number('3740132')->is_valid_number, '群馬県邑楽郡板倉町板倉');
ok($zip->set_number('3740133')->is_valid_number, '群馬県邑楽郡板倉町岩田');
ok($zip->set_number('3740134')->is_valid_number, '群馬県邑楽郡板倉町籾谷');
ok($zip->set_number('3740135')->is_valid_number, '群馬県邑楽郡板倉町内蔵新田');
ok($zip->set_number('3750000')->is_valid_number, '群馬県藤岡市以下に掲載がない場合');
ok($zip->set_number('3750001')->is_valid_number, '群馬県藤岡市中島');
ok($zip->set_number('3750002')->is_valid_number, '群馬県藤岡市立石');
ok($zip->set_number('3750003')->is_valid_number, '群馬県藤岡市立石新田');
ok($zip->set_number('3750004')->is_valid_number, '群馬県藤岡市森');
ok($zip->set_number('3750005')->is_valid_number, '群馬県藤岡市中');
ok($zip->set_number('3750006')->is_valid_number, '群馬県藤岡市森新田');
ok($zip->set_number('3750011')->is_valid_number, '群馬県藤岡市岡之郷');
ok($zip->set_number('3750012')->is_valid_number, '群馬県藤岡市下戸塚');
ok($zip->set_number('3750013')->is_valid_number, '群馬県藤岡市上戸塚');
ok($zip->set_number('3750014')->is_valid_number, '群馬県藤岡市下栗須');
ok($zip->set_number('3750015')->is_valid_number, '群馬県藤岡市中栗須');
ok($zip->set_number('3750016')->is_valid_number, '群馬県藤岡市上栗須');
ok($zip->set_number('3750017')->is_valid_number, '群馬県藤岡市篠塚');
ok($zip->set_number('3750021')->is_valid_number, '群馬県藤岡市小林');
ok($zip->set_number('3750022')->is_valid_number, '群馬県藤岡市根岸');
ok($zip->set_number('3750023')->is_valid_number, '群馬県藤岡市本郷');
ok($zip->set_number('3750024')->is_valid_number, '群馬県藤岡市藤岡');
ok($zip->set_number('3750031')->is_valid_number, '群馬県藤岡市矢場');
ok($zip->set_number('3750032')->is_valid_number, '群馬県藤岡市神田');
ok($zip->set_number('3750033')->is_valid_number, '群馬県藤岡市川除');
ok($zip->set_number('3750034')->is_valid_number, '群馬県藤岡市牛田');
ok($zip->set_number('3750035')->is_valid_number, '群馬県藤岡市保美');
ok($zip->set_number('3750036')->is_valid_number, '群馬県藤岡市高山');
ok($zip->set_number('3750037')->is_valid_number, '群馬県藤岡市三本木');
ok($zip->set_number('3750041')->is_valid_number, '群馬県藤岡市緑埜');
ok($zip->set_number('3750042')->is_valid_number, '群馬県藤岡市鮎川');
ok($zip->set_number('3750043')->is_valid_number, '群馬県藤岡市東平井');
ok($zip->set_number('3750044')->is_valid_number, '群馬県藤岡市西平井');
ok($zip->set_number('3750045')->is_valid_number, '群馬県藤岡市金井');
ok($zip->set_number('3750046')->is_valid_number, '群馬県藤岡市下日野');
ok($zip->set_number('3750047')->is_valid_number, '群馬県藤岡市上日野');
ok($zip->set_number('3750051')->is_valid_number, '群馬県藤岡市本動堂');
ok($zip->set_number('3750052')->is_valid_number, '群馬県藤岡市下大塚');
ok($zip->set_number('3750053')->is_valid_number, '群馬県藤岡市中大塚');
ok($zip->set_number('3750054')->is_valid_number, '群馬県藤岡市上大塚');
ok($zip->set_number('3750055')->is_valid_number, '群馬県藤岡市白石');
ok($zip->set_number('3750056')->is_valid_number, '群馬県藤岡市三ツ木');
ok($zip->set_number('3750057')->is_valid_number, '群馬県藤岡市上落合');
ok($zip->set_number('3760000')->is_valid_number, '群馬県桐生市以下に掲載がない場合');
ok($zip->set_number('3760001')->is_valid_number, '群馬県桐生市菱町');
ok($zip->set_number('3760002')->is_valid_number, '群馬県桐生市境野町');
ok($zip->set_number('3760003')->is_valid_number, '群馬県桐生市琴平町');
ok($zip->set_number('3760004')->is_valid_number, '群馬県桐生市小梅町');
ok($zip->set_number('3760005')->is_valid_number, '群馬県桐生市三吉町');
ok($zip->set_number('3760006')->is_valid_number, '群馬県桐生市新宿');
ok($zip->set_number('3760007')->is_valid_number, '群馬県桐生市浜松町');
ok($zip->set_number('3760011')->is_valid_number, '群馬県桐生市相生町');
ok($zip->set_number('3760012')->is_valid_number, '群馬県桐生市桜木町');
ok($zip->set_number('3760013')->is_valid_number, '群馬県桐生市広沢町');
ok($zip->set_number('3760014')->is_valid_number, '群馬県桐生市広沢町間ノ島');
ok($zip->set_number('3760021')->is_valid_number, '群馬県桐生市巴町');
ok($zip->set_number('3760022')->is_valid_number, '群馬県桐生市稲荷町');
ok($zip->set_number('3760023')->is_valid_number, '群馬県桐生市錦町');
ok($zip->set_number('3760024')->is_valid_number, '群馬県桐生市織姫町');
ok($zip->set_number('3760025')->is_valid_number, '群馬県桐生市美原町');
ok($zip->set_number('3760026')->is_valid_number, '群馬県桐生市清瀬町');
ok($zip->set_number('3760027')->is_valid_number, '群馬県桐生市元宿町');
ok($zip->set_number('3760031')->is_valid_number, '群馬県桐生市本町');
ok($zip->set_number('3760032')->is_valid_number, '群馬県桐生市東町');
ok($zip->set_number('3760033')->is_valid_number, '群馬県桐生市泉町');
ok($zip->set_number('3760034')->is_valid_number, '群馬県桐生市東');
ok($zip->set_number('3760035')->is_valid_number, '群馬県桐生市仲町');
ok($zip->set_number('3760036')->is_valid_number, '群馬県桐生市川岸町');
ok($zip->set_number('3760037')->is_valid_number, '群馬県桐生市旭町');
ok($zip->set_number('3760038')->is_valid_number, '群馬県桐生市高砂町');
ok($zip->set_number('3760041')->is_valid_number, '群馬県桐生市川内町');
ok($zip->set_number('3760042')->is_valid_number, '群馬県桐生市堤町');
ok($zip->set_number('3760043')->is_valid_number, '群馬県桐生市小曾根町');
ok($zip->set_number('3760044')->is_valid_number, '群馬県桐生市永楽町');
ok($zip->set_number('3760045')->is_valid_number, '群馬県桐生市末広町');
ok($zip->set_number('3760046')->is_valid_number, '群馬県桐生市宮前町');
ok($zip->set_number('3760051')->is_valid_number, '群馬県桐生市平井町');
ok($zip->set_number('3760052')->is_valid_number, '群馬県桐生市天神町');
ok($zip->set_number('3760053')->is_valid_number, '群馬県桐生市東久方町');
ok($zip->set_number('3760054')->is_valid_number, '群馬県桐生市西久方町');
ok($zip->set_number('3760055')->is_valid_number, '群馬県桐生市横山町');
ok($zip->set_number('3760056')->is_valid_number, '群馬県桐生市宮本町');
ok($zip->set_number('3760100')->is_valid_number, '群馬県みどり市以下に掲載がない場合');
ok($zip->set_number('3760101')->is_valid_number, '群馬県みどり市大間々町大間々');
ok($zip->set_number('3760102')->is_valid_number, '群馬県みどり市大間々町桐原');
ok($zip->set_number('3760103')->is_valid_number, '群馬県みどり市大間々町下神梅');
ok($zip->set_number('3760104')->is_valid_number, '群馬県みどり市大間々町上神梅');
ok($zip->set_number('3760111')->is_valid_number, '群馬県みどり市大間々町小平');
ok($zip->set_number('3760112')->is_valid_number, '群馬県みどり市大間々町長尾根');
ok($zip->set_number('3760113')->is_valid_number, '群馬県みどり市大間々町高津戸');
ok($zip->set_number('3760114')->is_valid_number, '群馬県みどり市大間々町浅原');
ok($zip->set_number('3760115')->is_valid_number, '群馬県みどり市大間々町塩原');
ok($zip->set_number('3760116')->is_valid_number, '群馬県みどり市大間々町塩沢');
ok($zip->set_number('3760121')->is_valid_number, '群馬県桐生市新里町新川');
ok($zip->set_number('3760122')->is_valid_number, '群馬県桐生市新里町野');
ok($zip->set_number('3760123')->is_valid_number, '群馬県桐生市新里町武井');
ok($zip->set_number('3760124')->is_valid_number, '群馬県桐生市新里町小林');
ok($zip->set_number('3760125')->is_valid_number, '群馬県桐生市新里町山上');
ok($zip->set_number('3760131')->is_valid_number, '群馬県桐生市新里町奥沢');
ok($zip->set_number('3760132')->is_valid_number, '群馬県桐生市新里町鶴ケ谷');
ok($zip->set_number('3760133')->is_valid_number, '群馬県桐生市新里町大久保');
ok($zip->set_number('3760134')->is_valid_number, '群馬県桐生市新里町関');
ok($zip->set_number('3760135')->is_valid_number, '群馬県桐生市新里町高泉');
ok($zip->set_number('3760136')->is_valid_number, '群馬県桐生市新里町板橋');
ok($zip->set_number('3760137')->is_valid_number, '群馬県桐生市新里町赤城山');
ok($zip->set_number('3760141')->is_valid_number, '群馬県桐生市黒保根町水沼');
ok($zip->set_number('3760142')->is_valid_number, '群馬県桐生市黒保根町八木原');
ok($zip->set_number('3760143')->is_valid_number, '群馬県桐生市黒保根町宿廻');
ok($zip->set_number('3760144')->is_valid_number, '群馬県桐生市黒保根町下田沢');
ok($zip->set_number('3760145')->is_valid_number, '群馬県桐生市黒保根町上田沢');
ok($zip->set_number('3760301')->is_valid_number, '群馬県みどり市東町沢入');
ok($zip->set_number('3760302')->is_valid_number, '群馬県みどり市東町草木');
ok($zip->set_number('3760303')->is_valid_number, '群馬県みどり市東町座間');
ok($zip->set_number('3760304')->is_valid_number, '群馬県みどり市東町神戸');
ok($zip->set_number('3760305')->is_valid_number, '群馬県みどり市東町小夜戸');
ok($zip->set_number('3760306')->is_valid_number, '群馬県みどり市東町荻原');
ok($zip->set_number('3760307')->is_valid_number, '群馬県みどり市東町花輪');
ok($zip->set_number('3760308')->is_valid_number, '群馬県みどり市東町小中');
ok($zip->set_number('3760601')->is_valid_number, '群馬県桐生市梅田町');
ok($zip->set_number('3770000')->is_valid_number, '群馬県渋川市以下に掲載がない場合');
ok($zip->set_number('3770002')->is_valid_number, '群馬県渋川市中村');
ok($zip->set_number('3770003')->is_valid_number, '群馬県渋川市八木原');
ok($zip->set_number('3770004')->is_valid_number, '群馬県渋川市半田');
ok($zip->set_number('3770005')->is_valid_number, '群馬県渋川市有馬');
ok($zip->set_number('3770006')->is_valid_number, '群馬県渋川市行幸田');
ok($zip->set_number('3770007')->is_valid_number, '群馬県渋川市石原');
ok($zip->set_number('3770008')->is_valid_number, '群馬県渋川市渋川');
ok($zip->set_number('3770024')->is_valid_number, '群馬県渋川市祖母島');
ok($zip->set_number('3770025')->is_valid_number, '群馬県渋川市川島');
ok($zip->set_number('3770026')->is_valid_number, '群馬県渋川市南牧');
ok($zip->set_number('3770027')->is_valid_number, '群馬県渋川市金井');
ok($zip->set_number('3770031')->is_valid_number, '群馬県渋川市阿久津');
ok($zip->set_number('3770051')->is_valid_number, '群馬県渋川市北橘町赤城山');
ok($zip->set_number('3770052')->is_valid_number, '群馬県渋川市北橘町上箱田');
ok($zip->set_number('3770053')->is_valid_number, '群馬県渋川市北橘町箱田');
ok($zip->set_number('3770054')->is_valid_number, '群馬県渋川市北橘町下南室');
ok($zip->set_number('3770055')->is_valid_number, '群馬県渋川市北橘町上南室');
ok($zip->set_number('3770061')->is_valid_number, '群馬県渋川市北橘町下箱田');
ok($zip->set_number('3770062')->is_valid_number, '群馬県渋川市北橘町真壁');
ok($zip->set_number('3770063')->is_valid_number, '群馬県渋川市北橘町分郷八崎');
ok($zip->set_number('3770064')->is_valid_number, '群馬県渋川市北橘町八崎');
ok($zip->set_number('3770065')->is_valid_number, '群馬県渋川市北橘町小室');
ok($zip->set_number('3770101')->is_valid_number, '群馬県渋川市伊香保町湯中子');
ok($zip->set_number('3770102')->is_valid_number, '群馬県渋川市伊香保町伊香保');
ok($zip->set_number('3770103')->is_valid_number, '群馬県渋川市伊香保町水沢');
ok($zip->set_number('3770201')->is_valid_number, '群馬県渋川市上白井');
ok($zip->set_number('3770202')->is_valid_number, '群馬県渋川市中郷');
ok($zip->set_number('3770203')->is_valid_number, '群馬県渋川市吹屋');
ok($zip->set_number('3770204')->is_valid_number, '群馬県渋川市白井');
ok($zip->set_number('3770205')->is_valid_number, '群馬県渋川市北牧');
ok($zip->set_number('3770206')->is_valid_number, '群馬県渋川市横堀');
ok($zip->set_number('3770301')->is_valid_number, '群馬県吾妻郡東吾妻町箱島');
ok($zip->set_number('3770302')->is_valid_number, '群馬県吾妻郡東吾妻町岡崎(その他)');
ok($zip->set_number('3770303')->is_valid_number, '群馬県吾妻郡東吾妻町新巻');
ok($zip->set_number('3770304')->is_valid_number, '群馬県吾妻郡東吾妻町奥田');
ok($zip->set_number('3770305')->is_valid_number, '群馬県吾妻郡東吾妻町五町田');
ok($zip->set_number('3770311')->is_valid_number, '群馬県渋川市村上');
ok($zip->set_number('3770312')->is_valid_number, '群馬県渋川市小野子');
ok($zip->set_number('3770400')->is_valid_number, '群馬県吾妻郡中之条町以下に掲載がない場合');
ok($zip->set_number('3770411')->is_valid_number, '群馬県吾妻郡中之条町大道');
ok($zip->set_number('3770412')->is_valid_number, '群馬県吾妻郡中之条町栃窪');
ok($zip->set_number('3770413')->is_valid_number, '群馬県吾妻郡中之条町大塚');
ok($zip->set_number('3770414')->is_valid_number, '群馬県吾妻郡中之条町平');
ok($zip->set_number('3770415')->is_valid_number, '群馬県吾妻郡中之条町横尾');
ok($zip->set_number('3770416')->is_valid_number, '群馬県吾妻郡中之条町蟻川');
ok($zip->set_number('3770417')->is_valid_number, '群馬県吾妻郡中之条町赤坂');
ok($zip->set_number('3770421')->is_valid_number, '群馬県吾妻郡中之条町市城');
ok($zip->set_number('3770422')->is_valid_number, '群馬県吾妻郡中之条町青山');
ok($zip->set_number('3770423')->is_valid_number, '群馬県吾妻郡中之条町伊勢町');
ok($zip->set_number('3770424')->is_valid_number, '群馬県吾妻郡中之条町中之条町');
ok($zip->set_number('3770425')->is_valid_number, '群馬県吾妻郡中之条町西中之条');
ok($zip->set_number('3770431')->is_valid_number, '群馬県吾妻郡中之条町岩本');
ok($zip->set_number('3770432')->is_valid_number, '群馬県吾妻郡中之条町五反田');
ok($zip->set_number('3770433')->is_valid_number, '群馬県吾妻郡中之条町折田(その他)');
ok($zip->set_number('3770434')->is_valid_number, '群馬県吾妻郡中之条町山田(その他)');
ok($zip->set_number('3770541')->is_valid_number, '群馬県吾妻郡中之条町上沢渡');
ok($zip->set_number('3770542')->is_valid_number, '群馬県吾妻郡中之条町下沢渡');
ok($zip->set_number('3770543')->is_valid_number, '群馬県吾妻郡中之条町山田(寺社原、細尾)');
ok($zip->set_number('3770544')->is_valid_number, '群馬県吾妻郡中之条町折田(戦道)');
ok($zip->set_number('3770601')->is_valid_number, '群馬県吾妻郡中之条町四万');
ok($zip->set_number('3770700')->is_valid_number, '群馬県吾妻郡高山村以下に掲載がない場合');
ok($zip->set_number('3770701')->is_valid_number, '群馬県吾妻郡高山村尻高');
ok($zip->set_number('3770702')->is_valid_number, '群馬県吾妻郡高山村中山');
ok($zip->set_number('3770800')->is_valid_number, '群馬県吾妻郡東吾妻町以下に掲載がない場合');
ok($zip->set_number('3770801')->is_valid_number, '群馬県吾妻郡東吾妻町原町');
ok($zip->set_number('3770802')->is_valid_number, '群馬県吾妻郡東吾妻町川戸(その他)');
ok($zip->set_number('3770803')->is_valid_number, '群馬県吾妻郡東吾妻町金井');
ok($zip->set_number('3770804')->is_valid_number, '群馬県吾妻郡東吾妻町岩井');
ok($zip->set_number('3770805')->is_valid_number, '群馬県吾妻郡東吾妻町植栗');
ok($zip->set_number('3770806')->is_valid_number, '群馬県吾妻郡東吾妻町小泉');
ok($zip->set_number('3770807')->is_valid_number, '群馬県吾妻郡東吾妻町泉沢(その他)');
ok($zip->set_number('3770811')->is_valid_number, '群馬県吾妻郡東吾妻町郷原');
ok($zip->set_number('3770812')->is_valid_number, '群馬県吾妻郡東吾妻町厚田');
ok($zip->set_number('3770813')->is_valid_number, '群馬県吾妻郡東吾妻町三島');
ok($zip->set_number('3770814')->is_valid_number, '群馬県吾妻郡東吾妻町松谷');
ok($zip->set_number('3770815')->is_valid_number, '群馬県吾妻郡東吾妻町岩下');
ok($zip->set_number('3770816')->is_valid_number, '群馬県吾妻郡東吾妻町矢倉');
ok($zip->set_number('3770931')->is_valid_number, '群馬県吾妻郡東吾妻町大戸');
ok($zip->set_number('3770932')->is_valid_number, '群馬県吾妻郡東吾妻町萩生');
ok($zip->set_number('3770933')->is_valid_number, '群馬県吾妻郡東吾妻町本宿');
ok($zip->set_number('3770934')->is_valid_number, '群馬県吾妻郡東吾妻町須賀尾');
ok($zip->set_number('3770935')->is_valid_number, '群馬県吾妻郡東吾妻町大柏木');
ok($zip->set_number('3771300')->is_valid_number, '群馬県吾妻郡長野原町以下に掲載がない場合');
ok($zip->set_number('3771301')->is_valid_number, '群馬県吾妻郡長野原町川原畑');
ok($zip->set_number('3771302')->is_valid_number, '群馬県吾妻郡長野原町川原湯');
ok($zip->set_number('3771303')->is_valid_number, '群馬県吾妻郡長野原町横壁');
ok($zip->set_number('3771304')->is_valid_number, '群馬県吾妻郡長野原町長野原');
ok($zip->set_number('3771305')->is_valid_number, '群馬県吾妻郡長野原町与喜屋');
ok($zip->set_number('3771306')->is_valid_number, '群馬県吾妻郡長野原町古森');
ok($zip->set_number('3771307')->is_valid_number, '群馬県吾妻郡長野原町羽根尾');
ok($zip->set_number('3771308')->is_valid_number, '群馬県吾妻郡長野原町大津');
ok($zip->set_number('3771309')->is_valid_number, '群馬県吾妻郡長野原町林');
ok($zip->set_number('3771310')->is_valid_number, '群馬県吾妻郡長野原町応桑(堂光原)');
ok($zip->set_number('3771311')->is_valid_number, '群馬県吾妻郡中之条町赤岩');
ok($zip->set_number('3771312')->is_valid_number, '群馬県吾妻郡中之条町日影');
ok($zip->set_number('3771401')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(奥軽井沢)');
ok($zip->set_number('3771402')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(鬼の泉水)');
ok($zip->set_number('3771403')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(あやめケ原)');
ok($zip->set_number('3771404')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(大カイシコ)');
ok($zip->set_number('3771405')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(モロシコ「浅間園」)');
ok($zip->set_number('3771411')->is_valid_number, '群馬県吾妻郡長野原町応桑(その他)');
ok($zip->set_number('3771412')->is_valid_number, '群馬県吾妻郡長野原町北軽井沢');
ok($zip->set_number('3771500')->is_valid_number, '群馬県吾妻郡嬬恋村以下に掲載がない場合');
ok($zip->set_number('3771512')->is_valid_number, '群馬県吾妻郡嬬恋村大前(細原2259~)');
ok($zip->set_number('3771521')->is_valid_number, '群馬県吾妻郡嬬恋村今井');
ok($zip->set_number('3771522')->is_valid_number, '群馬県吾妻郡嬬恋村袋倉');
ok($zip->set_number('3771523')->is_valid_number, '群馬県吾妻郡嬬恋村芦生田');
ok($zip->set_number('3771524')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(その他)');
ok($zip->set_number('3771525')->is_valid_number, '群馬県吾妻郡嬬恋村西窪');
ok($zip->set_number('3771526')->is_valid_number, '群馬県吾妻郡嬬恋村三原');
ok($zip->set_number('3771527')->is_valid_number, '群馬県吾妻郡嬬恋村門貝');
ok($zip->set_number('3771528')->is_valid_number, '群馬県吾妻郡嬬恋村干俣(吾妻鉱山、万座温泉)');
ok($zip->set_number('3771611')->is_valid_number, '群馬県吾妻郡嬬恋村干俣(その他)');
ok($zip->set_number('3771612')->is_valid_number, '群馬県吾妻郡嬬恋村大前(その他)');
ok($zip->set_number('3771613')->is_valid_number, '群馬県吾妻郡嬬恋村大笹');
ok($zip->set_number('3771614')->is_valid_number, '群馬県吾妻郡嬬恋村田代');
ok($zip->set_number('3771615')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(藤原)');
ok($zip->set_number('3771616')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(柏木塚)');
ok($zip->set_number('3771617')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(群馬坂)');
ok($zip->set_number('3771700')->is_valid_number, '群馬県吾妻郡草津町以下に掲載がない場合');
ok($zip->set_number('3771701')->is_valid_number, '群馬県吾妻郡中之条町入山');
ok($zip->set_number('3771702')->is_valid_number, '群馬県吾妻郡中之条町生須');
ok($zip->set_number('3771703')->is_valid_number, '群馬県吾妻郡中之条町太子');
ok($zip->set_number('3771704')->is_valid_number, '群馬県吾妻郡中之条町小雨');
ok($zip->set_number('3771711')->is_valid_number, '群馬県吾妻郡草津町草津');
ok($zip->set_number('3771712')->is_valid_number, '群馬県吾妻郡草津町前口');
ok($zip->set_number('3780000')->is_valid_number, '群馬県沼田市以下に掲載がない場合');
ok($zip->set_number('3780001')->is_valid_number, '群馬県沼田市戸神町');
ok($zip->set_number('3780002')->is_valid_number, '群馬県沼田市横塚町');
ok($zip->set_number('3780003')->is_valid_number, '群馬県沼田市上久屋町');
ok($zip->set_number('3780004')->is_valid_number, '群馬県沼田市下久屋町');
ok($zip->set_number('3780005')->is_valid_number, '群馬県沼田市久屋原町');
ok($zip->set_number('3780011')->is_valid_number, '群馬県沼田市上沼須町');
ok($zip->set_number('3780012')->is_valid_number, '群馬県沼田市沼須町');
ok($zip->set_number('3780013')->is_valid_number, '群馬県沼田市新町');
ok($zip->set_number('3780014')->is_valid_number, '群馬県沼田市栄町');
ok($zip->set_number('3780015')->is_valid_number, '群馬県沼田市戸鹿野町');
ok($zip->set_number('3780016')->is_valid_number, '群馬県沼田市清水町');
ok($zip->set_number('3780017')->is_valid_number, '群馬県沼田市坊新田町');
ok($zip->set_number('3780018')->is_valid_number, '群馬県沼田市鍛冶町');
ok($zip->set_number('3780021')->is_valid_number, '群馬県沼田市岩本町');
ok($zip->set_number('3780022')->is_valid_number, '群馬県沼田市屋形原町');
ok($zip->set_number('3780023')->is_valid_number, '群馬県沼田市篠尾町');
ok($zip->set_number('3780024')->is_valid_number, '群馬県沼田市下川田町');
ok($zip->set_number('3780025')->is_valid_number, '群馬県沼田市今井町');
ok($zip->set_number('3780026')->is_valid_number, '群馬県沼田市上川田町');
ok($zip->set_number('3780031')->is_valid_number, '群馬県沼田市薄根町');
ok($zip->set_number('3780032')->is_valid_number, '群馬県沼田市硯田町');
ok($zip->set_number('3780033')->is_valid_number, '群馬県沼田市白岩町');
ok($zip->set_number('3780034')->is_valid_number, '群馬県沼田市恩田町');
ok($zip->set_number('3780035')->is_valid_number, '群馬県沼田市井土上町');
ok($zip->set_number('3780041')->is_valid_number, '群馬県沼田市榛名町');
ok($zip->set_number('3780042')->is_valid_number, '群馬県沼田市西倉内町');
ok($zip->set_number('3780043')->is_valid_number, '群馬県沼田市東倉内町');
ok($zip->set_number('3780044')->is_valid_number, '群馬県沼田市下之町');
ok($zip->set_number('3780045')->is_valid_number, '群馬県沼田市材木町');
ok($zip->set_number('3780046')->is_valid_number, '群馬県沼田市馬喰町');
ok($zip->set_number('3780047')->is_valid_number, '群馬県沼田市上之町');
ok($zip->set_number('3780048')->is_valid_number, '群馬県沼田市中町');
ok($zip->set_number('3780051')->is_valid_number, '群馬県沼田市上原町');
ok($zip->set_number('3780052')->is_valid_number, '群馬県沼田市桜町');
ok($zip->set_number('3780053')->is_valid_number, '群馬県沼田市東原新町');
ok($zip->set_number('3780054')->is_valid_number, '群馬県沼田市西原新町');
ok($zip->set_number('3780055')->is_valid_number, '群馬県沼田市柳町');
ok($zip->set_number('3780056')->is_valid_number, '群馬県沼田市高橋場町');
ok($zip->set_number('3780061')->is_valid_number, '群馬県沼田市岡谷町');
ok($zip->set_number('3780062')->is_valid_number, '群馬県沼田市町田町');
ok($zip->set_number('3780063')->is_valid_number, '群馬県沼田市下沼田町');
ok($zip->set_number('3780064')->is_valid_number, '群馬県沼田市善桂寺町');
ok($zip->set_number('3780065')->is_valid_number, '群馬県沼田市堀廻町');
ok($zip->set_number('3780066')->is_valid_number, '群馬県沼田市原町');
ok($zip->set_number('3780067')->is_valid_number, '群馬県沼田市大釜町');
ok($zip->set_number('3780068')->is_valid_number, '群馬県沼田市宇楚井町');
ok($zip->set_number('3780071')->is_valid_number, '群馬県沼田市上発知町');
ok($zip->set_number('3780072')->is_valid_number, '群馬県沼田市中発知町');
ok($zip->set_number('3780073')->is_valid_number, '群馬県沼田市発知新田町');
ok($zip->set_number('3780074')->is_valid_number, '群馬県沼田市下発知町');
ok($zip->set_number('3780075')->is_valid_number, '群馬県沼田市奈良町');
ok($zip->set_number('3780076')->is_valid_number, '群馬県沼田市秋塚町');
ok($zip->set_number('3780077')->is_valid_number, '群馬県沼田市石墨町');
ok($zip->set_number('3780078')->is_valid_number, '群馬県沼田市佐山町');
ok($zip->set_number('3780100')->is_valid_number, '群馬県利根郡川場村以下に掲載がない場合');
ok($zip->set_number('3780101')->is_valid_number, '群馬県利根郡川場村谷地');
ok($zip->set_number('3780102')->is_valid_number, '群馬県利根郡川場村川場湯原');
ok($zip->set_number('3780103')->is_valid_number, '群馬県利根郡川場村中野');
ok($zip->set_number('3780104')->is_valid_number, '群馬県利根郡川場村太田川');
ok($zip->set_number('3780105')->is_valid_number, '群馬県利根郡川場村小田川');
ok($zip->set_number('3780111')->is_valid_number, '群馬県利根郡川場村萩室');
ok($zip->set_number('3780112')->is_valid_number, '群馬県利根郡川場村立岩');
ok($zip->set_number('3780113')->is_valid_number, '群馬県利根郡川場村生品');
ok($zip->set_number('3780114')->is_valid_number, '群馬県利根郡川場村天神');
ok($zip->set_number('3780115')->is_valid_number, '群馬県利根郡川場村門前');
ok($zip->set_number('3780121')->is_valid_number, '群馬県沼田市白沢町高平');
ok($zip->set_number('3780122')->is_valid_number, '群馬県沼田市白沢町生枝');
ok($zip->set_number('3780123')->is_valid_number, '群馬県沼田市白沢町岩室');
ok($zip->set_number('3780124')->is_valid_number, '群馬県沼田市白沢町尾合');
ok($zip->set_number('3780125')->is_valid_number, '群馬県沼田市白沢町平出');
ok($zip->set_number('3780126')->is_valid_number, '群馬県沼田市白沢町上古語父');
ok($zip->set_number('3780127')->is_valid_number, '群馬県沼田市白沢町下古語父');
ok($zip->set_number('3780301')->is_valid_number, '群馬県沼田市利根町平川');
ok($zip->set_number('3780302')->is_valid_number, '群馬県沼田市利根町千鳥');
ok($zip->set_number('3780303')->is_valid_number, '群馬県沼田市利根町追貝');
ok($zip->set_number('3780304')->is_valid_number, '群馬県沼田市利根町大楊');
ok($zip->set_number('3780305')->is_valid_number, '群馬県沼田市利根町穴原');
ok($zip->set_number('3780306')->is_valid_number, '群馬県沼田市利根町日向南郷');
ok($zip->set_number('3780307')->is_valid_number, '群馬県沼田市利根町柿平');
ok($zip->set_number('3780311')->is_valid_number, '群馬県沼田市利根町小松');
ok($zip->set_number('3780312')->is_valid_number, '群馬県沼田市利根町根利');
ok($zip->set_number('3780313')->is_valid_number, '群馬県沼田市利根町日影南郷');
ok($zip->set_number('3780314')->is_valid_number, '群馬県沼田市利根町青木');
ok($zip->set_number('3780315')->is_valid_number, '群馬県沼田市利根町砂川');
ok($zip->set_number('3780316')->is_valid_number, '群馬県沼田市利根町二本松');
ok($zip->set_number('3780317')->is_valid_number, '群馬県沼田市利根町多那');
ok($zip->set_number('3780321')->is_valid_number, '群馬県沼田市利根町高戸谷');
ok($zip->set_number('3780322')->is_valid_number, '群馬県沼田市利根町老神');
ok($zip->set_number('3780323')->is_valid_number, '群馬県沼田市利根町大原');
ok($zip->set_number('3780324')->is_valid_number, '群馬県沼田市利根町園原');
ok($zip->set_number('3780325')->is_valid_number, '群馬県沼田市利根町輪組');
ok($zip->set_number('3780326')->is_valid_number, '群馬県沼田市利根町石戸新田');
ok($zip->set_number('3780400')->is_valid_number, '群馬県利根郡片品村以下に掲載がない場合');
ok($zip->set_number('3780401')->is_valid_number, '群馬県利根郡片品村須賀川');
ok($zip->set_number('3780402')->is_valid_number, '群馬県利根郡片品村御座入');
ok($zip->set_number('3780403')->is_valid_number, '群馬県利根郡片品村菅沼');
ok($zip->set_number('3780404')->is_valid_number, '群馬県利根郡片品村築地');
ok($zip->set_number('3780405')->is_valid_number, '群馬県利根郡片品村下平');
ok($zip->set_number('3780406')->is_valid_number, '群馬県利根郡片品村摺淵');
ok($zip->set_number('3780407')->is_valid_number, '群馬県利根郡片品村幡谷');
ok($zip->set_number('3780408')->is_valid_number, '群馬県利根郡片品村花咲');
ok($zip->set_number('3780409')->is_valid_number, '群馬県利根郡片品村針山');
ok($zip->set_number('3780411')->is_valid_number, '群馬県利根郡片品村戸倉');
ok($zip->set_number('3780412')->is_valid_number, '群馬県利根郡片品村土出');
ok($zip->set_number('3780413')->is_valid_number, '群馬県利根郡片品村越本');
ok($zip->set_number('3780414')->is_valid_number, '群馬県利根郡片品村東小川');
ok($zip->set_number('3780415')->is_valid_number, '群馬県利根郡片品村鎌田');
ok($zip->set_number('3790100')->is_valid_number, '群馬県安中市以下に掲載がない場合');
ok($zip->set_number('3790101')->is_valid_number, '群馬県安中市西上秋間');
ok($zip->set_number('3790102')->is_valid_number, '群馬県安中市東上秋間');
ok($zip->set_number('3790103')->is_valid_number, '群馬県安中市中秋間');
ok($zip->set_number('3790104')->is_valid_number, '群馬県安中市下秋間');
ok($zip->set_number('3790105')->is_valid_number, '群馬県安中市小俣');
ok($zip->set_number('3790106')->is_valid_number, '群馬県安中市下後閑');
ok($zip->set_number('3790107')->is_valid_number, '群馬県安中市中後閑');
ok($zip->set_number('3790108')->is_valid_number, '群馬県安中市上後閑');
ok($zip->set_number('3790109')->is_valid_number, '群馬県安中市秋間みのりが丘');
ok($zip->set_number('3790111')->is_valid_number, '群馬県安中市板鼻');
ok($zip->set_number('3790112')->is_valid_number, '群馬県安中市岩井');
ok($zip->set_number('3790113')->is_valid_number, '群馬県安中市大谷');
ok($zip->set_number('3790114')->is_valid_number, '群馬県安中市野殿');
ok($zip->set_number('3790115')->is_valid_number, '群馬県安中市中宿');
ok($zip->set_number('3790116')->is_valid_number, '群馬県安中市安中');
ok($zip->set_number('3790121')->is_valid_number, '群馬県安中市大竹');
ok($zip->set_number('3790122')->is_valid_number, '群馬県安中市下間仁田');
ok($zip->set_number('3790123')->is_valid_number, '群馬県安中市上間仁田');
ok($zip->set_number('3790124')->is_valid_number, '群馬県安中市鷺宮');
ok($zip->set_number('3790125')->is_valid_number, '群馬県安中市中野谷');
ok($zip->set_number('3790126')->is_valid_number, '群馬県安中市西上磯部');
ok($zip->set_number('3790127')->is_valid_number, '群馬県安中市磯部');
ok($zip->set_number('3790128')->is_valid_number, '群馬県安中市東上磯部');
ok($zip->set_number('3790129')->is_valid_number, '群馬県安中市下磯部');
ok($zip->set_number('3790131')->is_valid_number, '群馬県安中市古屋');
ok($zip->set_number('3790132')->is_valid_number, '群馬県安中市高別当');
ok($zip->set_number('3790133')->is_valid_number, '群馬県安中市原市');
ok($zip->set_number('3790134')->is_valid_number, '群馬県安中市簗瀬');
ok($zip->set_number('3790135')->is_valid_number, '群馬県安中市郷原');
ok($zip->set_number('3790136')->is_valid_number, '群馬県安中市嶺');
ok($zip->set_number('3790201')->is_valid_number, '群馬県富岡市妙義町妙義');
ok($zip->set_number('3790202')->is_valid_number, '群馬県富岡市妙義町大牛');
ok($zip->set_number('3790203')->is_valid_number, '群馬県富岡市妙義町岳');
ok($zip->set_number('3790204')->is_valid_number, '群馬県富岡市妙義町行沢');
ok($zip->set_number('3790205')->is_valid_number, '群馬県富岡市妙義町北山');
ok($zip->set_number('3790206')->is_valid_number, '群馬県富岡市妙義町中里');
ok($zip->set_number('3790207')->is_valid_number, '群馬県富岡市妙義町古立');
ok($zip->set_number('3790208')->is_valid_number, '群馬県富岡市妙義町菅原');
ok($zip->set_number('3790209')->is_valid_number, '群馬県富岡市妙義町諸戸');
ok($zip->set_number('3790211')->is_valid_number, '群馬県安中市松井田町上増田');
ok($zip->set_number('3790212')->is_valid_number, '群馬県安中市松井田町下増田');
ok($zip->set_number('3790213')->is_valid_number, '群馬県安中市松井田町小日向');
ok($zip->set_number('3790214')->is_valid_number, '群馬県安中市松井田町国衙');
ok($zip->set_number('3790215')->is_valid_number, '群馬県安中市松井田町高梨子');
ok($zip->set_number('3790216')->is_valid_number, '群馬県安中市松井田町新井');
ok($zip->set_number('3790217')->is_valid_number, '群馬県安中市松井田町土塩');
ok($zip->set_number('3790221')->is_valid_number, '群馬県安中市松井田町新堀');
ok($zip->set_number('3790222')->is_valid_number, '群馬県安中市松井田町松井田');
ok($zip->set_number('3790223')->is_valid_number, '群馬県安中市松井田町二軒在家');
ok($zip->set_number('3790224')->is_valid_number, '群馬県安中市松井田町人見');
ok($zip->set_number('3790225')->is_valid_number, '群馬県安中市松井田町八城');
ok($zip->set_number('3790226')->is_valid_number, '群馬県安中市松井田町行田');
ok($zip->set_number('3790301')->is_valid_number, '群馬県安中市松井田町横川');
ok($zip->set_number('3790302')->is_valid_number, '群馬県安中市松井田町五料');
ok($zip->set_number('3790303')->is_valid_number, '群馬県安中市松井田町西野牧');
ok($zip->set_number('3790304')->is_valid_number, '群馬県安中市松井田町北野牧');
ok($zip->set_number('3790305')->is_valid_number, '群馬県安中市松井田町入山');
ok($zip->set_number('3790306')->is_valid_number, '群馬県安中市松井田町原');
ok($zip->set_number('3790307')->is_valid_number, '群馬県安中市松井田町坂本');
ok($zip->set_number('3791101')->is_valid_number, '群馬県渋川市赤城町棚下');
ok($zip->set_number('3791102')->is_valid_number, '群馬県渋川市赤城町長井小川田');
ok($zip->set_number('3791103')->is_valid_number, '群馬県渋川市赤城町津久田');
ok($zip->set_number('3791104')->is_valid_number, '群馬県渋川市赤城町敷島');
ok($zip->set_number('3791105')->is_valid_number, '群馬県渋川市赤城町北上野');
ok($zip->set_number('3791111')->is_valid_number, '群馬県渋川市赤城町北赤城山');
ok($zip->set_number('3791112')->is_valid_number, '群馬県渋川市赤城町深山');
ok($zip->set_number('3791113')->is_valid_number, '群馬県渋川市赤城町南赤城山');
ok($zip->set_number('3791114')->is_valid_number, '群馬県渋川市赤城町栄');
ok($zip->set_number('3791115')->is_valid_number, '群馬県渋川市赤城町溝呂木');
ok($zip->set_number('3791116')->is_valid_number, '群馬県渋川市赤城町持柏木');
ok($zip->set_number('3791121')->is_valid_number, '群馬県渋川市赤城町宮田');
ok($zip->set_number('3791122')->is_valid_number, '群馬県渋川市赤城町勝保沢');
ok($zip->set_number('3791123')->is_valid_number, '群馬県渋川市赤城町見立');
ok($zip->set_number('3791124')->is_valid_number, '群馬県渋川市赤城町滝沢');
ok($zip->set_number('3791125')->is_valid_number, '群馬県渋川市赤城町上三原田');
ok($zip->set_number('3791126')->is_valid_number, '群馬県渋川市赤城町三原田');
ok($zip->set_number('3791127')->is_valid_number, '群馬県渋川市赤城町樽');
ok($zip->set_number('3791200')->is_valid_number, '群馬県利根郡昭和村以下に掲載がない場合');
ok($zip->set_number('3791201')->is_valid_number, '群馬県利根郡昭和村生越');
ok($zip->set_number('3791202')->is_valid_number, '群馬県利根郡昭和村貝野瀬');
ok($zip->set_number('3791203')->is_valid_number, '群馬県利根郡昭和村糸井');
ok($zip->set_number('3791204')->is_valid_number, '群馬県利根郡昭和村森下');
ok($zip->set_number('3791205')->is_valid_number, '群馬県利根郡昭和村川額');
ok($zip->set_number('3791206')->is_valid_number, '群馬県利根郡昭和村橡久保');
ok($zip->set_number('3791207')->is_valid_number, '群馬県利根郡昭和村赤城原');
ok($zip->set_number('3791300')->is_valid_number, '群馬県利根郡みなかみ町以下に掲載がない場合');
ok($zip->set_number('3791301')->is_valid_number, '群馬県利根郡みなかみ町奈女沢');
ok($zip->set_number('3791302')->is_valid_number, '群馬県利根郡みなかみ町大沼');
ok($zip->set_number('3791303')->is_valid_number, '群馬県利根郡みなかみ町上牧');
ok($zip->set_number('3791304')->is_valid_number, '群馬県利根郡みなかみ町下牧');
ok($zip->set_number('3791305')->is_valid_number, '群馬県利根郡みなかみ町後閑');
ok($zip->set_number('3791306')->is_valid_number, '群馬県利根郡みなかみ町師');
ok($zip->set_number('3791307')->is_valid_number, '群馬県利根郡みなかみ町政所');
ok($zip->set_number('3791308')->is_valid_number, '群馬県利根郡みなかみ町真庭');
ok($zip->set_number('3791311')->is_valid_number, '群馬県利根郡みなかみ町石倉');
ok($zip->set_number('3791312')->is_valid_number, '群馬県利根郡みなかみ町小川');
ok($zip->set_number('3791313')->is_valid_number, '群馬県利根郡みなかみ町月夜野');
ok($zip->set_number('3791314')->is_valid_number, '群馬県利根郡みなかみ町下津');
ok($zip->set_number('3791315')->is_valid_number, '群馬県利根郡みなかみ町上津');
ok($zip->set_number('3791401')->is_valid_number, '群馬県利根郡みなかみ町永井');
ok($zip->set_number('3791402')->is_valid_number, '群馬県利根郡みなかみ町吹路');
ok($zip->set_number('3791403')->is_valid_number, '群馬県利根郡みなかみ町猿ヶ京温泉');
ok($zip->set_number('3791404')->is_valid_number, '群馬県利根郡みなかみ町相俣');
ok($zip->set_number('3791409')->is_valid_number, '群馬県利根郡みなかみ町湯宿温泉');
ok($zip->set_number('3791411')->is_valid_number, '群馬県利根郡みなかみ町新巻');
ok($zip->set_number('3791412')->is_valid_number, '群馬県利根郡みなかみ町羽場');
ok($zip->set_number('3791413')->is_valid_number, '群馬県利根郡みなかみ町師田');
ok($zip->set_number('3791414')->is_valid_number, '群馬県利根郡みなかみ町布施');
ok($zip->set_number('3791415')->is_valid_number, '群馬県利根郡みなかみ町西峰須川');
ok($zip->set_number('3791416')->is_valid_number, '群馬県利根郡みなかみ町入須川');
ok($zip->set_number('3791417')->is_valid_number, '群馬県利根郡みなかみ町東峰');
ok($zip->set_number('3791418')->is_valid_number, '群馬県利根郡みなかみ町須川');
ok($zip->set_number('3791601')->is_valid_number, '群馬県利根郡みなかみ町吉本');
ok($zip->set_number('3791611')->is_valid_number, '群馬県利根郡みなかみ町鹿野沢');
ok($zip->set_number('3791612')->is_valid_number, '群馬県利根郡みなかみ町小日向');
ok($zip->set_number('3791613')->is_valid_number, '群馬県利根郡みなかみ町高日向');
ok($zip->set_number('3791614')->is_valid_number, '群馬県利根郡みなかみ町寺間');
ok($zip->set_number('3791615')->is_valid_number, '群馬県利根郡みなかみ町小仁田');
ok($zip->set_number('3791616')->is_valid_number, '群馬県利根郡みなかみ町川上');
ok($zip->set_number('3791617')->is_valid_number, '群馬県利根郡みなかみ町湯原');
ok($zip->set_number('3791618')->is_valid_number, '群馬県利根郡みなかみ町阿能川');
ok($zip->set_number('3791619')->is_valid_number, '群馬県利根郡みなかみ町谷川');
ok($zip->set_number('3791721')->is_valid_number, '群馬県利根郡みなかみ町藤原');
ok($zip->set_number('3791722')->is_valid_number, '群馬県利根郡みなかみ町夜後');
ok($zip->set_number('3791723')->is_valid_number, '群馬県利根郡みなかみ町粟沢');
ok($zip->set_number('3791724')->is_valid_number, '群馬県利根郡みなかみ町向山');
ok($zip->set_number('3791725')->is_valid_number, '群馬県利根郡みなかみ町綱子');
ok($zip->set_number('3791726')->is_valid_number, '群馬県利根郡みなかみ町幸知');
ok($zip->set_number('3791727')->is_valid_number, '群馬県利根郡みなかみ町大穴');
ok($zip->set_number('3791728')->is_valid_number, '群馬県利根郡みなかみ町湯桧曽');
ok($zip->set_number('3792101')->is_valid_number, '群馬県前橋市泉沢町');
ok($zip->set_number('3792102')->is_valid_number, '群馬県前橋市下大屋町');
ok($zip->set_number('3792103')->is_valid_number, '群馬県前橋市神沢の森');
ok($zip->set_number('3792104')->is_valid_number, '群馬県前橋市西大室町');
ok($zip->set_number('3792105')->is_valid_number, '群馬県前橋市東大室町');
ok($zip->set_number('3792106')->is_valid_number, '群馬県前橋市荒子町');
ok($zip->set_number('3792107')->is_valid_number, '群馬県前橋市荒口町');
ok($zip->set_number('3792108')->is_valid_number, '群馬県前橋市鶴が谷町');
ok($zip->set_number('3792111')->is_valid_number, '群馬県前橋市飯土井町');
ok($zip->set_number('3792112')->is_valid_number, '群馬県前橋市新井町');
ok($zip->set_number('3792113')->is_valid_number, '群馬県前橋市下増田町');
ok($zip->set_number('3792114')->is_valid_number, '群馬県前橋市上増田町');
ok($zip->set_number('3792115')->is_valid_number, '群馬県前橋市笂井町');
ok($zip->set_number('3792116')->is_valid_number, '群馬県前橋市今井町');
ok($zip->set_number('3792117')->is_valid_number, '群馬県前橋市二之宮町');
ok($zip->set_number('3792121')->is_valid_number, '群馬県前橋市小屋原町');
ok($zip->set_number('3792122')->is_valid_number, '群馬県前橋市駒形町');
ok($zip->set_number('3792123')->is_valid_number, '群馬県前橋市山王町');
ok($zip->set_number('3792131')->is_valid_number, '群馬県前橋市西善町');
ok($zip->set_number('3792132')->is_valid_number, '群馬県前橋市東善町');
ok($zip->set_number('3792133')->is_valid_number, '群馬県前橋市中内町');
ok($zip->set_number('3792134')->is_valid_number, '群馬県前橋市力丸町');
ok($zip->set_number('3792135')->is_valid_number, '群馬県前橋市徳丸町');
ok($zip->set_number('3792136')->is_valid_number, '群馬県前橋市房丸町');
ok($zip->set_number('3792141')->is_valid_number, '群馬県前橋市鶴光路町');
ok($zip->set_number('3792142')->is_valid_number, '群馬県前橋市下阿内町');
ok($zip->set_number('3792143')->is_valid_number, '群馬県前橋市新堀町');
ok($zip->set_number('3792144')->is_valid_number, '群馬県前橋市下川町');
ok($zip->set_number('3792145')->is_valid_number, '群馬県前橋市横手町');
ok($zip->set_number('3792146')->is_valid_number, '群馬県前橋市公田町');
ok($zip->set_number('3792147')->is_valid_number, '群馬県前橋市亀里町');
ok($zip->set_number('3792151')->is_valid_number, '群馬県前橋市下長磯町');
ok($zip->set_number('3792152')->is_valid_number, '群馬県前橋市下大島町');
ok($zip->set_number('3792153')->is_valid_number, '群馬県前橋市上大島町');
ok($zip->set_number('3792154')->is_valid_number, '群馬県前橋市天川大島町');
ok($zip->set_number('3792161')->is_valid_number, '群馬県前橋市富田町');
ok($zip->set_number('3792162')->is_valid_number, '群馬県前橋市小島田町');
ok($zip->set_number('3792163')->is_valid_number, '群馬県前橋市女屋町');
ok($zip->set_number('3792164')->is_valid_number, '群馬県前橋市東上野町');
ok($zip->set_number('3792165')->is_valid_number, '群馬県前橋市上長磯町');
ok($zip->set_number('3792166')->is_valid_number, '群馬県前橋市野中町');
ok($zip->set_number('3792201')->is_valid_number, '群馬県伊勢崎市間野谷町');
ok($zip->set_number('3792202')->is_valid_number, '群馬県伊勢崎市赤堀鹿島町');
ok($zip->set_number('3792203')->is_valid_number, '群馬県伊勢崎市曲沢町');
ok($zip->set_number('3792204')->is_valid_number, '群馬県伊勢崎市西久保町');
ok($zip->set_number('3792205')->is_valid_number, '群馬県伊勢崎市野町');
ok($zip->set_number('3792206')->is_valid_number, '群馬県伊勢崎市香林町');
ok($zip->set_number('3792211')->is_valid_number, '群馬県伊勢崎市市場町');
ok($zip->set_number('3792212')->is_valid_number, '群馬県伊勢崎市堀下町');
ok($zip->set_number('3792213')->is_valid_number, '群馬県伊勢崎市五目牛町');
ok($zip->set_number('3792214')->is_valid_number, '群馬県伊勢崎市下触町');
ok($zip->set_number('3792215')->is_valid_number, '群馬県伊勢崎市赤堀今井町');
ok($zip->set_number('3792216')->is_valid_number, '群馬県伊勢崎市西野町');
ok($zip->set_number('3792217')->is_valid_number, '群馬県伊勢崎市磯町');
ok($zip->set_number('3792221')->is_valid_number, '群馬県伊勢崎市国定町');
ok($zip->set_number('3792222')->is_valid_number, '群馬県伊勢崎市田部井町');
ok($zip->set_number('3792224')->is_valid_number, '群馬県伊勢崎市西小保方町');
ok($zip->set_number('3792225')->is_valid_number, '群馬県伊勢崎市上田町');
ok($zip->set_number('3792231')->is_valid_number, '群馬県伊勢崎市東町');
ok($zip->set_number('3792232')->is_valid_number, '群馬県伊勢崎市小泉町');
ok($zip->set_number('3792233')->is_valid_number, '群馬県伊勢崎市平井町');
ok($zip->set_number('3792234')->is_valid_number, '群馬県伊勢崎市東小保方町');
ok($zip->set_number('3792235')->is_valid_number, '群馬県伊勢崎市三室町');
ok($zip->set_number('3792236')->is_valid_number, '群馬県伊勢崎市八寸町');
ok($zip->set_number('3792301')->is_valid_number, '群馬県太田市藪塚町');
ok($zip->set_number('3792302')->is_valid_number, '群馬県太田市山之神町');
ok($zip->set_number('3792303')->is_valid_number, '群馬県太田市寄合町');
ok($zip->set_number('3792304')->is_valid_number, '群馬県太田市大原町');
ok($zip->set_number('3792305')->is_valid_number, '群馬県太田市六千石町');
ok($zip->set_number('3792306')->is_valid_number, '群馬県太田市大久保町');
ok($zip->set_number('3792311')->is_valid_number, '群馬県みどり市笠懸町阿左美');
ok($zip->set_number('3792312')->is_valid_number, '群馬県みどり市笠懸町久宮');
ok($zip->set_number('3792313')->is_valid_number, '群馬県みどり市笠懸町鹿');
ok($zip->set_number('3792314')->is_valid_number, '群馬県みどり市笠懸町西鹿田');
ok($zip->set_number('3800801')->is_valid_number, '長野県長野市箱清水');
ok($zip->set_number('3800802')->is_valid_number, '長野県長野市上松');
ok($zip->set_number('3800803')->is_valid_number, '長野県長野市三輪');
ok($zip->set_number('3800804')->is_valid_number, '長野県長野市荒屋');
ok($zip->set_number('3800805')->is_valid_number, '長野県長野市柳町');
ok($zip->set_number('3800806')->is_valid_number, '長野県長野市淀ケ橋');
ok($zip->set_number('3800807')->is_valid_number, '長野県長野市横山');
ok($zip->set_number('3800811')->is_valid_number, '長野県長野市鶴賀(東鶴賀町)');
ok($zip->set_number('3800811')->is_valid_number, '長野県長野市東鶴賀町');
ok($zip->set_number('3800812')->is_valid_number, '長野県長野市早苗町');
ok($zip->set_number('3800812')->is_valid_number, '長野県長野市鶴賀(早苗町)');
ok($zip->set_number('3800813')->is_valid_number, '長野県長野市鶴賀(緑町)');
ok($zip->set_number('3800813')->is_valid_number, '長野県長野市緑町');
ok($zip->set_number('3800814')->is_valid_number, '長野県長野市鶴賀(西鶴賀町)');
ok($zip->set_number('3800814')->is_valid_number, '長野県長野市西鶴賀町');
ok($zip->set_number('3800815')->is_valid_number, '長野県長野市田町');
ok($zip->set_number('3800815')->is_valid_number, '長野県長野市鶴賀(田町)');
ok($zip->set_number('3800816')->is_valid_number, '長野県長野市三輪田町');
ok($zip->set_number('3800821')->is_valid_number, '長野県長野市上千歳町');
ok($zip->set_number('3800821')->is_valid_number, '長野県長野市鶴賀(上千歳町)');
ok($zip->set_number('3800822')->is_valid_number, '長野県長野市鶴賀(南千歳町)');
ok($zip->set_number('3800822')->is_valid_number, '長野県長野市南千歳町');
ok($zip->set_number('3800823')->is_valid_number, '長野県長野市南千歳');
ok($zip->set_number('3800824')->is_valid_number, '長野県長野市南石堂町');
ok($zip->set_number('3800825')->is_valid_number, '長野県長野市末広町');
ok($zip->set_number('3800826')->is_valid_number, '長野県長野市北石堂町');
ok($zip->set_number('3800831')->is_valid_number, '長野県長野市東町');
ok($zip->set_number('3800832')->is_valid_number, '長野県長野市東後町');
ok($zip->set_number('3800833')->is_valid_number, '長野県長野市権堂町');
ok($zip->set_number('3800833')->is_valid_number, '長野県長野市鶴賀(権堂町)');
ok($zip->set_number('3800834')->is_valid_number, '長野県長野市鶴賀(問御所町)');
ok($zip->set_number('3800834')->is_valid_number, '長野県長野市問御所町');
ok($zip->set_number('3800835')->is_valid_number, '長野県長野市新田町');
ok($zip->set_number('3800836')->is_valid_number, '長野県長野市南県町');
ok($zip->set_number('3800837')->is_valid_number, '長野県長野市南長野(幅下)');
ok($zip->set_number('3800838')->is_valid_number, '長野県長野市県町');
ok($zip->set_number('3800841')->is_valid_number, '長野県長野市大門町');
ok($zip->set_number('3800842')->is_valid_number, '長野県長野市西町');
ok($zip->set_number('3800843')->is_valid_number, '長野県長野市長門町');
ok($zip->set_number('3800844')->is_valid_number, '長野県長野市諏訪町');
ok($zip->set_number('3800845')->is_valid_number, '長野県長野市西後町');
ok($zip->set_number('3800846')->is_valid_number, '長野県長野市旭町');
ok($zip->set_number('3800847')->is_valid_number, '長野県長野市若松町');
ok($zip->set_number('3800851')->is_valid_number, '長野県長野市元善町');
ok($zip->set_number('3800852')->is_valid_number, '長野県長野市東之門町');
ok($zip->set_number('3800853')->is_valid_number, '長野県長野市新町');
ok($zip->set_number('3800854')->is_valid_number, '長野県長野市伊勢町');
ok($zip->set_number('3800855')->is_valid_number, '長野県長野市岩石町');
ok($zip->set_number('3800856')->is_valid_number, '長野県長野市横町');
ok($zip->set_number('3800857')->is_valid_number, '長野県長野市西之門町');
ok($zip->set_number('3800858')->is_valid_number, '長野県長野市上西之門町');
ok($zip->set_number('3800861')->is_valid_number, '長野県長野市横沢町');
ok($zip->set_number('3800862')->is_valid_number, '長野県長野市桜枝町');
ok($zip->set_number('3800863')->is_valid_number, '長野県長野市栄町');
ok($zip->set_number('3800864')->is_valid_number, '長野県長野市立町');
ok($zip->set_number('3800865')->is_valid_number, '長野県長野市花咲町');
ok($zip->set_number('3800866')->is_valid_number, '長野県長野市狐池');
ok($zip->set_number('3800867')->is_valid_number, '長野県長野市往生地');
ok($zip->set_number('3800871')->is_valid_number, '長野県長野市西長野');
ok($zip->set_number('3800872')->is_valid_number, '長野県長野市妻科');
ok($zip->set_number('3800873')->is_valid_number, '長野県長野市新諏訪');
ok($zip->set_number('3800873')->is_valid_number, '長野県長野市新諏訪町');
ok($zip->set_number('3800874')->is_valid_number, '長野県長野市茂菅');
ok($zip->set_number('3800875')->is_valid_number, '長野県長野市小鍋');
ok($zip->set_number('3800876')->is_valid_number, '長野県長野市山田中');
ok($zip->set_number('3800877')->is_valid_number, '長野県長野市塩生');
ok($zip->set_number('3800881')->is_valid_number, '長野県長野市門沢');
ok($zip->set_number('3800882')->is_valid_number, '長野県長野市富田');
ok($zip->set_number('3800883')->is_valid_number, '長野県長野市泉平');
ok($zip->set_number('3800884')->is_valid_number, '長野県長野市鑪');
ok($zip->set_number('3800885')->is_valid_number, '長野県長野市桜');
ok($zip->set_number('3800886')->is_valid_number, '長野県長野市広瀬');
ok($zip->set_number('3800887')->is_valid_number, '長野県長野市入山');
ok($zip->set_number('3800888')->is_valid_number, '長野県長野市上ケ屋');
ok($zip->set_number('3800901')->is_valid_number, '長野県長野市居町');
ok($zip->set_number('3800901')->is_valid_number, '長野県長野市鶴賀(居町)');
ok($zip->set_number('3800902')->is_valid_number, '長野県長野市鶴賀(中堰)');
ok($zip->set_number('3800903')->is_valid_number, '長野県長野市鶴賀(峰村)');
ok($zip->set_number('3800904')->is_valid_number, '長野県長野市鶴賀(七瀬中町)');
ok($zip->set_number('3800904')->is_valid_number, '長野県長野市七瀬中町');
ok($zip->set_number('3800905')->is_valid_number, '長野県長野市鶴賀(七瀬南部)');
ok($zip->set_number('3800905')->is_valid_number, '長野県長野市七瀬南部');
ok($zip->set_number('3800906')->is_valid_number, '長野県長野市鶴賀(七瀬)');
ok($zip->set_number('3800907')->is_valid_number, '長野県長野市鶴賀');
ok($zip->set_number('3800911')->is_valid_number, '長野県長野市稲葉');
ok($zip->set_number('3800912')->is_valid_number, '長野県長野市稲葉日詰');
ok($zip->set_number('3800913')->is_valid_number, '長野県長野市川合新田');
ok($zip->set_number('3800914')->is_valid_number, '長野県長野市稲葉母袋');
ok($zip->set_number('3800915')->is_valid_number, '長野県長野市稲葉上千田');
ok($zip->set_number('3800916')->is_valid_number, '長野県長野市稲葉中千田');
ok($zip->set_number('3800917')->is_valid_number, '長野県長野市稲葉南俣');
ok($zip->set_number('3800918')->is_valid_number, '長野県長野市アークス');
ok($zip->set_number('3800921')->is_valid_number, '長野県長野市栗田');
ok($zip->set_number('3800922')->is_valid_number, '長野県長野市七瀬');
ok($zip->set_number('3800927')->is_valid_number, '長野県長野市栗田北中');
ok($zip->set_number('3800928')->is_valid_number, '長野県長野市若里');
ok($zip->set_number('3800934')->is_valid_number, '長野県長野市中御所町');
ok($zip->set_number('3800935')->is_valid_number, '長野県長野市中御所');
ok($zip->set_number('3800936')->is_valid_number, '長野県長野市岡田町');
ok($zip->set_number('3800941')->is_valid_number, '長野県長野市安茂里');
ok($zip->set_number('3800942')->is_valid_number, '長野県長野市小柴見');
ok($zip->set_number('3800943')->is_valid_number, '長野県長野市安茂里差出');
ok($zip->set_number('3800944')->is_valid_number, '長野県長野市安茂里米村');
ok($zip->set_number('3800945')->is_valid_number, '長野県長野市安茂里杏花台');
ok($zip->set_number('3800946')->is_valid_number, '長野県長野市平柴台');
ok($zip->set_number('3800947')->is_valid_number, '長野県長野市平柴');
ok($zip->set_number('3800948')->is_valid_number, '長野県長野市差出南');
ok($zip->set_number('3800952')->is_valid_number, '長野県長野市宮沖');
ok($zip->set_number('3800953')->is_valid_number, '長野県長野市安茂里犀北');
ok($zip->set_number('3800954')->is_valid_number, '長野県長野市安茂里犀北団地');
ok($zip->set_number('3800955')->is_valid_number, '長野県長野市安茂里西河原');
ok($zip->set_number('3800956')->is_valid_number, '長野県長野市安茂里小路');
ok($zip->set_number('3800957')->is_valid_number, '長野県長野市安茂里大門');
ok($zip->set_number('3800958')->is_valid_number, '長野県長野市伊勢宮');
ok($zip->set_number('3800961')->is_valid_number, '長野県長野市安茂里小市');
ok($zip->set_number('3810000')->is_valid_number, '長野県長野市以下に掲載がない場合');
ok($zip->set_number('3810001')->is_valid_number, '長野県長野市赤沼');
ok($zip->set_number('3810002')->is_valid_number, '長野県長野市津野');
ok($zip->set_number('3810003')->is_valid_number, '長野県長野市穂保');
ok($zip->set_number('3810004')->is_valid_number, '長野県長野市大町');
ok($zip->set_number('3810005')->is_valid_number, '長野県長野市北堀');
ok($zip->set_number('3810006')->is_valid_number, '長野県長野市富竹');
ok($zip->set_number('3810007')->is_valid_number, '長野県長野市金箱');
ok($zip->set_number('3810008')->is_valid_number, '長野県長野市下駒沢');
ok($zip->set_number('3810011')->is_valid_number, '長野県長野市村山');
ok($zip->set_number('3810012')->is_valid_number, '長野県長野市柳原');
ok($zip->set_number('3810013')->is_valid_number, '長野県長野市桜新町');
ok($zip->set_number('3810014')->is_valid_number, '長野県長野市北尾張部');
ok($zip->set_number('3810015')->is_valid_number, '長野県長野市石渡');
ok($zip->set_number('3810016')->is_valid_number, '長野県長野市南堀');
ok($zip->set_number('3810017')->is_valid_number, '長野県長野市小島');
ok($zip->set_number('3810021')->is_valid_number, '長野県長野市屋島');
ok($zip->set_number('3810022')->is_valid_number, '長野県長野市大豆島');
ok($zip->set_number('3810023')->is_valid_number, '長野県長野市風間');
ok($zip->set_number('3810024')->is_valid_number, '長野県長野市南長池');
ok($zip->set_number('3810025')->is_valid_number, '長野県長野市北長池');
ok($zip->set_number('3810026')->is_valid_number, '長野県長野市松岡');
ok($zip->set_number('3810031')->is_valid_number, '長野県長野市西尾張部');
ok($zip->set_number('3810032')->is_valid_number, '長野県長野市若宮');
ok($zip->set_number('3810033')->is_valid_number, '長野県長野市南高田');
ok($zip->set_number('3810034')->is_valid_number, '長野県長野市高田');
ok($zip->set_number('3810035')->is_valid_number, '長野県長野市北条町');
ok($zip->set_number('3810036')->is_valid_number, '長野県長野市平林');
ok($zip->set_number('3810037')->is_valid_number, '長野県長野市西和田');
ok($zip->set_number('3810038')->is_valid_number, '長野県長野市東和田');
ok($zip->set_number('3810041')->is_valid_number, '長野県長野市徳間');
ok($zip->set_number('3810042')->is_valid_number, '長野県長野市稲田');
ok($zip->set_number('3810043')->is_valid_number, '長野県長野市吉田');
ok($zip->set_number('3810044')->is_valid_number, '長野県長野市中越');
ok($zip->set_number('3810045')->is_valid_number, '長野県長野市桐原');
ok($zip->set_number('3810051')->is_valid_number, '長野県長野市若槻団地');
ok($zip->set_number('3810052')->is_valid_number, '長野県長野市檀田');
ok($zip->set_number('3810053')->is_valid_number, '長野県長野市神楽橋');
ok($zip->set_number('3810054')->is_valid_number, '長野県長野市浅川');
ok($zip->set_number('3810055')->is_valid_number, '長野県長野市屋敷田');
ok($zip->set_number('3810056')->is_valid_number, '長野県長野市浅川押田');
ok($zip->set_number('3810057')->is_valid_number, '長野県長野市浅川西条');
ok($zip->set_number('3810061')->is_valid_number, '長野県長野市坂中');
ok($zip->set_number('3810062')->is_valid_number, '長野県長野市浅川福岡');
ok($zip->set_number('3810063')->is_valid_number, '長野県長野市伺去');
ok($zip->set_number('3810064')->is_valid_number, '長野県長野市浅川東条');
ok($zip->set_number('3810065')->is_valid_number, '長野県長野市真光寺');
ok($zip->set_number('3810066')->is_valid_number, '長野県長野市浅川西平');
ok($zip->set_number('3810071')->is_valid_number, '長野県長野市台ケ窪');
ok($zip->set_number('3810072')->is_valid_number, '長野県長野市浅川清水');
ok($zip->set_number('3810073')->is_valid_number, '長野県長野市浅川畑山');
ok($zip->set_number('3810074')->is_valid_number, '長野県長野市中曽根');
ok($zip->set_number('3810075')->is_valid_number, '長野県長野市北郷');
ok($zip->set_number('3810076')->is_valid_number, '長野県長野市三ツ出');
ok($zip->set_number('3810081')->is_valid_number, '長野県長野市三才');
ok($zip->set_number('3810082')->is_valid_number, '長野県長野市上駒沢');
ok($zip->set_number('3810083')->is_valid_number, '長野県長野市西三才');
ok($zip->set_number('3810084')->is_valid_number, '長野県長野市若槻東条');
ok($zip->set_number('3810085')->is_valid_number, '長野県長野市上野');
ok($zip->set_number('3810086')->is_valid_number, '長野県長野市田中');
ok($zip->set_number('3810087')->is_valid_number, '長野県長野市田子');
ok($zip->set_number('3810088')->is_valid_number, '長野県長野市吉');
ok($zip->set_number('3810089')->is_valid_number, '長野県長野市若槻西条');
ok($zip->set_number('3810101')->is_valid_number, '長野県長野市若穂綿内');
ok($zip->set_number('3810102')->is_valid_number, '長野県長野市若穂保科');
ok($zip->set_number('3810103')->is_valid_number, '長野県長野市若穂川田');
ok($zip->set_number('3810104')->is_valid_number, '長野県長野市若穂牛島(その他)');
ok($zip->set_number('3810200')->is_valid_number, '長野県上高井郡小布施町以下に掲載がない場合');
ok($zip->set_number('3810201')->is_valid_number, '長野県上高井郡小布施町小布施');
ok($zip->set_number('3810202')->is_valid_number, '長野県上高井郡小布施町福原');
ok($zip->set_number('3810203')->is_valid_number, '長野県上高井郡小布施町大島');
ok($zip->set_number('3810204')->is_valid_number, '長野県上高井郡小布施町飯田');
ok($zip->set_number('3810205')->is_valid_number, '長野県上高井郡小布施町山王島');
ok($zip->set_number('3810206')->is_valid_number, '長野県上高井郡小布施町北岡');
ok($zip->set_number('3810207')->is_valid_number, '長野県上高井郡小布施町押羽');
ok($zip->set_number('3810208')->is_valid_number, '長野県上高井郡小布施町都住');
ok($zip->set_number('3810209')->is_valid_number, '長野県上高井郡小布施町中松');
ok($zip->set_number('3810211')->is_valid_number, '長野県上高井郡小布施町雁田');
ok($zip->set_number('3810212')->is_valid_number, '長野県上高井郡小布施町吉島');
ok($zip->set_number('3810400')->is_valid_number, '長野県下高井郡山ノ内町以下に掲載がない場合');
ok($zip->set_number('3810401')->is_valid_number, '長野県下高井郡山ノ内町平穏');
ok($zip->set_number('3810402')->is_valid_number, '長野県下高井郡山ノ内町佐野');
ok($zip->set_number('3810403')->is_valid_number, '長野県下高井郡山ノ内町寒沢');
ok($zip->set_number('3810404')->is_valid_number, '長野県下高井郡山ノ内町戸狩');
ok($zip->set_number('3810405')->is_valid_number, '長野県下高井郡山ノ内町夜間瀬');
ok($zip->set_number('3811211')->is_valid_number, '長野県長野市松代町大室');
ok($zip->set_number('3811212')->is_valid_number, '長野県長野市松代町牧島');
ok($zip->set_number('3811213')->is_valid_number, '長野県長野市松代町小島田');
ok($zip->set_number('3811214')->is_valid_number, '長野県長野市松代町柴');
ok($zip->set_number('3811215')->is_valid_number, '長野県長野市松代町西寺尾');
ok($zip->set_number('3811221')->is_valid_number, '長野県長野市松代町東条');
ok($zip->set_number('3811222')->is_valid_number, '長野県長野市松代町豊栄');
ok($zip->set_number('3811223')->is_valid_number, '長野県長野市皆神台');
ok($zip->set_number('3811224')->is_valid_number, '長野県長野市松代町城東');
ok($zip->set_number('3811225')->is_valid_number, '長野県長野市松代町東寺尾');
ok($zip->set_number('3811226')->is_valid_number, '長野県長野市松代温泉');
ok($zip->set_number('3811231')->is_valid_number, '長野県長野市松代町松代');
ok($zip->set_number('3811232')->is_valid_number, '長野県長野市松代町西条');
ok($zip->set_number('3811233')->is_valid_number, '長野県長野市松代町清野');
ok($zip->set_number('3811234')->is_valid_number, '長野県長野市松代町岩野');
ok($zip->set_number('3811235')->is_valid_number, '長野県長野市松代町城北');
ok($zip->set_number('3812201')->is_valid_number, '長野県長野市若穂牛島(1298~1835番地)');
ok($zip->set_number('3812202')->is_valid_number, '長野県長野市市場');
ok($zip->set_number('3812203')->is_valid_number, '長野県長野市真島町川合');
ok($zip->set_number('3812204')->is_valid_number, '長野県長野市真島町真島');
ok($zip->set_number('3812205')->is_valid_number, '長野県長野市青木島町大塚');
ok($zip->set_number('3812206')->is_valid_number, '長野県長野市青木島町綱島');
ok($zip->set_number('3812207')->is_valid_number, '長野県長野市大橋南');
ok($zip->set_number('3812211')->is_valid_number, '長野県長野市稲里町下氷鉋');
ok($zip->set_number('3812212')->is_valid_number, '長野県長野市小島田町');
ok($zip->set_number('3812213')->is_valid_number, '長野県長野市広田');
ok($zip->set_number('3812214')->is_valid_number, '長野県長野市稲里町田牧');
ok($zip->set_number('3812215')->is_valid_number, '長野県長野市稲里町中氷鉋');
ok($zip->set_number('3812216')->is_valid_number, '長野県長野市下氷鉋');
ok($zip->set_number('3812217')->is_valid_number, '長野県長野市稲里町中央');
ok($zip->set_number('3812221')->is_valid_number, '長野県長野市川中島町御厨');
ok($zip->set_number('3812222')->is_valid_number, '長野県長野市金井田');
ok($zip->set_number('3812223')->is_valid_number, '長野県長野市里島');
ok($zip->set_number('3812224')->is_valid_number, '長野県長野市川中島町原');
ok($zip->set_number('3812225')->is_valid_number, '長野県長野市篠ノ井岡田');
ok($zip->set_number('3812226')->is_valid_number, '長野県長野市川中島町今井');
ok($zip->set_number('3812227')->is_valid_number, '長野県長野市川中島町今井原');
ok($zip->set_number('3812231')->is_valid_number, '長野県長野市川中島町四ツ屋');
ok($zip->set_number('3812232')->is_valid_number, '長野県長野市川中島町若葉町');
ok($zip->set_number('3812233')->is_valid_number, '長野県長野市川中島町上氷鉋');
ok($zip->set_number('3812234')->is_valid_number, '長野県長野市川中島町今里');
ok($zip->set_number('3812235')->is_valid_number, '長野県長野市篠ノ井小松原');
ok($zip->set_number('3812241')->is_valid_number, '長野県長野市青木島町青木島乙');
ok($zip->set_number('3812242')->is_valid_number, '長野県長野市青木島町青木島');
ok($zip->set_number('3812243')->is_valid_number, '長野県長野市稲里');
ok($zip->set_number('3812244')->is_valid_number, '長野県長野市三本柳西');
ok($zip->set_number('3812245')->is_valid_number, '長野県長野市三本柳東');
ok($zip->set_number('3812246')->is_valid_number, '長野県長野市丹波島');
ok($zip->set_number('3812247')->is_valid_number, '長野県長野市青木島');
ok($zip->set_number('3812341')->is_valid_number, '長野県長野市信更町下平');
ok($zip->set_number('3812342')->is_valid_number, '長野県長野市信更町宮平');
ok($zip->set_number('3812343')->is_valid_number, '長野県長野市信更町桜井');
ok($zip->set_number('3812344')->is_valid_number, '長野県長野市信更町上尾');
ok($zip->set_number('3812345')->is_valid_number, '長野県長野市信更町涌池');
ok($zip->set_number('3812346')->is_valid_number, '長野県長野市信更町安庭');
ok($zip->set_number('3812347')->is_valid_number, '長野県長野市信更町古藤');
ok($zip->set_number('3812351')->is_valid_number, '長野県長野市信更町氷ノ田');
ok($zip->set_number('3812352')->is_valid_number, '長野県長野市信更町赤田');
ok($zip->set_number('3812353')->is_valid_number, '長野県長野市信更町田野口');
ok($zip->set_number('3812354')->is_valid_number, '長野県長野市信更町田沢');
ok($zip->set_number('3812355')->is_valid_number, '長野県長野市信更町高野');
ok($zip->set_number('3812356')->is_valid_number, '長野県長野市信更町吉原');
ok($zip->set_number('3812357')->is_valid_number, '長野県長野市信更町灰原');
ok($zip->set_number('3812358')->is_valid_number, '長野県長野市信更町今泉');
ok($zip->set_number('3812359')->is_valid_number, '長野県長野市信更町三水');
ok($zip->set_number('3812401')->is_valid_number, '長野県長野市信州新町越道');
ok($zip->set_number('3812402')->is_valid_number, '長野県長野市信州新町山上条');
ok($zip->set_number('3812403')->is_valid_number, '長野県長野市信州新町水内');
ok($zip->set_number('3812404')->is_valid_number, '長野県長野市信州新町上条');
ok($zip->set_number('3812405')->is_valid_number, '長野県長野市信州新町新町');
ok($zip->set_number('3812406')->is_valid_number, '長野県長野市信州新町里穂刈');
ok($zip->set_number('3812407')->is_valid_number, '長野県長野市信州新町山穂刈');
ok($zip->set_number('3812411')->is_valid_number, '長野県長野市信州新町竹房');
ok($zip->set_number('3812412')->is_valid_number, '長野県長野市信州新町牧野島');
ok($zip->set_number('3812413')->is_valid_number, '長野県長野市信州新町下市場');
ok($zip->set_number('3812414')->is_valid_number, '長野県長野市信州新町牧田中');
ok($zip->set_number('3812415')->is_valid_number, '長野県長野市信州新町中牧');
ok($zip->set_number('3812416')->is_valid_number, '長野県長野市信州新町弘崎');
ok($zip->set_number('3812421')->is_valid_number, '長野県長野市信州新町信級');
ok($zip->set_number('3812422')->is_valid_number, '長野県長野市信州新町日原東');
ok($zip->set_number('3812423')->is_valid_number, '長野県長野市信州新町日原西');
ok($zip->set_number('3812424')->is_valid_number, '長野県長野市信州新町左右');
ok($zip->set_number('3812701')->is_valid_number, '長野県長野市大岡中牧');
ok($zip->set_number('3812702')->is_valid_number, '長野県長野市大岡丙');
ok($zip->set_number('3812703')->is_valid_number, '長野県長野市大岡乙');
ok($zip->set_number('3812704')->is_valid_number, '長野県長野市大岡甲');
ok($zip->set_number('3812705')->is_valid_number, '長野県長野市大岡弘崎');
ok($zip->set_number('3813161')->is_valid_number, '長野県長野市七二会丁');
ok($zip->set_number('3813162')->is_valid_number, '長野県長野市七二会戊');
ok($zip->set_number('3813163')->is_valid_number, '長野県長野市七二会己');
ok($zip->set_number('3813164')->is_valid_number, '長野県長野市七二会乙');
ok($zip->set_number('3813165')->is_valid_number, '長野県長野市七二会甲');
ok($zip->set_number('3813166')->is_valid_number, '長野県長野市七二会丙');
ok($zip->set_number('3813201')->is_valid_number, '長野県長野市中条日高');
ok($zip->set_number('3813202')->is_valid_number, '長野県長野市中条日下野');
ok($zip->set_number('3813203')->is_valid_number, '長野県長野市中条');
ok($zip->set_number('3813204')->is_valid_number, '長野県長野市中条御山里');
ok($zip->set_number('3813205')->is_valid_number, '長野県長野市中条住良木');
ok($zip->set_number('3813300')->is_valid_number, '長野県上水内郡小川村以下に掲載がない場合');
ok($zip->set_number('3813301')->is_valid_number, '長野県上水内郡小川村稲丘');
ok($zip->set_number('3813302')->is_valid_number, '長野県上水内郡小川村高府');
ok($zip->set_number('3813303')->is_valid_number, '長野県上水内郡小川村小根山');
ok($zip->set_number('3813304')->is_valid_number, '長野県上水内郡小川村瀬戸川');
ok($zip->set_number('3814101')->is_valid_number, '長野県長野市戸隠');
ok($zip->set_number('3814102')->is_valid_number, '長野県長野市戸隠豊岡');
ok($zip->set_number('3814103')->is_valid_number, '長野県長野市戸隠祖山');
ok($zip->set_number('3814104')->is_valid_number, '長野県長野市戸隠栃原');
ok($zip->set_number('3814301')->is_valid_number, '長野県長野市鬼無里');
ok($zip->set_number('3814302')->is_valid_number, '長野県長野市鬼無里日影');
ok($zip->set_number('3814303')->is_valid_number, '長野県長野市鬼無里日下野');
ok($zip->set_number('3820000')->is_valid_number, '長野県須坂市以下に掲載がない場合');
ok($zip->set_number('3820001')->is_valid_number, '長野県須坂市松川町');
ok($zip->set_number('3820002')->is_valid_number, '長野県須坂市北旭ケ丘町');
ok($zip->set_number('3820003')->is_valid_number, '長野県須坂市旭ケ丘');
ok($zip->set_number('3820004')->is_valid_number, '長野県須坂市高畑町');
ok($zip->set_number('3820005')->is_valid_number, '長野県須坂市新田町');
ok($zip->set_number('3820006')->is_valid_number, '長野県須坂市光ケ丘ニュータウン');
ok($zip->set_number('3820011')->is_valid_number, '長野県須坂市本郷町');
ok($zip->set_number('3820012')->is_valid_number, '長野県須坂市大谷町');
ok($zip->set_number('3820013')->is_valid_number, '長野県須坂市常盤町');
ok($zip->set_number('3820014')->is_valid_number, '長野県須坂市新町');
ok($zip->set_number('3820015')->is_valid_number, '長野県須坂市太子町');
ok($zip->set_number('3820016')->is_valid_number, '長野県須坂市高橋町');
ok($zip->set_number('3820017')->is_valid_number, '長野県須坂市相森町');
ok($zip->set_number('3820021')->is_valid_number, '長野県須坂市豊丘町');
ok($zip->set_number('3820022')->is_valid_number, '長野県須坂市豊丘上町');
ok($zip->set_number('3820023')->is_valid_number, '長野県須坂市米子町');
ok($zip->set_number('3820024')->is_valid_number, '長野県須坂市塩野町');
ok($zip->set_number('3820025')->is_valid_number, '長野県須坂市大日向町');
ok($zip->set_number('3820026')->is_valid_number, '長野県須坂市坂田町');
ok($zip->set_number('3820027')->is_valid_number, '長野県須坂市南原町');
ok($zip->set_number('3820028')->is_valid_number, '長野県須坂市臥竜');
ok($zip->set_number('3820031')->is_valid_number, '長野県須坂市村石町');
ok($zip->set_number('3820032')->is_valid_number, '長野県須坂市夏端町');
ok($zip->set_number('3820033')->is_valid_number, '長野県須坂市亀倉町');
ok($zip->set_number('3820034')->is_valid_number, '長野県須坂市仁礼町(その他)');
ok($zip->set_number('3820036')->is_valid_number, '長野県須坂市明徳町');
ok($zip->set_number('3820037')->is_valid_number, '長野県須坂市野辺町');
ok($zip->set_number('3820041')->is_valid_number, '長野県須坂市米持町');
ok($zip->set_number('3820042')->is_valid_number, '長野県須坂市望岳台');
ok($zip->set_number('3820043')->is_valid_number, '長野県須坂市下八町');
ok($zip->set_number('3820044')->is_valid_number, '長野県須坂市上八町');
ok($zip->set_number('3820045')->is_valid_number, '長野県須坂市井上');
ok($zip->set_number('3820046')->is_valid_number, '長野県須坂市二睦町');
ok($zip->set_number('3820047')->is_valid_number, '長野県須坂市幸高町');
ok($zip->set_number('3820048')->is_valid_number, '長野県須坂市九反田町');
ok($zip->set_number('3820051')->is_valid_number, '長野県須坂市八重森町');
ok($zip->set_number('3820052')->is_valid_number, '長野県須坂市塩川町');
ok($zip->set_number('3820053')->is_valid_number, '長野県須坂市五閑町');
ok($zip->set_number('3820054')->is_valid_number, '長野県須坂市高梨町');
ok($zip->set_number('3820055')->is_valid_number, '長野県須坂市中島町');
ok($zip->set_number('3820056')->is_valid_number, '長野県須坂市福島町');
ok($zip->set_number('3820057')->is_valid_number, '長野県須坂市村山町');
ok($zip->set_number('3820061')->is_valid_number, '長野県須坂市北相之島町');
ok($zip->set_number('3820062')->is_valid_number, '長野県須坂市小島町');
ok($zip->set_number('3820063')->is_valid_number, '長野県須坂市西町');
ok($zip->set_number('3820064')->is_valid_number, '長野県須坂市沼目町');
ok($zip->set_number('3820065')->is_valid_number, '長野県須坂市相之島');
ok($zip->set_number('3820066')->is_valid_number, '長野県須坂市豊島町');
ok($zip->set_number('3820071')->is_valid_number, '長野県須坂市小河原町');
ok($zip->set_number('3820072')->is_valid_number, '長野県須坂市南小河原町');
ok($zip->set_number('3820073')->is_valid_number, '長野県須坂市田の神町');
ok($zip->set_number('3820074')->is_valid_number, '長野県須坂市春木町');
ok($zip->set_number('3820075')->is_valid_number, '長野県須坂市須坂ハイランド町');
ok($zip->set_number('3820076')->is_valid_number, '長野県須坂市馬場町');
ok($zip->set_number('3820077')->is_valid_number, '長野県須坂市北横町');
ok($zip->set_number('3820081')->is_valid_number, '長野県須坂市横町');
ok($zip->set_number('3820082')->is_valid_number, '長野県須坂市中町');
ok($zip->set_number('3820083')->is_valid_number, '長野県須坂市上中町');
ok($zip->set_number('3820084')->is_valid_number, '長野県須坂市上町');
ok($zip->set_number('3820085')->is_valid_number, '長野県須坂市穀町');
ok($zip->set_number('3820086')->is_valid_number, '長野県須坂市本上町');
ok($zip->set_number('3820087')->is_valid_number, '長野県須坂市東横町');
ok($zip->set_number('3820091')->is_valid_number, '長野県須坂市立町');
ok($zip->set_number('3820092')->is_valid_number, '長野県須坂市北原町');
ok($zip->set_number('3820094')->is_valid_number, '長野県須坂市屋部町');
ok($zip->set_number('3820097')->is_valid_number, '長野県須坂市南横町');
ok($zip->set_number('3820098')->is_valid_number, '長野県須坂市墨坂南');
ok($zip->set_number('3820099')->is_valid_number, '長野県須坂市墨坂');
ok($zip->set_number('3820800')->is_valid_number, '長野県上高井郡高山村以下に掲載がない場合');
ok($zip->set_number('3820801')->is_valid_number, '長野県上高井郡高山村駒場');
ok($zip->set_number('3820802')->is_valid_number, '長野県上高井郡高山村松原');
ok($zip->set_number('3820803')->is_valid_number, '長野県上高井郡高山村桝形');
ok($zip->set_number('3820804')->is_valid_number, '長野県上高井郡高山村中原');
ok($zip->set_number('3820805')->is_valid_number, '長野県上高井郡高山村三郷');
ok($zip->set_number('3820806')->is_valid_number, '長野県上高井郡高山村なかひら');
ok($zip->set_number('3820811')->is_valid_number, '長野県上高井郡高山村宮関');
ok($zip->set_number('3820813')->is_valid_number, '長野県上高井郡高山村蕨平');
ok($zip->set_number('3820814')->is_valid_number, '長野県上高井郡高山村天神原');
ok($zip->set_number('3820815')->is_valid_number, '長野県上高井郡高山村荻久保');
ok($zip->set_number('3820816')->is_valid_number, '長野県上高井郡高山村山田温泉');
ok($zip->set_number('3820817')->is_valid_number, '長野県上高井郡高山村山田牧場');
ok($zip->set_number('3820821')->is_valid_number, '長野県上高井郡高山村牧');
ok($zip->set_number('3820822')->is_valid_number, '長野県上高井郡高山村福井原');
ok($zip->set_number('3820823')->is_valid_number, '長野県上高井郡高山村黒部');
ok($zip->set_number('3820824')->is_valid_number, '長野県上高井郡高山村緑ケ丘');
ok($zip->set_number('3820825')->is_valid_number, '長野県上高井郡高山村紫');
ok($zip->set_number('3820826')->is_valid_number, '長野県上高井郡高山村二ツ石');
ok($zip->set_number('3820827')->is_valid_number, '長野県上高井郡高山村松南');
ok($zip->set_number('3820831')->is_valid_number, '長野県上高井郡高山村荒井原');
ok($zip->set_number('3820832')->is_valid_number, '長野県上高井郡高山村赤和');
ok($zip->set_number('3820833')->is_valid_number, '長野県上高井郡高山村久保');
ok($zip->set_number('3820834')->is_valid_number, '長野県上高井郡高山村水中');
ok($zip->set_number('3820835')->is_valid_number, '長野県上高井郡高山村千本松');
ok($zip->set_number('3820836')->is_valid_number, '長野県上高井郡高山村新堀');
ok($zip->set_number('3820837')->is_valid_number, '長野県上高井郡高山村堀之内');
ok($zip->set_number('3830000')->is_valid_number, '長野県中野市以下に掲載がない場合');
ok($zip->set_number('3830001')->is_valid_number, '長野県中野市岩井');
ok($zip->set_number('3830002')->is_valid_number, '長野県中野市田上(その他)');
ok($zip->set_number('3830003')->is_valid_number, '長野県中野市柳沢');
ok($zip->set_number('3830004')->is_valid_number, '長野県中野市赤岩');
ok($zip->set_number('3830005')->is_valid_number, '長野県中野市越');
ok($zip->set_number('3830006')->is_valid_number, '長野県中野市深沢');
ok($zip->set_number('3830007')->is_valid_number, '長野県中野市竹原');
ok($zip->set_number('3830008')->is_valid_number, '長野県中野市金井');
ok($zip->set_number('3830011')->is_valid_number, '長野県中野市若宮');
ok($zip->set_number('3830012')->is_valid_number, '長野県中野市一本木');
ok($zip->set_number('3830013')->is_valid_number, '長野県中野市中野');
ok($zip->set_number('3830014')->is_valid_number, '長野県中野市諏訪町');
ok($zip->set_number('3830015')->is_valid_number, '長野県中野市吉田');
ok($zip->set_number('3830021')->is_valid_number, '長野県中野市西');
ok($zip->set_number('3830022')->is_valid_number, '長野県中野市中央');
ok($zip->set_number('3830023')->is_valid_number, '長野県中野市小舘');
ok($zip->set_number('3830024')->is_valid_number, '長野県中野市東山');
ok($zip->set_number('3830025')->is_valid_number, '長野県中野市三好町');
ok($zip->set_number('3830031')->is_valid_number, '長野県中野市南宮');
ok($zip->set_number('3830032')->is_valid_number, '長野県中野市更科');
ok($zip->set_number('3830033')->is_valid_number, '長野県中野市間山');
ok($zip->set_number('3830034')->is_valid_number, '長野県中野市新野');
ok($zip->set_number('3830035')->is_valid_number, '長野県中野市篠井');
ok($zip->set_number('3830036')->is_valid_number, '長野県中野市新保');
ok($zip->set_number('3830037')->is_valid_number, '長野県中野市小田中');
ok($zip->set_number('3830041')->is_valid_number, '長野県中野市岩船');
ok($zip->set_number('3830042')->is_valid_number, '長野県中野市西条');
ok($zip->set_number('3830043')->is_valid_number, '長野県中野市三ツ和');
ok($zip->set_number('3830044')->is_valid_number, '長野県中野市桜沢');
ok($zip->set_number('3830045')->is_valid_number, '長野県中野市江部');
ok($zip->set_number('3830046')->is_valid_number, '長野県中野市片塩');
ok($zip->set_number('3830051')->is_valid_number, '長野県中野市七瀬');
ok($zip->set_number('3830052')->is_valid_number, '長野県中野市安源寺');
ok($zip->set_number('3830053')->is_valid_number, '長野県中野市草間');
ok($zip->set_number('3830054')->is_valid_number, '長野県中野市立ケ花');
ok($zip->set_number('3830055')->is_valid_number, '長野県中野市牛出');
ok($zip->set_number('3830056')->is_valid_number, '長野県中野市栗林');
ok($zip->set_number('3830057')->is_valid_number, '長野県中野市大俣');
ok($zip->set_number('3830061')->is_valid_number, '長野県中野市壁田');
ok($zip->set_number('3830062')->is_valid_number, '長野県中野市笠原');
ok($zip->set_number('3830063')->is_valid_number, '長野県中野市間長瀬');
ok($zip->set_number('3830064')->is_valid_number, '長野県中野市新井');
ok($zip->set_number('3830065')->is_valid_number, '長野県中野市田麦');
ok($zip->set_number('3830066')->is_valid_number, '長野県中野市厚貝');
ok($zip->set_number('3840000')->is_valid_number, '長野県小諸市以下に掲載がない場合');
ok($zip->set_number('3840001')->is_valid_number, '長野県小諸市小原');
ok($zip->set_number('3840002')->is_valid_number, '長野県小諸市唐松');
ok($zip->set_number('3840003')->is_valid_number, '長野県小諸市東山');
ok($zip->set_number('3840004')->is_valid_number, '長野県小諸市乙女');
ok($zip->set_number('3840005')->is_valid_number, '長野県小諸市御幸町');
ok($zip->set_number('3840006')->is_valid_number, '長野県小諸市与良町');
ok($zip->set_number('3840007')->is_valid_number, '長野県小諸市鶴巻');
ok($zip->set_number('3840008')->is_valid_number, '長野県小諸市東小諸');
ok($zip->set_number('3840011')->is_valid_number, '長野県小諸市赤坂');
ok($zip->set_number('3840012')->is_valid_number, '長野県小諸市南町');
ok($zip->set_number('3840013')->is_valid_number, '長野県小諸市緑ケ丘');
ok($zip->set_number('3840014')->is_valid_number, '長野県小諸市荒町');
ok($zip->set_number('3840015')->is_valid_number, '長野県小諸市紺屋町');
ok($zip->set_number('3840016')->is_valid_number, '長野県小諸市八幡町');
ok($zip->set_number('3840017')->is_valid_number, '長野県小諸市三和');
ok($zip->set_number('3840018')->is_valid_number, '長野県小諸市坂ノ上');
ok($zip->set_number('3840021')->is_valid_number, '長野県小諸市天池');
ok($zip->set_number('3840022')->is_valid_number, '長野県小諸市松井');
ok($zip->set_number('3840023')->is_valid_number, '長野県小諸市東雲');
ok($zip->set_number('3840024')->is_valid_number, '長野県小諸市熊ノ堂');
ok($zip->set_number('3840025')->is_valid_number, '長野県小諸市相生町');
ok($zip->set_number('3840026')->is_valid_number, '長野県小諸市本町');
ok($zip->set_number('3840027')->is_valid_number, '長野県小諸市六供');
ok($zip->set_number('3840028')->is_valid_number, '長野県小諸市田町');
ok($zip->set_number('3840031')->is_valid_number, '長野県小諸市大手');
ok($zip->set_number('3840032')->is_valid_number, '長野県小諸市古城');
ok($zip->set_number('3840033')->is_valid_number, '長野県小諸市市町');
ok($zip->set_number('3840034')->is_valid_number, '長野県小諸市新町');
ok($zip->set_number('3840035')->is_valid_number, '長野県小諸市両神');
ok($zip->set_number('3840036')->is_valid_number, '長野県小諸市富士見平');
ok($zip->set_number('3840037')->is_valid_number, '長野県小諸市押出');
ok($zip->set_number('3840038')->is_valid_number, '長野県小諸市栃木');
ok($zip->set_number('3840041')->is_valid_number, '長野県小諸市菱平');
ok($zip->set_number('3840042')->is_valid_number, '長野県小諸市後平');
ok($zip->set_number('3840043')->is_valid_number, '長野県小諸市諸');
ok($zip->set_number('3840044')->is_valid_number, '長野県小諸市西原');
ok($zip->set_number('3840045')->is_valid_number, '長野県小諸市滝原');
ok($zip->set_number('3840046')->is_valid_number, '長野県小諸市芝生田');
ok($zip->set_number('3840047')->is_valid_number, '長野県小諸市井子');
ok($zip->set_number('3840048')->is_valid_number, '長野県小諸市糠地');
ok($zip->set_number('3840051')->is_valid_number, '長野県小諸市八満');
ok($zip->set_number('3840052')->is_valid_number, '長野県小諸市東区');
ok($zip->set_number('3840053')->is_valid_number, '長野県小諸市藤塚');
ok($zip->set_number('3840054')->is_valid_number, '長野県小諸市石峠');
ok($zip->set_number('3840055')->is_valid_number, '長野県小諸市柏木');
ok($zip->set_number('3840056')->is_valid_number, '長野県小諸市四ツ谷');
ok($zip->set_number('3840061')->is_valid_number, '長野県小諸市加増');
ok($zip->set_number('3840062')->is_valid_number, '長野県小諸市荒堀');
ok($zip->set_number('3840063')->is_valid_number, '長野県小諸市南ケ原');
ok($zip->set_number('3840064')->is_valid_number, '長野県小諸市乗瀬');
ok($zip->set_number('3840065')->is_valid_number, '長野県小諸市ひばりケ丘');
ok($zip->set_number('3840071')->is_valid_number, '長野県小諸市大久保');
ok($zip->set_number('3840072')->is_valid_number, '長野県小諸市鴇久保');
ok($zip->set_number('3840074')->is_valid_number, '長野県小諸市西浦');
ok($zip->set_number('3840075')->is_valid_number, '長野県小諸市上ノ平');
ok($zip->set_number('3840076')->is_valid_number, '長野県小諸市久保');
ok($zip->set_number('3840077')->is_valid_number, '長野県小諸市大杭');
ok($zip->set_number('3840078')->is_valid_number, '長野県小諸市宮沢');
ok($zip->set_number('3840081')->is_valid_number, '長野県小諸市御牧ケ原');
ok($zip->set_number('3840082')->is_valid_number, '長野県小諸市諏訪山');
ok($zip->set_number('3840083')->is_valid_number, '長野県小諸市市');
ok($zip->set_number('3840084')->is_valid_number, '長野県小諸市耳取');
ok($zip->set_number('3840085')->is_valid_number, '長野県小諸市森山');
ok($zip->set_number('3840091')->is_valid_number, '長野県小諸市御影');
ok($zip->set_number('3840092')->is_valid_number, '長野県小諸市平原');
ok($zip->set_number('3840093')->is_valid_number, '長野県小諸市和田');
ok($zip->set_number('3840094')->is_valid_number, '長野県小諸市一ツ谷');
ok($zip->set_number('3840095')->is_valid_number, '長野県小諸市谷地原');
ok($zip->set_number('3840096')->is_valid_number, '長野県小諸市池ノ前');
ok($zip->set_number('3840097')->is_valid_number, '群馬県吾妻郡嬬恋村鎌原(高峰高原)');
ok($zip->set_number('3840301')->is_valid_number, '長野県佐久市臼田');
ok($zip->set_number('3840302')->is_valid_number, '長野県佐久市勝間');
ok($zip->set_number('3840303')->is_valid_number, '長野県佐久市下小田切');
ok($zip->set_number('3840304')->is_valid_number, '長野県佐久市北川');
ok($zip->set_number('3840305')->is_valid_number, '長野県佐久市中小田切');
ok($zip->set_number('3840306')->is_valid_number, '長野県佐久市上小田切');
ok($zip->set_number('3840307')->is_valid_number, '長野県佐久市湯原');
ok($zip->set_number('3840411')->is_valid_number, '長野県佐久市清川');
ok($zip->set_number('3840412')->is_valid_number, '長野県佐久市田口');
ok($zip->set_number('3840413')->is_valid_number, '長野県佐久市三分');
ok($zip->set_number('3840414')->is_valid_number, '長野県佐久市下越');
ok($zip->set_number('3840501')->is_valid_number, '長野県南佐久郡佐久穂町余地');
ok($zip->set_number('3840502')->is_valid_number, '長野県南佐久郡佐久穂町大日向');
ok($zip->set_number('3840503')->is_valid_number, '長野県南佐久郡佐久穂町海瀬');
ok($zip->set_number('3840600')->is_valid_number, '長野県南佐久郡佐久穂町以下に掲載がない場合');
ok($zip->set_number('3840611')->is_valid_number, '長野県南佐久郡佐久穂町平林');
ok($zip->set_number('3840612')->is_valid_number, '長野県南佐久郡佐久穂町宿岩');
ok($zip->set_number('3840613')->is_valid_number, '長野県南佐久郡佐久穂町高野町');
ok($zip->set_number('3840614')->is_valid_number, '長野県南佐久郡佐久穂町上');
ok($zip->set_number('3840621')->is_valid_number, '長野県佐久市入澤');
ok($zip->set_number('3840622')->is_valid_number, '長野県佐久市平林');
ok($zip->set_number('3840701')->is_valid_number, '長野県南佐久郡佐久穂町畑');
ok($zip->set_number('3840702')->is_valid_number, '長野県南佐久郡佐久穂町穂積');
ok($zip->set_number('3840703')->is_valid_number, '長野県南佐久郡佐久穂町千代里');
ok($zip->set_number('3840704')->is_valid_number, '長野県南佐久郡佐久穂町八郡');
ok($zip->set_number('3840801')->is_valid_number, '長野県小諸市甲');
ok($zip->set_number('3840802')->is_valid_number, '長野県小諸市乙');
ok($zip->set_number('3840803')->is_valid_number, '長野県小諸市丙');
ok($zip->set_number('3840804')->is_valid_number, '長野県小諸市丁');
ok($zip->set_number('3840805')->is_valid_number, '長野県小諸市己');
ok($zip->set_number('3840806')->is_valid_number, '長野県小諸市塩野');
ok($zip->set_number('3840807')->is_valid_number, '長野県小諸市山浦');
ok($zip->set_number('3840808')->is_valid_number, '長野県小諸市御影新田');
ok($zip->set_number('3840809')->is_valid_number, '長野県小諸市滋野甲');
ok($zip->set_number('3841100')->is_valid_number, '長野県南佐久郡小海町以下に掲載がない場合');
ok($zip->set_number('3841101')->is_valid_number, '長野県南佐久郡小海町東馬流');
ok($zip->set_number('3841102')->is_valid_number, '長野県南佐久郡小海町小海');
ok($zip->set_number('3841103')->is_valid_number, '長野県南佐久郡小海町豊里');
ok($zip->set_number('3841104')->is_valid_number, '長野県南佐久郡小海町稲子');
ok($zip->set_number('3841105')->is_valid_number, '長野県南佐久郡小海町千代里');
ok($zip->set_number('3841201')->is_valid_number, '長野県南佐久郡北相木村北相木村一円');
ok($zip->set_number('3841211')->is_valid_number, '長野県南佐久郡南相木村南相木村一円');
ok($zip->set_number('3841300')->is_valid_number, '長野県南佐久郡南牧村以下に掲載がない場合');
ok($zip->set_number('3841301')->is_valid_number, '長野県南佐久郡南牧村海尻');
ok($zip->set_number('3841302')->is_valid_number, '長野県南佐久郡南牧村海ノ口');
ok($zip->set_number('3841303')->is_valid_number, '長野県南佐久郡南牧村広瀬');
ok($zip->set_number('3841304')->is_valid_number, '長野県南佐久郡南牧村板橋');
ok($zip->set_number('3841305')->is_valid_number, '長野県南佐久郡南牧村野辺山');
ok($zip->set_number('3841306')->is_valid_number, '長野県南佐久郡南牧村平沢');
ok($zip->set_number('3841400')->is_valid_number, '長野県南佐久郡川上村以下に掲載がない場合');
ok($zip->set_number('3841401')->is_valid_number, '長野県南佐久郡川上村川端下');
ok($zip->set_number('3841402')->is_valid_number, '長野県南佐久郡川上村梓山');
ok($zip->set_number('3841403')->is_valid_number, '長野県南佐久郡川上村秋山');
ok($zip->set_number('3841404')->is_valid_number, '長野県南佐久郡川上村居倉');
ok($zip->set_number('3841405')->is_valid_number, '長野県南佐久郡川上村大深山');
ok($zip->set_number('3841406')->is_valid_number, '長野県南佐久郡川上村原');
ok($zip->set_number('3841407')->is_valid_number, '長野県南佐久郡川上村御所平');
ok($zip->set_number('3841408')->is_valid_number, '長野県南佐久郡川上村樋沢');
ok($zip->set_number('3842101')->is_valid_number, '長野県佐久市桑山');
ok($zip->set_number('3842102')->is_valid_number, '長野県佐久市塩名田');
ok($zip->set_number('3842103')->is_valid_number, '長野県佐久市御馬寄');
ok($zip->set_number('3842104')->is_valid_number, '長野県佐久市甲');
ok($zip->set_number('3842105')->is_valid_number, '長野県佐久市矢嶋');
ok($zip->set_number('3842106')->is_valid_number, '長野県佐久市八幡');
ok($zip->set_number('3842107')->is_valid_number, '長野県佐久市蓬田');
ok($zip->set_number('3842201')->is_valid_number, '長野県佐久市印内');
ok($zip->set_number('3842202')->is_valid_number, '長野県佐久市望月');
ok($zip->set_number('3842203')->is_valid_number, '長野県佐久市布施');
ok($zip->set_number('3842204')->is_valid_number, '長野県佐久市協和');
ok($zip->set_number('3842205')->is_valid_number, '長野県佐久市春日');
ok($zip->set_number('3842206')->is_valid_number, '長野県佐久市茂田井');
ok($zip->set_number('3842211')->is_valid_number, '長野県北佐久郡立科町茂田井(その他)');
ok($zip->set_number('3842300')->is_valid_number, '長野県北佐久郡立科町以下に掲載がない場合');
ok($zip->set_number('3842301')->is_valid_number, '長野県北佐久郡立科町桐原');
ok($zip->set_number('3842302')->is_valid_number, '長野県北佐久郡立科町藤沢');
ok($zip->set_number('3842303')->is_valid_number, '長野県北佐久郡立科町塩沢');
ok($zip->set_number('3842304')->is_valid_number, '長野県北佐久郡立科町茂田井(1~500「211番地を除く」「古町」、2527~2529「土遠」)');
ok($zip->set_number('3842305')->is_valid_number, '長野県北佐久郡立科町芦田');
ok($zip->set_number('3842306')->is_valid_number, '長野県北佐久郡立科町宇山');
ok($zip->set_number('3842307')->is_valid_number, '長野県北佐久郡立科町山部');
ok($zip->set_number('3842308')->is_valid_number, '長野県北佐久郡立科町牛鹿');
ok($zip->set_number('3842309')->is_valid_number, '長野県北佐久郡立科町芦田八ケ野(その他)');
ok($zip->set_number('3850000')->is_valid_number, '長野県佐久市以下に掲載がない場合');
ok($zip->set_number('3850001')->is_valid_number, '長野県佐久市横根');
ok($zip->set_number('3850002')->is_valid_number, '長野県佐久市上平尾');
ok($zip->set_number('3850003')->is_valid_number, '長野県佐久市下平尾');
ok($zip->set_number('3850004')->is_valid_number, '長野県佐久市安原');
ok($zip->set_number('3850005')->is_valid_number, '長野県佐久市香坂');
ok($zip->set_number('3850006')->is_valid_number, '長野県佐久市志賀');
ok($zip->set_number('3850007')->is_valid_number, '長野県佐久市新子田');
ok($zip->set_number('3850009')->is_valid_number, '長野県佐久市小田井');
ok($zip->set_number('3850011')->is_valid_number, '長野県佐久市猿久保');
ok($zip->set_number('3850012')->is_valid_number, '長野県佐久市根々井');
ok($zip->set_number('3850013')->is_valid_number, '長野県佐久市横和');
ok($zip->set_number('3850014')->is_valid_number, '長野県佐久市三河田');
ok($zip->set_number('3850015')->is_valid_number, '長野県佐久市今井');
ok($zip->set_number('3850016')->is_valid_number, '長野県佐久市鳴瀬');
ok($zip->set_number('3850021')->is_valid_number, '長野県佐久市長土呂');
ok($zip->set_number('3850022')->is_valid_number, '長野県佐久市岩村田');
ok($zip->set_number('3850023')->is_valid_number, '長野県佐久市岩村田北');
ok($zip->set_number('3850024')->is_valid_number, '長野県佐久市平塚');
ok($zip->set_number('3850025')->is_valid_number, '長野県佐久市塚原');
ok($zip->set_number('3850026')->is_valid_number, '長野県佐久市常田');
ok($zip->set_number('3850027')->is_valid_number, '長野県佐久市佐久平駅北');
ok($zip->set_number('3850028')->is_valid_number, '長野県佐久市佐久平駅東');
ok($zip->set_number('3850029')->is_valid_number, '長野県佐久市佐久平駅南');
ok($zip->set_number('3850031')->is_valid_number, '長野県佐久市内山');
ok($zip->set_number('3850032')->is_valid_number, '長野県佐久市常和');
ok($zip->set_number('3850033')->is_valid_number, '長野県佐久市太田部');
ok($zip->set_number('3850034')->is_valid_number, '長野県佐久市平賀');
ok($zip->set_number('3850035')->is_valid_number, '長野県佐久市瀬戸');
ok($zip->set_number('3850041')->is_valid_number, '長野県佐久市鍛冶屋');
ok($zip->set_number('3850042')->is_valid_number, '長野県佐久市高柳');
ok($zip->set_number('3850043')->is_valid_number, '長野県佐久市取出町');
ok($zip->set_number('3850044')->is_valid_number, '長野県佐久市本新町');
ok($zip->set_number('3850045')->is_valid_number, '長野県佐久市大沢');
ok($zip->set_number('3850046')->is_valid_number, '長野県佐久市前山');
ok($zip->set_number('3850047')->is_valid_number, '長野県佐久市小宮山');
ok($zip->set_number('3850051')->is_valid_number, '長野県佐久市中込');
ok($zip->set_number('3850052')->is_valid_number, '長野県佐久市原');
ok($zip->set_number('3850053')->is_valid_number, '長野県佐久市野沢');
ok($zip->set_number('3850054')->is_valid_number, '長野県佐久市跡部');
ok($zip->set_number('3850055')->is_valid_number, '長野県佐久市三塚');
ok($zip->set_number('3850056')->is_valid_number, '長野県佐久市桜井');
ok($zip->set_number('3850061')->is_valid_number, '長野県佐久市伴野');
ok($zip->set_number('3850062')->is_valid_number, '長野県佐久市根岸');
ok($zip->set_number('3850063')->is_valid_number, '長野県佐久市東立科');
ok($zip->set_number('3860000')->is_valid_number, '長野県上田市以下に掲載がない場合');
ok($zip->set_number('3860001')->is_valid_number, '長野県上田市上田');
ok($zip->set_number('3860002')->is_valid_number, '長野県上田市住吉');
ok($zip->set_number('3860003')->is_valid_number, '長野県上田市上野');
ok($zip->set_number('3860004')->is_valid_number, '長野県上田市殿城');
ok($zip->set_number('3860005')->is_valid_number, '長野県上田市古里');
ok($zip->set_number('3860006')->is_valid_number, '長野県上田市漆戸');
ok($zip->set_number('3860011')->is_valid_number, '長野県上田市中央北');
ok($zip->set_number('3860012')->is_valid_number, '長野県上田市中央');
ok($zip->set_number('3860013')->is_valid_number, '長野県上田市中央東');
ok($zip->set_number('3860014')->is_valid_number, '長野県上田市材木町');
ok($zip->set_number('3860015')->is_valid_number, '長野県上田市常入');
ok($zip->set_number('3860016')->is_valid_number, '長野県上田市国分');
ok($zip->set_number('3860017')->is_valid_number, '長野県上田市踏入');
ok($zip->set_number('3860018')->is_valid_number, '長野県上田市常田');
ok($zip->set_number('3860022')->is_valid_number, '長野県上田市緑が丘');
ok($zip->set_number('3860023')->is_valid_number, '長野県上田市中央西');
ok($zip->set_number('3860024')->is_valid_number, '長野県上田市大手');
ok($zip->set_number('3860025')->is_valid_number, '長野県上田市天神');
ok($zip->set_number('3860026')->is_valid_number, '長野県上田市二の丸');
ok($zip->set_number('3860027')->is_valid_number, '長野県上田市常磐城');
ok($zip->set_number('3860031')->is_valid_number, '長野県上田市小牧');
ok($zip->set_number('3860032')->is_valid_number, '長野県上田市諏訪形');
ok($zip->set_number('3860033')->is_valid_number, '長野県上田市御所');
ok($zip->set_number('3860034')->is_valid_number, '長野県上田市中之条');
ok($zip->set_number('3860041')->is_valid_number, '長野県上田市秋和');
ok($zip->set_number('3860042')->is_valid_number, '長野県上田市上塩尻');
ok($zip->set_number('3860043')->is_valid_number, '長野県上田市下塩尻');
ok($zip->set_number('3860151')->is_valid_number, '長野県上田市芳田');
ok($zip->set_number('3860152')->is_valid_number, '長野県上田市大屋');
ok($zip->set_number('3860153')->is_valid_number, '長野県上田市岩下');
ok($zip->set_number('3860155')->is_valid_number, '長野県上田市蒼久保');
ok($zip->set_number('3860156')->is_valid_number, '長野県上田市林之郷');
ok($zip->set_number('3860321')->is_valid_number, '長野県上田市平井');
ok($zip->set_number('3860322')->is_valid_number, '長野県上田市西内');
ok($zip->set_number('3860323')->is_valid_number, '長野県上田市鹿教湯温泉');
ok($zip->set_number('3860401')->is_valid_number, '長野県上田市塩川');
ok($zip->set_number('3860402')->is_valid_number, '長野県上田市藤原田');
ok($zip->set_number('3860403')->is_valid_number, '長野県上田市腰越');
ok($zip->set_number('3860404')->is_valid_number, '長野県上田市上丸子');
ok($zip->set_number('3860405')->is_valid_number, '長野県上田市中丸子');
ok($zip->set_number('3860406')->is_valid_number, '長野県上田市下丸子');
ok($zip->set_number('3860407')->is_valid_number, '長野県上田市長瀬');
ok($zip->set_number('3860408')->is_valid_number, '長野県上田市本海野');
ok($zip->set_number('3860411')->is_valid_number, '長野県上田市生田');
ok($zip->set_number('3860412')->is_valid_number, '長野県上田市御嶽堂');
ok($zip->set_number('3860413')->is_valid_number, '長野県上田市東内');
ok($zip->set_number('3860501')->is_valid_number, '長野県上田市武石鳥屋');
ok($zip->set_number('3860502')->is_valid_number, '長野県上田市武石沖');
ok($zip->set_number('3860503')->is_valid_number, '長野県上田市下武石');
ok($zip->set_number('3860504')->is_valid_number, '長野県上田市武石小沢根');
ok($zip->set_number('3860505')->is_valid_number, '長野県上田市武石余里');
ok($zip->set_number('3860506')->is_valid_number, '長野県上田市武石下本入');
ok($zip->set_number('3860507')->is_valid_number, '長野県上田市武石上本入');
ok($zip->set_number('3860508')->is_valid_number, '長野県上田市上武石');
ok($zip->set_number('3860600')->is_valid_number, '長野県小県郡長和町以下に掲載がない場合');
ok($zip->set_number('3860601')->is_valid_number, '長野県小県郡長和町大門');
ok($zip->set_number('3860602')->is_valid_number, '長野県小県郡長和町長久保');
ok($zip->set_number('3860603')->is_valid_number, '長野県小県郡長和町古町');
ok($zip->set_number('3860701')->is_valid_number, '長野県小県郡長和町和田');
ok($zip->set_number('3861101')->is_valid_number, '長野県上田市下之条');
ok($zip->set_number('3861102')->is_valid_number, '長野県上田市上田原');
ok($zip->set_number('3861103')->is_valid_number, '長野県上田市神畑');
ok($zip->set_number('3861104')->is_valid_number, '長野県上田市福田');
ok($zip->set_number('3861105')->is_valid_number, '長野県上田市吉田');
ok($zip->set_number('3861106')->is_valid_number, '長野県上田市小泉');
ok($zip->set_number('3861107')->is_valid_number, '長野県上田市築地');
ok($zip->set_number('3861108')->is_valid_number, '長野県上田市神畑乙');
ok($zip->set_number('3861211')->is_valid_number, '長野県上田市下之郷');
ok($zip->set_number('3861212')->is_valid_number, '長野県上田市富士山');
ok($zip->set_number('3861213')->is_valid_number, '長野県上田市古安曽');
ok($zip->set_number('3861214')->is_valid_number, '長野県上田市下之郷乙');
ok($zip->set_number('3861321')->is_valid_number, '長野県上田市保野');
ok($zip->set_number('3861322')->is_valid_number, '長野県上田市小島');
ok($zip->set_number('3861323')->is_valid_number, '長野県上田市本郷');
ok($zip->set_number('3861324')->is_valid_number, '長野県上田市五加');
ok($zip->set_number('3861325')->is_valid_number, '長野県上田市中野');
ok($zip->set_number('3861326')->is_valid_number, '長野県上田市舞田');
ok($zip->set_number('3861327')->is_valid_number, '長野県上田市八木沢');
ok($zip->set_number('3861431')->is_valid_number, '長野県上田市別所温泉');
ok($zip->set_number('3861432')->is_valid_number, '長野県上田市山田');
ok($zip->set_number('3861433')->is_valid_number, '長野県上田市手塚');
ok($zip->set_number('3861434')->is_valid_number, '長野県上田市新町');
ok($zip->set_number('3861435')->is_valid_number, '長野県上田市十人');
ok($zip->set_number('3861436')->is_valid_number, '長野県上田市前山');
ok($zip->set_number('3861437')->is_valid_number, '長野県上田市野倉');
ok($zip->set_number('3861541')->is_valid_number, '長野県上田市上室賀');
ok($zip->set_number('3861542')->is_valid_number, '長野県上田市下室賀');
ok($zip->set_number('3861543')->is_valid_number, '長野県上田市岡');
ok($zip->set_number('3861544')->is_valid_number, '長野県上田市仁古田');
ok($zip->set_number('3861545')->is_valid_number, '長野県上田市越戸');
ok($zip->set_number('3861546')->is_valid_number, '長野県上田市浦野');
ok($zip->set_number('3861600')->is_valid_number, '長野県小県郡青木村以下に掲載がない場合');
ok($zip->set_number('3861601')->is_valid_number, '長野県小県郡青木村田沢');
ok($zip->set_number('3861602')->is_valid_number, '長野県小県郡青木村村松');
ok($zip->set_number('3861603')->is_valid_number, '長野県小県郡青木村当郷');
ok($zip->set_number('3861604')->is_valid_number, '長野県小県郡青木村殿戸');
ok($zip->set_number('3861605')->is_valid_number, '長野県小県郡青木村夫神');
ok($zip->set_number('3861606')->is_valid_number, '長野県小県郡青木村沓掛');
ok($zip->set_number('3861607')->is_valid_number, '長野県小県郡青木村奈良本');
ok($zip->set_number('3862201')->is_valid_number, '長野県上田市真田町長');
ok($zip->set_number('3862202')->is_valid_number, '長野県上田市真田町本原');
ok($zip->set_number('3862203')->is_valid_number, '長野県上田市真田町傍陽');
ok($zip->set_number('3862204')->is_valid_number, '長野県上田市菅平高原');
ok($zip->set_number('3862211')->is_valid_number, '長野県須坂市仁礼町(3153-1~3153-1100「峰の原」)');
ok($zip->set_number('3870000')->is_valid_number, '長野県千曲市以下に掲載がない場合');
ok($zip->set_number('3870001')->is_valid_number, '長野県千曲市雨宮');
ok($zip->set_number('3870002')->is_valid_number, '長野県千曲市土口');
ok($zip->set_number('3870003')->is_valid_number, '長野県千曲市生萱');
ok($zip->set_number('3870004')->is_valid_number, '長野県千曲市倉科');
ok($zip->set_number('3870005')->is_valid_number, '長野県千曲市森');
ok($zip->set_number('3870006')->is_valid_number, '長野県千曲市粟佐');
ok($zip->set_number('3870007')->is_valid_number, '長野県千曲市屋代');
ok($zip->set_number('3870011')->is_valid_number, '長野県千曲市杭瀬下');
ok($zip->set_number('3870012')->is_valid_number, '長野県千曲市桜堂');
ok($zip->set_number('3870013')->is_valid_number, '長野県千曲市小島');
ok($zip->set_number('3870014')->is_valid_number, '長野県千曲市打沢');
ok($zip->set_number('3870015')->is_valid_number, '長野県千曲市鋳物師屋');
ok($zip->set_number('3870016')->is_valid_number, '長野県千曲市寂蒔');
ok($zip->set_number('3870017')->is_valid_number, '長野県千曲市中');
ok($zip->set_number('3870018')->is_valid_number, '長野県千曲市新田');
ok($zip->set_number('3870021')->is_valid_number, '長野県千曲市稲荷山');
ok($zip->set_number('3870022')->is_valid_number, '長野県千曲市野高場');
ok($zip->set_number('3870023')->is_valid_number, '長野県千曲市八幡');
ok($zip->set_number('3870024')->is_valid_number, '長野県千曲市桑原');
ok($zip->set_number('3888001')->is_valid_number, '長野県長野市東犀南');
ok($zip->set_number('3888002')->is_valid_number, '長野県長野市篠ノ井東福寺');
ok($zip->set_number('3888003')->is_valid_number, '長野県長野市篠ノ井小森');
ok($zip->set_number('3888004')->is_valid_number, '長野県長野市篠ノ井会');
ok($zip->set_number('3888005')->is_valid_number, '長野県長野市篠ノ井横田');
ok($zip->set_number('3888006')->is_valid_number, '長野県長野市篠ノ井御幣川');
ok($zip->set_number('3888007')->is_valid_number, '長野県長野市篠ノ井布施高田');
ok($zip->set_number('3888008')->is_valid_number, '長野県長野市合戦場');
ok($zip->set_number('3888011')->is_valid_number, '長野県長野市篠ノ井布施五明');
ok($zip->set_number('3888012')->is_valid_number, '長野県長野市篠ノ井二ツ柳');
ok($zip->set_number('3888013')->is_valid_number, '長野県長野市みこと川');
ok($zip->set_number('3888014')->is_valid_number, '長野県長野市篠ノ井塩崎');
ok($zip->set_number('3888015')->is_valid_number, '長野県長野市篠ノ井石川');
ok($zip->set_number('3888016')->is_valid_number, '長野県長野市篠ノ井有旅');
ok($zip->set_number('3888017')->is_valid_number, '長野県長野市篠ノ井山布施');
ok($zip->set_number('3888018')->is_valid_number, '長野県長野市篠ノ井西寺尾');
ok($zip->set_number('3888019')->is_valid_number, '長野県長野市篠ノ井杵淵');
ok($zip->set_number('3888020')->is_valid_number, '長野県長野市神明');
ok($zip->set_number('3890100')->is_valid_number, '長野県北佐久郡軽井沢町以下に掲載がない場合');
ok($zip->set_number('3890101')->is_valid_number, '長野県北佐久郡軽井沢町峠町');
ok($zip->set_number('3890102')->is_valid_number, '長野県北佐久郡軽井沢町軽井沢(大字)');
ok($zip->set_number('3890103')->is_valid_number, '長野県北佐久郡軽井沢町軽井沢(その他)');
ok($zip->set_number('3890104')->is_valid_number, '長野県北佐久郡軽井沢町軽井沢東');
ok($zip->set_number('3890111')->is_valid_number, '長野県北佐久郡軽井沢町長倉');
ok($zip->set_number('3890112')->is_valid_number, '長野県北佐久郡軽井沢町中軽井沢');
ok($zip->set_number('3890113')->is_valid_number, '長野県北佐久郡軽井沢町発地');
ok($zip->set_number('3890114')->is_valid_number, '長野県北佐久郡軽井沢町茂沢');
ok($zip->set_number('3890115')->is_valid_number, '長野県北佐久郡軽井沢町追分');
ok($zip->set_number('3890121')->is_valid_number, '群馬県安中市松井田町峠');
ok($zip->set_number('3890200')->is_valid_number, '長野県北佐久郡御代田町以下に掲載がない場合');
ok($zip->set_number('3890201')->is_valid_number, '長野県北佐久郡御代田町塩野');
ok($zip->set_number('3890202')->is_valid_number, '長野県北佐久郡御代田町草越');
ok($zip->set_number('3890203')->is_valid_number, '長野県北佐久郡御代田町広戸');
ok($zip->set_number('3890204')->is_valid_number, '長野県北佐久郡御代田町豊昇');
ok($zip->set_number('3890205')->is_valid_number, '長野県北佐久郡御代田町面替');
ok($zip->set_number('3890206')->is_valid_number, '長野県北佐久郡御代田町御代田');
ok($zip->set_number('3890207')->is_valid_number, '長野県北佐久郡御代田町馬瀬口');
ok($zip->set_number('3890208')->is_valid_number, '長野県北佐久郡御代田町茂沢');
ok($zip->set_number('3890401')->is_valid_number, '長野県東御市島川原');
ok($zip->set_number('3890402')->is_valid_number, '長野県東御市布下');
ok($zip->set_number('3890403')->is_valid_number, '長野県東御市御牧原');
ok($zip->set_number('3890404')->is_valid_number, '長野県東御市大日向');
ok($zip->set_number('3890405')->is_valid_number, '長野県東御市下之城');
ok($zip->set_number('3890406')->is_valid_number, '長野県東御市八重原');
ok($zip->set_number('3890407')->is_valid_number, '長野県東御市羽毛山');
ok($zip->set_number('3890500')->is_valid_number, '長野県東御市以下に掲載がない場合');
ok($zip->set_number('3890501')->is_valid_number, '長野県東御市新張');
ok($zip->set_number('3890502')->is_valid_number, '長野県東御市鞍掛');
ok($zip->set_number('3890503')->is_valid_number, '長野県東御市新屋');
ok($zip->set_number('3890504')->is_valid_number, '長野県東御市海善寺');
ok($zip->set_number('3890505')->is_valid_number, '長野県東御市和');
ok($zip->set_number('3890506')->is_valid_number, '長野県東御市祢津');
ok($zip->set_number('3890511')->is_valid_number, '長野県東御市滋野(甲)');
ok($zip->set_number('3890512')->is_valid_number, '長野県東御市滋野(乙)');
ok($zip->set_number('3890513')->is_valid_number, '長野県東御市滋野');
ok($zip->set_number('3890514')->is_valid_number, '長野県東御市加沢');
ok($zip->set_number('3890515')->is_valid_number, '長野県東御市常田');
ok($zip->set_number('3890516')->is_valid_number, '長野県東御市田中');
ok($zip->set_number('3890517')->is_valid_number, '長野県東御市県');
ok($zip->set_number('3890518')->is_valid_number, '長野県東御市本海野');
ok($zip->set_number('3890519')->is_valid_number, '長野県東御市塩川');
ok($zip->set_number('3890600')->is_valid_number, '長野県埴科郡坂城町以下に掲載がない場合');
ok($zip->set_number('3890601')->is_valid_number, '長野県埴科郡坂城町坂城');
ok($zip->set_number('3890602')->is_valid_number, '長野県埴科郡坂城町中之条');
ok($zip->set_number('3890603')->is_valid_number, '長野県埴科郡坂城町南条');
ok($zip->set_number('3890604')->is_valid_number, '長野県埴科郡坂城町網掛');
ok($zip->set_number('3890605')->is_valid_number, '長野県埴科郡坂城町上平');
ok($zip->set_number('3890606')->is_valid_number, '長野県埴科郡坂城町上五明');
ok($zip->set_number('3890801')->is_valid_number, '長野県千曲市小船山');
ok($zip->set_number('3890802')->is_valid_number, '長野県千曲市内川');
ok($zip->set_number('3890803')->is_valid_number, '長野県千曲市千本柳');
ok($zip->set_number('3890804')->is_valid_number, '長野県千曲市戸倉');
ok($zip->set_number('3890805')->is_valid_number, '長野県千曲市上徳間');
ok($zip->set_number('3890806')->is_valid_number, '長野県千曲市磯部');
ok($zip->set_number('3890807')->is_valid_number, '長野県千曲市戸倉温泉');
ok($zip->set_number('3890811')->is_valid_number, '長野県千曲市須坂');
ok($zip->set_number('3890812')->is_valid_number, '長野県千曲市羽尾');
ok($zip->set_number('3890813')->is_valid_number, '長野県千曲市若宮');
ok($zip->set_number('3890821')->is_valid_number, '長野県千曲市上山田温泉');
ok($zip->set_number('3890822')->is_valid_number, '長野県千曲市上山田');
ok($zip->set_number('3890823')->is_valid_number, '長野県千曲市新山');
ok($zip->set_number('3890824')->is_valid_number, '長野県千曲市力石');
ok($zip->set_number('3891101')->is_valid_number, '長野県長野市豊野町川谷');
ok($zip->set_number('3891102')->is_valid_number, '長野県長野市豊野町大倉');
ok($zip->set_number('3891103')->is_valid_number, '長野県長野市豊野町蟹沢');
ok($zip->set_number('3891104')->is_valid_number, '長野県長野市豊野町浅野');
ok($zip->set_number('3891105')->is_valid_number, '長野県長野市豊野町豊野');
ok($zip->set_number('3891106')->is_valid_number, '長野県長野市豊野町石');
ok($zip->set_number('3891107')->is_valid_number, '長野県長野市豊野町南郷');
ok($zip->set_number('3891200')->is_valid_number, '長野県上水内郡飯綱町以下に掲載がない場合');
ok($zip->set_number('3891201')->is_valid_number, '長野県上水内郡飯綱町芋川');
ok($zip->set_number('3891202')->is_valid_number, '長野県上水内郡飯綱町東柏原');
ok($zip->set_number('3891203')->is_valid_number, '長野県上水内郡飯綱町赤塩');
ok($zip->set_number('3891204')->is_valid_number, '長野県上水内郡飯綱町倉井');
ok($zip->set_number('3891205')->is_valid_number, '長野県上水内郡飯綱町川谷');
ok($zip->set_number('3891206')->is_valid_number, '長野県上水内郡飯綱町普光寺');
ok($zip->set_number('3891211')->is_valid_number, '長野県上水内郡飯綱町牟礼');
ok($zip->set_number('3891212')->is_valid_number, '長野県上水内郡飯綱町豊野');
ok($zip->set_number('3891213')->is_valid_number, '長野県上水内郡飯綱町平出');
ok($zip->set_number('3891214')->is_valid_number, '長野県上水内郡飯綱町黒川');
ok($zip->set_number('3891215')->is_valid_number, '長野県上水内郡飯綱町小玉');
ok($zip->set_number('3891221')->is_valid_number, '長野県上水内郡飯綱町古町');
ok($zip->set_number('3891222')->is_valid_number, '長野県上水内郡飯綱町柳里');
ok($zip->set_number('3891223')->is_valid_number, '長野県上水内郡飯綱町袖之山');
ok($zip->set_number('3891224')->is_valid_number, '長野県上水内郡飯綱町地蔵久保');
ok($zip->set_number('3891225')->is_valid_number, '長野県上水内郡飯綱町坂口');
ok($zip->set_number('3891226')->is_valid_number, '長野県上水内郡飯綱町川上');
ok($zip->set_number('3891227')->is_valid_number, '長野県上水内郡飯綱町高坂');
ok($zip->set_number('3891300')->is_valid_number, '長野県上水内郡信濃町以下に掲載がない場合');
ok($zip->set_number('3891301')->is_valid_number, '長野県上水内郡信濃町熊坂');
ok($zip->set_number('3891302')->is_valid_number, '長野県上水内郡信濃町古海');
ok($zip->set_number('3891303')->is_valid_number, '長野県上水内郡信濃町野尻');
ok($zip->set_number('3891304')->is_valid_number, '長野県上水内郡信濃町神山国際村');
ok($zip->set_number('3891305')->is_valid_number, '長野県上水内郡信濃町柏原');
ok($zip->set_number('3891306')->is_valid_number, '長野県上水内郡信濃町野尻(大学村)');
ok($zip->set_number('3891311')->is_valid_number, '長野県上水内郡信濃町荒瀬原');
ok($zip->set_number('3891312')->is_valid_number, '長野県上水内郡信濃町富濃');
ok($zip->set_number('3891313')->is_valid_number, '長野県上水内郡信濃町古間');
ok($zip->set_number('3891314')->is_valid_number, '長野県上水内郡信濃町穂波');
ok($zip->set_number('3891315')->is_valid_number, '長野県上水内郡信濃町平岡');
ok($zip->set_number('3891316')->is_valid_number, '長野県上水内郡信濃町大井');
ok($zip->set_number('3892101')->is_valid_number, '長野県中野市豊津');
ok($zip->set_number('3892102')->is_valid_number, '長野県中野市上今井');
ok($zip->set_number('3892103')->is_valid_number, '長野県中野市穴田');
ok($zip->set_number('3892104')->is_valid_number, '長野県中野市永江');
ok($zip->set_number('3892200')->is_valid_number, '長野県飯山市以下に掲載がない場合');
ok($zip->set_number('3892231')->is_valid_number, '長野県飯山市天神堂');
ok($zip->set_number('3892232')->is_valid_number, '長野県飯山市下木島');
ok($zip->set_number('3892233')->is_valid_number, '長野県飯山市野坂田');
ok($zip->set_number('3892234')->is_valid_number, '長野県飯山市木島');
ok($zip->set_number('3892235')->is_valid_number, '長野県飯山市坂井');
ok($zip->set_number('3892241')->is_valid_number, '長野県飯山市山岸');
ok($zip->set_number('3892242')->is_valid_number, '長野県飯山市其綿');
ok($zip->set_number('3892243')->is_valid_number, '長野県飯山市吉');
ok($zip->set_number('3892244')->is_valid_number, '長野県飯山市安田');
ok($zip->set_number('3892251')->is_valid_number, '長野県飯山市旭');
ok($zip->set_number('3892252')->is_valid_number, '長野県飯山市小佐原');
ok($zip->set_number('3892253')->is_valid_number, '長野県飯山市飯山');
ok($zip->set_number('3892254')->is_valid_number, '長野県飯山市南町');
ok($zip->set_number('3892255')->is_valid_number, '長野県飯山市静間');
ok($zip->set_number('3892256')->is_valid_number, '長野県飯山市蓮');
ok($zip->set_number('3892257')->is_valid_number, '長野県飯山市斑尾高原');
ok($zip->set_number('3892258')->is_valid_number, '長野県飯山市富倉');
ok($zip->set_number('3892261')->is_valid_number, '新潟県妙高市樽本(1101番地)');
ok($zip->set_number('3892300')->is_valid_number, '長野県下高井郡木島平村以下に掲載がない場合');
ok($zip->set_number('3892301')->is_valid_number, '長野県下高井郡木島平村穂高');
ok($zip->set_number('3892302')->is_valid_number, '長野県下高井郡木島平村往郷');
ok($zip->set_number('3892303')->is_valid_number, '長野県下高井郡木島平村上木島');
ok($zip->set_number('3892321')->is_valid_number, '長野県飯山市瑞穂豊');
ok($zip->set_number('3892322')->is_valid_number, '長野県飯山市瑞穂');
ok($zip->set_number('3892371')->is_valid_number, '長野県中野市田上(1300~2511番地)');
ok($zip->set_number('3892411')->is_valid_number, '長野県飯山市豊田');
ok($zip->set_number('3892412')->is_valid_number, '長野県飯山市常郷');
ok($zip->set_number('3892413')->is_valid_number, '長野県飯山市照里');
ok($zip->set_number('3892414')->is_valid_number, '長野県飯山市常盤');
ok($zip->set_number('3892415')->is_valid_number, '長野県飯山市大池');
ok($zip->set_number('3892416')->is_valid_number, '長野県飯山市緑');
ok($zip->set_number('3892417')->is_valid_number, '長野県飯山市中曽根');
ok($zip->set_number('3892418')->is_valid_number, '長野県飯山市寿');
ok($zip->set_number('3892500')->is_valid_number, '長野県下高井郡野沢温泉村以下に掲載がない場合');
ok($zip->set_number('3892501')->is_valid_number, '長野県下高井郡野沢温泉村坪山');
ok($zip->set_number('3892502')->is_valid_number, '長野県下高井郡野沢温泉村豊郷');
ok($zip->set_number('3892503')->is_valid_number, '長野県下高井郡野沢温泉村前坂');
ok($zip->set_number('3892601')->is_valid_number, '長野県飯山市照岡');
ok($zip->set_number('3892602')->is_valid_number, '長野県飯山市一山');
ok($zip->set_number('3892611')->is_valid_number, '長野県下高井郡野沢温泉村東大滝');
ok($zip->set_number('3892612')->is_valid_number, '長野県下高井郡野沢温泉村七ケ巻');
ok($zip->set_number('3892613')->is_valid_number, '長野県下高井郡野沢温泉村虫生');
ok($zip->set_number('3892614')->is_valid_number, '長野県下高井郡野沢温泉村平林');
ok($zip->set_number('3892700')->is_valid_number, '長野県下水内郡栄村以下に掲載がない場合');
ok($zip->set_number('3892701')->is_valid_number, '長野県下水内郡栄村豊栄');
ok($zip->set_number('3892702')->is_valid_number, '長野県下水内郡栄村北信');
ok($zip->set_number('3892703')->is_valid_number, '長野県下水内郡栄村堺(その他)');
ok($zip->set_number('3900221')->is_valid_number, '長野県松本市里山辺');
ok($zip->set_number('3900222')->is_valid_number, '長野県松本市入山辺');
ok($zip->set_number('3900301')->is_valid_number, '長野県松本市稲倉');
ok($zip->set_number('3900302')->is_valid_number, '長野県松本市三才山');
ok($zip->set_number('3900303')->is_valid_number, '長野県松本市浅間温泉');
ok($zip->set_number('3900304')->is_valid_number, '長野県松本市大村');
ok($zip->set_number('3900305')->is_valid_number, '長野県松本市惣社');
ok($zip->set_number('3900306')->is_valid_number, '長野県松本市南浅間');
ok($zip->set_number('3900311')->is_valid_number, '長野県松本市水汲');
ok($zip->set_number('3900312')->is_valid_number, '長野県松本市岡田松岡');
ok($zip->set_number('3900313')->is_valid_number, '長野県松本市岡田下岡田');
ok($zip->set_number('3900314')->is_valid_number, '長野県松本市岡田伊深');
ok($zip->set_number('3900315')->is_valid_number, '長野県松本市岡田町');
ok($zip->set_number('3900316')->is_valid_number, '長野県松本市原');
ok($zip->set_number('3900317')->is_valid_number, '長野県松本市洞');
ok($zip->set_number('3900801')->is_valid_number, '長野県松本市美須々');
ok($zip->set_number('3900802')->is_valid_number, '長野県松本市旭');
ok($zip->set_number('3900803')->is_valid_number, '長野県松本市元町');
ok($zip->set_number('3900804')->is_valid_number, '長野県松本市横田');
ok($zip->set_number('3900805')->is_valid_number, '長野県松本市清水');
ok($zip->set_number('3900806')->is_valid_number, '長野県松本市女鳥羽');
ok($zip->set_number('3900807')->is_valid_number, '長野県松本市城東');
ok($zip->set_number('3900811')->is_valid_number, '長野県松本市中央');
ok($zip->set_number('3900812')->is_valid_number, '長野県松本市県');
ok($zip->set_number('3900813')->is_valid_number, '長野県松本市埋橋');
ok($zip->set_number('3900814')->is_valid_number, '長野県松本市本庄');
ok($zip->set_number('3900815')->is_valid_number, '長野県松本市深志');
ok($zip->set_number('3900816')->is_valid_number, '長野県松本市中条');
ok($zip->set_number('3900817')->is_valid_number, '長野県松本市巾上');
ok($zip->set_number('3900821')->is_valid_number, '長野県松本市筑摩');
ok($zip->set_number('3900822')->is_valid_number, '長野県松本市神田');
ok($zip->set_number('3900823')->is_valid_number, '長野県松本市中山');
ok($zip->set_number('3900824')->is_valid_number, '長野県松本市中山台');
ok($zip->set_number('3900825')->is_valid_number, '長野県松本市並柳');
ok($zip->set_number('3900826')->is_valid_number, '長野県松本市出川町');
ok($zip->set_number('3900827')->is_valid_number, '長野県松本市出川');
ok($zip->set_number('3900828')->is_valid_number, '長野県松本市庄内');
ok($zip->set_number('3900831')->is_valid_number, '長野県松本市井川城');
ok($zip->set_number('3900832')->is_valid_number, '長野県松本市南松本');
ok($zip->set_number('3900833')->is_valid_number, '長野県松本市双葉');
ok($zip->set_number('3900834')->is_valid_number, '長野県松本市高宮中');
ok($zip->set_number('3900835')->is_valid_number, '長野県松本市高宮東');
ok($zip->set_number('3900836')->is_valid_number, '長野県松本市高宮北');
ok($zip->set_number('3900837')->is_valid_number, '長野県松本市鎌田');
ok($zip->set_number('3900841')->is_valid_number, '長野県松本市渚');
ok($zip->set_number('3900842')->is_valid_number, '長野県松本市征矢野');
ok($zip->set_number('3900843')->is_valid_number, '長野県松本市高宮南');
ok($zip->set_number('3900844')->is_valid_number, '長野県松本市高宮西');
ok($zip->set_number('3900845')->is_valid_number, '長野県松本市石芝(1、2丁目)');
ok($zip->set_number('3900846')->is_valid_number, '長野県松本市南原');
ok($zip->set_number('3900847')->is_valid_number, '長野県松本市笹部');
ok($zip->set_number('3900848')->is_valid_number, '長野県松本市両島');
ok($zip->set_number('3900851')->is_valid_number, '長野県松本市島内(1~9819、9822、9831~9863番地)');
ok($zip->set_number('3900852')->is_valid_number, '長野県松本市島立');
ok($zip->set_number('3900861')->is_valid_number, '長野県松本市蟻ケ崎');
ok($zip->set_number('3900862')->is_valid_number, '長野県松本市宮渕');
ok($zip->set_number('3900863')->is_valid_number, '長野県松本市白板');
ok($zip->set_number('3900864')->is_valid_number, '長野県松本市宮渕本村');
ok($zip->set_number('3900865')->is_valid_number, '長野県松本市新橋');
ok($zip->set_number('3900866')->is_valid_number, '長野県松本市城山');
ok($zip->set_number('3900867')->is_valid_number, '長野県松本市蟻ケ崎台');
ok($zip->set_number('3900871')->is_valid_number, '長野県松本市桐');
ok($zip->set_number('3900872')->is_valid_number, '長野県松本市北深志');
ok($zip->set_number('3900873')->is_valid_number, '長野県松本市丸の内');
ok($zip->set_number('3900874')->is_valid_number, '長野県松本市大手');
ok($zip->set_number('3900875')->is_valid_number, '長野県松本市城西');
ok($zip->set_number('3900876')->is_valid_number, '長野県松本市開智');
ok($zip->set_number('3900877')->is_valid_number, '長野県松本市沢村');
ok($zip->set_number('3901100')->is_valid_number, '長野県東筑摩郡朝日村以下に掲載がない場合');
ok($zip->set_number('3901101')->is_valid_number, '長野県東筑摩郡朝日村西洗馬');
ok($zip->set_number('3901102')->is_valid_number, '長野県東筑摩郡朝日村小野沢');
ok($zip->set_number('3901103')->is_valid_number, '長野県東筑摩郡朝日村針尾');
ok($zip->set_number('3901104')->is_valid_number, '長野県東筑摩郡朝日村古見');
ok($zip->set_number('3901131')->is_valid_number, '長野県松本市今井');
ok($zip->set_number('3901132')->is_valid_number, '長野県松本市空港東');
ok($zip->set_number('3901241')->is_valid_number, '長野県松本市新村');
ok($zip->set_number('3901242')->is_valid_number, '長野県松本市和田');
ok($zip->set_number('3901243')->is_valid_number, '長野県松本市神林');
ok($zip->set_number('3901301')->is_valid_number, '長野県東筑摩郡山形村山形村一円');
ok($zip->set_number('3901401')->is_valid_number, '長野県松本市波田');
ok($zip->set_number('3901501')->is_valid_number, '長野県松本市安曇(大野田)');
ok($zip->set_number('3901502')->is_valid_number, '長野県松本市安曇(島々)');
ok($zip->set_number('3901503')->is_valid_number, '長野県松本市安曇(橋場)');
ok($zip->set_number('3901504')->is_valid_number, '長野県松本市安曇(稲核)');
ok($zip->set_number('3901506')->is_valid_number, '長野県松本市安曇(番所)');
ok($zip->set_number('3901507')->is_valid_number, '長野県松本市安曇(宮の原)');
ok($zip->set_number('3901511')->is_valid_number, '長野県松本市安曇(千石平)');
ok($zip->set_number('3901512')->is_valid_number, '長野県松本市安曇(楢ノ木)');
ok($zip->set_number('3901513')->is_valid_number, '長野県松本市安曇(鈴蘭)');
ok($zip->set_number('3901514')->is_valid_number, '長野県松本市安曇(沢渡)');
ok($zip->set_number('3901515')->is_valid_number, '長野県松本市安曇(白骨)');
ok($zip->set_number('3901516')->is_valid_number, '長野県松本市安曇(上高地)');
ok($zip->set_number('3901520')->is_valid_number, '長野県松本市安曇(その他)');
ok($zip->set_number('3901611')->is_valid_number, '長野県松本市奈川');
ok($zip->set_number('3901701')->is_valid_number, '長野県松本市梓川倭');
ok($zip->set_number('3901702')->is_valid_number, '長野県松本市梓川梓');
ok($zip->set_number('3901703')->is_valid_number, '長野県松本市梓川上野');
ok($zip->set_number('3910000')->is_valid_number, '長野県茅野市以下に掲載がない場合');
ok($zip->set_number('3910001')->is_valid_number, '長野県茅野市ちの');
ok($zip->set_number('3910002')->is_valid_number, '長野県茅野市塚原');
ok($zip->set_number('3910003')->is_valid_number, '長野県茅野市本町');
ok($zip->set_number('3910004')->is_valid_number, '長野県茅野市城山');
ok($zip->set_number('3910005')->is_valid_number, '長野県茅野市仲町');
ok($zip->set_number('3910011')->is_valid_number, '長野県茅野市玉川');
ok($zip->set_number('3910012')->is_valid_number, '長野県茅野市金沢');
ok($zip->set_number('3910013')->is_valid_number, '長野県茅野市宮川');
ok($zip->set_number('3910021')->is_valid_number, '長野県諏訪郡富士見町富士見(入笠湖)');
ok($zip->set_number('3910100')->is_valid_number, '長野県諏訪郡原村以下に掲載がない場合');
ok($zip->set_number('3910101')->is_valid_number, '長野県諏訪郡原村大久保');
ok($zip->set_number('3910102')->is_valid_number, '長野県諏訪郡原村柳沢');
ok($zip->set_number('3910103')->is_valid_number, '長野県諏訪郡原村八ツ手');
ok($zip->set_number('3910104')->is_valid_number, '長野県諏訪郡原村払沢');
ok($zip->set_number('3910105')->is_valid_number, '長野県諏訪郡原村柏木');
ok($zip->set_number('3910106')->is_valid_number, '長野県諏訪郡原村菖蒲沢');
ok($zip->set_number('3910107')->is_valid_number, '長野県諏訪郡原村室内');
ok($zip->set_number('3910108')->is_valid_number, '長野県諏訪郡原村中新田');
ok($zip->set_number('3910109')->is_valid_number, '長野県諏訪郡原村南原');
ok($zip->set_number('3910111')->is_valid_number, '長野県諏訪郡原村上里');
ok($zip->set_number('3910112')->is_valid_number, '長野県諏訪郡原村農場');
ok($zip->set_number('3910113')->is_valid_number, '長野県諏訪郡原村やつがね');
ok($zip->set_number('3910114')->is_valid_number, '長野県諏訪郡原村ペンション');
ok($zip->set_number('3910115')->is_valid_number, '長野県諏訪郡原村原山');
ok($zip->set_number('3910116')->is_valid_number, '長野県諏訪郡原村判の木');
ok($zip->set_number('3910211')->is_valid_number, '長野県茅野市湖東');
ok($zip->set_number('3910212')->is_valid_number, '長野県茅野市北山(渋御殿湯・渋の湯)');
ok($zip->set_number('3910213')->is_valid_number, '長野県茅野市豊平');
ok($zip->set_number('3910214')->is_valid_number, '長野県茅野市泉野');
ok($zip->set_number('3910215')->is_valid_number, '長野県茅野市中大塩');
ok($zip->set_number('3910216')->is_valid_number, '長野県茅野市米沢');
ok($zip->set_number('3910301')->is_valid_number, '長野県茅野市北山(その他)');
ok($zip->set_number('3910321')->is_valid_number, '長野県北佐久郡立科町芦田八ケ野(1519~1635)');
ok($zip->set_number('3910321')->is_valid_number, '長野県北佐久郡立科町池の平');
ok($zip->set_number('3920000')->is_valid_number, '長野県諏訪市以下に掲載がない場合');
ok($zip->set_number('3920001')->is_valid_number, '長野県諏訪市大和');
ok($zip->set_number('3920002')->is_valid_number, '長野県諏訪市湯の脇');
ok($zip->set_number('3920003')->is_valid_number, '長野県諏訪市上諏訪');
ok($zip->set_number('3920004')->is_valid_number, '長野県諏訪市諏訪');
ok($zip->set_number('3920005')->is_valid_number, '長野県諏訪市岡村');
ok($zip->set_number('3920006')->is_valid_number, '長野県諏訪市元町');
ok($zip->set_number('3920007')->is_valid_number, '長野県諏訪市清水');
ok($zip->set_number('3920008')->is_valid_number, '長野県諏訪市霧ケ峰');
ok($zip->set_number('3920009')->is_valid_number, '長野県諏訪市杉菜池');
ok($zip->set_number('3920010')->is_valid_number, '長野県諏訪市渋崎');
ok($zip->set_number('3920011')->is_valid_number, '長野県諏訪市赤羽根');
ok($zip->set_number('3920012')->is_valid_number, '長野県諏訪市四賀');
ok($zip->set_number('3920013')->is_valid_number, '長野県諏訪市沖田町');
ok($zip->set_number('3920014')->is_valid_number, '長野県諏訪市南町');
ok($zip->set_number('3920015')->is_valid_number, '長野県諏訪市中洲');
ok($zip->set_number('3920016')->is_valid_number, '長野県諏訪市豊田');
ok($zip->set_number('3920017')->is_valid_number, '長野県諏訪市城南');
ok($zip->set_number('3920021')->is_valid_number, '長野県諏訪市上川');
ok($zip->set_number('3920022')->is_valid_number, '長野県諏訪市高島');
ok($zip->set_number('3920023')->is_valid_number, '長野県諏訪市小和田南');
ok($zip->set_number('3920024')->is_valid_number, '長野県諏訪市小和田');
ok($zip->set_number('3920025')->is_valid_number, '長野県諏訪市末広');
ok($zip->set_number('3920026')->is_valid_number, '長野県諏訪市大手');
ok($zip->set_number('3920027')->is_valid_number, '長野県諏訪市湖岸通り');
ok($zip->set_number('3920131')->is_valid_number, '長野県諏訪市湖南');
ok($zip->set_number('3930000')->is_valid_number, '長野県諏訪郡下諏訪町以下に掲載がない場合');
ok($zip->set_number('3930001')->is_valid_number, '長野県諏訪郡下諏訪町樋橋');
ok($zip->set_number('3930002')->is_valid_number, '長野県諏訪郡下諏訪町東俣');
ok($zip->set_number('3930003')->is_valid_number, '長野県諏訪郡下諏訪町萩倉');
ok($zip->set_number('3930004')->is_valid_number, '長野県諏訪郡下諏訪町東町下');
ok($zip->set_number('3930005')->is_valid_number, '長野県諏訪郡下諏訪町東町中');
ok($zip->set_number('3930006')->is_valid_number, '長野県諏訪郡下諏訪町東町上');
ok($zip->set_number('3930007')->is_valid_number, '長野県諏訪郡下諏訪町下屋敷');
ok($zip->set_number('3930008')->is_valid_number, '長野県諏訪郡下諏訪町町屋敷');
ok($zip->set_number('3930011')->is_valid_number, '長野県諏訪郡下諏訪町新町上');
ok($zip->set_number('3930012')->is_valid_number, '長野県諏訪郡下諏訪町横町');
ok($zip->set_number('3930013')->is_valid_number, '長野県諏訪郡下諏訪町小湯の上');
ok($zip->set_number('3930014')->is_valid_number, '長野県諏訪郡下諏訪町木の下');
ok($zip->set_number('3930015')->is_valid_number, '長野県諏訪郡下諏訪町立町');
ok($zip->set_number('3930016')->is_valid_number, '長野県諏訪郡下諏訪町湯田町');
ok($zip->set_number('3930017')->is_valid_number, '長野県諏訪郡下諏訪町湯田仲町');
ok($zip->set_number('3930018')->is_valid_number, '長野県諏訪郡下諏訪町新町下');
ok($zip->set_number('3930019')->is_valid_number, '長野県諏訪郡下諏訪町横町木の下');
ok($zip->set_number('3930021')->is_valid_number, '長野県諏訪郡下諏訪町武居');
ok($zip->set_number('3930022')->is_valid_number, '長野県諏訪郡下諏訪町関屋');
ok($zip->set_number('3930023')->is_valid_number, '長野県諏訪郡下諏訪町富ケ丘');
ok($zip->set_number('3930024')->is_valid_number, '長野県諏訪郡下諏訪町五官');
ok($zip->set_number('3930025')->is_valid_number, '長野県諏訪郡下諏訪町本郷');
ok($zip->set_number('3930026')->is_valid_number, '長野県諏訪郡下諏訪町久保海道');
ok($zip->set_number('3930031')->is_valid_number, '長野県諏訪郡下諏訪町東豊');
ok($zip->set_number('3930032')->is_valid_number, '長野県諏訪郡下諏訪町西浜');
ok($zip->set_number('3930033')->is_valid_number, '長野県諏訪郡下諏訪町高木');
ok($zip->set_number('3930034')->is_valid_number, '長野県諏訪郡下諏訪町高浜');
ok($zip->set_number('3930035')->is_valid_number, '長野県諏訪郡下諏訪町西豊');
ok($zip->set_number('3930041')->is_valid_number, '長野県諏訪郡下諏訪町西四王');
ok($zip->set_number('3930042')->is_valid_number, '長野県諏訪郡下諏訪町北四王');
ok($zip->set_number('3930043')->is_valid_number, '長野県諏訪郡下諏訪町東四王');
ok($zip->set_number('3930044')->is_valid_number, '長野県諏訪郡下諏訪町湖畔町');
ok($zip->set_number('3930045')->is_valid_number, '長野県諏訪郡下諏訪町南四王');
ok($zip->set_number('3930046')->is_valid_number, '長野県諏訪郡下諏訪町東赤砂');
ok($zip->set_number('3930047')->is_valid_number, '長野県諏訪郡下諏訪町西赤砂');
ok($zip->set_number('3930051')->is_valid_number, '長野県諏訪郡下諏訪町大社通');
ok($zip->set_number('3930052')->is_valid_number, '長野県諏訪郡下諏訪町上久保');
ok($zip->set_number('3930053')->is_valid_number, '長野県諏訪郡下諏訪町上馬場');
ok($zip->set_number('3930054')->is_valid_number, '長野県諏訪郡下諏訪町菅野町');
ok($zip->set_number('3930055')->is_valid_number, '長野県諏訪郡下諏訪町富士見町');
ok($zip->set_number('3930056')->is_valid_number, '長野県諏訪郡下諏訪町広瀬町');
ok($zip->set_number('3930057')->is_valid_number, '長野県諏訪郡下諏訪町友之町');
ok($zip->set_number('3930061')->is_valid_number, '長野県諏訪郡下諏訪町御田町');
ok($zip->set_number('3930062')->is_valid_number, '長野県諏訪郡下諏訪町平沢町');
ok($zip->set_number('3930063')->is_valid_number, '長野県諏訪郡下諏訪町花咲町');
ok($zip->set_number('3930064')->is_valid_number, '長野県諏訪郡下諏訪町中汐町');
ok($zip->set_number('3930065')->is_valid_number, '長野県諏訪郡下諏訪町魁町');
ok($zip->set_number('3930066')->is_valid_number, '長野県諏訪郡下諏訪町曙町');
ok($zip->set_number('3930067')->is_valid_number, '長野県諏訪郡下諏訪町矢木東');
ok($zip->set_number('3930068')->is_valid_number, '長野県諏訪郡下諏訪町春日町');
ok($zip->set_number('3930071')->is_valid_number, '長野県諏訪郡下諏訪町仲町');
ok($zip->set_number('3930072')->is_valid_number, '長野県諏訪郡下諏訪町桜町');
ok($zip->set_number('3930073')->is_valid_number, '長野県諏訪郡下諏訪町塚田町');
ok($zip->set_number('3930074')->is_valid_number, '長野県諏訪郡下諏訪町緑町');
ok($zip->set_number('3930075')->is_valid_number, '長野県諏訪郡下諏訪町中央通');
ok($zip->set_number('3930076')->is_valid_number, '長野県諏訪郡下諏訪町矢木西');
ok($zip->set_number('3930077')->is_valid_number, '長野県諏訪郡下諏訪町矢木町');
ok($zip->set_number('3930078')->is_valid_number, '長野県諏訪郡下諏訪町田中町');
ok($zip->set_number('3930081')->is_valid_number, '長野県諏訪郡下諏訪町社東町');
ok($zip->set_number('3930082')->is_valid_number, '長野県諏訪郡下諏訪町西弥生町');
ok($zip->set_number('3930083')->is_valid_number, '長野県諏訪郡下諏訪町東弥生町');
ok($zip->set_number('3930084')->is_valid_number, '長野県諏訪郡下諏訪町栄町');
ok($zip->set_number('3930085')->is_valid_number, '長野県諏訪郡下諏訪町東鷹野町');
ok($zip->set_number('3930086')->is_valid_number, '長野県諏訪郡下諏訪町清水町');
ok($zip->set_number('3930087')->is_valid_number, '長野県諏訪郡下諏訪町西鷹野町');
ok($zip->set_number('3930091')->is_valid_number, '長野県諏訪郡下諏訪町星が丘');
ok($zip->set_number('3930092')->is_valid_number, '長野県諏訪郡下諏訪町大門');
ok($zip->set_number('3930093')->is_valid_number, '長野県諏訪郡下諏訪町東山田');
ok($zip->set_number('3940000')->is_valid_number, '長野県岡谷市以下に掲載がない場合');
ok($zip->set_number('3940001')->is_valid_number, '長野県岡谷市今井');
ok($zip->set_number('3940002')->is_valid_number, '長野県岡谷市赤羽');
ok($zip->set_number('3940003')->is_valid_number, '長野県岡谷市加茂町');
ok($zip->set_number('3940004')->is_valid_number, '長野県岡谷市神明町');
ok($zip->set_number('3940005')->is_valid_number, '長野県岡谷市山下町');
ok($zip->set_number('3940011')->is_valid_number, '長野県岡谷市長地');
ok($zip->set_number('3940021')->is_valid_number, '長野県岡谷市郷田');
ok($zip->set_number('3940022')->is_valid_number, '長野県岡谷市銀座');
ok($zip->set_number('3940023')->is_valid_number, '長野県岡谷市東銀座');
ok($zip->set_number('3940024')->is_valid_number, '長野県岡谷市堀ノ内');
ok($zip->set_number('3940025')->is_valid_number, '長野県岡谷市大栄町');
ok($zip->set_number('3940026')->is_valid_number, '長野県岡谷市塚間町');
ok($zip->set_number('3940027')->is_valid_number, '長野県岡谷市中央町');
ok($zip->set_number('3940028')->is_valid_number, '長野県岡谷市本町');
ok($zip->set_number('3940029')->is_valid_number, '長野県岡谷市幸町');
ok($zip->set_number('3940031')->is_valid_number, '長野県岡谷市田中町');
ok($zip->set_number('3940032')->is_valid_number, '長野県岡谷市若宮');
ok($zip->set_number('3940033')->is_valid_number, '長野県岡谷市南宮');
ok($zip->set_number('3940034')->is_valid_number, '長野県岡谷市湖畔');
ok($zip->set_number('3940035')->is_valid_number, '長野県岡谷市天竜町');
ok($zip->set_number('3940041')->is_valid_number, '長野県岡谷市山手町');
ok($zip->set_number('3940042')->is_valid_number, '長野県岡谷市成田町');
ok($zip->set_number('3940043')->is_valid_number, '長野県岡谷市御倉町');
ok($zip->set_number('3940044')->is_valid_number, '長野県岡谷市湊');
ok($zip->set_number('3940045')->is_valid_number, '長野県岡谷市川岸東');
ok($zip->set_number('3940046')->is_valid_number, '長野県岡谷市川岸西');
ok($zip->set_number('3940047')->is_valid_number, '長野県岡谷市川岸中');
ok($zip->set_number('3940048')->is_valid_number, '長野県岡谷市川岸上');
ok($zip->set_number('3940051')->is_valid_number, '長野県岡谷市塩嶺');
ok($zip->set_number('3940052')->is_valid_number, '長野県岡谷市西林');
ok($zip->set_number('3940053')->is_valid_number, '長野県岡谷市芦ノ沢');
ok($zip->set_number('3940053')->is_valid_number, '長野県岡谷市ヨギトギ沢');
ok($zip->set_number('3940054')->is_valid_number, '長野県岡谷市半ノ木');
ok($zip->set_number('3940055')->is_valid_number, '長野県岡谷市内山');
ok($zip->set_number('3940056')->is_valid_number, '長野県岡谷市樋沢');
ok($zip->set_number('3940081')->is_valid_number, '長野県岡谷市長地権現町');
ok($zip->set_number('3940082')->is_valid_number, '長野県岡谷市長地御所');
ok($zip->set_number('3940083')->is_valid_number, '長野県岡谷市長地柴宮');
ok($zip->set_number('3940084')->is_valid_number, '長野県岡谷市長地片間町');
ok($zip->set_number('3940085')->is_valid_number, '長野県岡谷市長地小萩');
ok($zip->set_number('3940086')->is_valid_number, '長野県岡谷市長地源');
ok($zip->set_number('3940087')->is_valid_number, '長野県岡谷市長地鎮');
ok($zip->set_number('3940088')->is_valid_number, '長野県岡谷市長地梨久保');
ok($zip->set_number('3940089')->is_valid_number, '長野県岡谷市長地出早');
ok($zip->set_number('3940091')->is_valid_number, '長野県岡谷市岡谷市の次に番地がくる場合');
ok($zip->set_number('3950000')->is_valid_number, '長野県飯田市以下に掲載がない場合');
ok($zip->set_number('3950001')->is_valid_number, '長野県飯田市座光寺');
ok($zip->set_number('3950002')->is_valid_number, '長野県飯田市上郷飯沼');
ok($zip->set_number('3950003')->is_valid_number, '長野県飯田市上郷別府');
ok($zip->set_number('3950004')->is_valid_number, '長野県飯田市上郷黒田');
ok($zip->set_number('3950011')->is_valid_number, '長野県飯田市大門町');
ok($zip->set_number('3950012')->is_valid_number, '長野県飯田市大王路');
ok($zip->set_number('3950013')->is_valid_number, '長野県飯田市小伝馬町');
ok($zip->set_number('3950014')->is_valid_number, '長野県飯田市桜町');
ok($zip->set_number('3950015')->is_valid_number, '長野県飯田市江戸町');
ok($zip->set_number('3950016')->is_valid_number, '長野県飯田市伝馬町');
ok($zip->set_number('3950017')->is_valid_number, '長野県飯田市東新町');
ok($zip->set_number('3950018')->is_valid_number, '長野県飯田市諏訪町');
ok($zip->set_number('3950021')->is_valid_number, '長野県飯田市仲ノ町');
ok($zip->set_number('3950022')->is_valid_number, '長野県飯田市浜井町');
ok($zip->set_number('3950023')->is_valid_number, '長野県飯田市江戸浜町');
ok($zip->set_number('3950024')->is_valid_number, '長野県飯田市東栄町');
ok($zip->set_number('3950025')->is_valid_number, '長野県飯田市東中央通り');
ok($zip->set_number('3950026')->is_valid_number, '長野県飯田市鼎西鼎');
ok($zip->set_number('3950027')->is_valid_number, '長野県飯田市馬場町');
ok($zip->set_number('3950028')->is_valid_number, '長野県飯田市長姫町');
ok($zip->set_number('3950029')->is_valid_number, '長野県飯田市二本松');
ok($zip->set_number('3950031')->is_valid_number, '長野県飯田市銀座');
ok($zip->set_number('3950032')->is_valid_number, '長野県飯田市主税町');
ok($zip->set_number('3950033')->is_valid_number, '長野県飯田市常盤町');
ok($zip->set_number('3950034')->is_valid_number, '長野県飯田市追手町');
ok($zip->set_number('3950035')->is_valid_number, '長野県飯田市水の手町');
ok($zip->set_number('3950036')->is_valid_number, '長野県飯田市愛宕町');
ok($zip->set_number('3950037')->is_valid_number, '長野県飯田市南常盤町');
ok($zip->set_number('3950041')->is_valid_number, '長野県飯田市中央通り');
ok($zip->set_number('3950042')->is_valid_number, '長野県飯田市松尾町');
ok($zip->set_number('3950043')->is_valid_number, '長野県飯田市通り町');
ok($zip->set_number('3950044')->is_valid_number, '長野県飯田市本町');
ok($zip->set_number('3950045')->is_valid_number, '長野県飯田市知久町');
ok($zip->set_number('3950046')->is_valid_number, '長野県飯田市扇町');
ok($zip->set_number('3950048')->is_valid_number, '長野県飯田市滝の沢');
ok($zip->set_number('3950051')->is_valid_number, '長野県飯田市高羽町');
ok($zip->set_number('3950052')->is_valid_number, '長野県飯田市元町');
ok($zip->set_number('3950053')->is_valid_number, '長野県飯田市大久保町');
ok($zip->set_number('3950054')->is_valid_number, '長野県飯田市箕瀬町');
ok($zip->set_number('3950055')->is_valid_number, '長野県飯田市旭町');
ok($zip->set_number('3950056')->is_valid_number, '長野県飯田市大通');
ok($zip->set_number('3950061')->is_valid_number, '長野県飯田市正永町');
ok($zip->set_number('3950062')->is_valid_number, '長野県飯田市砂払町');
ok($zip->set_number('3950063')->is_valid_number, '長野県飯田市羽場町');
ok($zip->set_number('3950064')->is_valid_number, '長野県飯田市羽場仲畑');
ok($zip->set_number('3950065')->is_valid_number, '長野県飯田市羽場上河原');
ok($zip->set_number('3950066')->is_valid_number, '長野県飯田市羽場赤坂');
ok($zip->set_number('3950067')->is_valid_number, '長野県飯田市羽場権現');
ok($zip->set_number('3950068')->is_valid_number, '長野県飯田市大休');
ok($zip->set_number('3950071')->is_valid_number, '長野県飯田市今宮町');
ok($zip->set_number('3950072')->is_valid_number, '長野県飯田市曙町');
ok($zip->set_number('3950073')->is_valid_number, '長野県飯田市羽場坂町');
ok($zip->set_number('3950074')->is_valid_number, '長野県飯田市松川町');
ok($zip->set_number('3950075')->is_valid_number, '長野県飯田市白山通り');
ok($zip->set_number('3950076')->is_valid_number, '長野県飯田市白山町');
ok($zip->set_number('3950077')->is_valid_number, '長野県飯田市丸山町');
ok($zip->set_number('3950081')->is_valid_number, '長野県飯田市宮ノ上');
ok($zip->set_number('3950082')->is_valid_number, '長野県飯田市宮の前');
ok($zip->set_number('3950083')->is_valid_number, '長野県飯田市錦町');
ok($zip->set_number('3950084')->is_valid_number, '長野県飯田市鈴加町');
ok($zip->set_number('3950085')->is_valid_number, '長野県飯田市吾妻町');
ok($zip->set_number('3950086')->is_valid_number, '長野県飯田市東和町');
ok($zip->set_number('3950151')->is_valid_number, '長野県飯田市北方');
ok($zip->set_number('3950152')->is_valid_number, '長野県飯田市育良町');
ok($zip->set_number('3950153')->is_valid_number, '長野県飯田市上殿岡');
ok($zip->set_number('3950154')->is_valid_number, '長野県飯田市下殿岡');
ok($zip->set_number('3950155')->is_valid_number, '長野県飯田市三日市場');
ok($zip->set_number('3950156')->is_valid_number, '長野県飯田市中村');
ok($zip->set_number('3950157')->is_valid_number, '長野県飯田市大瀬木');
ok($zip->set_number('3950241')->is_valid_number, '長野県飯田市久米');
ok($zip->set_number('3950242')->is_valid_number, '長野県飯田市竹佐');
ok($zip->set_number('3950243')->is_valid_number, '長野県飯田市箱川');
ok($zip->set_number('3950244')->is_valid_number, '長野県飯田市山本');
ok($zip->set_number('3950245')->is_valid_number, '長野県飯田市山本二ツ山団地');
ok($zip->set_number('3950300')->is_valid_number, '長野県下伊那郡阿智村以下に掲載がない場合');
ok($zip->set_number('3950301')->is_valid_number, '長野県下伊那郡阿智村春日');
ok($zip->set_number('3950302')->is_valid_number, '長野県下伊那郡阿智村伍和');
ok($zip->set_number('3950303')->is_valid_number, '長野県下伊那郡阿智村駒場');
ok($zip->set_number('3950304')->is_valid_number, '長野県下伊那郡阿智村智里');
ok($zip->set_number('3950305')->is_valid_number, '長野県下伊那郡阿智村駒');
ok($zip->set_number('3950401')->is_valid_number, '長野県下伊那郡阿智村清内路');
ok($zip->set_number('3950501')->is_valid_number, '長野県下伊那郡阿智村浪合');
ok($zip->set_number('3950601')->is_valid_number, '長野県下伊那郡平谷村平谷村一円');
ok($zip->set_number('3950701')->is_valid_number, '長野県下伊那郡根羽村根羽村一円');
ok($zip->set_number('3950801')->is_valid_number, '長野県飯田市鼎中平');
ok($zip->set_number('3950802')->is_valid_number, '長野県飯田市鼎下茶屋');
ok($zip->set_number('3950803')->is_valid_number, '長野県飯田市鼎下山');
ok($zip->set_number('3950804')->is_valid_number, '長野県飯田市鼎名古熊');
ok($zip->set_number('3950805')->is_valid_number, '長野県飯田市鼎一色');
ok($zip->set_number('3950806')->is_valid_number, '長野県飯田市鼎上山');
ok($zip->set_number('3950807')->is_valid_number, '長野県飯田市鼎切石');
ok($zip->set_number('3950808')->is_valid_number, '長野県飯田市鼎上茶屋');
ok($zip->set_number('3950811')->is_valid_number, '長野県飯田市松尾上溝');
ok($zip->set_number('3950812')->is_valid_number, '長野県飯田市松尾代田');
ok($zip->set_number('3950813')->is_valid_number, '長野県飯田市毛賀');
ok($zip->set_number('3950814')->is_valid_number, '長野県飯田市八幡町');
ok($zip->set_number('3950815')->is_valid_number, '長野県飯田市松尾常盤台');
ok($zip->set_number('3950816')->is_valid_number, '長野県飯田市松尾久井');
ok($zip->set_number('3950817')->is_valid_number, '長野県飯田市鼎東鼎');
ok($zip->set_number('3950821')->is_valid_number, '長野県飯田市松尾新井');
ok($zip->set_number('3950822')->is_valid_number, '長野県飯田市松尾寺所');
ok($zip->set_number('3950823')->is_valid_number, '長野県飯田市松尾明');
ok($zip->set_number('3950824')->is_valid_number, '長野県飯田市松尾清水');
ok($zip->set_number('3950825')->is_valid_number, '長野県飯田市松尾城');
ok($zip->set_number('3950826')->is_valid_number, '長野県飯田市松尾水城');
ok($zip->set_number('3951100')->is_valid_number, '長野県下伊那郡喬木村以下に掲載がない場合');
ok($zip->set_number('3951101')->is_valid_number, '長野県下伊那郡喬木村阿島');
ok($zip->set_number('3951102')->is_valid_number, '長野県下伊那郡喬木村加々須');
ok($zip->set_number('3951103')->is_valid_number, '長野県下伊那郡喬木村大島');
ok($zip->set_number('3951104')->is_valid_number, '長野県下伊那郡喬木村氏乗');
ok($zip->set_number('3951105')->is_valid_number, '長野県下伊那郡喬木村大和知');
ok($zip->set_number('3951106')->is_valid_number, '長野県下伊那郡喬木村富田');
ok($zip->set_number('3951107')->is_valid_number, '長野県下伊那郡喬木村小川');
ok($zip->set_number('3951108')->is_valid_number, '長野県下伊那郡喬木村伊久間');
ok($zip->set_number('3960000')->is_valid_number, '長野県伊那市以下に掲載がない場合');
ok($zip->set_number('3960001')->is_valid_number, '長野県伊那市福島');
ok($zip->set_number('3960002')->is_valid_number, '長野県伊那市手良沢岡');
ok($zip->set_number('3960003')->is_valid_number, '長野県伊那市手良野口');
ok($zip->set_number('3960004')->is_valid_number, '長野県伊那市手良中坪');
ok($zip->set_number('3960005')->is_valid_number, '長野県伊那市野底');
ok($zip->set_number('3960006')->is_valid_number, '長野県伊那市上牧');
ok($zip->set_number('3960007')->is_valid_number, '長野県伊那市若宮');
ok($zip->set_number('3960008')->is_valid_number, '長野県伊那市上の原');
ok($zip->set_number('3960009')->is_valid_number, '長野県伊那市日影');
ok($zip->set_number('3960010')->is_valid_number, '長野県伊那市境');
ok($zip->set_number('3960011')->is_valid_number, '長野県伊那市伊那部');
ok($zip->set_number('3960012')->is_valid_number, '長野県伊那市上新田');
ok($zip->set_number('3960013')->is_valid_number, '長野県伊那市下新田');
ok($zip->set_number('3960014')->is_valid_number, '長野県伊那市狐島');
ok($zip->set_number('3960015')->is_valid_number, '長野県伊那市中央');
ok($zip->set_number('3960021')->is_valid_number, '長野県伊那市伊那');
ok($zip->set_number('3960022')->is_valid_number, '長野県伊那市御園');
ok($zip->set_number('3960023')->is_valid_number, '長野県伊那市山寺');
ok($zip->set_number('3960024')->is_valid_number, '長野県伊那市坂下');
ok($zip->set_number('3960025')->is_valid_number, '長野県伊那市荒井');
ok($zip->set_number('3960026')->is_valid_number, '長野県伊那市西町');
ok($zip->set_number('3960027')->is_valid_number, '長野県伊那市ますみヶ丘');
ok($zip->set_number('3960028')->is_valid_number, '長野県伊那市荒井内の萱');
ok($zip->set_number('3960029')->is_valid_number, '長野県伊那市横山');
ok($zip->set_number('3960030')->is_valid_number, '長野県伊那市平沢');
ok($zip->set_number('3960031')->is_valid_number, '長野県伊那市中の原');
ok($zip->set_number('3960032')->is_valid_number, '長野県伊那市小沢');
ok($zip->set_number('3960033')->is_valid_number, '長野県伊那市小四郎久保');
ok($zip->set_number('3960111')->is_valid_number, '長野県伊那市美篶');
ok($zip->set_number('3960112')->is_valid_number, '長野県伊那市前原');
ok($zip->set_number('3960113')->is_valid_number, '長野県伊那市美原');
ok($zip->set_number('3960114')->is_valid_number, '長野県伊那市仙美');
ok($zip->set_number('3960211')->is_valid_number, '長野県伊那市高遠町西高遠');
ok($zip->set_number('3960212')->is_valid_number, '長野県伊那市高遠町長藤(1~658番地)');
ok($zip->set_number('3960213')->is_valid_number, '長野県伊那市高遠町東高遠');
ok($zip->set_number('3960214')->is_valid_number, '長野県伊那市高遠町勝間');
ok($zip->set_number('3960215')->is_valid_number, '長野県伊那市高遠町小原');
ok($zip->set_number('3960216')->is_valid_number, '長野県伊那市高遠町下山田');
ok($zip->set_number('3960217')->is_valid_number, '長野県伊那市高遠町上山田');
ok($zip->set_number('3960301')->is_valid_number, '長野県伊那市高遠町藤沢');
ok($zip->set_number('3960302')->is_valid_number, '長野県伊那市高遠町芝平');
ok($zip->set_number('3960303')->is_valid_number, '長野県伊那市高遠町荊口');
ok($zip->set_number('3960304')->is_valid_number, '長野県伊那市高遠町山室');
ok($zip->set_number('3960305')->is_valid_number, '長野県伊那市高遠町長藤(その他)');
ok($zip->set_number('3960401')->is_valid_number, '長野県伊那市長谷非持');
ok($zip->set_number('3960402')->is_valid_number, '長野県伊那市長谷溝口');
ok($zip->set_number('3960403')->is_valid_number, '長野県伊那市長谷黒河内');
ok($zip->set_number('3960404')->is_valid_number, '長野県伊那市長谷中尾');
ok($zip->set_number('3960405')->is_valid_number, '長野県伊那市長谷市野瀬');
ok($zip->set_number('3960406')->is_valid_number, '長野県伊那市長谷杉島');
ok($zip->set_number('3960407')->is_valid_number, '長野県伊那市長谷浦');
ok($zip->set_number('3960621')->is_valid_number, '長野県伊那市富県');
ok($zip->set_number('3970000')->is_valid_number, '長野県木曽郡木曽町以下に掲載がない場合');
ok($zip->set_number('3970001')->is_valid_number, '長野県木曽郡木曽町福島');
ok($zip->set_number('3970002')->is_valid_number, '長野県木曽郡木曽町新開');
ok($zip->set_number('3970003')->is_valid_number, '長野県木曽郡木曽町新開福');
ok($zip->set_number('3970101')->is_valid_number, '長野県木曽郡木曽町三岳');
ok($zip->set_number('3970201')->is_valid_number, '長野県木曽郡王滝村王滝村一円');
ok($zip->set_number('3970301')->is_valid_number, '長野県木曽郡木曽町開田高原末川');
ok($zip->set_number('3970302')->is_valid_number, '長野県木曽郡木曽町開田高原西野');
ok($zip->set_number('3980000')->is_valid_number, '長野県大町市以下に掲載がない場合');
ok($zip->set_number('3980001')->is_valid_number, '長野県大町市平');
ok($zip->set_number('3980002')->is_valid_number, '長野県大町市大町');
ok($zip->set_number('3980003')->is_valid_number, '長野県大町市社');
ok($zip->set_number('3980004')->is_valid_number, '長野県大町市常盤');
ok($zip->set_number('3990000')->is_valid_number, '長野県松本市以下に掲載がない場合');
ok($zip->set_number('3990001')->is_valid_number, '長野県松本市宮田');
ok($zip->set_number('3990002')->is_valid_number, '長野県松本市芳野');
ok($zip->set_number('3990004')->is_valid_number, '長野県松本市市場');
ok($zip->set_number('3990005')->is_valid_number, '長野県松本市野溝木工');
ok($zip->set_number('3990006')->is_valid_number, '長野県松本市野溝西');
ok($zip->set_number('3990007')->is_valid_number, '長野県松本市石芝(3、4丁目)');
ok($zip->set_number('3990011')->is_valid_number, '長野県松本市寿北');
ok($zip->set_number('3990012')->is_valid_number, '長野県松本市寿白瀬渕');
ok($zip->set_number('3990014')->is_valid_number, '長野県松本市平田東');
ok($zip->set_number('3990015')->is_valid_number, '長野県松本市平田西');
ok($zip->set_number('3990021')->is_valid_number, '長野県松本市寿豊丘');
ok($zip->set_number('3990022')->is_valid_number, '長野県松本市松原');
ok($zip->set_number('3990023')->is_valid_number, '長野県松本市内田');
ok($zip->set_number('3990024')->is_valid_number, '長野県松本市寿小赤');
ok($zip->set_number('3990025')->is_valid_number, '長野県松本市寿台');
ok($zip->set_number('3990026')->is_valid_number, '長野県松本市寿中');
ok($zip->set_number('3990027')->is_valid_number, '長野県松本市寿南');
ok($zip->set_number('3990033')->is_valid_number, '長野県松本市笹賀');
ok($zip->set_number('3990034')->is_valid_number, '長野県松本市野溝東');
ok($zip->set_number('3990035')->is_valid_number, '長野県松本市村井町北');
ok($zip->set_number('3990036')->is_valid_number, '長野県松本市村井町南');
ok($zip->set_number('3990037')->is_valid_number, '長野県松本市村井町西');
ok($zip->set_number('3990038')->is_valid_number, '長野県松本市小屋南');
ok($zip->set_number('3990039')->is_valid_number, '長野県松本市小屋北');
ok($zip->set_number('3990071')->is_valid_number, '長野県塩尻市片丘(3635、3680、5794、6114番地)');
ok($zip->set_number('3990101')->is_valid_number, '長野県諏訪郡富士見町境');
ok($zip->set_number('3990102')->is_valid_number, '長野県諏訪郡富士見町落合(3060、3600~4600番地)');
ok($zip->set_number('3990200')->is_valid_number, '長野県諏訪郡富士見町以下に掲載がない場合');
ok($zip->set_number('3990211')->is_valid_number, '長野県諏訪郡富士見町富士見(その他)');
ok($zip->set_number('3990212')->is_valid_number, '長野県諏訪郡富士見町立沢');
ok($zip->set_number('3990213')->is_valid_number, '長野県諏訪郡富士見町乙事');
ok($zip->set_number('3990214')->is_valid_number, '長野県諏訪郡富士見町落合(その他)');
ok($zip->set_number('3990400')->is_valid_number, '長野県上伊那郡辰野町以下に掲載がない場合');
ok($zip->set_number('3990421')->is_valid_number, '長野県上伊那郡辰野町辰野');
ok($zip->set_number('3990422')->is_valid_number, '長野県上伊那郡辰野町平出');
ok($zip->set_number('3990423')->is_valid_number, '長野県上伊那郡辰野町沢底');
ok($zip->set_number('3990424')->is_valid_number, '長野県上伊那郡辰野町赤羽');
ok($zip->set_number('3990425')->is_valid_number, '長野県上伊那郡辰野町樋口');
ok($zip->set_number('3990426')->is_valid_number, '長野県上伊那郡辰野町宮木');
ok($zip->set_number('3990427')->is_valid_number, '長野県上伊那郡辰野町中央');
ok($zip->set_number('3990428')->is_valid_number, '長野県上伊那郡辰野町伊那富');
ok($zip->set_number('3990511')->is_valid_number, '長野県上伊那郡辰野町横川');
ok($zip->set_number('3990512')->is_valid_number, '長野県上伊那郡辰野町上島');
ok($zip->set_number('3990601')->is_valid_number, '長野県上伊那郡辰野町小野');
ok($zip->set_number('3990651')->is_valid_number, '長野県塩尻市北小野');
ok($zip->set_number('3990700')->is_valid_number, '長野県塩尻市以下に掲載がない場合');
ok($zip->set_number('3990701')->is_valid_number, '長野県塩尻市広丘吉田');
ok($zip->set_number('3990702')->is_valid_number, '長野県塩尻市広丘野村');
ok($zip->set_number('3990703')->is_valid_number, '長野県塩尻市広丘高出');
ok($zip->set_number('3990704')->is_valid_number, '長野県塩尻市広丘郷原');
ok($zip->set_number('3990705')->is_valid_number, '長野県塩尻市広丘堅石');
ok($zip->set_number('3990706')->is_valid_number, '長野県塩尻市広丘原新田');
ok($zip->set_number('3990711')->is_valid_number, '長野県塩尻市片丘(その他)');
ok($zip->set_number('3990712')->is_valid_number, '長野県塩尻市塩尻町');
ok($zip->set_number('3990713')->is_valid_number, '長野県塩尻市大小屋');
ok($zip->set_number('3990714')->is_valid_number, '長野県塩尻市堀ノ内');
ok($zip->set_number('3990715')->is_valid_number, '長野県塩尻市長畝');
ok($zip->set_number('3990716')->is_valid_number, '長野県塩尻市桟敷');
ok($zip->set_number('3990721')->is_valid_number, '長野県塩尻市金井');
ok($zip->set_number('3990722')->is_valid_number, '長野県塩尻市柿沢');
ok($zip->set_number('3990723')->is_valid_number, '長野県塩尻市旧塩尻');
ok($zip->set_number('3990724')->is_valid_number, '長野県塩尻市上西条');
ok($zip->set_number('3990725')->is_valid_number, '長野県塩尻市中西条');
ok($zip->set_number('3990726')->is_valid_number, '長野県塩尻市下西条');
ok($zip->set_number('3990727')->is_valid_number, '長野県塩尻市みどり湖');
ok($zip->set_number('3990728')->is_valid_number, '長野県塩尻市峰原');
ok($zip->set_number('3990731')->is_valid_number, '長野県塩尻市大門六番町');
ok($zip->set_number('3990732')->is_valid_number, '長野県塩尻市大門五番町');
ok($zip->set_number('3990733')->is_valid_number, '長野県塩尻市大門三番町');
ok($zip->set_number('3990734')->is_valid_number, '長野県塩尻市大門四番町');
ok($zip->set_number('3990735')->is_valid_number, '長野県塩尻市大門二番町');
ok($zip->set_number('3990736')->is_valid_number, '長野県塩尻市大門一番町');
ok($zip->set_number('3990737')->is_valid_number, '長野県塩尻市大門八番町');
ok($zip->set_number('3990738')->is_valid_number, '長野県塩尻市大門七番町');
ok($zip->set_number('3990741')->is_valid_number, '長野県塩尻市大門幸町');
ok($zip->set_number('3990742')->is_valid_number, '長野県塩尻市大門泉町');
ok($zip->set_number('3990743')->is_valid_number, '長野県塩尻市大門田川町');
ok($zip->set_number('3990744')->is_valid_number, '長野県塩尻市大門七区');
ok($zip->set_number('3990744')->is_valid_number, '長野県塩尻市大門(番地)');
ok($zip->set_number('3990745')->is_valid_number, '長野県塩尻市大門桔梗町');
ok($zip->set_number('3990746')->is_valid_number, '長野県塩尻市大門並木町');
ok($zip->set_number('3991200')->is_valid_number, '長野県下伊那郡天龍村以下に掲載がない場合');
ok($zip->set_number('3991201')->is_valid_number, '長野県下伊那郡天龍村平岡');
ok($zip->set_number('3991202')->is_valid_number, '長野県下伊那郡天龍村神原');
ok($zip->set_number('3991203')->is_valid_number, '長野県下伊那郡天龍村長島');
ok($zip->set_number('3991221')->is_valid_number, '長野県飯田市南信濃南和田(万古)');
ok($zip->set_number('3991311')->is_valid_number, '長野県飯田市南信濃和田');
ok($zip->set_number('3991312')->is_valid_number, '長野県飯田市南信濃八重河内');
ok($zip->set_number('3991313')->is_valid_number, '長野県飯田市南信濃南和田(その他)');
ok($zip->set_number('3991401')->is_valid_number, '長野県飯田市南信濃木沢');
ok($zip->set_number('3991403')->is_valid_number, '長野県飯田市上村');
ok($zip->set_number('3991500')->is_valid_number, '長野県下伊那郡阿南町以下に掲載がない場合');
ok($zip->set_number('3991501')->is_valid_number, '長野県下伊那郡阿南町北條');
ok($zip->set_number('3991502')->is_valid_number, '長野県下伊那郡阿南町東條');
ok($zip->set_number('3991503')->is_valid_number, '長野県下伊那郡阿南町南條');
ok($zip->set_number('3991504')->is_valid_number, '長野県下伊那郡阿南町西條');
ok($zip->set_number('3991505')->is_valid_number, '長野県下伊那郡阿南町富草');
ok($zip->set_number('3991601')->is_valid_number, '長野県下伊那郡売木村売木村一円');
ok($zip->set_number('3991611')->is_valid_number, '長野県下伊那郡阿南町和合');
ok($zip->set_number('3991612')->is_valid_number, '長野県下伊那郡阿南町新野');
ok($zip->set_number('3991801')->is_valid_number, '長野県下伊那郡泰阜村泰阜村一円');
ok($zip->set_number('3992100')->is_valid_number, '長野県下伊那郡下條村以下に掲載がない場合');
ok($zip->set_number('3992101')->is_valid_number, '長野県下伊那郡下條村睦沢');
ok($zip->set_number('3992102')->is_valid_number, '長野県下伊那郡下條村陽皐');
ok($zip->set_number('3992221')->is_valid_number, '長野県飯田市龍江');
ok($zip->set_number('3992222')->is_valid_number, '長野県飯田市千代');
ok($zip->set_number('3992223')->is_valid_number, '長野県飯田市千栄');
ok($zip->set_number('3992431')->is_valid_number, '長野県飯田市川路');
ok($zip->set_number('3992432')->is_valid_number, '長野県飯田市下瀬');
ok($zip->set_number('3992433')->is_valid_number, '長野県飯田市立石');
ok($zip->set_number('3992434')->is_valid_number, '長野県飯田市伊豆木');
ok($zip->set_number('3992561')->is_valid_number, '長野県飯田市駄科');
ok($zip->set_number('3992562')->is_valid_number, '長野県飯田市長野原');
ok($zip->set_number('3992563')->is_valid_number, '長野県飯田市時又');
ok($zip->set_number('3992564')->is_valid_number, '長野県飯田市上川路');
ok($zip->set_number('3992565')->is_valid_number, '長野県飯田市桐林');
ok($zip->set_number('3992566')->is_valid_number, '長野県飯田市嶋');
ok($zip->set_number('3992601')->is_valid_number, '長野県飯田市虎岩');
ok($zip->set_number('3992602')->is_valid_number, '長野県飯田市下久堅下虎岩');
ok($zip->set_number('3992603')->is_valid_number, '長野県飯田市下久堅知久平');
ok($zip->set_number('3992604')->is_valid_number, '長野県飯田市下久堅柿野沢');
ok($zip->set_number('3992605')->is_valid_number, '長野県飯田市下久堅小林');
ok($zip->set_number('3992606')->is_valid_number, '長野県飯田市下久堅稲葉');
ok($zip->set_number('3992607')->is_valid_number, '長野県飯田市下久堅南原');
ok($zip->set_number('3992611')->is_valid_number, '長野県飯田市上久堅');
ok($zip->set_number('3992612')->is_valid_number, '長野県飯田市上久堅戊');
ok($zip->set_number('3993100')->is_valid_number, '長野県下伊那郡高森町以下に掲載がない場合');
ok($zip->set_number('3993101')->is_valid_number, '長野県下伊那郡高森町山吹');
ok($zip->set_number('3993102')->is_valid_number, '長野県下伊那郡高森町吉田');
ok($zip->set_number('3993103')->is_valid_number, '長野県下伊那郡高森町下市田');
ok($zip->set_number('3993104')->is_valid_number, '長野県下伊那郡高森町上市田');
ok($zip->set_number('3993105')->is_valid_number, '長野県下伊那郡高森町牛牧');
ok($zip->set_number('3993106')->is_valid_number, '長野県下伊那郡高森町大島山');
ok($zip->set_number('3993107')->is_valid_number, '長野県下伊那郡高森町出原');
ok($zip->set_number('3993200')->is_valid_number, '長野県下伊那郡豊丘村以下に掲載がない場合');
ok($zip->set_number('3993201')->is_valid_number, '長野県下伊那郡豊丘村河野(その他)');
ok($zip->set_number('3993202')->is_valid_number, '長野県下伊那郡豊丘村神稲');
ok($zip->set_number('3993300')->is_valid_number, '長野県下伊那郡松川町以下に掲載がない場合');
ok($zip->set_number('3993301')->is_valid_number, '長野県下伊那郡松川町上片桐');
ok($zip->set_number('3993302')->is_valid_number, '長野県下伊那郡松川町生田');
ok($zip->set_number('3993303')->is_valid_number, '長野県下伊那郡松川町元大島');
ok($zip->set_number('3993304')->is_valid_number, '長野県下伊那郡松川町大島');
ok($zip->set_number('3993311')->is_valid_number, '長野県下伊那郡豊丘村河野(7530~7590番地)');
ok($zip->set_number('3993500')->is_valid_number, '長野県下伊那郡大鹿村以下に掲載がない場合');
ok($zip->set_number('3993501')->is_valid_number, '長野県下伊那郡大鹿村鹿塩');
ok($zip->set_number('3993502')->is_valid_number, '長野県下伊那郡大鹿村大河原');
ok($zip->set_number('3993700')->is_valid_number, '長野県上伊那郡飯島町以下に掲載がない場合');
ok($zip->set_number('3993701')->is_valid_number, '長野県上伊那郡飯島町田切');
ok($zip->set_number('3993702')->is_valid_number, '長野県上伊那郡飯島町飯島');
ok($zip->set_number('3993703')->is_valid_number, '長野県上伊那郡飯島町日曽利');
ok($zip->set_number('3993704')->is_valid_number, '長野県上伊那郡飯島町本郷');
ok($zip->set_number('3993705')->is_valid_number, '長野県上伊那郡飯島町七久保');
ok($zip->set_number('3993800')->is_valid_number, '長野県上伊那郡中川村以下に掲載がない場合');
ok($zip->set_number('3993801')->is_valid_number, '長野県上伊那郡中川村大草');
ok($zip->set_number('3993802')->is_valid_number, '長野県上伊那郡中川村片桐');
ok($zip->set_number('3993803')->is_valid_number, '長野県上伊那郡中川村葛島');
ok($zip->set_number('3993804')->is_valid_number, '長野県上伊那郡中川村四徳');
ok($zip->set_number('3994100')->is_valid_number, '長野県駒ヶ根市以下に掲載がない場合');
ok($zip->set_number('3994101')->is_valid_number, '長野県駒ヶ根市下平(その他)');
ok($zip->set_number('3994102')->is_valid_number, '長野県駒ヶ根市飯坂');
ok($zip->set_number('3994103')->is_valid_number, '長野県駒ヶ根市梨の木');
ok($zip->set_number('3994104')->is_valid_number, '長野県駒ヶ根市経塚');
ok($zip->set_number('3994105')->is_valid_number, '長野県駒ヶ根市赤須東');
ok($zip->set_number('3994106')->is_valid_number, '長野県駒ヶ根市東町');
ok($zip->set_number('3994107')->is_valid_number, '長野県駒ヶ根市南田');
ok($zip->set_number('3994108')->is_valid_number, '長野県駒ヶ根市下市場');
ok($zip->set_number('3994111')->is_valid_number, '長野県駒ヶ根市北町');
ok($zip->set_number('3994112')->is_valid_number, '長野県駒ヶ根市中央');
ok($zip->set_number('3994113')->is_valid_number, '長野県駒ヶ根市赤須町');
ok($zip->set_number('3994114')->is_valid_number, '長野県駒ヶ根市上穂南');
ok($zip->set_number('3994115')->is_valid_number, '長野県駒ヶ根市上穂栄町');
ok($zip->set_number('3994116')->is_valid_number, '長野県駒ヶ根市上穂北');
ok($zip->set_number('3994117')->is_valid_number, '長野県駒ヶ根市赤穂');
ok($zip->set_number('3994231')->is_valid_number, '長野県駒ヶ根市中沢');
ok($zip->set_number('3994232')->is_valid_number, '長野県駒ヶ根市下平(2070~2119、2309~2311、2419、2421~2426');
ok($zip->set_number('3994232')->is_valid_number, '長野県駒ヶ根市、2433~2450)');
ok($zip->set_number('3994301')->is_valid_number, '長野県上伊那郡宮田村宮田村一円');
ok($zip->set_number('3994321')->is_valid_number, '長野県駒ヶ根市東伊那');
ok($zip->set_number('3994431')->is_valid_number, '長野県伊那市西春近');
ok($zip->set_number('3994432')->is_valid_number, '長野県伊那市東春近');
ok($zip->set_number('3994501')->is_valid_number, '長野県伊那市西箕輪');
ok($zip->set_number('3994511')->is_valid_number, '長野県上伊那郡南箕輪村南箕輪村一円');
ok($zip->set_number('3994600')->is_valid_number, '長野県上伊那郡箕輪町以下に掲載がない場合');
ok($zip->set_number('3994601')->is_valid_number, '長野県上伊那郡箕輪町中箕輪');
ok($zip->set_number('3994602')->is_valid_number, '長野県上伊那郡箕輪町東箕輪');
ok($zip->set_number('3994603')->is_valid_number, '長野県上伊那郡箕輪町三日町');
ok($zip->set_number('3994604')->is_valid_number, '長野県上伊那郡箕輪町福与');
ok($zip->set_number('3994605')->is_valid_number, '長野県上伊那郡箕輪町中曽根');
ok($zip->set_number('3995300')->is_valid_number, '長野県木曽郡南木曽町以下に掲載がない場合');
ok($zip->set_number('3995301')->is_valid_number, '長野県木曽郡南木曽町読書');
ok($zip->set_number('3995302')->is_valid_number, '長野県木曽郡南木曽町吾妻');
ok($zip->set_number('3995303')->is_valid_number, '長野県木曽郡南木曽町田立');
ok($zip->set_number('3995500')->is_valid_number, '長野県木曽郡大桑村以下に掲載がない場合');
ok($zip->set_number('3995501')->is_valid_number, '長野県木曽郡大桑村殿');
ok($zip->set_number('3995502')->is_valid_number, '長野県木曽郡大桑村須原');
ok($zip->set_number('3995503')->is_valid_number, '長野県木曽郡大桑村長野');
ok($zip->set_number('3995504')->is_valid_number, '長野県木曽郡大桑村野尻');
ok($zip->set_number('3995600')->is_valid_number, '長野県木曽郡上松町以下に掲載がない場合');
ok($zip->set_number('3995601')->is_valid_number, '長野県木曽郡上松町上松');
ok($zip->set_number('3995602')->is_valid_number, '長野県木曽郡上松町本町通り');
ok($zip->set_number('3995603')->is_valid_number, '長野県木曽郡上松町駅前通り');
ok($zip->set_number('3995604')->is_valid_number, '長野県木曽郡上松町正島町');
ok($zip->set_number('3995605')->is_valid_number, '長野県木曽郡上松町栄町');
ok($zip->set_number('3995606')->is_valid_number, '長野県木曽郡上松町緑町');
ok($zip->set_number('3995607')->is_valid_number, '長野県木曽郡上松町小川');
ok($zip->set_number('3995608')->is_valid_number, '長野県木曽郡上松町荻原');
ok($zip->set_number('3995609')->is_valid_number, '長野県木曽郡上松町旭町');
ok($zip->set_number('3996101')->is_valid_number, '長野県木曽郡木曽町日義');
ok($zip->set_number('3996200')->is_valid_number, '長野県木曽郡木祖村以下に掲載がない場合');
ok($zip->set_number('3996201')->is_valid_number, '長野県木曽郡木祖村薮原');
ok($zip->set_number('3996202')->is_valid_number, '長野県木曽郡木祖村菅');
ok($zip->set_number('3996203')->is_valid_number, '長野県木曽郡木祖村小木曽');
ok($zip->set_number('3996301')->is_valid_number, '長野県塩尻市贄川');
ok($zip->set_number('3996302')->is_valid_number, '長野県塩尻市木曽平沢');
ok($zip->set_number('3996303')->is_valid_number, '長野県塩尻市奈良井');
ok($zip->set_number('3996461')->is_valid_number, '長野県塩尻市宗賀');
ok($zip->set_number('3996462')->is_valid_number, '長野県塩尻市洗馬');
ok($zip->set_number('3997101')->is_valid_number, '長野県安曇野市明科東川手');
ok($zip->set_number('3997102')->is_valid_number, '長野県安曇野市明科中川手');
ok($zip->set_number('3997103')->is_valid_number, '長野県安曇野市明科光');
ok($zip->set_number('3997104')->is_valid_number, '長野県安曇野市明科七貴');
ok($zip->set_number('3997105')->is_valid_number, '長野県安曇野市明科南陸郷');
ok($zip->set_number('3997200')->is_valid_number, '長野県東筑摩郡生坂村以下に掲載がない場合');
ok($zip->set_number('3997201')->is_valid_number, '長野県東筑摩郡生坂村生坂村の次に番地がくる場合');
ok($zip->set_number('3997202')->is_valid_number, '長野県東筑摩郡生坂村北陸郷');
ok($zip->set_number('3997301')->is_valid_number, '長野県大町市八坂');
ok($zip->set_number('3997302')->is_valid_number, '長野県大町市八坂菖蒲');
ok($zip->set_number('3997311')->is_valid_number, '長野県東筑摩郡生坂村東広津');
ok($zip->set_number('3997401')->is_valid_number, '長野県松本市五常');
ok($zip->set_number('3997402')->is_valid_number, '長野県松本市会田');
ok($zip->set_number('3997403')->is_valid_number, '長野県松本市穴沢');
ok($zip->set_number('3997404')->is_valid_number, '長野県松本市取出');
ok($zip->set_number('3997405')->is_valid_number, '長野県松本市板場');
ok($zip->set_number('3997411')->is_valid_number, '長野県松本市中川');
ok($zip->set_number('3997412')->is_valid_number, '長野県松本市保福寺町');
ok($zip->set_number('3997413')->is_valid_number, '長野県松本市金山町');
ok($zip->set_number('3997414')->is_valid_number, '長野県松本市殿野入');
ok($zip->set_number('3997415')->is_valid_number, '長野県松本市赤怒田');
ok($zip->set_number('3997416')->is_valid_number, '長野県松本市七嵐');
ok($zip->set_number('3997417')->is_valid_number, '長野県松本市刈谷原町');
ok($zip->set_number('3997418')->is_valid_number, '長野県松本市反町');
ok($zip->set_number('3997500')->is_valid_number, '長野県東筑摩郡筑北村以下に掲載がない場合');
ok($zip->set_number('3997501')->is_valid_number, '長野県東筑摩郡筑北村西条');
ok($zip->set_number('3997502')->is_valid_number, '長野県東筑摩郡筑北村東条');
ok($zip->set_number('3997503')->is_valid_number, '長野県東筑摩郡筑北村大沢新田');
ok($zip->set_number('3997504')->is_valid_number, '長野県東筑摩郡筑北村乱橋');
ok($zip->set_number('3997601')->is_valid_number, '長野県東筑摩郡筑北村坂北');
ok($zip->set_number('3997700')->is_valid_number, '長野県東筑摩郡麻績村以下に掲載がない場合');
ok($zip->set_number('3997701')->is_valid_number, '長野県東筑摩郡麻績村麻');
ok($zip->set_number('3997702')->is_valid_number, '長野県東筑摩郡麻績村日');
ok($zip->set_number('3997711')->is_valid_number, '長野県東筑摩郡筑北村坂井');
ok($zip->set_number('3998101')->is_valid_number, '長野県安曇野市三郷明盛');
ok($zip->set_number('3998102')->is_valid_number, '長野県安曇野市三郷温');
ok($zip->set_number('3998103')->is_valid_number, '長野県安曇野市三郷小倉');
ok($zip->set_number('3998200')->is_valid_number, '長野県安曇野市以下に掲載がない場合');
ok($zip->set_number('3998201')->is_valid_number, '長野県安曇野市豊科南穂高');
ok($zip->set_number('3998202')->is_valid_number, '長野県安曇野市豊科光');
ok($zip->set_number('3998203')->is_valid_number, '長野県安曇野市豊科田沢');
ok($zip->set_number('3998204')->is_valid_number, '長野県安曇野市豊科高家');
ok($zip->set_number('3998205')->is_valid_number, '長野県安曇野市豊科');
ok($zip->set_number('3998211')->is_valid_number, '長野県安曇野市堀金烏川');
ok($zip->set_number('3998212')->is_valid_number, '長野県安曇野市堀金三田');
ok($zip->set_number('3998251')->is_valid_number, '長野県松本市島内(9820、9821、9823~9830、9864番地以上)');
ok($zip->set_number('3998301')->is_valid_number, '長野県安曇野市穂高有明');
ok($zip->set_number('3998302')->is_valid_number, '長野県安曇野市穂高北穂高');
ok($zip->set_number('3998303')->is_valid_number, '長野県安曇野市穂高');
ok($zip->set_number('3998304')->is_valid_number, '長野県安曇野市穂高柏原');
ok($zip->set_number('3998305')->is_valid_number, '長野県安曇野市穂高牧');
ok($zip->set_number('3998501')->is_valid_number, '長野県北安曇郡松川村松川村一円');
ok($zip->set_number('3998600')->is_valid_number, '長野県北安曇郡池田町以下に掲載がない場合');
ok($zip->set_number('3998601')->is_valid_number, '長野県北安曇郡池田町池田');
ok($zip->set_number('3998602')->is_valid_number, '長野県北安曇郡池田町会染');
ok($zip->set_number('3998603')->is_valid_number, '長野県北安曇郡池田町中鵜');
ok($zip->set_number('3998604')->is_valid_number, '長野県北安曇郡池田町広津');
ok($zip->set_number('3998605')->is_valid_number, '長野県北安曇郡池田町陸郷');
ok($zip->set_number('3999101')->is_valid_number, '長野県大町市美麻');
ok($zip->set_number('3999211')->is_valid_number, '長野県北安曇郡白馬村神城');
ok($zip->set_number('3999300')->is_valid_number, '長野県北安曇郡白馬村以下に掲載がない場合');
ok($zip->set_number('3999301')->is_valid_number, '長野県北安曇郡白馬村北城');
ok($zip->set_number('3999400')->is_valid_number, '長野県北安曇郡小谷村以下に掲載がない場合');
ok($zip->set_number('3999421')->is_valid_number, '長野県北安曇郡小谷村中小谷');
ok($zip->set_number('3999422')->is_valid_number, '長野県北安曇郡小谷村千国');
ok($zip->set_number('3999511')->is_valid_number, '長野県北安曇郡小谷村中土');
ok($zip->set_number('3999601')->is_valid_number, '長野県北安曇郡小谷村北小谷');
ok($zip->set_number('4000000')->is_valid_number, '山梨県甲府市以下に掲載がない場合');
ok($zip->set_number('4000001')->is_valid_number, '山梨県甲府市和田町');
ok($zip->set_number('4000002')->is_valid_number, '山梨県甲府市小松町');
ok($zip->set_number('4000003')->is_valid_number, '山梨県甲府市塚原町');
ok($zip->set_number('4000004')->is_valid_number, '山梨県甲府市西田町');
ok($zip->set_number('4000005')->is_valid_number, '山梨県甲府市北新');
ok($zip->set_number('4000006')->is_valid_number, '山梨県甲府市天神町');
ok($zip->set_number('4000007')->is_valid_number, '山梨県甲府市美咲');
ok($zip->set_number('4000008')->is_valid_number, '山梨県甲府市緑が丘');
ok($zip->set_number('4000011')->is_valid_number, '山梨県甲府市上積翠寺町');
ok($zip->set_number('4000012')->is_valid_number, '山梨県甲府市下積翠寺町');
ok($zip->set_number('4000013')->is_valid_number, '山梨県甲府市岩窪町');
ok($zip->set_number('4000014')->is_valid_number, '山梨県甲府市古府中町');
ok($zip->set_number('4000015')->is_valid_number, '山梨県甲府市大手');
ok($zip->set_number('4000016')->is_valid_number, '山梨県甲府市武田');
ok($zip->set_number('4000017')->is_valid_number, '山梨県甲府市屋形');
ok($zip->set_number('4000021')->is_valid_number, '山梨県甲府市宮前町');
ok($zip->set_number('4000022')->is_valid_number, '山梨県甲府市元紺屋町');
ok($zip->set_number('4000023')->is_valid_number, '山梨県甲府市愛宕町');
ok($zip->set_number('4000024')->is_valid_number, '山梨県甲府市北口');
ok($zip->set_number('4000025')->is_valid_number, '山梨県甲府市朝日');
ok($zip->set_number('4000026')->is_valid_number, '山梨県甲府市塩部');
ok($zip->set_number('4000027')->is_valid_number, '山梨県甲府市富士見');
ok($zip->set_number('4000028')->is_valid_number, '山梨県甲府市音羽町');
ok($zip->set_number('4000031')->is_valid_number, '山梨県甲府市丸の内');
ok($zip->set_number('4000032')->is_valid_number, '山梨県甲府市中央');
ok($zip->set_number('4000033')->is_valid_number, '山梨県甲府市寿町');
ok($zip->set_number('4000034')->is_valid_number, '山梨県甲府市宝');
ok($zip->set_number('4000035')->is_valid_number, '山梨県甲府市飯田');
ok($zip->set_number('4000041')->is_valid_number, '山梨県甲府市上石田');
ok($zip->set_number('4000042')->is_valid_number, '山梨県甲府市高畑');
ok($zip->set_number('4000043')->is_valid_number, '山梨県甲府市国母');
ok($zip->set_number('4000044')->is_valid_number, '山梨県甲府市上小河原町');
ok($zip->set_number('4000045')->is_valid_number, '山梨県甲府市後屋町');
ok($zip->set_number('4000046')->is_valid_number, '山梨県甲府市下石田');
ok($zip->set_number('4000047')->is_valid_number, '山梨県甲府市徳行');
ok($zip->set_number('4000048')->is_valid_number, '山梨県甲府市貢川本町');
ok($zip->set_number('4000049')->is_valid_number, '山梨県甲府市富竹');
ok($zip->set_number('4000051')->is_valid_number, '山梨県甲府市古上条町');
ok($zip->set_number('4000052')->is_valid_number, '山梨県甲府市上条新居町');
ok($zip->set_number('4000053')->is_valid_number, '山梨県甲府市大里町');
ok($zip->set_number('4000054')->is_valid_number, '山梨県甲府市西下条町');
ok($zip->set_number('4000055')->is_valid_number, '山梨県甲府市大津町');
ok($zip->set_number('4000056')->is_valid_number, '山梨県甲府市堀之内町');
ok($zip->set_number('4000057')->is_valid_number, '山梨県甲府市高室町');
ok($zip->set_number('4000058')->is_valid_number, '山梨県甲府市宮原町');
ok($zip->set_number('4000061')->is_valid_number, '山梨県甲府市荒川');
ok($zip->set_number('4000062')->is_valid_number, '山梨県甲府市池田');
ok($zip->set_number('4000063')->is_valid_number, '山梨県甲府市金竹町');
ok($zip->set_number('4000064')->is_valid_number, '山梨県甲府市下飯田');
ok($zip->set_number('4000065')->is_valid_number, '山梨県甲府市貢川');
ok($zip->set_number('4000066')->is_valid_number, '山梨県甲府市新田町');
ok($zip->set_number('4000067')->is_valid_number, '山梨県甲府市長松寺町');
ok($zip->set_number('4000068')->is_valid_number, '山梨県甲府市下河原町');
ok($zip->set_number('4000069')->is_valid_number, '山梨県甲府市中村町');
ok($zip->set_number('4000071')->is_valid_number, '山梨県甲府市羽黒町');
ok($zip->set_number('4000072')->is_valid_number, '山梨県甲府市大和町');
ok($zip->set_number('4000073')->is_valid_number, '山梨県甲府市湯村');
ok($zip->set_number('4000074')->is_valid_number, '山梨県甲府市千塚');
ok($zip->set_number('4000075')->is_valid_number, '山梨県甲府市山宮町');
ok($zip->set_number('4000081')->is_valid_number, '山梨県甲府市上帯那町');
ok($zip->set_number('4000082')->is_valid_number, '山梨県甲府市下帯那町');
ok($zip->set_number('4000083')->is_valid_number, '山梨県甲府市平瀬町');
ok($zip->set_number('4000100')->is_valid_number, '山梨県甲斐市以下に掲載がない場合');
ok($zip->set_number('4000101')->is_valid_number, '山梨県甲斐市菖蒲沢');
ok($zip->set_number('4000102')->is_valid_number, '山梨県甲斐市団子新居');
ok($zip->set_number('4000103')->is_valid_number, '山梨県甲斐市大垈');
ok($zip->set_number('4000104')->is_valid_number, '山梨県甲斐市龍地');
ok($zip->set_number('4000105')->is_valid_number, '山梨県甲斐市下今井');
ok($zip->set_number('4000106')->is_valid_number, '山梨県甲斐市岩森');
ok($zip->set_number('4000107')->is_valid_number, '山梨県甲斐市志田');
ok($zip->set_number('4000108')->is_valid_number, '山梨県甲斐市宇津谷');
ok($zip->set_number('4000111')->is_valid_number, '山梨県甲斐市竜王新町');
ok($zip->set_number('4000112')->is_valid_number, '山梨県甲斐市名取');
ok($zip->set_number('4000113')->is_valid_number, '山梨県甲斐市富竹新田');
ok($zip->set_number('4000114')->is_valid_number, '山梨県甲斐市万才');
ok($zip->set_number('4000115')->is_valid_number, '山梨県甲斐市篠原');
ok($zip->set_number('4000116')->is_valid_number, '山梨県甲斐市玉川');
ok($zip->set_number('4000117')->is_valid_number, '山梨県甲斐市西八幡');
ok($zip->set_number('4000118')->is_valid_number, '山梨県甲斐市竜王');
ok($zip->set_number('4000121')->is_valid_number, '山梨県甲斐市牛句');
ok($zip->set_number('4000122')->is_valid_number, '山梨県甲斐市境');
ok($zip->set_number('4000123')->is_valid_number, '山梨県甲斐市島上条');
ok($zip->set_number('4000124')->is_valid_number, '山梨県甲斐市中下条');
ok($zip->set_number('4000125')->is_valid_number, '山梨県甲斐市長塚');
ok($zip->set_number('4000126')->is_valid_number, '山梨県甲斐市大下条');
ok($zip->set_number('4000127')->is_valid_number, '山梨県甲斐市天狗沢');
ok($zip->set_number('4000128')->is_valid_number, '山梨県甲斐市大久保');
ok($zip->set_number('4000201')->is_valid_number, '山梨県南アルプス市上高砂');
ok($zip->set_number('4000202')->is_valid_number, '山梨県南アルプス市下高砂');
ok($zip->set_number('4000203')->is_valid_number, '山梨県南アルプス市徳永');
ok($zip->set_number('4000204')->is_valid_number, '山梨県南アルプス市榎原');
ok($zip->set_number('4000205')->is_valid_number, '山梨県南アルプス市野牛島');
ok($zip->set_number('4000206')->is_valid_number, '山梨県南アルプス市六科');
ok($zip->set_number('4000211')->is_valid_number, '山梨県南アルプス市上今諏訪');
ok($zip->set_number('4000212')->is_valid_number, '山梨県南アルプス市下今諏訪');
ok($zip->set_number('4000213')->is_valid_number, '山梨県南アルプス市西野');
ok($zip->set_number('4000214')->is_valid_number, '山梨県南アルプス市百々');
ok($zip->set_number('4000215')->is_valid_number, '山梨県南アルプス市上八田');
ok($zip->set_number('4000221')->is_valid_number, '山梨県南アルプス市在家塚');
ok($zip->set_number('4000222')->is_valid_number, '山梨県南アルプス市飯野');
ok($zip->set_number('4000223')->is_valid_number, '山梨県南アルプス市曲輪田新田');
ok($zip->set_number('4000224')->is_valid_number, '山梨県南アルプス市飯野新田');
ok($zip->set_number('4000225')->is_valid_number, '山梨県南アルプス市築山');
ok($zip->set_number('4000226')->is_valid_number, '山梨県南アルプス市有野');
ok($zip->set_number('4000231')->is_valid_number, '山梨県南アルプス市塩前');
ok($zip->set_number('4000232')->is_valid_number, '山梨県南アルプス市駒場');
ok($zip->set_number('4000233')->is_valid_number, '山梨県南アルプス市須沢');
ok($zip->set_number('4000234')->is_valid_number, '山梨県南アルプス市大嵐');
ok($zip->set_number('4000241')->is_valid_number, '山梨県南アルプス市芦安芦倉');
ok($zip->set_number('4000242')->is_valid_number, '山梨県南アルプス市芦安安通');
ok($zip->set_number('4000301')->is_valid_number, '山梨県南アルプス市桃園');
ok($zip->set_number('4000302')->is_valid_number, '山梨県南アルプス市沢登');
ok($zip->set_number('4000303')->is_valid_number, '山梨県南アルプス市上今井');
ok($zip->set_number('4000304')->is_valid_number, '山梨県南アルプス市吉田');
ok($zip->set_number('4000305')->is_valid_number, '山梨県南アルプス市十五所');
ok($zip->set_number('4000306')->is_valid_number, '山梨県南アルプス市小笠原');
ok($zip->set_number('4000308')->is_valid_number, '山梨県南アルプス市山寺');
ok($zip->set_number('4000311')->is_valid_number, '山梨県南アルプス市曲輪田');
ok($zip->set_number('4000312')->is_valid_number, '山梨県南アルプス市上宮地');
ok($zip->set_number('4000313')->is_valid_number, '山梨県南アルプス市平岡');
ok($zip->set_number('4000314')->is_valid_number, '山梨県南アルプス市下市之瀬');
ok($zip->set_number('4000315')->is_valid_number, '山梨県南アルプス市上野');
ok($zip->set_number('4000316')->is_valid_number, '山梨県南アルプス市中野');
ok($zip->set_number('4000317')->is_valid_number, '山梨県南アルプス市上市之瀬');
ok($zip->set_number('4000318')->is_valid_number, '山梨県南アルプス市高尾');
ok($zip->set_number('4000319')->is_valid_number, '山梨県南アルプス市あやめが丘');
ok($zip->set_number('4000331')->is_valid_number, '山梨県南アルプス市下今井');
ok($zip->set_number('4000332')->is_valid_number, '山梨県南アルプス市鏡中條');
ok($zip->set_number('4000333')->is_valid_number, '山梨県南アルプス市浅原');
ok($zip->set_number('4000334')->is_valid_number, '山梨県南アルプス市藤田');
ok($zip->set_number('4000335')->is_valid_number, '山梨県南アルプス市加賀美');
ok($zip->set_number('4000336')->is_valid_number, '山梨県南アルプス市十日市場');
ok($zip->set_number('4000337')->is_valid_number, '山梨県南アルプス市寺部');
ok($zip->set_number('4000400')->is_valid_number, '山梨県南アルプス市以下に掲載がない場合');
ok($zip->set_number('4000401')->is_valid_number, '山梨県南アルプス市江原');
ok($zip->set_number('4000402')->is_valid_number, '山梨県南アルプス市田島');
ok($zip->set_number('4000403')->is_valid_number, '山梨県南アルプス市鮎沢');
ok($zip->set_number('4000404')->is_valid_number, '山梨県南アルプス市古市場');
ok($zip->set_number('4000405')->is_valid_number, '山梨県南アルプス市下宮地');
ok($zip->set_number('4000411')->is_valid_number, '山梨県南アルプス市西南湖');
ok($zip->set_number('4000412')->is_valid_number, '山梨県南アルプス市東南湖');
ok($zip->set_number('4000413')->is_valid_number, '山梨県南アルプス市和泉');
ok($zip->set_number('4000414')->is_valid_number, '山梨県南アルプス市戸田');
ok($zip->set_number('4000415')->is_valid_number, '山梨県南アルプス市宮沢');
ok($zip->set_number('4000416')->is_valid_number, '山梨県南アルプス市大師');
ok($zip->set_number('4000417')->is_valid_number, '山梨県南アルプス市清水');
ok($zip->set_number('4000421')->is_valid_number, '山梨県南アルプス市川上');
ok($zip->set_number('4000422')->is_valid_number, '山梨県南アルプス市荊沢');
ok($zip->set_number('4000423')->is_valid_number, '山梨県南アルプス市落合');
ok($zip->set_number('4000424')->is_valid_number, '山梨県南アルプス市秋山');
ok($zip->set_number('4000425')->is_valid_number, '山梨県南アルプス市湯沢');
ok($zip->set_number('4000426')->is_valid_number, '山梨県南アルプス市塚原');
ok($zip->set_number('4000500')->is_valid_number, '山梨県南巨摩郡富士川町以下に掲載がない場合');
ok($zip->set_number('4000501')->is_valid_number, '山梨県南巨摩郡富士川町青柳町');
ok($zip->set_number('4000502')->is_valid_number, '山梨県南巨摩郡富士川町最勝寺');
ok($zip->set_number('4000503')->is_valid_number, '山梨県南巨摩郡富士川町天神中條');
ok($zip->set_number('4000504')->is_valid_number, '山梨県南巨摩郡富士川町小林');
ok($zip->set_number('4000505')->is_valid_number, '山梨県南巨摩郡富士川町長澤');
ok($zip->set_number('4000506')->is_valid_number, '山梨県南巨摩郡富士川町大椚');
ok($zip->set_number('4000511')->is_valid_number, '山梨県南巨摩郡富士川町大久保');
ok($zip->set_number('4000512')->is_valid_number, '山梨県南巨摩郡富士川町小室');
ok($zip->set_number('4000513')->is_valid_number, '山梨県南巨摩郡富士川町高下');
ok($zip->set_number('4000514')->is_valid_number, '山梨県南巨摩郡富士川町平林');
ok($zip->set_number('4000515')->is_valid_number, '山梨県南巨摩郡富士川町舂米');
ok($zip->set_number('4000601')->is_valid_number, '山梨県南巨摩郡富士川町鰍沢');
ok($zip->set_number('4000602')->is_valid_number, '山梨県南巨摩郡富士川町駅前通');
ok($zip->set_number('4000603')->is_valid_number, '山梨県南巨摩郡富士川町鹿島');
ok($zip->set_number('4000604')->is_valid_number, '山梨県南巨摩郡富士川町箱原');
ok($zip->set_number('4000605')->is_valid_number, '山梨県南巨摩郡富士川町柳川');
ok($zip->set_number('4000606')->is_valid_number, '山梨県南巨摩郡富士川町十谷');
ok($zip->set_number('4000607')->is_valid_number, '山梨県南巨摩郡富士川町鳥屋');
ok($zip->set_number('4000608')->is_valid_number, '山梨県南巨摩郡富士川町長知沢');
ok($zip->set_number('4000801')->is_valid_number, '山梨県甲府市善光寺町');
ok($zip->set_number('4000802')->is_valid_number, '山梨県甲府市横根町');
ok($zip->set_number('4000803')->is_valid_number, '山梨県甲府市桜井町');
ok($zip->set_number('4000804')->is_valid_number, '山梨県甲府市酒折町');
ok($zip->set_number('4000805')->is_valid_number, '山梨県甲府市酒折');
ok($zip->set_number('4000806')->is_valid_number, '山梨県甲府市善光寺');
ok($zip->set_number('4000807')->is_valid_number, '山梨県甲府市東光寺');
ok($zip->set_number('4000808')->is_valid_number, '山梨県甲府市東光寺町');
ok($zip->set_number('4000811')->is_valid_number, '山梨県甲府市川田町');
ok($zip->set_number('4000812')->is_valid_number, '山梨県甲府市和戸町');
ok($zip->set_number('4000813')->is_valid_number, '山梨県甲府市向町');
ok($zip->set_number('4000814')->is_valid_number, '山梨県甲府市上阿原町');
ok($zip->set_number('4000815')->is_valid_number, '山梨県甲府市国玉町');
ok($zip->set_number('4000821')->is_valid_number, '山梨県甲府市砂田町');
ok($zip->set_number('4000822')->is_valid_number, '山梨県甲府市里吉');
ok($zip->set_number('4000823')->is_valid_number, '山梨県甲府市里吉町');
ok($zip->set_number('4000824')->is_valid_number, '山梨県甲府市蓬沢町');
ok($zip->set_number('4000825')->is_valid_number, '山梨県甲府市七沢町');
ok($zip->set_number('4000826')->is_valid_number, '山梨県甲府市西高橋町');
ok($zip->set_number('4000827')->is_valid_number, '山梨県甲府市蓬沢');
ok($zip->set_number('4000828')->is_valid_number, '山梨県甲府市青葉町');
ok($zip->set_number('4000831')->is_valid_number, '山梨県甲府市上町');
ok($zip->set_number('4000832')->is_valid_number, '山梨県甲府市増坪町');
ok($zip->set_number('4000833')->is_valid_number, '山梨県甲府市西油川町');
ok($zip->set_number('4000834')->is_valid_number, '山梨県甲府市落合町');
ok($zip->set_number('4000835')->is_valid_number, '山梨県甲府市下鍛冶屋町');
ok($zip->set_number('4000836')->is_valid_number, '山梨県甲府市小瀬町');
ok($zip->set_number('4000841')->is_valid_number, '山梨県甲府市小曲町');
ok($zip->set_number('4000842')->is_valid_number, '山梨県甲府市下今井町');
ok($zip->set_number('4000843')->is_valid_number, '山梨県甲府市東下条町');
ok($zip->set_number('4000844')->is_valid_number, '山梨県甲府市中町');
ok($zip->set_number('4000845')->is_valid_number, '山梨県甲府市上今井町');
ok($zip->set_number('4000851')->is_valid_number, '山梨県甲府市住吉');
ok($zip->set_number('4000852')->is_valid_number, '山梨県甲府市住吉本町');
ok($zip->set_number('4000853')->is_valid_number, '山梨県甲府市下小河原町');
ok($zip->set_number('4000854')->is_valid_number, '山梨県甲府市中小河原町');
ok($zip->set_number('4000855')->is_valid_number, '山梨県甲府市中小河原');
ok($zip->set_number('4000856')->is_valid_number, '山梨県甲府市伊勢');
ok($zip->set_number('4000857')->is_valid_number, '山梨県甲府市幸町');
ok($zip->set_number('4000858')->is_valid_number, '山梨県甲府市相生');
ok($zip->set_number('4000861')->is_valid_number, '山梨県甲府市城東');
ok($zip->set_number('4000862')->is_valid_number, '山梨県甲府市朝気');
ok($zip->set_number('4000863')->is_valid_number, '山梨県甲府市南口町');
ok($zip->set_number('4000864')->is_valid_number, '山梨県甲府市湯田');
ok($zip->set_number('4000865')->is_valid_number, '山梨県甲府市太田町');
ok($zip->set_number('4000866')->is_valid_number, '山梨県甲府市若松町');
ok($zip->set_number('4000867')->is_valid_number, '山梨県甲府市青沼');
ok($zip->set_number('4001111')->is_valid_number, '山梨県甲斐市千田');
ok($zip->set_number('4001112')->is_valid_number, '山梨県甲斐市吉沢');
ok($zip->set_number('4001113')->is_valid_number, '山梨県甲斐市亀沢(その他)');
ok($zip->set_number('4001114')->is_valid_number, '山梨県甲斐市打返');
ok($zip->set_number('4001115')->is_valid_number, '山梨県甲斐市漆戸');
ok($zip->set_number('4001116')->is_valid_number, '山梨県甲斐市獅子平');
ok($zip->set_number('4001117')->is_valid_number, '山梨県甲斐市上菅口');
ok($zip->set_number('4001121')->is_valid_number, '山梨県甲斐市上芦沢');
ok($zip->set_number('4001122')->is_valid_number, '山梨県甲斐市下芦沢');
ok($zip->set_number('4001123')->is_valid_number, '山梨県甲斐市上福沢');
ok($zip->set_number('4001124')->is_valid_number, '山梨県甲斐市下福沢');
ok($zip->set_number('4001125')->is_valid_number, '山梨県甲斐市下菅口');
ok($zip->set_number('4001126')->is_valid_number, '山梨県甲斐市安寺');
ok($zip->set_number('4001127')->is_valid_number, '山梨県甲斐市神戸');
ok($zip->set_number('4001131')->is_valid_number, '山梨県甲斐市亀沢(大明神、6949番地)');
ok($zip->set_number('4001211')->is_valid_number, '山梨県甲府市黒平町');
ok($zip->set_number('4001212')->is_valid_number, '山梨県甲府市高町');
ok($zip->set_number('4001213')->is_valid_number, '山梨県甲府市川窪町');
ok($zip->set_number('4001214')->is_valid_number, '山梨県甲府市高成町');
ok($zip->set_number('4001215')->is_valid_number, '山梨県甲府市竹日向町');
ok($zip->set_number('4001216')->is_valid_number, '山梨県甲府市塔岩町');
ok($zip->set_number('4001217')->is_valid_number, '山梨県甲府市猪狩町');
ok($zip->set_number('4001218')->is_valid_number, '山梨県甲府市御岳町');
ok($zip->set_number('4001219')->is_valid_number, '山梨県甲府市草鹿沢町');
ok($zip->set_number('4001501')->is_valid_number, '山梨県甲府市上曽根町');
ok($zip->set_number('4001502')->is_valid_number, '山梨県甲府市白井町');
ok($zip->set_number('4001503')->is_valid_number, '山梨県甲府市心経寺町');
ok($zip->set_number('4001504')->is_valid_number, '山梨県甲府市右左口町');
ok($zip->set_number('4001505')->is_valid_number, '山梨県甲府市中畑町');
ok($zip->set_number('4001506')->is_valid_number, '山梨県甲府市上向山町');
ok($zip->set_number('4001507')->is_valid_number, '山梨県甲府市下向山町');
ok($zip->set_number('4001508')->is_valid_number, '山梨県甲府市下曽根町');
ok($zip->set_number('4001511')->is_valid_number, '山梨県中央市木原');
ok($zip->set_number('4001512')->is_valid_number, '山梨県中央市関原');
ok($zip->set_number('4001513')->is_valid_number, '山梨県中央市大鳥居');
ok($zip->set_number('4001514')->is_valid_number, '山梨県中央市浅利');
ok($zip->set_number('4001515')->is_valid_number, '山梨県中央市高部');
ok($zip->set_number('4010000')->is_valid_number, '山梨県大月市以下に掲載がない場合');
ok($zip->set_number('4010001')->is_valid_number, '山梨県大月市賑岡町畑倉');
ok($zip->set_number('4010002')->is_valid_number, '山梨県大月市賑岡町岩殿');
ok($zip->set_number('4010003')->is_valid_number, '山梨県大月市賑岡町ゆりケ丘');
ok($zip->set_number('4010004')->is_valid_number, '山梨県大月市賑岡町強瀬');
ok($zip->set_number('4010005')->is_valid_number, '山梨県大月市賑岡町浅利');
ok($zip->set_number('4010006')->is_valid_number, '山梨県大月市賑岡町奥山');
ok($zip->set_number('4010011')->is_valid_number, '山梨県大月市駒橋');
ok($zip->set_number('4010012')->is_valid_number, '山梨県大月市御太刀');
ok($zip->set_number('4010013')->is_valid_number, '山梨県大月市大月(1~3丁目)');
ok($zip->set_number('4010014')->is_valid_number, '山梨県大月市大月町大月');
ok($zip->set_number('4010015')->is_valid_number, '山梨県大月市大月町花咲');
ok($zip->set_number('4010016')->is_valid_number, '山梨県大月市大月町真木');
ok($zip->set_number('4010021')->is_valid_number, '山梨県大月市初狩町下初狩');
ok($zip->set_number('4010022')->is_valid_number, '山梨県大月市初狩町中初狩');
ok($zip->set_number('4010023')->is_valid_number, '山梨県大月市笹子町白野');
ok($zip->set_number('4010024')->is_valid_number, '山梨県大月市笹子町吉久保');
ok($zip->set_number('4010025')->is_valid_number, '山梨県大月市笹子町黒野田');
ok($zip->set_number('4010201')->is_valid_number, '山梨県上野原市秋山');
ok($zip->set_number('4010300')->is_valid_number, '山梨県南都留郡富士河口湖町以下に掲載がない場合');
ok($zip->set_number('4010301')->is_valid_number, '山梨県南都留郡富士河口湖町船津');
ok($zip->set_number('4010302')->is_valid_number, '山梨県南都留郡富士河口湖町小立');
ok($zip->set_number('4010303')->is_valid_number, '山梨県南都留郡富士河口湖町浅川');
ok($zip->set_number('4010304')->is_valid_number, '山梨県南都留郡富士河口湖町河口');
ok($zip->set_number('4010305')->is_valid_number, '山梨県南都留郡富士河口湖町大石');
ok($zip->set_number('4010310')->is_valid_number, '山梨県南都留郡富士河口湖町勝山');
ok($zip->set_number('4010320')->is_valid_number, '山梨県南都留郡鳴沢村鳴沢村一円');
ok($zip->set_number('4010331')->is_valid_number, '山梨県南都留郡富士河口湖町長浜');
ok($zip->set_number('4010332')->is_valid_number, '山梨県南都留郡富士河口湖町西湖');
ok($zip->set_number('4010333')->is_valid_number, '山梨県南都留郡富士河口湖町西湖西');
ok($zip->set_number('4010334')->is_valid_number, '山梨県南都留郡富士河口湖町西湖南');
ok($zip->set_number('4010335')->is_valid_number, '山梨県南都留郡富士河口湖町大嵐');
ok($zip->set_number('4010336')->is_valid_number, '山梨県南都留郡富士河口湖町精進');
ok($zip->set_number('4010337')->is_valid_number, '山梨県南都留郡富士河口湖町本栖');
ok($zip->set_number('4010338')->is_valid_number, '山梨県南都留郡富士河口湖町富士ケ嶺');
ok($zip->set_number('4010500')->is_valid_number, '山梨県南都留郡忍野村以下に掲載がない場合');
ok($zip->set_number('4010500')->is_valid_number, '山梨県南都留郡山中湖村以下に掲載がない場合');
ok($zip->set_number('4010501')->is_valid_number, '山梨県南都留郡山中湖村山中');
ok($zip->set_number('4010502')->is_valid_number, '山梨県南都留郡山中湖村平野');
ok($zip->set_number('4010511')->is_valid_number, '山梨県南都留郡忍野村忍草');
ok($zip->set_number('4010512')->is_valid_number, '山梨県南都留郡忍野村内野');
ok($zip->set_number('4020000')->is_valid_number, '山梨県都留市以下に掲載がない場合');
ok($zip->set_number('4020001')->is_valid_number, '山梨県都留市田野倉');
ok($zip->set_number('4020002')->is_valid_number, '山梨県都留市大原');
ok($zip->set_number('4020003')->is_valid_number, '山梨県都留市川茂');
ok($zip->set_number('4020004')->is_valid_number, '山梨県都留市古川渡');
ok($zip->set_number('4020005')->is_valid_number, '山梨県都留市四日市場');
ok($zip->set_number('4020006')->is_valid_number, '山梨県都留市小形山');
ok($zip->set_number('4020011')->is_valid_number, '山梨県都留市井倉');
ok($zip->set_number('4020012')->is_valid_number, '山梨県都留市与縄');
ok($zip->set_number('4020013')->is_valid_number, '山梨県都留市盛里');
ok($zip->set_number('4020014')->is_valid_number, '山梨県都留市朝日馬場');
ok($zip->set_number('4020015')->is_valid_number, '山梨県都留市朝日曽雌');
ok($zip->set_number('4020021')->is_valid_number, '山梨県都留市玉川');
ok($zip->set_number('4020022')->is_valid_number, '山梨県都留市戸沢');
ok($zip->set_number('4020023')->is_valid_number, '山梨県都留市大野');
ok($zip->set_number('4020024')->is_valid_number, '山梨県都留市小野');
ok($zip->set_number('4020025')->is_valid_number, '山梨県都留市法能');
ok($zip->set_number('4020031')->is_valid_number, '山梨県都留市十日市場');
ok($zip->set_number('4020032')->is_valid_number, '山梨県都留市鹿留');
ok($zip->set_number('4020033')->is_valid_number, '山梨県都留市境');
ok($zip->set_number('4020034')->is_valid_number, '山梨県都留市桂町');
ok($zip->set_number('4020035')->is_valid_number, '山梨県都留市夏狩');
ok($zip->set_number('4020041')->is_valid_number, '山梨県都留市金井');
ok($zip->set_number('4020042')->is_valid_number, '山梨県都留市厚原');
ok($zip->set_number('4020043')->is_valid_number, '山梨県都留市平栗');
ok($zip->set_number('4020044')->is_valid_number, '山梨県都留市加畑');
ok($zip->set_number('4020045')->is_valid_number, '山梨県都留市大幡');
ok($zip->set_number('4020046')->is_valid_number, '山梨県都留市中津森');
ok($zip->set_number('4020051')->is_valid_number, '山梨県都留市下谷');
ok($zip->set_number('4020052')->is_valid_number, '山梨県都留市中央');
ok($zip->set_number('4020053')->is_valid_number, '山梨県都留市上谷');
ok($zip->set_number('4020054')->is_valid_number, '山梨県都留市田原');
ok($zip->set_number('4020055')->is_valid_number, '山梨県都留市川棚');
ok($zip->set_number('4020056')->is_valid_number, '山梨県都留市つる');
ok($zip->set_number('4020200')->is_valid_number, '山梨県南都留郡道志村以下に掲載がない場合');
ok($zip->set_number('4020201')->is_valid_number, '山梨県南都留郡道志村月夜野');
ok($zip->set_number('4020202')->is_valid_number, '山梨県南都留郡道志村大野');
ok($zip->set_number('4020203')->is_valid_number, '山梨県南都留郡道志村久保');
ok($zip->set_number('4020204')->is_valid_number, '山梨県南都留郡道志村大室指');
ok($zip->set_number('4020205')->is_valid_number, '山梨県南都留郡道志村椿');
ok($zip->set_number('4020206')->is_valid_number, '山梨県南都留郡道志村小善地');
ok($zip->set_number('4020207')->is_valid_number, '山梨県南都留郡道志村大栗');
ok($zip->set_number('4020208')->is_valid_number, '山梨県南都留郡道志村馬場');
ok($zip->set_number('4020209')->is_valid_number, '山梨県南都留郡道志村竹之本');
ok($zip->set_number('4020211')->is_valid_number, '山梨県南都留郡道志村東和出村');
ok($zip->set_number('4020212')->is_valid_number, '山梨県南都留郡道志村西和出村');
ok($zip->set_number('4020213')->is_valid_number, '山梨県南都留郡道志村谷相');
ok($zip->set_number('4020214')->is_valid_number, '山梨県南都留郡道志村川原畑');
ok($zip->set_number('4020215')->is_valid_number, '山梨県南都留郡道志村大指');
ok($zip->set_number('4020216')->is_valid_number, '山梨県南都留郡道志村釜之前');
ok($zip->set_number('4020217')->is_valid_number, '山梨県南都留郡道志村東神地');
ok($zip->set_number('4020218')->is_valid_number, '山梨県南都留郡道志村中神地');
ok($zip->set_number('4020219')->is_valid_number, '山梨県南都留郡道志村下中山');
ok($zip->set_number('4020221')->is_valid_number, '山梨県南都留郡道志村上中山');
ok($zip->set_number('4020222')->is_valid_number, '山梨県南都留郡道志村下善之木');
ok($zip->set_number('4020223')->is_valid_number, '山梨県南都留郡道志村上善之木');
ok($zip->set_number('4020224')->is_valid_number, '山梨県南都留郡道志村川村');
ok($zip->set_number('4020225')->is_valid_number, '山梨県南都留郡道志村板橋');
ok($zip->set_number('4020226')->is_valid_number, '山梨県南都留郡道志村下白井平');
ok($zip->set_number('4020227')->is_valid_number, '山梨県南都留郡道志村上白井平');
ok($zip->set_number('4020228')->is_valid_number, '山梨県南都留郡道志村長又');
ok($zip->set_number('4030000')->is_valid_number, '山梨県富士吉田市以下に掲載がない場合');
ok($zip->set_number('4030000')->is_valid_number, '山梨県南都留郡西桂町以下に掲載がない場合');
ok($zip->set_number('4030001')->is_valid_number, '山梨県富士吉田市上暮地');
ok($zip->set_number('4030002')->is_valid_number, '山梨県富士吉田市小明見');
ok($zip->set_number('4030003')->is_valid_number, '山梨県富士吉田市大明見');
ok($zip->set_number('4030004')->is_valid_number, '山梨県富士吉田市下吉田');
ok($zip->set_number('4030005')->is_valid_number, '山梨県富士吉田市上吉田');
ok($zip->set_number('4030006')->is_valid_number, '山梨県富士吉田市新屋');
ok($zip->set_number('4030007')->is_valid_number, '山梨県富士吉田市中曽根');
ok($zip->set_number('4030008')->is_valid_number, '山梨県富士吉田市下吉田東');
ok($zip->set_number('4030009')->is_valid_number, '山梨県富士吉田市富士見');
ok($zip->set_number('4030011')->is_valid_number, '山梨県富士吉田市新倉');
ok($zip->set_number('4030012')->is_valid_number, '山梨県富士吉田市旭');
ok($zip->set_number('4030013')->is_valid_number, '山梨県富士吉田市緑ケ丘');
ok($zip->set_number('4030014')->is_valid_number, '山梨県富士吉田市竜ケ丘');
ok($zip->set_number('4030015')->is_valid_number, '山梨県富士吉田市ときわ台');
ok($zip->set_number('4030016')->is_valid_number, '山梨県富士吉田市松山');
ok($zip->set_number('4030017')->is_valid_number, '山梨県富士吉田市新西原');
ok($zip->set_number('4030018')->is_valid_number, '山梨県富士吉田市向原');
ok($zip->set_number('4030019')->is_valid_number, '山梨県富士吉田市新町');
ok($zip->set_number('4030021')->is_valid_number, '山梨県南都留郡西桂町下暮地');
ok($zip->set_number('4030022')->is_valid_number, '山梨県南都留郡西桂町小沼');
ok($zip->set_number('4030023')->is_valid_number, '山梨県南都留郡西桂町倉見');
ok($zip->set_number('4030031')->is_valid_number, '山梨県富士吉田市浅間');
ok($zip->set_number('4030032')->is_valid_number, '山梨県富士吉田市上吉田東');
ok($zip->set_number('4040000')->is_valid_number, '山梨県甲州市以下に掲載がない場合');
ok($zip->set_number('4040001')->is_valid_number, '山梨県山梨市牧丘町柳平');
ok($zip->set_number('4040002')->is_valid_number, '山梨県山梨市牧丘町杣口');
ok($zip->set_number('4040003')->is_valid_number, '山梨県山梨市牧丘町倉科');
ok($zip->set_number('4040004')->is_valid_number, '山梨県山梨市牧丘町西保下');
ok($zip->set_number('4040005')->is_valid_number, '山梨県山梨市牧丘町西保中');
ok($zip->set_number('4040006')->is_valid_number, '山梨県山梨市牧丘町牧平');
ok($zip->set_number('4040007')->is_valid_number, '山梨県山梨市牧丘町北原');
ok($zip->set_number('4040011')->is_valid_number, '山梨県山梨市牧丘町成沢');
ok($zip->set_number('4040012')->is_valid_number, '山梨県山梨市牧丘町室伏');
ok($zip->set_number('4040013')->is_valid_number, '山梨県山梨市牧丘町窪平');
ok($zip->set_number('4040014')->is_valid_number, '山梨県山梨市牧丘町隼');
ok($zip->set_number('4040015')->is_valid_number, '山梨県山梨市牧丘町城古寺');
ok($zip->set_number('4040016')->is_valid_number, '山梨県山梨市牧丘町千野々宮');
ok($zip->set_number('4040021')->is_valid_number, '山梨県甲州市塩山一之瀬高橋');
ok($zip->set_number('4040022')->is_valid_number, '山梨県甲州市塩山上萩原(その他)');
ok($zip->set_number('4040023')->is_valid_number, '山梨県甲州市塩山中萩原(その他)');
ok($zip->set_number('4040024')->is_valid_number, '山梨県甲州市塩山下萩原');
ok($zip->set_number('4040025')->is_valid_number, '山梨県甲州市塩山下小田原');
ok($zip->set_number('4040026')->is_valid_number, '山梨県甲州市塩山上小田原');
ok($zip->set_number('4040031')->is_valid_number, '山梨県甲州市塩山上粟生野');
ok($zip->set_number('4040032')->is_valid_number, '山梨県甲州市塩山下粟生野');
ok($zip->set_number('4040033')->is_valid_number, '山梨県甲州市塩山赤尾');
ok($zip->set_number('4040034')->is_valid_number, '山梨県甲州市塩山牛奥(その他)');
ok($zip->set_number('4040035')->is_valid_number, '山梨県甲州市塩山西野原');
ok($zip->set_number('4040036')->is_valid_number, '山梨県甲州市塩山熊野');
ok($zip->set_number('4040037')->is_valid_number, '山梨県甲州市塩山西広門田');
ok($zip->set_number('4040041')->is_valid_number, '山梨県甲州市塩山千野');
ok($zip->set_number('4040042')->is_valid_number, '山梨県甲州市塩山上於曽');
ok($zip->set_number('4040043')->is_valid_number, '山梨県甲州市塩山下於曽');
ok($zip->set_number('4040044')->is_valid_number, '山梨県甲州市塩山下塩後');
ok($zip->set_number('4040045')->is_valid_number, '山梨県甲州市塩山上塩後');
ok($zip->set_number('4040046')->is_valid_number, '山梨県甲州市塩山上井尻');
ok($zip->set_number('4040047')->is_valid_number, '山梨県甲州市塩山三日市場');
ok($zip->set_number('4040051')->is_valid_number, '山梨県甲州市塩山竹森');
ok($zip->set_number('4040052')->is_valid_number, '山梨県甲州市塩山平沢');
ok($zip->set_number('4040053')->is_valid_number, '山梨県甲州市塩山小屋敷(その他)');
ok($zip->set_number('4040054')->is_valid_number, '山梨県甲州市塩山藤木');
ok($zip->set_number('4040055')->is_valid_number, '山梨県甲州市塩山下柚木');
ok($zip->set_number('4040056')->is_valid_number, '山梨県甲州市塩山福生里');
ok($zip->set_number('4040201')->is_valid_number, '山梨県山梨市三富川浦');
ok($zip->set_number('4040202')->is_valid_number, '山梨県山梨市三富上柚木');
ok($zip->set_number('4040203')->is_valid_number, '山梨県山梨市三富下荻原');
ok($zip->set_number('4040204')->is_valid_number, '山梨県山梨市三富下釜口');
ok($zip->set_number('4040205')->is_valid_number, '山梨県山梨市三富徳和');
ok($zip->set_number('4040206')->is_valid_number, '山梨県山梨市三富上釜口');
ok($zip->set_number('4040211')->is_valid_number, '山梨県甲州市塩山小屋敷(滑沢)');
ok($zip->set_number('4050000')->is_valid_number, '山梨県山梨市以下に掲載がない場合');
ok($zip->set_number('4050001')->is_valid_number, '山梨県山梨市西');
ok($zip->set_number('4050002')->is_valid_number, '山梨県山梨市東');
ok($zip->set_number('4050003')->is_valid_number, '山梨県山梨市下井尻');
ok($zip->set_number('4050004')->is_valid_number, '山梨県山梨市上之割');
ok($zip->set_number('4050005')->is_valid_number, '山梨県山梨市小原東');
ok($zip->set_number('4050006')->is_valid_number, '山梨県山梨市小原西');
ok($zip->set_number('4050007')->is_valid_number, '山梨県山梨市七日市場');
ok($zip->set_number('4050011')->is_valid_number, '山梨県山梨市三ケ所');
ok($zip->set_number('4050012')->is_valid_number, '山梨県山梨市東後屋敷');
ok($zip->set_number('4050013')->is_valid_number, '山梨県山梨市鴨居寺');
ok($zip->set_number('4050014')->is_valid_number, '山梨県山梨市上石森');
ok($zip->set_number('4050015')->is_valid_number, '山梨県山梨市下石森');
ok($zip->set_number('4050016')->is_valid_number, '山梨県山梨市大野');
ok($zip->set_number('4050017')->is_valid_number, '山梨県山梨市下神内川');
ok($zip->set_number('4050018')->is_valid_number, '山梨県山梨市上神内川');
ok($zip->set_number('4050021')->is_valid_number, '山梨県山梨市中村');
ok($zip->set_number('4050022')->is_valid_number, '山梨県山梨市上栗原');
ok($zip->set_number('4050023')->is_valid_number, '山梨県山梨市下栗原');
ok($zip->set_number('4050024')->is_valid_number, '山梨県山梨市歌田');
ok($zip->set_number('4050025')->is_valid_number, '山梨県山梨市一町田中');
ok($zip->set_number('4050031')->is_valid_number, '山梨県山梨市万力');
ok($zip->set_number('4050032')->is_valid_number, '山梨県山梨市正徳寺');
ok($zip->set_number('4050033')->is_valid_number, '山梨県山梨市落合');
ok($zip->set_number('4050034')->is_valid_number, '山梨県山梨市上岩下');
ok($zip->set_number('4050035')->is_valid_number, '山梨県山梨市山根');
ok($zip->set_number('4050036')->is_valid_number, '山梨県山梨市矢坪');
ok($zip->set_number('4050041')->is_valid_number, '山梨県山梨市北');
ok($zip->set_number('4050042')->is_valid_number, '山梨県山梨市南');
ok($zip->set_number('4050043')->is_valid_number, '山梨県山梨市江曽原');
ok($zip->set_number('4050044')->is_valid_number, '山梨県山梨市市川');
ok($zip->set_number('4050045')->is_valid_number, '山梨県山梨市大工');
ok($zip->set_number('4050046')->is_valid_number, '山梨県山梨市堀内');
ok($zip->set_number('4050047')->is_valid_number, '山梨県山梨市水口');
ok($zip->set_number('4050048')->is_valid_number, '山梨県山梨市切差');
ok($zip->set_number('4050051')->is_valid_number, '山梨県笛吹市一宮町北野呂');
ok($zip->set_number('4050052')->is_valid_number, '山梨県笛吹市一宮町南野呂');
ok($zip->set_number('4050053')->is_valid_number, '山梨県笛吹市一宮町中尾');
ok($zip->set_number('4050054')->is_valid_number, '山梨県笛吹市一宮町千米寺');
ok($zip->set_number('4050055')->is_valid_number, '山梨県笛吹市一宮町地蔵堂');
ok($zip->set_number('4050056')->is_valid_number, '山梨県笛吹市一宮町一ノ宮');
ok($zip->set_number('4050057')->is_valid_number, '山梨県笛吹市一宮町下矢作');
ok($zip->set_number('4050058')->is_valid_number, '山梨県笛吹市一宮町小城');
ok($zip->set_number('4050059')->is_valid_number, '山梨県笛吹市一宮町上矢作');
ok($zip->set_number('4050061')->is_valid_number, '山梨県笛吹市一宮町石');
ok($zip->set_number('4050062')->is_valid_number, '山梨県笛吹市一宮町金沢');
ok($zip->set_number('4050063')->is_valid_number, '山梨県笛吹市一宮町市之蔵');
ok($zip->set_number('4050064')->is_valid_number, '山梨県笛吹市一宮町塩田');
ok($zip->set_number('4050065')->is_valid_number, '山梨県笛吹市一宮町新巻');
ok($zip->set_number('4050066')->is_valid_number, '山梨県笛吹市一宮町神沢');
ok($zip->set_number('4050067')->is_valid_number, '山梨県笛吹市一宮町土塚');
ok($zip->set_number('4050068')->is_valid_number, '山梨県笛吹市一宮町狐新居');
ok($zip->set_number('4050069')->is_valid_number, '山梨県笛吹市一宮町東新居');
ok($zip->set_number('4050071')->is_valid_number, '山梨県笛吹市一宮町北都塚');
ok($zip->set_number('4050072')->is_valid_number, '山梨県笛吹市一宮町本都塚');
ok($zip->set_number('4050073')->is_valid_number, '山梨県笛吹市一宮町末木');
ok($zip->set_number('4050074')->is_valid_number, '山梨県笛吹市一宮町国分');
ok($zip->set_number('4050075')->is_valid_number, '山梨県笛吹市一宮町橋立');
ok($zip->set_number('4050075')->is_valid_number, '山梨県笛吹市一宮町東原');
ok($zip->set_number('4050076')->is_valid_number, '山梨県笛吹市一宮町竹原田');
ok($zip->set_number('4050077')->is_valid_number, '山梨県笛吹市一宮町坪井');
ok($zip->set_number('4050078')->is_valid_number, '山梨県笛吹市一宮町田中');
ok($zip->set_number('4050079')->is_valid_number, '山梨県笛吹市一宮町金田');
ok($zip->set_number('4060000')->is_valid_number, '山梨県笛吹市以下に掲載がない場合');
ok($zip->set_number('4060001')->is_valid_number, '山梨県笛吹市春日居町下岩下');
ok($zip->set_number('4060002')->is_valid_number, '山梨県笛吹市春日居町別田');
ok($zip->set_number('4060003')->is_valid_number, '山梨県笛吹市春日居町桑戸');
ok($zip->set_number('4060004')->is_valid_number, '山梨県笛吹市春日居町小松');
ok($zip->set_number('4060005')->is_valid_number, '山梨県笛吹市春日居町加茂');
ok($zip->set_number('4060011')->is_valid_number, '山梨県笛吹市春日居町徳条');
ok($zip->set_number('4060012')->is_valid_number, '山梨県笛吹市春日居町熊野堂');
ok($zip->set_number('4060013')->is_valid_number, '山梨県笛吹市春日居町寺本');
ok($zip->set_number('4060014')->is_valid_number, '山梨県笛吹市春日居町国府');
ok($zip->set_number('4060015')->is_valid_number, '山梨県笛吹市春日居町鎮目');
ok($zip->set_number('4060021')->is_valid_number, '山梨県笛吹市石和町松本');
ok($zip->set_number('4060022')->is_valid_number, '山梨県笛吹市石和町山崎');
ok($zip->set_number('4060023')->is_valid_number, '山梨県笛吹市石和町八田');
ok($zip->set_number('4060024')->is_valid_number, '山梨県笛吹市石和町川中島');
ok($zip->set_number('4060025')->is_valid_number, '山梨県笛吹市石和町上平井');
ok($zip->set_number('4060026')->is_valid_number, '山梨県笛吹市石和町中川');
ok($zip->set_number('4060027')->is_valid_number, '山梨県笛吹市石和町下平井');
ok($zip->set_number('4060028')->is_valid_number, '山梨県笛吹市石和町駅前');
ok($zip->set_number('4060031')->is_valid_number, '山梨県笛吹市石和町市部');
ok($zip->set_number('4060032')->is_valid_number, '山梨県笛吹市石和町四日市場');
ok($zip->set_number('4060033')->is_valid_number, '山梨県笛吹市石和町小石和');
ok($zip->set_number('4060034')->is_valid_number, '山梨県笛吹市石和町唐柏');
ok($zip->set_number('4060035')->is_valid_number, '山梨県笛吹市石和町広瀬');
ok($zip->set_number('4060036')->is_valid_number, '山梨県笛吹市石和町窪中島');
ok($zip->set_number('4060041')->is_valid_number, '山梨県笛吹市石和町東高橋');
ok($zip->set_number('4060042')->is_valid_number, '山梨県笛吹市石和町今井');
ok($zip->set_number('4060043')->is_valid_number, '山梨県笛吹市石和町河内');
ok($zip->set_number('4060044')->is_valid_number, '山梨県笛吹市石和町砂原');
ok($zip->set_number('4060045')->is_valid_number, '山梨県笛吹市石和町井戸');
ok($zip->set_number('4060046')->is_valid_number, '山梨県笛吹市石和町東油川');
ok($zip->set_number('4060801')->is_valid_number, '山梨県笛吹市御坂町成田');
ok($zip->set_number('4060802')->is_valid_number, '山梨県笛吹市御坂町金川原');
ok($zip->set_number('4060803')->is_valid_number, '山梨県笛吹市御坂町井之上');
ok($zip->set_number('4060804')->is_valid_number, '山梨県笛吹市御坂町夏目原');
ok($zip->set_number('4060805')->is_valid_number, '山梨県笛吹市御坂町栗合');
ok($zip->set_number('4060806')->is_valid_number, '山梨県笛吹市御坂町八千蔵');
ok($zip->set_number('4060807')->is_valid_number, '山梨県笛吹市御坂町二之宮');
ok($zip->set_number('4060808')->is_valid_number, '山梨県笛吹市御坂町国衙');
ok($zip->set_number('4060811')->is_valid_number, '山梨県笛吹市御坂町下野原');
ok($zip->set_number('4060812')->is_valid_number, '山梨県笛吹市御坂町下黒駒');
ok($zip->set_number('4060813')->is_valid_number, '山梨県笛吹市御坂町上黒駒');
ok($zip->set_number('4060814')->is_valid_number, '山梨県笛吹市御坂町藤野木');
ok($zip->set_number('4060815')->is_valid_number, '山梨県笛吹市御坂町尾山');
ok($zip->set_number('4060816')->is_valid_number, '山梨県笛吹市御坂町竹居');
ok($zip->set_number('4060817')->is_valid_number, '山梨県笛吹市御坂町大野寺');
ok($zip->set_number('4060818')->is_valid_number, '山梨県笛吹市御坂町蕎麦塚');
ok($zip->set_number('4060821')->is_valid_number, '山梨県笛吹市八代町北');
ok($zip->set_number('4060822')->is_valid_number, '山梨県笛吹市八代町南');
ok($zip->set_number('4060823')->is_valid_number, '山梨県笛吹市八代町永井');
ok($zip->set_number('4060824')->is_valid_number, '山梨県笛吹市八代町増利');
ok($zip->set_number('4060825')->is_valid_number, '山梨県笛吹市八代町大間田');
ok($zip->set_number('4060831')->is_valid_number, '山梨県笛吹市八代町高家');
ok($zip->set_number('4060832')->is_valid_number, '山梨県笛吹市八代町竹居');
ok($zip->set_number('4060833')->is_valid_number, '山梨県笛吹市八代町奈良原');
ok($zip->set_number('4060834')->is_valid_number, '山梨県笛吹市八代町岡');
ok($zip->set_number('4060835')->is_valid_number, '山梨県笛吹市八代町米倉');
ok($zip->set_number('4060841')->is_valid_number, '山梨県笛吹市境川町大坪');
ok($zip->set_number('4060842')->is_valid_number, '山梨県笛吹市境川町石橋');
ok($zip->set_number('4060843')->is_valid_number, '山梨県笛吹市境川町前間田');
ok($zip->set_number('4060844')->is_valid_number, '山梨県笛吹市境川町小山');
ok($zip->set_number('4060845')->is_valid_number, '山梨県笛吹市境川町坊ケ峰');
ok($zip->set_number('4060846')->is_valid_number, '山梨県笛吹市境川町三椚');
ok($zip->set_number('4060851')->is_valid_number, '山梨県笛吹市境川町小黒坂');
ok($zip->set_number('4060852')->is_valid_number, '山梨県笛吹市境川町大黒坂');
ok($zip->set_number('4060853')->is_valid_number, '山梨県笛吹市境川町藤垈');
ok($zip->set_number('4060854')->is_valid_number, '山梨県笛吹市境川町寺尾');
ok($zip->set_number('4060855')->is_valid_number, '山梨県笛吹市境川町大窪');
ok($zip->set_number('4070000')->is_valid_number, '山梨県韮崎市以下に掲載がない場合');
ok($zip->set_number('4070001')->is_valid_number, '山梨県韮崎市藤井町駒井');
ok($zip->set_number('4070002')->is_valid_number, '山梨県韮崎市藤井町坂井');
ok($zip->set_number('4070003')->is_valid_number, '山梨県韮崎市藤井町北下條');
ok($zip->set_number('4070004')->is_valid_number, '山梨県韮崎市藤井町南下條');
ok($zip->set_number('4070005')->is_valid_number, '山梨県韮崎市一ツ谷');
ok($zip->set_number('4070006')->is_valid_number, '山梨県韮崎市下祖母石');
ok($zip->set_number('4070007')->is_valid_number, '山梨県韮崎市上祖母石');
ok($zip->set_number('4070011')->is_valid_number, '山梨県韮崎市上ノ山');
ok($zip->set_number('4070012')->is_valid_number, '山梨県韮崎市岩下');
ok($zip->set_number('4070013')->is_valid_number, '山梨県韮崎市中島');
ok($zip->set_number('4070014')->is_valid_number, '山梨県韮崎市富士見');
ok($zip->set_number('4070015')->is_valid_number, '山梨県韮崎市若宮');
ok($zip->set_number('4070021')->is_valid_number, '山梨県韮崎市富士見ケ丘');
ok($zip->set_number('4070022')->is_valid_number, '山梨県韮崎市水神');
ok($zip->set_number('4070023')->is_valid_number, '山梨県韮崎市中央町');
ok($zip->set_number('4070024')->is_valid_number, '山梨県韮崎市本町');
ok($zip->set_number('4070025')->is_valid_number, '山梨県韮崎市栄');
ok($zip->set_number('4070031')->is_valid_number, '山梨県韮崎市龍岡町若尾新田');
ok($zip->set_number('4070032')->is_valid_number, '山梨県韮崎市龍岡町下條東割');
ok($zip->set_number('4070033')->is_valid_number, '山梨県韮崎市龍岡町下條南割');
ok($zip->set_number('4070034')->is_valid_number, '山梨県韮崎市大草町下條中割');
ok($zip->set_number('4070035')->is_valid_number, '山梨県韮崎市大草町下條西割');
ok($zip->set_number('4070036')->is_valid_number, '山梨県韮崎市大草町上條東割');
ok($zip->set_number('4070037')->is_valid_number, '山梨県韮崎市大草町若尾');
ok($zip->set_number('4070041')->is_valid_number, '山梨県韮崎市神山町武田');
ok($zip->set_number('4070042')->is_valid_number, '山梨県韮崎市神山町北宮地');
ok($zip->set_number('4070043')->is_valid_number, '山梨県韮崎市神山町鍋山');
ok($zip->set_number('4070044')->is_valid_number, '山梨県韮崎市旭町上條北割');
ok($zip->set_number('4070045')->is_valid_number, '山梨県韮崎市旭町上條中割');
ok($zip->set_number('4070046')->is_valid_number, '山梨県韮崎市旭町上條南割');
ok($zip->set_number('4070051')->is_valid_number, '山梨県韮崎市円野町上円井');
ok($zip->set_number('4070052')->is_valid_number, '山梨県韮崎市円野町下円井');
ok($zip->set_number('4070053')->is_valid_number, '山梨県韮崎市円野町入戸野');
ok($zip->set_number('4070054')->is_valid_number, '山梨県韮崎市清哲町折居');
ok($zip->set_number('4070055')->is_valid_number, '山梨県韮崎市清哲町青木');
ok($zip->set_number('4070057')->is_valid_number, '山梨県韮崎市清哲町樋口');
ok($zip->set_number('4070058')->is_valid_number, '山梨県韮崎市清哲町水上');
ok($zip->set_number('4070171')->is_valid_number, '山梨県韮崎市穂坂町柳平');
ok($zip->set_number('4070172')->is_valid_number, '山梨県韮崎市穂坂町上今井');
ok($zip->set_number('4070173')->is_valid_number, '山梨県韮崎市穂坂町長久保');
ok($zip->set_number('4070174')->is_valid_number, '山梨県韮崎市穂坂町三ツ沢');
ok($zip->set_number('4070175')->is_valid_number, '山梨県韮崎市穂坂町宮久保');
ok($zip->set_number('4070176')->is_valid_number, '山梨県韮崎市穂坂町三之蔵');
ok($zip->set_number('4070261')->is_valid_number, '山梨県韮崎市中田町小田川');
ok($zip->set_number('4070262')->is_valid_number, '山梨県韮崎市中田町中條');
ok($zip->set_number('4070263')->is_valid_number, '山梨県韮崎市穴山町');
ok($zip->set_number('4070301')->is_valid_number, '山梨県北杜市高根町清里');
ok($zip->set_number('4070302')->is_valid_number, '山梨県北杜市高根町浅川');
ok($zip->set_number('4070311')->is_valid_number, '山梨県北杜市大泉町西井出8240-1(美森、たかね荘、清泉寮、サンメドウズスキー場)');
ok($zip->set_number('4070321')->is_valid_number, '山梨県北杜市須玉町上津金');
ok($zip->set_number('4070322')->is_valid_number, '山梨県北杜市須玉町下津金');
ok($zip->set_number('4080000')->is_valid_number, '山梨県北杜市以下に掲載がない場合');
ok($zip->set_number('4080001')->is_valid_number, '山梨県北杜市高根町長沢');
ok($zip->set_number('4080002')->is_valid_number, '山梨県北杜市高根町村山北割');
ok($zip->set_number('4080003')->is_valid_number, '山梨県北杜市高根町東井出');
ok($zip->set_number('4080004')->is_valid_number, '山梨県北杜市高根町堤');
ok($zip->set_number('4080011')->is_valid_number, '山梨県北杜市高根町箕輪新町');
ok($zip->set_number('4080012')->is_valid_number, '山梨県北杜市高根町箕輪');
ok($zip->set_number('4080013')->is_valid_number, '山梨県北杜市高根町蔵原');
ok($zip->set_number('4080014')->is_valid_number, '山梨県北杜市高根町小池');
ok($zip->set_number('4080015')->is_valid_number, '山梨県北杜市高根町下黒澤');
ok($zip->set_number('4080016')->is_valid_number, '山梨県北杜市高根町上黒澤');
ok($zip->set_number('4080017')->is_valid_number, '山梨県北杜市高根町五町田');
ok($zip->set_number('4080018')->is_valid_number, '山梨県北杜市高根町村山西割');
ok($zip->set_number('4080019')->is_valid_number, '山梨県北杜市高根町村山東割');
ok($zip->set_number('4080021')->is_valid_number, '山梨県北杜市長坂町長坂上条');
ok($zip->set_number('4080022')->is_valid_number, '山梨県北杜市長坂町塚川');
ok($zip->set_number('4080023')->is_valid_number, '山梨県北杜市長坂町渋沢');
ok($zip->set_number('4080024')->is_valid_number, '山梨県北杜市長坂町富岡');
ok($zip->set_number('4080025')->is_valid_number, '山梨県北杜市長坂町長坂下条');
ok($zip->set_number('4080026')->is_valid_number, '山梨県北杜市長坂町日野');
ok($zip->set_number('4080031')->is_valid_number, '山梨県北杜市長坂町小荒間');
ok($zip->set_number('4080032')->is_valid_number, '山梨県北杜市長坂町大井ケ森');
ok($zip->set_number('4080033')->is_valid_number, '山梨県北杜市長坂町白井沢');
ok($zip->set_number('4080034')->is_valid_number, '山梨県北杜市長坂町大八田');
ok($zip->set_number('4080035')->is_valid_number, '山梨県北杜市長坂町夏秋');
ok($zip->set_number('4080036')->is_valid_number, '山梨県北杜市長坂町中丸');
ok($zip->set_number('4080037')->is_valid_number, '山梨県北杜市長坂町中島');
ok($zip->set_number('4080041')->is_valid_number, '山梨県北杜市小淵沢町上笹尾');
ok($zip->set_number('4080042')->is_valid_number, '山梨県北杜市小淵沢町松向');
ok($zip->set_number('4080043')->is_valid_number, '山梨県北杜市小淵沢町下笹尾');
ok($zip->set_number('4080044')->is_valid_number, '山梨県北杜市小淵沢町');
ok($zip->set_number('4080101')->is_valid_number, '山梨県北杜市須玉町小尾');
ok($zip->set_number('4080102')->is_valid_number, '山梨県北杜市須玉町比志');
ok($zip->set_number('4080103')->is_valid_number, '山梨県北杜市須玉町江草');
ok($zip->set_number('4080104')->is_valid_number, '山梨県北杜市須玉町小倉');
ok($zip->set_number('4080105')->is_valid_number, '山梨県北杜市須玉町東向');
ok($zip->set_number('4080111')->is_valid_number, '山梨県北杜市須玉町穴平');
ok($zip->set_number('4080112')->is_valid_number, '山梨県北杜市須玉町若神子');
ok($zip->set_number('4080113')->is_valid_number, '山梨県北杜市須玉町大蔵');
ok($zip->set_number('4080114')->is_valid_number, '山梨県北杜市須玉町藤田');
ok($zip->set_number('4080115')->is_valid_number, '山梨県北杜市須玉町大豆生田');
ok($zip->set_number('4080116')->is_valid_number, '山梨県北杜市須玉町境之澤');
ok($zip->set_number('4080117')->is_valid_number, '山梨県北杜市須玉町若神子新町');
ok($zip->set_number('4080201')->is_valid_number, '山梨県北杜市明野町浅尾');
ok($zip->set_number('4080202')->is_valid_number, '山梨県北杜市明野町小笠原');
ok($zip->set_number('4080203')->is_valid_number, '山梨県北杜市明野町三之蔵');
ok($zip->set_number('4080204')->is_valid_number, '山梨県北杜市明野町上手');
ok($zip->set_number('4080205')->is_valid_number, '山梨県北杜市明野町浅尾新田');
ok($zip->set_number('4080206')->is_valid_number, '山梨県北杜市明野町下神取');
ok($zip->set_number('4080207')->is_valid_number, '山梨県北杜市明野町上神取');
ok($zip->set_number('4080301')->is_valid_number, '山梨県北杜市武川町三吹');
ok($zip->set_number('4080302')->is_valid_number, '山梨県北杜市武川町牧原');
ok($zip->set_number('4080303')->is_valid_number, '山梨県北杜市武川町宮脇');
ok($zip->set_number('4080304')->is_valid_number, '山梨県北杜市武川町新奥');
ok($zip->set_number('4080305')->is_valid_number, '山梨県北杜市武川町黒澤');
ok($zip->set_number('4080306')->is_valid_number, '山梨県北杜市武川町山高');
ok($zip->set_number('4080307')->is_valid_number, '山梨県北杜市武川町柳澤');
ok($zip->set_number('4080311')->is_valid_number, '山梨県北杜市白州町花水');
ok($zip->set_number('4080312')->is_valid_number, '山梨県北杜市白州町台ケ原');
ok($zip->set_number('4080313')->is_valid_number, '山梨県北杜市白州町横手');
ok($zip->set_number('4080314')->is_valid_number, '山梨県北杜市白州町大坊');
ok($zip->set_number('4080315')->is_valid_number, '山梨県北杜市白州町白須');
ok($zip->set_number('4080316')->is_valid_number, '山梨県北杜市白州町鳥原');
ok($zip->set_number('4080317')->is_valid_number, '山梨県北杜市白州町下教来石');
ok($zip->set_number('4080318')->is_valid_number, '山梨県北杜市白州町上教来石');
ok($zip->set_number('4080319')->is_valid_number, '山梨県北杜市白州町大武川');
ok($zip->set_number('4090100')->is_valid_number, '山梨県上野原市以下に掲載がない場合');
ok($zip->set_number('4090111')->is_valid_number, '山梨県上野原市棡原');
ok($zip->set_number('4090112')->is_valid_number, '山梨県上野原市上野原');
ok($zip->set_number('4090113')->is_valid_number, '山梨県上野原市新田');
ok($zip->set_number('4090114')->is_valid_number, '山梨県上野原市鶴島');
ok($zip->set_number('4090115')->is_valid_number, '山梨県上野原市松留');
ok($zip->set_number('4090121')->is_valid_number, '山梨県上野原市四方津');
ok($zip->set_number('4090122')->is_valid_number, '山梨県上野原市川合');
ok($zip->set_number('4090123')->is_valid_number, '山梨県上野原市大野');
ok($zip->set_number('4090124')->is_valid_number, '山梨県上野原市犬目');
ok($zip->set_number('4090125')->is_valid_number, '山梨県上野原市野田尻');
ok($zip->set_number('4090126')->is_valid_number, '山梨県上野原市コモアしおつ');
ok($zip->set_number('4090131')->is_valid_number, '山梨県上野原市大曽根');
ok($zip->set_number('4090132')->is_valid_number, '山梨県上野原市鶴川');
ok($zip->set_number('4090133')->is_valid_number, '山梨県上野原市八ツ沢');
ok($zip->set_number('4090134')->is_valid_number, '山梨県上野原市大椚');
ok($zip->set_number('4090135')->is_valid_number, '山梨県上野原市芦垣');
ok($zip->set_number('4090136')->is_valid_number, '山梨県上野原市桑久保');
ok($zip->set_number('4090137')->is_valid_number, '山梨県上野原市和見');
ok($zip->set_number('4090138')->is_valid_number, '山梨県上野原市大倉');
ok($zip->set_number('4090141')->is_valid_number, '山梨県上野原市西原');
ok($zip->set_number('4090142')->is_valid_number, '山梨県北都留郡小菅村小菅村の次に1~663番地がくる場合');
ok($zip->set_number('4090200')->is_valid_number, '山梨県北都留郡小菅村以下に掲載がない場合');
ok($zip->set_number('4090211')->is_valid_number, '山梨県北都留郡小菅村小菅村の次に664番地以降がくる場合');
ok($zip->set_number('4090300')->is_valid_number, '山梨県北都留郡丹波山村以下に掲載がない場合');
ok($zip->set_number('4090301')->is_valid_number, '山梨県北都留郡丹波山村奥秋');
ok($zip->set_number('4090302')->is_valid_number, '山梨県北都留郡丹波山村上組');
ok($zip->set_number('4090303')->is_valid_number, '山梨県北都留郡丹波山村中組');
ok($zip->set_number('4090304')->is_valid_number, '山梨県北都留郡丹波山村下組');
ok($zip->set_number('4090305')->is_valid_number, '山梨県北都留郡丹波山村高尾');
ok($zip->set_number('4090306')->is_valid_number, '山梨県北都留郡丹波山村押垣外');
ok($zip->set_number('4090311')->is_valid_number, '山梨県北都留郡丹波山村保之瀬');
ok($zip->set_number('4090312')->is_valid_number, '山梨県北都留郡丹波山村高畑');
ok($zip->set_number('4090313')->is_valid_number, '山梨県北都留郡丹波山村親川');
ok($zip->set_number('4090314')->is_valid_number, '山梨県北都留郡丹波山村御祭');
ok($zip->set_number('4090315')->is_valid_number, '山梨県北都留郡丹波山村杉奈久保');
ok($zip->set_number('4090316')->is_valid_number, '山梨県北都留郡丹波山村所畑');
ok($zip->set_number('4090317')->is_valid_number, '山梨県北都留郡丹波山村小袖');
ok($zip->set_number('4090318')->is_valid_number, '山梨県北都留郡丹波山村鴨沢');
ok($zip->set_number('4090501')->is_valid_number, '山梨県大月市富浜町宮谷');
ok($zip->set_number('4090502')->is_valid_number, '山梨県大月市富浜町鳥沢');
ok($zip->set_number('4090503')->is_valid_number, '山梨県大月市梁川町綱の上');
ok($zip->set_number('4090504')->is_valid_number, '山梨県大月市梁川町新倉');
ok($zip->set_number('4090505')->is_valid_number, '山梨県大月市梁川町塩瀬');
ok($zip->set_number('4090506')->is_valid_number, '山梨県大月市梁川町立野');
ok($zip->set_number('4090611')->is_valid_number, '山梨県大月市猿橋町小篠');
ok($zip->set_number('4090612')->is_valid_number, '山梨県大月市猿橋町藤崎');
ok($zip->set_number('4090613')->is_valid_number, '山梨県大月市猿橋町伊良原');
ok($zip->set_number('4090614')->is_valid_number, '山梨県大月市猿橋町猿橋');
ok($zip->set_number('4090615')->is_valid_number, '山梨県大月市猿橋町朝日小沢');
ok($zip->set_number('4090616')->is_valid_number, '山梨県大月市猿橋町小沢');
ok($zip->set_number('4090617')->is_valid_number, '山梨県大月市猿橋町殿上');
ok($zip->set_number('4090618')->is_valid_number, '山梨県大月市猿橋町桂台');
ok($zip->set_number('4090621')->is_valid_number, '山梨県大月市七保町浅川');
ok($zip->set_number('4090622')->is_valid_number, '山梨県大月市七保町下和田');
ok($zip->set_number('4090623')->is_valid_number, '山梨県大月市七保町葛野');
ok($zip->set_number('4090624')->is_valid_number, '山梨県大月市七保町林');
ok($zip->set_number('4090625')->is_valid_number, '山梨県大月市七保町奈良子');
ok($zip->set_number('4090626')->is_valid_number, '山梨県大月市七保町瀬戸');
ok($zip->set_number('4090627')->is_valid_number, '山梨県大月市七保町駒宮');
ok($zip->set_number('4091201')->is_valid_number, '山梨県甲州市大和町木賊');
ok($zip->set_number('4091202')->is_valid_number, '山梨県甲州市大和町田野');
ok($zip->set_number('4091203')->is_valid_number, '山梨県甲州市大和町初鹿野');
ok($zip->set_number('4091204')->is_valid_number, '山梨県甲州市大和町日影');
ok($zip->set_number('4091205')->is_valid_number, '山梨県甲州市大和町鶴瀬');
ok($zip->set_number('4091211')->is_valid_number, '山梨県甲州市塩山上萩原(4051、4783、4784、すずらん荘、東電上部ダム)');
ok($zip->set_number('4091212')->is_valid_number, '山梨県甲州市塩山中萩原(日川小屋)');
ok($zip->set_number('4091213')->is_valid_number, '山梨県甲州市塩山牛奥(5532~5550、奥野田開拓、嵯峨塩開拓、嵯峨塩温泉)');
ok($zip->set_number('4091301')->is_valid_number, '山梨県甲州市勝沼町中原');
ok($zip->set_number('4091302')->is_valid_number, '山梨県甲州市勝沼町菱山');
ok($zip->set_number('4091303')->is_valid_number, '山梨県甲州市勝沼町小佐手');
ok($zip->set_number('4091304')->is_valid_number, '山梨県甲州市勝沼町休息');
ok($zip->set_number('4091305')->is_valid_number, '山梨県甲州市勝沼町綿塚');
ok($zip->set_number('4091306')->is_valid_number, '山梨県甲州市勝沼町山');
ok($zip->set_number('4091311')->is_valid_number, '山梨県甲州市勝沼町深沢');
ok($zip->set_number('4091312')->is_valid_number, '山梨県甲州市勝沼町上岩崎');
ok($zip->set_number('4091313')->is_valid_number, '山梨県甲州市勝沼町下岩崎');
ok($zip->set_number('4091314')->is_valid_number, '山梨県甲州市勝沼町藤井');
ok($zip->set_number('4091315')->is_valid_number, '山梨県甲州市勝沼町等々力');
ok($zip->set_number('4091316')->is_valid_number, '山梨県甲州市勝沼町勝沼');
ok($zip->set_number('4091321')->is_valid_number, '山梨県甲州市塩山牛奥(5288、5288-1、5288-3、5289、5289');
ok($zip->set_number('4091321')->is_valid_number, '山梨県甲州市-2、5289-15)');
ok($zip->set_number('4091501')->is_valid_number, '山梨県北杜市大泉町西井出(その他)');
ok($zip->set_number('4091502')->is_valid_number, '山梨県北杜市大泉町谷戸');
ok($zip->set_number('4092100')->is_valid_number, '山梨県南巨摩郡南部町以下に掲載がない場合');
ok($zip->set_number('4092101')->is_valid_number, '山梨県南巨摩郡南部町楮根');
ok($zip->set_number('4092102')->is_valid_number, '山梨県南巨摩郡南部町福士');
ok($zip->set_number('4092103')->is_valid_number, '山梨県南巨摩郡南部町万沢');
ok($zip->set_number('4092211')->is_valid_number, '山梨県南巨摩郡南部町中野');
ok($zip->set_number('4092212')->is_valid_number, '山梨県南巨摩郡南部町南部');
ok($zip->set_number('4092213')->is_valid_number, '山梨県南巨摩郡南部町大和');
ok($zip->set_number('4092214')->is_valid_number, '山梨県南巨摩郡南部町塩沢');
ok($zip->set_number('4092215')->is_valid_number, '山梨県南巨摩郡南部町柳島');
ok($zip->set_number('4092216')->is_valid_number, '山梨県南巨摩郡南部町成島');
ok($zip->set_number('4092217')->is_valid_number, '山梨県南巨摩郡南部町本郷');
ok($zip->set_number('4092301')->is_valid_number, '山梨県南巨摩郡南部町上佐野');
ok($zip->set_number('4092302')->is_valid_number, '山梨県南巨摩郡南部町下佐野');
ok($zip->set_number('4092303')->is_valid_number, '山梨県南巨摩郡南部町十島');
ok($zip->set_number('4092304')->is_valid_number, '山梨県南巨摩郡南部町井出');
ok($zip->set_number('4092305')->is_valid_number, '山梨県南巨摩郡南部町内船');
ok($zip->set_number('4092401')->is_valid_number, '山梨県南巨摩郡身延町上八木沢');
ok($zip->set_number('4092402')->is_valid_number, '山梨県南巨摩郡身延町下八木沢');
ok($zip->set_number('4092403')->is_valid_number, '山梨県南巨摩郡身延町帯金');
ok($zip->set_number('4092404')->is_valid_number, '山梨県南巨摩郡身延町大垈');
ok($zip->set_number('4092405')->is_valid_number, '山梨県南巨摩郡身延町椿草里');
ok($zip->set_number('4092406')->is_valid_number, '山梨県南巨摩郡身延町大崩');
ok($zip->set_number('4092411')->is_valid_number, '山梨県南巨摩郡身延町丸滝');
ok($zip->set_number('4092412')->is_valid_number, '山梨県南巨摩郡身延町角打');
ok($zip->set_number('4092413')->is_valid_number, '山梨県南巨摩郡身延町和田');
ok($zip->set_number('4092414')->is_valid_number, '山梨県南巨摩郡身延町樋之上');
ok($zip->set_number('4092415')->is_valid_number, '山梨県南巨摩郡身延町大島');
ok($zip->set_number('4092500')->is_valid_number, '山梨県南巨摩郡身延町以下に掲載がない場合');
ok($zip->set_number('4092521')->is_valid_number, '山梨県南巨摩郡身延町粟倉');
ok($zip->set_number('4092522')->is_valid_number, '山梨県南巨摩郡身延町下山');
ok($zip->set_number('4092523')->is_valid_number, '山梨県南巨摩郡身延町波木井');
ok($zip->set_number('4092524')->is_valid_number, '山梨県南巨摩郡身延町身延');
ok($zip->set_number('4092531')->is_valid_number, '山梨県南巨摩郡身延町梅平');
ok($zip->set_number('4092532')->is_valid_number, '山梨県南巨摩郡身延町大野');
ok($zip->set_number('4092533')->is_valid_number, '山梨県南巨摩郡身延町清子');
ok($zip->set_number('4092534')->is_valid_number, '山梨県南巨摩郡身延町光子沢');
ok($zip->set_number('4092535')->is_valid_number, '山梨県南巨摩郡身延町横根中');
ok($zip->set_number('4092536')->is_valid_number, '山梨県南巨摩郡身延町相又');
ok($zip->set_number('4092537')->is_valid_number, '山梨県南巨摩郡身延町大城');
ok($zip->set_number('4092538')->is_valid_number, '山梨県南巨摩郡身延町門野');
ok($zip->set_number('4092539')->is_valid_number, '山梨県南巨摩郡身延町小田船原');
ok($zip->set_number('4092700')->is_valid_number, '山梨県南巨摩郡早川町以下に掲載がない場合');
ok($zip->set_number('4092701')->is_valid_number, '山梨県南巨摩郡早川町奈良田');
ok($zip->set_number('4092702')->is_valid_number, '山梨県南巨摩郡早川町湯島');
ok($zip->set_number('4092703')->is_valid_number, '山梨県南巨摩郡早川町新倉');
ok($zip->set_number('4092704')->is_valid_number, '山梨県南巨摩郡早川町大原野');
ok($zip->set_number('4092705')->is_valid_number, '山梨県南巨摩郡早川町早川');
ok($zip->set_number('4092711')->is_valid_number, '山梨県南巨摩郡早川町黒桂');
ok($zip->set_number('4092712')->is_valid_number, '山梨県南巨摩郡早川町西之宮');
ok($zip->set_number('4092713')->is_valid_number, '山梨県南巨摩郡早川町保');
ok($zip->set_number('4092714')->is_valid_number, '山梨県南巨摩郡早川町草塩');
ok($zip->set_number('4092715')->is_valid_number, '山梨県南巨摩郡早川町京ケ島');
ok($zip->set_number('4092721')->is_valid_number, '山梨県南巨摩郡早川町塩之上');
ok($zip->set_number('4092722')->is_valid_number, '山梨県南巨摩郡早川町笹走');
ok($zip->set_number('4092723')->is_valid_number, '山梨県南巨摩郡早川町榑坪');
ok($zip->set_number('4092724')->is_valid_number, '山梨県南巨摩郡早川町初鹿島');
ok($zip->set_number('4092725')->is_valid_number, '山梨県南巨摩郡早川町小縄');
ok($zip->set_number('4092726')->is_valid_number, '山梨県南巨摩郡早川町千須和');
ok($zip->set_number('4092727')->is_valid_number, '山梨県南巨摩郡早川町薬袋');
ok($zip->set_number('4092731')->is_valid_number, '山梨県南巨摩郡早川町大島');
ok($zip->set_number('4092732')->is_valid_number, '山梨県南巨摩郡早川町高住');
ok($zip->set_number('4092733')->is_valid_number, '山梨県南巨摩郡早川町赤沢');
ok($zip->set_number('4092734')->is_valid_number, '山梨県南巨摩郡早川町雨畑');
ok($zip->set_number('4092931')->is_valid_number, '山梨県南巨摩郡身延町北川');
ok($zip->set_number('4092932')->is_valid_number, '山梨県南巨摩郡身延町杉山');
ok($zip->set_number('4092933')->is_valid_number, '山梨県南巨摩郡身延町岩欠');
ok($zip->set_number('4092934')->is_valid_number, '山梨県南巨摩郡身延町大炊平');
ok($zip->set_number('4092935')->is_valid_number, '山梨県南巨摩郡身延町清沢');
ok($zip->set_number('4092936')->is_valid_number, '山梨県南巨摩郡身延町常葉');
ok($zip->set_number('4092937')->is_valid_number, '山梨県南巨摩郡身延町一色');
ok($zip->set_number('4092938')->is_valid_number, '山梨県南巨摩郡身延町市之瀬');
ok($zip->set_number('4092941')->is_valid_number, '山梨県南巨摩郡身延町湯之奥');
ok($zip->set_number('4092942')->is_valid_number, '山梨県南巨摩郡身延町下部');
ok($zip->set_number('4092943')->is_valid_number, '山梨県南巨摩郡身延町川向');
ok($zip->set_number('4092944')->is_valid_number, '山梨県南巨摩郡身延町桃ケ窪');
ok($zip->set_number('4092945')->is_valid_number, '山梨県南巨摩郡身延町波高島');
ok($zip->set_number('4092946')->is_valid_number, '山梨県南巨摩郡身延町大子');
ok($zip->set_number('4092947')->is_valid_number, '山梨県南巨摩郡身延町上之平');
ok($zip->set_number('4093101')->is_valid_number, '山梨県南巨摩郡身延町折門');
ok($zip->set_number('4093102')->is_valid_number, '山梨県南巨摩郡身延町八坂');
ok($zip->set_number('4093103')->is_valid_number, '山梨県南巨摩郡身延町根子');
ok($zip->set_number('4093104')->is_valid_number, '山梨県南巨摩郡身延町中之倉');
ok($zip->set_number('4093105')->is_valid_number, '山梨県南巨摩郡身延町釜額');
ok($zip->set_number('4093106')->is_valid_number, '山梨県南巨摩郡身延町古関');
ok($zip->set_number('4093107')->is_valid_number, '山梨県南巨摩郡身延町瀬戸');
ok($zip->set_number('4093111')->is_valid_number, '山梨県南巨摩郡身延町大磯小磯');
ok($zip->set_number('4093112')->is_valid_number, '山梨県南巨摩郡身延町芝草');
ok($zip->set_number('4093113')->is_valid_number, '山梨県南巨摩郡身延町水船');
ok($zip->set_number('4093114')->is_valid_number, '山梨県南巨摩郡身延町道');
ok($zip->set_number('4093115')->is_valid_number, '山梨県南巨摩郡身延町切房木');
ok($zip->set_number('4093116')->is_valid_number, '山梨県南巨摩郡身延町車田');
ok($zip->set_number('4093117')->is_valid_number, '山梨県南巨摩郡身延町三沢');
ok($zip->set_number('4093118')->is_valid_number, '山梨県南巨摩郡身延町上田原');
ok($zip->set_number('4093121')->is_valid_number, '山梨県南巨摩郡身延町大山');
ok($zip->set_number('4093122')->is_valid_number, '山梨県南巨摩郡身延町久保');
ok($zip->set_number('4093123')->is_valid_number, '山梨県南巨摩郡身延町熊沢');
ok($zip->set_number('4093124')->is_valid_number, '山梨県南巨摩郡身延町樋田');
ok($zip->set_number('4093125')->is_valid_number, '山梨県南巨摩郡身延町嶺');
ok($zip->set_number('4093126')->is_valid_number, '山梨県南巨摩郡身延町山家');
ok($zip->set_number('4093231')->is_valid_number, '山梨県西八代郡市川三郷町落居');
ok($zip->set_number('4093232')->is_valid_number, '山梨県西八代郡市川三郷町寺所');
ok($zip->set_number('4093233')->is_valid_number, '山梨県西八代郡市川三郷町五八');
ok($zip->set_number('4093234')->is_valid_number, '山梨県西八代郡市川三郷町岩下');
ok($zip->set_number('4093241')->is_valid_number, '山梨県西八代郡市川三郷町葛籠沢');
ok($zip->set_number('4093242')->is_valid_number, '山梨県西八代郡市川三郷町宮原');
ok($zip->set_number('4093243')->is_valid_number, '山梨県西八代郡市川三郷町鴨狩津向');
ok($zip->set_number('4093244')->is_valid_number, '山梨県西八代郡市川三郷町岩間');
ok($zip->set_number('4093245')->is_valid_number, '山梨県西八代郡市川三郷町楠甫');
ok($zip->set_number('4093301')->is_valid_number, '山梨県南巨摩郡身延町西嶋');
ok($zip->set_number('4093302')->is_valid_number, '山梨県南巨摩郡身延町手打沢');
ok($zip->set_number('4093303')->is_valid_number, '山梨県南巨摩郡身延町寺沢');
ok($zip->set_number('4093304')->is_valid_number, '山梨県南巨摩郡身延町切石');
ok($zip->set_number('4093305')->is_valid_number, '山梨県南巨摩郡身延町下田原');
ok($zip->set_number('4093306')->is_valid_number, '山梨県南巨摩郡身延町夜子沢');
ok($zip->set_number('4093307')->is_valid_number, '山梨県南巨摩郡身延町日向南沢');
ok($zip->set_number('4093311')->is_valid_number, '山梨県南巨摩郡身延町大塩');
ok($zip->set_number('4093312')->is_valid_number, '山梨県南巨摩郡身延町久成');
ok($zip->set_number('4093313')->is_valid_number, '山梨県南巨摩郡身延町平須');
ok($zip->set_number('4093421')->is_valid_number, '山梨県南巨摩郡身延町八日市場');
ok($zip->set_number('4093422')->is_valid_number, '山梨県南巨摩郡身延町宮木');
ok($zip->set_number('4093423')->is_valid_number, '山梨県南巨摩郡身延町飯富');
ok($zip->set_number('4093424')->is_valid_number, '山梨県南巨摩郡身延町伊沼');
ok($zip->set_number('4093431')->is_valid_number, '山梨県南巨摩郡身延町矢細工');
ok($zip->set_number('4093432')->is_valid_number, '山梨県南巨摩郡身延町中山');
ok($zip->set_number('4093433')->is_valid_number, '山梨県南巨摩郡身延町遅沢');
ok($zip->set_number('4093434')->is_valid_number, '山梨県南巨摩郡身延町江尻窪');
ok($zip->set_number('4093435')->is_valid_number, '山梨県南巨摩郡身延町梨子');
ok($zip->set_number('4093436')->is_valid_number, '山梨県南巨摩郡身延町福原');
ok($zip->set_number('4093437')->is_valid_number, '山梨県南巨摩郡身延町古長谷');
ok($zip->set_number('4093600')->is_valid_number, '山梨県西八代郡市川三郷町以下に掲載がない場合');
ok($zip->set_number('4093601')->is_valid_number, '山梨県西八代郡市川三郷町市川大門');
ok($zip->set_number('4093602')->is_valid_number, '山梨県西八代郡市川三郷町山保');
ok($zip->set_number('4093603')->is_valid_number, '山梨県西八代郡市川三郷町黒沢');
ok($zip->set_number('4093604')->is_valid_number, '山梨県西八代郡市川三郷町八之尻');
ok($zip->set_number('4093605')->is_valid_number, '山梨県西八代郡市川三郷町下大鳥居');
ok($zip->set_number('4093606')->is_valid_number, '山梨県西八代郡市川三郷町高田');
ok($zip->set_number('4093607')->is_valid_number, '山梨県西八代郡市川三郷町印沢');
ok($zip->set_number('4093611')->is_valid_number, '山梨県西八代郡市川三郷町大塚');
ok($zip->set_number('4093612')->is_valid_number, '山梨県西八代郡市川三郷町上野');
ok($zip->set_number('4093621')->is_valid_number, '山梨県西八代郡市川三郷町下芦川');
ok($zip->set_number('4093622')->is_valid_number, '山梨県西八代郡市川三郷町三帳');
ok($zip->set_number('4093623')->is_valid_number, '山梨県西八代郡市川三郷町高萩');
ok($zip->set_number('4093624')->is_valid_number, '山梨県西八代郡市川三郷町垈');
ok($zip->set_number('4093625')->is_valid_number, '山梨県西八代郡市川三郷町中山');
ok($zip->set_number('4093626')->is_valid_number, '山梨県西八代郡市川三郷町畑熊');
ok($zip->set_number('4093701')->is_valid_number, '山梨県笛吹市芦川町上芦川');
ok($zip->set_number('4093702')->is_valid_number, '山梨県笛吹市芦川町新井原');
ok($zip->set_number('4093703')->is_valid_number, '山梨県笛吹市芦川町中芦川');
ok($zip->set_number('4093704')->is_valid_number, '山梨県笛吹市芦川町鶯宿');
ok($zip->set_number('4093711')->is_valid_number, '山梨県甲府市梯町');
ok($zip->set_number('4093712')->is_valid_number, '山梨県甲府市古関町');
ok($zip->set_number('4093800')->is_valid_number, '山梨県中央市以下に掲載がない場合');
ok($zip->set_number('4093800')->is_valid_number, '山梨県中巨摩郡昭和町以下に掲載がない場合');
ok($zip->set_number('4093801')->is_valid_number, '山梨県中央市中楯');
ok($zip->set_number('4093802')->is_valid_number, '山梨県中央市西新居');
ok($zip->set_number('4093803')->is_valid_number, '山梨県中央市若宮');
ok($zip->set_number('4093804')->is_valid_number, '山梨県中央市井之口');
ok($zip->set_number('4093811')->is_valid_number, '山梨県中央市極楽寺');
ok($zip->set_number('4093812')->is_valid_number, '山梨県中央市乙黒');
ok($zip->set_number('4093813')->is_valid_number, '山梨県中央市一町畑');
ok($zip->set_number('4093814')->is_valid_number, '山梨県中央市町之田');
ok($zip->set_number('4093815')->is_valid_number, '山梨県中央市成島');
ok($zip->set_number('4093821')->is_valid_number, '山梨県中央市下河東');
ok($zip->set_number('4093822')->is_valid_number, '山梨県中央市下三條');
ok($zip->set_number('4093823')->is_valid_number, '山梨県中央市上三條');
ok($zip->set_number('4093831')->is_valid_number, '山梨県中央市大田和');
ok($zip->set_number('4093832')->is_valid_number, '山梨県中央市馬籠');
ok($zip->set_number('4093833')->is_valid_number, '山梨県中央市藤巻');
ok($zip->set_number('4093834')->is_valid_number, '山梨県中央市今福');
ok($zip->set_number('4093835')->is_valid_number, '山梨県中央市今福新田');
ok($zip->set_number('4093841')->is_valid_number, '山梨県中央市布施');
ok($zip->set_number('4093842')->is_valid_number, '山梨県中央市東花輪');
ok($zip->set_number('4093843')->is_valid_number, '山梨県中央市西花輪');
ok($zip->set_number('4093844')->is_valid_number, '山梨県中央市臼井阿原');
ok($zip->set_number('4093845')->is_valid_number, '山梨県中央市山之神');
ok($zip->set_number('4093851')->is_valid_number, '山梨県中巨摩郡昭和町河西');
ok($zip->set_number('4093852')->is_valid_number, '山梨県中巨摩郡昭和町飯喰');
ok($zip->set_number('4093853')->is_valid_number, '山梨県中巨摩郡昭和町築地新居');
ok($zip->set_number('4093854')->is_valid_number, '山梨県中巨摩郡昭和町築地新田');
ok($zip->set_number('4093861')->is_valid_number, '山梨県中巨摩郡昭和町紙漉阿原');
ok($zip->set_number('4093862')->is_valid_number, '山梨県中巨摩郡昭和町上河東');
ok($zip->set_number('4093863')->is_valid_number, '山梨県中巨摩郡昭和町河東中島');
ok($zip->set_number('4093864')->is_valid_number, '山梨県中巨摩郡昭和町押越');
ok($zip->set_number('4093865')->is_valid_number, '山梨県中巨摩郡昭和町西条新田');
ok($zip->set_number('4093866')->is_valid_number, '山梨県中巨摩郡昭和町西条');
ok($zip->set_number('4093867')->is_valid_number, '山梨県中巨摩郡昭和町清水新居');
ok($zip->set_number('4100000')->is_valid_number, '静岡県沼津市以下に掲載がない場合');
ok($zip->set_number('4100001')->is_valid_number, '静岡県沼津市足高');
ok($zip->set_number('4100002')->is_valid_number, '静岡県沼津市東沢田');
ok($zip->set_number('4100003')->is_valid_number, '静岡県沼津市新沢田町');
ok($zip->set_number('4100004')->is_valid_number, '静岡県沼津市本田町');
ok($zip->set_number('4100005')->is_valid_number, '静岡県沼津市双葉町');
ok($zip->set_number('4100006')->is_valid_number, '静岡県沼津市中沢田');
ok($zip->set_number('4100007')->is_valid_number, '静岡県沼津市西沢田');
ok($zip->set_number('4100011')->is_valid_number, '静岡県沼津市岡宮');
ok($zip->set_number('4100012')->is_valid_number, '静岡県沼津市岡一色');
ok($zip->set_number('4100013')->is_valid_number, '静岡県沼津市東熊堂');
ok($zip->set_number('4100014')->is_valid_number, '静岡県沼津市松沢町');
ok($zip->set_number('4100015')->is_valid_number, '静岡県沼津市駿河台');
ok($zip->set_number('4100016')->is_valid_number, '静岡県沼津市高砂町');
ok($zip->set_number('4100017')->is_valid_number, '静岡県沼津市高尾台');
ok($zip->set_number('4100018')->is_valid_number, '静岡県沼津市豊町');
ok($zip->set_number('4100021')->is_valid_number, '静岡県沼津市小林台');
ok($zip->set_number('4100022')->is_valid_number, '静岡県沼津市大岡');
ok($zip->set_number('4100031')->is_valid_number, '静岡県沼津市三枚橋');
ok($zip->set_number('4100032')->is_valid_number, '静岡県沼津市日の出町');
ok($zip->set_number('4100033')->is_valid_number, '静岡県沼津市杉崎町');
ok($zip->set_number('4100034')->is_valid_number, '静岡県沼津市富士見町');
ok($zip->set_number('4100035')->is_valid_number, '静岡県沼津市山王台');
ok($zip->set_number('4100036')->is_valid_number, '静岡県沼津市平町');
ok($zip->set_number('4100037')->is_valid_number, '静岡県沼津市三枚橋町');
ok($zip->set_number('4100038')->is_valid_number, '静岡県沼津市三芳町');
ok($zip->set_number('4100041')->is_valid_number, '静岡県沼津市筒井町');
ok($zip->set_number('4100042')->is_valid_number, '静岡県沼津市神田町');
ok($zip->set_number('4100043')->is_valid_number, '静岡県沼津市柳町');
ok($zip->set_number('4100044')->is_valid_number, '静岡県沼津市五月町');
ok($zip->set_number('4100045')->is_valid_number, '静岡県沼津市泉町');
ok($zip->set_number('4100046')->is_valid_number, '静岡県沼津市米山町');
ok($zip->set_number('4100047')->is_valid_number, '静岡県沼津市庄栄町');
ok($zip->set_number('4100048')->is_valid_number, '静岡県沼津市新宿町');
ok($zip->set_number('4100049')->is_valid_number, '静岡県沼津市江原町');
ok($zip->set_number('4100051')->is_valid_number, '静岡県沼津市西熊堂');
ok($zip->set_number('4100052')->is_valid_number, '静岡県沼津市沢田町');
ok($zip->set_number('4100053')->is_valid_number, '静岡県沼津市寿町');
ok($zip->set_number('4100054')->is_valid_number, '静岡県沼津市北高島町');
ok($zip->set_number('4100055')->is_valid_number, '静岡県沼津市高島本町');
ok($zip->set_number('4100056')->is_valid_number, '静岡県沼津市高島町');
ok($zip->set_number('4100057')->is_valid_number, '静岡県沼津市高沢町');
ok($zip->set_number('4100058')->is_valid_number, '静岡県沼津市沼北町');
ok($zip->set_number('4100059')->is_valid_number, '静岡県沼津市若葉町');
ok($zip->set_number('4100061')->is_valid_number, '静岡県沼津市北園町');
ok($zip->set_number('4100062')->is_valid_number, '静岡県沼津市宮前町');
ok($zip->set_number('4100063')->is_valid_number, '静岡県沼津市緑ケ丘');
ok($zip->set_number('4100064')->is_valid_number, '静岡県沼津市共栄町');
ok($zip->set_number('4100065')->is_valid_number, '静岡県沼津市花園町');
ok($zip->set_number('4100101')->is_valid_number, '静岡県沼津市多比');
ok($zip->set_number('4100102')->is_valid_number, '静岡県沼津市口野');
ok($zip->set_number('4100103')->is_valid_number, '静岡県沼津市江浦');
ok($zip->set_number('4100104')->is_valid_number, '静岡県沼津市獅子浜');
ok($zip->set_number('4100105')->is_valid_number, '静岡県沼津市馬込');
ok($zip->set_number('4100106')->is_valid_number, '静岡県沼津市志下');
ok($zip->set_number('4100221')->is_valid_number, '静岡県沼津市内浦重寺');
ok($zip->set_number('4100222')->is_valid_number, '静岡県沼津市内浦小海');
ok($zip->set_number('4100223')->is_valid_number, '静岡県沼津市内浦三津');
ok($zip->set_number('4100224')->is_valid_number, '静岡県沼津市内浦長浜');
ok($zip->set_number('4100225')->is_valid_number, '静岡県沼津市内浦重須');
ok($zip->set_number('4100231')->is_valid_number, '静岡県沼津市西浦木負');
ok($zip->set_number('4100232')->is_valid_number, '静岡県沼津市西浦河内');
ok($zip->set_number('4100233')->is_valid_number, '静岡県沼津市西浦久連');
ok($zip->set_number('4100234')->is_valid_number, '静岡県沼津市西浦平沢');
ok($zip->set_number('4100235')->is_valid_number, '静岡県沼津市西浦立保');
ok($zip->set_number('4100241')->is_valid_number, '静岡県沼津市西浦古宇');
ok($zip->set_number('4100242')->is_valid_number, '静岡県沼津市西浦足保');
ok($zip->set_number('4100243')->is_valid_number, '静岡県沼津市西浦久料');
ok($zip->set_number('4100244')->is_valid_number, '静岡県沼津市西浦江梨');
ok($zip->set_number('4100244')->is_valid_number, '静岡県沼津市西浦大瀬');
ok($zip->set_number('4100301')->is_valid_number, '静岡県沼津市宮本');
ok($zip->set_number('4100302')->is_valid_number, '静岡県沼津市東椎路');
ok($zip->set_number('4100303')->is_valid_number, '静岡県沼津市西椎路');
ok($zip->set_number('4100304')->is_valid_number, '静岡県沼津市東原');
ok($zip->set_number('4100305')->is_valid_number, '静岡県沼津市鳥谷');
ok($zip->set_number('4100306')->is_valid_number, '静岡県沼津市大塚');
ok($zip->set_number('4100307')->is_valid_number, '静岡県沼津市青野');
ok($zip->set_number('4100308')->is_valid_number, '静岡県沼津市柳沢');
ok($zip->set_number('4100309')->is_valid_number, '静岡県沼津市根古屋');
ok($zip->set_number('4100311')->is_valid_number, '静岡県沼津市原町中');
ok($zip->set_number('4100312')->is_valid_number, '静岡県沼津市原');
ok($zip->set_number('4100313')->is_valid_number, '静岡県沼津市西添町');
ok($zip->set_number('4100314')->is_valid_number, '静岡県沼津市一本松');
ok($zip->set_number('4100315')->is_valid_number, '静岡県沼津市桃里');
ok($zip->set_number('4100316')->is_valid_number, '静岡県沼津市植田');
ok($zip->set_number('4100317')->is_valid_number, '静岡県沼津市石川');
ok($zip->set_number('4100318')->is_valid_number, '静岡県沼津市平沼');
ok($zip->set_number('4100319')->is_valid_number, '静岡県沼津市井出');
ok($zip->set_number('4100321')->is_valid_number, '静岡県沼津市西野');
ok($zip->set_number('4100801')->is_valid_number, '静岡県沼津市大手町');
ok($zip->set_number('4100802')->is_valid_number, '静岡県沼津市上土町');
ok($zip->set_number('4100803')->is_valid_number, '静岡県沼津市添地町');
ok($zip->set_number('4100804')->is_valid_number, '静岡県沼津市西条町');
ok($zip->set_number('4100805')->is_valid_number, '静岡県沼津市白銀町');
ok($zip->set_number('4100806')->is_valid_number, '静岡県沼津市丸子町');
ok($zip->set_number('4100807')->is_valid_number, '静岡県沼津市錦町');
ok($zip->set_number('4100811')->is_valid_number, '静岡県沼津市中瀬町');
ok($zip->set_number('4100812')->is_valid_number, '静岡県沼津市山ケ下町');
ok($zip->set_number('4100813')->is_valid_number, '静岡県沼津市上香貫');
ok($zip->set_number('4100814')->is_valid_number, '静岡県沼津市玉江町');
ok($zip->set_number('4100815')->is_valid_number, '静岡県沼津市南本郷町');
ok($zip->set_number('4100816')->is_valid_number, '静岡県沼津市住吉町');
ok($zip->set_number('4100817')->is_valid_number, '静岡県沼津市本郷町');
ok($zip->set_number('4100818')->is_valid_number, '静岡県沼津市中原町');
ok($zip->set_number('4100819')->is_valid_number, '静岡県沼津市黒瀬町');
ok($zip->set_number('4100821')->is_valid_number, '静岡県沼津市大平');
ok($zip->set_number('4100822')->is_valid_number, '静岡県沼津市下香貫');
ok($zip->set_number('4100823')->is_valid_number, '静岡県沼津市我入道');
ok($zip->set_number('4100824')->is_valid_number, '静岡県沼津市香貫が丘');
ok($zip->set_number('4100831')->is_valid_number, '静岡県沼津市市場町');
ok($zip->set_number('4100832')->is_valid_number, '静岡県沼津市御幸町');
ok($zip->set_number('4100833')->is_valid_number, '静岡県沼津市三園町');
ok($zip->set_number('4100834')->is_valid_number, '静岡県沼津市槇島町');
ok($zip->set_number('4100835')->is_valid_number, '静岡県沼津市西島町');
ok($zip->set_number('4100836')->is_valid_number, '静岡県沼津市吉田町');
ok($zip->set_number('4100841')->is_valid_number, '静岡県沼津市下河原町');
ok($zip->set_number('4100842')->is_valid_number, '静岡県沼津市蛇松町');
ok($zip->set_number('4100843')->is_valid_number, '静岡県沼津市蓼原町');
ok($zip->set_number('4100844')->is_valid_number, '静岡県沼津市春日町');
ok($zip->set_number('4100845')->is_valid_number, '静岡県沼津市千本港町');
ok($zip->set_number('4100846')->is_valid_number, '静岡県沼津市千本東町');
ok($zip->set_number('4100847')->is_valid_number, '静岡県沼津市千本中町');
ok($zip->set_number('4100848')->is_valid_number, '静岡県沼津市千本西町');
ok($zip->set_number('4100849')->is_valid_number, '静岡県沼津市千本郷林');
ok($zip->set_number('4100851')->is_valid_number, '静岡県沼津市宮町');
ok($zip->set_number('4100852')->is_valid_number, '静岡県沼津市旭町');
ok($zip->set_number('4100853')->is_valid_number, '静岡県沼津市常盤町');
ok($zip->set_number('4100854')->is_valid_number, '静岡県沼津市千本常盤町');
ok($zip->set_number('4100855')->is_valid_number, '静岡県沼津市千本緑町');
ok($zip->set_number('4100861')->is_valid_number, '静岡県沼津市真砂町');
ok($zip->set_number('4100862')->is_valid_number, '静岡県沼津市幸町');
ok($zip->set_number('4100863')->is_valid_number, '静岡県沼津市下一丁田');
ok($zip->set_number('4100864')->is_valid_number, '静岡県沼津市松下');
ok($zip->set_number('4100865')->is_valid_number, '静岡県沼津市東間門');
ok($zip->set_number('4100866')->is_valid_number, '静岡県沼津市市道');
ok($zip->set_number('4100867')->is_valid_number, '静岡県沼津市下中溝');
ok($zip->set_number('4100867')->is_valid_number, '静岡県沼津市千本');
ok($zip->set_number('4100867')->is_valid_number, '静岡県沼津市出口町');
ok($zip->set_number('4100867')->is_valid_number, '静岡県沼津市西松下');
ok($zip->set_number('4100867')->is_valid_number, '静岡県沼津市本');
ok($zip->set_number('4100867')->is_valid_number, '静岡県沼津市前田');
ok($zip->set_number('4100867')->is_valid_number, '静岡県沼津市松下七反田');
ok($zip->set_number('4100868')->is_valid_number, '静岡県沼津市下小路町');
ok($zip->set_number('4100871')->is_valid_number, '静岡県沼津市西間門');
ok($zip->set_number('4100872')->is_valid_number, '静岡県沼津市小諏訪');
ok($zip->set_number('4100873')->is_valid_number, '静岡県沼津市大諏訪');
ok($zip->set_number('4100874')->is_valid_number, '静岡県沼津市松長');
ok($zip->set_number('4100875')->is_valid_number, '静岡県沼津市今沢');
ok($zip->set_number('4100876')->is_valid_number, '静岡県沼津市北今沢');
ok($zip->set_number('4100881')->is_valid_number, '静岡県沼津市八幡町');
ok($zip->set_number('4100882')->is_valid_number, '静岡県沼津市町方町');
ok($zip->set_number('4100883')->is_valid_number, '静岡県沼津市大門町');
ok($zip->set_number('4100884')->is_valid_number, '静岡県沼津市本町');
ok($zip->set_number('4100885')->is_valid_number, '静岡県沼津市下本町');
ok($zip->set_number('4100886')->is_valid_number, '静岡県沼津市浅間町');
ok($zip->set_number('4100887')->is_valid_number, '静岡県沼津市東宮後町');
ok($zip->set_number('4100888')->is_valid_number, '静岡県沼津市末広町');
ok($zip->set_number('4100891')->is_valid_number, '静岡県沼津市通横町');
ok($zip->set_number('4100892')->is_valid_number, '静岡県沼津市魚町');
ok($zip->set_number('4100893')->is_valid_number, '静岡県沼津市くまだか町');
ok($zip->set_number('4100894')->is_valid_number, '静岡県沼津市仲町');
ok($zip->set_number('4100895')->is_valid_number, '静岡県沼津市新町');
ok($zip->set_number('4101100')->is_valid_number, '静岡県裾野市以下に掲載がない場合');
ok($zip->set_number('4101101')->is_valid_number, '静岡県裾野市岩波');
ok($zip->set_number('4101102')->is_valid_number, '静岡県裾野市深良');
ok($zip->set_number('4101103')->is_valid_number, '静岡県裾野市葛山');
ok($zip->set_number('4101104')->is_valid_number, '静岡県裾野市今里');
ok($zip->set_number('4101105')->is_valid_number, '静岡県裾野市下和田');
ok($zip->set_number('4101106')->is_valid_number, '静岡県裾野市金沢');
ok($zip->set_number('4101107')->is_valid_number, '静岡県裾野市御宿');
ok($zip->set_number('4101108')->is_valid_number, '静岡県裾野市上ケ田');
ok($zip->set_number('4101109')->is_valid_number, '静岡県裾野市呼子');
ok($zip->set_number('4101111')->is_valid_number, '静岡県裾野市久根');
ok($zip->set_number('4101112')->is_valid_number, '静岡県裾野市公文名');
ok($zip->set_number('4101113')->is_valid_number, '静岡県裾野市稲荷');
ok($zip->set_number('4101114')->is_valid_number, '静岡県裾野市大畑');
ok($zip->set_number('4101115')->is_valid_number, '静岡県裾野市千福が丘');
ok($zip->set_number('4101116')->is_valid_number, '静岡県裾野市千福');
ok($zip->set_number('4101117')->is_valid_number, '静岡県裾野市石脇');
ok($zip->set_number('4101118')->is_valid_number, '静岡県裾野市佐野');
ok($zip->set_number('4101121')->is_valid_number, '静岡県裾野市茶畑');
ok($zip->set_number('4101122')->is_valid_number, '静岡県裾野市麦塚');
ok($zip->set_number('4101123')->is_valid_number, '静岡県裾野市伊豆島田');
ok($zip->set_number('4101124')->is_valid_number, '静岡県裾野市水窪');
ok($zip->set_number('4101125')->is_valid_number, '静岡県裾野市富沢');
ok($zip->set_number('4101126')->is_valid_number, '静岡県裾野市桃園');
ok($zip->set_number('4101127')->is_valid_number, '静岡県裾野市平松');
ok($zip->set_number('4101128')->is_valid_number, '静岡県裾野市二ツ屋');
ok($zip->set_number('4101231')->is_valid_number, '静岡県裾野市須山');
ok($zip->set_number('4101300')->is_valid_number, '静岡県駿東郡小山町以下に掲載がない場合');
ok($zip->set_number('4101301')->is_valid_number, '静岡県駿東郡小山町柳島');
ok($zip->set_number('4101302')->is_valid_number, '静岡県駿東郡小山町中島');
ok($zip->set_number('4101303')->is_valid_number, '静岡県駿東郡小山町生土');
ok($zip->set_number('4101304')->is_valid_number, '静岡県駿東郡小山町藤曲');
ok($zip->set_number('4101305')->is_valid_number, '静岡県駿東郡小山町湯船');
ok($zip->set_number('4101306')->is_valid_number, '静岡県駿東郡小山町上野');
ok($zip->set_number('4101307')->is_valid_number, '静岡県駿東郡小山町中日向');
ok($zip->set_number('4101308')->is_valid_number, '静岡県駿東郡小山町大御神');
ok($zip->set_number('4101311')->is_valid_number, '静岡県駿東郡小山町小山');
ok($zip->set_number('4101312')->is_valid_number, '静岡県駿東郡小山町菅沼');
ok($zip->set_number('4101313')->is_valid_number, '静岡県駿東郡小山町竹之下');
ok($zip->set_number('4101314')->is_valid_number, '静岡県駿東郡小山町新柴');
ok($zip->set_number('4101315')->is_valid_number, '静岡県駿東郡小山町桑木');
ok($zip->set_number('4101316')->is_valid_number, '静岡県駿東郡小山町下古城');
ok($zip->set_number('4101317')->is_valid_number, '静岡県駿東郡小山町大胡田');
ok($zip->set_number('4101321')->is_valid_number, '静岡県駿東郡小山町阿多野');
ok($zip->set_number('4101322')->is_valid_number, '静岡県駿東郡小山町吉久保');
ok($zip->set_number('4101323')->is_valid_number, '静岡県駿東郡小山町上古城');
ok($zip->set_number('4101324')->is_valid_number, '静岡県駿東郡小山町下小林');
ok($zip->set_number('4101325')->is_valid_number, '静岡県駿東郡小山町一色');
ok($zip->set_number('4101326')->is_valid_number, '静岡県駿東郡小山町用沢');
ok($zip->set_number('4101327')->is_valid_number, '静岡県駿東郡小山町棚頭');
ok($zip->set_number('4101431')->is_valid_number, '静岡県駿東郡小山町須走');
ok($zip->set_number('4101432')->is_valid_number, '静岡県駿東郡小山町自衛隊富士学校');
ok($zip->set_number('4102101')->is_valid_number, '静岡県伊豆の国市小松ケ原');
ok($zip->set_number('4102102')->is_valid_number, '静岡県伊豆の国市富士見ニュータウン');
ok($zip->set_number('4102103')->is_valid_number, '静岡県伊豆の国市エメラルドタウン');
ok($zip->set_number('4102111')->is_valid_number, '静岡県伊豆の国市立花台');
ok($zip->set_number('4102112')->is_valid_number, '静岡県伊豆の国市内中');
ok($zip->set_number('4102113')->is_valid_number, '静岡県伊豆の国市中');
ok($zip->set_number('4102114')->is_valid_number, '静岡県伊豆の国市南條');
ok($zip->set_number('4102121')->is_valid_number, '静岡県伊豆の国市中條');
ok($zip->set_number('4102122')->is_valid_number, '静岡県伊豆の国市寺家');
ok($zip->set_number('4102123')->is_valid_number, '静岡県伊豆の国市四日町');
ok($zip->set_number('4102124')->is_valid_number, '静岡県伊豆の国市原木');
ok($zip->set_number('4102131')->is_valid_number, '静岡県伊豆の国市長崎');
ok($zip->set_number('4102132')->is_valid_number, '静岡県伊豆の国市奈古谷');
ok($zip->set_number('4102133')->is_valid_number, '静岡県伊豆の国市韮山多田');
ok($zip->set_number('4102141')->is_valid_number, '静岡県伊豆の国市韮山山木');
ok($zip->set_number('4102142')->is_valid_number, '静岡県伊豆の国市韮山金谷');
ok($zip->set_number('4102143')->is_valid_number, '静岡県伊豆の国市韮山韮山');
ok($zip->set_number('4102144')->is_valid_number, '静岡県伊豆の国市韮山土手和田');
ok($zip->set_number('4102200')->is_valid_number, '静岡県伊豆の国市以下に掲載がない場合');
ok($zip->set_number('4102201')->is_valid_number, '静岡県伊豆の国市古奈');
ok($zip->set_number('4102202')->is_valid_number, '静岡県伊豆の国市天野');
ok($zip->set_number('4102203')->is_valid_number, '静岡県伊豆の国市小坂');
ok($zip->set_number('4102204')->is_valid_number, '静岡県伊豆の国市墹之上');
ok($zip->set_number('4102205')->is_valid_number, '静岡県伊豆の国市富士見');
ok($zip->set_number('4102211')->is_valid_number, '静岡県伊豆の国市長岡');
ok($zip->set_number('4102212')->is_valid_number, '静岡県伊豆の国市長瀬');
ok($zip->set_number('4102213')->is_valid_number, '静岡県伊豆の国市戸沢');
ok($zip->set_number('4102214')->is_valid_number, '静岡県伊豆の国市花坂');
ok($zip->set_number('4102221')->is_valid_number, '静岡県伊豆の国市南江間');
ok($zip->set_number('4102223')->is_valid_number, '静岡県伊豆の国市北江間');
ok($zip->set_number('4102301')->is_valid_number, '静岡県伊豆の国市田中山');
ok($zip->set_number('4102302')->is_valid_number, '静岡県伊豆の国市宗光寺');
ok($zip->set_number('4102303')->is_valid_number, '静岡県伊豆の国市立花');
ok($zip->set_number('4102304')->is_valid_number, '静岡県伊豆の国市宗光寺(星和)');
ok($zip->set_number('4102311')->is_valid_number, '静岡県伊豆の国市浮橋');
ok($zip->set_number('4102312')->is_valid_number, '静岡県伊豆の国市長者原');
ok($zip->set_number('4102313')->is_valid_number, '静岡県伊豆の国市田原野');
ok($zip->set_number('4102314')->is_valid_number, '静岡県伊豆の国市下畑');
ok($zip->set_number('4102315')->is_valid_number, '静岡県伊豆の国市田京');
ok($zip->set_number('4102316')->is_valid_number, '静岡県伊豆の国市御門');
ok($zip->set_number('4102317')->is_valid_number, '静岡県伊豆の国市守木');
ok($zip->set_number('4102318')->is_valid_number, '静岡県伊豆の国市白山堂');
ok($zip->set_number('4102321')->is_valid_number, '静岡県伊豆の国市三福');
ok($zip->set_number('4102322')->is_valid_number, '静岡県伊豆の国市吉田');
ok($zip->set_number('4102323')->is_valid_number, '静岡県伊豆の国市大仁');
ok($zip->set_number('4102324')->is_valid_number, '静岡県伊豆の国市中島');
ok($zip->set_number('4102325')->is_valid_number, '静岡県伊豆の国市神島');
ok($zip->set_number('4102400')->is_valid_number, '静岡県伊豆市以下に掲載がない場合');
ok($zip->set_number('4102401')->is_valid_number, '静岡県伊豆市牧之郷');
ok($zip->set_number('4102402')->is_valid_number, '静岡県伊豆市大野');
ok($zip->set_number('4102403')->is_valid_number, '静岡県伊豆市年川');
ok($zip->set_number('4102404')->is_valid_number, '静岡県伊豆市田代');
ok($zip->set_number('4102405')->is_valid_number, '静岡県伊豆市加殿');
ok($zip->set_number('4102406')->is_valid_number, '静岡県伊豆市日向');
ok($zip->set_number('4102407')->is_valid_number, '静岡県伊豆市柏久保');
ok($zip->set_number('4102411')->is_valid_number, '静岡県伊豆市熊坂');
ok($zip->set_number('4102412')->is_valid_number, '静岡県伊豆市瓜生野');
ok($zip->set_number('4102413')->is_valid_number, '静岡県伊豆市小立野');
ok($zip->set_number('4102414')->is_valid_number, '静岡県伊豆市本立野');
ok($zip->set_number('4102415')->is_valid_number, '静岡県伊豆市大平');
ok($zip->set_number('4102416')->is_valid_number, '静岡県伊豆市修善寺');
ok($zip->set_number('4102417')->is_valid_number, '静岡県伊豆市大沢');
ok($zip->set_number('4102418')->is_valid_number, '静岡県伊豆市堀切');
ok($zip->set_number('4102501')->is_valid_number, '静岡県伊豆市下白岩');
ok($zip->set_number('4102502')->is_valid_number, '静岡県伊豆市上白岩');
ok($zip->set_number('4102503')->is_valid_number, '静岡県伊豆市城');
ok($zip->set_number('4102504')->is_valid_number, '静岡県伊豆市関野');
ok($zip->set_number('4102505')->is_valid_number, '静岡県伊豆市八幡');
ok($zip->set_number('4102506')->is_valid_number, '静岡県伊豆市徳永');
ok($zip->set_number('4102507')->is_valid_number, '静岡県伊豆市冷川');
ok($zip->set_number('4102508')->is_valid_number, '静岡県伊豆市柳瀬');
ok($zip->set_number('4102509')->is_valid_number, '静岡県伊豆市梅木');
ok($zip->set_number('4102511')->is_valid_number, '静岡県伊豆市宮上');
ok($zip->set_number('4102512')->is_valid_number, '静岡県伊豆市中原戸');
ok($zip->set_number('4102513')->is_valid_number, '静岡県伊豆市菅引');
ok($zip->set_number('4102514')->is_valid_number, '静岡県伊豆市原保');
ok($zip->set_number('4102515')->is_valid_number, '静岡県伊豆市地蔵堂');
ok($zip->set_number('4102516')->is_valid_number, '静岡県伊豆市筏場');
ok($zip->set_number('4102517')->is_valid_number, '静岡県伊豆市貴僧坊');
ok($zip->set_number('4102518')->is_valid_number, '静岡県伊豆市姫之湯');
ok($zip->set_number('4102519')->is_valid_number, '静岡県伊豆市戸倉野');
ok($zip->set_number('4103201')->is_valid_number, '静岡県伊豆市佐野');
ok($zip->set_number('4103202')->is_valid_number, '静岡県伊豆市雲金');
ok($zip->set_number('4103203')->is_valid_number, '静岡県伊豆市矢熊');
ok($zip->set_number('4103204')->is_valid_number, '静岡県伊豆市田沢');
ok($zip->set_number('4103205')->is_valid_number, '静岡県伊豆市市山');
ok($zip->set_number('4103206')->is_valid_number, '静岡県伊豆市湯ケ島');
ok($zip->set_number('4103207')->is_valid_number, '静岡県伊豆市持越');
ok($zip->set_number('4103208')->is_valid_number, '静岡県伊豆市吉奈');
ok($zip->set_number('4103209')->is_valid_number, '静岡県伊豆市門野原');
ok($zip->set_number('4103211')->is_valid_number, '静岡県伊豆市松ケ瀬');
ok($zip->set_number('4103212')->is_valid_number, '静岡県伊豆市本柿木');
ok($zip->set_number('4103213')->is_valid_number, '静岡県伊豆市青羽根');
ok($zip->set_number('4103214')->is_valid_number, '静岡県伊豆市下船原');
ok($zip->set_number('4103215')->is_valid_number, '静岡県伊豆市月ケ瀬');
ok($zip->set_number('4103216')->is_valid_number, '静岡県伊豆市上船原');
ok($zip->set_number('4103217')->is_valid_number, '静岡県伊豆市大平柿木');
ok($zip->set_number('4103301')->is_valid_number, '静岡県伊豆市小土肥');
ok($zip->set_number('4103302')->is_valid_number, '静岡県伊豆市土肥');
ok($zip->set_number('4103303')->is_valid_number, '静岡県伊豆市八木沢');
ok($zip->set_number('4103304')->is_valid_number, '静岡県伊豆市小下田');
ok($zip->set_number('4103401')->is_valid_number, '静岡県沼津市井田');
ok($zip->set_number('4103402')->is_valid_number, '静岡県沼津市戸田');
ok($zip->set_number('4103500')->is_valid_number, '静岡県賀茂郡西伊豆町以下に掲載がない場合');
ok($zip->set_number('4103501')->is_valid_number, '静岡県賀茂郡西伊豆町宇久須');
ok($zip->set_number('4103502')->is_valid_number, '静岡県賀茂郡西伊豆町安良里');
ok($zip->set_number('4103511')->is_valid_number, '静岡県賀茂郡西伊豆町大沢里');
ok($zip->set_number('4103512')->is_valid_number, '静岡県賀茂郡西伊豆町一色');
ok($zip->set_number('4103513')->is_valid_number, '静岡県賀茂郡西伊豆町中');
ok($zip->set_number('4103514')->is_valid_number, '静岡県賀茂郡西伊豆町仁科');
ok($zip->set_number('4103515')->is_valid_number, '静岡県賀茂郡西伊豆町田子');
ok($zip->set_number('4103600')->is_valid_number, '静岡県賀茂郡松崎町以下に掲載がない場合');
ok($zip->set_number('4103601')->is_valid_number, '静岡県賀茂郡松崎町池代');
ok($zip->set_number('4103602')->is_valid_number, '静岡県賀茂郡松崎町小杉原');
ok($zip->set_number('4103603')->is_valid_number, '静岡県賀茂郡松崎町明伏');
ok($zip->set_number('4103604')->is_valid_number, '静岡県賀茂郡松崎町大沢');
ok($zip->set_number('4103605')->is_valid_number, '静岡県賀茂郡松崎町峰輪');
ok($zip->set_number('4103606')->is_valid_number, '静岡県賀茂郡松崎町船田');
ok($zip->set_number('4103607')->is_valid_number, '静岡県賀茂郡松崎町門野');
ok($zip->set_number('4103611')->is_valid_number, '静岡県賀茂郡松崎町松崎');
ok($zip->set_number('4103612')->is_valid_number, '静岡県賀茂郡松崎町宮内');
ok($zip->set_number('4103613')->is_valid_number, '静岡県賀茂郡松崎町岩科北側');
ok($zip->set_number('4103614')->is_valid_number, '静岡県賀茂郡松崎町岩科南側');
ok($zip->set_number('4103615')->is_valid_number, '静岡県賀茂郡松崎町雲見');
ok($zip->set_number('4103616')->is_valid_number, '静岡県賀茂郡松崎町石部');
ok($zip->set_number('4103617')->is_valid_number, '静岡県賀茂郡松崎町岩地');
ok($zip->set_number('4103618')->is_valid_number, '静岡県賀茂郡松崎町道部');
ok($zip->set_number('4103621')->is_valid_number, '静岡県賀茂郡松崎町吉田');
ok($zip->set_number('4103622')->is_valid_number, '静岡県賀茂郡松崎町南郷');
ok($zip->set_number('4103623')->is_valid_number, '静岡県賀茂郡松崎町伏倉');
ok($zip->set_number('4103624')->is_valid_number, '静岡県賀茂郡松崎町江奈');
ok($zip->set_number('4103625')->is_valid_number, '静岡県賀茂郡松崎町桜田');
ok($zip->set_number('4103626')->is_valid_number, '静岡県賀茂郡松崎町那賀');
ok($zip->set_number('4103627')->is_valid_number, '静岡県賀茂郡松崎町建久寺');
ok($zip->set_number('4110000')->is_valid_number, '静岡県三島市以下に掲載がない場合');
ok($zip->set_number('4110000')->is_valid_number, '静岡県駿東郡清水町以下に掲載がない場合');
ok($zip->set_number('4110000')->is_valid_number, '静岡県駿東郡長泉町以下に掲載がない場合');
ok($zip->set_number('4110001')->is_valid_number, '静岡県田方郡函南町桑原(茨ケ平)');
ok($zip->set_number('4110001')->is_valid_number, '静岡県田方郡函南町桑原(箱根峠)');
ok($zip->set_number('4110011')->is_valid_number, '静岡県三島市山中新田');
ok($zip->set_number('4110012')->is_valid_number, '静岡県三島市笹原新田');
ok($zip->set_number('4110013')->is_valid_number, '静岡県三島市三ツ谷新田');
ok($zip->set_number('4110014')->is_valid_number, '静岡県三島市玉沢');
ok($zip->set_number('4110015')->is_valid_number, '静岡県三島市市山新田');
ok($zip->set_number('4110016')->is_valid_number, '静岡県三島市塚原新田');
ok($zip->set_number('4110017')->is_valid_number, '静岡県三島市三恵台');
ok($zip->set_number('4110018')->is_valid_number, '静岡県三島市初音台');
ok($zip->set_number('4110019')->is_valid_number, '静岡県三島市松が丘');
ok($zip->set_number('4110020')->is_valid_number, '静岡県三島市旭ケ丘');
ok($zip->set_number('4110021')->is_valid_number, '静岡県三島市富士見台');
ok($zip->set_number('4110022')->is_valid_number, '静岡県三島市川原ケ谷');
ok($zip->set_number('4110023')->is_valid_number, '静岡県三島市加茂');
ok($zip->set_number('4110024')->is_valid_number, '静岡県三島市若松町');
ok($zip->set_number('4110025')->is_valid_number, '静岡県三島市壱町田');
ok($zip->set_number('4110026')->is_valid_number, '静岡県三島市東壱町田');
ok($zip->set_number('4110027')->is_valid_number, '静岡県三島市千枚原');
ok($zip->set_number('4110028')->is_valid_number, '静岡県三島市富士ビレッジ');
ok($zip->set_number('4110029')->is_valid_number, '静岡県三島市光ケ丘');
ok($zip->set_number('4110030')->is_valid_number, '静岡県三島市西旭ケ丘町');
ok($zip->set_number('4110031')->is_valid_number, '静岡県三島市幸原町');
ok($zip->set_number('4110032')->is_valid_number, '静岡県三島市末広町');
ok($zip->set_number('4110033')->is_valid_number, '静岡県三島市文教町');
ok($zip->set_number('4110034')->is_valid_number, '静岡県三島市加茂川町');
ok($zip->set_number('4110035')->is_valid_number, '静岡県三島市大宮町');
ok($zip->set_number('4110036')->is_valid_number, '静岡県三島市一番町');
ok($zip->set_number('4110037')->is_valid_number, '静岡県三島市泉町');
ok($zip->set_number('4110038')->is_valid_number, '静岡県三島市西若町');
ok($zip->set_number('4110039')->is_valid_number, '静岡県三島市寿町');
ok($zip->set_number('4110041')->is_valid_number, '静岡県三島市佐野見晴台');
ok($zip->set_number('4110042')->is_valid_number, '静岡県三島市平成台');
ok($zip->set_number('4110043')->is_valid_number, '静岡県三島市沢地');
ok($zip->set_number('4110044')->is_valid_number, '静岡県三島市徳倉');
ok($zip->set_number('4110045')->is_valid_number, '静岡県三島市萩');
ok($zip->set_number('4110046')->is_valid_number, '静岡県三島市芙蓉台');
ok($zip->set_number('4110047')->is_valid_number, '静岡県三島市佐野');
ok($zip->set_number('4110801')->is_valid_number, '静岡県三島市谷田');
ok($zip->set_number('4110802')->is_valid_number, '静岡県三島市東大場');
ok($zip->set_number('4110803')->is_valid_number, '静岡県三島市大場');
ok($zip->set_number('4110804')->is_valid_number, '静岡県三島市多呂');
ok($zip->set_number('4110805')->is_valid_number, '静岡県三島市北沢');
ok($zip->set_number('4110806')->is_valid_number, '静岡県三島市柳郷地');
ok($zip->set_number('4110807')->is_valid_number, '静岡県三島市竹倉');
ok($zip->set_number('4110808')->is_valid_number, '静岡県三島市錦が丘');
ok($zip->set_number('4110811')->is_valid_number, '静岡県三島市青木');
ok($zip->set_number('4110812')->is_valid_number, '静岡県三島市藤代町');
ok($zip->set_number('4110813')->is_valid_number, '静岡県三島市鶴喰');
ok($zip->set_number('4110814')->is_valid_number, '静岡県三島市中島');
ok($zip->set_number('4110815')->is_valid_number, '静岡県三島市安久');
ok($zip->set_number('4110816')->is_valid_number, '静岡県三島市梅名');
ok($zip->set_number('4110817')->is_valid_number, '静岡県三島市八反畑');
ok($zip->set_number('4110821')->is_valid_number, '静岡県三島市平田');
ok($zip->set_number('4110822')->is_valid_number, '静岡県三島市松本');
ok($zip->set_number('4110823')->is_valid_number, '静岡県三島市御園');
ok($zip->set_number('4110824')->is_valid_number, '静岡県三島市長伏');
ok($zip->set_number('4110831')->is_valid_number, '静岡県三島市東本町');
ok($zip->set_number('4110832')->is_valid_number, '静岡県三島市南二日町');
ok($zip->set_number('4110833')->is_valid_number, '静岡県三島市中');
ok($zip->set_number('4110834')->is_valid_number, '静岡県三島市新谷');
ok($zip->set_number('4110835')->is_valid_number, '静岡県三島市玉川');
ok($zip->set_number('4110836')->is_valid_number, '静岡県三島市富田町');
ok($zip->set_number('4110837')->is_valid_number, '静岡県三島市南田町');
ok($zip->set_number('4110838')->is_valid_number, '静岡県三島市中田町');
ok($zip->set_number('4110841')->is_valid_number, '静岡県三島市南本町');
ok($zip->set_number('4110842')->is_valid_number, '静岡県三島市南町');
ok($zip->set_number('4110843')->is_valid_number, '静岡県三島市三好町');
ok($zip->set_number('4110844')->is_valid_number, '静岡県三島市清住町');
ok($zip->set_number('4110845')->is_valid_number, '静岡県三島市加屋町');
ok($zip->set_number('4110846')->is_valid_number, '静岡県三島市栄町');
ok($zip->set_number('4110847')->is_valid_number, '静岡県三島市西本町');
ok($zip->set_number('4110848')->is_valid_number, '静岡県三島市緑町');
ok($zip->set_number('4110851')->is_valid_number, '静岡県三島市日の出町');
ok($zip->set_number('4110852')->is_valid_number, '静岡県三島市東町');
ok($zip->set_number('4110853')->is_valid_number, '静岡県三島市大社町');
ok($zip->set_number('4110854')->is_valid_number, '静岡県三島市北田町');
ok($zip->set_number('4110855')->is_valid_number, '静岡県三島市本町');
ok($zip->set_number('4110856')->is_valid_number, '静岡県三島市広小路町');
ok($zip->set_number('4110857')->is_valid_number, '静岡県三島市芝本町');
ok($zip->set_number('4110858')->is_valid_number, '静岡県三島市中央町');
ok($zip->set_number('4110901')->is_valid_number, '静岡県駿東郡清水町新宿');
ok($zip->set_number('4110902')->is_valid_number, '静岡県駿東郡清水町玉川');
ok($zip->set_number('4110903')->is_valid_number, '静岡県駿東郡清水町堂庭');
ok($zip->set_number('4110904')->is_valid_number, '静岡県駿東郡清水町柿田');
ok($zip->set_number('4110905')->is_valid_number, '静岡県駿東郡清水町長沢');
ok($zip->set_number('4110906')->is_valid_number, '静岡県駿東郡清水町八幡');
ok($zip->set_number('4110907')->is_valid_number, '静岡県駿東郡清水町伏見');
ok($zip->set_number('4110911')->is_valid_number, '静岡県駿東郡清水町久米田');
ok($zip->set_number('4110912')->is_valid_number, '静岡県駿東郡清水町卸団地');
ok($zip->set_number('4110913')->is_valid_number, '静岡県駿東郡清水町戸田');
ok($zip->set_number('4110914')->is_valid_number, '静岡県駿東郡清水町畑中');
ok($zip->set_number('4110915')->is_valid_number, '静岡県駿東郡清水町的場');
ok($zip->set_number('4110916')->is_valid_number, '静岡県駿東郡清水町中徳倉');
ok($zip->set_number('4110917')->is_valid_number, '静岡県駿東郡清水町徳倉(上徳倉、下徳倉、外原)');
ok($zip->set_number('4110918')->is_valid_number, '静岡県駿東郡清水町湯川');
ok($zip->set_number('4110931')->is_valid_number, '静岡県駿東郡長泉町東野');
ok($zip->set_number('4110932')->is_valid_number, '静岡県駿東郡長泉町南一色');
ok($zip->set_number('4110933')->is_valid_number, '静岡県駿東郡長泉町納米里');
ok($zip->set_number('4110934')->is_valid_number, '静岡県駿東郡長泉町下長窪');
ok($zip->set_number('4110935')->is_valid_number, '静岡県駿東郡長泉町上長窪');
ok($zip->set_number('4110936')->is_valid_number, '静岡県駿東郡長泉町元長窪');
ok($zip->set_number('4110941')->is_valid_number, '静岡県駿東郡長泉町上土狩');
ok($zip->set_number('4110942')->is_valid_number, '静岡県駿東郡長泉町中土狩');
ok($zip->set_number('4110943')->is_valid_number, '静岡県駿東郡長泉町下土狩');
ok($zip->set_number('4110944')->is_valid_number, '静岡県駿東郡長泉町竹原');
ok($zip->set_number('4110945')->is_valid_number, '静岡県駿東郡長泉町本宿');
ok($zip->set_number('4110951')->is_valid_number, '静岡県駿東郡長泉町桜堤');
ok($zip->set_number('4120000')->is_valid_number, '静岡県御殿場市以下に掲載がない場合');
ok($zip->set_number('4120001')->is_valid_number, '静岡県御殿場市水土野');
ok($zip->set_number('4120002')->is_valid_number, '静岡県御殿場市上小林');
ok($zip->set_number('4120003')->is_valid_number, '静岡県御殿場市柴怒田');
ok($zip->set_number('4120004')->is_valid_number, '静岡県御殿場市北久原');
ok($zip->set_number('4120005')->is_valid_number, '静岡県御殿場市仁杉');
ok($zip->set_number('4120006')->is_valid_number, '静岡県御殿場市中畑');
ok($zip->set_number('4120007')->is_valid_number, '静岡県御殿場市永塚');
ok($zip->set_number('4120008')->is_valid_number, '静岡県御殿場市印野');
ok($zip->set_number('4120009')->is_valid_number, '静岡県御殿場市川柳');
ok($zip->set_number('4120011')->is_valid_number, '静岡県御殿場市古沢');
ok($zip->set_number('4120012')->is_valid_number, '静岡県御殿場市増田');
ok($zip->set_number('4120013')->is_valid_number, '静岡県御殿場市小倉野');
ok($zip->set_number('4120014')->is_valid_number, '静岡県御殿場市大堰');
ok($zip->set_number('4120015')->is_valid_number, '静岡県御殿場市中丸');
ok($zip->set_number('4120016')->is_valid_number, '静岡県御殿場市六日市場');
ok($zip->set_number('4120017')->is_valid_number, '静岡県御殿場市塚原');
ok($zip->set_number('4120018')->is_valid_number, '静岡県御殿場市山之尻');
ok($zip->set_number('4120019')->is_valid_number, '静岡県御殿場市山尾田');
ok($zip->set_number('4120021')->is_valid_number, '静岡県御殿場市二枚橋');
ok($zip->set_number('4120022')->is_valid_number, '静岡県御殿場市清後');
ok($zip->set_number('4120023')->is_valid_number, '静岡県御殿場市深沢');
ok($zip->set_number('4120024')->is_valid_number, '静岡県御殿場市東山');
ok($zip->set_number('4120025')->is_valid_number, '静岡県御殿場市二の岡');
ok($zip->set_number('4120026')->is_valid_number, '静岡県御殿場市東田中');
ok($zip->set_number('4120027')->is_valid_number, '静岡県御殿場市西田中');
ok($zip->set_number('4120028')->is_valid_number, '静岡県御殿場市御殿場');
ok($zip->set_number('4120029')->is_valid_number, '静岡県御殿場市神山平');
ok($zip->set_number('4120031')->is_valid_number, '静岡県御殿場市沼田');
ok($zip->set_number('4120032')->is_valid_number, '静岡県御殿場市二子');
ok($zip->set_number('4120033')->is_valid_number, '静岡県御殿場市神山');
ok($zip->set_number('4120034')->is_valid_number, '静岡県御殿場市大坂');
ok($zip->set_number('4120035')->is_valid_number, '静岡県御殿場市中山');
ok($zip->set_number('4120036')->is_valid_number, '静岡県御殿場市萩蕪');
ok($zip->set_number('4120037')->is_valid_number, '静岡県御殿場市中清水');
ok($zip->set_number('4120038')->is_valid_number, '静岡県御殿場市駒門');
ok($zip->set_number('4120039')->is_valid_number, '静岡県御殿場市竈');
ok($zip->set_number('4120041')->is_valid_number, '静岡県御殿場市茱萸沢');
ok($zip->set_number('4120042')->is_valid_number, '静岡県御殿場市萩原');
ok($zip->set_number('4120043')->is_valid_number, '静岡県御殿場市新橋');
ok($zip->set_number('4120044')->is_valid_number, '静岡県御殿場市杉名沢');
ok($zip->set_number('4120045')->is_valid_number, '静岡県御殿場市川島田');
ok($zip->set_number('4120046')->is_valid_number, '静岡県御殿場市保土沢');
ok($zip->set_number('4120047')->is_valid_number, '静岡県御殿場市神場');
ok($zip->set_number('4120048')->is_valid_number, '静岡県御殿場市板妻');
ok($zip->set_number('4120051')->is_valid_number, '静岡県御殿場市富士見原');
ok($zip->set_number('4130000')->is_valid_number, '静岡県熱海市以下に掲載がない場合');
ok($zip->set_number('4130001')->is_valid_number, '静岡県熱海市泉');
ok($zip->set_number('4130002')->is_valid_number, '静岡県熱海市伊豆山');
ok($zip->set_number('4130003')->is_valid_number, '静岡県熱海市海光町');
ok($zip->set_number('4130004')->is_valid_number, '静岡県熱海市初島');
ok($zip->set_number('4130005')->is_valid_number, '静岡県熱海市春日町');
ok($zip->set_number('4130006')->is_valid_number, '静岡県熱海市桃山町');
ok($zip->set_number('4130011')->is_valid_number, '静岡県熱海市田原本町');
ok($zip->set_number('4130012')->is_valid_number, '静岡県熱海市東海岸町');
ok($zip->set_number('4130013')->is_valid_number, '静岡県熱海市銀座町');
ok($zip->set_number('4130014')->is_valid_number, '静岡県熱海市渚町');
ok($zip->set_number('4130015')->is_valid_number, '静岡県熱海市中央町');
ok($zip->set_number('4130016')->is_valid_number, '静岡県熱海市水口町');
ok($zip->set_number('4130017')->is_valid_number, '静岡県熱海市福道町');
ok($zip->set_number('4130018')->is_valid_number, '静岡県熱海市上宿町');
ok($zip->set_number('4130019')->is_valid_number, '静岡県熱海市咲見町');
ok($zip->set_number('4130021')->is_valid_number, '静岡県熱海市清水町');
ok($zip->set_number('4130022')->is_valid_number, '静岡県熱海市昭和町');
ok($zip->set_number('4130023')->is_valid_number, '静岡県熱海市和田浜南町');
ok($zip->set_number('4130024')->is_valid_number, '静岡県熱海市和田町');
ok($zip->set_number('4130025')->is_valid_number, '静岡県熱海市桜木町');
ok($zip->set_number('4130026')->is_valid_number, '静岡県熱海市梅花町');
ok($zip->set_number('4130027')->is_valid_number, '静岡県熱海市紅葉ガ丘町');
ok($zip->set_number('4130028')->is_valid_number, '静岡県熱海市桜町');
ok($zip->set_number('4130029')->is_valid_number, '静岡県熱海市小嵐町');
ok($zip->set_number('4130031')->is_valid_number, '静岡県熱海市林ガ丘町');
ok($zip->set_number('4130032')->is_valid_number, '静岡県熱海市梅園町');
ok($zip->set_number('4130033')->is_valid_number, '静岡県熱海市熱海');
ok($zip->set_number('4130034')->is_valid_number, '静岡県熱海市西山町');
ok($zip->set_number('4130035')->is_valid_number, '静岡県熱海市緑ガ丘町');
ok($zip->set_number('4130036')->is_valid_number, '静岡県熱海市日金町');
ok($zip->set_number('4130037')->is_valid_number, '静岡県熱海市笹良ケ台町');
ok($zip->set_number('4130038')->is_valid_number, '静岡県熱海市西熱海町');
ok($zip->set_number('4130039')->is_valid_number, '静岡県熱海市相の原町');
ok($zip->set_number('4130041')->is_valid_number, '静岡県熱海市青葉町');
ok($zip->set_number('4130042')->is_valid_number, '静岡県熱海市山手町');
ok($zip->set_number('4130101')->is_valid_number, '静岡県熱海市上多賀');
ok($zip->set_number('4130102')->is_valid_number, '静岡県熱海市下多賀');
ok($zip->set_number('4130103')->is_valid_number, '静岡県熱海市網代');
ok($zip->set_number('4130111')->is_valid_number, '静岡県伊東市グリーンヒル別荘地');
ok($zip->set_number('4130231')->is_valid_number, '静岡県伊東市富戸');
ok($zip->set_number('4130232')->is_valid_number, '静岡県伊東市八幡野');
ok($zip->set_number('4130233')->is_valid_number, '静岡県伊東市赤沢');
ok($zip->set_number('4130234')->is_valid_number, '静岡県伊東市池');
ok($zip->set_number('4130235')->is_valid_number, '静岡県伊東市大室高原');
ok($zip->set_number('4130300')->is_valid_number, '静岡県賀茂郡東伊豆町以下に掲載がない場合');
ok($zip->set_number('4130301')->is_valid_number, '静岡県賀茂郡東伊豆町大川');
ok($zip->set_number('4130302')->is_valid_number, '静岡県賀茂郡東伊豆町奈良本');
ok($zip->set_number('4130302')->is_valid_number, '静岡県賀茂郡東伊豆町北川');
ok($zip->set_number('4130303')->is_valid_number, '静岡県賀茂郡東伊豆町片瀬');
ok($zip->set_number('4130304')->is_valid_number, '静岡県賀茂郡東伊豆町白田');
ok($zip->set_number('4130411')->is_valid_number, '静岡県賀茂郡東伊豆町稲取');
ok($zip->set_number('4130500')->is_valid_number, '静岡県賀茂郡河津町以下に掲載がない場合');
ok($zip->set_number('4130501')->is_valid_number, '静岡県賀茂郡河津町梨本');
ok($zip->set_number('4130502')->is_valid_number, '静岡県賀茂郡河津町川津筏場');
ok($zip->set_number('4130503')->is_valid_number, '静岡県賀茂郡河津町見高');
ok($zip->set_number('4130504')->is_valid_number, '静岡県賀茂郡河津町田中');
ok($zip->set_number('4130505')->is_valid_number, '静岡県賀茂郡河津町沢田');
ok($zip->set_number('4130506')->is_valid_number, '静岡県賀茂郡河津町下佐ケ野');
ok($zip->set_number('4130507')->is_valid_number, '静岡県賀茂郡河津町湯ケ野');
ok($zip->set_number('4130508')->is_valid_number, '静岡県賀茂郡河津町小鍋');
ok($zip->set_number('4130509')->is_valid_number, '静岡県賀茂郡河津町大鍋');
ok($zip->set_number('4130511')->is_valid_number, '静岡県賀茂郡河津町峰');
ok($zip->set_number('4130512')->is_valid_number, '静岡県賀茂郡河津町笹原');
ok($zip->set_number('4130513')->is_valid_number, '静岡県賀茂郡河津町浜');
ok($zip->set_number('4130514')->is_valid_number, '静岡県賀茂郡河津町縄地');
ok($zip->set_number('4130515')->is_valid_number, '静岡県賀茂郡河津町谷津');
ok($zip->set_number('4130516')->is_valid_number, '静岡県賀茂郡河津町逆川');
ok($zip->set_number('4130701')->is_valid_number, '静岡県下田市落合');
ok($zip->set_number('4130702')->is_valid_number, '静岡県下田市堀之内');
ok($zip->set_number('4130703')->is_valid_number, '静岡県下田市荒増');
ok($zip->set_number('4130704')->is_valid_number, '静岡県下田市椎原');
ok($zip->set_number('4130705')->is_valid_number, '静岡県下田市箕作');
ok($zip->set_number('4130711')->is_valid_number, '静岡県下田市相玉');
ok($zip->set_number('4130712')->is_valid_number, '静岡県下田市横川');
ok($zip->set_number('4130713')->is_valid_number, '静岡県下田市加増野');
ok($zip->set_number('4130714')->is_valid_number, '静岡県下田市北湯ケ野');
ok($zip->set_number('4130715')->is_valid_number, '静岡県下田市宇土金');
ok($zip->set_number('4130716')->is_valid_number, '静岡県下田市須原');
ok($zip->set_number('4140000')->is_valid_number, '静岡県伊東市以下に掲載がない場合');
ok($zip->set_number('4140001')->is_valid_number, '静岡県伊東市宇佐美');
ok($zip->set_number('4140002')->is_valid_number, '静岡県伊東市湯川');
ok($zip->set_number('4140003')->is_valid_number, '静岡県伊東市中央町');
ok($zip->set_number('4140004')->is_valid_number, '静岡県伊東市猪戸');
ok($zip->set_number('4140005')->is_valid_number, '静岡県伊東市松原湯端町');
ok($zip->set_number('4140006')->is_valid_number, '静岡県伊東市松原');
ok($zip->set_number('4140011')->is_valid_number, '静岡県伊東市松川町');
ok($zip->set_number('4140012')->is_valid_number, '静岡県伊東市宝町');
ok($zip->set_number('4140013')->is_valid_number, '静岡県伊東市桜木町');
ok($zip->set_number('4140014')->is_valid_number, '静岡県伊東市弥生町');
ok($zip->set_number('4140015')->is_valid_number, '静岡県伊東市末広町');
ok($zip->set_number('4140016')->is_valid_number, '静岡県伊東市岡広町');
ok($zip->set_number('4140017')->is_valid_number, '静岡県伊東市幸町');
ok($zip->set_number('4140018')->is_valid_number, '静岡県伊東市寿町');
ok($zip->set_number('4140021')->is_valid_number, '静岡県伊東市松原本町');
ok($zip->set_number('4140022')->is_valid_number, '静岡県伊東市東松原町');
ok($zip->set_number('4140023')->is_valid_number, '静岡県伊東市渚町');
ok($zip->set_number('4140024')->is_valid_number, '静岡県伊東市和田');
ok($zip->set_number('4140025')->is_valid_number, '静岡県伊東市物見が丘');
ok($zip->set_number('4140026')->is_valid_number, '静岡県伊東市竹の台');
ok($zip->set_number('4140027')->is_valid_number, '静岡県伊東市竹の内');
ok($zip->set_number('4140028')->is_valid_number, '静岡県伊東市銀座元町');
ok($zip->set_number('4140031')->is_valid_number, '静岡県伊東市湯田町');
ok($zip->set_number('4140032')->is_valid_number, '静岡県伊東市音無町');
ok($zip->set_number('4140033')->is_valid_number, '静岡県伊東市馬場町');
ok($zip->set_number('4140034')->is_valid_number, '静岡県伊東市瓶山');
ok($zip->set_number('4140035')->is_valid_number, '静岡県伊東市南町');
ok($zip->set_number('4140036')->is_valid_number, '静岡県伊東市宮川町');
ok($zip->set_number('4140037')->is_valid_number, '静岡県伊東市桜ガ丘');
ok($zip->set_number('4140038')->is_valid_number, '静岡県伊東市広野');
ok($zip->set_number('4140041')->is_valid_number, '静岡県伊東市芝町');
ok($zip->set_number('4140042')->is_valid_number, '静岡県伊東市静海町');
ok($zip->set_number('4140043')->is_valid_number, '静岡県伊東市新井');
ok($zip->set_number('4140044')->is_valid_number, '静岡県伊東市川奈');
ok($zip->set_number('4140045')->is_valid_number, '静岡県伊東市玖須美元和田');
ok($zip->set_number('4140046')->is_valid_number, '静岡県伊東市大原');
ok($zip->set_number('4140051')->is_valid_number, '静岡県伊東市吉田');
ok($zip->set_number('4140052')->is_valid_number, '静岡県伊東市十足');
ok($zip->set_number('4140053')->is_valid_number, '静岡県伊東市荻');
ok($zip->set_number('4140054')->is_valid_number, '静岡県伊東市鎌田');
ok($zip->set_number('4140055')->is_valid_number, '静岡県伊東市岡');
ok($zip->set_number('4150000')->is_valid_number, '静岡県下田市以下に掲載がない場合');
ok($zip->set_number('4150001')->is_valid_number, '静岡県下田市下田市の次に番地がくる場合');
ok($zip->set_number('4150011')->is_valid_number, '静岡県下田市河内');
ok($zip->set_number('4150012')->is_valid_number, '静岡県下田市白浜');
ok($zip->set_number('4150013')->is_valid_number, '静岡県下田市柿崎');
ok($zip->set_number('4150014')->is_valid_number, '静岡県下田市須崎');
ok($zip->set_number('4150015')->is_valid_number, '静岡県下田市武ガ浜');
ok($zip->set_number('4150016')->is_valid_number, '静岡県下田市中');
ok($zip->set_number('4150017')->is_valid_number, '静岡県下田市東中');
ok($zip->set_number('4150018')->is_valid_number, '静岡県下田市西中');
ok($zip->set_number('4150021')->is_valid_number, '静岡県下田市一丁目');
ok($zip->set_number('4150022')->is_valid_number, '静岡県下田市二丁目');
ok($zip->set_number('4150023')->is_valid_number, '静岡県下田市三丁目');
ok($zip->set_number('4150024')->is_valid_number, '静岡県下田市四丁目');
ok($zip->set_number('4150025')->is_valid_number, '静岡県下田市五丁目');
ok($zip->set_number('4150026')->is_valid_number, '静岡県下田市六丁目');
ok($zip->set_number('4150027')->is_valid_number, '静岡県下田市旧岡方村');
ok($zip->set_number('4150028')->is_valid_number, '静岡県下田市吉佐美');
ok($zip->set_number('4150029')->is_valid_number, '静岡県下田市田牛');
ok($zip->set_number('4150031')->is_valid_number, '静岡県下田市蓮台寺');
ok($zip->set_number('4150032')->is_valid_number, '静岡県下田市立野');
ok($zip->set_number('4150033')->is_valid_number, '静岡県下田市本郷');
ok($zip->set_number('4150034')->is_valid_number, '静岡県下田市高馬');
ok($zip->set_number('4150035')->is_valid_number, '静岡県下田市東本郷');
ok($zip->set_number('4150036')->is_valid_number, '静岡県下田市西本郷');
ok($zip->set_number('4150037')->is_valid_number, '静岡県下田市敷根');
ok($zip->set_number('4150038')->is_valid_number, '静岡県下田市大賀茂');
ok($zip->set_number('4150039')->is_valid_number, '静岡県下田市大沢');
ok($zip->set_number('4150151')->is_valid_number, '静岡県賀茂郡南伊豆町青市');
ok($zip->set_number('4150152')->is_valid_number, '静岡県賀茂郡南伊豆町湊');
ok($zip->set_number('4150153')->is_valid_number, '静岡県賀茂郡南伊豆町手石');
ok($zip->set_number('4150154')->is_valid_number, '静岡県賀茂郡南伊豆町下流');
ok($zip->set_number('4150155')->is_valid_number, '静岡県賀茂郡南伊豆町大瀬');
ok($zip->set_number('4150156')->is_valid_number, '静岡県賀茂郡南伊豆町石廊崎');
ok($zip->set_number('4150300')->is_valid_number, '静岡県賀茂郡南伊豆町以下に掲載がない場合');
ok($zip->set_number('4150301')->is_valid_number, '静岡県賀茂郡南伊豆町一條');
ok($zip->set_number('4150302')->is_valid_number, '静岡県賀茂郡南伊豆町上賀茂');
ok($zip->set_number('4150303')->is_valid_number, '静岡県賀茂郡南伊豆町下賀茂');
ok($zip->set_number('4150304')->is_valid_number, '静岡県賀茂郡南伊豆町加納');
ok($zip->set_number('4150305')->is_valid_number, '静岡県賀茂郡南伊豆町二條');
ok($zip->set_number('4150306')->is_valid_number, '静岡県賀茂郡南伊豆町石井');
ok($zip->set_number('4150311')->is_valid_number, '静岡県賀茂郡南伊豆町中木');
ok($zip->set_number('4150312')->is_valid_number, '静岡県賀茂郡南伊豆町入間');
ok($zip->set_number('4150312')->is_valid_number, '静岡県賀茂郡南伊豆町差田');
ok($zip->set_number('4150313')->is_valid_number, '静岡県賀茂郡南伊豆町一色');
ok($zip->set_number('4150314')->is_valid_number, '静岡県賀茂郡南伊豆町蝶ケ野');
ok($zip->set_number('4150321')->is_valid_number, '静岡県賀茂郡南伊豆町毛倉野');
ok($zip->set_number('4150322')->is_valid_number, '静岡県賀茂郡南伊豆町岩殿');
ok($zip->set_number('4150323')->is_valid_number, '静岡県賀茂郡南伊豆町川合野');
ok($zip->set_number('4150323')->is_valid_number, '静岡県賀茂郡南伊豆町下小野');
ok($zip->set_number('4150324')->is_valid_number, '静岡県賀茂郡南伊豆町上小野');
ok($zip->set_number('4150325')->is_valid_number, '静岡県賀茂郡南伊豆町市之瀬');
ok($zip->set_number('4150325')->is_valid_number, '静岡県賀茂郡南伊豆町平戸');
ok($zip->set_number('4150326')->is_valid_number, '静岡県賀茂郡南伊豆町蛇石');
ok($zip->set_number('4150327')->is_valid_number, '静岡県賀茂郡南伊豆町青野');
ok($zip->set_number('4150531')->is_valid_number, '静岡県賀茂郡南伊豆町一町田');
ok($zip->set_number('4150531')->is_valid_number, '静岡県賀茂郡南伊豆町伊浜');
ok($zip->set_number('4150531')->is_valid_number, '静岡県賀茂郡南伊豆町落居');
ok($zip->set_number('4150531')->is_valid_number, '静岡県賀茂郡南伊豆町天神原');
ok($zip->set_number('4150532')->is_valid_number, '静岡県賀茂郡南伊豆町子浦');
ok($zip->set_number('4150533')->is_valid_number, '静岡県賀茂郡南伊豆町立岩');
ok($zip->set_number('4150533')->is_valid_number, '静岡県賀茂郡南伊豆町妻良');
ok($zip->set_number('4150533')->is_valid_number, '静岡県賀茂郡南伊豆町吉田');
ok($zip->set_number('4160901')->is_valid_number, '静岡県富士市岩本');
ok($zip->set_number('4160902')->is_valid_number, '静岡県富士市長通');
ok($zip->set_number('4160903')->is_valid_number, '静岡県富士市松本');
ok($zip->set_number('4160904')->is_valid_number, '静岡県富士市本市場新田');
ok($zip->set_number('4160905')->is_valid_number, '静岡県富士市五味島');
ok($zip->set_number('4160906')->is_valid_number, '静岡県富士市本市場');
ok($zip->set_number('4160907')->is_valid_number, '静岡県富士市中島');
ok($zip->set_number('4160908')->is_valid_number, '静岡県富士市柚木');
ok($zip->set_number('4160909')->is_valid_number, '静岡県富士市松岡');
ok($zip->set_number('4160911')->is_valid_number, '静岡県富士市八幡町');
ok($zip->set_number('4160912')->is_valid_number, '静岡県富士市加島町');
ok($zip->set_number('4160913')->is_valid_number, '静岡県富士市平垣本町');
ok($zip->set_number('4160914')->is_valid_number, '静岡県富士市本町');
ok($zip->set_number('4160915')->is_valid_number, '静岡県富士市富士町');
ok($zip->set_number('4160916')->is_valid_number, '静岡県富士市平垣');
ok($zip->set_number('4160917')->is_valid_number, '静岡県富士市元町');
ok($zip->set_number('4160918')->is_valid_number, '静岡県富士市平垣町');
ok($zip->set_number('4160919')->is_valid_number, '静岡県富士市松富町');
ok($zip->set_number('4160921')->is_valid_number, '静岡県富士市水戸島');
ok($zip->set_number('4160922')->is_valid_number, '静岡県富士市水戸島元町');
ok($zip->set_number('4160923')->is_valid_number, '静岡県富士市横割本町');
ok($zip->set_number('4160924')->is_valid_number, '静岡県富士市水戸島本町');
ok($zip->set_number('4160931')->is_valid_number, '静岡県富士市蓼原');
ok($zip->set_number('4160932')->is_valid_number, '静岡県富士市柳島');
ok($zip->set_number('4160933')->is_valid_number, '静岡県富士市中丸');
ok($zip->set_number('4160934')->is_valid_number, '静岡県富士市鮫島');
ok($zip->set_number('4160935')->is_valid_number, '静岡県富士市田子');
ok($zip->set_number('4160936')->is_valid_number, '静岡県富士市中河原(その他)');
ok($zip->set_number('4160937')->is_valid_number, '静岡県富士市前田');
ok($zip->set_number('4160938')->is_valid_number, '静岡県富士市浜田町');
ok($zip->set_number('4160939')->is_valid_number, '静岡県富士市川成島');
ok($zip->set_number('4160941')->is_valid_number, '静岡県富士市十兵衛');
ok($zip->set_number('4160942')->is_valid_number, '静岡県富士市上横割');
ok($zip->set_number('4160943')->is_valid_number, '静岡県富士市下横割');
ok($zip->set_number('4160944')->is_valid_number, '静岡県富士市横割');
ok($zip->set_number('4160945')->is_valid_number, '静岡県富士市宮島');
ok($zip->set_number('4160946')->is_valid_number, '静岡県富士市五貫島');
ok($zip->set_number('4160947')->is_valid_number, '静岡県富士市宮下');
ok($zip->set_number('4160948')->is_valid_number, '静岡県富士市森島');
ok($zip->set_number('4160949')->is_valid_number, '静岡県富士市森下');
ok($zip->set_number('4160951')->is_valid_number, '静岡県富士市米之宮町');
ok($zip->set_number('4160952')->is_valid_number, '静岡県富士市青葉町');
ok($zip->set_number('4160953')->is_valid_number, '静岡県富士市蓼原町');
ok($zip->set_number('4160954')->is_valid_number, '静岡県富士市本市場町');
ok($zip->set_number('4160955')->is_valid_number, '静岡県富士市川成新町');
ok($zip->set_number('4170000')->is_valid_number, '静岡県富士市以下に掲載がない場合');
ok($zip->set_number('4170001')->is_valid_number, '静岡県富士市今泉');
ok($zip->set_number('4170002')->is_valid_number, '静岡県富士市依田橋');
ok($zip->set_number('4170003')->is_valid_number, '静岡県富士市依田橋町');
ok($zip->set_number('4170004')->is_valid_number, '静岡県富士市新橋町');
ok($zip->set_number('4170011')->is_valid_number, '静岡県富士市鈴川本町');
ok($zip->set_number('4170012')->is_valid_number, '静岡県富士市鈴川東町');
ok($zip->set_number('4170013')->is_valid_number, '静岡県富士市鈴川中町');
ok($zip->set_number('4170014')->is_valid_number, '静岡県富士市鈴川西町');
ok($zip->set_number('4170015')->is_valid_number, '静岡県富士市鈴川町');
ok($zip->set_number('4170021')->is_valid_number, '静岡県富士市依田原');
ok($zip->set_number('4170022')->is_valid_number, '静岡県富士市依田原町');
ok($zip->set_number('4170023')->is_valid_number, '静岡県富士市吉原宝町');
ok($zip->set_number('4170024')->is_valid_number, '静岡県富士市八代町');
ok($zip->set_number('4170025')->is_valid_number, '静岡県富士市瓜島');
ok($zip->set_number('4170026')->is_valid_number, '静岡県富士市南町');
ok($zip->set_number('4170031')->is_valid_number, '静岡県富士市田島');
ok($zip->set_number('4170032')->is_valid_number, '静岡県富士市田島新田');
ok($zip->set_number('4170033')->is_valid_number, '静岡県富士市島田町');
ok($zip->set_number('4170034')->is_valid_number, '静岡県富士市津田');
ok($zip->set_number('4170035')->is_valid_number, '静岡県富士市津田町');
ok($zip->set_number('4170036')->is_valid_number, '静岡県富士市中河原(66、88、93、197、292-4、315番地)');
ok($zip->set_number('4170037')->is_valid_number, '静岡県富士市外木');
ok($zip->set_number('4170041')->is_valid_number, '静岡県富士市御幸町');
ok($zip->set_number('4170042')->is_valid_number, '静岡県富士市荒田島');
ok($zip->set_number('4170043')->is_valid_number, '静岡県富士市荒田島町');
ok($zip->set_number('4170044')->is_valid_number, '静岡県富士市高嶺町');
ok($zip->set_number('4170045')->is_valid_number, '静岡県富士市錦町');
ok($zip->set_number('4170046')->is_valid_number, '静岡県富士市青島');
ok($zip->set_number('4170047')->is_valid_number, '静岡県富士市青島町');
ok($zip->set_number('4170048')->is_valid_number, '静岡県富士市高島町');
ok($zip->set_number('4170049')->is_valid_number, '静岡県富士市緑町');
ok($zip->set_number('4170051')->is_valid_number, '静岡県富士市吉原');
ok($zip->set_number('4170052')->is_valid_number, '静岡県富士市中央町');
ok($zip->set_number('4170053')->is_valid_number, '静岡県富士市依田原新田');
ok($zip->set_number('4170054')->is_valid_number, '静岡県富士市永田');
ok($zip->set_number('4170055')->is_valid_number, '静岡県富士市永田町');
ok($zip->set_number('4170056')->is_valid_number, '静岡県富士市日乃出町');
ok($zip->set_number('4170057')->is_valid_number, '静岡県富士市瓜島町');
ok($zip->set_number('4170058')->is_valid_number, '静岡県富士市永田北町');
ok($zip->set_number('4170061')->is_valid_number, '静岡県富士市伝法');
ok($zip->set_number('4170062')->is_valid_number, '静岡県富士市香西');
ok($zip->set_number('4170063')->is_valid_number, '静岡県富士市香西新田');
ok($zip->set_number('4170064')->is_valid_number, '静岡県富士市弥生');
ok($zip->set_number('4170065')->is_valid_number, '静岡県富士市弥生新田');
ok($zip->set_number('4170071')->is_valid_number, '静岡県富士市国久保');
ok($zip->set_number('4170072')->is_valid_number, '静岡県富士市浅間上町');
ok($zip->set_number('4170073')->is_valid_number, '静岡県富士市浅間本町');
ok($zip->set_number('4170801')->is_valid_number, '静岡県富士市大淵');
ok($zip->set_number('4170802')->is_valid_number, '静岡県富士市今宮');
ok($zip->set_number('4170803')->is_valid_number, '静岡県富士市桑崎');
ok($zip->set_number('4170804')->is_valid_number, '静岡県富士市石井');
ok($zip->set_number('4170805')->is_valid_number, '静岡県富士市鵜無ケ淵');
ok($zip->set_number('4170806')->is_valid_number, '静岡県富士市間門');
ok($zip->set_number('4170807')->is_valid_number, '静岡県富士市神戸');
ok($zip->set_number('4170808')->is_valid_number, '静岡県富士市一色');
ok($zip->set_number('4170809')->is_valid_number, '静岡県富士市中野');
ok($zip->set_number('4170811')->is_valid_number, '静岡県富士市江尾');
ok($zip->set_number('4170812')->is_valid_number, '静岡県富士市境');
ok($zip->set_number('4170813')->is_valid_number, '静岡県富士市船津');
ok($zip->set_number('4170814')->is_valid_number, '静岡県富士市西船津');
ok($zip->set_number('4170815')->is_valid_number, '静岡県富士市増川');
ok($zip->set_number('4170816')->is_valid_number, '静岡県富士市増川新町');
ok($zip->set_number('4170817')->is_valid_number, '静岡県富士市江尾南');
ok($zip->set_number('4170821')->is_valid_number, '静岡県富士市神谷');
ok($zip->set_number('4170822')->is_valid_number, '静岡県富士市神谷新町');
ok($zip->set_number('4170823')->is_valid_number, '静岡県富士市神谷南');
ok($zip->set_number('4170824')->is_valid_number, '静岡県富士市川尻東');
ok($zip->set_number('4170825')->is_valid_number, '静岡県富士市川尻');
ok($zip->set_number('4170826')->is_valid_number, '静岡県富士市中里');
ok($zip->set_number('4170831')->is_valid_number, '静岡県富士市東柏原新田');
ok($zip->set_number('4170832')->is_valid_number, '静岡県富士市中柏原新田');
ok($zip->set_number('4170833')->is_valid_number, '静岡県富士市沼田新田');
ok($zip->set_number('4170834')->is_valid_number, '静岡県富士市西柏原新田');
ok($zip->set_number('4170835')->is_valid_number, '静岡県富士市柏原');
ok($zip->set_number('4170841')->is_valid_number, '静岡県富士市富士岡');
ok($zip->set_number('4170842')->is_valid_number, '静岡県富士市三新田');
ok($zip->set_number('4170843')->is_valid_number, '静岡県富士市田中新田');
ok($zip->set_number('4170844')->is_valid_number, '静岡県富士市檜新田');
ok($zip->set_number('4170845')->is_valid_number, '静岡県富士市大野新田');
ok($zip->set_number('4170846')->is_valid_number, '静岡県富士市今井');
ok($zip->set_number('4170847')->is_valid_number, '静岡県富士市比奈');
ok($zip->set_number('4170848')->is_valid_number, '静岡県富士市大野');
ok($zip->set_number('4170851')->is_valid_number, '静岡県富士市富士見台');
ok($zip->set_number('4170852')->is_valid_number, '静岡県富士市原田');
ok($zip->set_number('4170853')->is_valid_number, '静岡県富士市宇東川東町');
ok($zip->set_number('4170854')->is_valid_number, '静岡県富士市宇東川西町');
ok($zip->set_number('4170855')->is_valid_number, '静岡県富士市三ツ沢');
ok($zip->set_number('4170856')->is_valid_number, '静岡県富士市さんどまき');
ok($zip->set_number('4170861')->is_valid_number, '静岡県富士市広見東本町');
ok($zip->set_number('4170862')->is_valid_number, '静岡県富士市石坂');
ok($zip->set_number('4170863')->is_valid_number, '静岡県富士市広見西本町');
ok($zip->set_number('4170864')->is_valid_number, '静岡県富士市広見本町');
ok($zip->set_number('4180000')->is_valid_number, '静岡県富士宮市以下に掲載がない場合');
ok($zip->set_number('4180001')->is_valid_number, '静岡県富士宮市万野原新田');
ok($zip->set_number('4180002')->is_valid_number, '静岡県富士宮市中原町');
ok($zip->set_number('4180003')->is_valid_number, '静岡県富士宮市ひばりが丘');
ok($zip->set_number('4180004')->is_valid_number, '静岡県富士宮市三園平');
ok($zip->set_number('4180005')->is_valid_number, '静岡県富士宮市宮原');
ok($zip->set_number('4180006')->is_valid_number, '静岡県富士宮市外神');
ok($zip->set_number('4180007')->is_valid_number, '静岡県富士宮市外神東町');
ok($zip->set_number('4180011')->is_valid_number, '静岡県富士宮市粟倉');
ok($zip->set_number('4180012')->is_valid_number, '静岡県富士宮市村山');
ok($zip->set_number('4180013')->is_valid_number, '静岡県富士宮市大岩');
ok($zip->set_number('4180014')->is_valid_number, '静岡県富士宮市富士見ケ丘');
ok($zip->set_number('4180015')->is_valid_number, '静岡県富士宮市舞々木町');
ok($zip->set_number('4180016')->is_valid_number, '静岡県富士宮市阿幸地');
ok($zip->set_number('4180017')->is_valid_number, '静岡県富士宮市舟久保町');
ok($zip->set_number('4180018')->is_valid_number, '静岡県富士宮市粟倉南町');
ok($zip->set_number('4180019')->is_valid_number, '静岡県富士宮市南陵');
ok($zip->set_number('4180021')->is_valid_number, '静岡県富士宮市杉田');
ok($zip->set_number('4180022')->is_valid_number, '静岡県富士宮市小泉');
ok($zip->set_number('4180023')->is_valid_number, '静岡県富士宮市山本');
ok($zip->set_number('4180024')->is_valid_number, '静岡県富士宮市貫戸');
ok($zip->set_number('4180025')->is_valid_number, '静岡県富士宮市前田町');
ok($zip->set_number('4180026')->is_valid_number, '静岡県富士宮市西小泉町');
ok($zip->set_number('4180031')->is_valid_number, '静岡県富士宮市神田川町');
ok($zip->set_number('4180032')->is_valid_number, '静岡県富士宮市浅間町');
ok($zip->set_number('4180033')->is_valid_number, '静岡県富士宮市野中東町');
ok($zip->set_number('4180034')->is_valid_number, '静岡県富士宮市黒田');
ok($zip->set_number('4180035')->is_valid_number, '静岡県富士宮市星山');
ok($zip->set_number('4180036')->is_valid_number, '静岡県富士宮市沼久保');
ok($zip->set_number('4180037')->is_valid_number, '静岡県富士宮市安居山');
ok($zip->set_number('4180038')->is_valid_number, '静岡県富士宮市野中町');
ok($zip->set_number('4180039')->is_valid_number, '静岡県富士宮市野中');
ok($zip->set_number('4180041')->is_valid_number, '静岡県富士宮市淀川町');
ok($zip->set_number('4180042')->is_valid_number, '静岡県富士宮市貴船町');
ok($zip->set_number('4180043')->is_valid_number, '静岡県富士宮市泉町');
ok($zip->set_number('4180044')->is_valid_number, '静岡県富士宮市大中里');
ok($zip->set_number('4180045')->is_valid_number, '静岡県富士宮市中島町');
ok($zip->set_number('4180046')->is_valid_number, '静岡県富士宮市中里東町');
ok($zip->set_number('4180047')->is_valid_number, '静岡県富士宮市青木');
ok($zip->set_number('4180048')->is_valid_number, '静岡県富士宮市青木平');
ok($zip->set_number('4180051')->is_valid_number, '静岡県富士宮市淀師');
ok($zip->set_number('4180052')->is_valid_number, '静岡県富士宮市淀平町');
ok($zip->set_number('4180053')->is_valid_number, '静岡県富士宮市宮北町');
ok($zip->set_number('4180054')->is_valid_number, '静岡県富士宮市光町');
ok($zip->set_number('4180055')->is_valid_number, '静岡県富士宮市宝町');
ok($zip->set_number('4180056')->is_valid_number, '静岡県富士宮市西町');
ok($zip->set_number('4180057')->is_valid_number, '静岡県富士宮市朝日町');
ok($zip->set_number('4180058')->is_valid_number, '静岡県富士宮市穂波町');
ok($zip->set_number('4180061')->is_valid_number, '静岡県富士宮市北町');
ok($zip->set_number('4180062')->is_valid_number, '静岡県富士宮市城北町');
ok($zip->set_number('4180063')->is_valid_number, '静岡県富士宮市若の宮町');
ok($zip->set_number('4180064')->is_valid_number, '静岡県富士宮市元城町');
ok($zip->set_number('4180065')->is_valid_number, '静岡県富士宮市中央町');
ok($zip->set_number('4180066')->is_valid_number, '静岡県富士宮市大宮町');
ok($zip->set_number('4180067')->is_valid_number, '静岡県富士宮市宮町');
ok($zip->set_number('4180068')->is_valid_number, '静岡県富士宮市豊町');
ok($zip->set_number('4180071')->is_valid_number, '静岡県富士宮市東阿幸地');
ok($zip->set_number('4180072')->is_valid_number, '静岡県富士宮市矢立町');
ok($zip->set_number('4180073')->is_valid_number, '静岡県富士宮市弓沢町');
ok($zip->set_number('4180074')->is_valid_number, '静岡県富士宮市源道寺町');
ok($zip->set_number('4180075')->is_valid_number, '静岡県富士宮市田中町');
ok($zip->set_number('4180076')->is_valid_number, '静岡県富士宮市錦町');
ok($zip->set_number('4180077')->is_valid_number, '静岡県富士宮市東町');
ok($zip->set_number('4180078')->is_valid_number, '静岡県富士宮市阿幸地町');
ok($zip->set_number('4180101')->is_valid_number, '静岡県富士宮市根原');
ok($zip->set_number('4180102')->is_valid_number, '静岡県富士宮市人穴');
ok($zip->set_number('4180103')->is_valid_number, '静岡県富士宮市上井出');
ok($zip->set_number('4180104')->is_valid_number, '静岡県富士宮市内野');
ok($zip->set_number('4180105')->is_valid_number, '静岡県富士宮市原');
ok($zip->set_number('4180106')->is_valid_number, '静岡県富士宮市半野');
ok($zip->set_number('4180107')->is_valid_number, '静岡県富士宮市佐折');
ok($zip->set_number('4180108')->is_valid_number, '静岡県富士宮市猪之頭');
ok($zip->set_number('4180109')->is_valid_number, '静岡県富士宮市麓');
ok($zip->set_number('4180111')->is_valid_number, '静岡県富士宮市山宮');
ok($zip->set_number('4180112')->is_valid_number, '静岡県富士宮市北山');
ok($zip->set_number('4180113')->is_valid_number, '静岡県富士宮市馬見塚');
ok($zip->set_number('4180114')->is_valid_number, '静岡県富士宮市下条');
ok($zip->set_number('4180115')->is_valid_number, '静岡県富士宮市精進川');
ok($zip->set_number('4180116')->is_valid_number, '静岡県富士宮市上条');
ok($zip->set_number('4180117')->is_valid_number, '静岡県富士宮市狩宿');
ok($zip->set_number('4190100')->is_valid_number, '静岡県田方郡函南町以下に掲載がない場合');
ok($zip->set_number('4190101')->is_valid_number, '静岡県田方郡函南町桑原(その他)');
ok($zip->set_number('4190102')->is_valid_number, '静岡県田方郡函南町田代');
ok($zip->set_number('4190103')->is_valid_number, '静岡県田方郡函南町軽井沢');
ok($zip->set_number('4190104')->is_valid_number, '静岡県田方郡函南町畑');
ok($zip->set_number('4190105')->is_valid_number, '静岡県田方郡函南町丹那');
ok($zip->set_number('4190106')->is_valid_number, '静岡県田方郡函南町南箱根ダイヤランド');
ok($zip->set_number('4190107')->is_valid_number, '静岡県田方郡函南町平井');
ok($zip->set_number('4190111')->is_valid_number, '静岡県田方郡函南町畑毛');
ok($zip->set_number('4190112')->is_valid_number, '静岡県田方郡函南町柏谷');
ok($zip->set_number('4190113')->is_valid_number, '静岡県田方郡函南町大土肥');
ok($zip->set_number('4190114')->is_valid_number, '静岡県田方郡函南町仁田');
ok($zip->set_number('4190115')->is_valid_number, '静岡県田方郡函南町新田');
ok($zip->set_number('4190116')->is_valid_number, '静岡県田方郡函南町日守');
ok($zip->set_number('4190121')->is_valid_number, '静岡県田方郡函南町大竹');
ok($zip->set_number('4190122')->is_valid_number, '静岡県田方郡函南町上沢');
ok($zip->set_number('4190123')->is_valid_number, '静岡県田方郡函南町間宮');
ok($zip->set_number('4190124')->is_valid_number, '静岡県田方郡函南町塚本');
ok($zip->set_number('4190125')->is_valid_number, '静岡県田方郡函南町肥田');
ok($zip->set_number('4190201')->is_valid_number, '静岡県富士市厚原');
ok($zip->set_number('4190202')->is_valid_number, '静岡県富士市久沢');
ok($zip->set_number('4190203')->is_valid_number, '静岡県富士市鷹岡本町');
ok($zip->set_number('4190204')->is_valid_number, '静岡県富士市入山瀬');
ok($zip->set_number('4190205')->is_valid_number, '静岡県富士市天間');
ok($zip->set_number('4190301')->is_valid_number, '静岡県富士宮市上柚野');
ok($zip->set_number('4190302')->is_valid_number, '静岡県富士宮市猫沢');
ok($zip->set_number('4190303')->is_valid_number, '静岡県富士宮市大鹿窪');
ok($zip->set_number('4190304')->is_valid_number, '静岡県富士宮市鳥並');
ok($zip->set_number('4190305')->is_valid_number, '静岡県富士宮市下柚野');
ok($zip->set_number('4190311')->is_valid_number, '静岡県富士宮市上稲子');
ok($zip->set_number('4190312')->is_valid_number, '静岡県富士宮市下稲子');
ok($zip->set_number('4190313')->is_valid_number, '静岡県富士宮市西山');
ok($zip->set_number('4190314')->is_valid_number, '静岡県富士宮市大久保');
ok($zip->set_number('4190315')->is_valid_number, '静岡県富士宮市長貫');
ok($zip->set_number('4190316')->is_valid_number, '静岡県富士宮市羽鮒');
ok($zip->set_number('4190317')->is_valid_number, '静岡県富士宮市内房');
ok($zip->set_number('4200001')->is_valid_number, '静岡県静岡市葵区井宮町');
ok($zip->set_number('4200002')->is_valid_number, '静岡県静岡市葵区材木町');
ok($zip->set_number('4200003')->is_valid_number, '静岡県静岡市葵区片羽町');
ok($zip->set_number('4200004')->is_valid_number, '静岡県静岡市葵区末広町');
ok($zip->set_number('4200005')->is_valid_number, '静岡県静岡市葵区北番町');
ok($zip->set_number('4200006')->is_valid_number, '静岡県静岡市葵区若松町');
ok($zip->set_number('4200007')->is_valid_number, '静岡県静岡市葵区柳町');
ok($zip->set_number('4200008')->is_valid_number, '静岡県静岡市葵区水道町');
ok($zip->set_number('4200009')->is_valid_number, '静岡県静岡市葵区神明町');
ok($zip->set_number('4200011')->is_valid_number, '静岡県静岡市葵区安西');
ok($zip->set_number('4200012')->is_valid_number, '静岡県静岡市葵区柚木町');
ok($zip->set_number('4200013')->is_valid_number, '静岡県静岡市葵区八千代町');
ok($zip->set_number('4200014')->is_valid_number, '静岡県静岡市葵区上桶屋町');
ok($zip->set_number('4200015')->is_valid_number, '静岡県静岡市葵区錦町');
ok($zip->set_number('4200016')->is_valid_number, '静岡県静岡市葵区住吉町');
ok($zip->set_number('4200017')->is_valid_number, '静岡県静岡市葵区葵町');
ok($zip->set_number('4200018')->is_valid_number, '静岡県静岡市葵区土太夫町');
ok($zip->set_number('4200021')->is_valid_number, '静岡県静岡市葵区茶町');
ok($zip->set_number('4200022')->is_valid_number, '静岡県静岡市葵区車町');
ok($zip->set_number('4200023')->is_valid_number, '静岡県静岡市葵区富士見町');
ok($zip->set_number('4200024')->is_valid_number, '静岡県静岡市葵区中町');
ok($zip->set_number('4200025')->is_valid_number, '静岡県静岡市葵区金座町');
ok($zip->set_number('4200026')->is_valid_number, '静岡県静岡市葵区大鋸町');
ok($zip->set_number('4200027')->is_valid_number, '静岡県静岡市葵区大工町');
ok($zip->set_number('4200028')->is_valid_number, '静岡県静岡市葵区屋形町');
ok($zip->set_number('4200029')->is_valid_number, '静岡県静岡市葵区研屋町');
ok($zip->set_number('4200031')->is_valid_number, '静岡県静岡市葵区呉服町');
ok($zip->set_number('4200032')->is_valid_number, '静岡県静岡市葵区両替町');
ok($zip->set_number('4200033')->is_valid_number, '静岡県静岡市葵区昭和町');
ok($zip->set_number('4200034')->is_valid_number, '静岡県静岡市葵区常磐町');
ok($zip->set_number('4200035')->is_valid_number, '静岡県静岡市葵区七間町');
ok($zip->set_number('4200036')->is_valid_number, '静岡県静岡市葵区駿河町');
ok($zip->set_number('4200037')->is_valid_number, '静岡県静岡市葵区人宿町');
ok($zip->set_number('4200038')->is_valid_number, '静岡県静岡市葵区梅屋町');
ok($zip->set_number('4200039')->is_valid_number, '静岡県静岡市葵区上石町');
ok($zip->set_number('4200041')->is_valid_number, '静岡県静岡市葵区双葉町');
ok($zip->set_number('4200042')->is_valid_number, '静岡県静岡市葵区駒形通');
ok($zip->set_number('4200043')->is_valid_number, '静岡県静岡市葵区川辺町');
ok($zip->set_number('4200044')->is_valid_number, '静岡県静岡市葵区西門町');
ok($zip->set_number('4200045')->is_valid_number, '静岡県静岡市葵区天王町');
ok($zip->set_number('4200046')->is_valid_number, '静岡県静岡市葵区吉野町');
ok($zip->set_number('4200047')->is_valid_number, '静岡県静岡市葵区清閑町');
ok($zip->set_number('4200048')->is_valid_number, '静岡県静岡市葵区桜木町');
ok($zip->set_number('4200051')->is_valid_number, '静岡県静岡市葵区南田町');
ok($zip->set_number('4200052')->is_valid_number, '静岡県静岡市葵区川越町');
ok($zip->set_number('4200053')->is_valid_number, '静岡県静岡市葵区弥勒');
ok($zip->set_number('4200054')->is_valid_number, '静岡県静岡市葵区南安倍(1、2丁目)');
ok($zip->set_number('4200061')->is_valid_number, '静岡県静岡市葵区新富町');
ok($zip->set_number('4200062')->is_valid_number, '静岡県静岡市葵区上新富町');
ok($zip->set_number('4200063')->is_valid_number, '静岡県静岡市葵区通車町');
ok($zip->set_number('4200064')->is_valid_number, '静岡県静岡市葵区本通');
ok($zip->set_number('4200065')->is_valid_number, '静岡県静岡市葵区新通');
ok($zip->set_number('4200066')->is_valid_number, '静岡県静岡市葵区本通西町');
ok($zip->set_number('4200067')->is_valid_number, '静岡県静岡市葵区幸町');
ok($zip->set_number('4200068')->is_valid_number, '静岡県静岡市葵区田町');
ok($zip->set_number('4200071')->is_valid_number, '静岡県静岡市葵区一番町');
ok($zip->set_number('4200072')->is_valid_number, '静岡県静岡市葵区二番町');
ok($zip->set_number('4200073')->is_valid_number, '静岡県静岡市葵区三番町');
ok($zip->set_number('4200074')->is_valid_number, '静岡県静岡市葵区四番町');
ok($zip->set_number('4200075')->is_valid_number, '静岡県静岡市葵区五番町');
ok($zip->set_number('4200076')->is_valid_number, '静岡県静岡市葵区六番町');
ok($zip->set_number('4200077')->is_valid_number, '静岡県静岡市葵区七番町');
ok($zip->set_number('4200078')->is_valid_number, '静岡県静岡市葵区八番町');
ok($zip->set_number('4200801')->is_valid_number, '静岡県静岡市葵区東千代田');
ok($zip->set_number('4200803')->is_valid_number, '静岡県静岡市葵区千代田');
ok($zip->set_number('4200804')->is_valid_number, '静岡県静岡市葵区竜南');
ok($zip->set_number('4200805')->is_valid_number, '静岡県静岡市葵区城北');
ok($zip->set_number('4200810')->is_valid_number, '静岡県静岡市葵区上土');
ok($zip->set_number('4200811')->is_valid_number, '静岡県静岡市葵区上土新田');
ok($zip->set_number('4200812')->is_valid_number, '静岡県静岡市葵区古庄');
ok($zip->set_number('4200813')->is_valid_number, '静岡県静岡市葵区長沼');
ok($zip->set_number('4200814')->is_valid_number, '静岡県静岡市葵区長沼南');
ok($zip->set_number('4200815')->is_valid_number, '静岡県静岡市葵区上沓谷町');
ok($zip->set_number('4200816')->is_valid_number, '静岡県静岡市葵区沓谷');
ok($zip->set_number('4200817')->is_valid_number, '静岡県静岡市葵区東静岡');
ok($zip->set_number('4200821')->is_valid_number, '静岡県静岡市葵区柚木');
ok($zip->set_number('4200822')->is_valid_number, '静岡県静岡市葵区宮前町');
ok($zip->set_number('4200823')->is_valid_number, '静岡県静岡市葵区春日');
ok($zip->set_number('4200824')->is_valid_number, '静岡県静岡市葵区春日町');
ok($zip->set_number('4200825')->is_valid_number, '静岡県静岡市葵区瓦場町');
ok($zip->set_number('4200831')->is_valid_number, '静岡県静岡市葵区水落町');
ok($zip->set_number('4200832')->is_valid_number, '静岡県静岡市葵区横内町');
ok($zip->set_number('4200833')->is_valid_number, '静岡県静岡市葵区東鷹匠町');
ok($zip->set_number('4200834')->is_valid_number, '静岡県静岡市葵区音羽町');
ok($zip->set_number('4200835')->is_valid_number, '静岡県静岡市葵区横田町');
ok($zip->set_number('4200836')->is_valid_number, '静岡県静岡市葵区東町');
ok($zip->set_number('4200837')->is_valid_number, '静岡県静岡市葵区日出町');
ok($zip->set_number('4200838')->is_valid_number, '静岡県静岡市葵区相生町');
ok($zip->set_number('4200839')->is_valid_number, '静岡県静岡市葵区鷹匠');
ok($zip->set_number('4200841')->is_valid_number, '静岡県静岡市葵区上足洗');
ok($zip->set_number('4200842')->is_valid_number, '静岡県静岡市葵区銭座町');
ok($zip->set_number('4200843')->is_valid_number, '静岡県静岡市葵区巴町');
ok($zip->set_number('4200844')->is_valid_number, '静岡県静岡市葵区緑町');
ok($zip->set_number('4200845')->is_valid_number, '静岡県静岡市葵区太田町');
ok($zip->set_number('4200846')->is_valid_number, '静岡県静岡市葵区城東町');
ok($zip->set_number('4200847')->is_valid_number, '静岡県静岡市葵区西千代田町');
ok($zip->set_number('4200851')->is_valid_number, '静岡県静岡市葵区黒金町');
ok($zip->set_number('4200852')->is_valid_number, '静岡県静岡市葵区紺屋町');
ok($zip->set_number('4200853')->is_valid_number, '静岡県静岡市葵区追手町');
ok($zip->set_number('4200854')->is_valid_number, '静岡県静岡市葵区城内町');
ok($zip->set_number('4200855')->is_valid_number, '静岡県静岡市葵区駿府城公園');
ok($zip->set_number('4200856')->is_valid_number, '静岡県静岡市葵区駿府町');
ok($zip->set_number('4200857')->is_valid_number, '静岡県静岡市葵区御幸町');
ok($zip->set_number('4200858')->is_valid_number, '静岡県静岡市葵区伝馬町');
ok($zip->set_number('4200859')->is_valid_number, '静岡県静岡市葵区栄町');
ok($zip->set_number('4200861')->is_valid_number, '静岡県静岡市葵区丸山町');
ok($zip->set_number('4200862')->is_valid_number, '静岡県静岡市葵区浅間町');
ok($zip->set_number('4200863')->is_valid_number, '静岡県静岡市葵区安東柳町');
ok($zip->set_number('4200864')->is_valid_number, '静岡県静岡市葵区長谷町');
ok($zip->set_number('4200865')->is_valid_number, '静岡県静岡市葵区東草深町');
ok($zip->set_number('4200866')->is_valid_number, '静岡県静岡市葵区西草深町');
ok($zip->set_number('4200867')->is_valid_number, '静岡県静岡市葵区馬場町');
ok($zip->set_number('4200868')->is_valid_number, '静岡県静岡市葵区宮ケ崎町');
ok($zip->set_number('4200869')->is_valid_number, '静岡県静岡市葵区安倍町');
ok($zip->set_number('4200871')->is_valid_number, '静岡県静岡市葵区昭府');
ok($zip->set_number('4200872')->is_valid_number, '静岡県静岡市葵区昭府町');
ok($zip->set_number('4200873')->is_valid_number, '静岡県静岡市葵区籠上');
ok($zip->set_number('4200874')->is_valid_number, '静岡県静岡市葵区辰起町');
ok($zip->set_number('4200875')->is_valid_number, '静岡県静岡市葵区美川町');
ok($zip->set_number('4200876')->is_valid_number, '静岡県静岡市葵区平和');
ok($zip->set_number('4200881')->is_valid_number, '静岡県静岡市葵区北安東');
ok($zip->set_number('4200882')->is_valid_number, '静岡県静岡市葵区安東');
ok($zip->set_number('4200883')->is_valid_number, '静岡県静岡市葵区大岩宮下町');
ok($zip->set_number('4200884')->is_valid_number, '静岡県静岡市葵区大岩本町');
ok($zip->set_number('4200885')->is_valid_number, '静岡県静岡市葵区大岩町');
ok($zip->set_number('4200886')->is_valid_number, '静岡県静岡市葵区大岩');
ok($zip->set_number('4200901')->is_valid_number, '静岡県静岡市葵区北沼上');
ok($zip->set_number('4200902')->is_valid_number, '静岡県静岡市葵区諏訪');
ok($zip->set_number('4200903')->is_valid_number, '静岡県静岡市葵区長尾');
ok($zip->set_number('4200904')->is_valid_number, '静岡県静岡市葵区平山');
ok($zip->set_number('4200905')->is_valid_number, '静岡県静岡市葵区南沼上');
ok($zip->set_number('4200906')->is_valid_number, '静岡県静岡市葵区薬師');
ok($zip->set_number('4200911')->is_valid_number, '静岡県静岡市葵区瀬名');
ok($zip->set_number('4200912')->is_valid_number, '静岡県静岡市葵区東瀬名町');
ok($zip->set_number('4200913')->is_valid_number, '静岡県静岡市葵区瀬名川');
ok($zip->set_number('4200914')->is_valid_number, '静岡県静岡市葵区西瀬名町');
ok($zip->set_number('4200915')->is_valid_number, '静岡県静岡市葵区南瀬名町');
ok($zip->set_number('4200916')->is_valid_number, '静岡県静岡市葵区瀬名中央');
ok($zip->set_number('4200921')->is_valid_number, '静岡県静岡市葵区野丈');
ok($zip->set_number('4200922')->is_valid_number, '静岡県静岡市葵区流通センター');
ok($zip->set_number('4200923')->is_valid_number, '静岡県静岡市葵区川合');
ok($zip->set_number('4200924')->is_valid_number, '静岡県静岡市葵区川合新田');
ok($zip->set_number('4200925')->is_valid_number, '静岡県静岡市葵区加藤島');
ok($zip->set_number('4200931')->is_valid_number, '静岡県静岡市葵区観山');
ok($zip->set_number('4200932')->is_valid_number, '静岡県静岡市葵区豊地');
ok($zip->set_number('4200933')->is_valid_number, '静岡県静岡市葵区立石');
ok($zip->set_number('4200934')->is_valid_number, '静岡県静岡市葵区岳美');
ok($zip->set_number('4200935')->is_valid_number, '静岡県静岡市葵区池ケ谷東');
ok($zip->set_number('4200936')->is_valid_number, '静岡県静岡市葵区池ケ谷');
ok($zip->set_number('4200937')->is_valid_number, '静岡県静岡市葵区唐瀬');
ok($zip->set_number('4200941')->is_valid_number, '静岡県静岡市葵区松富');
ok($zip->set_number('4200942')->is_valid_number, '静岡県静岡市葵区松富上組');
ok($zip->set_number('4200943')->is_valid_number, '静岡県静岡市葵区上伝馬');
ok($zip->set_number('4200944')->is_valid_number, '静岡県静岡市葵区新伝馬');
ok($zip->set_number('4200945')->is_valid_number, '静岡県静岡市葵区桜町');
ok($zip->set_number('4200946')->is_valid_number, '静岡県静岡市葵区伊呂波町');
ok($zip->set_number('4200947')->is_valid_number, '静岡県静岡市葵区堤町');
ok($zip->set_number('4200948')->is_valid_number, '静岡県静岡市葵区秋山町');
ok($zip->set_number('4200949')->is_valid_number, '静岡県静岡市葵区与一');
ok($zip->set_number('4200951')->is_valid_number, '静岡県静岡市葵区天神前');
ok($zip->set_number('4200952')->is_valid_number, '静岡県静岡市葵区牛田');
ok($zip->set_number('4200953')->is_valid_number, '静岡県静岡市葵区漆山');
ok($zip->set_number('4200954')->is_valid_number, '静岡県静岡市葵区平柳');
ok($zip->set_number('4200955')->is_valid_number, '静岡県静岡市葵区芝原');
ok($zip->set_number('4200956')->is_valid_number, '静岡県静岡市葵区南');
ok($zip->set_number('4200957')->is_valid_number, '静岡県静岡市葵区前林');
ok($zip->set_number('4200961')->is_valid_number, '静岡県静岡市葵区北');
ok($zip->set_number('4200962')->is_valid_number, '静岡県静岡市葵区東');
ok($zip->set_number('4200963')->is_valid_number, '静岡県静岡市葵区赤松');
ok($zip->set_number('4200964')->is_valid_number, '静岡県静岡市葵区柳原');
ok($zip->set_number('4200965')->is_valid_number, '静岡県静岡市葵区有永');
ok($zip->set_number('4200966')->is_valid_number, '静岡県静岡市葵区羽高');
ok($zip->set_number('4200967')->is_valid_number, '静岡県静岡市葵区羽高町');
ok($zip->set_number('4200968')->is_valid_number, '静岡県静岡市葵区あさはた');
ok($zip->set_number('4200969')->is_valid_number, '静岡県静岡市葵区有永町');
ok($zip->set_number('4210101')->is_valid_number, '静岡県静岡市駿河区向敷地');
ok($zip->set_number('4210102')->is_valid_number, '静岡県静岡市駿河区手越');
ok($zip->set_number('4210103')->is_valid_number, '静岡県静岡市駿河区丸子');
ok($zip->set_number('4210104')->is_valid_number, '静岡県静岡市駿河区丸子芹が谷町');
ok($zip->set_number('4210105')->is_valid_number, '静岡県静岡市駿河区宇津ノ谷');
ok($zip->set_number('4210106')->is_valid_number, '静岡県静岡市駿河区北丸子');
ok($zip->set_number('4210107')->is_valid_number, '静岡県静岡市駿河区向手越');
ok($zip->set_number('4210111')->is_valid_number, '静岡県静岡市駿河区丸子新田');
ok($zip->set_number('4210112')->is_valid_number, '静岡県静岡市駿河区東新田');
ok($zip->set_number('4210113')->is_valid_number, '静岡県静岡市駿河区下川原');
ok($zip->set_number('4210114')->is_valid_number, '静岡県静岡市駿河区桃園町');
ok($zip->set_number('4210115')->is_valid_number, '静岡県静岡市駿河区みずほ');
ok($zip->set_number('4210116')->is_valid_number, '静岡県静岡市駿河区光陽町');
ok($zip->set_number('4210117')->is_valid_number, '静岡県静岡市駿河区下川原南');
ok($zip->set_number('4210121')->is_valid_number, '静岡県静岡市駿河区広野');
ok($zip->set_number('4210122')->is_valid_number, '静岡県静岡市駿河区用宗');
ok($zip->set_number('4210123')->is_valid_number, '静岡県静岡市駿河区石部');
ok($zip->set_number('4210124')->is_valid_number, '静岡県静岡市駿河区用宗城山町');
ok($zip->set_number('4210125')->is_valid_number, '静岡県静岡市駿河区用宗小石町');
ok($zip->set_number('4210126')->is_valid_number, '静岡県静岡市駿河区用宗巴町');
ok($zip->set_number('4210131')->is_valid_number, '静岡県静岡市駿河区手越原');
ok($zip->set_number('4210132')->is_valid_number, '静岡県静岡市駿河区上川原');
ok($zip->set_number('4210133')->is_valid_number, '静岡県静岡市駿河区鎌田');
ok($zip->set_number('4210134')->is_valid_number, '静岡県静岡市駿河区青木');
ok($zip->set_number('4210135')->is_valid_number, '静岡県静岡市駿河区小坂');
ok($zip->set_number('4210136')->is_valid_number, '静岡県静岡市駿河区大和田');
ok($zip->set_number('4210137')->is_valid_number, '静岡県静岡市駿河区寺田');
ok($zip->set_number('4210201')->is_valid_number, '静岡県焼津市上小杉');
ok($zip->set_number('4210202')->is_valid_number, '静岡県焼津市下小杉');
ok($zip->set_number('4210203')->is_valid_number, '静岡県焼津市藤守');
ok($zip->set_number('4210204')->is_valid_number, '静岡県焼津市高新田');
ok($zip->set_number('4210205')->is_valid_number, '静岡県焼津市宗高');
ok($zip->set_number('4210206')->is_valid_number, '静岡県焼津市上新田');
ok($zip->set_number('4210211')->is_valid_number, '静岡県焼津市吉永');
ok($zip->set_number('4210212')->is_valid_number, '静岡県焼津市利右衛門');
ok($zip->set_number('4210213')->is_valid_number, '静岡県焼津市飯淵');
ok($zip->set_number('4210214')->is_valid_number, '静岡県焼津市中島');
ok($zip->set_number('4210215')->is_valid_number, '静岡県焼津市西島');
ok($zip->set_number('4210216')->is_valid_number, '静岡県焼津市相川');
ok($zip->set_number('4210217')->is_valid_number, '静岡県焼津市上泉');
ok($zip->set_number('4210218')->is_valid_number, '静岡県焼津市下江留');
ok($zip->set_number('4210300')->is_valid_number, '静岡県榛原郡吉田町以下に掲載がない場合');
ok($zip->set_number('4210301')->is_valid_number, '静岡県榛原郡吉田町住吉');
ok($zip->set_number('4210302')->is_valid_number, '静岡県榛原郡吉田町川尻');
ok($zip->set_number('4210303')->is_valid_number, '静岡県榛原郡吉田町片岡');
ok($zip->set_number('4210304')->is_valid_number, '静岡県榛原郡吉田町神戸');
ok($zip->set_number('4210305')->is_valid_number, '静岡県榛原郡吉田町大幡');
ok($zip->set_number('4210401')->is_valid_number, '静岡県牧之原市切山');
ok($zip->set_number('4210402')->is_valid_number, '静岡県牧之原市勝間');
ok($zip->set_number('4210403')->is_valid_number, '静岡県牧之原市中');
ok($zip->set_number('4210404')->is_valid_number, '静岡県牧之原市静谷');
ok($zip->set_number('4210405')->is_valid_number, '静岡県牧之原市白井(1291~1682、1839~1840番地)');
ok($zip->set_number('4210406')->is_valid_number, '静岡県牧之原市勝田');
ok($zip->set_number('4210407')->is_valid_number, '静岡県牧之原市布引原');
ok($zip->set_number('4210408')->is_valid_number, '静岡県牧之原市嶋');
ok($zip->set_number('4210409')->is_valid_number, '静岡県牧之原市牧之原(その他)');
ok($zip->set_number('4210411')->is_valid_number, '静岡県牧之原市坂口');
ok($zip->set_number('4210412')->is_valid_number, '静岡県牧之原市坂部');
ok($zip->set_number('4210413')->is_valid_number, '静岡県牧之原市仁田');
ok($zip->set_number('4210414')->is_valid_number, '静岡県牧之原市勝俣');
ok($zip->set_number('4210415')->is_valid_number, '静岡県牧之原市道場');
ok($zip->set_number('4210421')->is_valid_number, '静岡県牧之原市細江');
ok($zip->set_number('4210422')->is_valid_number, '静岡県牧之原市静波');
ok($zip->set_number('4210500')->is_valid_number, '静岡県牧之原市以下に掲載がない場合');
ok($zip->set_number('4210501')->is_valid_number, '静岡県牧之原市東萩間');
ok($zip->set_number('4210502')->is_valid_number, '静岡県牧之原市白井(その他)');
ok($zip->set_number('4210503')->is_valid_number, '静岡県牧之原市蛭ケ谷');
ok($zip->set_number('4210504')->is_valid_number, '静岡県牧之原市黒子');
ok($zip->set_number('4210505')->is_valid_number, '静岡県牧之原市中西');
ok($zip->set_number('4210506')->is_valid_number, '静岡県牧之原市大寄');
ok($zip->set_number('4210507')->is_valid_number, '静岡県牧之原市和田');
ok($zip->set_number('4210508')->is_valid_number, '静岡県牧之原市西萩間');
ok($zip->set_number('4210509')->is_valid_number, '静岡県牧之原市牧之原(136~144番地)');
ok($zip->set_number('4210511')->is_valid_number, '静岡県牧之原市片浜');
ok($zip->set_number('4210512')->is_valid_number, '静岡県牧之原市大江');
ok($zip->set_number('4210513')->is_valid_number, '静岡県牧之原市松本');
ok($zip->set_number('4210514')->is_valid_number, '静岡県牧之原市菅ケ谷');
ok($zip->set_number('4210515')->is_valid_number, '静岡県牧之原市西山寺');
ok($zip->set_number('4210516')->is_valid_number, '静岡県牧之原市女神');
ok($zip->set_number('4210517')->is_valid_number, '静岡県牧之原市男神');
ok($zip->set_number('4210521')->is_valid_number, '静岡県牧之原市福岡');
ok($zip->set_number('4210522')->is_valid_number, '静岡県牧之原市相良');
ok($zip->set_number('4210523')->is_valid_number, '静岡県牧之原市波津');
ok($zip->set_number('4210524')->is_valid_number, '静岡県牧之原市須々木');
ok($zip->set_number('4210525')->is_valid_number, '静岡県牧之原市鬼女新田');
ok($zip->set_number('4210526')->is_valid_number, '静岡県牧之原市大沢');
ok($zip->set_number('4210527')->is_valid_number, '静岡県牧之原市汐見台');
ok($zip->set_number('4210531')->is_valid_number, '静岡県牧之原市落居');
ok($zip->set_number('4210532')->is_valid_number, '静岡県牧之原市地頭方');
ok($zip->set_number('4210533')->is_valid_number, '静岡県牧之原市新庄');
ok($zip->set_number('4210534')->is_valid_number, '静岡県牧之原市堀野新田');
ok($zip->set_number('4210535')->is_valid_number, '静岡県牧之原市笠名');
ok($zip->set_number('4211101')->is_valid_number, '静岡県藤枝市岡部町玉取');
ok($zip->set_number('4211102')->is_valid_number, '静岡県藤枝市岡部町宮島');
ok($zip->set_number('4211103')->is_valid_number, '静岡県藤枝市岡部町青羽根');
ok($zip->set_number('4211111')->is_valid_number, '静岡県藤枝市岡部町野田沢');
ok($zip->set_number('4211112')->is_valid_number, '静岡県藤枝市岡部町殿');
ok($zip->set_number('4211113')->is_valid_number, '静岡県藤枝市岡部町桂島');
ok($zip->set_number('4211114')->is_valid_number, '静岡県藤枝市岡部町羽佐間');
ok($zip->set_number('4211115')->is_valid_number, '静岡県藤枝市岡部町新舟');
ok($zip->set_number('4211121')->is_valid_number, '静岡県藤枝市岡部町岡部');
ok($zip->set_number('4211122')->is_valid_number, '静岡県藤枝市岡部町子持坂');
ok($zip->set_number('4211123')->is_valid_number, '静岡県藤枝市岡部町入野');
ok($zip->set_number('4211124')->is_valid_number, '静岡県藤枝市岡部町村良');
ok($zip->set_number('4211131')->is_valid_number, '静岡県藤枝市岡部町内谷');
ok($zip->set_number('4211132')->is_valid_number, '静岡県藤枝市岡部町三輪');
ok($zip->set_number('4211201')->is_valid_number, '静岡県静岡市葵区新間');
ok($zip->set_number('4211202')->is_valid_number, '静岡県静岡市葵区谷津');
ok($zip->set_number('4211211')->is_valid_number, '静岡県静岡市葵区慈悲尾');
ok($zip->set_number('4211212')->is_valid_number, '静岡県静岡市葵区千代');
ok($zip->set_number('4211213')->is_valid_number, '静岡県静岡市葵区山崎');
ok($zip->set_number('4211214')->is_valid_number, '静岡県静岡市葵区建穂');
ok($zip->set_number('4211215')->is_valid_number, '静岡県静岡市葵区羽鳥');
ok($zip->set_number('4211216')->is_valid_number, '静岡県静岡市葵区羽鳥大門町');
ok($zip->set_number('4211217')->is_valid_number, '静岡県静岡市葵区羽鳥本町');
ok($zip->set_number('4211221')->is_valid_number, '静岡県静岡市葵区牧ケ谷');
ok($zip->set_number('4211222')->is_valid_number, '静岡県静岡市葵区産女');
ok($zip->set_number('4211223')->is_valid_number, '静岡県静岡市葵区吉津');
ok($zip->set_number('4211224')->is_valid_number, '静岡県静岡市葵区飯間');
ok($zip->set_number('4211225')->is_valid_number, '静岡県静岡市葵区小瀬戸');
ok($zip->set_number('4211226')->is_valid_number, '静岡県静岡市葵区西又');
ok($zip->set_number('4211301')->is_valid_number, '静岡県静岡市葵区小島');
ok($zip->set_number('4211302')->is_valid_number, '静岡県静岡市葵区鍵穴');
ok($zip->set_number('4211303')->is_valid_number, '静岡県静岡市葵区坂本');
ok($zip->set_number('4211304')->is_valid_number, '静岡県静岡市葵区寺島');
ok($zip->set_number('4211305')->is_valid_number, '静岡県静岡市葵区赤沢');
ok($zip->set_number('4211306')->is_valid_number, '静岡県静岡市葵区昼居渡');
ok($zip->set_number('4211307')->is_valid_number, '静岡県静岡市葵区相俣');
ok($zip->set_number('4211308')->is_valid_number, '静岡県静岡市葵区黒俣');
ok($zip->set_number('4211309')->is_valid_number, '静岡県静岡市葵区杉尾');
ok($zip->set_number('4211311')->is_valid_number, '静岡県静岡市葵区富沢');
ok($zip->set_number('4211312')->is_valid_number, '静岡県静岡市葵区奈良間');
ok($zip->set_number('4211313')->is_valid_number, '静岡県静岡市葵区水見色');
ok($zip->set_number('4211314')->is_valid_number, '静岡県静岡市葵区大原');
ok($zip->set_number('4211315')->is_valid_number, '静岡県静岡市葵区富厚里');
ok($zip->set_number('4211316')->is_valid_number, '静岡県静岡市葵区小布杉');
ok($zip->set_number('4211401')->is_valid_number, '静岡県静岡市葵区大間');
ok($zip->set_number('4211402')->is_valid_number, '静岡県静岡市葵区諸子沢');
ok($zip->set_number('4211403')->is_valid_number, '静岡県静岡市葵区日向');
ok($zip->set_number('4211404')->is_valid_number, '静岡県静岡市葵区栃沢');
ok($zip->set_number('4211405')->is_valid_number, '静岡県静岡市葵区坂ノ上');
ok($zip->set_number('4211406')->is_valid_number, '静岡県静岡市葵区湯ノ島');
ok($zip->set_number('4211407')->is_valid_number, '静岡県静岡市葵区楢尾');
ok($zip->set_number('4211408')->is_valid_number, '静岡県静岡市葵区崩野');
ok($zip->set_number('4211409')->is_valid_number, '静岡県静岡市葵区八草');
ok($zip->set_number('4212101')->is_valid_number, '静岡県静岡市葵区俵峰');
ok($zip->set_number('4212102')->is_valid_number, '静岡県静岡市葵区油島');
ok($zip->set_number('4212103')->is_valid_number, '静岡県静岡市葵区俵沢');
ok($zip->set_number('4212104')->is_valid_number, '静岡県静岡市葵区野田平');
ok($zip->set_number('4212105')->is_valid_number, '静岡県静岡市葵区郷島');
ok($zip->set_number('4212106')->is_valid_number, '静岡県静岡市葵区牛妻');
ok($zip->set_number('4212107')->is_valid_number, '静岡県静岡市葵区門屋');
ok($zip->set_number('4212108')->is_valid_number, '静岡県静岡市葵区下');
ok($zip->set_number('4212109')->is_valid_number, '静岡県静岡市葵区福田ケ谷');
ok($zip->set_number('4212111')->is_valid_number, '静岡県静岡市葵区中ノ郷');
ok($zip->set_number('4212112')->is_valid_number, '静岡県静岡市葵区遠藤新田');
ok($zip->set_number('4212113')->is_valid_number, '静岡県静岡市葵区安倍口団地');
ok($zip->set_number('4212114')->is_valid_number, '静岡県静岡市葵区安倍口新田');
ok($zip->set_number('4212115')->is_valid_number, '静岡県静岡市葵区与左衛門新田');
ok($zip->set_number('4212116')->is_valid_number, '静岡県静岡市葵区西ケ谷');
ok($zip->set_number('4212117')->is_valid_number, '静岡県静岡市葵区幸庵新田');
ok($zip->set_number('4212118')->is_valid_number, '静岡県静岡市葵区内牧');
ok($zip->set_number('4212121')->is_valid_number, '静岡県静岡市葵区津渡野');
ok($zip->set_number('4212122')->is_valid_number, '静岡県静岡市葵区松野');
ok($zip->set_number('4212123')->is_valid_number, '静岡県静岡市葵区油山');
ok($zip->set_number('4212124')->is_valid_number, '静岡県静岡市葵区足久保口組');
ok($zip->set_number('4212125')->is_valid_number, '静岡県静岡市葵区足久保奥組');
ok($zip->set_number('4212201')->is_valid_number, '静岡県静岡市葵区奥仙俣');
ok($zip->set_number('4212202')->is_valid_number, '静岡県静岡市葵区口仙俣');
ok($zip->set_number('4212203')->is_valid_number, '静岡県静岡市葵区口坂本');
ok($zip->set_number('4212211')->is_valid_number, '静岡県静岡市葵区上落合');
ok($zip->set_number('4212212')->is_valid_number, '静岡県静岡市葵区油野');
ok($zip->set_number('4212213')->is_valid_number, '静岡県静岡市葵区長妻田');
ok($zip->set_number('4212214')->is_valid_number, '静岡県静岡市葵区柿島');
ok($zip->set_number('4212215')->is_valid_number, '静岡県静岡市葵区奥池ケ谷');
ok($zip->set_number('4212216')->is_valid_number, '静岡県静岡市葵区長熊');
ok($zip->set_number('4212217')->is_valid_number, '静岡県静岡市葵区森腰');
ok($zip->set_number('4212221')->is_valid_number, '静岡県静岡市葵区中沢');
ok($zip->set_number('4212222')->is_valid_number, '静岡県静岡市葵区桂山');
ok($zip->set_number('4212223')->is_valid_number, '静岡県静岡市葵区落合');
ok($zip->set_number('4212224')->is_valid_number, '静岡県静岡市葵区内匠');
ok($zip->set_number('4212225')->is_valid_number, '静岡県静岡市葵区腰越');
ok($zip->set_number('4212226')->is_valid_number, '静岡県静岡市葵区横沢');
ok($zip->set_number('4212227')->is_valid_number, '静岡県静岡市葵区大沢');
ok($zip->set_number('4212301')->is_valid_number, '静岡県静岡市葵区梅ケ島');
ok($zip->set_number('4212302')->is_valid_number, '静岡県静岡市葵区入島');
ok($zip->set_number('4212303')->is_valid_number, '静岡県静岡市葵区有東木');
ok($zip->set_number('4212304')->is_valid_number, '静岡県静岡市葵区渡');
ok($zip->set_number('4212305')->is_valid_number, '静岡県静岡市葵区中平');
ok($zip->set_number('4212306')->is_valid_number, '静岡県静岡市葵区平野');
ok($zip->set_number('4212307')->is_valid_number, '静岡県静岡市葵区横山');
ok($zip->set_number('4212308')->is_valid_number, '静岡県静岡市葵区蕨野');
ok($zip->set_number('4212309')->is_valid_number, '静岡県静岡市葵区相淵');
ok($zip->set_number('4213101')->is_valid_number, '静岡県静岡市清水区由比入山');
ok($zip->set_number('4213102')->is_valid_number, '静岡県静岡市清水区由比東山寺');
ok($zip->set_number('4213103')->is_valid_number, '静岡県静岡市清水区由比');
ok($zip->set_number('4213104')->is_valid_number, '静岡県静岡市清水区由比北田');
ok($zip->set_number('4213105')->is_valid_number, '静岡県静岡市清水区由比町屋原');
ok($zip->set_number('4213106')->is_valid_number, '静岡県静岡市清水区由比西山寺');
ok($zip->set_number('4213107')->is_valid_number, '静岡県静岡市清水区由比阿僧');
ok($zip->set_number('4213111')->is_valid_number, '静岡県静岡市清水区由比今宿');
ok($zip->set_number('4213112')->is_valid_number, '静岡県静岡市清水区由比寺尾');
ok($zip->set_number('4213114')->is_valid_number, '静岡県静岡市清水区由比東倉澤');
ok($zip->set_number('4213115')->is_valid_number, '静岡県静岡市清水区由比西倉澤');
ok($zip->set_number('4213201')->is_valid_number, '静岡県静岡市清水区蒲原東');
ok($zip->set_number('4213202')->is_valid_number, '静岡県静岡市清水区蒲原新栄');
ok($zip->set_number('4213203')->is_valid_number, '静岡県静岡市清水区蒲原');
ok($zip->set_number('4213211')->is_valid_number, '静岡県静岡市清水区蒲原新田');
ok($zip->set_number('4213212')->is_valid_number, '静岡県静岡市清水区蒲原小金');
ok($zip->set_number('4213213')->is_valid_number, '静岡県静岡市清水区蒲原中');
ok($zip->set_number('4213214')->is_valid_number, '静岡県静岡市清水区蒲原堰沢');
ok($zip->set_number('4213215')->is_valid_number, '静岡県静岡市清水区蒲原神沢');
ok($zip->set_number('4213301')->is_valid_number, '静岡県富士市北松野');
ok($zip->set_number('4213302')->is_valid_number, '静岡県富士市中野台');
ok($zip->set_number('4213303')->is_valid_number, '静岡県富士市南松野');
ok($zip->set_number('4213304')->is_valid_number, '静岡県富士市木島');
ok($zip->set_number('4213305')->is_valid_number, '静岡県富士市岩淵');
ok($zip->set_number('4213306')->is_valid_number, '静岡県富士市中之郷');
ok($zip->set_number('4220000')->is_valid_number, '静岡県静岡市葵区以下に掲載がない場合');
ok($zip->set_number('4220000')->is_valid_number, '静岡県静岡市駿河区以下に掲載がない場合');
ok($zip->set_number('4220000')->is_valid_number, '静岡県静岡市清水区以下に掲載がない場合');
ok($zip->set_number('4228001')->is_valid_number, '静岡県静岡市駿河区中吉田');
ok($zip->set_number('4228002')->is_valid_number, '静岡県静岡市駿河区谷田');
ok($zip->set_number('4228003')->is_valid_number, '静岡県静岡市駿河区平沢');
ok($zip->set_number('4228004')->is_valid_number, '静岡県静岡市駿河区国吉田');
ok($zip->set_number('4228005')->is_valid_number, '静岡県静岡市駿河区池田');
ok($zip->set_number('4228006')->is_valid_number, '静岡県静岡市駿河区曲金');
ok($zip->set_number('4228007')->is_valid_number, '静岡県静岡市駿河区聖一色');
ok($zip->set_number('4228008')->is_valid_number, '静岡県静岡市駿河区栗原');
ok($zip->set_number('4228009')->is_valid_number, '静岡県静岡市駿河区弥生町');
ok($zip->set_number('4228011')->is_valid_number, '静岡県静岡市駿河区根古屋');
ok($zip->set_number('4228012')->is_valid_number, '静岡県静岡市駿河区安居');
ok($zip->set_number('4228013')->is_valid_number, '静岡県静岡市駿河区古宿');
ok($zip->set_number('4228014')->is_valid_number, '静岡県静岡市駿河区青沢');
ok($zip->set_number('4228015')->is_valid_number, '静岡県静岡市駿河区中平松');
ok($zip->set_number('4228016')->is_valid_number, '静岡県静岡市駿河区西平松');
ok($zip->set_number('4228017')->is_valid_number, '静岡県静岡市駿河区大谷');
ok($zip->set_number('4228018')->is_valid_number, '静岡県静岡市駿河区西大谷');
ok($zip->set_number('4228019')->is_valid_number, '静岡県静岡市駿河区東静岡');
ok($zip->set_number('4228021')->is_valid_number, '静岡県静岡市駿河区小鹿');
ok($zip->set_number('4228022')->is_valid_number, '静岡県静岡市駿河区恩田原');
ok($zip->set_number('4228023')->is_valid_number, '静岡県静岡市駿河区片山');
ok($zip->set_number('4228024')->is_valid_number, '静岡県静岡市駿河区宮川');
ok($zip->set_number('4228025')->is_valid_number, '静岡県静岡市駿河区水上');
ok($zip->set_number('4228026')->is_valid_number, '静岡県静岡市駿河区富士見台');
ok($zip->set_number('4228027')->is_valid_number, '静岡県静岡市駿河区豊田');
ok($zip->set_number('4228031')->is_valid_number, '静岡県静岡市駿河区有明町');
ok($zip->set_number('4228032')->is_valid_number, '静岡県静岡市駿河区有東');
ok($zip->set_number('4228033')->is_valid_number, '静岡県静岡市駿河区登呂');
ok($zip->set_number('4228034')->is_valid_number, '静岡県静岡市駿河区高松');
ok($zip->set_number('4228035')->is_valid_number, '静岡県静岡市駿河区宮竹');
ok($zip->set_number('4228036')->is_valid_number, '静岡県静岡市駿河区敷地');
ok($zip->set_number('4228037')->is_valid_number, '静岡県静岡市駿河区下島');
ok($zip->set_number('4228041')->is_valid_number, '静岡県静岡市駿河区中田');
ok($zip->set_number('4228042')->is_valid_number, '静岡県静岡市駿河区石田');
ok($zip->set_number('4228043')->is_valid_number, '静岡県静岡市駿河区中田本町');
ok($zip->set_number('4228044')->is_valid_number, '静岡県静岡市駿河区西脇');
ok($zip->set_number('4228045')->is_valid_number, '静岡県静岡市駿河区西島');
ok($zip->set_number('4228046')->is_valid_number, '静岡県静岡市駿河区中島');
ok($zip->set_number('4228047')->is_valid_number, '静岡県静岡市駿河区中村町');
ok($zip->set_number('4228051')->is_valid_number, '静岡県静岡市駿河区中野新田');
ok($zip->set_number('4228052')->is_valid_number, '静岡県静岡市駿河区緑が丘町');
ok($zip->set_number('4228053')->is_valid_number, '静岡県静岡市駿河区西中原');
ok($zip->set_number('4228054')->is_valid_number, '静岡県静岡市駿河区南安倍(3丁目)');
ok($zip->set_number('4228055')->is_valid_number, '静岡県静岡市駿河区寿町');
ok($zip->set_number('4228056')->is_valid_number, '静岡県静岡市駿河区津島町');
ok($zip->set_number('4228057')->is_valid_number, '静岡県静岡市駿河区見瀬');
ok($zip->set_number('4228058')->is_valid_number, '静岡県静岡市駿河区中原');
ok($zip->set_number('4228061')->is_valid_number, '静岡県静岡市駿河区森下町');
ok($zip->set_number('4228062')->is_valid_number, '静岡県静岡市駿河区稲川');
ok($zip->set_number('4228063')->is_valid_number, '静岡県静岡市駿河区馬渕');
ok($zip->set_number('4228064')->is_valid_number, '静岡県静岡市駿河区新川');
ok($zip->set_number('4228065')->is_valid_number, '静岡県静岡市駿河区宮本町');
ok($zip->set_number('4228066')->is_valid_number, '静岡県静岡市駿河区泉町');
ok($zip->set_number('4228067')->is_valid_number, '静岡県静岡市駿河区南町');
ok($zip->set_number('4228071')->is_valid_number, '静岡県静岡市駿河区豊原町');
ok($zip->set_number('4228072')->is_valid_number, '静岡県静岡市駿河区小黒');
ok($zip->set_number('4228073')->is_valid_number, '静岡県静岡市駿河区八幡山');
ok($zip->set_number('4228074')->is_valid_number, '静岡県静岡市駿河区南八幡町');
ok($zip->set_number('4228075')->is_valid_number, '静岡県静岡市駿河区大坪町');
ok($zip->set_number('4228076')->is_valid_number, '静岡県静岡市駿河区八幡');
ok($zip->set_number('4228077')->is_valid_number, '静岡県静岡市駿河区大和');
ok($zip->set_number('4228078')->is_valid_number, '静岡県静岡市駿河区さつき町');
ok($zip->set_number('4240001')->is_valid_number, '静岡県静岡市清水区梅ケ谷');
ok($zip->set_number('4240002')->is_valid_number, '静岡県静岡市清水区山原');
ok($zip->set_number('4240003')->is_valid_number, '静岡県静岡市清水区蜂ケ谷');
ok($zip->set_number('4240004')->is_valid_number, '静岡県静岡市清水区蜂ケ谷南町');
ok($zip->set_number('4240005')->is_valid_number, '静岡県静岡市清水区石川');
ok($zip->set_number('4240006')->is_valid_number, '静岡県静岡市清水区石川本町');
ok($zip->set_number('4240007')->is_valid_number, '静岡県静岡市清水区石川新町');
ok($zip->set_number('4240008')->is_valid_number, '静岡県静岡市清水区押切');
ok($zip->set_number('4240009')->is_valid_number, '静岡県静岡市清水区柏尾');
ok($zip->set_number('4240011')->is_valid_number, '静岡県静岡市清水区下野町');
ok($zip->set_number('4240012')->is_valid_number, '静岡県静岡市清水区下野西');
ok($zip->set_number('4240013')->is_valid_number, '静岡県静岡市清水区下野緑町');
ok($zip->set_number('4240014')->is_valid_number, '静岡県静岡市清水区天王南');
ok($zip->set_number('4240015')->is_valid_number, '静岡県静岡市清水区天王町');
ok($zip->set_number('4240016')->is_valid_number, '静岡県静岡市清水区天王西');
ok($zip->set_number('4240017')->is_valid_number, '静岡県静岡市清水区天王東');
ok($zip->set_number('4240018')->is_valid_number, '静岡県静岡市清水区弥生町');
ok($zip->set_number('4240021')->is_valid_number, '静岡県静岡市清水区下野北');
ok($zip->set_number('4240022')->is_valid_number, '静岡県静岡市清水区八坂町');
ok($zip->set_number('4240023')->is_valid_number, '静岡県静岡市清水区八坂北');
ok($zip->set_number('4240024')->is_valid_number, '静岡県静岡市清水区八坂東');
ok($zip->set_number('4240025')->is_valid_number, '静岡県静岡市清水区八坂西町');
ok($zip->set_number('4240026')->is_valid_number, '静岡県静岡市清水区八坂南町');
ok($zip->set_number('4240027')->is_valid_number, '静岡県静岡市清水区飯田町');
ok($zip->set_number('4240028')->is_valid_number, '静岡県静岡市清水区下野東');
ok($zip->set_number('4240029')->is_valid_number, '静岡県静岡市清水区下野中');
ok($zip->set_number('4240031')->is_valid_number, '静岡県静岡市清水区横砂');
ok($zip->set_number('4240032')->is_valid_number, '静岡県静岡市清水区横砂東町');
ok($zip->set_number('4240033')->is_valid_number, '静岡県静岡市清水区横砂本町');
ok($zip->set_number('4240034')->is_valid_number, '静岡県静岡市清水区横砂中町');
ok($zip->set_number('4240035')->is_valid_number, '静岡県静岡市清水区横砂南町');
ok($zip->set_number('4240036')->is_valid_number, '静岡県静岡市清水区横砂西町');
ok($zip->set_number('4240037')->is_valid_number, '静岡県静岡市清水区袖師町');
ok($zip->set_number('4240038')->is_valid_number, '静岡県静岡市清水区西久保');
ok($zip->set_number('4240041')->is_valid_number, '静岡県静岡市清水区高橋');
ok($zip->set_number('4240042')->is_valid_number, '静岡県静岡市清水区高橋南町');
ok($zip->set_number('4240043')->is_valid_number, '静岡県静岡市清水区永楽町');
ok($zip->set_number('4240044')->is_valid_number, '静岡県静岡市清水区江尻台町');
ok($zip->set_number('4240045')->is_valid_number, '静岡県静岡市清水区東大曲町');
ok($zip->set_number('4240046')->is_valid_number, '静岡県静岡市清水区西大曲町');
ok($zip->set_number('4240047')->is_valid_number, '静岡県静岡市清水区鶴舞町');
ok($zip->set_number('4240048')->is_valid_number, '静岡県静岡市清水区高橋町');
ok($zip->set_number('4240051')->is_valid_number, '静岡県静岡市清水区北脇新田');
ok($zip->set_number('4240052')->is_valid_number, '静岡県静岡市清水区北脇');
ok($zip->set_number('4240053')->is_valid_number, '静岡県静岡市清水区渋川');
ok($zip->set_number('4240054')->is_valid_number, '静岡県静岡市清水区恵比寿町');
ok($zip->set_number('4240055')->is_valid_number, '静岡県静岡市清水区吉川');
ok($zip->set_number('4240056')->is_valid_number, '静岡県静岡市清水区半左衛門新田');
ok($zip->set_number('4240057')->is_valid_number, '静岡県静岡市清水区堀込');
ok($zip->set_number('4240061')->is_valid_number, '静岡県静岡市清水区大内');
ok($zip->set_number('4240062')->is_valid_number, '静岡県静岡市清水区大内新田');
ok($zip->set_number('4240063')->is_valid_number, '静岡県静岡市清水区能島');
ok($zip->set_number('4240064')->is_valid_number, '静岡県静岡市清水区長崎新田');
ok($zip->set_number('4240065')->is_valid_number, '静岡県静岡市清水区長崎');
ok($zip->set_number('4240066')->is_valid_number, '静岡県静岡市清水区七ツ新屋');
ok($zip->set_number('4240067')->is_valid_number, '静岡県静岡市清水区鳥坂');
ok($zip->set_number('4240068')->is_valid_number, '静岡県静岡市清水区長崎南町');
ok($zip->set_number('4240101')->is_valid_number, '静岡県静岡市清水区茂畑');
ok($zip->set_number('4240102')->is_valid_number, '静岡県静岡市清水区広瀬');
ok($zip->set_number('4240103')->is_valid_number, '静岡県静岡市清水区尾羽');
ok($zip->set_number('4240104')->is_valid_number, '静岡県静岡市清水区草ケ谷');
ok($zip->set_number('4240105')->is_valid_number, '静岡県静岡市清水区山切');
ok($zip->set_number('4240106')->is_valid_number, '静岡県静岡市清水区杉山');
ok($zip->set_number('4240107')->is_valid_number, '静岡県静岡市清水区新丹谷');
ok($zip->set_number('4240111')->is_valid_number, '静岡県静岡市清水区吉原');
ok($zip->set_number('4240112')->is_valid_number, '静岡県静岡市清水区伊佐布');
ok($zip->set_number('4240113')->is_valid_number, '静岡県静岡市清水区原');
ok($zip->set_number('4240114')->is_valid_number, '静岡県静岡市清水区庵原町');
ok($zip->set_number('4240201')->is_valid_number, '静岡県静岡市清水区承元寺町');
ok($zip->set_number('4240202')->is_valid_number, '静岡県静岡市清水区興津井上町');
ok($zip->set_number('4240203')->is_valid_number, '静岡県静岡市清水区興津東町');
ok($zip->set_number('4240204')->is_valid_number, '静岡県静岡市清水区興津中町');
ok($zip->set_number('4240205')->is_valid_number, '静岡県静岡市清水区興津本町');
ok($zip->set_number('4240206')->is_valid_number, '静岡県静岡市清水区興津清見寺町');
ok($zip->set_number('4240211')->is_valid_number, '静岡県静岡市清水区谷津町');
ok($zip->set_number('4240212')->is_valid_number, '静岡県静岡市清水区八木間町');
ok($zip->set_number('4240301')->is_valid_number, '静岡県静岡市清水区宍原');
ok($zip->set_number('4240302')->is_valid_number, '静岡県静岡市清水区小河内');
ok($zip->set_number('4240303')->is_valid_number, '静岡県静岡市清水区但沼町');
ok($zip->set_number('4240304')->is_valid_number, '静岡県静岡市清水区立花');
ok($zip->set_number('4240305')->is_valid_number, '静岡県静岡市清水区小島町');
ok($zip->set_number('4240306')->is_valid_number, '静岡県静岡市清水区小島本町');
ok($zip->set_number('4240401')->is_valid_number, '静岡県静岡市清水区中河内');
ok($zip->set_number('4240402')->is_valid_number, '静岡県静岡市清水区清地');
ok($zip->set_number('4240403')->is_valid_number, '静岡県静岡市清水区和田島');
ok($zip->set_number('4240404')->is_valid_number, '静岡県静岡市清水区高山');
ok($zip->set_number('4240405')->is_valid_number, '静岡県静岡市清水区茂野島');
ok($zip->set_number('4240406')->is_valid_number, '静岡県静岡市清水区葛沢');
ok($zip->set_number('4240411')->is_valid_number, '静岡県静岡市清水区大平');
ok($zip->set_number('4240412')->is_valid_number, '静岡県静岡市清水区河内');
ok($zip->set_number('4240413')->is_valid_number, '静岡県静岡市清水区西里');
ok($zip->set_number('4240414')->is_valid_number, '静岡県静岡市清水区土');
ok($zip->set_number('4240415')->is_valid_number, '静岡県静岡市清水区布沢');
ok($zip->set_number('4240801')->is_valid_number, '静岡県静岡市清水区秋吉町');
ok($zip->set_number('4240802')->is_valid_number, '静岡県静岡市清水区矢倉町');
ok($zip->set_number('4240803')->is_valid_number, '静岡県静岡市清水区宮下町');
ok($zip->set_number('4240804')->is_valid_number, '静岡県静岡市清水区田町');
ok($zip->set_number('4240805')->is_valid_number, '静岡県静岡市清水区愛染町');
ok($zip->set_number('4240806')->is_valid_number, '静岡県静岡市清水区辻');
ok($zip->set_number('4240807')->is_valid_number, '静岡県静岡市清水区宮代町');
ok($zip->set_number('4240808')->is_valid_number, '静岡県静岡市清水区大手');
ok($zip->set_number('4240809')->is_valid_number, '静岡県静岡市清水区天神');
ok($zip->set_number('4240811')->is_valid_number, '静岡県静岡市清水区二の丸町');
ok($zip->set_number('4240812')->is_valid_number, '静岡県静岡市清水区小芝町');
ok($zip->set_number('4240813')->is_valid_number, '静岡県静岡市清水区宝町');
ok($zip->set_number('4240814')->is_valid_number, '静岡県静岡市清水区本郷町');
ok($zip->set_number('4240815')->is_valid_number, '静岡県静岡市清水区江尻東');
ok($zip->set_number('4240816')->is_valid_number, '静岡県静岡市清水区真砂町');
ok($zip->set_number('4240817')->is_valid_number, '静岡県静岡市清水区銀座');
ok($zip->set_number('4240818')->is_valid_number, '静岡県静岡市清水区江尻町');
ok($zip->set_number('4240819')->is_valid_number, '静岡県静岡市清水区元城町');
ok($zip->set_number('4240821')->is_valid_number, '静岡県静岡市清水区相生町');
ok($zip->set_number('4240822')->is_valid_number, '静岡県静岡市清水区旭町');
ok($zip->set_number('4240823')->is_valid_number, '静岡県静岡市清水区島崎町');
ok($zip->set_number('4240824')->is_valid_number, '静岡県静岡市清水区新港町');
ok($zip->set_number('4240825')->is_valid_number, '静岡県静岡市清水区松原町');
ok($zip->set_number('4240826')->is_valid_number, '静岡県静岡市清水区万世町');
ok($zip->set_number('4240827')->is_valid_number, '静岡県静岡市清水区上');
ok($zip->set_number('4240828')->is_valid_number, '静岡県静岡市清水区千歳町');
ok($zip->set_number('4240829')->is_valid_number, '静岡県静岡市清水区巴町');
ok($zip->set_number('4240831')->is_valid_number, '静岡県静岡市清水区入江');
ok($zip->set_number('4240832')->is_valid_number, '静岡県静岡市清水区入江南町');
ok($zip->set_number('4240833')->is_valid_number, '静岡県静岡市清水区新富町');
ok($zip->set_number('4240834')->is_valid_number, '静岡県静岡市清水区浜田町');
ok($zip->set_number('4240835')->is_valid_number, '静岡県静岡市清水区上清水町');
ok($zip->set_number('4240836')->is_valid_number, '静岡県静岡市清水区桜が丘町');
ok($zip->set_number('4240837')->is_valid_number, '静岡県静岡市清水区桜橋町');
ok($zip->set_number('4240838')->is_valid_number, '静岡県静岡市清水区淡島町');
ok($zip->set_number('4240839')->is_valid_number, '静岡県静岡市清水区入江岡町');
ok($zip->set_number('4240841')->is_valid_number, '静岡県静岡市清水区追分');
ok($zip->set_number('4240842')->is_valid_number, '静岡県静岡市清水区春日');
ok($zip->set_number('4240843')->is_valid_number, '静岡県静岡市清水区青葉町');
ok($zip->set_number('4240844')->is_valid_number, '静岡県静岡市清水区西高町');
ok($zip->set_number('4240845')->is_valid_number, '静岡県静岡市清水区船原');
ok($zip->set_number('4240846')->is_valid_number, '静岡県静岡市清水区木の下町');
ok($zip->set_number('4240847')->is_valid_number, '静岡県静岡市清水区大坪');
ok($zip->set_number('4240851')->is_valid_number, '静岡県静岡市清水区堂林');
ok($zip->set_number('4240852')->is_valid_number, '静岡県静岡市清水区神田町');
ok($zip->set_number('4240853')->is_valid_number, '静岡県静岡市清水区月見町');
ok($zip->set_number('4240854')->is_valid_number, '静岡県静岡市清水区中矢部町');
ok($zip->set_number('4240855')->is_valid_number, '静岡県静岡市清水区庄福町');
ok($zip->set_number('4240856')->is_valid_number, '静岡県静岡市清水区上力町');
ok($zip->set_number('4240857')->is_valid_number, '静岡県静岡市清水区川原町');
ok($zip->set_number('4240858')->is_valid_number, '静岡県静岡市清水区大沢町');
ok($zip->set_number('4240861')->is_valid_number, '静岡県静岡市清水区船越町');
ok($zip->set_number('4240862')->is_valid_number, '静岡県静岡市清水区船越東町');
ok($zip->set_number('4240863')->is_valid_number, '静岡県静岡市清水区船越南町');
ok($zip->set_number('4240864')->is_valid_number, '静岡県静岡市清水区南矢部');
ok($zip->set_number('4240865')->is_valid_number, '静岡県静岡市清水区北矢部');
ok($zip->set_number('4240866')->is_valid_number, '静岡県静岡市清水区船越');
ok($zip->set_number('4240871')->is_valid_number, '静岡県静岡市清水区上原');
ok($zip->set_number('4240872')->is_valid_number, '静岡県静岡市清水区平川地');
ok($zip->set_number('4240873')->is_valid_number, '静岡県静岡市清水区有東坂');
ok($zip->set_number('4240874')->is_valid_number, '静岡県静岡市清水区今泉');
ok($zip->set_number('4240875')->is_valid_number, '静岡県静岡市清水区馬走');
ok($zip->set_number('4240876')->is_valid_number, '静岡県静岡市清水区馬走北');
ok($zip->set_number('4240877')->is_valid_number, '静岡県静岡市清水区馬走坂の上');
ok($zip->set_number('4240878')->is_valid_number, '静岡県静岡市清水区御門台');
ok($zip->set_number('4240879')->is_valid_number, '静岡県静岡市清水区有度本町');
ok($zip->set_number('4240881')->is_valid_number, '静岡県静岡市清水区楠');
ok($zip->set_number('4240882')->is_valid_number, '静岡県静岡市清水区楠新田');
ok($zip->set_number('4240883')->is_valid_number, '静岡県静岡市清水区草薙北');
ok($zip->set_number('4240884')->is_valid_number, '静岡県静岡市清水区草薙一里山');
ok($zip->set_number('4240885')->is_valid_number, '静岡県静岡市清水区草薙杉道');
ok($zip->set_number('4240886')->is_valid_number, '静岡県静岡市清水区草薙');
ok($zip->set_number('4240887')->is_valid_number, '静岡県静岡市清水区谷田');
ok($zip->set_number('4240888')->is_valid_number, '静岡県静岡市清水区中之郷');
ok($zip->set_number('4240901')->is_valid_number, '静岡県静岡市清水区三保');
ok($zip->set_number('4240902')->is_valid_number, '静岡県静岡市清水区折戸');
ok($zip->set_number('4240903')->is_valid_number, '静岡県静岡市清水区駒越南町');
ok($zip->set_number('4240904')->is_valid_number, '静岡県静岡市清水区駒越中');
ok($zip->set_number('4240905')->is_valid_number, '静岡県静岡市清水区駒越西');
ok($zip->set_number('4240906')->is_valid_number, '静岡県静岡市清水区駒越北町');
ok($zip->set_number('4240907')->is_valid_number, '静岡県静岡市清水区駒越東町');
ok($zip->set_number('4240908')->is_valid_number, '静岡県静岡市清水区三保松原町');
ok($zip->set_number('4240911')->is_valid_number, '静岡県静岡市清水区宮加三');
ok($zip->set_number('4240912')->is_valid_number, '静岡県静岡市清水区殿沢');
ok($zip->set_number('4240913')->is_valid_number, '静岡県静岡市清水区迎山町');
ok($zip->set_number('4240914')->is_valid_number, '静岡県静岡市清水区港南町');
ok($zip->set_number('4240915')->is_valid_number, '静岡県静岡市清水区増');
ok($zip->set_number('4240916')->is_valid_number, '静岡県静岡市清水区蛇塚');
ok($zip->set_number('4240917')->is_valid_number, '静岡県静岡市清水区駒越');
ok($zip->set_number('4240921')->is_valid_number, '静岡県静岡市清水区松井町');
ok($zip->set_number('4240922')->is_valid_number, '静岡県静岡市清水区日の出町');
ok($zip->set_number('4240923')->is_valid_number, '静岡県静岡市清水区幸町');
ok($zip->set_number('4240924')->is_valid_number, '静岡県静岡市清水区清開');
ok($zip->set_number('4240925')->is_valid_number, '静岡県静岡市清水区清水村松地先新田');
ok($zip->set_number('4240926')->is_valid_number, '静岡県静岡市清水区村松');
ok($zip->set_number('4240927')->is_valid_number, '静岡県静岡市清水区新緑町');
ok($zip->set_number('4240928')->is_valid_number, '静岡県静岡市清水区緑が丘町');
ok($zip->set_number('4240929')->is_valid_number, '静岡県静岡市清水区日立町');
ok($zip->set_number('4240931')->is_valid_number, '静岡県静岡市清水区岡町');
ok($zip->set_number('4240932')->is_valid_number, '静岡県静岡市清水区南岡町');
ok($zip->set_number('4240933')->is_valid_number, '静岡県静岡市清水区三光町');
ok($zip->set_number('4240934')->is_valid_number, '静岡県静岡市清水区村松原');
ok($zip->set_number('4240935')->is_valid_number, '静岡県静岡市清水区沼田町');
ok($zip->set_number('4240936')->is_valid_number, '静岡県静岡市清水区向田町');
ok($zip->set_number('4240937')->is_valid_number, '静岡県静岡市清水区北矢部町');
ok($zip->set_number('4240938')->is_valid_number, '静岡県静岡市清水区梅が岡');
ok($zip->set_number('4240939')->is_valid_number, '静岡県静岡市清水区下清水町');
ok($zip->set_number('4240941')->is_valid_number, '静岡県静岡市清水区富士見町');
ok($zip->set_number('4240942')->is_valid_number, '静岡県静岡市清水区入船町');
ok($zip->set_number('4240943')->is_valid_number, '静岡県静岡市清水区港町');
ok($zip->set_number('4240944')->is_valid_number, '静岡県静岡市清水区築地町');
ok($zip->set_number('4240945')->is_valid_number, '静岡県静岡市清水区美濃輪町');
ok($zip->set_number('4240946')->is_valid_number, '静岡県静岡市清水区八千代町');
ok($zip->set_number('4240947')->is_valid_number, '静岡県静岡市清水区清水町');
ok($zip->set_number('4240948')->is_valid_number, '静岡県静岡市清水区梅田町');
ok($zip->set_number('4240949')->is_valid_number, '静岡県静岡市清水区本町');
ok($zip->set_number('4250000')->is_valid_number, '静岡県焼津市以下に掲載がない場合');
ok($zip->set_number('4250001')->is_valid_number, '静岡県焼津市花沢');
ok($zip->set_number('4250002')->is_valid_number, '静岡県焼津市吉津');
ok($zip->set_number('4250003')->is_valid_number, '静岡県焼津市高崎');
ok($zip->set_number('4250004')->is_valid_number, '静岡県焼津市坂本');
ok($zip->set_number('4250005')->is_valid_number, '静岡県焼津市方ノ上');
ok($zip->set_number('4250006')->is_valid_number, '静岡県焼津市関方');
ok($zip->set_number('4250007')->is_valid_number, '静岡県焼津市策牛');
ok($zip->set_number('4250011')->is_valid_number, '静岡県焼津市小浜');
ok($zip->set_number('4250012')->is_valid_number, '静岡県焼津市浜当目');
ok($zip->set_number('4250013')->is_valid_number, '静岡県焼津市岡当目');
ok($zip->set_number('4250014')->is_valid_number, '静岡県焼津市中里');
ok($zip->set_number('4250015')->is_valid_number, '静岡県焼津市石脇上');
ok($zip->set_number('4250016')->is_valid_number, '静岡県焼津市石脇下');
ok($zip->set_number('4250017')->is_valid_number, '静岡県焼津市野秋');
ok($zip->set_number('4250021')->is_valid_number, '静岡県焼津市中港');
ok($zip->set_number('4250022')->is_valid_number, '静岡県焼津市本町');
ok($zip->set_number('4250023')->is_valid_number, '静岡県焼津市新屋');
ok($zip->set_number('4250024')->is_valid_number, '静岡県焼津市北浜通');
ok($zip->set_number('4250025')->is_valid_number, '静岡県焼津市城之腰');
ok($zip->set_number('4250026')->is_valid_number, '静岡県焼津市焼津');
ok($zip->set_number('4250027')->is_valid_number, '静岡県焼津市栄町');
ok($zip->set_number('4250028')->is_valid_number, '静岡県焼津市駅北');
ok($zip->set_number('4250031')->is_valid_number, '静岡県焼津市小川新町');
ok($zip->set_number('4250032')->is_valid_number, '静岡県焼津市鰯ケ島');
ok($zip->set_number('4250033')->is_valid_number, '静岡県焼津市小川');
ok($zip->set_number('4250034')->is_valid_number, '静岡県焼津市与惣次');
ok($zip->set_number('4250035')->is_valid_number, '静岡県焼津市東小川');
ok($zip->set_number('4250036')->is_valid_number, '静岡県焼津市西小川');
ok($zip->set_number('4250041')->is_valid_number, '静岡県焼津市石津');
ok($zip->set_number('4250042')->is_valid_number, '静岡県焼津市石津港町');
ok($zip->set_number('4250043')->is_valid_number, '静岡県焼津市石津中町');
ok($zip->set_number('4250044')->is_valid_number, '静岡県焼津市石津向町');
ok($zip->set_number('4250045')->is_valid_number, '静岡県焼津市祢宜島');
ok($zip->set_number('4250046')->is_valid_number, '静岡県焼津市三右衛門新田');
ok($zip->set_number('4250051')->is_valid_number, '静岡県焼津市田尻北');
ok($zip->set_number('4250052')->is_valid_number, '静岡県焼津市田尻');
ok($zip->set_number('4250053')->is_valid_number, '静岡県焼津市すみれ台');
ok($zip->set_number('4250054')->is_valid_number, '静岡県焼津市一色');
ok($zip->set_number('4250055')->is_valid_number, '静岡県焼津市道原');
ok($zip->set_number('4250056')->is_valid_number, '静岡県焼津市下小田中町');
ok($zip->set_number('4250057')->is_valid_number, '静岡県焼津市下小田');
ok($zip->set_number('4250058')->is_valid_number, '静岡県焼津市北新田');
ok($zip->set_number('4250061')->is_valid_number, '静岡県焼津市中根');
ok($zip->set_number('4250062')->is_valid_number, '静岡県焼津市中根新田');
ok($zip->set_number('4250063')->is_valid_number, '静岡県焼津市本中根');
ok($zip->set_number('4250064')->is_valid_number, '静岡県焼津市三和');
ok($zip->set_number('4250065')->is_valid_number, '静岡県焼津市惣右衛門');
ok($zip->set_number('4250066')->is_valid_number, '静岡県焼津市大島');
ok($zip->set_number('4250067')->is_valid_number, '静岡県焼津市治長請所');
ok($zip->set_number('4250068')->is_valid_number, '静岡県焼津市中新田');
ok($zip->set_number('4250069')->is_valid_number, '静岡県焼津市大島新田');
ok($zip->set_number('4250071')->is_valid_number, '静岡県焼津市三ケ名');
ok($zip->set_number('4250072')->is_valid_number, '静岡県焼津市大住');
ok($zip->set_number('4250073')->is_valid_number, '静岡県焼津市小柳津');
ok($zip->set_number('4250074')->is_valid_number, '静岡県焼津市柳新屋');
ok($zip->set_number('4250075')->is_valid_number, '静岡県焼津市西焼津');
ok($zip->set_number('4250076')->is_valid_number, '静岡県焼津市小屋敷');
ok($zip->set_number('4250077')->is_valid_number, '静岡県焼津市五ケ堀之内');
ok($zip->set_number('4250081')->is_valid_number, '静岡県焼津市大栄町');
ok($zip->set_number('4250082')->is_valid_number, '静岡県焼津市大村');
ok($zip->set_number('4250083')->is_valid_number, '静岡県焼津市大');
ok($zip->set_number('4250084')->is_valid_number, '静岡県焼津市大村新田');
ok($zip->set_number('4250085')->is_valid_number, '静岡県焼津市塩津');
ok($zip->set_number('4250086')->is_valid_number, '静岡県焼津市小土');
ok($zip->set_number('4250087')->is_valid_number, '静岡県焼津市保福島');
ok($zip->set_number('4250088')->is_valid_number, '静岡県焼津市大覚寺');
ok($zip->set_number('4250091')->is_valid_number, '静岡県焼津市八楠');
ok($zip->set_number('4250092')->is_valid_number, '静岡県焼津市越後島');
ok($zip->set_number('4260000')->is_valid_number, '静岡県藤枝市以下に掲載がない場合');
ok($zip->set_number('4260001')->is_valid_number, '静岡県藤枝市仮宿');
ok($zip->set_number('4260002')->is_valid_number, '静岡県藤枝市横内');
ok($zip->set_number('4260003')->is_valid_number, '静岡県藤枝市下当間');
ok($zip->set_number('4260004')->is_valid_number, '静岡県藤枝市上当間');
ok($zip->set_number('4260005')->is_valid_number, '静岡県藤枝市水守');
ok($zip->set_number('4260006')->is_valid_number, '静岡県藤枝市藤岡');
ok($zip->set_number('4260007')->is_valid_number, '静岡県藤枝市潮');
ok($zip->set_number('4260008')->is_valid_number, '静岡県藤枝市鬼島');
ok($zip->set_number('4260009')->is_valid_number, '静岡県藤枝市八幡');
ok($zip->set_number('4260011')->is_valid_number, '静岡県藤枝市平島');
ok($zip->set_number('4260012')->is_valid_number, '静岡県藤枝市田中');
ok($zip->set_number('4260013')->is_valid_number, '静岡県藤枝市立花');
ok($zip->set_number('4260014')->is_valid_number, '静岡県藤枝市若王子');
ok($zip->set_number('4260015')->is_valid_number, '静岡県藤枝市五十海');
ok($zip->set_number('4260016')->is_valid_number, '静岡県藤枝市郡');
ok($zip->set_number('4260017')->is_valid_number, '静岡県藤枝市大手');
ok($zip->set_number('4260018')->is_valid_number, '静岡県藤枝市本町');
ok($zip->set_number('4260019')->is_valid_number, '静岡県藤枝市天王町');
ok($zip->set_number('4260021')->is_valid_number, '静岡県藤枝市城南');
ok($zip->set_number('4260022')->is_valid_number, '静岡県藤枝市稲川');
ok($zip->set_number('4260023')->is_valid_number, '静岡県藤枝市茶町');
ok($zip->set_number('4260024')->is_valid_number, '静岡県藤枝市鬼岩寺');
ok($zip->set_number('4260025')->is_valid_number, '静岡県藤枝市藤枝');
ok($zip->set_number('4260026')->is_valid_number, '静岡県藤枝市岡出山');
ok($zip->set_number('4260027')->is_valid_number, '静岡県藤枝市緑町');
ok($zip->set_number('4260028')->is_valid_number, '静岡県藤枝市益津下');
ok($zip->set_number('4260029')->is_valid_number, '静岡県藤枝市益津');
ok($zip->set_number('4260031')->is_valid_number, '静岡県藤枝市築地');
ok($zip->set_number('4260032')->is_valid_number, '静岡県藤枝市築地上');
ok($zip->set_number('4260033')->is_valid_number, '静岡県藤枝市小石川町');
ok($zip->set_number('4260034')->is_valid_number, '静岡県藤枝市駅前');
ok($zip->set_number('4260035')->is_valid_number, '静岡県藤枝市下青島');
ok($zip->set_number('4260036')->is_valid_number, '静岡県藤枝市上青島');
ok($zip->set_number('4260037')->is_valid_number, '静岡県藤枝市青木');
ok($zip->set_number('4260038')->is_valid_number, '静岡県藤枝市東町');
ok($zip->set_number('4260041')->is_valid_number, '静岡県藤枝市高柳');
ok($zip->set_number('4260042')->is_valid_number, '静岡県藤枝市兵太夫');
ok($zip->set_number('4260043')->is_valid_number, '静岡県藤枝市大新島');
ok($zip->set_number('4260044')->is_valid_number, '静岡県藤枝市大東町');
ok($zip->set_number('4260045')->is_valid_number, '静岡県藤枝市泉町');
ok($zip->set_number('4260046')->is_valid_number, '静岡県藤枝市高洲');
ok($zip->set_number('4260047')->is_valid_number, '静岡県藤枝市与左衛門');
ok($zip->set_number('4260051')->is_valid_number, '静岡県藤枝市大洲');
ok($zip->set_number('4260052')->is_valid_number, '静岡県藤枝市弥左衛門');
ok($zip->set_number('4260053')->is_valid_number, '静岡県藤枝市善左衛門');
ok($zip->set_number('4260054')->is_valid_number, '静岡県藤枝市源助');
ok($zip->set_number('4260055')->is_valid_number, '静岡県藤枝市大西町');
ok($zip->set_number('4260056')->is_valid_number, '静岡県藤枝市五平');
ok($zip->set_number('4260057')->is_valid_number, '静岡県藤枝市忠兵衛');
ok($zip->set_number('4260061')->is_valid_number, '静岡県藤枝市田沼');
ok($zip->set_number('4260062')->is_valid_number, '静岡県藤枝市高岡');
ok($zip->set_number('4260063')->is_valid_number, '静岡県藤枝市青南町');
ok($zip->set_number('4260064')->is_valid_number, '静岡県藤枝市久兵衛市右衛門請新田');
ok($zip->set_number('4260065')->is_valid_number, '静岡県藤枝市末広');
ok($zip->set_number('4260066')->is_valid_number, '静岡県藤枝市青葉町');
ok($zip->set_number('4260067')->is_valid_number, '静岡県藤枝市前島');
ok($zip->set_number('4260070')->is_valid_number, '静岡県藤枝市緑の丘');
ok($zip->set_number('4260071')->is_valid_number, '静岡県藤枝市志太');
ok($zip->set_number('4260072')->is_valid_number, '静岡県藤枝市南新屋');
ok($zip->set_number('4260073')->is_valid_number, '静岡県藤枝市新南新屋');
ok($zip->set_number('4260074')->is_valid_number, '静岡県藤枝市水上');
ok($zip->set_number('4260075')->is_valid_number, '静岡県藤枝市瀬戸新屋');
ok($zip->set_number('4260076')->is_valid_number, '静岡県藤枝市内瀬戸');
ok($zip->set_number('4260077')->is_valid_number, '静岡県藤枝市駿河台');
ok($zip->set_number('4260078')->is_valid_number, '静岡県藤枝市南駿河台');
ok($zip->set_number('4260079')->is_valid_number, '静岡県藤枝市光洋台');
ok($zip->set_number('4260081')->is_valid_number, '静岡県藤枝市旭が丘');
ok($zip->set_number('4260082')->is_valid_number, '静岡県藤枝市瀬古');
ok($zip->set_number('4260083')->is_valid_number, '静岡県藤枝市谷稲葉');
ok($zip->set_number('4260084')->is_valid_number, '静岡県藤枝市寺島');
ok($zip->set_number('4260085')->is_valid_number, '静岡県藤枝市助宗');
ok($zip->set_number('4260086')->is_valid_number, '静岡県藤枝市原');
ok($zip->set_number('4260087')->is_valid_number, '静岡県藤枝市音羽町');
ok($zip->set_number('4260088')->is_valid_number, '静岡県藤枝市堀之内');
ok($zip->set_number('4260131')->is_valid_number, '静岡県藤枝市瀬戸ノ谷');
ok($zip->set_number('4260132')->is_valid_number, '静岡県藤枝市本郷');
ok($zip->set_number('4260133')->is_valid_number, '静岡県藤枝市宮原');
ok($zip->set_number('4260134')->is_valid_number, '静岡県藤枝市滝沢');
ok($zip->set_number('4260201')->is_valid_number, '静岡県藤枝市下藪田');
ok($zip->set_number('4260202')->is_valid_number, '静岡県藤枝市上藪田');
ok($zip->set_number('4260203')->is_valid_number, '静岡県藤枝市下之郷');
ok($zip->set_number('4260204')->is_valid_number, '静岡県藤枝市時ケ谷');
ok($zip->set_number('4260205')->is_valid_number, '静岡県藤枝市花倉');
ok($zip->set_number('4260211')->is_valid_number, '静岡県藤枝市西方');
ok($zip->set_number('4260212')->is_valid_number, '静岡県藤枝市北方');
ok($zip->set_number('4260213')->is_valid_number, '静岡県藤枝市中ノ合');
ok($zip->set_number('4260221')->is_valid_number, '静岡県藤枝市高田');
ok($zip->set_number('4260222')->is_valid_number, '静岡県藤枝市中藪田');
ok($zip->set_number('4260223')->is_valid_number, '静岡県藤枝市清里');
ok($zip->set_number('4260224')->is_valid_number, '静岡県藤枝市南清里');
ok($zip->set_number('4270000')->is_valid_number, '静岡県島田市以下に掲載がない場合');
ok($zip->set_number('4270001')->is_valid_number, '静岡県島田市千葉');
ok($zip->set_number('4270002')->is_valid_number, '静岡県島田市大草');
ok($zip->set_number('4270003')->is_valid_number, '静岡県島田市東光寺');
ok($zip->set_number('4270004')->is_valid_number, '静岡県島田市岸');
ok($zip->set_number('4270005')->is_valid_number, '静岡県島田市岸町');
ok($zip->set_number('4270006')->is_valid_number, '静岡県島田市阿知ケ谷');
ok($zip->set_number('4270007')->is_valid_number, '静岡県島田市野田');
ok($zip->set_number('4270008')->is_valid_number, '静岡県島田市落合');
ok($zip->set_number('4270009')->is_valid_number, '静岡県島田市尾川');
ok($zip->set_number('4270011')->is_valid_number, '静岡県島田市東町');
ok($zip->set_number('4270012')->is_valid_number, '静岡県島田市細島');
ok($zip->set_number('4270013')->is_valid_number, '静岡県島田市御請');
ok($zip->set_number('4270014')->is_valid_number, '静岡県島田市道悦島');
ok($zip->set_number('4270015')->is_valid_number, '静岡県島田市高島町');
ok($zip->set_number('4270016')->is_valid_number, '静岡県島田市宝来町');
ok($zip->set_number('4270017')->is_valid_number, '静岡県島田市南');
ok($zip->set_number('4270018')->is_valid_number, '静岡県島田市旭');
ok($zip->set_number('4270019')->is_valid_number, '静岡県島田市道悦');
ok($zip->set_number('4270021')->is_valid_number, '静岡県島田市柳町');
ok($zip->set_number('4270022')->is_valid_number, '静岡県島田市本通');
ok($zip->set_number('4270023')->is_valid_number, '静岡県島田市大川町');
ok($zip->set_number('4270024')->is_valid_number, '静岡県島田市横井');
ok($zip->set_number('4270025')->is_valid_number, '静岡県島田市大井町');
ok($zip->set_number('4270026')->is_valid_number, '静岡県島田市扇町');
ok($zip->set_number('4270027')->is_valid_number, '静岡県島田市幸町');
ok($zip->set_number('4270028')->is_valid_number, '静岡県島田市栄町');
ok($zip->set_number('4270029')->is_valid_number, '静岡県島田市日之出町');
ok($zip->set_number('4270031')->is_valid_number, '静岡県島田市鵜網');
ok($zip->set_number('4270032')->is_valid_number, '静岡県島田市神座');
ok($zip->set_number('4270033')->is_valid_number, '静岡県島田市相賀');
ok($zip->set_number('4270034')->is_valid_number, '静岡県島田市伊太');
ok($zip->set_number('4270035')->is_valid_number, '静岡県島田市向谷元町');
ok($zip->set_number('4270036')->is_valid_number, '静岡県島田市三ツ合町');
ok($zip->set_number('4270037')->is_valid_number, '静岡県島田市河原');
ok($zip->set_number('4270038')->is_valid_number, '静岡県島田市稲荷');
ok($zip->set_number('4270039')->is_valid_number, '静岡県島田市向谷');
ok($zip->set_number('4270041')->is_valid_number, '静岡県島田市中河町');
ok($zip->set_number('4270042')->is_valid_number, '静岡県島田市中央町');
ok($zip->set_number('4270043')->is_valid_number, '静岡県島田市中溝');
ok($zip->set_number('4270044')->is_valid_number, '静岡県島田市宮川町');
ok($zip->set_number('4270045')->is_valid_number, '静岡県島田市向島町');
ok($zip->set_number('4270046')->is_valid_number, '静岡県島田市若松町');
ok($zip->set_number('4270047')->is_valid_number, '静岡県島田市中溝町');
ok($zip->set_number('4270048')->is_valid_number, '静岡県島田市旗指');
ok($zip->set_number('4270051')->is_valid_number, '静岡県島田市元島田東町');
ok($zip->set_number('4270052')->is_valid_number, '静岡県島田市松葉町');
ok($zip->set_number('4270053')->is_valid_number, '静岡県島田市御仮屋町');
ok($zip->set_number('4270054')->is_valid_number, '静岡県島田市高砂町');
ok($zip->set_number('4270055')->is_valid_number, '静岡県島田市新町通');
ok($zip->set_number('4270056')->is_valid_number, '静岡県島田市大津通');
ok($zip->set_number('4270057')->is_valid_number, '静岡県島田市元島田');
ok($zip->set_number('4270058')->is_valid_number, '静岡県島田市祇園町');
ok($zip->set_number('4270059')->is_valid_number, '静岡県島田市新田町');
ok($zip->set_number('4270061')->is_valid_number, '静岡県島田市ばらの丘');
ok($zip->set_number('4270101')->is_valid_number, '静岡県島田市大柳');
ok($zip->set_number('4270102')->is_valid_number, '静岡県島田市大柳南');
ok($zip->set_number('4270103')->is_valid_number, '静岡県島田市中河');
ok($zip->set_number('4270104')->is_valid_number, '静岡県島田市井口');
ok($zip->set_number('4270105')->is_valid_number, '静岡県島田市南原');
ok($zip->set_number('4270106')->is_valid_number, '静岡県島田市岡田');
ok($zip->set_number('4270107')->is_valid_number, '静岡県島田市船木');
ok($zip->set_number('4270108')->is_valid_number, '静岡県島田市牧之原(その他)');
ok($zip->set_number('4270111')->is_valid_number, '静岡県島田市阪本');
ok($zip->set_number('4270112')->is_valid_number, '静岡県島田市月坂');
ok($zip->set_number('4270113')->is_valid_number, '静岡県島田市湯日');
ok($zip->set_number('4270231')->is_valid_number, '静岡県島田市笹間下');
ok($zip->set_number('4270232')->is_valid_number, '静岡県島田市伊久美');
ok($zip->set_number('4270233')->is_valid_number, '静岡県島田市身成');
ok($zip->set_number('4280001')->is_valid_number, '静岡県島田市高熊');
ok($zip->set_number('4280002')->is_valid_number, '静岡県島田市福用');
ok($zip->set_number('4280003')->is_valid_number, '静岡県島田市神尾');
ok($zip->set_number('4280004')->is_valid_number, '静岡県島田市横岡');
ok($zip->set_number('4280005')->is_valid_number, '静岡県島田市横岡新田');
ok($zip->set_number('4280006')->is_valid_number, '静岡県島田市牛尾');
ok($zip->set_number('4280007')->is_valid_number, '静岡県島田市島');
ok($zip->set_number('4280008')->is_valid_number, '静岡県島田市竹下');
ok($zip->set_number('4280009')->is_valid_number, '静岡県島田市大代');
ok($zip->set_number('4280011')->is_valid_number, '静岡県島田市番生寺');
ok($zip->set_number('4280012')->is_valid_number, '静岡県島田市金谷代官町');
ok($zip->set_number('4280013')->is_valid_number, '静岡県島田市金谷東');
ok($zip->set_number('4280014')->is_valid_number, '静岡県島田市金谷泉町');
ok($zip->set_number('4280015')->is_valid_number, '静岡県島田市金谷扇町');
ok($zip->set_number('4280016')->is_valid_number, '静岡県島田市金谷宮崎町');
ok($zip->set_number('4280017')->is_valid_number, '静岡県島田市金谷栄町');
ok($zip->set_number('4280018')->is_valid_number, '静岡県島田市金谷根岸町');
ok($zip->set_number('4280019')->is_valid_number, '静岡県島田市志戸呂');
ok($zip->set_number('4280023')->is_valid_number, '静岡県島田市金谷坂町');
ok($zip->set_number('4280024')->is_valid_number, '静岡県島田市金谷南町');
ok($zip->set_number('4280025')->is_valid_number, '静岡県島田市金谷田町');
ok($zip->set_number('4280026')->is_valid_number, '静岡県島田市金谷本町');
ok($zip->set_number('4280027')->is_valid_number, '静岡県島田市金谷上十五軒');
ok($zip->set_number('4280028')->is_valid_number, '静岡県島田市金谷下十五軒');
ok($zip->set_number('4280031')->is_valid_number, '静岡県島田市金谷清水');
ok($zip->set_number('4280032')->is_valid_number, '静岡県島田市金谷天王町');
ok($zip->set_number('4280033')->is_valid_number, '静岡県島田市金谷二軒家');
ok($zip->set_number('4280034')->is_valid_number, '静岡県島田市金谷富士見町');
ok($zip->set_number('4280035')->is_valid_number, '静岡県島田市切山');
ok($zip->set_number('4280036')->is_valid_number, '静岡県島田市神谷城');
ok($zip->set_number('4280037')->is_valid_number, '静岡県島田市菊川');
ok($zip->set_number('4280038')->is_valid_number, '静岡県島田市佐夜鹿');
ok($zip->set_number('4280039')->is_valid_number, '静岡県島田市金谷猪土居');
ok($zip->set_number('4280041')->is_valid_number, '静岡県島田市金谷都町');
ok($zip->set_number('4280042')->is_valid_number, '静岡県島田市金谷古横町');
ok($zip->set_number('4280043')->is_valid_number, '静岡県島田市金谷中町');
ok($zip->set_number('4280044')->is_valid_number, '静岡県島田市金谷緑町');
ok($zip->set_number('4280046')->is_valid_number, '静岡県島田市金谷金山町');
ok($zip->set_number('4280047')->is_valid_number, '静岡県島田市金谷新町');
ok($zip->set_number('4280048')->is_valid_number, '静岡県島田市金谷城山町');
ok($zip->set_number('4280049')->is_valid_number, '静岡県島田市牧之原(250~343番地「255、256、258、259、262、');
ok($zip->set_number('4280049')->is_valid_number, '静岡県島田市276、294~300、302~304番地を除く」)');
ok($zip->set_number('4280101')->is_valid_number, '静岡県島田市川根町笹間渡');
ok($zip->set_number('4280102')->is_valid_number, '静岡県島田市川根町上河内');
ok($zip->set_number('4280103')->is_valid_number, '静岡県島田市川根町身成');
ok($zip->set_number('4280104')->is_valid_number, '静岡県島田市川根町家山');
ok($zip->set_number('4280105')->is_valid_number, '静岡県島田市川根町葛籠');
ok($zip->set_number('4280106')->is_valid_number, '静岡県島田市川根町抜里');
ok($zip->set_number('4280211')->is_valid_number, '静岡県島田市川根町笹間上');
ok($zip->set_number('4280212')->is_valid_number, '静岡県島田市川根町笹間下');
ok($zip->set_number('4280300')->is_valid_number, '静岡県榛原郡川根本町以下に掲載がない場合');
ok($zip->set_number('4280301')->is_valid_number, '静岡県榛原郡川根本町徳山');
ok($zip->set_number('4280302')->is_valid_number, '静岡県榛原郡川根本町文沢');
ok($zip->set_number('4280303')->is_valid_number, '静岡県榛原郡川根本町壱町河内');
ok($zip->set_number('4280304')->is_valid_number, '静岡県榛原郡川根本町下泉');
ok($zip->set_number('4280305')->is_valid_number, '静岡県榛原郡川根本町地名');
ok($zip->set_number('4280306')->is_valid_number, '静岡県榛原郡川根本町田野口');
ok($zip->set_number('4280311')->is_valid_number, '静岡県榛原郡川根本町元藤川');
ok($zip->set_number('4280312')->is_valid_number, '静岡県榛原郡川根本町水川');
ok($zip->set_number('4280313')->is_valid_number, '静岡県榛原郡川根本町上長尾');
ok($zip->set_number('4280314')->is_valid_number, '静岡県榛原郡川根本町下長尾');
ok($zip->set_number('4280315')->is_valid_number, '静岡県榛原郡川根本町久野脇');
ok($zip->set_number('4280401')->is_valid_number, '静岡県榛原郡川根本町梅地');
ok($zip->set_number('4280402')->is_valid_number, '静岡県榛原郡川根本町犬間');
ok($zip->set_number('4280411')->is_valid_number, '静岡県榛原郡川根本町千頭');
ok($zip->set_number('4280412')->is_valid_number, '静岡県榛原郡川根本町奥泉');
ok($zip->set_number('4280413')->is_valid_number, '静岡県榛原郡川根本町桑野山');
ok($zip->set_number('4280414')->is_valid_number, '静岡県榛原郡川根本町東藤川');
ok($zip->set_number('4280415')->is_valid_number, '静岡県榛原郡川根本町上岸');
ok($zip->set_number('4280416')->is_valid_number, '静岡県榛原郡川根本町田代');
ok($zip->set_number('4280417')->is_valid_number, '静岡県榛原郡川根本町青部');
ok($zip->set_number('4280418')->is_valid_number, '静岡県榛原郡川根本町崎平');
ok($zip->set_number('4280501')->is_valid_number, '静岡県静岡市葵区小河内');
ok($zip->set_number('4280502')->is_valid_number, '静岡県静岡市葵区上坂本');
ok($zip->set_number('4280503')->is_valid_number, '静岡県静岡市葵区岩崎');
ok($zip->set_number('4280504')->is_valid_number, '静岡県静岡市葵区井川');
ok($zip->set_number('4280505')->is_valid_number, '静岡県静岡市葵区田代');
ok($zip->set_number('4300801')->is_valid_number, '静岡県浜松市東区神立町');
ok($zip->set_number('4300802')->is_valid_number, '静岡県浜松市東区将監町');
ok($zip->set_number('4300803')->is_valid_number, '静岡県浜松市東区植松町');
ok($zip->set_number('4300804')->is_valid_number, '静岡県浜松市中区富吉町');
ok($zip->set_number('4300805')->is_valid_number, '静岡県浜松市中区相生町');
ok($zip->set_number('4300806')->is_valid_number, '静岡県浜松市中区木戸町');
ok($zip->set_number('4300807')->is_valid_number, '静岡県浜松市中区佐藤');
ok($zip->set_number('4300808')->is_valid_number, '静岡県浜松市中区天神町');
ok($zip->set_number('4300811')->is_valid_number, '静岡県浜松市中区名塚町');
ok($zip->set_number('4300812')->is_valid_number, '静岡県浜松市南区本郷町');
ok($zip->set_number('4300813')->is_valid_number, '静岡県浜松市南区芳川町');
ok($zip->set_number('4300814')->is_valid_number, '静岡県浜松市南区恩地町');
ok($zip->set_number('4300815')->is_valid_number, '静岡県浜松市南区都盛町');
ok($zip->set_number('4300816')->is_valid_number, '静岡県浜松市南区参野町');
ok($zip->set_number('4300817')->is_valid_number, '静岡県浜松市南区頭陀寺町');
ok($zip->set_number('4300821')->is_valid_number, '静岡県浜松市南区西町');
ok($zip->set_number('4300822')->is_valid_number, '静岡県浜松市南区東町');
ok($zip->set_number('4300823')->is_valid_number, '静岡県浜松市南区河輪町');
ok($zip->set_number('4300824')->is_valid_number, '静岡県浜松市南区富屋町');
ok($zip->set_number('4300825')->is_valid_number, '静岡県浜松市南区下江町');
ok($zip->set_number('4300826')->is_valid_number, '静岡県浜松市南区四本松町');
ok($zip->set_number('4300827')->is_valid_number, '静岡県浜松市南区立野町');
ok($zip->set_number('4300831')->is_valid_number, '静岡県浜松市南区御給町');
ok($zip->set_number('4300832')->is_valid_number, '静岡県浜松市南区長田町');
ok($zip->set_number('4300833')->is_valid_number, '静岡県浜松市南区三新町');
ok($zip->set_number('4300834')->is_valid_number, '静岡県浜松市南区松島町');
ok($zip->set_number('4300835')->is_valid_number, '静岡県浜松市南区遠州浜');
ok($zip->set_number('4300836')->is_valid_number, '静岡県浜松市南区福島町');
ok($zip->set_number('4300837')->is_valid_number, '静岡県浜松市南区西島町');
ok($zip->set_number('4300838')->is_valid_number, '静岡県浜松市南区鼡野町');
ok($zip->set_number('4300841')->is_valid_number, '静岡県浜松市南区寺脇町');
ok($zip->set_number('4300842')->is_valid_number, '静岡県浜松市南区大柳町');
ok($zip->set_number('4300843')->is_valid_number, '静岡県浜松市南区福塚町');
ok($zip->set_number('4300844')->is_valid_number, '静岡県浜松市南区江之島町');
ok($zip->set_number('4300845')->is_valid_number, '静岡県浜松市南区中田島町');
ok($zip->set_number('4300846')->is_valid_number, '静岡県浜松市南区白羽町');
ok($zip->set_number('4300851')->is_valid_number, '静岡県浜松市中区向宿');
ok($zip->set_number('4300852')->is_valid_number, '静岡県浜松市中区領家');
ok($zip->set_number('4300853')->is_valid_number, '静岡県浜松市南区三島町');
ok($zip->set_number('4300854')->is_valid_number, '静岡県浜松市中区瓜内町');
ok($zip->set_number('4300854')->is_valid_number, '静岡県浜松市南区瓜内町');
ok($zip->set_number('4300855')->is_valid_number, '静岡県浜松市南区楊子町');
ok($zip->set_number('4300856')->is_valid_number, '静岡県浜松市中区中島');
ok($zip->set_number('4300857')->is_valid_number, '静岡県浜松市中区中島町');
ok($zip->set_number('4300901')->is_valid_number, '静岡県浜松市中区曳馬');
ok($zip->set_number('4300902')->is_valid_number, '静岡県浜松市中区曳馬町');
ok($zip->set_number('4300903')->is_valid_number, '静岡県浜松市中区助信町');
ok($zip->set_number('4300904')->is_valid_number, '静岡県浜松市中区中沢町');
ok($zip->set_number('4300905')->is_valid_number, '静岡県浜松市中区下池川町');
ok($zip->set_number('4300906')->is_valid_number, '静岡県浜松市中区住吉');
ok($zip->set_number('4300907')->is_valid_number, '静岡県浜松市中区高林');
ok($zip->set_number('4300911')->is_valid_number, '静岡県浜松市中区新津町');
ok($zip->set_number('4300912')->is_valid_number, '静岡県浜松市中区茄子町');
ok($zip->set_number('4300913')->is_valid_number, '静岡県浜松市中区船越町');
ok($zip->set_number('4300915')->is_valid_number, '静岡県浜松市中区東田町');
ok($zip->set_number('4300916')->is_valid_number, '静岡県浜松市中区早馬町');
ok($zip->set_number('4300917')->is_valid_number, '静岡県浜松市中区常盤町');
ok($zip->set_number('4300918')->is_valid_number, '静岡県浜松市中区八幡町');
ok($zip->set_number('4300919')->is_valid_number, '静岡県浜松市中区野口町');
ok($zip->set_number('4300923')->is_valid_number, '静岡県浜松市中区北寺島町');
ok($zip->set_number('4300924')->is_valid_number, '静岡県浜松市中区龍禅寺町');
ok($zip->set_number('4300925')->is_valid_number, '静岡県浜松市中区寺島町');
ok($zip->set_number('4300926')->is_valid_number, '静岡県浜松市中区砂山町');
ok($zip->set_number('4300927')->is_valid_number, '静岡県浜松市中区旭町');
ok($zip->set_number('4300928')->is_valid_number, '静岡県浜松市中区板屋町(次のビルを除く)');
ok($zip->set_number('4300929')->is_valid_number, '静岡県浜松市中区中央');
ok($zip->set_number('4300931')->is_valid_number, '静岡県浜松市中区神明町');
ok($zip->set_number('4300932')->is_valid_number, '静岡県浜松市中区肴町');
ok($zip->set_number('4300933')->is_valid_number, '静岡県浜松市中区鍛冶町');
ok($zip->set_number('4300934')->is_valid_number, '静岡県浜松市中区千歳町');
ok($zip->set_number('4300935')->is_valid_number, '静岡県浜松市中区伝馬町');
ok($zip->set_number('4300936')->is_valid_number, '静岡県浜松市中区大工町');
ok($zip->set_number('4300937')->is_valid_number, '静岡県浜松市中区利町');
ok($zip->set_number('4300938')->is_valid_number, '静岡県浜松市中区紺屋町');
ok($zip->set_number('4300939')->is_valid_number, '静岡県浜松市中区連尺町');
ok($zip->set_number('4300941')->is_valid_number, '静岡県浜松市中区山下町');
ok($zip->set_number('4300942')->is_valid_number, '静岡県浜松市中区元浜町');
ok($zip->set_number('4300943')->is_valid_number, '静岡県浜松市中区北田町');
ok($zip->set_number('4300944')->is_valid_number, '静岡県浜松市中区田町');
ok($zip->set_number('4300945')->is_valid_number, '静岡県浜松市中区池町');
ok($zip->set_number('4300946')->is_valid_number, '静岡県浜松市中区元城町');
ok($zip->set_number('4300947')->is_valid_number, '静岡県浜松市中区松城町');
ok($zip->set_number('4300948')->is_valid_number, '静岡県浜松市中区元目町');
ok($zip->set_number('4300949')->is_valid_number, '静岡県浜松市中区尾張町');
ok($zip->set_number('4307701')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(1階)');
ok($zip->set_number('4307702')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(2階)');
ok($zip->set_number('4307703')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(3階)');
ok($zip->set_number('4307704')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(4階)');
ok($zip->set_number('4307705')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(5階)');
ok($zip->set_number('4307706')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(6階)');
ok($zip->set_number('4307707')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(7階)');
ok($zip->set_number('4307708')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(8階)');
ok($zip->set_number('4307709')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(9階)');
ok($zip->set_number('4307710')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(10階)');
ok($zip->set_number('4307711')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(11階)');
ok($zip->set_number('4307712')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(12階)');
ok($zip->set_number('4307713')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(13階)');
ok($zip->set_number('4307714')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(14階)');
ok($zip->set_number('4307715')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(15階)');
ok($zip->set_number('4307716')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(16階)');
ok($zip->set_number('4307717')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(17階)');
ok($zip->set_number('4307718')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(18階)');
ok($zip->set_number('4307719')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(19階)');
ok($zip->set_number('4307720')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(20階)');
ok($zip->set_number('4307721')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(21階)');
ok($zip->set_number('4307722')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(22階)');
ok($zip->set_number('4307723')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(23階)');
ok($zip->set_number('4307724')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(24階)');
ok($zip->set_number('4307725')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(25階)');
ok($zip->set_number('4307726')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(26階)');
ok($zip->set_number('4307727')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(27階)');
ok($zip->set_number('4307728')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(28階)');
ok($zip->set_number('4307729')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(29階)');
ok($zip->set_number('4307730')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(30階)');
ok($zip->set_number('4307731')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(31階)');
ok($zip->set_number('4307732')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(32階)');
ok($zip->set_number('4307733')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(33階)');
ok($zip->set_number('4307734')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(34階)');
ok($zip->set_number('4307735')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(35階)');
ok($zip->set_number('4307736')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(36階)');
ok($zip->set_number('4307737')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(37階)');
ok($zip->set_number('4307738')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(38階)');
ok($zip->set_number('4307739')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(39階)');
ok($zip->set_number('4307740')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(40階)');
ok($zip->set_number('4307741')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(41階)');
ok($zip->set_number('4307742')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(42階)');
ok($zip->set_number('4307743')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(43階)');
ok($zip->set_number('4307744')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(44階)');
ok($zip->set_number('4307745')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(45階)');
ok($zip->set_number('4307790')->is_valid_number, '静岡県浜松市中区板屋町浜松アクトタワー(地階・階層不明)');
ok($zip->set_number('4310101')->is_valid_number, '静岡県浜松市西区雄踏町山崎');
ok($zip->set_number('4310102')->is_valid_number, '静岡県浜松市西区雄踏町宇布見');
ok($zip->set_number('4310103')->is_valid_number, '静岡県浜松市西区雄踏');
ok($zip->set_number('4310201')->is_valid_number, '静岡県浜松市西区篠原町');
ok($zip->set_number('4310202')->is_valid_number, '静岡県浜松市西区坪井町');
ok($zip->set_number('4310203')->is_valid_number, '静岡県浜松市西区馬郡町');
ok($zip->set_number('4310211')->is_valid_number, '静岡県浜松市西区舞阪町舞阪');
ok($zip->set_number('4310212')->is_valid_number, '静岡県浜松市西区舞阪町長十新田');
ok($zip->set_number('4310213')->is_valid_number, '静岡県浜松市西区舞阪町浜田');
ok($zip->set_number('4310214')->is_valid_number, '静岡県浜松市西区舞阪町弁天島');
ok($zip->set_number('4310301')->is_valid_number, '静岡県湖西市新居町中之郷');
ok($zip->set_number('4310302')->is_valid_number, '静岡県湖西市新居町新居');
ok($zip->set_number('4310303')->is_valid_number, '静岡県湖西市新居町浜名');
ok($zip->set_number('4310304')->is_valid_number, '静岡県湖西市新居町内山');
ok($zip->set_number('4310400')->is_valid_number, '静岡県湖西市以下に掲載がない場合');
ok($zip->set_number('4310401')->is_valid_number, '静岡県湖西市横山');
ok($zip->set_number('4310402')->is_valid_number, '静岡県湖西市利木');
ok($zip->set_number('4310403')->is_valid_number, '静岡県湖西市大知波');
ok($zip->set_number('4310404')->is_valid_number, '静岡県湖西市太田');
ok($zip->set_number('4310405')->is_valid_number, '静岡県湖西市神座');
ok($zip->set_number('4310411')->is_valid_number, '静岡県湖西市入出');
ok($zip->set_number('4310412')->is_valid_number, '静岡県湖西市内浦');
ok($zip->set_number('4310421')->is_valid_number, '静岡県湖西市新所');
ok($zip->set_number('4310422')->is_valid_number, '静岡県湖西市岡崎');
ok($zip->set_number('4310423')->is_valid_number, '静岡県湖西市新所・岡崎・梅田入会地');
ok($zip->set_number('4310424')->is_valid_number, '静岡県湖西市新所原');
ok($zip->set_number('4310425')->is_valid_number, '静岡県湖西市梅田');
ok($zip->set_number('4310426')->is_valid_number, '静岡県湖西市新所原東');
ok($zip->set_number('4310427')->is_valid_number, '静岡県湖西市駅南');
ok($zip->set_number('4310428')->is_valid_number, '静岡県湖西市ときわ');
ok($zip->set_number('4310429')->is_valid_number, '静岡県湖西市南台');
ok($zip->set_number('4310431')->is_valid_number, '静岡県湖西市鷲津');
ok($zip->set_number('4310432')->is_valid_number, '静岡県湖西市風の杜');
ok($zip->set_number('4310441')->is_valid_number, '静岡県湖西市吉美');
ok($zip->set_number('4310442')->is_valid_number, '静岡県湖西市古見');
ok($zip->set_number('4310443')->is_valid_number, '静岡県湖西市山口');
ok($zip->set_number('4310444')->is_valid_number, '静岡県湖西市坊瀬');
ok($zip->set_number('4310451')->is_valid_number, '静岡県湖西市白須賀');
ok($zip->set_number('4310452')->is_valid_number, '静岡県湖西市境宿');
ok($zip->set_number('4311101')->is_valid_number, '静岡県浜松市西区和光町');
ok($zip->set_number('4311102')->is_valid_number, '静岡県浜松市西区大山町');
ok($zip->set_number('4311103')->is_valid_number, '静岡県浜松市西区湖東町');
ok($zip->set_number('4311104')->is_valid_number, '静岡県浜松市西区桜台');
ok($zip->set_number('4311111')->is_valid_number, '静岡県浜松市西区伊左地町');
ok($zip->set_number('4311112')->is_valid_number, '静岡県浜松市西区大人見町');
ok($zip->set_number('4311113')->is_valid_number, '静岡県浜松市西区古人見町');
ok($zip->set_number('4311114')->is_valid_number, '静岡県浜松市西区佐浜町');
ok($zip->set_number('4311115')->is_valid_number, '静岡県浜松市西区和地町');
ok($zip->set_number('4311201')->is_valid_number, '静岡県浜松市西区深萩町');
ok($zip->set_number('4311202')->is_valid_number, '静岡県浜松市西区呉松町');
ok($zip->set_number('4311203')->is_valid_number, '静岡県浜松市西区平松町');
ok($zip->set_number('4311204')->is_valid_number, '静岡県浜松市西区白洲町');
ok($zip->set_number('4311205')->is_valid_number, '静岡県浜松市西区協和町');
ok($zip->set_number('4311206')->is_valid_number, '静岡県浜松市西区庄和町');
ok($zip->set_number('4311207')->is_valid_number, '静岡県浜松市西区村櫛町');
ok($zip->set_number('4311208')->is_valid_number, '静岡県浜松市西区庄内町');
ok($zip->set_number('4311209')->is_valid_number, '静岡県浜松市西区舘山寺町');
ok($zip->set_number('4311301')->is_valid_number, '静岡県浜松市北区細江町小野');
ok($zip->set_number('4311302')->is_valid_number, '静岡県浜松市北区細江町広岡');
ok($zip->set_number('4311303')->is_valid_number, '静岡県浜松市北区細江町三和');
ok($zip->set_number('4311304')->is_valid_number, '静岡県浜松市北区細江町中川');
ok($zip->set_number('4311305')->is_valid_number, '静岡県浜松市北区細江町気賀');
ok($zip->set_number('4311401')->is_valid_number, '静岡県浜松市北区三ヶ日町佐久米');
ok($zip->set_number('4311402')->is_valid_number, '静岡県浜松市北区三ヶ日町都筑');
ok($zip->set_number('4311403')->is_valid_number, '静岡県浜松市北区三ヶ日町大崎');
ok($zip->set_number('4311404')->is_valid_number, '静岡県浜松市北区三ヶ日町宇志');
ok($zip->set_number('4311405')->is_valid_number, '静岡県浜松市北区三ヶ日町津々崎');
ok($zip->set_number('4311406')->is_valid_number, '静岡県浜松市北区三ヶ日町駒場');
ok($zip->set_number('4311407')->is_valid_number, '静岡県浜松市北区三ヶ日町大谷');
ok($zip->set_number('4311411')->is_valid_number, '静岡県浜松市北区三ヶ日町福長');
ok($zip->set_number('4311412')->is_valid_number, '静岡県浜松市北区三ヶ日町只木');
ok($zip->set_number('4311413')->is_valid_number, '静岡県浜松市北区三ヶ日町摩訶耶');
ok($zip->set_number('4311414')->is_valid_number, '静岡県浜松市北区三ヶ日町三ヶ日');
ok($zip->set_number('4311415')->is_valid_number, '静岡県浜松市北区三ヶ日町岡本');
ok($zip->set_number('4311416')->is_valid_number, '静岡県浜松市北区三ヶ日町釣');
ok($zip->set_number('4311417')->is_valid_number, '静岡県浜松市北区三ヶ日町平山');
ok($zip->set_number('4311421')->is_valid_number, '静岡県浜松市北区三ヶ日町本坂');
ok($zip->set_number('4311422')->is_valid_number, '静岡県浜松市北区三ヶ日町日比沢');
ok($zip->set_number('4311423')->is_valid_number, '静岡県浜松市北区三ヶ日町鵺代');
ok($zip->set_number('4311424')->is_valid_number, '静岡県浜松市北区三ヶ日町下尾奈');
ok($zip->set_number('4311425')->is_valid_number, '静岡県浜松市北区三ヶ日町上尾奈');
ok($zip->set_number('4312101')->is_valid_number, '静岡県浜松市北区滝沢町');
ok($zip->set_number('4312102')->is_valid_number, '静岡県浜松市北区都田町');
ok($zip->set_number('4312103')->is_valid_number, '静岡県浜松市北区新都田');
ok($zip->set_number('4312104')->is_valid_number, '静岡県浜松市北区鷲沢町');
ok($zip->set_number('4312201')->is_valid_number, '静岡県浜松市北区引佐町東久留女木(その他)');
ok($zip->set_number('4312202')->is_valid_number, '静岡県浜松市北区引佐町川名');
ok($zip->set_number('4312203')->is_valid_number, '静岡県浜松市北区引佐町三岳');
ok($zip->set_number('4312204')->is_valid_number, '静岡県浜松市北区引佐町兎荷');
ok($zip->set_number('4312205')->is_valid_number, '静岡県浜松市北区引佐町伊平');
ok($zip->set_number('4312206')->is_valid_number, '静岡県浜松市北区引佐町西黒田');
ok($zip->set_number('4312207')->is_valid_number, '静岡県浜松市北区引佐町東黒田');
ok($zip->set_number('4312211')->is_valid_number, '静岡県浜松市北区引佐町花平');
ok($zip->set_number('4312212')->is_valid_number, '静岡県浜松市北区引佐町井伊谷');
ok($zip->set_number('4312213')->is_valid_number, '静岡県浜松市北区引佐町金指');
ok($zip->set_number('4312214')->is_valid_number, '静岡県浜松市北区引佐町横尾');
ok($zip->set_number('4312215')->is_valid_number, '静岡県浜松市北区引佐町白岩');
ok($zip->set_number('4312216')->is_valid_number, '静岡県浜松市北区神宮寺町');
ok($zip->set_number('4312221')->is_valid_number, '静岡県浜松市北区引佐町田畑');
ok($zip->set_number('4312222')->is_valid_number, '静岡県浜松市北区引佐町黒渕');
ok($zip->set_number('4312223')->is_valid_number, '静岡県浜松市北区引佐町栃窪');
ok($zip->set_number('4312224')->is_valid_number, '静岡県浜松市北区引佐町奥山');
ok($zip->set_number('4312225')->is_valid_number, '静岡県浜松市北区引佐町狩宿');
ok($zip->set_number('4312226')->is_valid_number, '静岡県浜松市北区引佐町谷沢');
ok($zip->set_number('4312531')->is_valid_number, '静岡県浜松市北区引佐町東久留女木(372~799番地)');
ok($zip->set_number('4312532')->is_valid_number, '静岡県浜松市北区引佐町西久留女木');
ok($zip->set_number('4312533')->is_valid_number, '静岡県浜松市北区引佐町四方浄');
ok($zip->set_number('4312534')->is_valid_number, '静岡県浜松市北区引佐町別所');
ok($zip->set_number('4312535')->is_valid_number, '静岡県浜松市北区引佐町的場');
ok($zip->set_number('4312536')->is_valid_number, '静岡県浜松市北区引佐町田沢');
ok($zip->set_number('4312537')->is_valid_number, '静岡県浜松市北区引佐町渋川');
ok($zip->set_number('4313101')->is_valid_number, '静岡県浜松市東区豊町');
ok($zip->set_number('4313102')->is_valid_number, '静岡県浜松市東区豊西町');
ok($zip->set_number('4313103')->is_valid_number, '静岡県浜松市東区常光町');
ok($zip->set_number('4313104')->is_valid_number, '静岡県浜松市東区貴平町');
ok($zip->set_number('4313105')->is_valid_number, '静岡県浜松市東区笠井新田町');
ok($zip->set_number('4313106')->is_valid_number, '静岡県浜松市東区笠井上町');
ok($zip->set_number('4313107')->is_valid_number, '静岡県浜松市東区笠井町');
ok($zip->set_number('4313108')->is_valid_number, '静岡県浜松市東区恒武町');
ok($zip->set_number('4313111')->is_valid_number, '静岡県浜松市東区中郡町');
ok($zip->set_number('4313112')->is_valid_number, '静岡県浜松市東区大島町');
ok($zip->set_number('4313113')->is_valid_number, '静岡県浜松市東区大瀬町');
ok($zip->set_number('4313114')->is_valid_number, '静岡県浜松市東区積志町');
ok($zip->set_number('4313115')->is_valid_number, '静岡県浜松市東区西ケ崎町');
ok($zip->set_number('4313121')->is_valid_number, '静岡県浜松市東区有玉北町');
ok($zip->set_number('4313122')->is_valid_number, '静岡県浜松市東区有玉南町');
ok($zip->set_number('4313123')->is_valid_number, '静岡県浜松市東区有玉西町');
ok($zip->set_number('4313124')->is_valid_number, '静岡県浜松市東区半田町');
ok($zip->set_number('4313125')->is_valid_number, '静岡県浜松市東区半田山');
ok($zip->set_number('4313126')->is_valid_number, '静岡県浜松市東区有玉台');
ok($zip->set_number('4313301')->is_valid_number, '静岡県浜松市天竜区横川');
ok($zip->set_number('4313302')->is_valid_number, '静岡県浜松市天竜区只来');
ok($zip->set_number('4313303')->is_valid_number, '静岡県浜松市天竜区山東');
ok($zip->set_number('4313304')->is_valid_number, '静岡県浜松市天竜区次郎八新田');
ok($zip->set_number('4313305')->is_valid_number, '静岡県浜松市天竜区大谷');
ok($zip->set_number('4313306')->is_valid_number, '静岡県浜松市天竜区船明');
ok($zip->set_number('4313311')->is_valid_number, '静岡県浜松市天竜区二俣町阿蔵');
ok($zip->set_number('4313312')->is_valid_number, '静岡県浜松市天竜区二俣町南鹿島');
ok($zip->set_number('4313313')->is_valid_number, '静岡県浜松市天竜区二俣町鹿島');
ok($zip->set_number('4313314')->is_valid_number, '静岡県浜松市天竜区二俣町二俣');
ok($zip->set_number('4313315')->is_valid_number, '静岡県浜松市天竜区二俣町大園');
ok($zip->set_number('4313421')->is_valid_number, '静岡県浜松市天竜区日明');
ok($zip->set_number('4313422')->is_valid_number, '静岡県浜松市天竜区米沢');
ok($zip->set_number('4313423')->is_valid_number, '静岡県浜松市天竜区渡ケ島');
ok($zip->set_number('4313424')->is_valid_number, '静岡県浜松市天竜区緑恵台');
ok($zip->set_number('4313425')->is_valid_number, '静岡県浜松市天竜区青谷');
ok($zip->set_number('4313426')->is_valid_number, '静岡県浜松市天竜区両島');
ok($zip->set_number('4313427')->is_valid_number, '静岡県浜松市天竜区上野');
ok($zip->set_number('4313428')->is_valid_number, '静岡県浜松市天竜区石神');
ok($zip->set_number('4313531')->is_valid_number, '静岡県浜松市天竜区東藤平');
ok($zip->set_number('4313532')->is_valid_number, '静岡県浜松市天竜区西藤平');
ok($zip->set_number('4313533')->is_valid_number, '静岡県浜松市天竜区長沢');
ok($zip->set_number('4313534')->is_valid_number, '静岡県浜松市天竜区懐山');
ok($zip->set_number('4313535')->is_valid_number, '静岡県浜松市天竜区芦窪');
ok($zip->set_number('4313536')->is_valid_number, '静岡県浜松市天竜区阿寺');
ok($zip->set_number('4313641')->is_valid_number, '静岡県浜松市天竜区熊');
ok($zip->set_number('4313642')->is_valid_number, '静岡県浜松市天竜区大栗安');
ok($zip->set_number('4313643')->is_valid_number, '静岡県浜松市天竜区神沢');
ok($zip->set_number('4313751')->is_valid_number, '静岡県浜松市天竜区東雲名');
ok($zip->set_number('4313752')->is_valid_number, '静岡県浜松市天竜区小川');
ok($zip->set_number('4313753')->is_valid_number, '静岡県浜松市天竜区佐久');
ok($zip->set_number('4313754')->is_valid_number, '静岡県浜松市天竜区相津');
ok($zip->set_number('4313755')->is_valid_number, '静岡県浜松市天竜区大川');
ok($zip->set_number('4313756')->is_valid_number, '静岡県浜松市天竜区谷山');
ok($zip->set_number('4313761')->is_valid_number, '静岡県浜松市天竜区西雲名');
ok($zip->set_number('4313762')->is_valid_number, '静岡県浜松市天竜区伊砂');
ok($zip->set_number('4313763')->is_valid_number, '静岡県浜松市天竜区月');
ok($zip->set_number('4313764')->is_valid_number, '静岡県浜松市天竜区横山町');
ok($zip->set_number('4313801')->is_valid_number, '静岡県浜松市天竜区龍山町瀬尻');
ok($zip->set_number('4313802')->is_valid_number, '静岡県浜松市天竜区龍山町下平山');
ok($zip->set_number('4313803')->is_valid_number, '静岡県浜松市天竜区龍山町戸倉');
ok($zip->set_number('4313804')->is_valid_number, '静岡県浜松市天竜区龍山町大嶺');
ok($zip->set_number('4313901')->is_valid_number, '静岡県浜松市天竜区佐久間町佐久間');
ok($zip->set_number('4313902')->is_valid_number, '静岡県浜松市天竜区佐久間町大井');
ok($zip->set_number('4313903')->is_valid_number, '静岡県浜松市天竜区佐久間町上平山');
ok($zip->set_number('4313904')->is_valid_number, '静岡県浜松市天竜区佐久間町戸口');
ok($zip->set_number('4313905')->is_valid_number, '静岡県浜松市天竜区佐久間町半場');
ok($zip->set_number('4313906')->is_valid_number, '静岡県浜松市天竜区佐久間町浦川');
ok($zip->set_number('4313907')->is_valid_number, '静岡県浜松市天竜区佐久間町川合');
ok($zip->set_number('4313908')->is_valid_number, '静岡県浜松市天竜区佐久間町中部');
ok($zip->set_number('4314101')->is_valid_number, '静岡県浜松市天竜区水窪町奥領家');
ok($zip->set_number('4314102')->is_valid_number, '静岡県浜松市天竜区水窪町地頭方');
ok($zip->set_number('4314103')->is_valid_number, '静岡県浜松市天竜区水窪町山住');
ok($zip->set_number('4314111')->is_valid_number, '静岡県浜松市天竜区佐久間町相月');
ok($zip->set_number('4314112')->is_valid_number, '静岡県浜松市天竜区佐久間町奥領家');
ok($zip->set_number('4314121')->is_valid_number, '愛知県北設楽郡豊根村富山');
ok($zip->set_number('4320000')->is_valid_number, '静岡県浜松市中区以下に掲載がない場合');
ok($zip->set_number('4320000')->is_valid_number, '静岡県浜松市東区以下に掲載がない場合');
ok($zip->set_number('4320000')->is_valid_number, '静岡県浜松市西区以下に掲載がない場合');
ok($zip->set_number('4320000')->is_valid_number, '静岡県浜松市南区以下に掲載がない場合');
ok($zip->set_number('4320000')->is_valid_number, '静岡県浜松市北区以下に掲載がない場合');
ok($zip->set_number('4320000')->is_valid_number, '静岡県浜松市天竜区以下に掲載がない場合');
ok($zip->set_number('4328001')->is_valid_number, '静岡県浜松市西区西山町');
ok($zip->set_number('4328002')->is_valid_number, '静岡県浜松市中区富塚町');
ok($zip->set_number('4328003')->is_valid_number, '静岡県浜松市中区和地山');
ok($zip->set_number('4328004')->is_valid_number, '静岡県浜松市中区文丘町');
ok($zip->set_number('4328005')->is_valid_number, '静岡県浜松市西区神ケ谷町');
ok($zip->set_number('4328006')->is_valid_number, '静岡県浜松市西区大久保町');
ok($zip->set_number('4328007')->is_valid_number, '静岡県浜松市西区神原町');
ok($zip->set_number('4328011')->is_valid_number, '静岡県浜松市中区城北');
ok($zip->set_number('4328012')->is_valid_number, '静岡県浜松市中区布橋');
ok($zip->set_number('4328013')->is_valid_number, '静岡県浜松市中区広沢');
ok($zip->set_number('4328014')->is_valid_number, '静岡県浜松市中区鹿谷町');
ok($zip->set_number('4328015')->is_valid_number, '静岡県浜松市中区高町');
ok($zip->set_number('4328016')->is_valid_number, '静岡県浜松市中区中山町');
ok($zip->set_number('4328017')->is_valid_number, '静岡県浜松市中区三組町');
ok($zip->set_number('4328018')->is_valid_number, '静岡県浜松市中区蜆塚');
ok($zip->set_number('4328021')->is_valid_number, '静岡県浜松市中区佐鳴台');
ok($zip->set_number('4328022')->is_valid_number, '静岡県浜松市中区山手町');
ok($zip->set_number('4328023')->is_valid_number, '静岡県浜松市中区鴨江');
ok($zip->set_number('4328024')->is_valid_number, '静岡県浜松市中区鴨江町');
ok($zip->set_number('4328025')->is_valid_number, '静岡県浜松市中区栄町');
ok($zip->set_number('4328026')->is_valid_number, '静岡県浜松市中区元魚町');
ok($zip->set_number('4328027')->is_valid_number, '静岡県浜松市中区旅籠町');
ok($zip->set_number('4328031')->is_valid_number, '静岡県浜松市中区平田町');
ok($zip->set_number('4328032')->is_valid_number, '静岡県浜松市中区海老塚町');
ok($zip->set_number('4328033')->is_valid_number, '静岡県浜松市中区海老塚');
ok($zip->set_number('4328034')->is_valid_number, '静岡県浜松市中区塩町');
ok($zip->set_number('4328035')->is_valid_number, '静岡県浜松市中区成子町');
ok($zip->set_number('4328036')->is_valid_number, '静岡県浜松市中区東伊場');
ok($zip->set_number('4328037')->is_valid_number, '静岡県浜松市中区南伊場町');
ok($zip->set_number('4328038')->is_valid_number, '静岡県浜松市中区西伊場町');
ok($zip->set_number('4328041')->is_valid_number, '静岡県浜松市中区菅原町');
ok($zip->set_number('4328042')->is_valid_number, '静岡県浜松市中区上浅田');
ok($zip->set_number('4328043')->is_valid_number, '静岡県浜松市中区浅田町');
ok($zip->set_number('4328044')->is_valid_number, '静岡県浜松市中区南浅田');
ok($zip->set_number('4328045')->is_valid_number, '静岡県浜松市中区西浅田');
ok($zip->set_number('4328046')->is_valid_number, '静岡県浜松市中区春日町');
ok($zip->set_number('4328047')->is_valid_number, '静岡県浜松市中区神田町');
ok($zip->set_number('4328048')->is_valid_number, '静岡県浜松市中区森田町');
ok($zip->set_number('4328051')->is_valid_number, '静岡県浜松市南区若林町');
ok($zip->set_number('4328052')->is_valid_number, '静岡県浜松市南区東若林町');
ok($zip->set_number('4328053')->is_valid_number, '静岡県浜松市中区法枝町');
ok($zip->set_number('4328053')->is_valid_number, '静岡県浜松市南区法枝町');
ok($zip->set_number('4328054')->is_valid_number, '静岡県浜松市南区田尻町');
ok($zip->set_number('4328055')->is_valid_number, '静岡県浜松市南区卸本町');
ok($zip->set_number('4328056')->is_valid_number, '静岡県浜松市南区米津町');
ok($zip->set_number('4328057')->is_valid_number, '静岡県浜松市南区堤町');
ok($zip->set_number('4328058')->is_valid_number, '静岡県浜松市南区新橋町');
ok($zip->set_number('4328061')->is_valid_number, '静岡県浜松市西区入野町');
ok($zip->set_number('4328062')->is_valid_number, '静岡県浜松市南区増楽町');
ok($zip->set_number('4328063')->is_valid_number, '静岡県浜松市南区小沢渡町');
ok($zip->set_number('4328064')->is_valid_number, '静岡県浜松市南区倉松町');
ok($zip->set_number('4328065')->is_valid_number, '静岡県浜松市南区高塚町');
ok($zip->set_number('4328066')->is_valid_number, '静岡県浜松市西区志都呂町');
ok($zip->set_number('4328067')->is_valid_number, '静岡県浜松市西区西鴨江町');
ok($zip->set_number('4328068')->is_valid_number, '静岡県浜松市西区大平台');
ok($zip->set_number('4328069')->is_valid_number, '静岡県浜松市西区志都呂');
ok($zip->set_number('4328071')->is_valid_number, '静岡県浜松市西区西都台町');
ok($zip->set_number('4338101')->is_valid_number, '静岡県浜松市北区三幸町');
ok($zip->set_number('4338102')->is_valid_number, '静岡県浜松市北区大原町');
ok($zip->set_number('4338103')->is_valid_number, '静岡県浜松市北区豊岡町');
ok($zip->set_number('4338104')->is_valid_number, '静岡県浜松市北区東三方町');
ok($zip->set_number('4338105')->is_valid_number, '静岡県浜松市北区三方原町');
ok($zip->set_number('4338108')->is_valid_number, '静岡県浜松市北区根洗町');
ok($zip->set_number('4338109')->is_valid_number, '静岡県浜松市中区花川町');
ok($zip->set_number('4338111')->is_valid_number, '静岡県浜松市中区葵西');
ok($zip->set_number('4338112')->is_valid_number, '静岡県浜松市北区初生町');
ok($zip->set_number('4338113')->is_valid_number, '静岡県浜松市中区小豆餅');
ok($zip->set_number('4338114')->is_valid_number, '静岡県浜松市中区葵東');
ok($zip->set_number('4338116')->is_valid_number, '静岡県浜松市中区西丘町');
ok($zip->set_number('4338117')->is_valid_number, '静岡県浜松市中区高丘東');
ok($zip->set_number('4338118')->is_valid_number, '静岡県浜松市中区高丘西');
ok($zip->set_number('4338119')->is_valid_number, '静岡県浜松市中区高丘北');
ok($zip->set_number('4338121')->is_valid_number, '静岡県浜松市中区萩丘');
ok($zip->set_number('4338122')->is_valid_number, '静岡県浜松市中区上島');
ok($zip->set_number('4338123')->is_valid_number, '静岡県浜松市中区幸');
ok($zip->set_number('4338124')->is_valid_number, '静岡県浜松市中区泉');
ok($zip->set_number('4338125')->is_valid_number, '静岡県浜松市中区和合町');
ok($zip->set_number('4338126')->is_valid_number, '静岡県浜松市中区泉町');
ok($zip->set_number('4338127')->is_valid_number, '静岡県浜松市中区和合北');
ok($zip->set_number('4340000')->is_valid_number, '静岡県浜松市浜北区以下に掲載がない場合');
ok($zip->set_number('4340001')->is_valid_number, '静岡県浜松市浜北区堀谷');
ok($zip->set_number('4340002')->is_valid_number, '静岡県浜松市浜北区尾野');
ok($zip->set_number('4340003')->is_valid_number, '静岡県浜松市浜北区新原');
ok($zip->set_number('4340004')->is_valid_number, '静岡県浜松市浜北区宮口');
ok($zip->set_number('4340005')->is_valid_number, '静岡県浜松市浜北区大平');
ok($zip->set_number('4340006')->is_valid_number, '静岡県浜松市浜北区四大地');
ok($zip->set_number('4340007')->is_valid_number, '静岡県浜松市浜北区灰木');
ok($zip->set_number('4340011')->is_valid_number, '静岡県浜松市浜北区上島');
ok($zip->set_number('4340012')->is_valid_number, '静岡県浜松市浜北区中瀬');
ok($zip->set_number('4340013')->is_valid_number, '静岡県浜松市浜北区永島');
ok($zip->set_number('4340014')->is_valid_number, '静岡県浜松市浜北区本沢合');
ok($zip->set_number('4340015')->is_valid_number, '静岡県浜松市浜北区於呂');
ok($zip->set_number('4340016')->is_valid_number, '静岡県浜松市浜北区根堅');
ok($zip->set_number('4340017')->is_valid_number, '静岡県浜松市浜北区豊保');
ok($zip->set_number('4340018')->is_valid_number, '静岡県浜松市浜北区西中瀬');
ok($zip->set_number('4340021')->is_valid_number, '静岡県浜松市浜北区八幡');
ok($zip->set_number('4340022')->is_valid_number, '静岡県浜松市浜北区新堀');
ok($zip->set_number('4340023')->is_valid_number, '静岡県浜松市浜北区高薗');
ok($zip->set_number('4340024')->is_valid_number, '静岡県浜松市浜北区竜南');
ok($zip->set_number('4340025')->is_valid_number, '静岡県浜松市浜北区善地');
ok($zip->set_number('4340026')->is_valid_number, '静岡県浜松市浜北区東美薗');
ok($zip->set_number('4340027')->is_valid_number, '静岡県浜松市浜北区油一色');
ok($zip->set_number('4340028')->is_valid_number, '静岡県浜松市浜北区上善地');
ok($zip->set_number('4340029')->is_valid_number, '静岡県浜松市浜北区新野');
ok($zip->set_number('4340031')->is_valid_number, '静岡県浜松市浜北区小林');
ok($zip->set_number('4340032')->is_valid_number, '静岡県浜松市浜北区道本');
ok($zip->set_number('4340033')->is_valid_number, '静岡県浜松市浜北区西美薗');
ok($zip->set_number('4340034')->is_valid_number, '静岡県浜松市浜北区高畑');
ok($zip->set_number('4340035')->is_valid_number, '静岡県浜松市浜北区寺島');
ok($zip->set_number('4340036')->is_valid_number, '静岡県浜松市浜北区横須賀');
ok($zip->set_number('4340037')->is_valid_number, '静岡県浜松市浜北区沼');
ok($zip->set_number('4340038')->is_valid_number, '静岡県浜松市浜北区貴布祢');
ok($zip->set_number('4340041')->is_valid_number, '静岡県浜松市浜北区平口');
ok($zip->set_number('4340042')->is_valid_number, '静岡県浜松市浜北区小松');
ok($zip->set_number('4340043')->is_valid_number, '静岡県浜松市浜北区中条');
ok($zip->set_number('4340044')->is_valid_number, '静岡県浜松市浜北区内野');
ok($zip->set_number('4340045')->is_valid_number, '静岡県浜松市浜北区内野台');
ok($zip->set_number('4340046')->is_valid_number, '静岡県浜松市浜北区染地台');
ok($zip->set_number('4350001')->is_valid_number, '静岡県浜松市東区上石田町');
ok($zip->set_number('4350002')->is_valid_number, '静岡県浜松市東区白鳥町');
ok($zip->set_number('4350003')->is_valid_number, '静岡県浜松市東区中里町');
ok($zip->set_number('4350004')->is_valid_number, '静岡県浜松市東区中野町');
ok($zip->set_number('4350005')->is_valid_number, '静岡県浜松市東区安新町');
ok($zip->set_number('4350006')->is_valid_number, '静岡県浜松市東区下石田町');
ok($zip->set_number('4350007')->is_valid_number, '静岡県浜松市東区流通元町');
ok($zip->set_number('4350008')->is_valid_number, '静岡県浜松市東区松小池町');
ok($zip->set_number('4350011')->is_valid_number, '静岡県浜松市東区国吉町');
ok($zip->set_number('4350012')->is_valid_number, '静岡県浜松市東区安間町');
ok($zip->set_number('4350013')->is_valid_number, '静岡県浜松市東区天龍川町');
ok($zip->set_number('4350014')->is_valid_number, '静岡県浜松市東区大蒲町');
ok($zip->set_number('4350015')->is_valid_number, '静岡県浜松市東区子安町');
ok($zip->set_number('4350016')->is_valid_number, '静岡県浜松市東区和田町');
ok($zip->set_number('4350017')->is_valid_number, '静岡県浜松市東区薬師町');
ok($zip->set_number('4350018')->is_valid_number, '静岡県浜松市東区薬新町');
ok($zip->set_number('4350021')->is_valid_number, '静岡県浜松市東区材木町');
ok($zip->set_number('4350022')->is_valid_number, '静岡県浜松市南区鶴見町');
ok($zip->set_number('4350023')->is_valid_number, '静岡県浜松市南区新貝町');
ok($zip->set_number('4350024')->is_valid_number, '静岡県浜松市南区大塚町');
ok($zip->set_number('4350025')->is_valid_number, '静岡県浜松市南区老間町');
ok($zip->set_number('4350026')->is_valid_number, '静岡県浜松市南区金折町');
ok($zip->set_number('4350027')->is_valid_number, '静岡県浜松市南区下飯田町');
ok($zip->set_number('4350028')->is_valid_number, '静岡県浜松市南区飯田町');
ok($zip->set_number('4350029')->is_valid_number, '静岡県浜松市東区龍光町');
ok($zip->set_number('4350031')->is_valid_number, '静岡県浜松市東区長鶴町');
ok($zip->set_number('4350032')->is_valid_number, '静岡県浜松市南区古川町');
ok($zip->set_number('4350033')->is_valid_number, '静岡県浜松市南区石原町');
ok($zip->set_number('4350034')->is_valid_number, '静岡県浜松市南区安松町');
ok($zip->set_number('4350035')->is_valid_number, '静岡県浜松市南区西伝寺町');
ok($zip->set_number('4350036')->is_valid_number, '静岡県浜松市南区渡瀬町');
ok($zip->set_number('4350037')->is_valid_number, '静岡県浜松市南区青屋町');
ok($zip->set_number('4350038')->is_valid_number, '静岡県浜松市南区三和町');
ok($zip->set_number('4350041')->is_valid_number, '静岡県浜松市東区北島町');
ok($zip->set_number('4350042')->is_valid_number, '静岡県浜松市東区篠ケ瀬町');
ok($zip->set_number('4350043')->is_valid_number, '静岡県浜松市東区宮竹町');
ok($zip->set_number('4350044')->is_valid_number, '静岡県浜松市東区西塚町');
ok($zip->set_number('4350045')->is_valid_number, '静岡県浜松市中区細島町');
ok($zip->set_number('4350046')->is_valid_number, '静岡県浜松市東区丸塚町');
ok($zip->set_number('4350047')->is_valid_number, '静岡県浜松市東区原島町');
ok($zip->set_number('4350048')->is_valid_number, '静岡県浜松市東区上西町');
ok($zip->set_number('4350051')->is_valid_number, '静岡県浜松市東区市野町');
ok($zip->set_number('4350052')->is_valid_number, '静岡県浜松市東区天王町');
ok($zip->set_number('4350053')->is_valid_number, '静岡県浜松市東区上新屋町');
ok($zip->set_number('4350054')->is_valid_number, '静岡県浜松市中区早出町');
ok($zip->set_number('4350055')->is_valid_number, '静岡県浜松市中区十軒町');
ok($zip->set_number('4350056')->is_valid_number, '静岡県浜松市東区小池町');
ok($zip->set_number('4350057')->is_valid_number, '静岡県浜松市東区中田町');
ok($zip->set_number('4360000')->is_valid_number, '静岡県掛川市以下に掲載がない場合');
ok($zip->set_number('4360001')->is_valid_number, '静岡県掛川市東山');
ok($zip->set_number('4360002')->is_valid_number, '静岡県掛川市佐夜鹿');
ok($zip->set_number('4360003')->is_valid_number, '静岡県掛川市日坂');
ok($zip->set_number('4360004')->is_valid_number, '静岡県掛川市八坂');
ok($zip->set_number('4360005')->is_valid_number, '静岡県掛川市伊達方');
ok($zip->set_number('4360006')->is_valid_number, '静岡県掛川市本所');
ok($zip->set_number('4360007')->is_valid_number, '静岡県掛川市小原子');
ok($zip->set_number('4360008')->is_valid_number, '静岡県掛川市千羽');
ok($zip->set_number('4360009')->is_valid_number, '静岡県掛川市大野');
ok($zip->set_number('4360011')->is_valid_number, '静岡県掛川市満水');
ok($zip->set_number('4360012')->is_valid_number, '静岡県掛川市上内田');
ok($zip->set_number('4360013')->is_valid_number, '静岡県掛川市子隣');
ok($zip->set_number('4360014')->is_valid_number, '静岡県掛川市岩井寺');
ok($zip->set_number('4360015')->is_valid_number, '静岡県掛川市和田');
ok($zip->set_number('4360016')->is_valid_number, '静岡県掛川市板沢');
ok($zip->set_number('4360017')->is_valid_number, '静岡県掛川市杉谷');
ok($zip->set_number('4360018')->is_valid_number, '静岡県掛川市葵町');
ok($zip->set_number('4360019')->is_valid_number, '静岡県掛川市青葉台');
ok($zip->set_number('4360020')->is_valid_number, '静岡県掛川市矢崎町');
ok($zip->set_number('4360021')->is_valid_number, '静岡県掛川市緑ケ丘');
ok($zip->set_number('4360022')->is_valid_number, '静岡県掛川市上張');
ok($zip->set_number('4360023')->is_valid_number, '静岡県掛川市結縁寺');
ok($zip->set_number('4360024')->is_valid_number, '静岡県掛川市南西郷');
ok($zip->set_number('4360025')->is_valid_number, '静岡県掛川市下俣');
ok($zip->set_number('4360026')->is_valid_number, '静岡県掛川市下俣南');
ok($zip->set_number('4360027')->is_valid_number, '静岡県掛川市久保');
ok($zip->set_number('4360028')->is_valid_number, '静岡県掛川市亀の甲');
ok($zip->set_number('4360029')->is_valid_number, '静岡県掛川市南');
ok($zip->set_number('4360030')->is_valid_number, '静岡県掛川市杉谷南');
ok($zip->set_number('4360031')->is_valid_number, '静岡県掛川市高御所');
ok($zip->set_number('4360032')->is_valid_number, '静岡県掛川市平野');
ok($zip->set_number('4360033')->is_valid_number, '静岡県掛川市篠場');
ok($zip->set_number('4360034')->is_valid_number, '静岡県掛川市梅橋');
ok($zip->set_number('4360035')->is_valid_number, '静岡県掛川市徳泉');
ok($zip->set_number('4360036')->is_valid_number, '静岡県掛川市原川');
ok($zip->set_number('4360037')->is_valid_number, '静岡県掛川市岡津');
ok($zip->set_number('4360038')->is_valid_number, '静岡県掛川市領家');
ok($zip->set_number('4360039')->is_valid_number, '静岡県掛川市沢田');
ok($zip->set_number('4360040')->is_valid_number, '静岡県掛川市菖蒲ヶ池');
ok($zip->set_number('4360041')->is_valid_number, '静岡県掛川市秋葉路');
ok($zip->set_number('4360042')->is_valid_number, '静岡県掛川市二瀬川');
ok($zip->set_number('4360043')->is_valid_number, '静岡県掛川市大池');
ok($zip->set_number('4360044')->is_valid_number, '静岡県掛川市清崎');
ok($zip->set_number('4360045')->is_valid_number, '静岡県掛川市小鷹町');
ok($zip->set_number('4360046')->is_valid_number, '静岡県掛川市中央高町');
ok($zip->set_number('4360047')->is_valid_number, '静岡県掛川市長谷');
ok($zip->set_number('4360048')->is_valid_number, '静岡県掛川市細田');
ok($zip->set_number('4360049')->is_valid_number, '静岡県掛川市上屋敷');
ok($zip->set_number('4360051')->is_valid_number, '静岡県掛川市中宿');
ok($zip->set_number('4360052')->is_valid_number, '静岡県掛川市柳町');
ok($zip->set_number('4360053')->is_valid_number, '静岡県掛川市弥生町');
ok($zip->set_number('4360054')->is_valid_number, '静岡県掛川市城西');
ok($zip->set_number('4360055')->is_valid_number, '静岡県掛川市紺屋町');
ok($zip->set_number('4360056')->is_valid_number, '静岡県掛川市中央');
ok($zip->set_number('4360057')->is_valid_number, '静岡県掛川市十九首');
ok($zip->set_number('4360058')->is_valid_number, '静岡県掛川市七日町');
ok($zip->set_number('4360059')->is_valid_number, '静岡県掛川市城北');
ok($zip->set_number('4360061')->is_valid_number, '静岡県掛川市水垂');
ok($zip->set_number('4360062')->is_valid_number, '静岡県掛川市旭ケ丘');
ok($zip->set_number('4360063')->is_valid_number, '静岡県掛川市北池新田');
ok($zip->set_number('4360064')->is_valid_number, '静岡県掛川市北門');
ok($zip->set_number('4360065')->is_valid_number, '静岡県掛川市天王町');
ok($zip->set_number('4360066')->is_valid_number, '静岡県掛川市谷の口町');
ok($zip->set_number('4360067')->is_valid_number, '静岡県掛川市下西郷');
ok($zip->set_number('4360068')->is_valid_number, '静岡県掛川市御所原');
ok($zip->set_number('4360069')->is_valid_number, '静岡県掛川市旭台');
ok($zip->set_number('4360070')->is_valid_number, '静岡県掛川市紅葉台');
ok($zip->set_number('4360071')->is_valid_number, '静岡県掛川市仁藤');
ok($zip->set_number('4360072')->is_valid_number, '静岡県掛川市印内');
ok($zip->set_number('4360073')->is_valid_number, '静岡県掛川市金城');
ok($zip->set_number('4360074')->is_valid_number, '静岡県掛川市葛川');
ok($zip->set_number('4360075')->is_valid_number, '静岡県掛川市仁藤町');
ok($zip->set_number('4360076')->is_valid_number, '静岡県掛川市塩町');
ok($zip->set_number('4360077')->is_valid_number, '静岡県掛川市駅前');
ok($zip->set_number('4360078')->is_valid_number, '静岡県掛川市肴町');
ok($zip->set_number('4360079')->is_valid_number, '静岡県掛川市掛川');
ok($zip->set_number('4360081')->is_valid_number, '静岡県掛川市初馬');
ok($zip->set_number('4360082')->is_valid_number, '静岡県掛川市淡陽');
ok($zip->set_number('4360083')->is_valid_number, '静岡県掛川市薗ケ谷');
ok($zip->set_number('4360084')->is_valid_number, '静岡県掛川市逆川');
ok($zip->set_number('4360085')->is_valid_number, '静岡県掛川市成滝');
ok($zip->set_number('4360086')->is_valid_number, '静岡県掛川市宮脇');
ok($zip->set_number('4360087')->is_valid_number, '静岡県掛川市大多郎');
ok($zip->set_number('4360088')->is_valid_number, '静岡県掛川市葛ケ丘');
ok($zip->set_number('4360089')->is_valid_number, '静岡県掛川市安養寺');
ok($zip->set_number('4360090')->is_valid_number, '静岡県掛川市光陽');
ok($zip->set_number('4360091')->is_valid_number, '静岡県掛川市城下');
ok($zip->set_number('4360092')->is_valid_number, '静岡県掛川市中町');
ok($zip->set_number('4360093')->is_valid_number, '静岡県掛川市連雀');
ok($zip->set_number('4360094')->is_valid_number, '静岡県掛川市喜町');
ok($zip->set_number('4360101')->is_valid_number, '静岡県掛川市上西之谷');
ok($zip->set_number('4360102')->is_valid_number, '静岡県掛川市中西之谷');
ok($zip->set_number('4360103')->is_valid_number, '静岡県掛川市久居島');
ok($zip->set_number('4360104')->is_valid_number, '静岡県掛川市平島');
ok($zip->set_number('4360105')->is_valid_number, '静岡県掛川市原里');
ok($zip->set_number('4360106')->is_valid_number, '静岡県掛川市寺島');
ok($zip->set_number('4360111')->is_valid_number, '静岡県掛川市本郷');
ok($zip->set_number('4360112')->is_valid_number, '静岡県掛川市細谷');
ok($zip->set_number('4360113')->is_valid_number, '静岡県掛川市各和');
ok($zip->set_number('4360114')->is_valid_number, '静岡県掛川市高田');
ok($zip->set_number('4360115')->is_valid_number, '静岡県掛川市吉岡');
ok($zip->set_number('4360116')->is_valid_number, '静岡県掛川市西山');
ok($zip->set_number('4360117')->is_valid_number, '静岡県掛川市幡鎌');
ok($zip->set_number('4360221')->is_valid_number, '静岡県掛川市上垂木');
ok($zip->set_number('4360222')->is_valid_number, '静岡県掛川市下垂木');
ok($zip->set_number('4360223')->is_valid_number, '静岡県掛川市黒田');
ok($zip->set_number('4360224')->is_valid_number, '静岡県掛川市富部');
ok($zip->set_number('4360225')->is_valid_number, '静岡県掛川市家代');
ok($zip->set_number('4360226')->is_valid_number, '静岡県掛川市遊家');
ok($zip->set_number('4360227')->is_valid_number, '静岡県掛川市家代の里');
ok($zip->set_number('4360331')->is_valid_number, '静岡県掛川市黒俣');
ok($zip->set_number('4360332')->is_valid_number, '静岡県掛川市居尻');
ok($zip->set_number('4360333')->is_valid_number, '静岡県掛川市丹間');
ok($zip->set_number('4360334')->is_valid_number, '静岡県掛川市孕石');
ok($zip->set_number('4360335')->is_valid_number, '静岡県掛川市大和田');
ok($zip->set_number('4360336')->is_valid_number, '静岡県掛川市萩間');
ok($zip->set_number('4360337')->is_valid_number, '静岡県掛川市炭焼');
ok($zip->set_number('4360338')->is_valid_number, '静岡県掛川市和光');
ok($zip->set_number('4360341')->is_valid_number, '静岡県掛川市倉真');
ok($zip->set_number('4360342')->is_valid_number, '静岡県掛川市上西郷');
ok($zip->set_number('4360343')->is_valid_number, '静岡県掛川市五明');
ok($zip->set_number('4370000')->is_valid_number, '静岡県袋井市以下に掲載がない場合');
ok($zip->set_number('4370001')->is_valid_number, '静岡県袋井市山田');
ok($zip->set_number('4370002')->is_valid_number, '静岡県袋井市川会');
ok($zip->set_number('4370003')->is_valid_number, '静岡県袋井市萱間');
ok($zip->set_number('4370004')->is_valid_number, '静岡県袋井市友永');
ok($zip->set_number('4370005')->is_valid_number, '静岡県袋井市見取');
ok($zip->set_number('4370006')->is_valid_number, '静岡県袋井市大谷');
ok($zip->set_number('4370011')->is_valid_number, '静岡県袋井市村松');
ok($zip->set_number('4370012')->is_valid_number, '静岡県袋井市国本');
ok($zip->set_number('4370013')->is_valid_number, '静岡県袋井市新屋');
ok($zip->set_number('4370014')->is_valid_number, '静岡県袋井市永楽町');
ok($zip->set_number('4370015')->is_valid_number, '静岡県袋井市旭町');
ok($zip->set_number('4370016')->is_valid_number, '静岡県袋井市葵町');
ok($zip->set_number('4370017')->is_valid_number, '静岡県袋井市鷲巣');
ok($zip->set_number('4370021')->is_valid_number, '静岡県袋井市広岡');
ok($zip->set_number('4370022')->is_valid_number, '静岡県袋井市方丈');
ok($zip->set_number('4370023')->is_valid_number, '静岡県袋井市高尾');
ok($zip->set_number('4370024')->is_valid_number, '静岡県袋井市三門町');
ok($zip->set_number('4370025')->is_valid_number, '静岡県袋井市栄町');
ok($zip->set_number('4370026')->is_valid_number, '静岡県袋井市袋井');
ok($zip->set_number('4370027')->is_valid_number, '静岡県袋井市高尾町');
ok($zip->set_number('4370028')->is_valid_number, '静岡県袋井市神長');
ok($zip->set_number('4370029')->is_valid_number, '静岡県袋井市掛之上');
ok($zip->set_number('4370031')->is_valid_number, '静岡県袋井市愛野');
ok($zip->set_number('4370032')->is_valid_number, '静岡県袋井市豊沢');
ok($zip->set_number('4370033')->is_valid_number, '静岡県袋井市上田町');
ok($zip->set_number('4370034')->is_valid_number, '静岡県袋井市青木町');
ok($zip->set_number('4370035')->is_valid_number, '静岡県袋井市砂本町');
ok($zip->set_number('4370036')->is_valid_number, '静岡県袋井市小川町');
ok($zip->set_number('4370037')->is_valid_number, '静岡県袋井市清水町');
ok($zip->set_number('4370038')->is_valid_number, '静岡県袋井市大門');
ok($zip->set_number('4370039')->is_valid_number, '静岡県袋井市愛野東');
ok($zip->set_number('4370040')->is_valid_number, '静岡県袋井市愛野南');
ok($zip->set_number('4370041')->is_valid_number, '静岡県袋井市睦町');
ok($zip->set_number('4370042')->is_valid_number, '静岡県袋井市山名町');
ok($zip->set_number('4370043')->is_valid_number, '静岡県袋井市新池');
ok($zip->set_number('4370044')->is_valid_number, '静岡県袋井市松袋井');
ok($zip->set_number('4370045')->is_valid_number, '静岡県袋井市彦島');
ok($zip->set_number('4370046')->is_valid_number, '静岡県袋井市木原');
ok($zip->set_number('4370047')->is_valid_number, '静岡県袋井市西田');
ok($zip->set_number('4370051')->is_valid_number, '静岡県袋井市深見');
ok($zip->set_number('4370052')->is_valid_number, '静岡県袋井市太田');
ok($zip->set_number('4370053')->is_valid_number, '静岡県袋井市延久');
ok($zip->set_number('4370054')->is_valid_number, '静岡県袋井市徳光');
ok($zip->set_number('4370055')->is_valid_number, '静岡県袋井市土橋');
ok($zip->set_number('4370056')->is_valid_number, '静岡県袋井市小山');
ok($zip->set_number('4370057')->is_valid_number, '静岡県袋井市横井');
ok($zip->set_number('4370061')->is_valid_number, '静岡県袋井市久能');
ok($zip->set_number('4370062')->is_valid_number, '静岡県袋井市泉町');
ok($zip->set_number('4370063')->is_valid_number, '静岡県袋井市田町');
ok($zip->set_number('4370064')->is_valid_number, '静岡県袋井市川井');
ok($zip->set_number('4370065')->is_valid_number, '静岡県袋井市堀越');
ok($zip->set_number('4370066')->is_valid_number, '静岡県袋井市山科');
ok($zip->set_number('4370067')->is_valid_number, '静岡県袋井市天神町');
ok($zip->set_number('4370121')->is_valid_number, '静岡県袋井市宇刈');
ok($zip->set_number('4370122')->is_valid_number, '静岡県袋井市春岡');
ok($zip->set_number('4370123')->is_valid_number, '静岡県袋井市下山梨');
ok($zip->set_number('4370124')->is_valid_number, '静岡県袋井市沖山梨');
ok($zip->set_number('4370125')->is_valid_number, '静岡県袋井市上山梨');
ok($zip->set_number('4370126')->is_valid_number, '静岡県袋井市月見町');
ok($zip->set_number('4370127')->is_valid_number, '静岡県袋井市可睡の杜');
ok($zip->set_number('4370200')->is_valid_number, '静岡県周智郡森町以下に掲載がない場合');
ok($zip->set_number('4370201')->is_valid_number, '静岡県周智郡森町嵯塚');
ok($zip->set_number('4370202')->is_valid_number, '静岡県周智郡森町亀久保');
ok($zip->set_number('4370203')->is_valid_number, '静岡県周智郡森町鍛冶島');
ok($zip->set_number('4370204')->is_valid_number, '静岡県周智郡森町問詰');
ok($zip->set_number('4370205')->is_valid_number, '静岡県周智郡森町大鳥居');
ok($zip->set_number('4370206')->is_valid_number, '静岡県周智郡森町葛布');
ok($zip->set_number('4370207')->is_valid_number, '静岡県周智郡森町西俣');
ok($zip->set_number('4370208')->is_valid_number, '静岡県周智郡森町三倉');
ok($zip->set_number('4370211')->is_valid_number, '静岡県周智郡森町城下');
ok($zip->set_number('4370212')->is_valid_number, '静岡県周智郡森町向天方');
ok($zip->set_number('4370213')->is_valid_number, '静岡県周智郡森町睦実');
ok($zip->set_number('4370214')->is_valid_number, '静岡県周智郡森町草ケ谷');
ok($zip->set_number('4370215')->is_valid_number, '静岡県周智郡森町森');
ok($zip->set_number('4370216')->is_valid_number, '静岡県周智郡森町天宮');
ok($zip->set_number('4370217')->is_valid_number, '静岡県周智郡森町薄場');
ok($zip->set_number('4370221')->is_valid_number, '静岡県周智郡森町円田');
ok($zip->set_number('4370222')->is_valid_number, '静岡県周智郡森町飯田');
ok($zip->set_number('4370223')->is_valid_number, '静岡県周智郡森町中川');
ok($zip->set_number('4370224')->is_valid_number, '静岡県周智郡森町牛飼');
ok($zip->set_number('4370225')->is_valid_number, '静岡県周智郡森町谷中');
ok($zip->set_number('4370226')->is_valid_number, '静岡県周智郡森町一宮');
ok($zip->set_number('4370227')->is_valid_number, '静岡県周智郡森町橘');
ok($zip->set_number('4370601')->is_valid_number, '静岡県浜松市天竜区春野町川上');
ok($zip->set_number('4370602')->is_valid_number, '静岡県浜松市天竜区春野町杉');
ok($zip->set_number('4370603')->is_valid_number, '静岡県浜松市天竜区春野町五和');
ok($zip->set_number('4370604')->is_valid_number, '静岡県浜松市天竜区春野町宮川');
ok($zip->set_number('4370605')->is_valid_number, '静岡県浜松市天竜区春野町気田');
ok($zip->set_number('4370606')->is_valid_number, '静岡県浜松市天竜区春野町豊岡');
ok($zip->set_number('4370607')->is_valid_number, '静岡県浜松市天竜区春野町石切');
ok($zip->set_number('4370608')->is_valid_number, '静岡県浜松市天竜区春野町小俣京丸');
ok($zip->set_number('4370611')->is_valid_number, '静岡県浜松市天竜区春野町田河内');
ok($zip->set_number('4370612')->is_valid_number, '静岡県浜松市天竜区春野町花島');
ok($zip->set_number('4370613')->is_valid_number, '静岡県浜松市天竜区春野町牧野');
ok($zip->set_number('4370614')->is_valid_number, '静岡県浜松市天竜区春野町長蔵寺');
ok($zip->set_number('4370615')->is_valid_number, '静岡県浜松市天竜区春野町石打松下');
ok($zip->set_number('4370616')->is_valid_number, '静岡県浜松市天竜区春野町田黒');
ok($zip->set_number('4370617')->is_valid_number, '静岡県浜松市天竜区春野町筏戸大上');
ok($zip->set_number('4370618')->is_valid_number, '静岡県浜松市天竜区春野町越木平');
ok($zip->set_number('4370621')->is_valid_number, '静岡県浜松市天竜区春野町砂川');
ok($zip->set_number('4370622')->is_valid_number, '静岡県浜松市天竜区春野町大時');
ok($zip->set_number('4370623')->is_valid_number, '静岡県浜松市天竜区春野町胡桃平');
ok($zip->set_number('4370624')->is_valid_number, '静岡県浜松市天竜区春野町和泉平');
ok($zip->set_number('4370625')->is_valid_number, '静岡県浜松市天竜区春野町堀之内');
ok($zip->set_number('4370626')->is_valid_number, '静岡県浜松市天竜区春野町領家');
ok($zip->set_number('4371101')->is_valid_number, '静岡県袋井市浅羽');
ok($zip->set_number('4371102')->is_valid_number, '静岡県袋井市浅名');
ok($zip->set_number('4371103')->is_valid_number, '静岡県袋井市豊住');
ok($zip->set_number('4371104')->is_valid_number, '静岡県袋井市新堀');
ok($zip->set_number('4371105')->is_valid_number, '静岡県袋井市梅山');
ok($zip->set_number('4371111')->is_valid_number, '静岡県袋井市中新田');
ok($zip->set_number('4371112')->is_valid_number, '静岡県袋井市大野');
ok($zip->set_number('4371113')->is_valid_number, '静岡県袋井市東同笠');
ok($zip->set_number('4371114')->is_valid_number, '静岡県袋井市西同笠');
ok($zip->set_number('4371115')->is_valid_number, '静岡県袋井市湊');
ok($zip->set_number('4371116')->is_valid_number, '静岡県袋井市太郎助');
ok($zip->set_number('4371117')->is_valid_number, '静岡県袋井市松原');
ok($zip->set_number('4371118')->is_valid_number, '静岡県袋井市西ケ崎');
ok($zip->set_number('4371119')->is_valid_number, '静岡県袋井市初越');
ok($zip->set_number('4371121')->is_valid_number, '静岡県袋井市諸井');
ok($zip->set_number('4371122')->is_valid_number, '静岡県袋井市浅岡');
ok($zip->set_number('4371123')->is_valid_number, '静岡県袋井市浅羽一色');
ok($zip->set_number('4371124')->is_valid_number, '静岡県袋井市富里');
ok($zip->set_number('4371125')->is_valid_number, '静岡県袋井市中');
ok($zip->set_number('4371126')->is_valid_number, '静岡県袋井市長溝');
ok($zip->set_number('4371201')->is_valid_number, '静岡県磐田市豊浜中野');
ok($zip->set_number('4371202')->is_valid_number, '静岡県磐田市豊浜');
ok($zip->set_number('4371203')->is_valid_number, '静岡県磐田市福田');
ok($zip->set_number('4371204')->is_valid_number, '静岡県磐田市福田中島');
ok($zip->set_number('4371205')->is_valid_number, '静岡県磐田市下太');
ok($zip->set_number('4371206')->is_valid_number, '静岡県磐田市五十子');
ok($zip->set_number('4371207')->is_valid_number, '静岡県磐田市蛭池');
ok($zip->set_number('4371208')->is_valid_number, '静岡県磐田市東小島');
ok($zip->set_number('4371209')->is_valid_number, '静岡県磐田市南島');
ok($zip->set_number('4371211')->is_valid_number, '静岡県磐田市大原(その他)');
ok($zip->set_number('4371212')->is_valid_number, '静岡県磐田市南田');
ok($zip->set_number('4371213')->is_valid_number, '静岡県磐田市塩新田');
ok($zip->set_number('4371214')->is_valid_number, '静岡県磐田市清庵新田');
ok($zip->set_number('4371215')->is_valid_number, '静岡県磐田市太郎馬新田');
ok($zip->set_number('4371216')->is_valid_number, '静岡県磐田市一色');
ok($zip->set_number('4371217')->is_valid_number, '静岡県磐田市宇兵衛新田');
ok($zip->set_number('4371218')->is_valid_number, '静岡県磐田市南田伊兵衛新田');
ok($zip->set_number('4371301')->is_valid_number, '静岡県掛川市横須賀');
ok($zip->set_number('4371302')->is_valid_number, '静岡県掛川市大渕');
ok($zip->set_number('4371303')->is_valid_number, '静岡県掛川市沖之須');
ok($zip->set_number('4371304')->is_valid_number, '静岡県掛川市西大渕');
ok($zip->set_number('4371305')->is_valid_number, '静岡県掛川市山崎');
ok($zip->set_number('4371306')->is_valid_number, '静岡県掛川市洋望台');
ok($zip->set_number('4371311')->is_valid_number, '静岡県袋井市山崎');
ok($zip->set_number('4371312')->is_valid_number, '静岡県袋井市岡崎');
ok($zip->set_number('4371401')->is_valid_number, '静岡県掛川市高瀬');
ok($zip->set_number('4371402')->is_valid_number, '静岡県掛川市中方');
ok($zip->set_number('4371403')->is_valid_number, '静岡県掛川市岩滑');
ok($zip->set_number('4371404')->is_valid_number, '静岡県掛川市西之谷');
ok($zip->set_number('4371405')->is_valid_number, '静岡県掛川市中');
ok($zip->set_number('4371406')->is_valid_number, '静岡県掛川市川久保');
ok($zip->set_number('4371407')->is_valid_number, '静岡県掛川市小貫');
ok($zip->set_number('4371411')->is_valid_number, '静岡県掛川市坂里');
ok($zip->set_number('4371412')->is_valid_number, '静岡県掛川市千浜');
ok($zip->set_number('4371413')->is_valid_number, '静岡県掛川市国安');
ok($zip->set_number('4371414')->is_valid_number, '静岡県掛川市国包');
ok($zip->set_number('4371415')->is_valid_number, '静岡県掛川市菊浜');
ok($zip->set_number('4371416')->is_valid_number, '静岡県掛川市三俣');
ok($zip->set_number('4371421')->is_valid_number, '静岡県掛川市大坂');
ok($zip->set_number('4371422')->is_valid_number, '静岡県掛川市海戸');
ok($zip->set_number('4371423')->is_valid_number, '静岡県掛川市浜川新田');
ok($zip->set_number('4371424')->is_valid_number, '静岡県掛川市浜野');
ok($zip->set_number('4371425')->is_valid_number, '静岡県掛川市浜野新田');
ok($zip->set_number('4371431')->is_valid_number, '静岡県掛川市上土方落合');
ok($zip->set_number('4371432')->is_valid_number, '静岡県掛川市上土方工業団地');
ok($zip->set_number('4371433')->is_valid_number, '静岡県掛川市上土方');
ok($zip->set_number('4371434')->is_valid_number, '静岡県掛川市下土方');
ok($zip->set_number('4371435')->is_valid_number, '静岡県掛川市上土方嶺向');
ok($zip->set_number('4371436')->is_valid_number, '静岡県掛川市今滝');
ok($zip->set_number('4371437')->is_valid_number, '静岡県掛川市上土方旦付新田');
ok($zip->set_number('4371438')->is_valid_number, '静岡県掛川市入山瀬');
ok($zip->set_number('4371439')->is_valid_number, '静岡県掛川市大坪台');
ok($zip->set_number('4371501')->is_valid_number, '静岡県菊川市丹野');
ok($zip->set_number('4371502')->is_valid_number, '静岡県菊川市古谷');
ok($zip->set_number('4371503')->is_valid_number, '静岡県菊川市川上');
ok($zip->set_number('4371504')->is_valid_number, '静岡県菊川市花水木');
ok($zip->set_number('4371505')->is_valid_number, '静岡県菊川市高橋');
ok($zip->set_number('4371506')->is_valid_number, '静岡県菊川市河東');
ok($zip->set_number('4371507')->is_valid_number, '静岡県菊川市赤土');
ok($zip->set_number('4371511')->is_valid_number, '静岡県菊川市目木');
ok($zip->set_number('4371512')->is_valid_number, '静岡県菊川市猿渡');
ok($zip->set_number('4371513')->is_valid_number, '静岡県菊川市棚草');
ok($zip->set_number('4371514')->is_valid_number, '静岡県菊川市下平川');
ok($zip->set_number('4371521')->is_valid_number, '静岡県菊川市上平川');
ok($zip->set_number('4371522')->is_valid_number, '静岡県菊川市嶺田');
ok($zip->set_number('4371523')->is_valid_number, '静岡県菊川市堂山新田');
ok($zip->set_number('4371524')->is_valid_number, '静岡県菊川市大石');
ok($zip->set_number('4371600')->is_valid_number, '静岡県御前崎市以下に掲載がない場合');
ok($zip->set_number('4371601')->is_valid_number, '静岡県御前崎市上朝比奈');
ok($zip->set_number('4371602')->is_valid_number, '静岡県御前崎市比木');
ok($zip->set_number('4371603')->is_valid_number, '静岡県御前崎市宮内');
ok($zip->set_number('4371604')->is_valid_number, '静岡県御前崎市佐倉');
ok($zip->set_number('4371605')->is_valid_number, '静岡県御前崎市下朝比奈');
ok($zip->set_number('4371611')->is_valid_number, '静岡県御前崎市新野');
ok($zip->set_number('4371612')->is_valid_number, '静岡県御前崎市池新田');
ok($zip->set_number('4371613')->is_valid_number, '静岡県御前崎市合戸');
ok($zip->set_number('4371614')->is_valid_number, '静岡県御前崎市塩原新田');
ok($zip->set_number('4371615')->is_valid_number, '静岡県御前崎市門屋');
ok($zip->set_number('4371621')->is_valid_number, '静岡県御前崎市御前崎');
ok($zip->set_number('4371622')->is_valid_number, '静岡県御前崎市白羽');
ok($zip->set_number('4371623')->is_valid_number, '静岡県御前崎市港');
ok($zip->set_number('4380000')->is_valid_number, '静岡県磐田市以下に掲載がない場合');
ok($zip->set_number('4380001')->is_valid_number, '静岡県磐田市藤上原');
ok($zip->set_number('4380002')->is_valid_number, '静岡県磐田市大久保');
ok($zip->set_number('4380003')->is_valid_number, '静岡県磐田市匂坂新');
ok($zip->set_number('4380004')->is_valid_number, '静岡県磐田市匂坂中');
ok($zip->set_number('4380005')->is_valid_number, '静岡県磐田市匂坂上');
ok($zip->set_number('4380006')->is_valid_number, '静岡県磐田市寺谷');
ok($zip->set_number('4380007')->is_valid_number, '静岡県磐田市寺谷新田');
ok($zip->set_number('4380008')->is_valid_number, '静岡県磐田市平松掛下入作');
ok($zip->set_number('4380011')->is_valid_number, '静岡県磐田市笠梅');
ok($zip->set_number('4380012')->is_valid_number, '静岡県磐田市向笠新屋');
ok($zip->set_number('4380013')->is_valid_number, '静岡県磐田市向笠竹之内');
ok($zip->set_number('4380014')->is_valid_number, '静岡県磐田市向笠西');
ok($zip->set_number('4380015')->is_valid_number, '静岡県磐田市篠原');
ok($zip->set_number('4380016')->is_valid_number, '静岡県磐田市岩井');
ok($zip->set_number('4380017')->is_valid_number, '静岡県磐田市安久路');
ok($zip->set_number('4380018')->is_valid_number, '静岡県磐田市三ケ野台');
ok($zip->set_number('4380019')->is_valid_number, '静岡県磐田市明ケ島原');
ok($zip->set_number('4380021')->is_valid_number, '静岡県磐田市玉越');
ok($zip->set_number('4380022')->is_valid_number, '静岡県磐田市西島');
ok($zip->set_number('4380023')->is_valid_number, '静岡県磐田市彦島');
ok($zip->set_number('4380024')->is_valid_number, '静岡県磐田市明ケ島');
ok($zip->set_number('4380025')->is_valid_number, '静岡県磐田市新貝');
ok($zip->set_number('4380026')->is_valid_number, '静岡県磐田市西貝塚');
ok($zip->set_number('4380027')->is_valid_number, '静岡県磐田市三ケ野');
ok($zip->set_number('4380028')->is_valid_number, '静岡県磐田市東山');
ok($zip->set_number('4380031')->is_valid_number, '静岡県磐田市稗原');
ok($zip->set_number('4380032')->is_valid_number, '静岡県磐田市東脇');
ok($zip->set_number('4380033')->is_valid_number, '静岡県磐田市新出');
ok($zip->set_number('4380034')->is_valid_number, '静岡県磐田市和口');
ok($zip->set_number('4380035')->is_valid_number, '静岡県磐田市東新屋');
ok($zip->set_number('4380036')->is_valid_number, '静岡県磐田市大立野');
ok($zip->set_number('4380037')->is_valid_number, '静岡県磐田市東貝塚');
ok($zip->set_number('4380038')->is_valid_number, '静岡県磐田市鎌田');
ok($zip->set_number('4380039')->is_valid_number, '静岡県磐田市東新町');
ok($zip->set_number('4380041')->is_valid_number, '静岡県磐田市西之島');
ok($zip->set_number('4380042')->is_valid_number, '静岡県磐田市上南田');
ok($zip->set_number('4380043')->is_valid_number, '静岡県磐田市大原(1番地~2061番地、2757番地~2768番地)');
ok($zip->set_number('4380044')->is_valid_number, '静岡県磐田市大泉町');
ok($zip->set_number('4380045')->is_valid_number, '静岡県磐田市上岡田');
ok($zip->set_number('4380046')->is_valid_number, '静岡県磐田市下岡田');
ok($zip->set_number('4380047')->is_valid_number, '静岡県磐田市豊島');
ok($zip->set_number('4380051')->is_valid_number, '静岡県磐田市上大之郷');
ok($zip->set_number('4380052')->is_valid_number, '静岡県磐田市下大之郷');
ok($zip->set_number('4380053')->is_valid_number, '静岡県磐田市中野');
ok($zip->set_number('4380054')->is_valid_number, '静岡県磐田市浜部');
ok($zip->set_number('4380055')->is_valid_number, '静岡県磐田市鮫島');
ok($zip->set_number('4380056')->is_valid_number, '静岡県磐田市小島');
ok($zip->set_number('4380057')->is_valid_number, '静岡県磐田市千手堂');
ok($zip->set_number('4380058')->is_valid_number, '静岡県磐田市万正寺');
ok($zip->set_number('4380061')->is_valid_number, '静岡県磐田市刑部島');
ok($zip->set_number('4380062')->is_valid_number, '静岡県磐田市新島');
ok($zip->set_number('4380063')->is_valid_number, '静岡県磐田市真光寺');
ok($zip->set_number('4380064')->is_valid_number, '静岡県磐田市北島');
ok($zip->set_number('4380065')->is_valid_number, '静岡県磐田市野箱');
ok($zip->set_number('4380066')->is_valid_number, '静岡県磐田市白拍子');
ok($zip->set_number('4380067')->is_valid_number, '静岡県磐田市草崎');
ok($zip->set_number('4380068')->is_valid_number, '静岡県磐田市前野');
ok($zip->set_number('4380069')->is_valid_number, '静岡県磐田市長須賀');
ok($zip->set_number('4380071')->is_valid_number, '静岡県磐田市今之浦');
ok($zip->set_number('4380072')->is_valid_number, '静岡県磐田市鳥之瀬');
ok($zip->set_number('4380073')->is_valid_number, '静岡県磐田市二之宮東');
ok($zip->set_number('4380074')->is_valid_number, '静岡県磐田市二之宮');
ok($zip->set_number('4380074')->is_valid_number, '静岡県磐田市二之宮浅間');
ok($zip->set_number('4380075')->is_valid_number, '静岡県磐田市天龍');
ok($zip->set_number('4380077')->is_valid_number, '静岡県磐田市国府台');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市旭ケ丘');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市石原町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市泉町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市久保町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市御殿');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市坂上町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市栄町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市桜ケ丘');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市七軒町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市田町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市中央町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市中泉');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市中町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市西新町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市西町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市東町');
ok($zip->set_number('4380078')->is_valid_number, '静岡県磐田市本町');
ok($zip->set_number('4380081')->is_valid_number, '静岡県磐田市緑ケ丘');
ok($zip->set_number('4380082')->is_valid_number, '静岡県磐田市元天神町');
ok($zip->set_number('4380083')->is_valid_number, '静岡県磐田市富士見町');
ok($zip->set_number('4380084')->is_valid_number, '静岡県磐田市城之崎');
ok($zip->set_number('4380085')->is_valid_number, '静岡県磐田市水堀');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市一番町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市梅屋町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市加茂川通');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市河原町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市北見町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市権現町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市幸町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市清水町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市宿町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市地脇町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市新通町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市住吉町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市天王町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市中川町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市西坂町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市二番町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市馬場町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市東坂町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市見付');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市美登里町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市元倉町');
ok($zip->set_number('4380086')->is_valid_number, '静岡県磐田市元宮町');
ok($zip->set_number('4380088')->is_valid_number, '静岡県磐田市富士見台');
ok($zip->set_number('4380101')->is_valid_number, '静岡県磐田市万瀬');
ok($zip->set_number('4380102')->is_valid_number, '静岡県磐田市虫生');
ok($zip->set_number('4380103')->is_valid_number, '静岡県磐田市大平');
ok($zip->set_number('4380104')->is_valid_number, '静岡県磐田市岩室');
ok($zip->set_number('4380105')->is_valid_number, '静岡県磐田市家田');
ok($zip->set_number('4380106')->is_valid_number, '静岡県磐田市敷地');
ok($zip->set_number('4380107')->is_valid_number, '静岡県磐田市大当所');
ok($zip->set_number('4380108')->is_valid_number, '静岡県磐田市社山');
ok($zip->set_number('4380111')->is_valid_number, '静岡県磐田市上野部');
ok($zip->set_number('4380112')->is_valid_number, '静岡県磐田市下野部');
ok($zip->set_number('4380113')->is_valid_number, '静岡県磐田市新開');
ok($zip->set_number('4380114')->is_valid_number, '静岡県磐田市合代島');
ok($zip->set_number('4380115')->is_valid_number, '静岡県磐田市上神増');
ok($zip->set_number('4380116')->is_valid_number, '静岡県磐田市壱貫地');
ok($zip->set_number('4380121')->is_valid_number, '静岡県磐田市神増');
ok($zip->set_number('4380122')->is_valid_number, '静岡県磐田市惣兵衛下新田');
ok($zip->set_number('4380123')->is_valid_number, '静岡県磐田市平松');
ok($zip->set_number('4380124')->is_valid_number, '静岡県磐田市掛下');
ok($zip->set_number('4380125')->is_valid_number, '静岡県磐田市松之木島');
ok($zip->set_number('4380126')->is_valid_number, '静岡県磐田市下神増');
ok($zip->set_number('4380127')->is_valid_number, '静岡県磐田市三家');
ok($zip->set_number('4380201')->is_valid_number, '静岡県磐田市竜洋中島');
ok($zip->set_number('4380202')->is_valid_number, '静岡県磐田市高木');
ok($zip->set_number('4380203')->is_valid_number, '静岡県磐田市平間');
ok($zip->set_number('4380204')->is_valid_number, '静岡県磐田市岡');
ok($zip->set_number('4380205')->is_valid_number, '静岡県磐田市堀之内');
ok($zip->set_number('4380206')->is_valid_number, '静岡県磐田市松本');
ok($zip->set_number('4380207')->is_valid_number, '静岡県磐田市宮本');
ok($zip->set_number('4380211')->is_valid_number, '静岡県磐田市東平松');
ok($zip->set_number('4380212')->is_valid_number, '静岡県磐田市海老島');
ok($zip->set_number('4380213')->is_valid_number, '静岡県磐田市竜洋稗原');
ok($zip->set_number('4380214')->is_valid_number, '静岡県磐田市大中瀬');
ok($zip->set_number('4380215')->is_valid_number, '静岡県磐田市小中瀬');
ok($zip->set_number('4380216')->is_valid_number, '静岡県磐田市飛平松');
ok($zip->set_number('4380217')->is_valid_number, '静岡県磐田市西平松');
ok($zip->set_number('4380218')->is_valid_number, '静岡県磐田市中平松');
ok($zip->set_number('4380221')->is_valid_number, '静岡県磐田市南平松');
ok($zip->set_number('4380222')->is_valid_number, '静岡県磐田市須恵新田');
ok($zip->set_number('4380223')->is_valid_number, '静岡県磐田市請負新田');
ok($zip->set_number('4380224')->is_valid_number, '静岡県磐田市浜新田');
ok($zip->set_number('4380231')->is_valid_number, '静岡県磐田市豊岡');
ok($zip->set_number('4380232')->is_valid_number, '静岡県磐田市川袋');
ok($zip->set_number('4380233')->is_valid_number, '静岡県磐田市駒場');
ok($zip->set_number('4380234')->is_valid_number, '静岡県磐田市掛塚');
ok($zip->set_number('4380235')->is_valid_number, '静岡県磐田市白羽');
ok($zip->set_number('4380236')->is_valid_number, '静岡県磐田市十郎島');
ok($zip->set_number('4380801')->is_valid_number, '静岡県磐田市高見丘');
ok($zip->set_number('4380802')->is_valid_number, '静岡県磐田市東原');
ok($zip->set_number('4380803')->is_valid_number, '静岡県磐田市富丘');
ok($zip->set_number('4380804')->is_valid_number, '静岡県磐田市加茂');
ok($zip->set_number('4380805')->is_valid_number, '静岡県磐田市池田');
ok($zip->set_number('4380806')->is_valid_number, '静岡県磐田市東名');
ok($zip->set_number('4380807')->is_valid_number, '静岡県磐田市富里');
ok($zip->set_number('4380808')->is_valid_number, '静岡県磐田市豊田');
ok($zip->set_number('4380811')->is_valid_number, '静岡県磐田市一言');
ok($zip->set_number('4380812')->is_valid_number, '静岡県磐田市海老塚');
ok($zip->set_number('4380813')->is_valid_number, '静岡県磐田市笹原島');
ok($zip->set_number('4380814')->is_valid_number, '静岡県磐田市気子島');
ok($zip->set_number('4380815')->is_valid_number, '静岡県磐田市中田');
ok($zip->set_number('4380816')->is_valid_number, '静岡県磐田市宮之一色');
ok($zip->set_number('4380817')->is_valid_number, '静岡県磐田市上万能');
ok($zip->set_number('4380818')->is_valid_number, '静岡県磐田市下万能');
ok($zip->set_number('4380821')->is_valid_number, '静岡県磐田市立野');
ok($zip->set_number('4380822')->is_valid_number, '静岡県磐田市上本郷');
ok($zip->set_number('4380823')->is_valid_number, '静岡県磐田市下本郷');
ok($zip->set_number('4380824')->is_valid_number, '静岡県磐田市赤池');
ok($zip->set_number('4380825')->is_valid_number, '静岡県磐田市森本');
ok($zip->set_number('4380831')->is_valid_number, '静岡県磐田市上新屋');
ok($zip->set_number('4380832')->is_valid_number, '静岡県磐田市森岡');
ok($zip->set_number('4380833')->is_valid_number, '静岡県磐田市弥藤太島');
ok($zip->set_number('4380834')->is_valid_number, '静岡県磐田市森下');
ok($zip->set_number('4380835')->is_valid_number, '静岡県磐田市豊田西之島');
ok($zip->set_number('4380836')->is_valid_number, '静岡県磐田市長森');
ok($zip->set_number('4380837')->is_valid_number, '静岡県磐田市源平新田');
ok($zip->set_number('4380838')->is_valid_number, '静岡県磐田市小立野');
ok($zip->set_number('4390000')->is_valid_number, '静岡県菊川市以下に掲載がない場合');
ok($zip->set_number('4390001')->is_valid_number, '静岡県菊川市富田');
ok($zip->set_number('4390002')->is_valid_number, '静岡県菊川市倉沢');
ok($zip->set_number('4390003')->is_valid_number, '静岡県菊川市沢水加');
ok($zip->set_number('4390004')->is_valid_number, '静岡県菊川市和田');
ok($zip->set_number('4390005')->is_valid_number, '静岡県菊川市潮海寺');
ok($zip->set_number('4390006')->is_valid_number, '静岡県菊川市堀之内');
ok($zip->set_number('4390007')->is_valid_number, '静岡県菊川市柳');
ok($zip->set_number('4390008')->is_valid_number, '静岡県菊川市友田');
ok($zip->set_number('4390009')->is_valid_number, '静岡県菊川市吉沢');
ok($zip->set_number('4390011')->is_valid_number, '静岡県菊川市仲島');
ok($zip->set_number('4390012')->is_valid_number, '静岡県菊川市青葉台');
ok($zip->set_number('4390013')->is_valid_number, '静岡県菊川市牛渕');
ok($zip->set_number('4390014')->is_valid_number, '静岡県菊川市小沢');
ok($zip->set_number('4390015')->is_valid_number, '静岡県菊川市牧之原');
ok($zip->set_number('4390016')->is_valid_number, '静岡県菊川市神尾');
ok($zip->set_number('4390017')->is_valid_number, '静岡県菊川市朝日');
ok($zip->set_number('4390018')->is_valid_number, '静岡県菊川市本所');
ok($zip->set_number('4390019')->is_valid_number, '静岡県菊川市半済');
ok($zip->set_number('4390021')->is_valid_number, '静岡県菊川市小出');
ok($zip->set_number('4390022')->is_valid_number, '静岡県菊川市東横地');
ok($zip->set_number('4390023')->is_valid_number, '静岡県菊川市三沢');
ok($zip->set_number('4390024')->is_valid_number, '静岡県菊川市奈良野');
ok($zip->set_number('4390025')->is_valid_number, '静岡県菊川市土橋');
ok($zip->set_number('4390026')->is_valid_number, '静岡県菊川市西横地');
ok($zip->set_number('4390031')->is_valid_number, '静岡県菊川市加茂');
ok($zip->set_number('4390032')->is_valid_number, '静岡県菊川市月岡');
ok($zip->set_number('4390033')->is_valid_number, '静岡県菊川市耳川');
ok($zip->set_number('4390034')->is_valid_number, '静岡県菊川市下内田');
ok($zip->set_number('4390035')->is_valid_number, '静岡県菊川市平尾');
ok($zip->set_number('4390036')->is_valid_number, '静岡県菊川市中内田');
ok($zip->set_number('4390037')->is_valid_number, '静岡県菊川市西方');
ok($zip->set_number('4400001')->is_valid_number, '愛知県豊橋市下条西町');
ok($zip->set_number('4400002')->is_valid_number, '愛知県豊橋市下条東町');
ok($zip->set_number('4400003')->is_valid_number, '愛知県豊橋市浪の上町');
ok($zip->set_number('4400004')->is_valid_number, '愛知県豊橋市忠興');
ok($zip->set_number('4400005')->is_valid_number, '愛知県豊橋市緑ケ丘');
ok($zip->set_number('4400006')->is_valid_number, '愛知県豊橋市牛川町(池下)');
ok($zip->set_number('4400006')->is_valid_number, '愛知県豊橋市牛川町(押川)');
ok($zip->set_number('4400006')->is_valid_number, '愛知県豊橋市牛川町(東仲田)');
ok($zip->set_number('4400006')->is_valid_number, '愛知県豊橋市牛川町(西仲田)');
ok($zip->set_number('4400006')->is_valid_number, '愛知県豊橋市牛川町(乗小路)');
ok($zip->set_number('4400011')->is_valid_number, '愛知県豊橋市牛川通');
ok($zip->set_number('4400012')->is_valid_number, '愛知県豊橋市東小鷹野');
ok($zip->set_number('4400013')->is_valid_number, '愛知県豊橋市西小鷹野');
ok($zip->set_number('4400014')->is_valid_number, '愛知県豊橋市南牛川');
ok($zip->set_number('4400015')->is_valid_number, '愛知県豊橋市牛川薬師町');
ok($zip->set_number('4400016')->is_valid_number, '愛知県豊橋市牛川町(その他)');
ok($zip->set_number('4400021')->is_valid_number, '愛知県豊橋市多米町');
ok($zip->set_number('4400022')->is_valid_number, '愛知県豊橋市岩崎町');
ok($zip->set_number('4400023')->is_valid_number, '愛知県豊橋市岩田町(影岩)');
ok($zip->set_number('4400024')->is_valid_number, '愛知県豊橋市東田町(井原)');
ok($zip->set_number('4400025')->is_valid_number, '愛知県豊橋市井原町');
ok($zip->set_number('4400026')->is_valid_number, '愛知県豊橋市多米西町');
ok($zip->set_number('4400027')->is_valid_number, '愛知県豊橋市多米中町');
ok($zip->set_number('4400028')->is_valid_number, '愛知県豊橋市多米東町');
ok($zip->set_number('4400031')->is_valid_number, '愛知県豊橋市北岩田');
ok($zip->set_number('4400032')->is_valid_number, '愛知県豊橋市岩田町居村、北郷中');
ok($zip->set_number('4400033')->is_valid_number, '愛知県豊橋市東岩田');
ok($zip->set_number('4400034')->is_valid_number, '愛知県豊橋市豊岡町');
ok($zip->set_number('4400035')->is_valid_number, '愛知県豊橋市平川南町');
ok($zip->set_number('4400036')->is_valid_number, '愛知県豊橋市東光町');
ok($zip->set_number('4400037')->is_valid_number, '愛知県豊橋市平川町');
ok($zip->set_number('4400038')->is_valid_number, '愛知県豊橋市平川本町');
ok($zip->set_number('4400041')->is_valid_number, '愛知県豊橋市岩田町宮下、道合');
ok($zip->set_number('4400042')->is_valid_number, '愛知県豊橋市栄町');
ok($zip->set_number('4400043')->is_valid_number, '愛知県豊橋市朝丘町');
ok($zip->set_number('4400044')->is_valid_number, '愛知県豊橋市宮下町');
ok($zip->set_number('4400045')->is_valid_number, '愛知県豊橋市吾妻町');
ok($zip->set_number('4400046')->is_valid_number, '愛知県豊橋市仲ノ町');
ok($zip->set_number('4400047')->is_valid_number, '愛知県豊橋市東田仲の町');
ok($zip->set_number('4400048')->is_valid_number, '愛知県豊橋市東田町(その他)');
ok($zip->set_number('4400051')->is_valid_number, '愛知県豊橋市東雲町');
ok($zip->set_number('4400052')->is_valid_number, '愛知県豊橋市住吉町');
ok($zip->set_number('4400053')->is_valid_number, '愛知県豊橋市老松町');
ok($zip->set_number('4400054')->is_valid_number, '愛知県豊橋市東田町(北蓮田)');
ok($zip->set_number('4400054')->is_valid_number, '愛知県豊橋市東田町(東前山)');
ok($zip->set_number('4400054')->is_valid_number, '愛知県豊橋市東田町(西前山)');
ok($zip->set_number('4400055')->is_valid_number, '愛知県豊橋市前畑町');
ok($zip->set_number('4400056')->is_valid_number, '愛知県豊橋市南旭町');
ok($zip->set_number('4400057')->is_valid_number, '愛知県豊橋市旭町');
ok($zip->set_number('4400058')->is_valid_number, '愛知県豊橋市旭本町');
ok($zip->set_number('4400061')->is_valid_number, '愛知県豊橋市飽海町');
ok($zip->set_number('4400062')->is_valid_number, '愛知県豊橋市東田町(西郷)');
ok($zip->set_number('4400062')->is_valid_number, '愛知県豊橋市東田町(中郷)');
ok($zip->set_number('4400062')->is_valid_number, '愛知県豊橋市東田町(西脇)');
ok($zip->set_number('4400063')->is_valid_number, '愛知県豊橋市東田中郷町');
ok($zip->set_number('4400064')->is_valid_number, '愛知県豊橋市西郷町');
ok($zip->set_number('4400065')->is_valid_number, '愛知県豊橋市仁連木町');
ok($zip->set_number('4400066')->is_valid_number, '愛知県豊橋市東田町(番地)');
ok($zip->set_number('4400067')->is_valid_number, '愛知県豊橋市上地町');
ok($zip->set_number('4400068')->is_valid_number, '愛知県豊橋市東郷町');
ok($zip->set_number('4400069')->is_valid_number, '愛知県豊橋市御園町');
ok($zip->set_number('4400071')->is_valid_number, '愛知県豊橋市北島町');
ok($zip->set_number('4400072')->is_valid_number, '愛知県豊橋市船町');
ok($zip->set_number('4400073')->is_valid_number, '愛知県豊橋市湊町');
ok($zip->set_number('4400074')->is_valid_number, '愛知県豊橋市上伝馬町');
ok($zip->set_number('4400075')->is_valid_number, '愛知県豊橋市花田町(石塚)');
ok($zip->set_number('4400075')->is_valid_number, '愛知県豊橋市花田町官有地(無番地を除く)');
ok($zip->set_number('4400075')->is_valid_number, '愛知県豊橋市花田町西宿(110-2、110-7、110-10番地を除く)');
ok($zip->set_number('4400075')->is_valid_number, '愛知県豊橋市花田町(無番地)');
ok($zip->set_number('4400076')->is_valid_number, '愛知県豊橋市大橋通');
ok($zip->set_number('4400077')->is_valid_number, '愛知県豊橋市南島町');
ok($zip->set_number('4400078')->is_valid_number, '愛知県豊橋市絹田町');
ok($zip->set_number('4400081')->is_valid_number, '愛知県豊橋市大村町');
ok($zip->set_number('4400082')->is_valid_number, '愛知県豊橋市長瀬町');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(大圦)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(北村)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(操穴)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(五貫)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(境田)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(天神)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(野箱)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(柳目)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(横山)');
ok($zip->set_number('4400083')->is_valid_number, '愛知県豊橋市下地町(若宮)');
ok($zip->set_number('4400084')->is_valid_number, '愛知県豊橋市下地町(神田)');
ok($zip->set_number('4400084')->is_valid_number, '愛知県豊橋市下地町(瀬上)');
ok($zip->set_number('4400084')->is_valid_number, '愛知県豊橋市下地町(緑)');
ok($zip->set_number('4400084')->is_valid_number, '愛知県豊橋市下地町(宮腰)');
ok($zip->set_number('4400085')->is_valid_number, '愛知県豊橋市下地町(丁目)');
ok($zip->set_number('4400086')->is_valid_number, '愛知県豊橋市下地町(その他)');
ok($zip->set_number('4400091')->is_valid_number, '愛知県豊橋市下五井町');
ok($zip->set_number('4400092')->is_valid_number, '愛知県豊橋市瓜郷町');
ok($zip->set_number('4400093')->is_valid_number, '愛知県豊橋市横須賀町');
ok($zip->set_number('4400094')->is_valid_number, '愛知県豊橋市川崎町');
ok($zip->set_number('4400095')->is_valid_number, '愛知県豊橋市清須町');
ok($zip->set_number('4400801')->is_valid_number, '愛知県豊橋市今橋町');
ok($zip->set_number('4400802')->is_valid_number, '愛知県豊橋市鍛冶町');
ok($zip->set_number('4400803')->is_valid_number, '愛知県豊橋市曲尺手町');
ok($zip->set_number('4400804')->is_valid_number, '愛知県豊橋市呉服町');
ok($zip->set_number('4400805')->is_valid_number, '愛知県豊橋市大手町');
ok($zip->set_number('4400806')->is_valid_number, '愛知県豊橋市八町通');
ok($zip->set_number('4400811')->is_valid_number, '愛知県豊橋市西新町');
ok($zip->set_number('4400812')->is_valid_number, '愛知県豊橋市東新町');
ok($zip->set_number('4400813')->is_valid_number, '愛知県豊橋市舟原町');
ok($zip->set_number('4400814')->is_valid_number, '愛知県豊橋市前田町');
ok($zip->set_number('4400815')->is_valid_number, '愛知県豊橋市中世古町');
ok($zip->set_number('4400816')->is_valid_number, '愛知県豊橋市談合町');
ok($zip->set_number('4400821')->is_valid_number, '愛知県豊橋市春日町');
ok($zip->set_number('4400822')->is_valid_number, '愛知県豊橋市伝馬町');
ok($zip->set_number('4400823')->is_valid_number, '愛知県豊橋市南瓦町');
ok($zip->set_number('4400824')->is_valid_number, '愛知県豊橋市瓦町通');
ok($zip->set_number('4400825')->is_valid_number, '愛知県豊橋市瓦町');
ok($zip->set_number('4400826')->is_valid_number, '愛知県豊橋市大井町');
ok($zip->set_number('4400827')->is_valid_number, '愛知県豊橋市池見町');
ok($zip->set_number('4400831')->is_valid_number, '愛知県豊橋市西岩田');
ok($zip->set_number('4400832')->is_valid_number, '愛知県豊橋市岩田町');
ok($zip->set_number('4400832')->is_valid_number, '愛知県豊橋市中岩田');
ok($zip->set_number('4400833')->is_valid_number, '愛知県豊橋市飯村町西山、高山');
ok($zip->set_number('4400834')->is_valid_number, '愛知県豊橋市飯村北');
ok($zip->set_number('4400835')->is_valid_number, '愛知県豊橋市飯村南');
ok($zip->set_number('4400836')->is_valid_number, '愛知県豊橋市飯村町(その他)');
ok($zip->set_number('4400837')->is_valid_number, '愛知県豊橋市三ノ輪町本興寺');
ok($zip->set_number('4400837')->is_valid_number, '愛知県豊橋市三ノ輪町三ノ輪');
ok($zip->set_number('4400838')->is_valid_number, '愛知県豊橋市三ノ輪町');
ok($zip->set_number('4400841')->is_valid_number, '愛知県豊橋市西口町');
ok($zip->set_number('4400842')->is_valid_number, '愛知県豊橋市岩屋町');
ok($zip->set_number('4400843')->is_valid_number, '愛知県豊橋市東幸町');
ok($zip->set_number('4400844')->is_valid_number, '愛知県豊橋市高師町(奥山田)');
ok($zip->set_number('4400844')->is_valid_number, '愛知県豊橋市高師町(清水)');
ok($zip->set_number('4400844')->is_valid_number, '愛知県豊橋市高師町(水神)');
ok($zip->set_number('4400844')->is_valid_number, '愛知県豊橋市高師町(丸田)');
ok($zip->set_number('4400845')->is_valid_number, '愛知県豊橋市高師町(北原、その他)');
ok($zip->set_number('4400845')->is_valid_number, '愛知県豊橋市高師町(その他)');
ok($zip->set_number('4400851')->is_valid_number, '愛知県豊橋市前田南町');
ok($zip->set_number('4400853')->is_valid_number, '愛知県豊橋市佐藤');
ok($zip->set_number('4400853')->is_valid_number, '愛知県豊橋市佐藤町');
ok($zip->set_number('4400854')->is_valid_number, '愛知県豊橋市山田町(その他)');
ok($zip->set_number('4400855')->is_valid_number, '愛知県豊橋市東小池町');
ok($zip->set_number('4400856')->is_valid_number, '愛知県豊橋市鍵田町');
ok($zip->set_number('4400857')->is_valid_number, '愛知県豊橋市堂浦町');
ok($zip->set_number('4400858')->is_valid_number, '愛知県豊橋市つつじが丘');
ok($zip->set_number('4400861')->is_valid_number, '愛知県豊橋市向山西町');
ok($zip->set_number('4400862')->is_valid_number, '愛知県豊橋市向山大池町');
ok($zip->set_number('4400863')->is_valid_number, '愛知県豊橋市向山東町');
ok($zip->set_number('4400864')->is_valid_number, '愛知県豊橋市向山町');
ok($zip->set_number('4400865')->is_valid_number, '愛知県豊橋市向山台町');
ok($zip->set_number('4400871')->is_valid_number, '愛知県豊橋市新吉町');
ok($zip->set_number('4400872')->is_valid_number, '愛知県豊橋市前田中町');
ok($zip->set_number('4400873')->is_valid_number, '愛知県豊橋市小畷町');
ok($zip->set_number('4400874')->is_valid_number, '愛知県豊橋市東松山町');
ok($zip->set_number('4400875')->is_valid_number, '愛知県豊橋市中松山町');
ok($zip->set_number('4400876')->is_valid_number, '愛知県豊橋市西松山町');
ok($zip->set_number('4400877')->is_valid_number, '愛知県豊橋市南松山町');
ok($zip->set_number('4400881')->is_valid_number, '愛知県豊橋市広小路');
ok($zip->set_number('4400882')->is_valid_number, '愛知県豊橋市神明町');
ok($zip->set_number('4400883')->is_valid_number, '愛知県豊橋市新川町');
ok($zip->set_number('4400884')->is_valid_number, '愛知県豊橋市大国町');
ok($zip->set_number('4400885')->is_valid_number, '愛知県豊橋市中柴町');
ok($zip->set_number('4400886')->is_valid_number, '愛知県豊橋市東小田原町');
ok($zip->set_number('4400887')->is_valid_number, '愛知県豊橋市西小田原町');
ok($zip->set_number('4400888')->is_valid_number, '愛知県豊橋市駅前大通');
ok($zip->set_number('4400891')->is_valid_number, '愛知県豊橋市関屋町');
ok($zip->set_number('4400892')->is_valid_number, '愛知県豊橋市新本町');
ok($zip->set_number('4400893')->is_valid_number, '愛知県豊橋市札木町');
ok($zip->set_number('4400894')->is_valid_number, '愛知県豊橋市魚町');
ok($zip->set_number('4400895')->is_valid_number, '愛知県豊橋市花園町');
ok($zip->set_number('4400896')->is_valid_number, '愛知県豊橋市萱町');
ok($zip->set_number('4400897')->is_valid_number, '愛知県豊橋市松葉町');
ok($zip->set_number('4410000')->is_valid_number, '愛知県豊橋市以下に掲載がない場合');
ok($zip->set_number('4410101')->is_valid_number, '愛知県豊川市宿町');
ok($zip->set_number('4410102')->is_valid_number, '愛知県豊川市篠束町');
ok($zip->set_number('4410103')->is_valid_number, '愛知県豊川市小坂井町');
ok($zip->set_number('4410104')->is_valid_number, '愛知県豊川市平井町');
ok($zip->set_number('4410105')->is_valid_number, '愛知県豊川市伊奈町');
ok($zip->set_number('4410106')->is_valid_number, '愛知県豊川市美園');
ok($zip->set_number('4410151')->is_valid_number, '愛知県豊橋市日色野町');
ok($zip->set_number('4410152')->is_valid_number, '愛知県豊橋市前芝町');
ok($zip->set_number('4410153')->is_valid_number, '愛知県豊橋市新西浜町');
ok($zip->set_number('4410154')->is_valid_number, '愛知県豊橋市梅薮西町');
ok($zip->set_number('4410155')->is_valid_number, '愛知県豊橋市梅薮町');
ok($zip->set_number('4410156')->is_valid_number, '愛知県豊橋市西浜町');
ok($zip->set_number('4410201')->is_valid_number, '愛知県豊川市萩町');
ok($zip->set_number('4410202')->is_valid_number, '愛知県豊川市赤坂町');
ok($zip->set_number('4410203')->is_valid_number, '愛知県豊川市長沢町');
ok($zip->set_number('4410204')->is_valid_number, '愛知県豊川市赤坂台');
ok($zip->set_number('4410211')->is_valid_number, '愛知県豊川市御油町(その他)');
ok($zip->set_number('4410212')->is_valid_number, '愛知県豊川市御油町(長谷山)');
ok($zip->set_number('4410213')->is_valid_number, '愛知県豊川市御油町(汲ケ谷)');
ok($zip->set_number('4410214')->is_valid_number, '愛知県豊川市御油町(東山)');
ok($zip->set_number('4410215')->is_valid_number, '愛知県豊川市御油町(炮六土)');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇雨田');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇犬田');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇大郡');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇河原田');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇観音堂');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇北区');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇中区');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇西区');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇西ノ貝津');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇二本松');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇野川');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇野添');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇花ノ木');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇東区');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇深田');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇松下');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇南区');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇屋敷');
ok($zip->set_number('4410301')->is_valid_number, '愛知県豊川市御津町上佐脇六反畑');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇洗出');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇荒古');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇新屋');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇市場');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇院田');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇梅田');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇籠畑');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇鎌田');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇河田');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇北浦');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇義郎');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇九作');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇郷中');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇御所');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇佐脇原');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇新洗出');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇新梅田');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇新畑');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇是願');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇高畑');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇田熊');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇玉袋');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇出口');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇天神');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇仲荒');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇仲ノ坪');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇縄口');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇縄手');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇野口');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇野先');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇八尻');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇八反田');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇羽鳥');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇花ノ木');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇浜道');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇引通');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇広野');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇平次');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇堀合');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇待井');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇都');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇宮前');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇宮本');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇村上');
ok($zip->set_number('4410302')->is_valid_number, '愛知県豊川市御津町下佐脇山崎');
ok($zip->set_number('4410303')->is_valid_number, '愛知県豊川市御津町新田');
ok($zip->set_number('4410303')->is_valid_number, '愛知県豊川市御津町新田洗出');
ok($zip->set_number('4410303')->is_valid_number, '愛知県豊川市御津町新田新砂山');
ok($zip->set_number('4410303')->is_valid_number, '愛知県豊川市御津町新田砂山');
ok($zip->set_number('4410304')->is_valid_number, '愛知県豊川市御津町佐脇浜');
ok($zip->set_number('4410304')->is_valid_number, '愛知県豊川市御津町佐脇浜一号地');
ok($zip->set_number('4410304')->is_valid_number, '愛知県豊川市御津町佐脇浜二号地');
ok($zip->set_number('4410304')->is_valid_number, '愛知県豊川市御津町佐脇浜三号地');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬梅田');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬加美');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬川端');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬塩入');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬塩浜');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬膳田');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬玉袋');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬剱');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬中島');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬仲田');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬長床');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬流田');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬西');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬西梅');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬野添');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬浜田');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬東');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬宮浦');
ok($zip->set_number('4410311')->is_valid_number, '愛知県豊川市御津町御馬向道');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方揚浜');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方入浜');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方井領田');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方狐塚');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方九策');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方源農');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方小貝津');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方下浜道');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方常ノ口');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方長田');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方樋田');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方中道');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方中屋敷');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方梨野');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方浜田');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方日暮');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方広田');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方松本');
ok($zip->set_number('4410312')->is_valid_number, '愛知県豊川市御津町西方宮長');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野楠木');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野久呂下');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野新屋敷');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野高畑');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野丁田');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野仲田');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野仲ノ坪');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野浜新田');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野堀合');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野宮永');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野村崎');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野餅田');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野柳原');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野山下');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野六角');
ok($zip->set_number('4410313')->is_valid_number, '愛知県豊川市御津町泙野六反田');
ok($zip->set_number('4410314')->is_valid_number, '愛知県豊川市御津町御幸浜');
ok($zip->set_number('4410314')->is_valid_number, '愛知県豊川市御津町御幸浜一号地');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草上竹');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草大森');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草神場');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草西郷');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草新田');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草神田');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草外新田');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草東郷');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草西浜');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草西分莚');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草分莚');
ok($zip->set_number('4410315')->is_valid_number, '愛知県豊川市御津町大草向野');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根角田');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根神場');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根柑子');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根下川');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根水神');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根堤下');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根天王');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根百々');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根仲田');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根西半郷');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根野竹');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根半郷');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根前浜');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根松葉');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根宮前');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根屋敷');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根谷田入');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町赤根山田');
ok($zip->set_number('4410316')->is_valid_number, '愛知県豊川市御津町安礼の崎');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石石堂野');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石市場');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石後畠');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石越川');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石金堂');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石蛇塚');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石高坂');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石小城前');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石五反田');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石小前');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石新宮山');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石千路');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石竹本');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石枋ケ坪');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石永井田');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石祢宜田');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石祓田');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石日暮');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石広国');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石船津');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石船山');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石神子田');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石御津山');
ok($zip->set_number('4410321')->is_valid_number, '愛知県豊川市御津町広石横町');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢赤羽根');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢石堂野');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢入ノ口');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢上野山');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢後田');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢大蔵');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢大沢');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢大坪');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢川原');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢久蔵');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢蔵下');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢小沢');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢小山');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢沢渡');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢篠川');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢新小山');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢新杉下');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢杉下');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢樽美');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢払田');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢引釣');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢松田');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢松ノ下');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢三沢');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢弥勒寺');
ok($zip->set_number('4410322')->is_valid_number, '愛知県豊川市御津町豊沢薬堂');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野青木');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野油田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野石田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野稲場');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野岩本');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野上野');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野籠田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野上沢');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野観音寺');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野国坂');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野郷作');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野五反田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野小根沢');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野猿沢');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野下');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野下ノ前');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野新砂田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野新山影');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野砂田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野竹入');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野足見');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野徳寒');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野中切');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野中畑');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野西沢');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野灰野坂');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野長谷沢');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野東河津');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野東田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野東畑');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野桧河津');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野深沢');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野深田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野袋田');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野藤ケ山');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野藤久保');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野見竹');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野山影');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野山本');
ok($zip->set_number('4410323')->is_valid_number, '愛知県豊川市御津町金野横手');
ok($zip->set_number('4411101')->is_valid_number, '愛知県豊橋市賀茂町');
ok($zip->set_number('4411102')->is_valid_number, '愛知県豊橋市石巻西川町');
ok($zip->set_number('4411103')->is_valid_number, '愛知県豊橋市石巻萩平町');
ok($zip->set_number('4411104')->is_valid_number, '愛知県豊橋市石巻中山町');
ok($zip->set_number('4411105')->is_valid_number, '愛知県豊橋市石巻平野町');
ok($zip->set_number('4411106')->is_valid_number, '愛知県豊橋市石巻小野田町');
ok($zip->set_number('4411111')->is_valid_number, '愛知県豊橋市嵩山町');
ok($zip->set_number('4411112')->is_valid_number, '愛知県豊橋市石巻町');
ok($zip->set_number('4411113')->is_valid_number, '愛知県豊橋市東森岡');
ok($zip->set_number('4411114')->is_valid_number, '愛知県豊橋市森岡町');
ok($zip->set_number('4411115')->is_valid_number, '愛知県豊橋市石巻本町');
ok($zip->set_number('4411201')->is_valid_number, '愛知県豊川市東上町');
ok($zip->set_number('4411202')->is_valid_number, '愛知県豊川市上長山町');
ok($zip->set_number('4411203')->is_valid_number, '愛知県豊川市足山田町');
ok($zip->set_number('4411204')->is_valid_number, '愛知県豊川市西原町');
ok($zip->set_number('4411205')->is_valid_number, '愛知県豊川市大木町');
ok($zip->set_number('4411206')->is_valid_number, '愛知県豊川市篠田町');
ok($zip->set_number('4411207')->is_valid_number, '愛知県豊川市大木新町通');
ok($zip->set_number('4411211')->is_valid_number, '愛知県豊川市江島町');
ok($zip->set_number('4411212')->is_valid_number, '愛知県豊川市金沢町');
ok($zip->set_number('4411221')->is_valid_number, '愛知県豊川市松原町');
ok($zip->set_number('4411222')->is_valid_number, '愛知県豊川市豊津町');
ok($zip->set_number('4411223')->is_valid_number, '愛知県豊川市橋尾町');
ok($zip->set_number('4411231')->is_valid_number, '愛知県豊川市一宮町');
ok($zip->set_number('4411300')->is_valid_number, '愛知県新城市以下に掲載がない場合');
ok($zip->set_number('4411301')->is_valid_number, '愛知県新城市矢部');
ok($zip->set_number('4411302')->is_valid_number, '愛知県新城市富永');
ok($zip->set_number('4411303')->is_valid_number, '愛知県新城市牛倉');
ok($zip->set_number('4411304')->is_valid_number, '愛知県新城市大宮');
ok($zip->set_number('4411305')->is_valid_number, '愛知県新城市竹広');
ok($zip->set_number('4411306')->is_valid_number, '愛知県新城市川路');
ok($zip->set_number('4411307')->is_valid_number, '愛知県新城市富沢');
ok($zip->set_number('4411311')->is_valid_number, '愛知県新城市須長');
ok($zip->set_number('4411312')->is_valid_number, '愛知県新城市浅谷');
ok($zip->set_number('4411313')->is_valid_number, '愛知県新城市出沢');
ok($zip->set_number('4411314')->is_valid_number, '愛知県新城市横川');
ok($zip->set_number('4411315')->is_valid_number, '愛知県新城市大海');
ok($zip->set_number('4411316')->is_valid_number, '愛知県新城市緑が丘');
ok($zip->set_number('4411317')->is_valid_number, '愛知県新城市有海');
ok($zip->set_number('4411318')->is_valid_number, '愛知県新城市八束穂');
ok($zip->set_number('4411321')->is_valid_number, '愛知県新城市市川');
ok($zip->set_number('4411322')->is_valid_number, '愛知県新城市日吉');
ok($zip->set_number('4411323')->is_valid_number, '愛知県新城市吉川');
ok($zip->set_number('4411324')->is_valid_number, '愛知県新城市井道、奥井道、内井道');
ok($zip->set_number('4411325')->is_valid_number, '愛知県新城市二本松');
ok($zip->set_number('4411326')->is_valid_number, '愛知県新城市中野');
ok($zip->set_number('4411327')->is_valid_number, '愛知県新城市鰹淵');
ok($zip->set_number('4411328')->is_valid_number, '愛知県新城市桜淵');
ok($zip->set_number('4411329')->is_valid_number, '愛知県新城市笠岩');
ok($zip->set_number('4411331')->is_valid_number, '愛知県新城市庭野');
ok($zip->set_number('4411332')->is_valid_number, '愛知県新城市黒田');
ok($zip->set_number('4411333')->is_valid_number, '愛知県新城市小畑');
ok($zip->set_number('4411334')->is_valid_number, '愛知県新城市中宇利');
ok($zip->set_number('4411335')->is_valid_number, '愛知県新城市富岡');
ok($zip->set_number('4411336')->is_valid_number, '愛知県新城市富岡(○○屋敷)');
ok($zip->set_number('4411337')->is_valid_number, '愛知県新城市八名井');
ok($zip->set_number('4411338')->is_valid_number, '愛知県新城市一鍬田');
ok($zip->set_number('4411341')->is_valid_number, '愛知県新城市杉山');
ok($zip->set_number('4411342')->is_valid_number, '愛知県新城市石田');
ok($zip->set_number('4411343')->is_valid_number, '愛知県新城市野田');
ok($zip->set_number('4411344')->is_valid_number, '愛知県新城市野田(上市場)');
ok($zip->set_number('4411345')->is_valid_number, '愛知県新城市豊島');
ok($zip->set_number('4411346')->is_valid_number, '愛知県新城市川田');
ok($zip->set_number('4411347')->is_valid_number, '愛知県新城市川田(本宮道)');
ok($zip->set_number('4411348')->is_valid_number, '愛知県新城市市場台');
ok($zip->set_number('4411351')->is_valid_number, '愛知県新城市稲木');
ok($zip->set_number('4411352')->is_valid_number, '愛知県新城市豊栄');
ok($zip->set_number('4411353')->is_valid_number, '愛知県新城市徳定');
ok($zip->set_number('4411354')->is_valid_number, '愛知県新城市片山');
ok($zip->set_number('4411355')->is_valid_number, '愛知県新城市上平井');
ok($zip->set_number('4411361')->is_valid_number, '愛知県新城市平井(その他)');
ok($zip->set_number('4411362')->is_valid_number, '愛知県新城市平井(東原、西原、原)');
ok($zip->set_number('4411363')->is_valid_number, '愛知県新城市東沖野');
ok($zip->set_number('4411364')->is_valid_number, '愛知県新城市沖野');
ok($zip->set_number('4411365')->is_valid_number, '愛知県新城市石名号');
ok($zip->set_number('4411366')->is_valid_number, '愛知県新城市向野');
ok($zip->set_number('4411367')->is_valid_number, '愛知県新城市札木');
ok($zip->set_number('4411368')->is_valid_number, '愛知県新城市屋敷');
ok($zip->set_number('4411371')->is_valid_number, '愛知県新城市城北');
ok($zip->set_number('4411372')->is_valid_number, '愛知県新城市裏野');
ok($zip->set_number('4411373')->is_valid_number, '愛知県新城市西新町');
ok($zip->set_number('4411374')->is_valid_number, '愛知県新城市町並');
ok($zip->set_number('4411375')->is_valid_number, '愛知県新城市的場');
ok($zip->set_number('4411376')->is_valid_number, '愛知県新城市宮ノ前');
ok($zip->set_number('4411377')->is_valid_number, '愛知県新城市宮ノ西');
ok($zip->set_number('4411378')->is_valid_number, '愛知県新城市宮ノ後');
ok($zip->set_number('4411381')->is_valid_number, '愛知県新城市下川');
ok($zip->set_number('4411382')->is_valid_number, '愛知県新城市滝ノ上');
ok($zip->set_number('4411383')->is_valid_number, '愛知県新城市東入船');
ok($zip->set_number('4411384')->is_valid_number, '愛知県新城市西入船');
ok($zip->set_number('4411385')->is_valid_number, '愛知県新城市八幡');
ok($zip->set_number('4411386')->is_valid_number, '愛知県新城市南畑');
ok($zip->set_number('4411387')->is_valid_number, '愛知県新城市北畑');
ok($zip->set_number('4411388')->is_valid_number, '愛知県新城市橋向');
ok($zip->set_number('4411401')->is_valid_number, '愛知県新城市作手守義');
ok($zip->set_number('4411402')->is_valid_number, '愛知県新城市作手木和田');
ok($zip->set_number('4411403')->is_valid_number, '愛知県新城市作手善夫');
ok($zip->set_number('4411404')->is_valid_number, '愛知県新城市作手菅沼');
ok($zip->set_number('4411411')->is_valid_number, '愛知県新城市作手岩波');
ok($zip->set_number('4411412')->is_valid_number, '愛知県新城市作手鴨ケ谷');
ok($zip->set_number('4411413')->is_valid_number, '愛知県新城市作手白鳥');
ok($zip->set_number('4411414')->is_valid_number, '愛知県新城市作手清岳');
ok($zip->set_number('4411421')->is_valid_number, '愛知県新城市作手黒瀬');
ok($zip->set_number('4411422')->is_valid_number, '愛知県新城市作手田原');
ok($zip->set_number('4411423')->is_valid_number, '愛知県新城市作手高里');
ok($zip->set_number('4411424')->is_valid_number, '愛知県新城市作手中河内');
ok($zip->set_number('4411531')->is_valid_number, '愛知県新城市作手大和田');
ok($zip->set_number('4411532')->is_valid_number, '愛知県新城市作手高松');
ok($zip->set_number('4411533')->is_valid_number, '愛知県新城市作手荒原');
ok($zip->set_number('4411534')->is_valid_number, '愛知県新城市作手田代');
ok($zip->set_number('4411535')->is_valid_number, '愛知県新城市作手杉平');
ok($zip->set_number('4411536')->is_valid_number, '愛知県新城市作手保永');
ok($zip->set_number('4411601')->is_valid_number, '愛知県新城市川合');
ok($zip->set_number('4411602')->is_valid_number, '愛知県新城市池場');
ok($zip->set_number('4411603')->is_valid_number, '愛知県新城市名号');
ok($zip->set_number('4411604')->is_valid_number, '愛知県新城市名越');
ok($zip->set_number('4411605')->is_valid_number, '愛知県新城市能登瀬');
ok($zip->set_number('4411611')->is_valid_number, '愛知県新城市七郷一色');
ok($zip->set_number('4411612')->is_valid_number, '愛知県新城市巣山');
ok($zip->set_number('4411613')->is_valid_number, '愛知県新城市細川');
ok($zip->set_number('4411614')->is_valid_number, '愛知県新城市睦平');
ok($zip->set_number('4411615')->is_valid_number, '愛知県新城市大野');
ok($zip->set_number('4411616')->is_valid_number, '愛知県新城市井代');
ok($zip->set_number('4411621')->is_valid_number, '愛知県新城市下吉田');
ok($zip->set_number('4411622')->is_valid_number, '愛知県新城市上吉田');
ok($zip->set_number('4411623')->is_valid_number, '愛知県新城市黄柳野');
ok($zip->set_number('4411624')->is_valid_number, '愛知県新城市竹ノ輪');
ok($zip->set_number('4411631')->is_valid_number, '愛知県新城市豊岡');
ok($zip->set_number('4411632')->is_valid_number, '愛知県新城市富栄');
ok($zip->set_number('4411633')->is_valid_number, '愛知県新城市乗本');
ok($zip->set_number('4411634')->is_valid_number, '愛知県新城市長篠');
ok($zip->set_number('4411636')->is_valid_number, '愛知県新城市富保');
ok($zip->set_number('4411693')->is_valid_number, '愛知県新城市門谷(鳳来寺7番地)');
ok($zip->set_number('4411941')->is_valid_number, '愛知県新城市連合');
ok($zip->set_number('4411942')->is_valid_number, '愛知県新城市四谷');
ok($zip->set_number('4411943')->is_valid_number, '愛知県新城市海老');
ok($zip->set_number('4411944')->is_valid_number, '愛知県新城市門谷(その他)');
ok($zip->set_number('4411945')->is_valid_number, '愛知県新城市玖老勢');
ok($zip->set_number('4411946')->is_valid_number, '愛知県新城市副川');
ok($zip->set_number('4411951')->is_valid_number, '愛知県新城市愛郷');
ok($zip->set_number('4411952')->is_valid_number, '愛知県新城市中島');
ok($zip->set_number('4411953')->is_valid_number, '愛知県新城市一色');
ok($zip->set_number('4411954')->is_valid_number, '愛知県新城市只持');
ok($zip->set_number('4411955')->is_valid_number, '愛知県新城市布里');
ok($zip->set_number('4411956')->is_valid_number, '愛知県新城市塩瀬');
ok($zip->set_number('4412221')->is_valid_number, '愛知県北設楽郡設楽町田峯');
ok($zip->set_number('4412222')->is_valid_number, '愛知県北設楽郡設楽町田内');
ok($zip->set_number('4412223')->is_valid_number, '愛知県北設楽郡設楽町三都橋');
ok($zip->set_number('4412224')->is_valid_number, '愛知県北設楽郡設楽町豊邦');
ok($zip->set_number('4412300')->is_valid_number, '愛知県北設楽郡設楽町以下に掲載がない場合');
ok($zip->set_number('4412301')->is_valid_number, '愛知県北設楽郡設楽町田口');
ok($zip->set_number('4412302')->is_valid_number, '愛知県北設楽郡設楽町清崎');
ok($zip->set_number('4412303')->is_valid_number, '愛知県北設楽郡設楽町松戸');
ok($zip->set_number('4412311')->is_valid_number, '愛知県北設楽郡設楽町八橋');
ok($zip->set_number('4412312')->is_valid_number, '愛知県北設楽郡設楽町長江');
ok($zip->set_number('4412313')->is_valid_number, '愛知県北設楽郡設楽町和市');
ok($zip->set_number('4412314')->is_valid_number, '愛知県北設楽郡設楽町平山');
ok($zip->set_number('4412315')->is_valid_number, '愛知県北設楽郡設楽町神田');
ok($zip->set_number('4412316')->is_valid_number, '愛知県北設楽郡設楽町荒尾');
ok($zip->set_number('4412317')->is_valid_number, '愛知県北設楽郡設楽町小松');
ok($zip->set_number('4412431')->is_valid_number, '愛知県北設楽郡設楽町西納庫(その他)');
ok($zip->set_number('4412432')->is_valid_number, '愛知県北設楽郡設楽町東納庫');
ok($zip->set_number('4412433')->is_valid_number, '愛知県北設楽郡設楽町川向');
ok($zip->set_number('4412434')->is_valid_number, '愛知県北設楽郡設楽町大名倉');
ok($zip->set_number('4412511')->is_valid_number, '愛知県豊田市大野瀬町');
ok($zip->set_number('4412512')->is_valid_number, '愛知県豊田市野入町');
ok($zip->set_number('4412513')->is_valid_number, '愛知県豊田市稲武町');
ok($zip->set_number('4412514')->is_valid_number, '愛知県豊田市中当町');
ok($zip->set_number('4412515')->is_valid_number, '愛知県豊田市夏焼町');
ok($zip->set_number('4412516')->is_valid_number, '愛知県豊田市押山町');
ok($zip->set_number('4412517')->is_valid_number, '愛知県豊田市川手町');
ok($zip->set_number('4412521')->is_valid_number, '愛知県豊田市桑原町');
ok($zip->set_number('4412522')->is_valid_number, '愛知県豊田市武節町');
ok($zip->set_number('4412523')->is_valid_number, '愛知県豊田市御所貝津町');
ok($zip->set_number('4412524')->is_valid_number, '愛知県豊田市黒田町');
ok($zip->set_number('4412525')->is_valid_number, '愛知県豊田市小田木町');
ok($zip->set_number('4412526')->is_valid_number, '愛知県豊田市富永町');
ok($zip->set_number('4412531')->is_valid_number, '愛知県北設楽郡設楽町西納庫(沖ノ平)');
ok($zip->set_number('4412601')->is_valid_number, '愛知県北設楽郡設楽町津具');
ok($zip->set_number('4413101')->is_valid_number, '愛知県豊橋市大脇町(大脇)');
ok($zip->set_number('4413102')->is_valid_number, '愛知県豊橋市大脇町(大脇ノ谷)');
ok($zip->set_number('4413103')->is_valid_number, '愛知県豊橋市雲谷町(上ノ山)');
ok($zip->set_number('4413104')->is_valid_number, '愛知県豊橋市雲谷町');
ok($zip->set_number('4413105')->is_valid_number, '愛知県豊橋市中原町(南)');
ok($zip->set_number('4413106')->is_valid_number, '愛知県豊橋市中原町');
ok($zip->set_number('4413111')->is_valid_number, '愛知県豊橋市原町');
ok($zip->set_number('4413112')->is_valid_number, '愛知県豊橋市東細谷町');
ok($zip->set_number('4413113')->is_valid_number, '愛知県豊橋市細谷町');
ok($zip->set_number('4413114')->is_valid_number, '愛知県豊橋市三弥町');
ok($zip->set_number('4413115')->is_valid_number, '愛知県豊橋市豊清町');
ok($zip->set_number('4413121')->is_valid_number, '愛知県豊橋市西山町');
ok($zip->set_number('4413122')->is_valid_number, '愛知県豊橋市小島町');
ok($zip->set_number('4413123')->is_valid_number, '愛知県豊橋市小松原町');
ok($zip->set_number('4413124')->is_valid_number, '愛知県豊橋市寺沢町');
ok($zip->set_number('4413125')->is_valid_number, '愛知県豊橋市豊栄町');
ok($zip->set_number('4413126')->is_valid_number, '愛知県豊橋市冨士見町');
ok($zip->set_number('4413131')->is_valid_number, '愛知県豊橋市大岩町(小山塚)');
ok($zip->set_number('4413132')->is_valid_number, '愛知県豊橋市大岩町(東荒田)');
ok($zip->set_number('4413133')->is_valid_number, '愛知県豊橋市大岩町(西荒田)');
ok($zip->set_number('4413134')->is_valid_number, '愛知県豊橋市大岩町(久保田)');
ok($zip->set_number('4413141')->is_valid_number, '愛知県豊橋市大岩町(北山)');
ok($zip->set_number('4413142')->is_valid_number, '愛知県豊橋市大岩町(東郷内)');
ok($zip->set_number('4413143')->is_valid_number, '愛知県豊橋市大岩町(西郷内)');
ok($zip->set_number('4413144')->is_valid_number, '愛知県豊橋市大岩町(南元屋敷)');
ok($zip->set_number('4413145')->is_valid_number, '愛知県豊橋市大岩町(北元屋敷)');
ok($zip->set_number('4413146')->is_valid_number, '愛知県豊橋市大岩町(北山6)');
ok($zip->set_number('4413147')->is_valid_number, '愛知県豊橋市大岩町(その他)');
ok($zip->set_number('4413151')->is_valid_number, '愛知県豊橋市二川町(北裏)');
ok($zip->set_number('4413152')->is_valid_number, '愛知県豊橋市二川町(南裏)');
ok($zip->set_number('4413153')->is_valid_number, '愛知県豊橋市二川町(東向山)');
ok($zip->set_number('4413154')->is_valid_number, '愛知県豊橋市二川町(西向山)');
ok($zip->set_number('4413155')->is_valid_number, '愛知県豊橋市二川町(その他)');
ok($zip->set_number('4413201')->is_valid_number, '愛知県豊橋市東七根町');
ok($zip->set_number('4413202')->is_valid_number, '愛知県豊橋市西七根町');
ok($zip->set_number('4413203')->is_valid_number, '愛知県豊橋市高塚町');
ok($zip->set_number('4413211')->is_valid_number, '愛知県豊橋市伊古部町');
ok($zip->set_number('4413212')->is_valid_number, '愛知県豊橋市東赤沢町');
ok($zip->set_number('4413213')->is_valid_number, '愛知県豊橋市西赤沢町');
ok($zip->set_number('4413214')->is_valid_number, '愛知県豊橋市城下町');
ok($zip->set_number('4413301')->is_valid_number, '愛知県豊橋市老津町');
ok($zip->set_number('4413302')->is_valid_number, '愛知県豊橋市杉山町');
ok($zip->set_number('4413400')->is_valid_number, '愛知県田原市以下に掲載がない場合');
ok($zip->set_number('4413401')->is_valid_number, '愛知県田原市緑が浜');
ok($zip->set_number('4413402')->is_valid_number, '愛知県田原市吉胡町');
ok($zip->set_number('4413403')->is_valid_number, '愛知県田原市浦町');
ok($zip->set_number('4413404')->is_valid_number, '愛知県田原市片浜町');
ok($zip->set_number('4413405')->is_valid_number, '愛知県田原市姫見台');
ok($zip->set_number('4413406')->is_valid_number, '愛知県田原市波瀬町');
ok($zip->set_number('4413407')->is_valid_number, '愛知県田原市光崎');
ok($zip->set_number('4413408')->is_valid_number, '愛知県田原市吉胡台');
ok($zip->set_number('4413409')->is_valid_number, '愛知県田原市片西');
ok($zip->set_number('4413411')->is_valid_number, '愛知県田原市やぐま台');
ok($zip->set_number('4413412')->is_valid_number, '愛知県田原市谷熊町');
ok($zip->set_number('4413413')->is_valid_number, '愛知県田原市六連町');
ok($zip->set_number('4413414')->is_valid_number, '愛知県田原市東神戸町');
ok($zip->set_number('4413415')->is_valid_number, '愛知県田原市神戸町');
ok($zip->set_number('4413416')->is_valid_number, '愛知県田原市東赤石');
ok($zip->set_number('4413417')->is_valid_number, '愛知県田原市豊島町');
ok($zip->set_number('4413418')->is_valid_number, '愛知県田原市相川町');
ok($zip->set_number('4413419')->is_valid_number, '愛知県田原市御殿山');
ok($zip->set_number('4413421')->is_valid_number, '愛知県田原市田原町');
ok($zip->set_number('4413422')->is_valid_number, '愛知県田原市赤石');
ok($zip->set_number('4413423')->is_valid_number, '愛知県田原市西神戸町');
ok($zip->set_number('4413424')->is_valid_number, '愛知県田原市南神戸町');
ok($zip->set_number('4413425')->is_valid_number, '愛知県田原市大草町');
ok($zip->set_number('4413426')->is_valid_number, '愛知県田原市大久保町');
ok($zip->set_number('4413427')->is_valid_number, '愛知県田原市加治町');
ok($zip->set_number('4413431')->is_valid_number, '愛知県田原市白谷町');
ok($zip->set_number('4413432')->is_valid_number, '愛知県田原市野田町');
ok($zip->set_number('4413433')->is_valid_number, '愛知県田原市芦町');
ok($zip->set_number('4413434')->is_valid_number, '愛知県田原市ほると台');
ok($zip->set_number('4413435')->is_valid_number, '愛知県田原市仁崎町');
ok($zip->set_number('4413436')->is_valid_number, '愛知県田原市白浜');
ok($zip->set_number('4413501')->is_valid_number, '愛知県田原市高松町');
ok($zip->set_number('4413502')->is_valid_number, '愛知県田原市赤羽根町');
ok($zip->set_number('4413503')->is_valid_number, '愛知県田原市若見町');
ok($zip->set_number('4413504')->is_valid_number, '愛知県田原市越戸町');
ok($zip->set_number('4413505')->is_valid_number, '愛知県田原市池尻町');
ok($zip->set_number('4413601')->is_valid_number, '愛知県田原市宇津江町');
ok($zip->set_number('4413602')->is_valid_number, '愛知県田原市八王子町');
ok($zip->set_number('4413603')->is_valid_number, '愛知県田原市村松町');
ok($zip->set_number('4413604')->is_valid_number, '愛知県田原市伊川津町');
ok($zip->set_number('4413605')->is_valid_number, '愛知県田原市江比間町');
ok($zip->set_number('4413606')->is_valid_number, '愛知県田原市馬伏町');
ok($zip->set_number('4413607')->is_valid_number, '愛知県田原市夕陽が浜');
ok($zip->set_number('4413608')->is_valid_number, '愛知県田原市折立町');
ok($zip->set_number('4413609')->is_valid_number, '愛知県田原市長沢町');
ok($zip->set_number('4413611')->is_valid_number, '愛知県田原市石神町');
ok($zip->set_number('4413612')->is_valid_number, '愛知県田原市高木町');
ok($zip->set_number('4413613')->is_valid_number, '愛知県田原市古田町');
ok($zip->set_number('4413614')->is_valid_number, '愛知県田原市保美町');
ok($zip->set_number('4413615')->is_valid_number, '愛知県田原市中山町');
ok($zip->set_number('4413616')->is_valid_number, '愛知県田原市向山町');
ok($zip->set_number('4413617')->is_valid_number, '愛知県田原市福江町');
ok($zip->set_number('4413618')->is_valid_number, '愛知県田原市小中山町');
ok($zip->set_number('4413619')->is_valid_number, '愛知県田原市西山町');
ok($zip->set_number('4413621')->is_valid_number, '愛知県田原市山田町');
ok($zip->set_number('4413622')->is_valid_number, '愛知県田原市和地町');
ok($zip->set_number('4413623')->is_valid_number, '愛知県田原市日出町');
ok($zip->set_number('4413624')->is_valid_number, '愛知県田原市伊良湖町');
ok($zip->set_number('4413625')->is_valid_number, '愛知県田原市亀山町');
ok($zip->set_number('4413626')->is_valid_number, '愛知県田原市小塩津町');
ok($zip->set_number('4413627')->is_valid_number, '愛知県田原市堀切町');
ok($zip->set_number('4418001')->is_valid_number, '愛知県豊橋市野田町');
ok($zip->set_number('4418002')->is_valid_number, '愛知県豊橋市吉川町');
ok($zip->set_number('4418003')->is_valid_number, '愛知県豊橋市小向町');
ok($zip->set_number('4418004')->is_valid_number, '愛知県豊橋市吉前町');
ok($zip->set_number('4418005')->is_valid_number, '愛知県豊橋市富久縞町');
ok($zip->set_number('4418006')->is_valid_number, '愛知県豊橋市高洲町');
ok($zip->set_number('4418007')->is_valid_number, '愛知県豊橋市馬見塚町');
ok($zip->set_number('4418008')->is_valid_number, '愛知県豊橋市三ツ相町');
ok($zip->set_number('4418011')->is_valid_number, '愛知県豊橋市菰口町');
ok($zip->set_number('4418012')->is_valid_number, '愛知県豊橋市羽田町');
ok($zip->set_number('4418013')->is_valid_number, '愛知県豊橋市花田一番町');
ok($zip->set_number('4418014')->is_valid_number, '愛知県豊橋市花田二番町');
ok($zip->set_number('4418015')->is_valid_number, '愛知県豊橋市築地町');
ok($zip->set_number('4418016')->is_valid_number, '愛知県豊橋市新栄町');
ok($zip->set_number('4418017')->is_valid_number, '愛知県豊橋市北側町');
ok($zip->set_number('4418018')->is_valid_number, '愛知県豊橋市花田三番町');
ok($zip->set_number('4418019')->is_valid_number, '愛知県豊橋市花田町(その他)');
ok($zip->set_number('4418021')->is_valid_number, '愛知県豊橋市白河町');
ok($zip->set_number('4418022')->is_valid_number, '愛知県豊橋市野黒町');
ok($zip->set_number('4418023')->is_valid_number, '愛知県豊橋市八通町');
ok($zip->set_number('4418024')->is_valid_number, '愛知県豊橋市花田町(後田)');
ok($zip->set_number('4418024')->is_valid_number, '愛知県豊橋市花田町(西郷)');
ok($zip->set_number('4418024')->is_valid_number, '愛知県豊橋市花田町(中郷)');
ok($zip->set_number('4418025')->is_valid_number, '愛知県豊橋市羽根井町');
ok($zip->set_number('4418026')->is_valid_number, '愛知県豊橋市羽根井西町');
ok($zip->set_number('4418027')->is_valid_number, '愛知県豊橋市錦町');
ok($zip->set_number('4418028')->is_valid_number, '愛知県豊橋市立花町');
ok($zip->set_number('4418029')->is_valid_number, '愛知県豊橋市羽根井本町');
ok($zip->set_number('4418031')->is_valid_number, '愛知県豊橋市中郷町');
ok($zip->set_number('4418032')->is_valid_number, '愛知県豊橋市花中町');
ok($zip->set_number('4418033')->is_valid_number, '愛知県豊橋市入船町');
ok($zip->set_number('4418034')->is_valid_number, '愛知県豊橋市松村町');
ok($zip->set_number('4418035')->is_valid_number, '愛知県豊橋市有楽町');
ok($zip->set_number('4418036')->is_valid_number, '愛知県豊橋市東橋良町');
ok($zip->set_number('4418037')->is_valid_number, '愛知県豊橋市中橋良町');
ok($zip->set_number('4418038')->is_valid_number, '愛知県豊橋市堂坂町');
ok($zip->set_number('4418039')->is_valid_number, '愛知県豊橋市西橋良町');
ok($zip->set_number('4418041')->is_valid_number, '愛知県豊橋市柳生町');
ok($zip->set_number('4418042')->is_valid_number, '愛知県豊橋市小池町');
ok($zip->set_number('4418043')->is_valid_number, '愛知県豊橋市高師石塚町');
ok($zip->set_number('4418044')->is_valid_number, '愛知県豊橋市南小池町');
ok($zip->set_number('4418045')->is_valid_number, '愛知県豊橋市北丘町');
ok($zip->set_number('4418046')->is_valid_number, '愛知県豊橋市福岡町');
ok($zip->set_number('4418047')->is_valid_number, '愛知県豊橋市鴨田町');
ok($zip->set_number('4418048')->is_valid_number, '愛知県豊橋市西小池町');
ok($zip->set_number('4418051')->is_valid_number, '愛知県豊橋市柱四番町');
ok($zip->set_number('4418052')->is_valid_number, '愛知県豊橋市柱三番町');
ok($zip->set_number('4418053')->is_valid_number, '愛知県豊橋市柱二番町');
ok($zip->set_number('4418054')->is_valid_number, '愛知県豊橋市柱一番町');
ok($zip->set_number('4418055')->is_valid_number, '愛知県豊橋市柱九番町');
ok($zip->set_number('4418056')->is_valid_number, '愛知県豊橋市柱八番町');
ok($zip->set_number('4418057')->is_valid_number, '愛知県豊橋市柱七番町');
ok($zip->set_number('4418058')->is_valid_number, '愛知県豊橋市柱六番町');
ok($zip->set_number('4418059')->is_valid_number, '愛知県豊橋市柱五番町');
ok($zip->set_number('4418061')->is_valid_number, '愛知県豊橋市藤沢町');
ok($zip->set_number('4418062')->is_valid_number, '愛知県豊橋市東小浜町');
ok($zip->set_number('4418063')->is_valid_number, '愛知県豊橋市橋良町');
ok($zip->set_number('4418064')->is_valid_number, '愛知県豊橋市富本町');
ok($zip->set_number('4418065')->is_valid_number, '愛知県豊橋市中浜町');
ok($zip->set_number('4418066')->is_valid_number, '愛知県豊橋市王ケ崎町');
ok($zip->set_number('4418067')->is_valid_number, '愛知県豊橋市小浜町');
ok($zip->set_number('4418068')->is_valid_number, '愛知県豊橋市神ノ輪町');
ok($zip->set_number('4418069')->is_valid_number, '愛知県豊橋市潮崎町');
ok($zip->set_number('4418071')->is_valid_number, '愛知県豊橋市大山町');
ok($zip->set_number('4418072')->is_valid_number, '愛知県豊橋市船渡町');
ok($zip->set_number('4418073')->is_valid_number, '愛知県豊橋市大崎町');
ok($zip->set_number('4418074')->is_valid_number, '愛知県豊橋市明海町');
ok($zip->set_number('4418075')->is_valid_number, '愛知県豊橋市神野ふ頭町');
ok($zip->set_number('4418076')->is_valid_number, '愛知県豊橋市神野西町');
ok($zip->set_number('4418077')->is_valid_number, '愛知県豊橋市神野新田町');
ok($zip->set_number('4418081')->is_valid_number, '愛知県豊橋市西羽田町');
ok($zip->set_number('4418082')->is_valid_number, '愛知県豊橋市往完町');
ok($zip->set_number('4418083')->is_valid_number, '愛知県豊橋市東脇');
ok($zip->set_number('4418084')->is_valid_number, '愛知県豊橋市市場');
ok($zip->set_number('4418085')->is_valid_number, '愛知県豊橋市青竹町');
ok($zip->set_number('4418086')->is_valid_number, '愛知県豊橋市問屋町');
ok($zip->set_number('4418087')->is_valid_number, '愛知県豊橋市牟呂町');
ok($zip->set_number('4418088')->is_valid_number, '愛知県豊橋市牟呂市場町');
ok($zip->set_number('4418089')->is_valid_number, '愛知県豊橋市牟呂大西町');
ok($zip->set_number('4418090')->is_valid_number, '愛知県豊橋市牟呂公文町');
ok($zip->set_number('4418091')->is_valid_number, '愛知県豊橋市牟呂水神町');
ok($zip->set_number('4418092')->is_valid_number, '愛知県豊橋市牟呂外神町');
ok($zip->set_number('4418093')->is_valid_number, '愛知県豊橋市牟呂中村町');
ok($zip->set_number('4418101')->is_valid_number, '愛知県豊橋市山田町(瀬戸、郷、西山)');
ok($zip->set_number('4418102')->is_valid_number, '愛知県豊橋市山田一番町');
ok($zip->set_number('4418103')->is_valid_number, '愛知県豊橋市山田三番町');
ok($zip->set_number('4418104')->is_valid_number, '愛知県豊橋市山田二番町');
ok($zip->set_number('4418105')->is_valid_number, '愛知県豊橋市北山町');
ok($zip->set_number('4418106')->is_valid_number, '愛知県豊橋市弥生町');
ok($zip->set_number('4418107')->is_valid_number, '愛知県豊橋市南栄町');
ok($zip->set_number('4418108')->is_valid_number, '愛知県豊橋市町畑町');
ok($zip->set_number('4418109')->is_valid_number, '愛知県豊橋市小松町');
ok($zip->set_number('4418111')->is_valid_number, '愛知県豊橋市江島町');
ok($zip->set_number('4418112')->is_valid_number, '愛知県豊橋市牧野町');
ok($zip->set_number('4418113')->is_valid_number, '愛知県豊橋市西幸町');
ok($zip->set_number('4418114')->is_valid_number, '愛知県豊橋市藤並町');
ok($zip->set_number('4418115')->is_valid_number, '愛知県豊橋市東高田町');
ok($zip->set_number('4418116')->is_valid_number, '愛知県豊橋市高田町');
ok($zip->set_number('4418117')->is_valid_number, '愛知県豊橋市浜道町');
ok($zip->set_number('4418121')->is_valid_number, '愛知県豊橋市畑ケ田町');
ok($zip->set_number('4418122')->is_valid_number, '愛知県豊橋市天伯町');
ok($zip->set_number('4418123')->is_valid_number, '愛知県豊橋市若松町');
ok($zip->set_number('4418124')->is_valid_number, '愛知県豊橋市野依町');
ok($zip->set_number('4418125')->is_valid_number, '愛知県豊橋市野依台');
ok($zip->set_number('4418131')->is_valid_number, '愛知県豊橋市東大清水町');
ok($zip->set_number('4418132')->is_valid_number, '愛知県豊橋市南大清水町');
ok($zip->set_number('4418133')->is_valid_number, '愛知県豊橋市大清水町');
ok($zip->set_number('4418134')->is_valid_number, '愛知県豊橋市植田町');
ok($zip->set_number('4418135')->is_valid_number, '愛知県豊橋市富士見台');
ok($zip->set_number('4418141')->is_valid_number, '愛知県豊橋市草間町');
ok($zip->set_number('4418142')->is_valid_number, '愛知県豊橋市向草間町');
ok($zip->set_number('4418143')->is_valid_number, '愛知県豊橋市松井町');
ok($zip->set_number('4418144')->is_valid_number, '愛知県豊橋市磯辺下地町');
ok($zip->set_number('4418145')->is_valid_number, '愛知県豊橋市駒形町');
ok($zip->set_number('4418146')->is_valid_number, '愛知県豊橋市城山町');
ok($zip->set_number('4418147')->is_valid_number, '愛知県豊橋市内張町');
ok($zip->set_number('4418148')->is_valid_number, '愛知県豊橋市一色町');
ok($zip->set_number('4418149')->is_valid_number, '愛知県豊橋市中野町');
ok($zip->set_number('4418151')->is_valid_number, '愛知県豊橋市曙町');
ok($zip->set_number('4418152')->is_valid_number, '愛知県豊橋市三本木町');
ok($zip->set_number('4418153')->is_valid_number, '愛知県豊橋市高師本郷町');
ok($zip->set_number('4418154')->is_valid_number, '愛知県豊橋市西高師町');
ok($zip->set_number('4418155')->is_valid_number, '愛知県豊橋市芦原町');
ok($zip->set_number('4418156')->is_valid_number, '愛知県豊橋市高師町(小野)');
ok($zip->set_number('4418156')->is_valid_number, '愛知県豊橋市高師町(北新切)');
ok($zip->set_number('4418156')->is_valid_number, '愛知県豊橋市高師町(北原1、1-57、58、76、80~86、44番地)');
ok($zip->set_number('4418156')->is_valid_number, '愛知県豊橋市高師町(西沢)');
ok($zip->set_number('4418157')->is_valid_number, '愛知県豊橋市上野町');
ok($zip->set_number('4420000')->is_valid_number, '愛知県豊川市以下に掲載がない場合');
ok($zip->set_number('4420001')->is_valid_number, '愛知県豊川市千両町');
ok($zip->set_number('4420002')->is_valid_number, '愛知県豊川市六角町');
ok($zip->set_number('4420003')->is_valid_number, '愛知県豊川市長草町');
ok($zip->set_number('4420004')->is_valid_number, '愛知県豊川市樽井町');
ok($zip->set_number('4420005')->is_valid_number, '愛知県豊川市本野ケ原');
ok($zip->set_number('4420006')->is_valid_number, '愛知県豊川市三蔵子町');
ok($zip->set_number('4420007')->is_valid_number, '愛知県豊川市大崎町');
ok($zip->set_number('4420008')->is_valid_number, '愛知県豊川市南千両');
ok($zip->set_number('4420011')->is_valid_number, '愛知県豊川市東曙町');
ok($zip->set_number('4420012')->is_valid_number, '愛知県豊川市新豊町');
ok($zip->set_number('4420013')->is_valid_number, '愛知県豊川市大堀町');
ok($zip->set_number('4420014')->is_valid_number, '愛知県豊川市豊栄町');
ok($zip->set_number('4420015')->is_valid_number, '愛知県豊川市曙町');
ok($zip->set_number('4420016')->is_valid_number, '愛知県豊川市美幸町');
ok($zip->set_number('4420017')->is_valid_number, '愛知県豊川市佐土町');
ok($zip->set_number('4420018')->is_valid_number, '愛知県豊川市白雲町');
ok($zip->set_number('4420019')->is_valid_number, '愛知県豊川市東名町');
ok($zip->set_number('4420021')->is_valid_number, '愛知県豊川市小桜町');
ok($zip->set_number('4420022')->is_valid_number, '愛知県豊川市東光町');
ok($zip->set_number('4420023')->is_valid_number, '愛知県豊川市稲荷通');
ok($zip->set_number('4420024')->is_valid_number, '愛知県豊川市西豊町');
ok($zip->set_number('4420025')->is_valid_number, '愛知県豊川市東豊町');
ok($zip->set_number('4420026')->is_valid_number, '愛知県豊川市東新町');
ok($zip->set_number('4420027')->is_valid_number, '愛知県豊川市桜木通');
ok($zip->set_number('4420028')->is_valid_number, '愛知県豊川市東桜木町');
ok($zip->set_number('4420029')->is_valid_number, '愛知県豊川市末広通');
ok($zip->set_number('4420031')->is_valid_number, '愛知県豊川市豊川西町');
ok($zip->set_number('4420032')->is_valid_number, '愛知県豊川市豊川仲町');
ok($zip->set_number('4420033')->is_valid_number, '愛知県豊川市豊川町');
ok($zip->set_number('4420034')->is_valid_number, '愛知県豊川市西本町');
ok($zip->set_number('4420035')->is_valid_number, '愛知県豊川市豊川元町');
ok($zip->set_number('4420036')->is_valid_number, '愛知県豊川市豊川栄町');
ok($zip->set_number('4420037')->is_valid_number, '愛知県豊川市門前町');
ok($zip->set_number('4420038')->is_valid_number, '愛知県豊川市光陽町');
ok($zip->set_number('4420039')->is_valid_number, '愛知県豊川市天神町');
ok($zip->set_number('4420041')->is_valid_number, '愛知県豊川市旭町');
ok($zip->set_number('4420042')->is_valid_number, '愛知県豊川市北浦町');
ok($zip->set_number('4420043')->is_valid_number, '愛知県豊川市新宿町');
ok($zip->set_number('4420044')->is_valid_number, '愛知県豊川市二見町');
ok($zip->set_number('4420045')->is_valid_number, '愛知県豊川市駅前通');
ok($zip->set_number('4420046')->is_valid_number, '愛知県豊川市幸町');
ok($zip->set_number('4420047')->is_valid_number, '愛知県豊川市若宮町');
ok($zip->set_number('4420048')->is_valid_number, '愛知県豊川市開運通');
ok($zip->set_number('4420049')->is_valid_number, '愛知県豊川市緑町');
ok($zip->set_number('4420051')->is_valid_number, '愛知県豊川市中央通');
ok($zip->set_number('4420052')->is_valid_number, '愛知県豊川市金屋本町');
ok($zip->set_number('4420053')->is_valid_number, '愛知県豊川市金屋町');
ok($zip->set_number('4420054')->is_valid_number, '愛知県豊川市赤代町');
ok($zip->set_number('4420055')->is_valid_number, '愛知県豊川市金屋橋町');
ok($zip->set_number('4420061')->is_valid_number, '愛知県豊川市穂ノ原');
ok($zip->set_number('4420062')->is_valid_number, '愛知県豊川市本野町');
ok($zip->set_number('4420063')->is_valid_number, '愛知県豊川市西桜木町');
ok($zip->set_number('4420064')->is_valid_number, '愛知県豊川市桜ケ丘町');
ok($zip->set_number('4420065')->is_valid_number, '愛知県豊川市若鳩町');
ok($zip->set_number('4420066')->is_valid_number, '愛知県豊川市金屋元町');
ok($zip->set_number('4420067')->is_valid_number, '愛知県豊川市金屋西町');
ok($zip->set_number('4420068')->is_valid_number, '愛知県豊川市諏訪');
ok($zip->set_number('4420069')->is_valid_number, '愛知県豊川市諏訪西町');
ok($zip->set_number('4420801')->is_valid_number, '愛知県豊川市上野');
ok($zip->set_number('4420802')->is_valid_number, '愛知県豊川市麻生田町');
ok($zip->set_number('4420803')->is_valid_number, '愛知県豊川市向河原町');
ok($zip->set_number('4420804')->is_valid_number, '愛知県豊川市二葉町');
ok($zip->set_number('4420805')->is_valid_number, '愛知県豊川市三谷原町');
ok($zip->set_number('4420806')->is_valid_number, '愛知県豊川市牧野町');
ok($zip->set_number('4420807')->is_valid_number, '愛知県豊川市谷川町');
ok($zip->set_number('4420808')->is_valid_number, '愛知県豊川市豊が丘町');
ok($zip->set_number('4420809')->is_valid_number, '愛知県豊川市大橋町');
ok($zip->set_number('4420811')->is_valid_number, '愛知県豊川市馬場町');
ok($zip->set_number('4420812')->is_valid_number, '愛知県豊川市三上町');
ok($zip->set_number('4420813')->is_valid_number, '愛知県豊川市土筒町');
ok($zip->set_number('4420814')->is_valid_number, '愛知県豊川市院之子町');
ok($zip->set_number('4420815')->is_valid_number, '愛知県豊川市瀬木町');
ok($zip->set_number('4420816')->is_valid_number, '愛知県豊川市花井町');
ok($zip->set_number('4420817')->is_valid_number, '愛知県豊川市古宿町');
ok($zip->set_number('4420818')->is_valid_number, '愛知県豊川市中条町');
ok($zip->set_number('4420819')->is_valid_number, '愛知県豊川市住吉町');
ok($zip->set_number('4420821')->is_valid_number, '愛知県豊川市当古町');
ok($zip->set_number('4420822')->is_valid_number, '愛知県豊川市行明町');
ok($zip->set_number('4420823')->is_valid_number, '愛知県豊川市正岡町');
ok($zip->set_number('4420824')->is_valid_number, '愛知県豊川市下長山町');
ok($zip->set_number('4420825')->is_valid_number, '愛知県豊川市美和通');
ok($zip->set_number('4420826')->is_valid_number, '愛知県豊川市牛久保町');
ok($zip->set_number('4420827')->is_valid_number, '愛知県豊川市西島町');
ok($zip->set_number('4420828')->is_valid_number, '愛知県豊川市柑子町');
ok($zip->set_number('4420831')->is_valid_number, '愛知県豊川市弥生町');
ok($zip->set_number('4420832')->is_valid_number, '愛知県豊川市寿通');
ok($zip->set_number('4420833')->is_valid_number, '愛知県豊川市西口町');
ok($zip->set_number('4420834')->is_valid_number, '愛知県豊川市西香ノ木町');
ok($zip->set_number('4420835')->is_valid_number, '愛知県豊川市新桜町通');
ok($zip->set_number('4420836')->is_valid_number, '愛知県豊川市堺町');
ok($zip->set_number('4420837')->is_valid_number, '愛知県豊川市川花町');
ok($zip->set_number('4420838')->is_valid_number, '愛知県豊川市西塚町');
ok($zip->set_number('4420839')->is_valid_number, '愛知県豊川市四ツ谷町');
ok($zip->set_number('4420841')->is_valid_number, '愛知県豊川市代田町');
ok($zip->set_number('4420842')->is_valid_number, '愛知県豊川市蔵子');
ok($zip->set_number('4420843')->is_valid_number, '愛知県豊川市桜町');
ok($zip->set_number('4420844')->is_valid_number, '愛知県豊川市小田渕町');
ok($zip->set_number('4420845')->is_valid_number, '愛知県豊川市為当町');
ok($zip->set_number('4420846')->is_valid_number, '愛知県豊川市森');
ok($zip->set_number('4420847')->is_valid_number, '愛知県豊川市白鳥');
ok($zip->set_number('4420848')->is_valid_number, '愛知県豊川市白鳥町');
ok($zip->set_number('4420851')->is_valid_number, '愛知県豊川市野口町');
ok($zip->set_number('4420852')->is_valid_number, '愛知県豊川市国府南');
ok($zip->set_number('4420853')->is_valid_number, '愛知県豊川市新青馬町');
ok($zip->set_number('4420854')->is_valid_number, '愛知県豊川市国府町');
ok($zip->set_number('4420855')->is_valid_number, '愛知県豊川市新栄町');
ok($zip->set_number('4420856')->is_valid_number, '愛知県豊川市久保町');
ok($zip->set_number('4420857')->is_valid_number, '愛知県豊川市八幡町');
ok($zip->set_number('4420861')->is_valid_number, '愛知県豊川市財賀町');
ok($zip->set_number('4420862')->is_valid_number, '愛知県豊川市市田町');
ok($zip->set_number('4420863')->is_valid_number, '愛知県豊川市平尾町');
ok($zip->set_number('4420871')->is_valid_number, '愛知県豊川市松風町');
ok($zip->set_number('4420872')->is_valid_number, '愛知県豊川市金塚町');
ok($zip->set_number('4420873')->is_valid_number, '愛知県豊川市山道町');
ok($zip->set_number('4420874')->is_valid_number, '愛知県豊川市松久町');
ok($zip->set_number('4420875')->is_valid_number, '愛知県豊川市佐奈川町');
ok($zip->set_number('4420876')->is_valid_number, '愛知県豊川市中部町');
ok($zip->set_number('4420877')->is_valid_number, '愛知県豊川市下野川町');
ok($zip->set_number('4420878')->is_valid_number, '愛知県豊川市新道町');
ok($zip->set_number('4420879')->is_valid_number, '愛知県豊川市萩山町');
ok($zip->set_number('4420881')->is_valid_number, '愛知県豊川市塔ノ木町');
ok($zip->set_number('4420882')->is_valid_number, '愛知県豊川市光輝町');
ok($zip->set_number('4420883')->is_valid_number, '愛知県豊川市高見町');
ok($zip->set_number('4420884')->is_valid_number, '愛知県豊川市光明町');
ok($zip->set_number('4420885')->is_valid_number, '愛知県豊川市中野川町');
ok($zip->set_number('4420886')->is_valid_number, '愛知県豊川市牛久保駅通');
ok($zip->set_number('4420887')->is_valid_number, '愛知県豊川市明野町');
ok($zip->set_number('4420888')->is_valid_number, '愛知県豊川市千歳通');
ok($zip->set_number('4420889')->is_valid_number, '愛知県豊川市南大通');
ok($zip->set_number('4430000')->is_valid_number, '愛知県蒲郡市以下に掲載がない場合');
ok($zip->set_number('4430001')->is_valid_number, '愛知県蒲郡市坂本町');
ok($zip->set_number('4430002')->is_valid_number, '愛知県蒲郡市清田町');
ok($zip->set_number('4430003')->is_valid_number, '愛知県蒲郡市五井町');
ok($zip->set_number('4430004')->is_valid_number, '愛知県蒲郡市平田町');
ok($zip->set_number('4430005')->is_valid_number, '愛知県蒲郡市水竹町');
ok($zip->set_number('4430006')->is_valid_number, '愛知県蒲郡市蒲郡町');
ok($zip->set_number('4430007')->is_valid_number, '愛知県蒲郡市神ノ郷町');
ok($zip->set_number('4430008')->is_valid_number, '愛知県蒲郡市柏原町');
ok($zip->set_number('4430011')->is_valid_number, '愛知県蒲郡市豊岡町');
ok($zip->set_number('4430012')->is_valid_number, '愛知県蒲郡市相楽町');
ok($zip->set_number('4430013')->is_valid_number, '愛知県蒲郡市大塚町');
ok($zip->set_number('4430014')->is_valid_number, '愛知県蒲郡市海陽町');
ok($zip->set_number('4430021')->is_valid_number, '愛知県蒲郡市三谷町');
ok($zip->set_number('4430022')->is_valid_number, '愛知県蒲郡市三谷北通');
ok($zip->set_number('4430031')->is_valid_number, '愛知県蒲郡市竹島町');
ok($zip->set_number('4430032')->is_valid_number, '愛知県蒲郡市丸山町');
ok($zip->set_number('4430033')->is_valid_number, '愛知県蒲郡市松原町');
ok($zip->set_number('4430034')->is_valid_number, '愛知県蒲郡市港町');
ok($zip->set_number('4430035')->is_valid_number, '愛知県蒲郡市栄町');
ok($zip->set_number('4430036')->is_valid_number, '愛知県蒲郡市浜町');
ok($zip->set_number('4430037')->is_valid_number, '愛知県蒲郡市鹿島町');
ok($zip->set_number('4430038')->is_valid_number, '愛知県蒲郡市拾石町');
ok($zip->set_number('4430041')->is_valid_number, '愛知県蒲郡市宮成町');
ok($zip->set_number('4430042')->is_valid_number, '愛知県蒲郡市御幸町');
ok($zip->set_number('4430043')->is_valid_number, '愛知県蒲郡市元町');
ok($zip->set_number('4430044')->is_valid_number, '愛知県蒲郡市宝町');
ok($zip->set_number('4430045')->is_valid_number, '愛知県蒲郡市旭町');
ok($zip->set_number('4430046')->is_valid_number, '愛知県蒲郡市竹谷町');
ok($zip->set_number('4430047')->is_valid_number, '愛知県蒲郡市西迫町');
ok($zip->set_number('4430048')->is_valid_number, '愛知県蒲郡市緑町');
ok($zip->set_number('4430051')->is_valid_number, '愛知県蒲郡市新井形町');
ok($zip->set_number('4430051')->is_valid_number, '愛知県蒲郡市新井形町南');
ok($zip->set_number('4430052')->is_valid_number, '愛知県蒲郡市新井町');
ok($zip->set_number('4430052')->is_valid_number, '愛知県蒲郡市新井町南');
ok($zip->set_number('4430053')->is_valid_number, '愛知県蒲郡市堀込町');
ok($zip->set_number('4430054')->is_valid_number, '愛知県蒲郡市府相町');
ok($zip->set_number('4430055')->is_valid_number, '愛知県蒲郡市八百富町');
ok($zip->set_number('4430056')->is_valid_number, '愛知県蒲郡市神明町');
ok($zip->set_number('4430056')->is_valid_number, '愛知県蒲郡市神明町東');
ok($zip->set_number('4430057')->is_valid_number, '愛知県蒲郡市中央本町');
ok($zip->set_number('4430058')->is_valid_number, '愛知県蒲郡市上本町');
ok($zip->set_number('4430059')->is_valid_number, '愛知県蒲郡市本町');
ok($zip->set_number('4430059')->is_valid_number, '愛知県蒲郡市本町東');
ok($zip->set_number('4430101')->is_valid_number, '愛知県蒲郡市一色町');
ok($zip->set_number('4430102')->is_valid_number, '愛知県蒲郡市金平町');
ok($zip->set_number('4430103')->is_valid_number, '愛知県蒲郡市形原町北浜');
ok($zip->set_number('4430104')->is_valid_number, '愛知県蒲郡市形原町');
ok($zip->set_number('4430105')->is_valid_number, '愛知県蒲郡市西浦町');
ok($zip->set_number('4430106')->is_valid_number, '愛知県蒲郡市形原町春日浦');
ok($zip->set_number('4440000')->is_valid_number, '愛知県岡崎市以下に掲載がない場合');
ok($zip->set_number('4440001')->is_valid_number, '愛知県岡崎市箱柳町(その他)');
ok($zip->set_number('4440002')->is_valid_number, '愛知県岡崎市高隆寺町');
ok($zip->set_number('4440003')->is_valid_number, '愛知県岡崎市小美町');
ok($zip->set_number('4440004')->is_valid_number, '愛知県岡崎市保母町');
ok($zip->set_number('4440005')->is_valid_number, '愛知県岡崎市岡町');
ok($zip->set_number('4440006')->is_valid_number, '愛知県岡崎市丸山町');
ok($zip->set_number('4440007')->is_valid_number, '愛知県岡崎市大平町');
ok($zip->set_number('4440008')->is_valid_number, '愛知県岡崎市洞町');
ok($zip->set_number('4440009')->is_valid_number, '愛知県岡崎市小呂町');
ok($zip->set_number('4440011')->is_valid_number, '愛知県岡崎市欠町');
ok($zip->set_number('4440012')->is_valid_number, '愛知県岡崎市栄町');
ok($zip->set_number('4440013')->is_valid_number, '愛知県岡崎市根石町');
ok($zip->set_number('4440014')->is_valid_number, '愛知県岡崎市若宮町');
ok($zip->set_number('4440015')->is_valid_number, '愛知県岡崎市中町');
ok($zip->set_number('4440016')->is_valid_number, '愛知県岡崎市元欠町');
ok($zip->set_number('4440021')->is_valid_number, '愛知県岡崎市蓬莱町');
ok($zip->set_number('4440022')->is_valid_number, '愛知県岡崎市朝日町');
ok($zip->set_number('4440023')->is_valid_number, '愛知県岡崎市両町');
ok($zip->set_number('4440024')->is_valid_number, '愛知県岡崎市西中町');
ok($zip->set_number('4440025')->is_valid_number, '愛知県岡崎市曙町');
ok($zip->set_number('4440031')->is_valid_number, '愛知県岡崎市梅園町');
ok($zip->set_number('4440032')->is_valid_number, '愛知県岡崎市門前町');
ok($zip->set_number('4440033')->is_valid_number, '愛知県岡崎市久右ヱ門町');
ok($zip->set_number('4440034')->is_valid_number, '愛知県岡崎市十王町');
ok($zip->set_number('4440035')->is_valid_number, '愛知県岡崎市菅生町');
ok($zip->set_number('4440036')->is_valid_number, '愛知県岡崎市島町');
ok($zip->set_number('4440037')->is_valid_number, '愛知県岡崎市祐金町');
ok($zip->set_number('4440038')->is_valid_number, '愛知県岡崎市伝馬通');
ok($zip->set_number('4440039')->is_valid_number, '愛知県岡崎市花崗町');
ok($zip->set_number('4440041')->is_valid_number, '愛知県岡崎市籠田町');
ok($zip->set_number('4440042')->is_valid_number, '愛知県岡崎市六地蔵町');
ok($zip->set_number('4440043')->is_valid_number, '愛知県岡崎市唐沢町');
ok($zip->set_number('4440044')->is_valid_number, '愛知県岡崎市康生通南');
ok($zip->set_number('4440045')->is_valid_number, '愛知県岡崎市康生通東');
ok($zip->set_number('4440046')->is_valid_number, '愛知県岡崎市連尺通');
ok($zip->set_number('4440047')->is_valid_number, '愛知県岡崎市八幡町');
ok($zip->set_number('4440048')->is_valid_number, '愛知県岡崎市六供本町');
ok($zip->set_number('4440049')->is_valid_number, '愛知県岡崎市亀井町');
ok($zip->set_number('4440051')->is_valid_number, '愛知県岡崎市本町通');
ok($zip->set_number('4440052')->is_valid_number, '愛知県岡崎市康生町');
ok($zip->set_number('4440053')->is_valid_number, '愛知県岡崎市板屋町');
ok($zip->set_number('4440054')->is_valid_number, '愛知県岡崎市田町');
ok($zip->set_number('4440055')->is_valid_number, '愛知県岡崎市西魚町');
ok($zip->set_number('4440056')->is_valid_number, '愛知県岡崎市福寿町');
ok($zip->set_number('4440057')->is_valid_number, '愛知県岡崎市材木町');
ok($zip->set_number('4440058')->is_valid_number, '愛知県岡崎市魚町');
ok($zip->set_number('4440059')->is_valid_number, '愛知県岡崎市康生通西');
ok($zip->set_number('4440061')->is_valid_number, '愛知県岡崎市能見町');
ok($zip->set_number('4440062')->is_valid_number, '愛知県岡崎市松本町');
ok($zip->set_number('4440063')->is_valid_number, '愛知県岡崎市元能見町');
ok($zip->set_number('4440064')->is_valid_number, '愛知県岡崎市城北町');
ok($zip->set_number('4440065')->is_valid_number, '愛知県岡崎市柿田町');
ok($zip->set_number('4440066')->is_valid_number, '愛知県岡崎市広幡町');
ok($zip->set_number('4440067')->is_valid_number, '愛知県岡崎市錦町');
ok($zip->set_number('4440068')->is_valid_number, '愛知県岡崎市井田南町');
ok($zip->set_number('4440069')->is_valid_number, '愛知県岡崎市井田新町');
ok($zip->set_number('4440071')->is_valid_number, '愛知県岡崎市稲熊町');
ok($zip->set_number('4440072')->is_valid_number, '愛知県岡崎市六供町');
ok($zip->set_number('4440073')->is_valid_number, '愛知県岡崎市能見通');
ok($zip->set_number('4440074')->is_valid_number, '愛知県岡崎市東能見町');
ok($zip->set_number('4440075')->is_valid_number, '愛知県岡崎市伊賀町');
ok($zip->set_number('4440076')->is_valid_number, '愛知県岡崎市井田町');
ok($zip->set_number('4440077')->is_valid_number, '愛知県岡崎市井田町茨坪');
ok($zip->set_number('4440078')->is_valid_number, '愛知県岡崎市伊賀新町');
ok($zip->set_number('4440079')->is_valid_number, '愛知県岡崎市石神町');
ok($zip->set_number('4440100')->is_valid_number, '愛知県額田郡幸田町以下に掲載がない場合');
ok($zip->set_number('4440101')->is_valid_number, '愛知県額田郡幸田町長嶺');
ok($zip->set_number('4440102')->is_valid_number, '愛知県額田郡幸田町久保田');
ok($zip->set_number('4440103')->is_valid_number, '愛知県額田郡幸田町大草');
ok($zip->set_number('4440104')->is_valid_number, '愛知県額田郡幸田町坂崎');
ok($zip->set_number('4440111')->is_valid_number, '愛知県額田郡幸田町高力');
ok($zip->set_number('4440113')->is_valid_number, '愛知県額田郡幸田町菱池');
ok($zip->set_number('4440114')->is_valid_number, '愛知県額田郡幸田町横落');
ok($zip->set_number('4440115')->is_valid_number, '愛知県額田郡幸田町荻');
ok($zip->set_number('4440116')->is_valid_number, '愛知県額田郡幸田町芦谷');
ok($zip->set_number('4440117')->is_valid_number, '愛知県額田郡幸田町相見');
ok($zip->set_number('4440121')->is_valid_number, '愛知県額田郡幸田町永野');
ok($zip->set_number('4440122')->is_valid_number, '愛知県額田郡幸田町六栗');
ok($zip->set_number('4440123')->is_valid_number, '愛知県額田郡幸田町上六栗');
ok($zip->set_number('4440124')->is_valid_number, '愛知県額田郡幸田町深溝');
ok($zip->set_number('4440125')->is_valid_number, '愛知県額田郡幸田町逆川');
ok($zip->set_number('4440126')->is_valid_number, '愛知県額田郡幸田町桐山');
ok($zip->set_number('4440127')->is_valid_number, '愛知県額田郡幸田町須美');
ok($zip->set_number('4440128')->is_valid_number, '愛知県額田郡幸田町野場');
ok($zip->set_number('4440201')->is_valid_number, '愛知県岡崎市上和田町');
ok($zip->set_number('4440202')->is_valid_number, '愛知県岡崎市宮地町');
ok($zip->set_number('4440203')->is_valid_number, '愛知県岡崎市井内町');
ok($zip->set_number('4440204')->is_valid_number, '愛知県岡崎市土井町');
ok($zip->set_number('4440205')->is_valid_number, '愛知県岡崎市牧御堂町');
ok($zip->set_number('4440206')->is_valid_number, '愛知県岡崎市法性寺町');
ok($zip->set_number('4440211')->is_valid_number, '愛知県岡崎市野畑町');
ok($zip->set_number('4440212')->is_valid_number, '愛知県岡崎市下和田町');
ok($zip->set_number('4440213')->is_valid_number, '愛知県岡崎市坂左右町');
ok($zip->set_number('4440214')->is_valid_number, '愛知県岡崎市国正町');
ok($zip->set_number('4440215')->is_valid_number, '愛知県岡崎市中村町');
ok($zip->set_number('4440216')->is_valid_number, '愛知県岡崎市定国町');
ok($zip->set_number('4440221')->is_valid_number, '愛知県岡崎市正名町');
ok($zip->set_number('4440222')->is_valid_number, '愛知県岡崎市二軒屋町');
ok($zip->set_number('4440223')->is_valid_number, '愛知県岡崎市中島東町');
ok($zip->set_number('4440224')->is_valid_number, '愛知県岡崎市中島中町');
ok($zip->set_number('4440225')->is_valid_number, '愛知県岡崎市中島西町');
ok($zip->set_number('4440226')->is_valid_number, '愛知県岡崎市中島町');
ok($zip->set_number('4440231')->is_valid_number, '愛知県岡崎市高橋町');
ok($zip->set_number('4440232')->is_valid_number, '愛知県岡崎市合歓木町');
ok($zip->set_number('4440233')->is_valid_number, '愛知県岡崎市福桶町');
ok($zip->set_number('4440234')->is_valid_number, '愛知県岡崎市安藤町');
ok($zip->set_number('4440241')->is_valid_number, '愛知県岡崎市赤渋町');
ok($zip->set_number('4440242')->is_valid_number, '愛知県岡崎市中之郷町');
ok($zip->set_number('4440243')->is_valid_number, '愛知県岡崎市上青野町');
ok($zip->set_number('4440244')->is_valid_number, '愛知県岡崎市下青野町');
ok($zip->set_number('4440245')->is_valid_number, '愛知県岡崎市在家町');
ok($zip->set_number('4440246')->is_valid_number, '愛知県岡崎市上三ツ木町');
ok($zip->set_number('4440247')->is_valid_number, '愛知県岡崎市下三ツ木町');
ok($zip->set_number('4440301')->is_valid_number, '愛知県西尾市田貫町');
ok($zip->set_number('4440302')->is_valid_number, '愛知県西尾市田貫');
ok($zip->set_number('4440303')->is_valid_number, '愛知県西尾市中畑町');
ok($zip->set_number('4440304')->is_valid_number, '愛知県西尾市中畑');
ok($zip->set_number('4440305')->is_valid_number, '愛知県西尾市平坂町');
ok($zip->set_number('4440311')->is_valid_number, '愛知県西尾市新在家町');
ok($zip->set_number('4440312')->is_valid_number, '愛知県西尾市国森町');
ok($zip->set_number('4440313')->is_valid_number, '愛知県西尾市上矢田町');
ok($zip->set_number('4440314')->is_valid_number, '愛知県西尾市下矢田町');
ok($zip->set_number('4440315')->is_valid_number, '愛知県西尾市徳永町');
ok($zip->set_number('4440316')->is_valid_number, '愛知県西尾市羽塚町');
ok($zip->set_number('4440317')->is_valid_number, '愛知県西尾市羽塚西ノ山');
ok($zip->set_number('4440318')->is_valid_number, '愛知県西尾市矢田');
ok($zip->set_number('4440321')->is_valid_number, '愛知県西尾市刈宿町');
ok($zip->set_number('4440322')->is_valid_number, '愛知県西尾市巨海町');
ok($zip->set_number('4440323')->is_valid_number, '愛知県西尾市中根町');
ok($zip->set_number('4440324')->is_valid_number, '愛知県西尾市寺津町');
ok($zip->set_number('4440325')->is_valid_number, '愛知県西尾市楠村町');
ok($zip->set_number('4440326')->is_valid_number, '愛知県西尾市富山町');
ok($zip->set_number('4440327')->is_valid_number, '愛知県西尾市寺津');
ok($zip->set_number('4440328')->is_valid_number, '愛知県西尾市平坂吉山');
ok($zip->set_number('4440329')->is_valid_number, '愛知県西尾市富山');
ok($zip->set_number('4440331')->is_valid_number, '愛知県西尾市西小梛町');
ok($zip->set_number('4440332')->is_valid_number, '愛知県西尾市小栗町');
ok($zip->set_number('4440333')->is_valid_number, '愛知県西尾市奥田町');
ok($zip->set_number('4440334')->is_valid_number, '愛知県西尾市南奥田町');
ok($zip->set_number('4440335')->is_valid_number, '愛知県西尾市港町');
ok($zip->set_number('4440336')->is_valid_number, '愛知県西尾市西奥田町');
ok($zip->set_number('4440401')->is_valid_number, '愛知県西尾市一色町池田');
ok($zip->set_number('4440402')->is_valid_number, '愛知県西尾市一色町大塚');
ok($zip->set_number('4440403')->is_valid_number, '愛知県西尾市一色町松木島');
ok($zip->set_number('4440404')->is_valid_number, '愛知県西尾市一色町野田');
ok($zip->set_number('4440405')->is_valid_number, '愛知県西尾市一色町惣五郎');
ok($zip->set_number('4440406')->is_valid_number, '愛知県西尾市一色町対米');
ok($zip->set_number('4440407')->is_valid_number, '愛知県西尾市一色町前野');
ok($zip->set_number('4440411')->is_valid_number, '愛知県西尾市一色町千間');
ok($zip->set_number('4440412')->is_valid_number, '愛知県西尾市一色町生田');
ok($zip->set_number('4440413')->is_valid_number, '愛知県西尾市一色町坂田新田');
ok($zip->set_number('4440414')->is_valid_number, '愛知県西尾市一色町藤江');
ok($zip->set_number('4440415')->is_valid_number, '愛知県西尾市一色町酒手島');
ok($zip->set_number('4440416')->is_valid_number, '愛知県西尾市一色町佐久島');
ok($zip->set_number('4440421')->is_valid_number, '愛知県西尾市一色町開正');
ok($zip->set_number('4440422')->is_valid_number, '愛知県西尾市一色町味浜');
ok($zip->set_number('4440423')->is_valid_number, '愛知県西尾市一色町一色');
ok($zip->set_number('4440424')->is_valid_number, '愛知県西尾市一色町小薮');
ok($zip->set_number('4440425')->is_valid_number, '愛知県西尾市一色町細川');
ok($zip->set_number('4440426')->is_valid_number, '愛知県西尾市一色町治明');
ok($zip->set_number('4440427')->is_valid_number, '愛知県西尾市一色町赤羽');
ok($zip->set_number('4440428')->is_valid_number, '愛知県西尾市一色町中外沢');
ok($zip->set_number('4440429')->is_valid_number, '愛知県西尾市一色町養ケ島');
ok($zip->set_number('4440501')->is_valid_number, '愛知県西尾市吉良町駮馬');
ok($zip->set_number('4440502')->is_valid_number, '愛知県西尾市吉良町宮迫');
ok($zip->set_number('4440503')->is_valid_number, '愛知県西尾市吉良町津平');
ok($zip->set_number('4440504')->is_valid_number, '愛知県西尾市吉良町友国');
ok($zip->set_number('4440511')->is_valid_number, '愛知県西尾市吉良町小山田');
ok($zip->set_number('4440512')->is_valid_number, '愛知県西尾市吉良町乙川');
ok($zip->set_number('4440513')->is_valid_number, '愛知県西尾市吉良町宮崎');
ok($zip->set_number('4440514')->is_valid_number, '愛知県西尾市吉良町白浜新田');
ok($zip->set_number('4440515')->is_valid_number, '愛知県西尾市吉良町富好新田');
ok($zip->set_number('4440516')->is_valid_number, '愛知県西尾市吉良町吉田');
ok($zip->set_number('4440517')->is_valid_number, '愛知県西尾市吉良町大島');
ok($zip->set_number('4440521')->is_valid_number, '愛知県西尾市吉良町上横須賀');
ok($zip->set_number('4440522')->is_valid_number, '愛知県西尾市吉良町下横須賀');
ok($zip->set_number('4440523')->is_valid_number, '愛知県西尾市吉良町饗庭');
ok($zip->set_number('4440524')->is_valid_number, '愛知県西尾市吉良町荻原');
ok($zip->set_number('4440525')->is_valid_number, '愛知県西尾市吉良町富田');
ok($zip->set_number('4440526')->is_valid_number, '愛知県西尾市吉良町八幡川田');
ok($zip->set_number('4440531')->is_valid_number, '愛知県西尾市吉良町岡山');
ok($zip->set_number('4440532')->is_valid_number, '愛知県西尾市吉良町瀬戸');
ok($zip->set_number('4440533')->is_valid_number, '愛知県西尾市吉良町寺嶋');
ok($zip->set_number('4440534')->is_valid_number, '愛知県西尾市吉良町木田');
ok($zip->set_number('4440535')->is_valid_number, '愛知県西尾市吉良町小牧');
ok($zip->set_number('4440536')->is_valid_number, '愛知県西尾市吉良町中野');
ok($zip->set_number('4440537')->is_valid_number, '愛知県西尾市吉良町酒井');
ok($zip->set_number('4440701')->is_valid_number, '愛知県西尾市東幡豆町');
ok($zip->set_number('4440702')->is_valid_number, '愛知県西尾市寺部町');
ok($zip->set_number('4440703')->is_valid_number, '愛知県西尾市西幡豆町');
ok($zip->set_number('4440704')->is_valid_number, '愛知県西尾市鳥羽町');
ok($zip->set_number('4440801')->is_valid_number, '愛知県岡崎市美合新町');
ok($zip->set_number('4440802')->is_valid_number, '愛知県岡崎市美合町');
ok($zip->set_number('4440803')->is_valid_number, '愛知県岡崎市美合町入込');
ok($zip->set_number('4440804')->is_valid_number, '愛知県岡崎市美合町生田');
ok($zip->set_number('4440805')->is_valid_number, '愛知県岡崎市美合町地蔵野');
ok($zip->set_number('4440806')->is_valid_number, '愛知県岡崎市緑丘');
ok($zip->set_number('4440807')->is_valid_number, '愛知県岡崎市美合西町');
ok($zip->set_number('4440811')->is_valid_number, '愛知県岡崎市大西町');
ok($zip->set_number('4440812')->is_valid_number, '愛知県岡崎市大西町南ケ原');
ok($zip->set_number('4440813')->is_valid_number, '愛知県岡崎市羽根町');
ok($zip->set_number('4440814')->is_valid_number, '愛知県岡崎市羽根町小豆坂');
ok($zip->set_number('4440815')->is_valid_number, '愛知県岡崎市羽根町陣場');
ok($zip->set_number('4440816')->is_valid_number, '愛知県岡崎市羽根町大池');
ok($zip->set_number('4440817')->is_valid_number, '愛知県岡崎市不吹町');
ok($zip->set_number('4440821')->is_valid_number, '愛知県岡崎市庄司田');
ok($zip->set_number('4440822')->is_valid_number, '愛知県岡崎市若松東');
ok($zip->set_number('4440823')->is_valid_number, '愛知県岡崎市上地');
ok($zip->set_number('4440824')->is_valid_number, '愛知県岡崎市上地町');
ok($zip->set_number('4440825')->is_valid_number, '愛知県岡崎市福岡町');
ok($zip->set_number('4440826')->is_valid_number, '愛知県岡崎市若松町');
ok($zip->set_number('4440827')->is_valid_number, '愛知県岡崎市針崎町');
ok($zip->set_number('4440828')->is_valid_number, '愛知県岡崎市針崎');
ok($zip->set_number('4440831')->is_valid_number, '愛知県岡崎市羽根北町');
ok($zip->set_number('4440832')->is_valid_number, '愛知県岡崎市羽根東町');
ok($zip->set_number('4440833')->is_valid_number, '愛知県岡崎市柱曙');
ok($zip->set_number('4440834')->is_valid_number, '愛知県岡崎市柱町');
ok($zip->set_number('4440835')->is_valid_number, '愛知県岡崎市城南町');
ok($zip->set_number('4440836')->is_valid_number, '愛知県岡崎市中田町');
ok($zip->set_number('4440837')->is_valid_number, '愛知県岡崎市柱');
ok($zip->set_number('4440838')->is_valid_number, '愛知県岡崎市羽根西');
ok($zip->set_number('4440839')->is_valid_number, '愛知県岡崎市羽根西新町');
ok($zip->set_number('4440840')->is_valid_number, '愛知県岡崎市戸崎町');
ok($zip->set_number('4440841')->is_valid_number, '愛知県岡崎市戸崎町藤狭');
ok($zip->set_number('4440842')->is_valid_number, '愛知県岡崎市戸崎元町');
ok($zip->set_number('4440843')->is_valid_number, '愛知県岡崎市江口');
ok($zip->set_number('4440844')->is_valid_number, '愛知県岡崎市天白町');
ok($zip->set_number('4440845')->is_valid_number, '愛知県岡崎市六名南');
ok($zip->set_number('4440846')->is_valid_number, '愛知県岡崎市六名新町');
ok($zip->set_number('4440847')->is_valid_number, '愛知県岡崎市六名東町');
ok($zip->set_number('4440848')->is_valid_number, '愛知県岡崎市向山町');
ok($zip->set_number('4440849')->is_valid_number, '愛知県岡崎市戸崎新町');
ok($zip->set_number('4440851')->is_valid_number, '愛知県岡崎市久後崎町');
ok($zip->set_number('4440852')->is_valid_number, '愛知県岡崎市南明大寺町');
ok($zip->set_number('4440853')->is_valid_number, '愛知県岡崎市三崎町');
ok($zip->set_number('4440854')->is_valid_number, '愛知県岡崎市六名本町');
ok($zip->set_number('4440855')->is_valid_number, '愛知県岡崎市真宮町');
ok($zip->set_number('4440856')->is_valid_number, '愛知県岡崎市六名');
ok($zip->set_number('4440857')->is_valid_number, '愛知県岡崎市六名町');
ok($zip->set_number('4440858')->is_valid_number, '愛知県岡崎市上六名');
ok($zip->set_number('4440859')->is_valid_number, '愛知県岡崎市上六名町');
ok($zip->set_number('4440860')->is_valid_number, '愛知県岡崎市明大寺本町');
ok($zip->set_number('4440861')->is_valid_number, '愛知県岡崎市上明大寺町');
ok($zip->set_number('4440862')->is_valid_number, '愛知県岡崎市吹矢町');
ok($zip->set_number('4440863')->is_valid_number, '愛知県岡崎市東明大寺町');
ok($zip->set_number('4440864')->is_valid_number, '愛知県岡崎市明大寺町(その他)');
ok($zip->set_number('4440865')->is_valid_number, '愛知県岡崎市明大寺町大圦');
ok($zip->set_number('4440866')->is_valid_number, '愛知県岡崎市明大寺町(仲ケ入)');
ok($zip->set_number('4440867')->is_valid_number, '愛知県岡崎市明大寺町(西郷中)');
ok($zip->set_number('4440868')->is_valid_number, '愛知県岡崎市明大寺町(馬場東)');
ok($zip->set_number('4440869')->is_valid_number, '愛知県岡崎市明大寺町(出口)');
ok($zip->set_number('4440870')->is_valid_number, '愛知県岡崎市竜美大入町');
ok($zip->set_number('4440871')->is_valid_number, '愛知県岡崎市大西');
ok($zip->set_number('4440872')->is_valid_number, '愛知県岡崎市竜美新町');
ok($zip->set_number('4440873')->is_valid_number, '愛知県岡崎市竜美台');
ok($zip->set_number('4440874')->is_valid_number, '愛知県岡崎市竜美南');
ok($zip->set_number('4440875')->is_valid_number, '愛知県岡崎市竜美西');
ok($zip->set_number('4440876')->is_valid_number, '愛知県岡崎市竜美北');
ok($zip->set_number('4440877')->is_valid_number, '愛知県岡崎市竜美旭町');
ok($zip->set_number('4440878')->is_valid_number, '愛知県岡崎市竜美東');
ok($zip->set_number('4440879')->is_valid_number, '愛知県岡崎市竜美中');
ok($zip->set_number('4440901')->is_valid_number, '愛知県岡崎市森越町');
ok($zip->set_number('4440902')->is_valid_number, '愛知県岡崎市舳越町');
ok($zip->set_number('4440903')->is_valid_number, '愛知県岡崎市東大友町');
ok($zip->set_number('4440904')->is_valid_number, '愛知県岡崎市西大友町');
ok($zip->set_number('4440905')->is_valid_number, '愛知県岡崎市宇頭町');
ok($zip->set_number('4440906')->is_valid_number, '愛知県岡崎市宇頭北町');
ok($zip->set_number('4440907')->is_valid_number, '愛知県岡崎市小針町');
ok($zip->set_number('4440908')->is_valid_number, '愛知県岡崎市橋目町');
ok($zip->set_number('4440909')->is_valid_number, '愛知県岡崎市橋目町御小屋西');
ok($zip->set_number('4440911')->is_valid_number, '愛知県岡崎市日名北町');
ok($zip->set_number('4440912')->is_valid_number, '愛知県岡崎市井田西町');
ok($zip->set_number('4440913')->is_valid_number, '愛知県岡崎市葵町');
ok($zip->set_number('4440914')->is_valid_number, '愛知県岡崎市末広町');
ok($zip->set_number('4440915')->is_valid_number, '愛知県岡崎市日名南町');
ok($zip->set_number('4440916')->is_valid_number, '愛知県岡崎市日名本町');
ok($zip->set_number('4440917')->is_valid_number, '愛知県岡崎市日名西町');
ok($zip->set_number('4440918')->is_valid_number, '愛知県岡崎市日名中町');
ok($zip->set_number('4440921')->is_valid_number, '愛知県岡崎市中岡崎町');
ok($zip->set_number('4440922')->is_valid_number, '愛知県岡崎市八帖南町');
ok($zip->set_number('4440923')->is_valid_number, '愛知県岡崎市八帖町');
ok($zip->set_number('4440924')->is_valid_number, '愛知県岡崎市八帖北町');
ok($zip->set_number('4440925')->is_valid_number, '愛知県岡崎市八丁町');
ok($zip->set_number('4440931')->is_valid_number, '愛知県岡崎市大和町');
ok($zip->set_number('4440932')->is_valid_number, '愛知県岡崎市筒針町');
ok($zip->set_number('4440933')->is_valid_number, '愛知県岡崎市渡町');
ok($zip->set_number('4440934')->is_valid_number, '愛知県岡崎市東牧内町');
ok($zip->set_number('4440935')->is_valid_number, '愛知県岡崎市下佐々木町');
ok($zip->set_number('4440936')->is_valid_number, '愛知県岡崎市上佐々木町');
ok($zip->set_number('4440937')->is_valid_number, '愛知県岡崎市島坂町');
ok($zip->set_number('4440938')->is_valid_number, '愛知県岡崎市昭和町');
ok($zip->set_number('4440939')->is_valid_number, '愛知県岡崎市新堀町');
ok($zip->set_number('4440941')->is_valid_number, '愛知県岡崎市暮戸町');
ok($zip->set_number('4440942')->is_valid_number, '愛知県岡崎市中園町');
ok($zip->set_number('4440943')->is_valid_number, '愛知県岡崎市矢作町');
ok($zip->set_number('4440944')->is_valid_number, '愛知県岡崎市北本郷町');
ok($zip->set_number('4440945')->is_valid_number, '愛知県岡崎市東本郷町');
ok($zip->set_number('4440946')->is_valid_number, '愛知県岡崎市富永町');
ok($zip->set_number('4440947')->is_valid_number, '愛知県岡崎市西本郷町');
ok($zip->set_number('4440948')->is_valid_number, '愛知県岡崎市西本郷町和志山');
ok($zip->set_number('4440949')->is_valid_number, '愛知県岡崎市宇頭南町');
ok($zip->set_number('4440950')->is_valid_number, '愛知県岡崎市宇頭東町');
ok($zip->set_number('4440951')->is_valid_number, '愛知県岡崎市北野町');
ok($zip->set_number('4441151')->is_valid_number, '愛知県安城市村高町');
ok($zip->set_number('4441152')->is_valid_number, '愛知県安城市川島町');
ok($zip->set_number('4441153')->is_valid_number, '愛知県安城市東町');
ok($zip->set_number('4441154')->is_valid_number, '愛知県安城市桜井町');
ok($zip->set_number('4441155')->is_valid_number, '愛知県安城市堀内町');
ok($zip->set_number('4441161')->is_valid_number, '愛知県安城市姫小川町');
ok($zip->set_number('4441162')->is_valid_number, '愛知県安城市小川町');
ok($zip->set_number('4441163')->is_valid_number, '愛知県安城市木戸町');
ok($zip->set_number('4441164')->is_valid_number, '愛知県安城市藤井町');
ok($zip->set_number('4441165')->is_valid_number, '愛知県安城市野寺町');
ok($zip->set_number('4441166')->is_valid_number, '愛知県安城市寺領町');
ok($zip->set_number('4441201')->is_valid_number, '愛知県安城市石井町');
ok($zip->set_number('4441202')->is_valid_number, '愛知県安城市城ケ入町(団戸)');
ok($zip->set_number('4441203')->is_valid_number, '愛知県安城市城ケ入町(立出)');
ok($zip->set_number('4441204')->is_valid_number, '愛知県安城市城ケ入町(北立出)');
ok($zip->set_number('4441205')->is_valid_number, '愛知県安城市城ケ入町(広見)');
ok($zip->set_number('4441206')->is_valid_number, '愛知県安城市城ケ入町');
ok($zip->set_number('4441211')->is_valid_number, '愛知県安城市根崎町');
ok($zip->set_number('4441212')->is_valid_number, '愛知県安城市根崎町(北根)');
ok($zip->set_number('4441213')->is_valid_number, '愛知県安城市東端町');
ok($zip->set_number('4441214')->is_valid_number, '愛知県安城市榎前町');
ok($zip->set_number('4441215')->is_valid_number, '愛知県安城市榎前町(井杭山)');
ok($zip->set_number('4441221')->is_valid_number, '愛知県安城市和泉町');
ok($zip->set_number('4441222')->is_valid_number, '愛知県安城市和泉町(大海古)');
ok($zip->set_number('4441223')->is_valid_number, '愛知県安城市和泉町(北大木)');
ok($zip->set_number('4441224')->is_valid_number, '愛知県安城市和泉町(八兵エ)');
ok($zip->set_number('4441225')->is_valid_number, '愛知県安城市和泉町(井上)');
ok($zip->set_number('4441300')->is_valid_number, '愛知県高浜市以下に掲載がない場合');
ok($zip->set_number('4441301')->is_valid_number, '愛知県高浜市新田町');
ok($zip->set_number('4441302')->is_valid_number, '愛知県高浜市八幡町');
ok($zip->set_number('4441303')->is_valid_number, '愛知県高浜市小池町');
ok($zip->set_number('4441304')->is_valid_number, '愛知県高浜市豊田町');
ok($zip->set_number('4441305')->is_valid_number, '愛知県高浜市神明町');
ok($zip->set_number('4441311')->is_valid_number, '愛知県高浜市本郷町');
ok($zip->set_number('4441312')->is_valid_number, '愛知県高浜市清水町');
ok($zip->set_number('4441313')->is_valid_number, '愛知県高浜市向山町');
ok($zip->set_number('4441314')->is_valid_number, '愛知県高浜市論地町');
ok($zip->set_number('4441321')->is_valid_number, '愛知県高浜市稗田町');
ok($zip->set_number('4441322')->is_valid_number, '愛知県高浜市二池町');
ok($zip->set_number('4441323')->is_valid_number, '愛知県高浜市田戸町');
ok($zip->set_number('4441324')->is_valid_number, '愛知県高浜市碧海町');
ok($zip->set_number('4441325')->is_valid_number, '愛知県高浜市青木町');
ok($zip->set_number('4441331')->is_valid_number, '愛知県高浜市屋敷町');
ok($zip->set_number('4441332')->is_valid_number, '愛知県高浜市湯山町');
ok($zip->set_number('4441333')->is_valid_number, '愛知県高浜市沢渡町');
ok($zip->set_number('4441334')->is_valid_number, '愛知県高浜市春日町');
ok($zip->set_number('4441335')->is_valid_number, '愛知県高浜市芳川町');
ok($zip->set_number('4441336')->is_valid_number, '愛知県高浜市呉竹町');
ok($zip->set_number('4442101')->is_valid_number, '愛知県岡崎市川向町');
ok($zip->set_number('4442102')->is_valid_number, '愛知県岡崎市日影町');
ok($zip->set_number('4442103')->is_valid_number, '愛知県岡崎市渡通津町');
ok($zip->set_number('4442104')->is_valid_number, '愛知県岡崎市駒立町');
ok($zip->set_number('4442105')->is_valid_number, '愛知県岡崎市丹坂町');
ok($zip->set_number('4442106')->is_valid_number, '愛知県岡崎市真福寺町');
ok($zip->set_number('4442107')->is_valid_number, '愛知県岡崎市恵田町');
ok($zip->set_number('4442108')->is_valid_number, '愛知県岡崎市奥殿町');
ok($zip->set_number('4442109')->is_valid_number, '愛知県岡崎市宮石町');
ok($zip->set_number('4442111')->is_valid_number, '愛知県岡崎市西阿知和町');
ok($zip->set_number('4442112')->is_valid_number, '愛知県岡崎市東阿知和町');
ok($zip->set_number('4442113')->is_valid_number, '愛知県岡崎市松橋町');
ok($zip->set_number('4442114')->is_valid_number, '愛知県岡崎市堂前町');
ok($zip->set_number('4442115')->is_valid_number, '愛知県岡崎市百々町');
ok($zip->set_number('4442116')->is_valid_number, '愛知県岡崎市寿町');
ok($zip->set_number('4442117')->is_valid_number, '愛知県岡崎市百々西町');
ok($zip->set_number('4442118')->is_valid_number, '愛知県岡崎市河原町');
ok($zip->set_number('4442121')->is_valid_number, '愛知県岡崎市鴨田町');
ok($zip->set_number('4442122')->is_valid_number, '愛知県岡崎市鴨田本町');
ok($zip->set_number('4442123')->is_valid_number, '愛知県岡崎市鴨田南町');
ok($zip->set_number('4442131')->is_valid_number, '愛知県岡崎市青木町');
ok($zip->set_number('4442132')->is_valid_number, '愛知県岡崎市井ノ口新町');
ok($zip->set_number('4442133')->is_valid_number, '愛知県岡崎市井ノ口町');
ok($zip->set_number('4442134')->is_valid_number, '愛知県岡崎市大樹寺');
ok($zip->set_number('4442135')->is_valid_number, '愛知県岡崎市大門');
ok($zip->set_number('4442136')->is_valid_number, '愛知県岡崎市上里');
ok($zip->set_number('4442137')->is_valid_number, '愛知県岡崎市薮田');
ok($zip->set_number('4442141')->is_valid_number, '愛知県岡崎市桑原町');
ok($zip->set_number('4442142')->is_valid_number, '愛知県岡崎市奥山田町');
ok($zip->set_number('4442143')->is_valid_number, '愛知県岡崎市八ツ木町');
ok($zip->set_number('4442144')->is_valid_number, '愛知県岡崎市岩津町');
ok($zip->set_number('4442145')->is_valid_number, '愛知県岡崎市東蔵前');
ok($zip->set_number('4442146')->is_valid_number, '愛知県岡崎市東蔵前町');
ok($zip->set_number('4442147')->is_valid_number, '愛知県岡崎市西蔵前町');
ok($zip->set_number('4442148')->is_valid_number, '愛知県岡崎市仁木町');
ok($zip->set_number('4442149')->is_valid_number, '愛知県岡崎市細川町');
ok($zip->set_number('4442201')->is_valid_number, '愛知県豊田市坂上町');
ok($zip->set_number('4442202')->is_valid_number, '愛知県豊田市松平町');
ok($zip->set_number('4442203')->is_valid_number, '愛知県豊田市豊松町');
ok($zip->set_number('4442204')->is_valid_number, '愛知県豊田市鵜ケ瀬町');
ok($zip->set_number('4442205')->is_valid_number, '愛知県豊田市鍋田町');
ok($zip->set_number('4442206')->is_valid_number, '愛知県豊田市王滝町');
ok($zip->set_number('4442207')->is_valid_number, '愛知県豊田市石楠町');
ok($zip->set_number('4442211')->is_valid_number, '愛知県豊田市長沢町');
ok($zip->set_number('4442212')->is_valid_number, '愛知県豊田市滝脇町');
ok($zip->set_number('4442213')->is_valid_number, '愛知県豊田市加茂川町');
ok($zip->set_number('4442214')->is_valid_number, '愛知県豊田市桂野町');
ok($zip->set_number('4442215')->is_valid_number, '愛知県豊田市中垣内町');
ok($zip->set_number('4442216')->is_valid_number, '愛知県豊田市九久平町');
ok($zip->set_number('4442217')->is_valid_number, '愛知県豊田市大内町');
ok($zip->set_number('4442218')->is_valid_number, '愛知県豊田市林添町');
ok($zip->set_number('4442221')->is_valid_number, '愛知県豊田市幸海町');
ok($zip->set_number('4442222')->is_valid_number, '愛知県豊田市穂積町');
ok($zip->set_number('4442223')->is_valid_number, '愛知県豊田市松平志賀町');
ok($zip->set_number('4442224')->is_valid_number, '愛知県豊田市巴町');
ok($zip->set_number('4442225')->is_valid_number, '愛知県豊田市岩倉町');
ok($zip->set_number('4442226')->is_valid_number, '愛知県豊田市幸穂台');
ok($zip->set_number('4442301')->is_valid_number, '愛知県豊田市東川端町');
ok($zip->set_number('4442302')->is_valid_number, '愛知県豊田市戸中町');
ok($zip->set_number('4442303')->is_valid_number, '愛知県豊田市野林町');
ok($zip->set_number('4442311')->is_valid_number, '愛知県豊田市沢ノ堂町');
ok($zip->set_number('4442312')->is_valid_number, '愛知県豊田市四ツ松町');
ok($zip->set_number('4442313')->is_valid_number, '愛知県豊田市冷田町');
ok($zip->set_number('4442314')->is_valid_number, '愛知県豊田市上小田町');
ok($zip->set_number('4442321')->is_valid_number, '愛知県豊田市下国谷町');
ok($zip->set_number('4442324')->is_valid_number, '愛知県豊田市栃本町');
ok($zip->set_number('4442325')->is_valid_number, '愛知県豊田市桑原田町');
ok($zip->set_number('4442326')->is_valid_number, '愛知県豊田市国谷町');
ok($zip->set_number('4442327')->is_valid_number, '愛知県豊田市白倉町');
ok($zip->set_number('4442331')->is_valid_number, '愛知県豊田市岩谷町');
ok($zip->set_number('4442332')->is_valid_number, '愛知県豊田市下平町');
ok($zip->set_number('4442333')->is_valid_number, '愛知県豊田市平折町');
ok($zip->set_number('4442334')->is_valid_number, '愛知県豊田市国閑町');
ok($zip->set_number('4442335')->is_valid_number, '愛知県豊田市上脇町');
ok($zip->set_number('4442336')->is_valid_number, '愛知県豊田市下佐切町');
ok($zip->set_number('4442337')->is_valid_number, '愛知県豊田市上佐切町');
ok($zip->set_number('4442342')->is_valid_number, '愛知県豊田市則定町');
ok($zip->set_number('4442343')->is_valid_number, '愛知県豊田市霧山町');
ok($zip->set_number('4442344')->is_valid_number, '愛知県豊田市東大島町');
ok($zip->set_number('4442351')->is_valid_number, '愛知県豊田市岩神町(その他)');
ok($zip->set_number('4442352')->is_valid_number, '愛知県豊田市篭林町');
ok($zip->set_number('4442353')->is_valid_number, '愛知県豊田市田振町');
ok($zip->set_number('4442354')->is_valid_number, '愛知県豊田市井ノ口町');
ok($zip->set_number('4442355')->is_valid_number, '愛知県豊田市近岡町');
ok($zip->set_number('4442401')->is_valid_number, '愛知県豊田市二タ宮町');
ok($zip->set_number('4442402')->is_valid_number, '愛知県豊田市竜岡町');
ok($zip->set_number('4442403')->is_valid_number, '愛知県豊田市川面町');
ok($zip->set_number('4442404')->is_valid_number, '愛知県豊田市怒田沢町');
ok($zip->set_number('4442405')->is_valid_number, '愛知県豊田市大蔵連町');
ok($zip->set_number('4442406')->is_valid_number, '愛知県豊田市漆畑町');
ok($zip->set_number('4442407')->is_valid_number, '愛知県豊田市桑田和町');
ok($zip->set_number('4442409')->is_valid_number, '愛知県豊田市菅生町');
ok($zip->set_number('4442411')->is_valid_number, '愛知県豊田市御内町');
ok($zip->set_number('4442412')->is_valid_number, '愛知県豊田市山ノ中立町');
ok($zip->set_number('4442413')->is_valid_number, '愛知県豊田市東大見町');
ok($zip->set_number('4442414')->is_valid_number, '愛知県豊田市葛沢町');
ok($zip->set_number('4442415')->is_valid_number, '愛知県豊田市山谷町');
ok($zip->set_number('4442416')->is_valid_number, '愛知県豊田市有洞町');
ok($zip->set_number('4442417')->is_valid_number, '愛知県豊田市室口町');
ok($zip->set_number('4442418')->is_valid_number, '愛知県豊田市綾渡町');
ok($zip->set_number('4442419')->is_valid_number, '愛知県豊田市椿立町');
ok($zip->set_number('4442423')->is_valid_number, '愛知県豊田市安実京町');
ok($zip->set_number('4442424')->is_valid_number, '愛知県豊田市足助町');
ok($zip->set_number('4442451')->is_valid_number, '愛知県豊田市岩神町(足助高等学校)');
ok($zip->set_number('4442501')->is_valid_number, '愛知県豊田市大井町');
ok($zip->set_number('4442502')->is_valid_number, '愛知県豊田市北小田町');
ok($zip->set_number('4442503')->is_valid_number, '愛知県豊田市細田町');
ok($zip->set_number('4442504')->is_valid_number, '愛知県豊田市永野町');
ok($zip->set_number('4442505')->is_valid_number, '愛知県豊田市新盛町');
ok($zip->set_number('4442506')->is_valid_number, '愛知県豊田市久木町');
ok($zip->set_number('4442510')->is_valid_number, '愛知県豊田市富岡町');
ok($zip->set_number('4442511')->is_valid_number, '愛知県豊田市大蔵町');
ok($zip->set_number('4442512')->is_valid_number, '愛知県豊田市東中山町');
ok($zip->set_number('4442513')->is_valid_number, '愛知県豊田市足助白山町');
ok($zip->set_number('4442514')->is_valid_number, '愛知県豊田市栃ノ沢町');
ok($zip->set_number('4442515')->is_valid_number, '愛知県豊田市大塚町');
ok($zip->set_number('4442516')->is_valid_number, '愛知県豊田市塩ノ沢町');
ok($zip->set_number('4442517')->is_valid_number, '愛知県豊田市中立町');
ok($zip->set_number('4442521')->is_valid_number, '愛知県豊田市小町');
ok($zip->set_number('4442522')->is_valid_number, '愛知県豊田市御蔵町');
ok($zip->set_number('4442523')->is_valid_number, '愛知県豊田市実栗町');
ok($zip->set_number('4442524')->is_valid_number, '愛知県豊田市摺町');
ok($zip->set_number('4442525')->is_valid_number, '愛知県豊田市大河原町');
ok($zip->set_number('4442526')->is_valid_number, '愛知県豊田市葛町');
ok($zip->set_number('4442527')->is_valid_number, '愛知県豊田市月原町');
ok($zip->set_number('4442528')->is_valid_number, '愛知県豊田市東渡合町');
ok($zip->set_number('4442531')->is_valid_number, '愛知県豊田市上切山町');
ok($zip->set_number('4442532')->is_valid_number, '愛知県豊田市西樫尾町');
ok($zip->set_number('4442533')->is_valid_number, '愛知県豊田市小手沢町');
ok($zip->set_number('4442601')->is_valid_number, '愛知県豊田市明川町');
ok($zip->set_number('4442602')->is_valid_number, '愛知県豊田市連谷町');
ok($zip->set_number('4442603')->is_valid_number, '愛知県豊田市大多賀町');
ok($zip->set_number('4442604')->is_valid_number, '愛知県豊田市上八木町');
ok($zip->set_number('4442605')->is_valid_number, '愛知県豊田市玉野町');
ok($zip->set_number('4442606')->is_valid_number, '愛知県豊田市千田町');
ok($zip->set_number('4442607')->is_valid_number, '愛知県豊田市平沢町');
ok($zip->set_number('4442608')->is_valid_number, '愛知県豊田市五反田町');
ok($zip->set_number('4442801')->is_valid_number, '愛知県豊田市牛地町');
ok($zip->set_number('4442802')->is_valid_number, '愛知県豊田市田津原町');
ok($zip->set_number('4442803')->is_valid_number, '愛知県豊田市坪崎町');
ok($zip->set_number('4442804')->is_valid_number, '愛知県豊田市日下部町');
ok($zip->set_number('4442805')->is_valid_number, '愛知県豊田市小畑町');
ok($zip->set_number('4442806')->is_valid_number, '愛知県豊田市惣田町');
ok($zip->set_number('4442807')->is_valid_number, '愛知県豊田市伊熊町');
ok($zip->set_number('4442808')->is_valid_number, '愛知県豊田市槇本町');
ok($zip->set_number('4442809')->is_valid_number, '愛知県豊田市小滝野町');
ok($zip->set_number('4442811')->is_valid_number, '愛知県豊田市太田町');
ok($zip->set_number('4442812')->is_valid_number, '愛知県豊田市押井町');
ok($zip->set_number('4442813')->is_valid_number, '愛知県豊田市加塩町');
ok($zip->set_number('4442814')->is_valid_number, '愛知県豊田市榊野町');
ok($zip->set_number('4442815')->is_valid_number, '愛知県豊田市万根町');
ok($zip->set_number('4442816')->is_valid_number, '愛知県豊田市杉本町');
ok($zip->set_number('4442817')->is_valid_number, '愛知県豊田市明賀町');
ok($zip->set_number('4442821')->is_valid_number, '愛知県豊田市小田町');
ok($zip->set_number('4442822')->is_valid_number, '愛知県豊田市大坪町');
ok($zip->set_number('4442823')->is_valid_number, '愛知県豊田市東萩平町');
ok($zip->set_number('4442824')->is_valid_number, '愛知県豊田市池島町');
ok($zip->set_number('4442825')->is_valid_number, '愛知県豊田市市平町');
ok($zip->set_number('4442826')->is_valid_number, '愛知県豊田市笹戸町');
ok($zip->set_number('4442827')->is_valid_number, '愛知県豊田市有間町');
ok($zip->set_number('4442831')->is_valid_number, '愛知県豊田市須渕町');
ok($zip->set_number('4442832')->is_valid_number, '愛知県豊田市浅谷町');
ok($zip->set_number('4442833')->is_valid_number, '愛知県豊田市下切町');
ok($zip->set_number('4442834')->is_valid_number, '愛知県豊田市島崎町');
ok($zip->set_number('4442835')->is_valid_number, '愛知県豊田市上中町');
ok($zip->set_number('4442836')->is_valid_number, '愛知県豊田市上切町');
ok($zip->set_number('4442837')->is_valid_number, '愛知県豊田市一色町');
ok($zip->set_number('4442838')->is_valid_number, '愛知県豊田市下中町');
ok($zip->set_number('4442839')->is_valid_number, '愛知県豊田市三分山町');
ok($zip->set_number('4442841')->is_valid_number, '愛知県豊田市閑羅瀬町');
ok($zip->set_number('4442842')->is_valid_number, '愛知県豊田市余平町');
ok($zip->set_number('4442843')->is_valid_number, '愛知県豊田市旭八幡町');
ok($zip->set_number('4442844')->is_valid_number, '愛知県豊田市伯母沢町');
ok($zip->set_number('4442845')->is_valid_number, '愛知県豊田市万町町');
ok($zip->set_number('4442846')->is_valid_number, '愛知県豊田市小渡町');
ok($zip->set_number('4442847')->is_valid_number, '愛知県豊田市時瀬町');
ok($zip->set_number('4443151')->is_valid_number, '愛知県岡崎市箱柳町(中立)');
ok($zip->set_number('4443161')->is_valid_number, '愛知県岡崎市大柳町');
ok($zip->set_number('4443162')->is_valid_number, '愛知県岡崎市新居町');
ok($zip->set_number('4443163')->is_valid_number, '愛知県岡崎市小丸町');
ok($zip->set_number('4443164')->is_valid_number, '愛知県岡崎市蔵次町');
ok($zip->set_number('4443165')->is_valid_number, '愛知県岡崎市岩中町');
ok($zip->set_number('4443166')->is_valid_number, '愛知県岡崎市大井野町');
ok($zip->set_number('4443167')->is_valid_number, '愛知県岡崎市米河内町');
ok($zip->set_number('4443168')->is_valid_number, '愛知県岡崎市安戸町');
ok($zip->set_number('4443171')->is_valid_number, '愛知県岡崎市板田町');
ok($zip->set_number('4443172')->is_valid_number, '愛知県岡崎市田口町');
ok($zip->set_number('4443173')->is_valid_number, '愛知県岡崎市滝町');
ok($zip->set_number('4443174')->is_valid_number, '愛知県岡崎市真伝町');
ok($zip->set_number('4443175')->is_valid_number, '愛知県岡崎市真伝');
ok($zip->set_number('4443176')->is_valid_number, '愛知県岡崎市真伝吉祥');
ok($zip->set_number('4443201')->is_valid_number, '愛知県豊田市梨野町');
ok($zip->set_number('4443202')->is_valid_number, '愛知県豊田市阿蔵町');
ok($zip->set_number('4443203')->is_valid_number, '愛知県豊田市宇連野町');
ok($zip->set_number('4443205')->is_valid_number, '愛知県豊田市野原町');
ok($zip->set_number('4443206')->is_valid_number, '愛知県豊田市羽布町');
ok($zip->set_number('4443207')->is_valid_number, '愛知県豊田市大桑町');
ok($zip->set_number('4443208')->is_valid_number, '愛知県豊田市高野町');
ok($zip->set_number('4443211')->is_valid_number, '愛知県豊田市和合町');
ok($zip->set_number('4443212')->is_valid_number, '愛知県豊田市黒坂町');
ok($zip->set_number('4443213')->is_valid_number, '愛知県豊田市小松野町');
ok($zip->set_number('4443216')->is_valid_number, '愛知県豊田市蘭町');
ok($zip->set_number('4443221')->is_valid_number, '愛知県豊田市田折町');
ok($zip->set_number('4443222')->is_valid_number, '愛知県豊田市下山田代町');
ok($zip->set_number('4443223')->is_valid_number, '愛知県豊田市蕪木町');
ok($zip->set_number('4443231')->is_valid_number, '愛知県豊田市花沢町');
ok($zip->set_number('4443242')->is_valid_number, '愛知県豊田市大沼町');
ok($zip->set_number('4443251')->is_valid_number, '愛知県豊田市平瀬町');
ok($zip->set_number('4443252')->is_valid_number, '愛知県豊田市神殿町');
ok($zip->set_number('4443261')->is_valid_number, '愛知県豊田市東大林町');
ok($zip->set_number('4443262')->is_valid_number, '愛知県豊田市立岩町');
ok($zip->set_number('4443264')->is_valid_number, '愛知県豊田市栃立町');
ok($zip->set_number('4443265')->is_valid_number, '愛知県豊田市田平沢町');
ok($zip->set_number('4443331')->is_valid_number, '愛知県岡崎市古部町');
ok($zip->set_number('4443332')->is_valid_number, '愛知県岡崎市切越町');
ok($zip->set_number('4443333')->is_valid_number, '愛知県岡崎市蓬生町');
ok($zip->set_number('4443334')->is_valid_number, '愛知県岡崎市生平町');
ok($zip->set_number('4443335')->is_valid_number, '愛知県岡崎市茅原沢町');
ok($zip->set_number('4443341')->is_valid_number, '愛知県岡崎市須淵町');
ok($zip->set_number('4443342')->is_valid_number, '愛知県岡崎市才栗町');
ok($zip->set_number('4443343')->is_valid_number, '愛知県岡崎市秦梨町');
ok($zip->set_number('4443344')->is_valid_number, '愛知県岡崎市岩戸町');
ok($zip->set_number('4443431')->is_valid_number, '愛知県岡崎市切山町');
ok($zip->set_number('4443432')->is_valid_number, '愛知県岡崎市千万町町');
ok($zip->set_number('4443433')->is_valid_number, '愛知県岡崎市木下町');
ok($zip->set_number('4443434')->is_valid_number, '愛知県岡崎市井沢町');
ok($zip->set_number('4443435')->is_valid_number, '愛知県岡崎市桜形町');
ok($zip->set_number('4443436')->is_valid_number, '愛知県岡崎市小久田町');
ok($zip->set_number('4443437')->is_valid_number, '愛知県岡崎市毛呂町');
ok($zip->set_number('4443441')->is_valid_number, '愛知県岡崎市冨尾町');
ok($zip->set_number('4443442')->is_valid_number, '愛知県岡崎市保久町');
ok($zip->set_number('4443443')->is_valid_number, '愛知県岡崎市鍛埜町');
ok($zip->set_number('4443444')->is_valid_number, '愛知県岡崎市南大須町');
ok($zip->set_number('4443445')->is_valid_number, '愛知県岡崎市大高味町');
ok($zip->set_number('4443446')->is_valid_number, '愛知県岡崎市中伊町');
ok($zip->set_number('4443447')->is_valid_number, '愛知県岡崎市一色町');
ok($zip->set_number('4443448')->is_valid_number, '愛知県岡崎市外山町');
ok($zip->set_number('4443449')->is_valid_number, '愛知県岡崎市中伊西町');
ok($zip->set_number('4443501')->is_valid_number, '愛知県岡崎市池金町');
ok($zip->set_number('4443502')->is_valid_number, '愛知県岡崎市大幡町');
ok($zip->set_number('4443503')->is_valid_number, '愛知県岡崎市鶇巣町');
ok($zip->set_number('4443504')->is_valid_number, '愛知県岡崎市上衣文町');
ok($zip->set_number('4443505')->is_valid_number, '愛知県岡崎市本宿町');
ok($zip->set_number('4443506')->is_valid_number, '愛知県岡崎市本宿西');
ok($zip->set_number('4443507')->is_valid_number, '愛知県岡崎市本宿台');
ok($zip->set_number('4443508')->is_valid_number, '愛知県岡崎市本宿茜');
ok($zip->set_number('4443511')->is_valid_number, '愛知県岡崎市舞木町');
ok($zip->set_number('4443512')->is_valid_number, '愛知県岡崎市鉢地町');
ok($zip->set_number('4443513')->is_valid_number, '愛知県岡崎市山綱町(その他)');
ok($zip->set_number('4443514')->is_valid_number, '愛知県岡崎市羽栗町');
ok($zip->set_number('4443515')->is_valid_number, '愛知県岡崎市桑谷町');
ok($zip->set_number('4443516')->is_valid_number, '愛知県岡崎市山綱町(丁目)');
ok($zip->set_number('4443521')->is_valid_number, '愛知県岡崎市市場町');
ok($zip->set_number('4443522')->is_valid_number, '愛知県岡崎市藤川台');
ok($zip->set_number('4443523')->is_valid_number, '愛知県岡崎市藤川町');
ok($zip->set_number('4443524')->is_valid_number, '愛知県岡崎市竜泉寺町');
ok($zip->set_number('4443525')->is_valid_number, '愛知県岡崎市蓑川町');
ok($zip->set_number('4443526')->is_valid_number, '愛知県岡崎市蓑川新町');
ok($zip->set_number('4443527')->is_valid_number, '愛知県岡崎市藤川荒古');
ok($zip->set_number('4443528')->is_valid_number, '愛知県岡崎市みはらし台');
ok($zip->set_number('4443601')->is_valid_number, '愛知県岡崎市石原町');
ok($zip->set_number('4443602')->is_valid_number, '愛知県岡崎市東河原町');
ok($zip->set_number('4443603')->is_valid_number, '愛知県岡崎市雨山町');
ok($zip->set_number('4443604')->is_valid_number, '愛知県岡崎市大代町');
ok($zip->set_number('4443605')->is_valid_number, '愛知県岡崎市中金町');
ok($zip->set_number('4443611')->is_valid_number, '愛知県岡崎市宮崎町');
ok($zip->set_number('4443612')->is_valid_number, '愛知県岡崎市明見町');
ok($zip->set_number('4443613')->is_valid_number, '愛知県岡崎市滝尻町');
ok($zip->set_number('4443614')->is_valid_number, '愛知県岡崎市鳥川町');
ok($zip->set_number('4443615')->is_valid_number, '愛知県岡崎市細光町');
ok($zip->set_number('4443616')->is_valid_number, '愛知県岡崎市片寄町');
ok($zip->set_number('4443617')->is_valid_number, '愛知県岡崎市淡渕町');
ok($zip->set_number('4443621')->is_valid_number, '愛知県岡崎市夏山町');
ok($zip->set_number('4443622')->is_valid_number, '愛知県岡崎市樫山町');
ok($zip->set_number('4443623')->is_valid_number, '愛知県岡崎市鹿勝川町');
ok($zip->set_number('4443624')->is_valid_number, '愛知県岡崎市牧平町');
ok($zip->set_number('4443625')->is_valid_number, '愛知県岡崎市下衣文町');
ok($zip->set_number('4443626')->is_valid_number, '愛知県岡崎市桜井寺町');
ok($zip->set_number('4450000')->is_valid_number, '愛知県西尾市以下に掲載がない場合');
ok($zip->set_number('4450001')->is_valid_number, '愛知県西尾市高落町');
ok($zip->set_number('4450002')->is_valid_number, '愛知県西尾市新村町');
ok($zip->set_number('4450003')->is_valid_number, '愛知県西尾市東浅井町');
ok($zip->set_number('4450004')->is_valid_number, '愛知県西尾市西浅井町');
ok($zip->set_number('4450005')->is_valid_number, '愛知県西尾市米野町');
ok($zip->set_number('4450006')->is_valid_number, '愛知県西尾市小島町');
ok($zip->set_number('4450011')->is_valid_number, '愛知県西尾市上羽角町');
ok($zip->set_number('4450012')->is_valid_number, '愛知県西尾市下羽角町');
ok($zip->set_number('4450013')->is_valid_number, '愛知県西尾市貝吹町');
ok($zip->set_number('4450014')->is_valid_number, '愛知県西尾市つくしが丘');
ok($zip->set_number('4450015')->is_valid_number, '愛知県西尾市竹山町');
ok($zip->set_number('4450016')->is_valid_number, '愛知県西尾市下永良町');
ok($zip->set_number('4450017')->is_valid_number, '愛知県西尾市上永良町');
ok($zip->set_number('4450021')->is_valid_number, '愛知県西尾市駒場町');
ok($zip->set_number('4450022')->is_valid_number, '愛知県西尾市岡島町');
ok($zip->set_number('4450023')->is_valid_number, '愛知県西尾市高河原町');
ok($zip->set_number('4450024')->is_valid_number, '愛知県西尾市大和田町');
ok($zip->set_number('4450025')->is_valid_number, '愛知県西尾市和気町');
ok($zip->set_number('4450026')->is_valid_number, '愛知県西尾市江原町');
ok($zip->set_number('4450027')->is_valid_number, '愛知県西尾市尾花町');
ok($zip->set_number('4450031')->is_valid_number, '愛知県西尾市家武町');
ok($zip->set_number('4450032')->is_valid_number, '愛知県西尾市平原町');
ok($zip->set_number('4450033')->is_valid_number, '愛知県西尾市室町');
ok($zip->set_number('4450034')->is_valid_number, '愛知県西尾市善明町');
ok($zip->set_number('4450035')->is_valid_number, '愛知県西尾市花蔵寺町');
ok($zip->set_number('4450041')->is_valid_number, '愛知県西尾市小焼野町');
ok($zip->set_number('4450042')->is_valid_number, '愛知県西尾市宅野島町');
ok($zip->set_number('4450043')->is_valid_number, '愛知県西尾市鵜ケ池町');
ok($zip->set_number('4450044')->is_valid_number, '愛知県西尾市鎌谷町');
ok($zip->set_number('4450045')->is_valid_number, '愛知県西尾市十郎島町');
ok($zip->set_number('4450046')->is_valid_number, '愛知県西尾市須脇町');
ok($zip->set_number('4450047')->is_valid_number, '愛知県西尾市細池町');
ok($zip->set_number('4450051')->is_valid_number, '愛知県西尾市天竹町');
ok($zip->set_number('4450052')->is_valid_number, '愛知県西尾市横手町');
ok($zip->set_number('4450053')->is_valid_number, '愛知県西尾市笹曽根町');
ok($zip->set_number('4450054')->is_valid_number, '愛知県西尾市平口町');
ok($zip->set_number('4450055')->is_valid_number, '愛知県西尾市市子町');
ok($zip->set_number('4450056')->is_valid_number, '愛知県西尾市斉藤町');
ok($zip->set_number('4450057')->is_valid_number, '愛知県西尾市野々宮町');
ok($zip->set_number('4450061')->is_valid_number, '愛知県西尾市寄近町');
ok($zip->set_number('4450062')->is_valid_number, '愛知県西尾市丁田町');
ok($zip->set_number('4450063')->is_valid_number, '愛知県西尾市今川町');
ok($zip->set_number('4450064')->is_valid_number, '愛知県西尾市高畠町');
ok($zip->set_number('4450065')->is_valid_number, '愛知県西尾市城崎町');
ok($zip->set_number('4450071')->is_valid_number, '愛知県西尾市熊味町');
ok($zip->set_number('4450072')->is_valid_number, '愛知県西尾市徳次町');
ok($zip->set_number('4450073')->is_valid_number, '愛知県西尾市寄住町');
ok($zip->set_number('4450074')->is_valid_number, '愛知県西尾市戸ケ崎町');
ok($zip->set_number('4450075')->is_valid_number, '愛知県西尾市戸ケ崎');
ok($zip->set_number('4450076')->is_valid_number, '愛知県西尾市新渡場');
ok($zip->set_number('4450077')->is_valid_number, '愛知県西尾市新渡場町');
ok($zip->set_number('4450081')->is_valid_number, '愛知県西尾市志籠谷町');
ok($zip->set_number('4450082')->is_valid_number, '愛知県西尾市八ツ面町');
ok($zip->set_number('4450083')->is_valid_number, '愛知県西尾市中原町');
ok($zip->set_number('4450084')->is_valid_number, '愛知県西尾市志貴野町');
ok($zip->set_number('4450801')->is_valid_number, '愛知県西尾市南中根町');
ok($zip->set_number('4450802')->is_valid_number, '愛知県西尾市米津町');
ok($zip->set_number('4450803')->is_valid_number, '愛知県西尾市桜町');
ok($zip->set_number('4450804')->is_valid_number, '愛知県西尾市緑町');
ok($zip->set_number('4450805')->is_valid_number, '愛知県西尾市鶴城町');
ok($zip->set_number('4450806')->is_valid_number, '愛知県西尾市伊藤町');
ok($zip->set_number('4450807')->is_valid_number, '愛知県西尾市伊藤');
ok($zip->set_number('4450811')->is_valid_number, '愛知県西尾市道光寺町');
ok($zip->set_number('4450812')->is_valid_number, '愛知県西尾市道光寺');
ok($zip->set_number('4450813')->is_valid_number, '愛知県西尾市若松町');
ok($zip->set_number('4450814')->is_valid_number, '愛知県西尾市新屋敷町');
ok($zip->set_number('4450815')->is_valid_number, '愛知県西尾市菅原町');
ok($zip->set_number('4450816')->is_valid_number, '愛知県西尾市宮町');
ok($zip->set_number('4450821')->is_valid_number, '愛知県西尾市矢場町');
ok($zip->set_number('4450822')->is_valid_number, '愛知県西尾市伊文町');
ok($zip->set_number('4450823')->is_valid_number, '愛知県西尾市神下町');
ok($zip->set_number('4450824')->is_valid_number, '愛知県西尾市和泉町');
ok($zip->set_number('4450825')->is_valid_number, '愛知県西尾市会生町');
ok($zip->set_number('4450826')->is_valid_number, '愛知県西尾市満全町');
ok($zip->set_number('4450827')->is_valid_number, '愛知県西尾市幸町');
ok($zip->set_number('4450831')->is_valid_number, '愛知県西尾市大給町');
ok($zip->set_number('4450832')->is_valid_number, '愛知県西尾市瓦町');
ok($zip->set_number('4450833')->is_valid_number, '愛知県西尾市天王町');
ok($zip->set_number('4450834')->is_valid_number, '愛知県西尾市順海町');
ok($zip->set_number('4450835')->is_valid_number, '愛知県西尾市肴町');
ok($zip->set_number('4450836')->is_valid_number, '愛知県西尾市中町');
ok($zip->set_number('4450837')->is_valid_number, '愛知県西尾市鶴ケ崎町');
ok($zip->set_number('4450841')->is_valid_number, '愛知県西尾市馬場町');
ok($zip->set_number('4450842')->is_valid_number, '愛知県西尾市弥生町');
ok($zip->set_number('4450843')->is_valid_number, '愛知県西尾市天神町');
ok($zip->set_number('4450844')->is_valid_number, '愛知県西尾市末広町');
ok($zip->set_number('4450845')->is_valid_number, '愛知県西尾市鶴舞町');
ok($zip->set_number('4450846')->is_valid_number, '愛知県西尾市千歳町');
ok($zip->set_number('4450847')->is_valid_number, '愛知県西尾市亀沢町');
ok($zip->set_number('4450851')->is_valid_number, '愛知県西尾市住吉町');
ok($zip->set_number('4450852')->is_valid_number, '愛知県西尾市花ノ木町');
ok($zip->set_number('4450853')->is_valid_number, '愛知県西尾市桜木町');
ok($zip->set_number('4450854')->is_valid_number, '愛知県西尾市永楽町');
ok($zip->set_number('4450855')->is_valid_number, '愛知県西尾市南旭町');
ok($zip->set_number('4450856')->is_valid_number, '愛知県西尾市高砂町');
ok($zip->set_number('4450857')->is_valid_number, '愛知県西尾市北旭町');
ok($zip->set_number('4450861')->is_valid_number, '愛知県西尾市吾妻町');
ok($zip->set_number('4450862')->is_valid_number, '愛知県西尾市須田町');
ok($zip->set_number('4450863')->is_valid_number, '愛知県西尾市葵町');
ok($zip->set_number('4450864')->is_valid_number, '愛知県西尾市錦城町');
ok($zip->set_number('4450865')->is_valid_number, '愛知県西尾市本町');
ok($zip->set_number('4450866')->is_valid_number, '愛知県西尾市塩町');
ok($zip->set_number('4450870')->is_valid_number, '愛知県西尾市永吉');
ok($zip->set_number('4450871')->is_valid_number, '愛知県西尾市永吉町');
ok($zip->set_number('4450872')->is_valid_number, '愛知県西尾市矢曽根町');
ok($zip->set_number('4450873')->is_valid_number, '愛知県西尾市川口町');
ok($zip->set_number('4450874')->is_valid_number, '愛知県西尾市菱池町');
ok($zip->set_number('4450875')->is_valid_number, '愛知県西尾市深池町');
ok($zip->set_number('4450876')->is_valid_number, '愛知県西尾市住崎町');
ok($zip->set_number('4450877')->is_valid_number, '愛知県西尾市山下町');
ok($zip->set_number('4450878')->is_valid_number, '愛知県西尾市新在家');
ok($zip->set_number('4450879')->is_valid_number, '愛知県西尾市住崎');
ok($zip->set_number('4450881')->is_valid_number, '愛知県西尾市熱池町');
ok($zip->set_number('4450882')->is_valid_number, '愛知県西尾市上道目記町');
ok($zip->set_number('4450883')->is_valid_number, '愛知県西尾市下道目記町');
ok($zip->set_number('4450884')->is_valid_number, '愛知県西尾市八ケ尻町');
ok($zip->set_number('4450885')->is_valid_number, '愛知県西尾市行用町');
ok($zip->set_number('4450886')->is_valid_number, '愛知県西尾市針曽根町');
ok($zip->set_number('4450887')->is_valid_number, '愛知県西尾市長縄町');
ok($zip->set_number('4450891')->is_valid_number, '愛知県西尾市下町');
ok($zip->set_number('4450892')->is_valid_number, '愛知県西尾市法光寺町');
ok($zip->set_number('4450893')->is_valid_number, '愛知県西尾市小間町');
ok($zip->set_number('4450894')->is_valid_number, '愛知県西尾市上町');
ok($zip->set_number('4460000')->is_valid_number, '愛知県安城市以下に掲載がない場合');
ok($zip->set_number('4460001')->is_valid_number, '愛知県安城市里町');
ok($zip->set_number('4460002')->is_valid_number, '愛知県安城市橋目町');
ok($zip->set_number('4460003')->is_valid_number, '愛知県安城市柿さき町');
ok($zip->set_number('4460004')->is_valid_number, '愛知県安城市尾崎町');
ok($zip->set_number('4460005')->is_valid_number, '愛知県安城市宇頭茶屋町');
ok($zip->set_number('4460006')->is_valid_number, '愛知県安城市浜屋町');
ok($zip->set_number('4460007')->is_valid_number, '愛知県安城市東栄町');
ok($zip->set_number('4460008')->is_valid_number, '愛知県安城市今本町');
ok($zip->set_number('4460011')->is_valid_number, '愛知県安城市北山崎町');
ok($zip->set_number('4460012')->is_valid_number, '愛知県安城市西別所町');
ok($zip->set_number('4460013')->is_valid_number, '愛知県安城市東別所町');
ok($zip->set_number('4460014')->is_valid_number, '愛知県安城市別郷町');
ok($zip->set_number('4460015')->is_valid_number, '愛知県安城市高木町');
ok($zip->set_number('4460016')->is_valid_number, '愛知県安城市山崎町');
ok($zip->set_number('4460017')->is_valid_number, '愛知県安城市大岡町');
ok($zip->set_number('4460018')->is_valid_number, '愛知県安城市東新町');
ok($zip->set_number('4460019')->is_valid_number, '愛知県安城市新明町');
ok($zip->set_number('4460021')->is_valid_number, '愛知県安城市法連町');
ok($zip->set_number('4460022')->is_valid_number, '愛知県安城市浜富町');
ok($zip->set_number('4460023')->is_valid_number, '愛知県安城市上条町');
ok($zip->set_number('4460024')->is_valid_number, '愛知県安城市河野町');
ok($zip->set_number('4460025')->is_valid_number, '愛知県安城市古井町');
ok($zip->set_number('4460026')->is_valid_number, '愛知県安城市安城町');
ok($zip->set_number('4460027')->is_valid_number, '愛知県安城市東明町');
ok($zip->set_number('4460031')->is_valid_number, '愛知県安城市朝日町');
ok($zip->set_number('4460032')->is_valid_number, '愛知県安城市御幸本町');
ok($zip->set_number('4460033')->is_valid_number, '愛知県安城市日の出町');
ok($zip->set_number('4460034')->is_valid_number, '愛知県安城市南町');
ok($zip->set_number('4460035')->is_valid_number, '愛知県安城市錦町');
ok($zip->set_number('4460036')->is_valid_number, '愛知県安城市小堤町');
ok($zip->set_number('4460037')->is_valid_number, '愛知県安城市相生町');
ok($zip->set_number('4460038')->is_valid_number, '愛知県安城市末広町');
ok($zip->set_number('4460039')->is_valid_number, '愛知県安城市花ノ木町');
ok($zip->set_number('4460041')->is_valid_number, '愛知県安城市桜町');
ok($zip->set_number('4460042')->is_valid_number, '愛知県安城市大山町');
ok($zip->set_number('4460043')->is_valid_number, '愛知県安城市城南町');
ok($zip->set_number('4460044')->is_valid_number, '愛知県安城市百石町');
ok($zip->set_number('4460045')->is_valid_number, '愛知県安城市横山町');
ok($zip->set_number('4460046')->is_valid_number, '愛知県安城市赤松町');
ok($zip->set_number('4460051')->is_valid_number, '愛知県安城市箕輪町');
ok($zip->set_number('4460052')->is_valid_number, '愛知県安城市福釜町');
ok($zip->set_number('4460053')->is_valid_number, '愛知県安城市高棚町');
ok($zip->set_number('4460054')->is_valid_number, '愛知県安城市二本木町');
ok($zip->set_number('4460055')->is_valid_number, '愛知県安城市緑町');
ok($zip->set_number('4460056')->is_valid_number, '愛知県安城市三河安城町');
ok($zip->set_number('4460057')->is_valid_number, '愛知県安城市三河安城東町');
ok($zip->set_number('4460058')->is_valid_number, '愛知県安城市三河安城南町');
ok($zip->set_number('4460059')->is_valid_number, '愛知県安城市三河安城本町');
ok($zip->set_number('4460061')->is_valid_number, '愛知県安城市新田町');
ok($zip->set_number('4460062')->is_valid_number, '愛知県安城市明治本町');
ok($zip->set_number('4460063')->is_valid_number, '愛知県安城市昭和町');
ok($zip->set_number('4460064')->is_valid_number, '愛知県安城市弁天町');
ok($zip->set_number('4460065')->is_valid_number, '愛知県安城市大東町');
ok($zip->set_number('4460066')->is_valid_number, '愛知県安城市池浦町');
ok($zip->set_number('4460071')->is_valid_number, '愛知県安城市今池町');
ok($zip->set_number('4460072')->is_valid_number, '愛知県安城市住吉町');
ok($zip->set_number('4460073')->is_valid_number, '愛知県安城市篠目町');
ok($zip->set_number('4460074')->is_valid_number, '愛知県安城市井杭山町');
ok($zip->set_number('4460075')->is_valid_number, '愛知県安城市二本木新町');
ok($zip->set_number('4460076')->is_valid_number, '愛知県安城市美園町');
ok($zip->set_number('4470000')->is_valid_number, '愛知県碧南市以下に掲載がない場合');
ok($zip->set_number('4470001')->is_valid_number, '愛知県碧南市北町');
ok($zip->set_number('4470002')->is_valid_number, '愛知県碧南市井口町');
ok($zip->set_number('4470003')->is_valid_number, '愛知県碧南市雁道町');
ok($zip->set_number('4470004')->is_valid_number, '愛知県碧南市用久町');
ok($zip->set_number('4470005')->is_valid_number, '愛知県碧南市若水町');
ok($zip->set_number('4470006')->is_valid_number, '愛知県碧南市宝町');
ok($zip->set_number('4470007')->is_valid_number, '愛知県碧南市竹原町');
ok($zip->set_number('4470008')->is_valid_number, '愛知県碧南市大久手町');
ok($zip->set_number('4470011')->is_valid_number, '愛知県碧南市平山町');
ok($zip->set_number('4470012')->is_valid_number, '愛知県碧南市大坪町');
ok($zip->set_number('4470013')->is_valid_number, '愛知県碧南市白沢町');
ok($zip->set_number('4470014')->is_valid_number, '愛知県碧南市長田町');
ok($zip->set_number('4470015')->is_valid_number, '愛知県碧南市半崎町');
ok($zip->set_number('4470016')->is_valid_number, '愛知県碧南市神田町');
ok($zip->set_number('4470017')->is_valid_number, '愛知県碧南市奥沢町');
ok($zip->set_number('4470021')->is_valid_number, '愛知県碧南市縄手町');
ok($zip->set_number('4470022')->is_valid_number, '愛知県碧南市旭町');
ok($zip->set_number('4470023')->is_valid_number, '愛知県碧南市池下町');
ok($zip->set_number('4470024')->is_valid_number, '愛知県碧南市亀穴町');
ok($zip->set_number('4470025')->is_valid_number, '愛知県碧南市大堤町');
ok($zip->set_number('4470026')->is_valid_number, '愛知県碧南市三宅町');
ok($zip->set_number('4470027')->is_valid_number, '愛知県碧南市照光町');
ok($zip->set_number('4470028')->is_valid_number, '愛知県碧南市神有町');
ok($zip->set_number('4470029')->is_valid_number, '愛知県碧南市二本木町');
ok($zip->set_number('4470031')->is_valid_number, '愛知県碧南市見合町');
ok($zip->set_number('4470032')->is_valid_number, '愛知県碧南市北浦町');
ok($zip->set_number('4470033')->is_valid_number, '愛知県碧南市天神町');
ok($zip->set_number('4470034')->is_valid_number, '愛知県碧南市鴻島町');
ok($zip->set_number('4470035')->is_valid_number, '愛知県碧南市中山町');
ok($zip->set_number('4470036')->is_valid_number, '愛知県碧南市尾城町');
ok($zip->set_number('4470037')->is_valid_number, '愛知県碧南市城山町');
ok($zip->set_number('4470038')->is_valid_number, '愛知県碧南市荒子町');
ok($zip->set_number('4470041')->is_valid_number, '愛知県碧南市緑町');
ok($zip->set_number('4470042')->is_valid_number, '愛知県碧南市中後町');
ok($zip->set_number('4470043')->is_valid_number, '愛知県碧南市幸町');
ok($zip->set_number('4470044')->is_valid_number, '愛知県碧南市末広町');
ok($zip->set_number('4470045')->is_valid_number, '愛知県碧南市篭田町');
ok($zip->set_number('4470046')->is_valid_number, '愛知県碧南市堀方町');
ok($zip->set_number('4470047')->is_valid_number, '愛知県碧南市植出町');
ok($zip->set_number('4470048')->is_valid_number, '愛知県碧南市福清水町');
ok($zip->set_number('4470051')->is_valid_number, '愛知県碧南市東山町');
ok($zip->set_number('4470052')->is_valid_number, '愛知県碧南市新道町');
ok($zip->set_number('4470053')->is_valid_number, '愛知県碧南市笹山町');
ok($zip->set_number('4470054')->is_valid_number, '愛知県碧南市踏分町');
ok($zip->set_number('4470055')->is_valid_number, '愛知県碧南市浜尾町');
ok($zip->set_number('4470056')->is_valid_number, '愛知県碧南市千福町');
ok($zip->set_number('4470057')->is_valid_number, '愛知県碧南市鶴見町');
ok($zip->set_number('4470058')->is_valid_number, '愛知県碧南市住吉町');
ok($zip->set_number('4470061')->is_valid_number, '愛知県碧南市三度山町');
ok($zip->set_number('4470062')->is_valid_number, '愛知県碧南市古川町');
ok($zip->set_number('4470063')->is_valid_number, '愛知県碧南市山下町');
ok($zip->set_number('4470064')->is_valid_number, '愛知県碧南市西山町');
ok($zip->set_number('4470065')->is_valid_number, '愛知県碧南市久沓町');
ok($zip->set_number('4470066')->is_valid_number, '愛知県碧南市丸山町');
ok($zip->set_number('4470067')->is_valid_number, '愛知県碧南市広見町');
ok($zip->set_number('4470068')->is_valid_number, '愛知県碧南市荒居町');
ok($zip->set_number('4470071')->is_valid_number, '愛知県碧南市桃山町');
ok($zip->set_number('4470072')->is_valid_number, '愛知県碧南市清水町');
ok($zip->set_number('4470073')->is_valid_number, '愛知県碧南市鳥追町');
ok($zip->set_number('4470074')->is_valid_number, '愛知県碧南市上町');
ok($zip->set_number('4470075')->is_valid_number, '愛知県碧南市立山町');
ok($zip->set_number('4470076')->is_valid_number, '愛知県碧南市白砂町');
ok($zip->set_number('4470077')->is_valid_number, '愛知県碧南市屋敷町');
ok($zip->set_number('4470078')->is_valid_number, '愛知県碧南市島池町');
ok($zip->set_number('4470079')->is_valid_number, '愛知県碧南市松原町');
ok($zip->set_number('4470081')->is_valid_number, '愛知県碧南市吹上町');
ok($zip->set_number('4470082')->is_valid_number, '愛知県碧南市湖西町');
ok($zip->set_number('4470083')->is_valid_number, '愛知県碧南市油渕町');
ok($zip->set_number('4470084')->is_valid_number, '愛知県碧南市平和町');
ok($zip->set_number('4470085')->is_valid_number, '愛知県碧南市金山町');
ok($zip->set_number('4470086')->is_valid_number, '愛知県碧南市洲先町');
ok($zip->set_number('4470087')->is_valid_number, '愛知県碧南市坂口町');
ok($zip->set_number('4470088')->is_valid_number, '愛知県碧南市札木町');
ok($zip->set_number('4470801')->is_valid_number, '愛知県碧南市野銭町');
ok($zip->set_number('4470802')->is_valid_number, '愛知県碧南市鷲林町');
ok($zip->set_number('4470803')->is_valid_number, '愛知県碧南市三角町');
ok($zip->set_number('4470804')->is_valid_number, '愛知県碧南市流作町');
ok($zip->set_number('4470805')->is_valid_number, '愛知県碧南市矢縄町');
ok($zip->set_number('4470806')->is_valid_number, '愛知県碧南市三間町');
ok($zip->set_number('4470807')->is_valid_number, '愛知県碧南市伏見町');
ok($zip->set_number('4470808')->is_valid_number, '愛知県碧南市鷲塚町');
ok($zip->set_number('4470809')->is_valid_number, '愛知県碧南市小屋下町');
ok($zip->set_number('4470811')->is_valid_number, '愛知県碧南市舟江町');
ok($zip->set_number('4470812')->is_valid_number, '愛知県碧南市中江町');
ok($zip->set_number('4470813')->is_valid_number, '愛知県碧南市雨池町');
ok($zip->set_number('4470814')->is_valid_number, '愛知県碧南市弥生町');
ok($zip->set_number('4470815')->is_valid_number, '愛知県碧南市棚尾本町');
ok($zip->set_number('4470816')->is_valid_number, '愛知県碧南市志貴崎町');
ok($zip->set_number('4470817')->is_valid_number, '愛知県碧南市川端町');
ok($zip->set_number('4470818')->is_valid_number, '愛知県碧南市若宮町');
ok($zip->set_number('4470821')->is_valid_number, '愛知県碧南市稲荷町');
ok($zip->set_number('4470822')->is_valid_number, '愛知県碧南市河方町');
ok($zip->set_number('4470823')->is_valid_number, '愛知県碧南市川口町');
ok($zip->set_number('4470824')->is_valid_number, '愛知県碧南市港南町');
ok($zip->set_number('4470825')->is_valid_number, '愛知県碧南市江口町');
ok($zip->set_number('4470826')->is_valid_number, '愛知県碧南市葭生町');
ok($zip->set_number('4470827')->is_valid_number, '愛知県碧南市前浜町');
ok($zip->set_number('4470828')->is_valid_number, '愛知県碧南市潮見町');
ok($zip->set_number('4470829')->is_valid_number, '愛知県碧南市中田町');
ok($zip->set_number('4470831')->is_valid_number, '愛知県碧南市入船町');
ok($zip->set_number('4470832')->is_valid_number, '愛知県碧南市岬町');
ok($zip->set_number('4470833')->is_valid_number, '愛知県碧南市権現町');
ok($zip->set_number('4470834')->is_valid_number, '愛知県碧南市玉津浦町');
ok($zip->set_number('4470835')->is_valid_number, '愛知県碧南市宮町');
ok($zip->set_number('4470836')->is_valid_number, '愛知県碧南市若松町');
ok($zip->set_number('4470837')->is_valid_number, '愛知県碧南市伊勢町');
ok($zip->set_number('4470838')->is_valid_number, '愛知県碧南市権田町');
ok($zip->set_number('4470841')->is_valid_number, '愛知県碧南市塩浜町');
ok($zip->set_number('4470842')->is_valid_number, '愛知県碧南市浜田町');
ok($zip->set_number('4470843')->is_valid_number, '愛知県碧南市西浜町');
ok($zip->set_number('4470844')->is_valid_number, '愛知県碧南市港本町');
ok($zip->set_number('4470845')->is_valid_number, '愛知県碧南市浜寺町');
ok($zip->set_number('4470846')->is_valid_number, '愛知県碧南市中町');
ok($zip->set_number('4470847')->is_valid_number, '愛知県碧南市音羽町');
ok($zip->set_number('4470848')->is_valid_number, '愛知県碧南市錦町');
ok($zip->set_number('4470849')->is_valid_number, '愛知県碧南市築山町');
ok($zip->set_number('4470851')->is_valid_number, '愛知県碧南市羽根町');
ok($zip->set_number('4470852')->is_valid_number, '愛知県碧南市本郷町');
ok($zip->set_number('4470853')->is_valid_number, '愛知県碧南市浜町');
ok($zip->set_number('4470854')->is_valid_number, '愛知県碧南市須磨町');
ok($zip->set_number('4470855')->is_valid_number, '愛知県碧南市天王町');
ok($zip->set_number('4470856')->is_valid_number, '愛知県碧南市宮後町');
ok($zip->set_number('4470857')->is_valid_number, '愛知県碧南市大浜上町');
ok($zip->set_number('4470858')->is_valid_number, '愛知県碧南市石橋町');
ok($zip->set_number('4470859')->is_valid_number, '愛知県碧南市中松町');
ok($zip->set_number('4470861')->is_valid_number, '愛知県碧南市六軒町');
ok($zip->set_number('4470862')->is_valid_number, '愛知県碧南市相生町');
ok($zip->set_number('4470863')->is_valid_number, '愛知県碧南市新川町');
ok($zip->set_number('4470864')->is_valid_number, '愛知県碧南市道場山町');
ok($zip->set_number('4470865')->is_valid_number, '愛知県碧南市浅間町');
ok($zip->set_number('4470866')->is_valid_number, '愛知県碧南市明石町');
ok($zip->set_number('4470867')->is_valid_number, '愛知県碧南市田尻町');
ok($zip->set_number('4470868')->is_valid_number, '愛知県碧南市松江町');
ok($zip->set_number('4470869')->is_valid_number, '愛知県碧南市山神町');
ok($zip->set_number('4470871')->is_valid_number, '愛知県碧南市向陽町');
ok($zip->set_number('4470872')->is_valid_number, '愛知県碧南市源氏神明町');
ok($zip->set_number('4470873')->is_valid_number, '愛知県碧南市栗山町');
ok($zip->set_number('4470874')->is_valid_number, '愛知県碧南市作塚町');
ok($zip->set_number('4470875')->is_valid_number, '愛知県碧南市善明町');
ok($zip->set_number('4470876')->is_valid_number, '愛知県碧南市野田町');
ok($zip->set_number('4470877')->is_valid_number, '愛知県碧南市栄町');
ok($zip->set_number('4470878')->is_valid_number, '愛知県碧南市松本町');
ok($zip->set_number('4470879')->is_valid_number, '愛知県碧南市沢渡町');
ok($zip->set_number('4470881')->is_valid_number, '愛知県碧南市霞浦町');
ok($zip->set_number('4470882')->is_valid_number, '愛知県碧南市日進町');
ok($zip->set_number('4470883')->is_valid_number, '愛知県碧南市下洲町');
ok($zip->set_number('4470884')->is_valid_number, '愛知県碧南市平七町');
ok($zip->set_number('4470885')->is_valid_number, '愛知県碧南市志貴町');
ok($zip->set_number('4470886')->is_valid_number, '愛知県碧南市源氏町');
ok($zip->set_number('4470887')->is_valid_number, '愛知県碧南市汐田町');
ok($zip->set_number('4470888')->is_valid_number, '愛知県碧南市春日町');
ok($zip->set_number('4470889')->is_valid_number, '愛知県碧南市東浦町');
ok($zip->set_number('4480000')->is_valid_number, '愛知県刈谷市以下に掲載がない場合');
ok($zip->set_number('4480001')->is_valid_number, '愛知県刈谷市井ケ谷町');
ok($zip->set_number('4480002')->is_valid_number, '愛知県刈谷市一里山町');
ok($zip->set_number('4480003')->is_valid_number, '愛知県刈谷市一ツ木町');
ok($zip->set_number('4480004')->is_valid_number, '愛知県刈谷市泉田町');
ok($zip->set_number('4480005')->is_valid_number, '愛知県刈谷市今川町');
ok($zip->set_number('4480006')->is_valid_number, '愛知県刈谷市西境町');
ok($zip->set_number('4480007')->is_valid_number, '愛知県刈谷市東境町');
ok($zip->set_number('4480008')->is_valid_number, '愛知県刈谷市今岡町');
ok($zip->set_number('4480011')->is_valid_number, '愛知県刈谷市築地町');
ok($zip->set_number('4480012')->is_valid_number, '愛知県刈谷市上重原町');
ok($zip->set_number('4480013')->is_valid_number, '愛知県刈谷市恩田町');
ok($zip->set_number('4480014')->is_valid_number, '愛知県刈谷市青山町');
ok($zip->set_number('4480015')->is_valid_number, '愛知県刈谷市新田町');
ok($zip->set_number('4480021')->is_valid_number, '愛知県刈谷市八軒町');
ok($zip->set_number('4480022')->is_valid_number, '愛知県刈谷市一色町');
ok($zip->set_number('4480023')->is_valid_number, '愛知県刈谷市重原本町');
ok($zip->set_number('4480024')->is_valid_number, '愛知県刈谷市下重原町');
ok($zip->set_number('4480025')->is_valid_number, '愛知県刈谷市幸町');
ok($zip->set_number('4480026')->is_valid_number, '愛知県刈谷市中山町');
ok($zip->set_number('4480027')->is_valid_number, '愛知県刈谷市相生町');
ok($zip->set_number('4480028')->is_valid_number, '愛知県刈谷市桜町');
ok($zip->set_number('4480029')->is_valid_number, '愛知県刈谷市昭和町');
ok($zip->set_number('4480031')->is_valid_number, '愛知県刈谷市東新町');
ok($zip->set_number('4480032')->is_valid_number, '愛知県刈谷市朝日町');
ok($zip->set_number('4480033')->is_valid_number, '愛知県刈谷市丸田町');
ok($zip->set_number('4480034')->is_valid_number, '愛知県刈谷市神明町');
ok($zip->set_number('4480035')->is_valid_number, '愛知県刈谷市矢場町');
ok($zip->set_number('4480036')->is_valid_number, '愛知県刈谷市山池町');
ok($zip->set_number('4480037')->is_valid_number, '愛知県刈谷市高倉町');
ok($zip->set_number('4480038')->is_valid_number, '愛知県刈谷市稲場町');
ok($zip->set_number('4480039')->is_valid_number, '愛知県刈谷市原崎町');
ok($zip->set_number('4480041')->is_valid_number, '愛知県刈谷市一番町');
ok($zip->set_number('4480042')->is_valid_number, '愛知県刈谷市広見町');
ok($zip->set_number('4480043')->is_valid_number, '愛知県刈谷市小山町');
ok($zip->set_number('4480044')->is_valid_number, '愛知県刈谷市池田町');
ok($zip->set_number('4480045')->is_valid_number, '愛知県刈谷市新富町');
ok($zip->set_number('4480046')->is_valid_number, '愛知県刈谷市日高町');
ok($zip->set_number('4480047')->is_valid_number, '愛知県刈谷市高津波町');
ok($zip->set_number('4480048')->is_valid_number, '愛知県刈谷市三田町');
ok($zip->set_number('4480049')->is_valid_number, '愛知県刈谷市中手町');
ok($zip->set_number('4480801')->is_valid_number, '愛知県刈谷市板倉町');
ok($zip->set_number('4480802')->is_valid_number, '愛知県刈谷市末広町');
ok($zip->set_number('4480803')->is_valid_number, '愛知県刈谷市野田町');
ok($zip->set_number('4480804')->is_valid_number, '愛知県刈谷市半城土町');
ok($zip->set_number('4480805')->is_valid_number, '愛知県刈谷市半城土中町');
ok($zip->set_number('4480806')->is_valid_number, '愛知県刈谷市松栄町');
ok($zip->set_number('4480807')->is_valid_number, '愛知県刈谷市東刈谷町');
ok($zip->set_number('4480808')->is_valid_number, '愛知県刈谷市沖野町');
ok($zip->set_number('4480809')->is_valid_number, '愛知県刈谷市南沖野町');
ok($zip->set_number('4480810')->is_valid_number, '愛知県刈谷市場割町');
ok($zip->set_number('4480811')->is_valid_number, '愛知県刈谷市田町');
ok($zip->set_number('4480812')->is_valid_number, '愛知県刈谷市高須町');
ok($zip->set_number('4480813')->is_valid_number, '愛知県刈谷市小垣江町');
ok($zip->set_number('4480814')->is_valid_number, '愛知県刈谷市荒井町');
ok($zip->set_number('4480815')->is_valid_number, '愛知県刈谷市中島町');
ok($zip->set_number('4480816')->is_valid_number, '愛知県刈谷市半城土西町');
ok($zip->set_number('4480821')->is_valid_number, '愛知県刈谷市御幸町');
ok($zip->set_number('4480822')->is_valid_number, '愛知県刈谷市松坂町');
ok($zip->set_number('4480823')->is_valid_number, '愛知県刈谷市中川町');
ok($zip->set_number('4480824')->is_valid_number, '愛知県刈谷市天王町');
ok($zip->set_number('4480825')->is_valid_number, '愛知県刈谷市元町');
ok($zip->set_number('4480831')->is_valid_number, '愛知県刈谷市熊野町');
ok($zip->set_number('4480832')->is_valid_number, '愛知県刈谷市八幡町');
ok($zip->set_number('4480833')->is_valid_number, '愛知県刈谷市城町');
ok($zip->set_number('4480834')->is_valid_number, '愛知県刈谷市司町');
ok($zip->set_number('4480835')->is_valid_number, '愛知県刈谷市港町');
ok($zip->set_number('4480836')->is_valid_number, '愛知県刈谷市浜町');
ok($zip->set_number('4480837')->is_valid_number, '愛知県刈谷市衣崎町');
ok($zip->set_number('4480838')->is_valid_number, '愛知県刈谷市逢妻町');
ok($zip->set_number('4480841')->is_valid_number, '愛知県刈谷市南桜町');
ok($zip->set_number('4480842')->is_valid_number, '愛知県刈谷市東陽町');
ok($zip->set_number('4480843')->is_valid_number, '愛知県刈谷市新栄町');
ok($zip->set_number('4480844')->is_valid_number, '愛知県刈谷市広小路');
ok($zip->set_number('4480845')->is_valid_number, '愛知県刈谷市銀座');
ok($zip->set_number('4480846')->is_valid_number, '愛知県刈谷市寺横町');
ok($zip->set_number('4480847')->is_valid_number, '愛知県刈谷市宝町');
ok($zip->set_number('4480848')->is_valid_number, '愛知県刈谷市豊田町');
ok($zip->set_number('4480851')->is_valid_number, '愛知県刈谷市神田町');
ok($zip->set_number('4480852')->is_valid_number, '愛知県刈谷市住吉町');
ok($zip->set_number('4480853')->is_valid_number, '愛知県刈谷市高松町');
ok($zip->set_number('4480854')->is_valid_number, '愛知県刈谷市富士見町');
ok($zip->set_number('4480855')->is_valid_number, '愛知県刈谷市大正町');
ok($zip->set_number('4480856')->is_valid_number, '愛知県刈谷市寿町');
ok($zip->set_number('4480857')->is_valid_number, '愛知県刈谷市大手町');
ok($zip->set_number('4480858')->is_valid_number, '愛知県刈谷市若松町');
ok($zip->set_number('4480861')->is_valid_number, '愛知県刈谷市半城土北町');
ok($zip->set_number('4480862')->is_valid_number, '愛知県刈谷市野田新町');
ok($zip->set_number('4490200')->is_valid_number, '愛知県北設楽郡東栄町以下に掲載がない場合');
ok($zip->set_number('4490201')->is_valid_number, '愛知県北設楽郡東栄町御園');
ok($zip->set_number('4490202')->is_valid_number, '愛知県北設楽郡東栄町足込');
ok($zip->set_number('4490203')->is_valid_number, '愛知県北設楽郡東栄町東薗目');
ok($zip->set_number('4490204')->is_valid_number, '愛知県北設楽郡東栄町西薗目');
ok($zip->set_number('4490205')->is_valid_number, '愛知県北設楽郡東栄町川角');
ok($zip->set_number('4490206')->is_valid_number, '愛知県北設楽郡東栄町下田');
ok($zip->set_number('4490211')->is_valid_number, '愛知県北設楽郡東栄町中設楽');
ok($zip->set_number('4490212')->is_valid_number, '愛知県北設楽郡東栄町月');
ok($zip->set_number('4490213')->is_valid_number, '愛知県北設楽郡東栄町振草');
ok($zip->set_number('4490214')->is_valid_number, '愛知県北設楽郡東栄町本郷');
ok($zip->set_number('4490215')->is_valid_number, '愛知県北設楽郡東栄町奈根');
ok($zip->set_number('4490216')->is_valid_number, '愛知県北設楽郡東栄町三輪');
ok($zip->set_number('4490400')->is_valid_number, '愛知県北設楽郡豊根村以下に掲載がない場合');
ok($zip->set_number('4490401')->is_valid_number, '愛知県北設楽郡豊根村三沢');
ok($zip->set_number('4490402')->is_valid_number, '愛知県北設楽郡豊根村古真立');
ok($zip->set_number('4490403')->is_valid_number, '愛知県北設楽郡豊根村下黒川');
ok($zip->set_number('4490404')->is_valid_number, '愛知県北設楽郡豊根村上黒川');
ok($zip->set_number('4490405')->is_valid_number, '愛知県北設楽郡豊根村坂宇場');
ok($zip->set_number('4500001')->is_valid_number, '愛知県名古屋市中村区那古野');
ok($zip->set_number('4500002')->is_valid_number, '愛知県名古屋市中村区名駅(その他)');
ok($zip->set_number('4500003')->is_valid_number, '愛知県名古屋市中村区名駅南');
ok($zip->set_number('4500004')->is_valid_number, '愛知県名古屋市中村区松重町');
ok($zip->set_number('4500005')->is_valid_number, '愛知県名古屋市中村区西日置');
ok($zip->set_number('4500006')->is_valid_number, '愛知県名古屋市中村区下広井町');
ok($zip->set_number('4500007')->is_valid_number, '愛知県名古屋市中村区笹島町');
ok($zip->set_number('4506001')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(1階)');
ok($zip->set_number('4506002')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(2階)');
ok($zip->set_number('4506003')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(3階)');
ok($zip->set_number('4506004')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(4階)');
ok($zip->set_number('4506005')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(5階)');
ok($zip->set_number('4506006')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(6階)');
ok($zip->set_number('4506007')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(7階)');
ok($zip->set_number('4506008')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(8階)');
ok($zip->set_number('4506009')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(9階)');
ok($zip->set_number('4506010')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(10階)');
ok($zip->set_number('4506011')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(11階)');
ok($zip->set_number('4506012')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(12階)');
ok($zip->set_number('4506013')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(13階)');
ok($zip->set_number('4506014')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(14階)');
ok($zip->set_number('4506015')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(15階)');
ok($zip->set_number('4506016')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(16階)');
ok($zip->set_number('4506017')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(17階)');
ok($zip->set_number('4506018')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(18階)');
ok($zip->set_number('4506019')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(19階)');
ok($zip->set_number('4506020')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(20階)');
ok($zip->set_number('4506021')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(21階)');
ok($zip->set_number('4506022')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(22階)');
ok($zip->set_number('4506023')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(23階)');
ok($zip->set_number('4506024')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(24階)');
ok($zip->set_number('4506025')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(25階)');
ok($zip->set_number('4506026')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(26階)');
ok($zip->set_number('4506027')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(27階)');
ok($zip->set_number('4506028')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(28階)');
ok($zip->set_number('4506029')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(29階)');
ok($zip->set_number('4506030')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(30階)');
ok($zip->set_number('4506031')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(31階)');
ok($zip->set_number('4506032')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(32階)');
ok($zip->set_number('4506033')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(33階)');
ok($zip->set_number('4506034')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(34階)');
ok($zip->set_number('4506035')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(35階)');
ok($zip->set_number('4506036')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(36階)');
ok($zip->set_number('4506037')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(37階)');
ok($zip->set_number('4506038')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(38階)');
ok($zip->set_number('4506039')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(39階)');
ok($zip->set_number('4506040')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(40階)');
ok($zip->set_number('4506041')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(41階)');
ok($zip->set_number('4506042')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(42階)');
ok($zip->set_number('4506043')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(43階)');
ok($zip->set_number('4506044')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(44階)');
ok($zip->set_number('4506045')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(45階)');
ok($zip->set_number('4506046')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(46階)');
ok($zip->set_number('4506047')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(47階)');
ok($zip->set_number('4506048')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(48階)');
ok($zip->set_number('4506049')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(49階)');
ok($zip->set_number('4506050')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(50階)');
ok($zip->set_number('4506051')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(51階)');
ok($zip->set_number('4506090')->is_valid_number, '愛知県名古屋市中村区名駅JRセントラルタワーズ(地階・階層不明)');
ok($zip->set_number('4506201')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(1階)');
ok($zip->set_number('4506202')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(2階)');
ok($zip->set_number('4506203')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(3階)');
ok($zip->set_number('4506204')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(4階)');
ok($zip->set_number('4506205')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(5階)');
ok($zip->set_number('4506206')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(6階)');
ok($zip->set_number('4506207')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(7階)');
ok($zip->set_number('4506208')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(8階)');
ok($zip->set_number('4506209')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(9階)');
ok($zip->set_number('4506210')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(10階)');
ok($zip->set_number('4506211')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(11階)');
ok($zip->set_number('4506212')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(12階)');
ok($zip->set_number('4506213')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(13階)');
ok($zip->set_number('4506214')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(14階)');
ok($zip->set_number('4506215')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(15階)');
ok($zip->set_number('4506216')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(16階)');
ok($zip->set_number('4506217')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(17階)');
ok($zip->set_number('4506218')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(18階)');
ok($zip->set_number('4506219')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(19階)');
ok($zip->set_number('4506220')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(20階)');
ok($zip->set_number('4506221')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(21階)');
ok($zip->set_number('4506222')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(22階)');
ok($zip->set_number('4506223')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(23階)');
ok($zip->set_number('4506224')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(24階)');
ok($zip->set_number('4506225')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(25階)');
ok($zip->set_number('4506226')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(26階)');
ok($zip->set_number('4506227')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(27階)');
ok($zip->set_number('4506228')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(28階)');
ok($zip->set_number('4506229')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(29階)');
ok($zip->set_number('4506230')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(30階)');
ok($zip->set_number('4506231')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(31階)');
ok($zip->set_number('4506232')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(32階)');
ok($zip->set_number('4506233')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(33階)');
ok($zip->set_number('4506234')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(34階)');
ok($zip->set_number('4506235')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(35階)');
ok($zip->set_number('4506236')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(36階)');
ok($zip->set_number('4506237')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(37階)');
ok($zip->set_number('4506238')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(38階)');
ok($zip->set_number('4506239')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(39階)');
ok($zip->set_number('4506240')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(40階)');
ok($zip->set_number('4506241')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(41階)');
ok($zip->set_number('4506242')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(42階)');
ok($zip->set_number('4506243')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(43階)');
ok($zip->set_number('4506244')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(44階)');
ok($zip->set_number('4506245')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(45階)');
ok($zip->set_number('4506246')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(46階)');
ok($zip->set_number('4506247')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(47階)');
ok($zip->set_number('4506290')->is_valid_number, '愛知県名古屋市中村区名駅ミッドランドスクエア(高層棟)(地階・階層不明)');
ok($zip->set_number('4506301')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(1階)');
ok($zip->set_number('4506302')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(2階)');
ok($zip->set_number('4506303')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(3階)');
ok($zip->set_number('4506304')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(4階)');
ok($zip->set_number('4506305')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(5階)');
ok($zip->set_number('4506306')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(6階)');
ok($zip->set_number('4506307')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(7階)');
ok($zip->set_number('4506308')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(8階)');
ok($zip->set_number('4506309')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(9階)');
ok($zip->set_number('4506310')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(10階)');
ok($zip->set_number('4506311')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(11階)');
ok($zip->set_number('4506312')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(12階)');
ok($zip->set_number('4506313')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(13階)');
ok($zip->set_number('4506314')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(14階)');
ok($zip->set_number('4506315')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(15階)');
ok($zip->set_number('4506316')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(16階)');
ok($zip->set_number('4506317')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(17階)');
ok($zip->set_number('4506318')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(18階)');
ok($zip->set_number('4506319')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(19階)');
ok($zip->set_number('4506320')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(20階)');
ok($zip->set_number('4506321')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(21階)');
ok($zip->set_number('4506322')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(22階)');
ok($zip->set_number('4506323')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(23階)');
ok($zip->set_number('4506324')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(24階)');
ok($zip->set_number('4506325')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(25階)');
ok($zip->set_number('4506326')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(26階)');
ok($zip->set_number('4506327')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(27階)');
ok($zip->set_number('4506328')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(28階)');
ok($zip->set_number('4506329')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(29階)');
ok($zip->set_number('4506330')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(30階)');
ok($zip->set_number('4506331')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(31階)');
ok($zip->set_number('4506332')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(32階)');
ok($zip->set_number('4506333')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(33階)');
ok($zip->set_number('4506334')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(34階)');
ok($zip->set_number('4506335')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(35階)');
ok($zip->set_number('4506336')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(36階)');
ok($zip->set_number('4506337')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(37階)');
ok($zip->set_number('4506338')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(38階)');
ok($zip->set_number('4506339')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(39階)');
ok($zip->set_number('4506340')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(40階)');
ok($zip->set_number('4506390')->is_valid_number, '愛知県名古屋市中村区名駅JPタワー名古屋(地階・階層不明)');
ok($zip->set_number('4506401')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(1階)');
ok($zip->set_number('4506402')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(2階)');
ok($zip->set_number('4506403')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(3階)');
ok($zip->set_number('4506404')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(4階)');
ok($zip->set_number('4506405')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(5階)');
ok($zip->set_number('4506406')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(6階)');
ok($zip->set_number('4506407')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(7階)');
ok($zip->set_number('4506408')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(8階)');
ok($zip->set_number('4506409')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(9階)');
ok($zip->set_number('4506410')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(10階)');
ok($zip->set_number('4506411')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(11階)');
ok($zip->set_number('4506412')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(12階)');
ok($zip->set_number('4506413')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(13階)');
ok($zip->set_number('4506414')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(14階)');
ok($zip->set_number('4506415')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(15階)');
ok($zip->set_number('4506416')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(16階)');
ok($zip->set_number('4506417')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(17階)');
ok($zip->set_number('4506418')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(18階)');
ok($zip->set_number('4506419')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(19階)');
ok($zip->set_number('4506420')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(20階)');
ok($zip->set_number('4506421')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(21階)');
ok($zip->set_number('4506422')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(22階)');
ok($zip->set_number('4506423')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(23階)');
ok($zip->set_number('4506424')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(24階)');
ok($zip->set_number('4506425')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(25階)');
ok($zip->set_number('4506426')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(26階)');
ok($zip->set_number('4506427')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(27階)');
ok($zip->set_number('4506428')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(28階)');
ok($zip->set_number('4506429')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(29階)');
ok($zip->set_number('4506430')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(30階)');
ok($zip->set_number('4506431')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(31階)');
ok($zip->set_number('4506432')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(32階)');
ok($zip->set_number('4506433')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(33階)');
ok($zip->set_number('4506434')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(34階)');
ok($zip->set_number('4506490')->is_valid_number, '愛知県名古屋市中村区名駅大名古屋ビルヂング(地階・階層不明)');
ok($zip->set_number('4506601')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(1階)');
ok($zip->set_number('4506602')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(2階)');
ok($zip->set_number('4506603')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(3階)');
ok($zip->set_number('4506604')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(4階)');
ok($zip->set_number('4506605')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(5階)');
ok($zip->set_number('4506606')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(6階)');
ok($zip->set_number('4506607')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(7階)');
ok($zip->set_number('4506608')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(8階)');
ok($zip->set_number('4506609')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(9階)');
ok($zip->set_number('4506610')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(10階)');
ok($zip->set_number('4506611')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(11階)');
ok($zip->set_number('4506612')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(12階)');
ok($zip->set_number('4506613')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(13階)');
ok($zip->set_number('4506614')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(14階)');
ok($zip->set_number('4506615')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(15階)');
ok($zip->set_number('4506616')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(16階)');
ok($zip->set_number('4506617')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(17階)');
ok($zip->set_number('4506618')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(18階)');
ok($zip->set_number('4506619')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(19階)');
ok($zip->set_number('4506620')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(20階)');
ok($zip->set_number('4506621')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(21階)');
ok($zip->set_number('4506622')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(22階)');
ok($zip->set_number('4506623')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(23階)');
ok($zip->set_number('4506624')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(24階)');
ok($zip->set_number('4506625')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(25階)');
ok($zip->set_number('4506626')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(26階)');
ok($zip->set_number('4506627')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(27階)');
ok($zip->set_number('4506628')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(28階)');
ok($zip->set_number('4506629')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(29階)');
ok($zip->set_number('4506630')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(30階)');
ok($zip->set_number('4506631')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(31階)');
ok($zip->set_number('4506632')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(32階)');
ok($zip->set_number('4506633')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(33階)');
ok($zip->set_number('4506634')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(34階)');
ok($zip->set_number('4506635')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(35階)');
ok($zip->set_number('4506636')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(36階)');
ok($zip->set_number('4506637')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(37階)');
ok($zip->set_number('4506638')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(38階)');
ok($zip->set_number('4506639')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(39階)');
ok($zip->set_number('4506640')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(40階)');
ok($zip->set_number('4506641')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(41階)');
ok($zip->set_number('4506642')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(42階)');
ok($zip->set_number('4506643')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(43階)');
ok($zip->set_number('4506644')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(44階)');
ok($zip->set_number('4506645')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(45階)');
ok($zip->set_number('4506646')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(46階)');
ok($zip->set_number('4506690')->is_valid_number, '愛知県名古屋市中村区名駅JRゲートタワー(地階・階層不明)');
ok($zip->set_number('4510000')->is_valid_number, '愛知県名古屋市西区以下に掲載がない場合');
ok($zip->set_number('4510011')->is_valid_number, '愛知県名古屋市西区桝形町');
ok($zip->set_number('4510012')->is_valid_number, '愛知県名古屋市西区稲生町');
ok($zip->set_number('4510013')->is_valid_number, '愛知県名古屋市西区江向町');
ok($zip->set_number('4510014')->is_valid_number, '愛知県名古屋市西区又穂町');
ok($zip->set_number('4510015')->is_valid_number, '愛知県名古屋市西区香呑町');
ok($zip->set_number('4510016')->is_valid_number, '愛知県名古屋市西区庄内通');
ok($zip->set_number('4510021')->is_valid_number, '愛知県名古屋市西区天塚町');
ok($zip->set_number('4510022')->is_valid_number, '愛知県名古屋市西区貝田町');
ok($zip->set_number('4510023')->is_valid_number, '愛知県名古屋市西区城北町');
ok($zip->set_number('4510024')->is_valid_number, '愛知県名古屋市西区秩父通');
ok($zip->set_number('4510025')->is_valid_number, '愛知県名古屋市西区上名古屋');
ok($zip->set_number('4510026')->is_valid_number, '愛知県名古屋市西区田幡町');
ok($zip->set_number('4510027')->is_valid_number, '愛知県名古屋市西区西志賀町');
ok($zip->set_number('4510031')->is_valid_number, '愛知県名古屋市西区城西');
ok($zip->set_number('4510032')->is_valid_number, '愛知県名古屋市西区数寄屋町');
ok($zip->set_number('4510033')->is_valid_number, '愛知県名古屋市西区堀端町');
ok($zip->set_number('4510034')->is_valid_number, '愛知県名古屋市西区樋の口町');
ok($zip->set_number('4510035')->is_valid_number, '愛知県名古屋市西区浅間');
ok($zip->set_number('4510041')->is_valid_number, '愛知県名古屋市西区幅下');
ok($zip->set_number('4510042')->is_valid_number, '愛知県名古屋市西区那古野');
ok($zip->set_number('4510043')->is_valid_number, '愛知県名古屋市西区新道');
ok($zip->set_number('4510044')->is_valid_number, '愛知県名古屋市西区菊井');
ok($zip->set_number('4510045')->is_valid_number, '愛知県名古屋市西区名駅');
ok($zip->set_number('4510046')->is_valid_number, '愛知県名古屋市西区牛島町(次のビルを除く)');
ok($zip->set_number('4510051')->is_valid_number, '愛知県名古屋市西区則武新町');
ok($zip->set_number('4510052')->is_valid_number, '愛知県名古屋市西区栄生');
ok($zip->set_number('4510053')->is_valid_number, '愛知県名古屋市西区枇杷島');
ok($zip->set_number('4510054')->is_valid_number, '愛知県名古屋市西区南堀越');
ok($zip->set_number('4510055')->is_valid_number, '愛知県名古屋市西区堀越');
ok($zip->set_number('4510061')->is_valid_number, '愛知県名古屋市西区浄心');
ok($zip->set_number('4510062')->is_valid_number, '愛知県名古屋市西区花の木');
ok($zip->set_number('4510063')->is_valid_number, '愛知県名古屋市西区押切');
ok($zip->set_number('4510064')->is_valid_number, '愛知県名古屋市西区名西');
ok($zip->set_number('4510065')->is_valid_number, '愛知県名古屋市西区天神山町');
ok($zip->set_number('4510066')->is_valid_number, '愛知県名古屋市西区児玉');
ok($zip->set_number('4510071')->is_valid_number, '愛知県名古屋市西区鳥見町');
ok($zip->set_number('4510072')->is_valid_number, '愛知県名古屋市西区笠取町');
ok($zip->set_number('4510073')->is_valid_number, '愛知県名古屋市西区浄心本通');
ok($zip->set_number('4510074')->is_valid_number, '愛知県名古屋市西区万代町');
ok($zip->set_number('4510075')->is_valid_number, '愛知県名古屋市西区康生通');
ok($zip->set_number('4510076')->is_valid_number, '愛知県名古屋市西区東岸町');
ok($zip->set_number('4510077')->is_valid_number, '愛知県名古屋市西区笹塚町');
ok($zip->set_number('4510081')->is_valid_number, '愛知県名古屋市西区名塚町');
ok($zip->set_number('4510082')->is_valid_number, '愛知県名古屋市西区大金町');
ok($zip->set_number('4510083')->is_valid_number, '愛知県名古屋市西区新福寺町');
ok($zip->set_number('4510084')->is_valid_number, '愛知県名古屋市西区上堀越町');
ok($zip->set_number('4516001')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(1階)');
ok($zip->set_number('4516002')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(2階)');
ok($zip->set_number('4516003')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(3階)');
ok($zip->set_number('4516004')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(4階)');
ok($zip->set_number('4516005')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(5階)');
ok($zip->set_number('4516006')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(6階)');
ok($zip->set_number('4516007')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(7階)');
ok($zip->set_number('4516008')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(8階)');
ok($zip->set_number('4516009')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(9階)');
ok($zip->set_number('4516010')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(10階)');
ok($zip->set_number('4516011')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(11階)');
ok($zip->set_number('4516012')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(12階)');
ok($zip->set_number('4516013')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(13階)');
ok($zip->set_number('4516014')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(14階)');
ok($zip->set_number('4516015')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(15階)');
ok($zip->set_number('4516016')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(16階)');
ok($zip->set_number('4516017')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(17階)');
ok($zip->set_number('4516018')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(18階)');
ok($zip->set_number('4516019')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(19階)');
ok($zip->set_number('4516020')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(20階)');
ok($zip->set_number('4516021')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(21階)');
ok($zip->set_number('4516022')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(22階)');
ok($zip->set_number('4516023')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(23階)');
ok($zip->set_number('4516024')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(24階)');
ok($zip->set_number('4516025')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(25階)');
ok($zip->set_number('4516026')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(26階)');
ok($zip->set_number('4516027')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(27階)');
ok($zip->set_number('4516028')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(28階)');
ok($zip->set_number('4516029')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(29階)');
ok($zip->set_number('4516030')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(30階)');
ok($zip->set_number('4516031')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(31階)');
ok($zip->set_number('4516032')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(32階)');
ok($zip->set_number('4516033')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(33階)');
ok($zip->set_number('4516034')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(34階)');
ok($zip->set_number('4516035')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(35階)');
ok($zip->set_number('4516036')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(36階)');
ok($zip->set_number('4516037')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(37階)');
ok($zip->set_number('4516038')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(38階)');
ok($zip->set_number('4516039')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(39階)');
ok($zip->set_number('4516040')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(40階)');
ok($zip->set_number('4516090')->is_valid_number, '愛知県名古屋市西区牛島町名古屋ルーセントタワー(地階・階層不明)');
ok($zip->set_number('4520000')->is_valid_number, '愛知県清須市以下に掲載がない場合');
ok($zip->set_number('4520001')->is_valid_number, '愛知県清須市西枇杷島町古城');
ok($zip->set_number('4520002')->is_valid_number, '愛知県清須市西枇杷島町花咲');
ok($zip->set_number('4520003')->is_valid_number, '愛知県清須市西枇杷島町末広');
ok($zip->set_number('4520004')->is_valid_number, '愛知県清須市西枇杷島町大黒');
ok($zip->set_number('4520005')->is_valid_number, '愛知県清須市西枇杷島町恵比須');
ok($zip->set_number('4520006')->is_valid_number, '愛知県清須市西枇杷島町弁天');
ok($zip->set_number('4520007')->is_valid_number, '愛知県清須市西枇杷島町一反五畝割');
ok($zip->set_number('4520008')->is_valid_number, '愛知県清須市西枇杷島町地領');
ok($zip->set_number('4520009')->is_valid_number, '愛知県清須市西枇杷島町西八丁');
ok($zip->set_number('4520010')->is_valid_number, '愛知県清須市西枇杷島町稲株');
ok($zip->set_number('4520011')->is_valid_number, '愛知県清須市西枇杷島町城並');
ok($zip->set_number('4520012')->is_valid_number, '愛知県清須市西枇杷島町北大和');
ok($zip->set_number('4520013')->is_valid_number, '愛知県清須市西枇杷島町南大和');
ok($zip->set_number('4520014')->is_valid_number, '愛知県清須市西枇杷島町押花');
ok($zip->set_number('4520015')->is_valid_number, '愛知県清須市西枇杷島町泉');
ok($zip->set_number('4520016')->is_valid_number, '愛知県清須市西枇杷島町砂入');
ok($zip->set_number('4520017')->is_valid_number, '愛知県清須市西枇杷島町下砂入');
ok($zip->set_number('4520018')->is_valid_number, '愛知県清須市西枇杷島町住吉');
ok($zip->set_number('4520021')->is_valid_number, '愛知県清須市西枇杷島町小田井');
ok($zip->set_number('4520022')->is_valid_number, '愛知県清須市西枇杷島町上新');
ok($zip->set_number('4520023')->is_valid_number, '愛知県清須市西枇杷島町下新');
ok($zip->set_number('4520024')->is_valid_number, '愛知県清須市西枇杷島町片町');
ok($zip->set_number('4520025')->is_valid_number, '愛知県清須市西枇杷島町十軒裏');
ok($zip->set_number('4520026')->is_valid_number, '愛知県清須市西枇杷島町橋詰');
ok($zip->set_number('4520031')->is_valid_number, '愛知県清須市西枇杷島町宮前');
ok($zip->set_number('4520032')->is_valid_number, '愛知県清須市西枇杷島町養和');
ok($zip->set_number('4520033')->is_valid_number, '愛知県清須市西枇杷島町二見');
ok($zip->set_number('4520034')->is_valid_number, '愛知県清須市西枇杷島町日之出');
ok($zip->set_number('4520034')->is_valid_number, '愛知県清須市西枇杷島町日の出');
ok($zip->set_number('4520035')->is_valid_number, '愛知県清須市西枇杷島町問屋');
ok($zip->set_number('4520036')->is_valid_number, '愛知県清須市西枇杷島町南問屋');
ok($zip->set_number('4520037')->is_valid_number, '愛知県清須市枇杷島駅前東');
ok($zip->set_number('4520041')->is_valid_number, '愛知県清須市西枇杷島町小野田');
ok($zip->set_number('4520042')->is_valid_number, '愛知県清須市西枇杷島町川口');
ok($zip->set_number('4520043')->is_valid_number, '愛知県清須市西枇杷島町東六軒');
ok($zip->set_number('4520044')->is_valid_number, '愛知県清須市西枇杷島町南六軒');
ok($zip->set_number('4520045')->is_valid_number, '愛知県清須市西枇杷島町西六軒');
ok($zip->set_number('4520046')->is_valid_number, '愛知県清須市西枇杷島町西笹子原');
ok($zip->set_number('4520047')->is_valid_number, '愛知県清須市西枇杷島町東笹子原');
ok($zip->set_number('4520051')->is_valid_number, '愛知県清須市西枇杷島町大野');
ok($zip->set_number('4520052')->is_valid_number, '愛知県清須市西枇杷島町辰新田');
ok($zip->set_number('4520053')->is_valid_number, '愛知県清須市西枇杷島町南松原');
ok($zip->set_number('4520054')->is_valid_number, '愛知県清須市西枇杷島町南二ツ杁');
ok($zip->set_number('4520055')->is_valid_number, '愛知県清須市西枇杷島町北二ツ杁');
ok($zip->set_number('4520061')->is_valid_number, '愛知県清須市西枇杷島町小場塚');
ok($zip->set_number('4520062')->is_valid_number, '愛知県清須市西枇杷島町五畝割');
ok($zip->set_number('4520063')->is_valid_number, '愛知県清須市西枇杷島町七畝割');
ok($zip->set_number('4520064')->is_valid_number, '愛知県清須市西枇杷島町旭');
ok($zip->set_number('4520065')->is_valid_number, '愛知県清須市西枇杷島町芳野');
ok($zip->set_number('4520066')->is_valid_number, '愛知県清須市西枇杷島町芝野新田');
ok($zip->set_number('4520067')->is_valid_number, '愛知県清須市西枇杷島町替地');
ok($zip->set_number('4520068')->is_valid_number, '愛知県清須市西枇杷島町子新田');
ok($zip->set_number('4520801')->is_valid_number, '愛知県名古屋市西区清里町');
ok($zip->set_number('4520802')->is_valid_number, '愛知県名古屋市西区比良');
ok($zip->set_number('4520803')->is_valid_number, '愛知県名古屋市西区大野木');
ok($zip->set_number('4520804')->is_valid_number, '愛知県名古屋市西区坂井戸町');
ok($zip->set_number('4520805')->is_valid_number, '愛知県名古屋市西区市場木町');
ok($zip->set_number('4520806')->is_valid_number, '愛知県名古屋市西区五才美町');
ok($zip->set_number('4520807')->is_valid_number, '愛知県名古屋市西区歌里町');
ok($zip->set_number('4520808')->is_valid_number, '愛知県名古屋市西区宝地町');
ok($zip->set_number('4520809')->is_valid_number, '愛知県名古屋市西区花原町');
ok($zip->set_number('4520811')->is_valid_number, '愛知県名古屋市西区砂原町');
ok($zip->set_number('4520812')->is_valid_number, '愛知県名古屋市西区玉池町');
ok($zip->set_number('4520813')->is_valid_number, '愛知県名古屋市西区赤城町');
ok($zip->set_number('4520814')->is_valid_number, '愛知県名古屋市西区南川町');
ok($zip->set_number('4520815')->is_valid_number, '愛知県名古屋市西区八筋町');
ok($zip->set_number('4520816')->is_valid_number, '愛知県名古屋市西区貴生町');
ok($zip->set_number('4520817')->is_valid_number, '愛知県名古屋市西区二方町');
ok($zip->set_number('4520818')->is_valid_number, '愛知県名古屋市西区山田町');
ok($zip->set_number('4520821')->is_valid_number, '愛知県名古屋市西区上小田井');
ok($zip->set_number('4520822')->is_valid_number, '愛知県名古屋市西区中小田井');
ok($zip->set_number('4520823')->is_valid_number, '愛知県名古屋市西区あし原町');
ok($zip->set_number('4520824')->is_valid_number, '愛知県名古屋市西区こも原町');
ok($zip->set_number('4520831')->is_valid_number, '愛知県名古屋市西区円明町');
ok($zip->set_number('4520832')->is_valid_number, '愛知県名古屋市西区平出町');
ok($zip->set_number('4520833')->is_valid_number, '愛知県名古屋市西区山木');
ok($zip->set_number('4520834')->is_valid_number, '愛知県名古屋市西区木前町');
ok($zip->set_number('4520835')->is_valid_number, '愛知県名古屋市西区丸野');
ok($zip->set_number('4520836')->is_valid_number, '愛知県名古屋市西区新木町');
ok($zip->set_number('4520837')->is_valid_number, '愛知県名古屋市西区十方町');
ok($zip->set_number('4520838')->is_valid_number, '愛知県名古屋市西区長先町');
ok($zip->set_number('4520839')->is_valid_number, '愛知県名古屋市西区見寄町');
ok($zip->set_number('4520841')->is_valid_number, '愛知県名古屋市西区城西町');
ok($zip->set_number('4520842')->is_valid_number, '愛知県名古屋市西区城町');
ok($zip->set_number('4520843')->is_valid_number, '愛知県名古屋市西区平中町');
ok($zip->set_number('4520844')->is_valid_number, '愛知県名古屋市西区上橋町');
ok($zip->set_number('4520845')->is_valid_number, '愛知県名古屋市西区中沼町');
ok($zip->set_number('4520846')->is_valid_number, '愛知県名古屋市西区浮野町');
ok($zip->set_number('4520847')->is_valid_number, '愛知県名古屋市西区野南町');
ok($zip->set_number('4520848')->is_valid_number, '愛知県名古屋市西区西原町');
ok($zip->set_number('4520901')->is_valid_number, '愛知県清須市阿原');
ok($zip->set_number('4520902')->is_valid_number, '愛知県清須市助七(その他)');
ok($zip->set_number('4520903')->is_valid_number, '愛知県清須市助七(1、2丁目)');
ok($zip->set_number('4520904')->is_valid_number, '愛知県清須市東須ケ口');
ok($zip->set_number('4520905')->is_valid_number, '愛知県清須市須ケ口');
ok($zip->set_number('4520906')->is_valid_number, '愛知県清須市東外町');
ok($zip->set_number('4520907')->is_valid_number, '愛知県清須市鍋片');
ok($zip->set_number('4520908')->is_valid_number, '愛知県清須市寺野');
ok($zip->set_number('4520911')->is_valid_number, '愛知県清須市西須ケ口');
ok($zip->set_number('4520912')->is_valid_number, '愛知県清須市須ケ口駅前');
ok($zip->set_number('4520913')->is_valid_number, '愛知県清須市上河原');
ok($zip->set_number('4520914')->is_valid_number, '愛知県清須市土器野');
ok($zip->set_number('4520915')->is_valid_number, '愛知県清須市中河原');
ok($zip->set_number('4520916')->is_valid_number, '愛知県清須市下河原');
ok($zip->set_number('4520917')->is_valid_number, '愛知県清須市西堀江');
ok($zip->set_number('4520918')->is_valid_number, '愛知県清須市桃栄');
ok($zip->set_number('4520919')->is_valid_number, '愛知県清須市萩野');
ok($zip->set_number('4520931')->is_valid_number, '愛知県清須市一場');
ok($zip->set_number('4520932')->is_valid_number, '愛知県清須市朝日');
ok($zip->set_number('4520933')->is_valid_number, '愛知県清須市西田中');
ok($zip->set_number('4520934')->is_valid_number, '愛知県清須市大嶋');
ok($zip->set_number('4520935')->is_valid_number, '愛知県清須市北市場本町');
ok($zip->set_number('4520941')->is_valid_number, '愛知県清須市西市場');
ok($zip->set_number('4520942')->is_valid_number, '愛知県清須市清洲');
ok($zip->set_number('4520943')->is_valid_number, '愛知県清須市新清洲');
ok($zip->set_number('4520944')->is_valid_number, '愛知県清須市上条');
ok($zip->set_number('4520945')->is_valid_number, '愛知県清須市土田');
ok($zip->set_number('4520946')->is_valid_number, '愛知県清須市廻間');
ok($zip->set_number('4520947')->is_valid_number, '愛知県清須市花水木');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日明河原');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日一番割');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日壱屋敷');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日一本松');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日稲荷');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日杁前');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日午');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日落合');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日上丑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日上川畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日上河原');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日上須ケ田');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日上高畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日上堤クロ');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日上中割');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日河原');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日桑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日郷裏');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日郷前');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日小塚西');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日小塚南');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日小松生');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日三番割');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日下丑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日下河原');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日下堤クロ');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日下中割');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日定ノ割');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日新田畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日新堀');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日新堀北');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日須ケ田');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日須ケ畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日大河戸');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日高畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日堤クロ');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日寺廻り');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日樋');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日酉');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日中河原');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日長畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日西須ケ畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日西牧前');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日西牧南');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日西余部');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日二番割');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日弐屋敷');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日野方');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日八幡');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日八幡裏');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日八幡前');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日八幡南');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日東小塚');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日東須ケ畑');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日東出');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日二ツ池');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日振形');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日堀田');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日宮越');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日宮重');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日宮重町');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日向河原');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日屋敷');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日夢の森');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日四番割');
ok($zip->set_number('4520961')->is_valid_number, '愛知県清須市春日蓮花寺前');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日県');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日江先');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日川中');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日郷ケ島');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日高札');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日五反地');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日社子地');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日白弓');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日新田');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日新町');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日神明');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日砂賀東');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日立作');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日長久寺');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日天神');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日鳥出');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日中沼');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日流');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日野田町');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日冨士塚');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日舟付');
ok($zip->set_number('4520962')->is_valid_number, '愛知県清須市春日焼田');
ok($zip->set_number('4520963')->is_valid_number, '愛知県清須市下津町');
ok($zip->set_number('4530000')->is_valid_number, '愛知県名古屋市中村区以下に掲載がない場合');
ok($zip->set_number('4530002')->is_valid_number, '愛知県名古屋市中村区名駅(1-1-8、1-1-12、1-1-13、1-1-14、1-3-4、');
ok($zip->set_number('4530002')->is_valid_number, '愛知県名古屋市中村区1-3-7)');
ok($zip->set_number('4530011')->is_valid_number, '愛知県名古屋市中村区千原町');
ok($zip->set_number('4530012')->is_valid_number, '愛知県名古屋市中村区井深町');
ok($zip->set_number('4530013')->is_valid_number, '愛知県名古屋市中村区亀島');
ok($zip->set_number('4530014')->is_valid_number, '愛知県名古屋市中村区則武');
ok($zip->set_number('4530015')->is_valid_number, '愛知県名古屋市中村区椿町');
ok($zip->set_number('4530016')->is_valid_number, '愛知県名古屋市中村区竹橋町');
ok($zip->set_number('4530017')->is_valid_number, '愛知県名古屋市中村区則武本通');
ok($zip->set_number('4530018')->is_valid_number, '愛知県名古屋市中村区佐古前町');
ok($zip->set_number('4530021')->is_valid_number, '愛知県名古屋市中村区松原町');
ok($zip->set_number('4530022')->is_valid_number, '愛知県名古屋市中村区中島町');
ok($zip->set_number('4530023')->is_valid_number, '愛知県名古屋市中村区若宮町');
ok($zip->set_number('4530024')->is_valid_number, '愛知県名古屋市中村区名楽町');
ok($zip->set_number('4530025')->is_valid_number, '愛知県名古屋市中村区賑町');
ok($zip->set_number('4530026')->is_valid_number, '愛知県名古屋市中村区羽衣町');
ok($zip->set_number('4530027')->is_valid_number, '愛知県名古屋市中村区大門町');
ok($zip->set_number('4530028')->is_valid_number, '愛知県名古屋市中村区寿町');
ok($zip->set_number('4530029')->is_valid_number, '愛知県名古屋市中村区日吉町');
ok($zip->set_number('4530031')->is_valid_number, '愛知県名古屋市中村区新富町');
ok($zip->set_number('4530032')->is_valid_number, '愛知県名古屋市中村区塩池町');
ok($zip->set_number('4530033')->is_valid_number, '愛知県名古屋市中村区栄生町');
ok($zip->set_number('4530034')->is_valid_number, '愛知県名古屋市中村区大日町');
ok($zip->set_number('4530035')->is_valid_number, '愛知県名古屋市中村区十王町');
ok($zip->set_number('4530036')->is_valid_number, '愛知県名古屋市中村区森田町');
ok($zip->set_number('4530037')->is_valid_number, '愛知県名古屋市中村区高道町');
ok($zip->set_number('4530038')->is_valid_number, '愛知県名古屋市中村区猪之越町');
ok($zip->set_number('4530041')->is_valid_number, '愛知県名古屋市中村区本陣通');
ok($zip->set_number('4530042')->is_valid_number, '愛知県名古屋市中村区大秋町');
ok($zip->set_number('4530043')->is_valid_number, '愛知県名古屋市中村区上ノ宮町');
ok($zip->set_number('4530044')->is_valid_number, '愛知県名古屋市中村区鳥居通');
ok($zip->set_number('4530045')->is_valid_number, '愛知県名古屋市中村区藤江町');
ok($zip->set_number('4530046')->is_valid_number, '愛知県名古屋市中村区道下町');
ok($zip->set_number('4530047')->is_valid_number, '愛知県名古屋市中村区元中村町');
ok($zip->set_number('4530051')->is_valid_number, '愛知県名古屋市中村区豊幡町');
ok($zip->set_number('4530052')->is_valid_number, '愛知県名古屋市中村区森末町');
ok($zip->set_number('4530053')->is_valid_number, '愛知県名古屋市中村区中村町');
ok($zip->set_number('4530054')->is_valid_number, '愛知県名古屋市中村区鳥居西通');
ok($zip->set_number('4530055')->is_valid_number, '愛知県名古屋市中村区香取町');
ok($zip->set_number('4530056')->is_valid_number, '愛知県名古屋市中村区砂田町');
ok($zip->set_number('4530057')->is_valid_number, '愛知県名古屋市中村区稲葉地本通');
ok($zip->set_number('4530058')->is_valid_number, '愛知県名古屋市中村区城屋敷町');
ok($zip->set_number('4530061')->is_valid_number, '愛知県名古屋市中村区日比津町');
ok($zip->set_number('4530062')->is_valid_number, '愛知県名古屋市中村区諏訪町');
ok($zip->set_number('4530063')->is_valid_number, '愛知県名古屋市中村区東宿町');
ok($zip->set_number('4530064')->is_valid_number, '愛知県名古屋市中村区草薙町');
ok($zip->set_number('4530065')->is_valid_number, '愛知県名古屋市中村区靖国町');
ok($zip->set_number('4530066')->is_valid_number, '愛知県名古屋市中村区稲上町');
ok($zip->set_number('4530067')->is_valid_number, '愛知県名古屋市中村区宿跡町');
ok($zip->set_number('4530068')->is_valid_number, '愛知県名古屋市中村区菊水町');
ok($zip->set_number('4530069')->is_valid_number, '愛知県名古屋市中村区橋下町');
ok($zip->set_number('4530801')->is_valid_number, '愛知県名古屋市中村区太閤');
ok($zip->set_number('4530802')->is_valid_number, '愛知県名古屋市中村区下米野町');
ok($zip->set_number('4530803')->is_valid_number, '愛知県名古屋市中村区長戸井町');
ok($zip->set_number('4530804')->is_valid_number, '愛知県名古屋市中村区黄金通');
ok($zip->set_number('4530805')->is_valid_number, '愛知県名古屋市中村区深川町');
ok($zip->set_number('4530806')->is_valid_number, '愛知県名古屋市中村区大正町');
ok($zip->set_number('4530807')->is_valid_number, '愛知県名古屋市中村区権現通');
ok($zip->set_number('4530808')->is_valid_number, '愛知県名古屋市中村区郷前町');
ok($zip->set_number('4530809')->is_valid_number, '愛知県名古屋市中村区上米野町');
ok($zip->set_number('4530811')->is_valid_number, '愛知県名古屋市中村区太閤通');
ok($zip->set_number('4530812')->is_valid_number, '愛知県名古屋市中村区西米野町');
ok($zip->set_number('4530813')->is_valid_number, '愛知県名古屋市中村区二ツ橋町');
ok($zip->set_number('4530814')->is_valid_number, '愛知県名古屋市中村区熊野町');
ok($zip->set_number('4530815')->is_valid_number, '愛知県名古屋市中村区北畑町');
ok($zip->set_number('4530816')->is_valid_number, '愛知県名古屋市中村区京田町');
ok($zip->set_number('4530817')->is_valid_number, '愛知県名古屋市中村区白子町');
ok($zip->set_number('4530818')->is_valid_number, '愛知県名古屋市中村区千成通');
ok($zip->set_number('4530819')->is_valid_number, '愛知県名古屋市中村区城主町');
ok($zip->set_number('4530821')->is_valid_number, '愛知県名古屋市中村区大宮町');
ok($zip->set_number('4530822')->is_valid_number, '愛知県名古屋市中村区名西通');
ok($zip->set_number('4530823')->is_valid_number, '愛知県名古屋市中村区日ノ宮町');
ok($zip->set_number('4530824')->is_valid_number, '愛知県名古屋市中村区北浦町');
ok($zip->set_number('4530825')->is_valid_number, '愛知県名古屋市中村区沖田町');
ok($zip->set_number('4530826')->is_valid_number, '愛知県名古屋市中村区鈍池町');
ok($zip->set_number('4530827')->is_valid_number, '愛知県名古屋市中村区下中村町');
ok($zip->set_number('4530828')->is_valid_number, '愛知県名古屋市中村区中村本町');
ok($zip->set_number('4530831')->is_valid_number, '愛知県名古屋市中村区中村中町');
ok($zip->set_number('4530832')->is_valid_number, '愛知県名古屋市中村区乾出町');
ok($zip->set_number('4530833')->is_valid_number, '愛知県名古屋市中村区押木田町');
ok($zip->set_number('4530834')->is_valid_number, '愛知県名古屋市中村区豊国通');
ok($zip->set_number('4530835')->is_valid_number, '愛知県名古屋市中村区上石川町');
ok($zip->set_number('4530836')->is_valid_number, '愛知県名古屋市中村区五反城町');
ok($zip->set_number('4530837')->is_valid_number, '愛知県名古屋市中村区二瀬町');
ok($zip->set_number('4530838')->is_valid_number, '愛知県名古屋市中村区向島町');
ok($zip->set_number('4530839')->is_valid_number, '愛知県名古屋市中村区長筬町');
ok($zip->set_number('4530841')->is_valid_number, '愛知県名古屋市中村区稲葉地町');
ok($zip->set_number('4530842')->is_valid_number, '愛知県名古屋市中村区剣町');
ok($zip->set_number('4530843')->is_valid_number, '愛知県名古屋市中村区鴨付町');
ok($zip->set_number('4530844')->is_valid_number, '愛知県名古屋市中村区小鴨町');
ok($zip->set_number('4530845')->is_valid_number, '愛知県名古屋市中村区宮塚町');
ok($zip->set_number('4530846')->is_valid_number, '愛知県名古屋市中村区西栄町');
ok($zip->set_number('4530847')->is_valid_number, '愛知県名古屋市中村区岩上町');
ok($zip->set_number('4530848')->is_valid_number, '愛知県名古屋市中村区荒輪井町');
ok($zip->set_number('4530849')->is_valid_number, '愛知県名古屋市中村区稲西町');
ok($zip->set_number('4530851')->is_valid_number, '愛知県名古屋市中村区畑江通');
ok($zip->set_number('4530852')->is_valid_number, '愛知県名古屋市中村区角割町');
ok($zip->set_number('4530853')->is_valid_number, '愛知県名古屋市中村区牛田通');
ok($zip->set_number('4530854')->is_valid_number, '愛知県名古屋市中村区高須賀町');
ok($zip->set_number('4530855')->is_valid_number, '愛知県名古屋市中村区烏森町');
ok($zip->set_number('4530856')->is_valid_number, '愛知県名古屋市中村区並木');
ok($zip->set_number('4530857')->is_valid_number, '愛知県名古屋市中村区長草町');
ok($zip->set_number('4530858')->is_valid_number, '愛知県名古屋市中村区野田町');
ok($zip->set_number('4530859')->is_valid_number, '愛知県名古屋市中村区野上町');
ok($zip->set_number('4530861')->is_valid_number, '愛知県名古屋市中村区岩塚本通');
ok($zip->set_number('4530862')->is_valid_number, '愛知県名古屋市中村区岩塚町');
ok($zip->set_number('4530863')->is_valid_number, '愛知県名古屋市中村区八社');
ok($zip->set_number('4530864')->is_valid_number, '愛知県名古屋市中村区横前町');
ok($zip->set_number('4530865')->is_valid_number, '愛知県名古屋市中村区川前町');
ok($zip->set_number('4530866')->is_valid_number, '愛知県名古屋市中村区横井');
ok($zip->set_number('4530867')->is_valid_number, '愛知県名古屋市中村区横井町');
ok($zip->set_number('4530871')->is_valid_number, '愛知県名古屋市中村区牧野町');
ok($zip->set_number('4530872')->is_valid_number, '愛知県名古屋市中村区平池町(次のビルを除く)');
ok($zip->set_number('4530873')->is_valid_number, '愛知県名古屋市中村区運河町');
ok($zip->set_number('4536101')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(1階)');
ok($zip->set_number('4536102')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(2階)');
ok($zip->set_number('4536103')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(3階)');
ok($zip->set_number('4536104')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(4階)');
ok($zip->set_number('4536105')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(5階)');
ok($zip->set_number('4536106')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(6階)');
ok($zip->set_number('4536107')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(7階)');
ok($zip->set_number('4536108')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(8階)');
ok($zip->set_number('4536109')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(9階)');
ok($zip->set_number('4536110')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(10階)');
ok($zip->set_number('4536111')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(11階)');
ok($zip->set_number('4536112')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(12階)');
ok($zip->set_number('4536113')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(13階)');
ok($zip->set_number('4536114')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(14階)');
ok($zip->set_number('4536115')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(15階)');
ok($zip->set_number('4536116')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(16階)');
ok($zip->set_number('4536117')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(17階)');
ok($zip->set_number('4536118')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(18階)');
ok($zip->set_number('4536119')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(19階)');
ok($zip->set_number('4536120')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(20階)');
ok($zip->set_number('4536121')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(21階)');
ok($zip->set_number('4536122')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(22階)');
ok($zip->set_number('4536123')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(23階)');
ok($zip->set_number('4536124')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(24階)');
ok($zip->set_number('4536125')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(25階)');
ok($zip->set_number('4536126')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(26階)');
ok($zip->set_number('4536127')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(27階)');
ok($zip->set_number('4536128')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(28階)');
ok($zip->set_number('4536129')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(29階)');
ok($zip->set_number('4536130')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(30階)');
ok($zip->set_number('4536131')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(31階)');
ok($zip->set_number('4536132')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(32階)');
ok($zip->set_number('4536133')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(33階)');
ok($zip->set_number('4536134')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(34階)');
ok($zip->set_number('4536135')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(35階)');
ok($zip->set_number('4536136')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(36階)');
ok($zip->set_number('4536190')->is_valid_number, '愛知県名古屋市中村区平池町グローバルゲート(地階・階層不明)');
ok($zip->set_number('4540000')->is_valid_number, '愛知県名古屋市中川区以下に掲載がない場合');
ok($zip->set_number('4540001')->is_valid_number, '愛知県名古屋市中川区運河町');
ok($zip->set_number('4540002')->is_valid_number, '愛知県名古屋市中川区運河通');
ok($zip->set_number('4540003')->is_valid_number, '愛知県名古屋市中川区松重町');
ok($zip->set_number('4540004')->is_valid_number, '愛知県名古屋市中川区西日置');
ok($zip->set_number('4540005')->is_valid_number, '愛知県名古屋市中川区西日置町');
ok($zip->set_number('4540006')->is_valid_number, '愛知県名古屋市中川区柳堀町');
ok($zip->set_number('4540007')->is_valid_number, '愛知県名古屋市中川区広住町');
ok($zip->set_number('4540011')->is_valid_number, '愛知県名古屋市中川区山王');
ok($zip->set_number('4540012')->is_valid_number, '愛知県名古屋市中川区尾頭橋');
ok($zip->set_number('4540013')->is_valid_number, '愛知県名古屋市中川区八熊');
ok($zip->set_number('4540014')->is_valid_number, '愛知県名古屋市中川区柳川町');
ok($zip->set_number('4540015')->is_valid_number, '愛知県名古屋市中川区南八熊町');
ok($zip->set_number('4540016')->is_valid_number, '愛知県名古屋市中川区幡野町');
ok($zip->set_number('4540021')->is_valid_number, '愛知県名古屋市中川区横堀町');
ok($zip->set_number('4540022')->is_valid_number, '愛知県名古屋市中川区露橋');
ok($zip->set_number('4540023')->is_valid_number, '愛知県名古屋市中川区石場町');
ok($zip->set_number('4540024')->is_valid_number, '愛知県名古屋市中川区柳島町');
ok($zip->set_number('4540025')->is_valid_number, '愛知県名古屋市中川区前並町');
ok($zip->set_number('4540026')->is_valid_number, '愛知県名古屋市中川区笈瀬町');
ok($zip->set_number('4540027')->is_valid_number, '愛知県名古屋市中川区広川町');
ok($zip->set_number('4540028')->is_valid_number, '愛知県名古屋市中川区露橋町');
ok($zip->set_number('4540031')->is_valid_number, '愛知県名古屋市中川区八幡本通');
ok($zip->set_number('4540032')->is_valid_number, '愛知県名古屋市中川区荒江町');
ok($zip->set_number('4540033')->is_valid_number, '愛知県名古屋市中川区五女子');
ok($zip->set_number('4540034')->is_valid_number, '愛知県名古屋市中川区五女子町');
ok($zip->set_number('4540035')->is_valid_number, '愛知県名古屋市中川区八熊通');
ok($zip->set_number('4540036')->is_valid_number, '愛知県名古屋市中川区二女子町');
ok($zip->set_number('4540037')->is_valid_number, '愛知県名古屋市中川区富川町');
ok($zip->set_number('4540041')->is_valid_number, '愛知県名古屋市中川区八神町');
ok($zip->set_number('4540042')->is_valid_number, '愛知県名古屋市中川区応仁町');
ok($zip->set_number('4540043')->is_valid_number, '愛知県名古屋市中川区牛立町');
ok($zip->set_number('4540044')->is_valid_number, '愛知県名古屋市中川区荒越町');
ok($zip->set_number('4540045')->is_valid_number, '愛知県名古屋市中川区丹後町');
ok($zip->set_number('4540046')->is_valid_number, '愛知県名古屋市中川区神郷町');
ok($zip->set_number('4540047')->is_valid_number, '愛知県名古屋市中川区中野本町');
ok($zip->set_number('4540048')->is_valid_number, '愛知県名古屋市中川区元中野町');
ok($zip->set_number('4540049')->is_valid_number, '愛知県名古屋市中川区清川町');
ok($zip->set_number('4540051')->is_valid_number, '愛知県名古屋市中川区大山町');
ok($zip->set_number('4540052')->is_valid_number, '愛知県名古屋市中川区花塚町');
ok($zip->set_number('4540053')->is_valid_number, '愛知県名古屋市中川区外新町');
ok($zip->set_number('4540054')->is_valid_number, '愛知県名古屋市中川区八剱町');
ok($zip->set_number('4540055')->is_valid_number, '愛知県名古屋市中川区十番町');
ok($zip->set_number('4540056')->is_valid_number, '愛知県名古屋市中川区十一番町');
ok($zip->set_number('4540057')->is_valid_number, '愛知県名古屋市中川区熱田新田東組');
ok($zip->set_number('4540058')->is_valid_number, '愛知県名古屋市中川区玉川町');
ok($zip->set_number('4540059')->is_valid_number, '愛知県名古屋市中川区福川町');
ok($zip->set_number('4540801')->is_valid_number, '愛知県名古屋市中川区百船町');
ok($zip->set_number('4540802')->is_valid_number, '愛知県名古屋市中川区福住町');
ok($zip->set_number('4540803')->is_valid_number, '愛知県名古屋市中川区豊成町');
ok($zip->set_number('4540804')->is_valid_number, '愛知県名古屋市中川区月島町');
ok($zip->set_number('4540805')->is_valid_number, '愛知県名古屋市中川区舟戸町');
ok($zip->set_number('4540806')->is_valid_number, '愛知県名古屋市中川区澄池町');
ok($zip->set_number('4540807')->is_valid_number, '愛知県名古屋市中川区愛知町');
ok($zip->set_number('4540808')->is_valid_number, '愛知県名古屋市中川区九重町');
ok($zip->set_number('4540811')->is_valid_number, '愛知県名古屋市中川区三ツ池町');
ok($zip->set_number('4540812')->is_valid_number, '愛知県名古屋市中川区五月通');
ok($zip->set_number('4540813')->is_valid_number, '愛知県名古屋市中川区乗越町');
ok($zip->set_number('4540814')->is_valid_number, '愛知県名古屋市中川区五月南通');
ok($zip->set_number('4540815')->is_valid_number, '愛知県名古屋市中川区長良町');
ok($zip->set_number('4540816')->is_valid_number, '愛知県名古屋市中川区中京南通');
ok($zip->set_number('4540817')->is_valid_number, '愛知県名古屋市中川区南脇町');
ok($zip->set_number('4540818')->is_valid_number, '愛知県名古屋市中川区松葉町');
ok($zip->set_number('4540819')->is_valid_number, '愛知県名古屋市中川区烏森町');
ok($zip->set_number('4540821')->is_valid_number, '愛知県名古屋市中川区宗円町');
ok($zip->set_number('4540822')->is_valid_number, '愛知県名古屋市中川区四女子町');
ok($zip->set_number('4540823')->is_valid_number, '愛知県名古屋市中川区富船町');
ok($zip->set_number('4540824')->is_valid_number, '愛知県名古屋市中川区蔦元町');
ok($zip->set_number('4540825')->is_valid_number, '愛知県名古屋市中川区好本町');
ok($zip->set_number('4540826')->is_valid_number, '愛知県名古屋市中川区小本本町');
ok($zip->set_number('4540827')->is_valid_number, '愛知県名古屋市中川区辻畑町');
ok($zip->set_number('4540828')->is_valid_number, '愛知県名古屋市中川区小本');
ok($zip->set_number('4540829')->is_valid_number, '愛知県名古屋市中川区小本町');
ok($zip->set_number('4540831')->is_valid_number, '愛知県名古屋市中川区三ツ屋町');
ok($zip->set_number('4540832')->is_valid_number, '愛知県名古屋市中川区清船町');
ok($zip->set_number('4540833')->is_valid_number, '愛知県名古屋市中川区上脇町');
ok($zip->set_number('4540834')->is_valid_number, '愛知県名古屋市中川区丸米町');
ok($zip->set_number('4540835')->is_valid_number, '愛知県名古屋市中川区八家町');
ok($zip->set_number('4540836')->is_valid_number, '愛知県名古屋市中川区福船町');
ok($zip->set_number('4540837')->is_valid_number, '愛知県名古屋市中川区中野新町');
ok($zip->set_number('4540838')->is_valid_number, '愛知県名古屋市中川区太平通');
ok($zip->set_number('4540839')->is_valid_number, '愛知県名古屋市中川区篠原橋通');
ok($zip->set_number('4540841')->is_valid_number, '愛知県名古屋市中川区押元町');
ok($zip->set_number('4540842')->is_valid_number, '愛知県名古屋市中川区宮脇町');
ok($zip->set_number('4540843')->is_valid_number, '愛知県名古屋市中川区大畑町');
ok($zip->set_number('4540844')->is_valid_number, '愛知県名古屋市中川区葉池町');
ok($zip->set_number('4540845')->is_valid_number, '愛知県名古屋市中川区馬手町');
ok($zip->set_number('4540846')->is_valid_number, '愛知県名古屋市中川区上流町');
ok($zip->set_number('4540847')->is_valid_number, '愛知県名古屋市中川区細米町');
ok($zip->set_number('4540848')->is_valid_number, '愛知県名古屋市中川区松ノ木町');
ok($zip->set_number('4540849')->is_valid_number, '愛知県名古屋市中川区小塚町');
ok($zip->set_number('4540851')->is_valid_number, '愛知県名古屋市中川区北江町');
ok($zip->set_number('4540852')->is_valid_number, '愛知県名古屋市中川区昭和橋通');
ok($zip->set_number('4540853')->is_valid_number, '愛知県名古屋市中川区玉船町');
ok($zip->set_number('4540854')->is_valid_number, '愛知県名古屋市中川区松年町');
ok($zip->set_number('4540855')->is_valid_number, '愛知県名古屋市中川区昭明町');
ok($zip->set_number('4540856')->is_valid_number, '愛知県名古屋市中川区小碓通');
ok($zip->set_number('4540857')->is_valid_number, '愛知県名古屋市中川区明徳町');
ok($zip->set_number('4540858')->is_valid_number, '愛知県名古屋市中川区正徳町');
ok($zip->set_number('4540859')->is_valid_number, '愛知県名古屋市中川区法蔵町');
ok($zip->set_number('4540860')->is_valid_number, '愛知県名古屋市中川区畑田町');
ok($zip->set_number('4540861')->is_valid_number, '愛知県名古屋市中川区荒子町');
ok($zip->set_number('4540862')->is_valid_number, '愛知県名古屋市中川区的場町');
ok($zip->set_number('4540863')->is_valid_number, '愛知県名古屋市中川区大塩町');
ok($zip->set_number('4540864')->is_valid_number, '愛知県名古屋市中川区平戸町');
ok($zip->set_number('4540865')->is_valid_number, '愛知県名古屋市中川区掛入町');
ok($zip->set_number('4540866')->is_valid_number, '愛知県名古屋市中川区東中島町');
ok($zip->set_number('4540867')->is_valid_number, '愛知県名古屋市中川区広田町');
ok($zip->set_number('4540868')->is_valid_number, '愛知県名古屋市中川区草平町');
ok($zip->set_number('4540869')->is_valid_number, '愛知県名古屋市中川区荒子');
ok($zip->set_number('4540871')->is_valid_number, '愛知県名古屋市中川区柳森町');
ok($zip->set_number('4540872')->is_valid_number, '愛知県名古屋市中川区万町');
ok($zip->set_number('4540873')->is_valid_number, '愛知県名古屋市中川区上高畑');
ok($zip->set_number('4540874')->is_valid_number, '愛知県名古屋市中川区吉良町');
ok($zip->set_number('4540875')->is_valid_number, '愛知県名古屋市中川区小城町');
ok($zip->set_number('4540876')->is_valid_number, '愛知県名古屋市中川区若山町');
ok($zip->set_number('4540877')->is_valid_number, '愛知県名古屋市中川区八田町');
ok($zip->set_number('4540901')->is_valid_number, '愛知県名古屋市中川区岩塚町(本地)');
ok($zip->set_number('4540902')->is_valid_number, '愛知県名古屋市中川区花池町');
ok($zip->set_number('4540903')->is_valid_number, '愛知県名古屋市中川区柳瀬町');
ok($zip->set_number('4540904')->is_valid_number, '愛知県名古屋市中川区八田本町');
ok($zip->set_number('4540905')->is_valid_number, '愛知県名古屋市中川区一柳通');
ok($zip->set_number('4540906')->is_valid_number, '愛知県名古屋市中川区開平町');
ok($zip->set_number('4540907')->is_valid_number, '愛知県名古屋市中川区柳田町');
ok($zip->set_number('4540911')->is_valid_number, '愛知県名古屋市中川区高畑');
ok($zip->set_number('4540912')->is_valid_number, '愛知県名古屋市中川区野田');
ok($zip->set_number('4540913')->is_valid_number, '愛知県名古屋市中川区土野町');
ok($zip->set_number('4540914')->is_valid_number, '愛知県名古屋市中川区本前田町');
ok($zip->set_number('4540915')->is_valid_number, '愛知県名古屋市中川区横井');
ok($zip->set_number('4540916')->is_valid_number, '愛知県名古屋市中川区川前町');
ok($zip->set_number('4540917')->is_valid_number, '愛知県名古屋市中川区横前町');
ok($zip->set_number('4540921')->is_valid_number, '愛知県名古屋市中川区中郷');
ok($zip->set_number('4540922')->is_valid_number, '愛知県名古屋市中川区荒中町');
ok($zip->set_number('4540923')->is_valid_number, '愛知県名古屋市中川区打出本町');
ok($zip->set_number('4540924')->is_valid_number, '愛知県名古屋市中川区打出町');
ok($zip->set_number('4540925')->is_valid_number, '愛知県名古屋市中川区中須町');
ok($zip->set_number('4540926')->is_valid_number, '愛知県名古屋市中川区打出');
ok($zip->set_number('4540927')->is_valid_number, '愛知県名古屋市中川区打中');
ok($zip->set_number('4540931')->is_valid_number, '愛知県名古屋市中川区中花町');
ok($zip->set_number('4540932')->is_valid_number, '愛知県名古屋市中川区中島新町');
ok($zip->set_number('4540933')->is_valid_number, '愛知県名古屋市中川区法華');
ok($zip->set_number('4540934')->is_valid_number, '愛知県名古屋市中川区西中島');
ok($zip->set_number('4540935')->is_valid_number, '愛知県名古屋市中川区東起町');
ok($zip->set_number('4540936')->is_valid_number, '愛知県名古屋市中川区高杉町');
ok($zip->set_number('4540937')->is_valid_number, '愛知県名古屋市中川区法華西町');
ok($zip->set_number('4540941')->is_valid_number, '愛知県名古屋市中川区前田西町');
ok($zip->set_number('4540942')->is_valid_number, '愛知県名古屋市中川区富田町前田');
ok($zip->set_number('4540943')->is_valid_number, '愛知県名古屋市中川区大当郎');
ok($zip->set_number('4540944')->is_valid_number, '愛知県名古屋市中川区大蟷螂町');
ok($zip->set_number('4540945')->is_valid_number, '愛知県名古屋市中川区下之一色町');
ok($zip->set_number('4540946')->is_valid_number, '愛知県名古屋市中川区一色新町');
ok($zip->set_number('4540947')->is_valid_number, '愛知県名古屋市中川区助光');
ok($zip->set_number('4540951')->is_valid_number, '愛知県名古屋市中川区榎津西町');
ok($zip->set_number('4540952')->is_valid_number, '愛知県名古屋市中川区榎松町');
ok($zip->set_number('4540953')->is_valid_number, '愛知県名古屋市中川区富田町榎津');
ok($zip->set_number('4540954')->is_valid_number, '愛知県名古屋市中川区江松');
ok($zip->set_number('4540954')->is_valid_number, '愛知県名古屋市中川区富田町江松');
ok($zip->set_number('4540955')->is_valid_number, '愛知県名古屋市中川区富田町包里');
ok($zip->set_number('4540956')->is_valid_number, '愛知県名古屋市中川区富田町供米田');
ok($zip->set_number('4540957')->is_valid_number, '愛知県名古屋市中川区かの里');
ok($zip->set_number('4540958')->is_valid_number, '愛知県名古屋市中川区東かの里町');
ok($zip->set_number('4540959')->is_valid_number, '愛知県名古屋市中川区江松西町');
ok($zip->set_number('4540961')->is_valid_number, '愛知県名古屋市中川区戸田明正');
ok($zip->set_number('4540961')->is_valid_number, '愛知県名古屋市中川区富田町戸田');
ok($zip->set_number('4540962')->is_valid_number, '愛知県名古屋市中川区戸田');
ok($zip->set_number('4540963')->is_valid_number, '愛知県名古屋市中川区水里');
ok($zip->set_number('4540964')->is_valid_number, '愛知県名古屋市中川区富永');
ok($zip->set_number('4540965')->is_valid_number, '愛知県名古屋市中川区福島');
ok($zip->set_number('4540966')->is_valid_number, '愛知県名古屋市中川区戸田ゆたか');
ok($zip->set_number('4540967')->is_valid_number, '愛知県名古屋市中川区戸田西');
ok($zip->set_number('4540971')->is_valid_number, '愛知県名古屋市中川区富田町千音寺');
ok($zip->set_number('4540972')->is_valid_number, '愛知県名古屋市中川区新家');
ok($zip->set_number('4540973')->is_valid_number, '愛知県名古屋市中川区富田町服部');
ok($zip->set_number('4540974')->is_valid_number, '愛知県名古屋市中川区島井町');
ok($zip->set_number('4540975')->is_valid_number, '愛知県名古屋市中川区七反田町');
ok($zip->set_number('4540976')->is_valid_number, '愛知県名古屋市中川区服部');
ok($zip->set_number('4540981')->is_valid_number, '愛知県名古屋市中川区吉津');
ok($zip->set_number('4540982')->is_valid_number, '愛知県名古屋市中川区西伏屋');
ok($zip->set_number('4540983')->is_valid_number, '愛知県名古屋市中川区東春田');
ok($zip->set_number('4540984')->is_valid_number, '愛知県名古屋市中川区供米田');
ok($zip->set_number('4540985')->is_valid_number, '愛知県名古屋市中川区春田');
ok($zip->set_number('4540986')->is_valid_number, '愛知県名古屋市中川区富田町春田');
ok($zip->set_number('4540991')->is_valid_number, '愛知県名古屋市中川区大地');
ok($zip->set_number('4540992')->is_valid_number, '愛知県名古屋市中川区富田町万場');
ok($zip->set_number('4540993')->is_valid_number, '愛知県名古屋市中川区富田町松下');
ok($zip->set_number('4540994')->is_valid_number, '愛知県名古屋市中川区長須賀');
ok($zip->set_number('4540995')->is_valid_number, '愛知県名古屋市中川区富田町伏屋');
ok($zip->set_number('4540996')->is_valid_number, '愛知県名古屋市中川区伏屋');
ok($zip->set_number('4540997')->is_valid_number, '愛知県名古屋市中川区万場');
ok($zip->set_number('4550000')->is_valid_number, '愛知県名古屋市港区以下に掲載がない場合');
ok($zip->set_number('4550001')->is_valid_number, '愛知県名古屋市港区七番町');
ok($zip->set_number('4550002')->is_valid_number, '愛知県名古屋市港区東海通');
ok($zip->set_number('4550003')->is_valid_number, '愛知県名古屋市港区辰巳町');
ok($zip->set_number('4550004')->is_valid_number, '愛知県名古屋市港区津金');
ok($zip->set_number('4550005')->is_valid_number, '愛知県名古屋市港区新川町');
ok($zip->set_number('4550006')->is_valid_number, '愛知県名古屋市港区南十一番町');
ok($zip->set_number('4550007')->is_valid_number, '愛知県名古屋市港区南十番町');
ok($zip->set_number('4550008')->is_valid_number, '愛知県名古屋市港区九番町');
ok($zip->set_number('4550011')->is_valid_number, '愛知県名古屋市港区千年');
ok($zip->set_number('4550012')->is_valid_number, '愛知県名古屋市港区作倉町');
ok($zip->set_number('4550013')->is_valid_number, '愛知県名古屋市港区港陽');
ok($zip->set_number('4550014')->is_valid_number, '愛知県名古屋市港区港楽');
ok($zip->set_number('4550015')->is_valid_number, '愛知県名古屋市港区港栄');
ok($zip->set_number('4550016')->is_valid_number, '愛知県名古屋市港区河口町');
ok($zip->set_number('4550017')->is_valid_number, '愛知県名古屋市港区金川町');
ok($zip->set_number('4550018')->is_valid_number, '愛知県名古屋市港区港明');
ok($zip->set_number('4550021')->is_valid_number, '愛知県名古屋市港区木場町');
ok($zip->set_number('4550022')->is_valid_number, '愛知県名古屋市港区竜宮町');
ok($zip->set_number('4550023')->is_valid_number, '愛知県名古屋市港区東築地町');
ok($zip->set_number('4550024')->is_valid_number, '愛知県名古屋市港区大江町');
ok($zip->set_number('4550025')->is_valid_number, '愛知県名古屋市港区本星崎町');
ok($zip->set_number('4550026')->is_valid_number, '愛知県名古屋市港区昭和町');
ok($zip->set_number('4550027')->is_valid_number, '愛知県名古屋市港区船見町');
ok($zip->set_number('4550028')->is_valid_number, '愛知県名古屋市港区潮見町');
ok($zip->set_number('4550031')->is_valid_number, '愛知県名古屋市港区千鳥');
ok($zip->set_number('4550032')->is_valid_number, '愛知県名古屋市港区入船');
ok($zip->set_number('4550033')->is_valid_number, '愛知県名古屋市港区港町');
ok($zip->set_number('4550034')->is_valid_number, '愛知県名古屋市港区西倉町');
ok($zip->set_number('4550035')->is_valid_number, '愛知県名古屋市港区熱田前新田');
ok($zip->set_number('4550036')->is_valid_number, '愛知県名古屋市港区浜');
ok($zip->set_number('4550037')->is_valid_number, '愛知県名古屋市港区名港');
ok($zip->set_number('4550041')->is_valid_number, '愛知県名古屋市港区幸町');
ok($zip->set_number('4550042')->is_valid_number, '愛知県名古屋市港区佐野町');
ok($zip->set_number('4550043')->is_valid_number, '愛知県名古屋市港区魁町');
ok($zip->set_number('4550044')->is_valid_number, '愛知県名古屋市港区築三町');
ok($zip->set_number('4550045')->is_valid_number, '愛知県名古屋市港区築地町');
ok($zip->set_number('4550046')->is_valid_number, '愛知県名古屋市港区大手町');
ok($zip->set_number('4550047')->is_valid_number, '愛知県名古屋市港区中之島通');
ok($zip->set_number('4550051')->is_valid_number, '愛知県名古屋市港区中川本町');
ok($zip->set_number('4550052')->is_valid_number, '愛知県名古屋市港区いろは町');
ok($zip->set_number('4550053')->is_valid_number, '愛知県名古屋市港区名四町');
ok($zip->set_number('4550054')->is_valid_number, '愛知県名古屋市港区遠若町');
ok($zip->set_number('4550055')->is_valid_number, '愛知県名古屋市港区品川町');
ok($zip->set_number('4550056')->is_valid_number, '愛知県名古屋市港区砂美町');
ok($zip->set_number('4550057')->is_valid_number, '愛知県名古屋市港区築盛町');
ok($zip->set_number('4550061')->is_valid_number, '愛知県名古屋市港区東土古町');
ok($zip->set_number('4550062')->is_valid_number, '愛知県名古屋市港区小碓町');
ok($zip->set_number('4550063')->is_valid_number, '愛知県名古屋市港区金船町');
ok($zip->set_number('4550064')->is_valid_number, '愛知県名古屋市港区本宮町');
ok($zip->set_number('4550065')->is_valid_number, '愛知県名古屋市港区本宮新町');
ok($zip->set_number('4550066')->is_valid_number, '愛知県名古屋市港区寛政町');
ok($zip->set_number('4550067')->is_valid_number, '愛知県名古屋市港区港北町');
ok($zip->set_number('4550068')->is_valid_number, '愛知県名古屋市港区土古町');
ok($zip->set_number('4550069')->is_valid_number, '愛知県名古屋市港区泰明町');
ok($zip->set_number('4550071')->is_valid_number, '愛知県名古屋市港区新船町');
ok($zip->set_number('4550072')->is_valid_number, '愛知県名古屋市港区須成町');
ok($zip->set_number('4550073')->is_valid_number, '愛知県名古屋市港区川西通');
ok($zip->set_number('4550074')->is_valid_number, '愛知県名古屋市港区正保町');
ok($zip->set_number('4550075')->is_valid_number, '愛知県名古屋市港区正徳町');
ok($zip->set_number('4550076')->is_valid_number, '愛知県名古屋市港区川間町');
ok($zip->set_number('4550077')->is_valid_number, '愛知県名古屋市港区小割通');
ok($zip->set_number('4550078')->is_valid_number, '愛知県名古屋市港区丸池町');
ok($zip->set_number('4550801')->is_valid_number, '愛知県名古屋市港区小碓');
ok($zip->set_number('4550802')->is_valid_number, '愛知県名古屋市港区入場町');
ok($zip->set_number('4550803')->is_valid_number, '愛知県名古屋市港区入場');
ok($zip->set_number('4550804')->is_valid_number, '愛知県名古屋市港区当知');
ok($zip->set_number('4550805')->is_valid_number, '愛知県名古屋市港区当知町');
ok($zip->set_number('4550806')->is_valid_number, '愛知県名古屋市港区明正');
ok($zip->set_number('4550811')->is_valid_number, '愛知県名古屋市港区善進町');
ok($zip->set_number('4550812')->is_valid_number, '愛知県名古屋市港区善北町');
ok($zip->set_number('4550813')->is_valid_number, '愛知県名古屋市港区善進本町');
ok($zip->set_number('4550814')->is_valid_number, '愛知県名古屋市港区善南町');
ok($zip->set_number('4550815')->is_valid_number, '愛知県名古屋市港区油屋町');
ok($zip->set_number('4550821')->is_valid_number, '愛知県名古屋市港区高木町');
ok($zip->set_number('4550822')->is_valid_number, '愛知県名古屋市港区甚兵衛通');
ok($zip->set_number('4550823')->is_valid_number, '愛知県名古屋市港区惟信町');
ok($zip->set_number('4550824')->is_valid_number, '愛知県名古屋市港区西川町');
ok($zip->set_number('4550825')->is_valid_number, '愛知県名古屋市港区多加良浦町');
ok($zip->set_number('4550831')->is_valid_number, '愛知県名古屋市港区十一屋');
ok($zip->set_number('4550832')->is_valid_number, '愛知県名古屋市港区宝神');
ok($zip->set_number('4550833')->is_valid_number, '愛知県名古屋市港区宝神町');
ok($zip->set_number('4550834')->is_valid_number, '愛知県名古屋市港区神宮寺');
ok($zip->set_number('4550835')->is_valid_number, '愛知県名古屋市港区十一屋町');
ok($zip->set_number('4550841')->is_valid_number, '愛知県名古屋市港区一州町');
ok($zip->set_number('4550842')->is_valid_number, '愛知県名古屋市港区稲永');
ok($zip->set_number('4550843')->is_valid_number, '愛知県名古屋市港区錦町');
ok($zip->set_number('4550844')->is_valid_number, '愛知県名古屋市港区潮凪町');
ok($zip->set_number('4550845')->is_valid_number, '愛知県名古屋市港区野跡');
ok($zip->set_number('4550846')->is_valid_number, '愛知県名古屋市港区汐止町');
ok($zip->set_number('4550847')->is_valid_number, '愛知県名古屋市港区空見町');
ok($zip->set_number('4550848')->is_valid_number, '愛知県名古屋市港区金城ふ頭');
ok($zip->set_number('4550851')->is_valid_number, '愛知県名古屋市港区東茶屋');
ok($zip->set_number('4550852')->is_valid_number, '愛知県名古屋市港区七島');
ok($zip->set_number('4550853')->is_valid_number, '愛知県名古屋市港区南陽町七島新田');
ok($zip->set_number('4550854')->is_valid_number, '愛知県名古屋市港区藤高');
ok($zip->set_number('4550855')->is_valid_number, '愛知県名古屋市港区藤前');
ok($zip->set_number('4550856')->is_valid_number, '愛知県名古屋市港区川園');
ok($zip->set_number('4550857')->is_valid_number, '愛知県名古屋市港区秋葉');
ok($zip->set_number('4550858')->is_valid_number, '愛知県名古屋市港区西茶屋');
ok($zip->set_number('4550861')->is_valid_number, '愛知県名古屋市港区大西');
ok($zip->set_number('4550862')->is_valid_number, '愛知県名古屋市港区南陽町茶屋新田');
ok($zip->set_number('4550863')->is_valid_number, '愛知県名古屋市港区新茶屋');
ok($zip->set_number('4550864')->is_valid_number, '愛知県名古屋市港区小川');
ok($zip->set_number('4550865')->is_valid_number, '愛知県名古屋市港区天目町');
ok($zip->set_number('4550866')->is_valid_number, '愛知県名古屋市港区南陽町茶屋後新田');
ok($zip->set_number('4550867')->is_valid_number, '愛知県名古屋市港区南陽町福田前新田');
ok($zip->set_number('4550868')->is_valid_number, '愛知県名古屋市港区南陽町西福田');
ok($zip->set_number('4550869')->is_valid_number, '愛知県名古屋市港区協和');
ok($zip->set_number('4550871')->is_valid_number, '愛知県名古屋市港区南陽町福田');
ok($zip->set_number('4550872')->is_valid_number, '愛知県名古屋市港区西蟹田');
ok($zip->set_number('4550873')->is_valid_number, '愛知県名古屋市港区春田野');
ok($zip->set_number('4550874')->is_valid_number, '愛知県名古屋市港区西福田');
ok($zip->set_number('4550875')->is_valid_number, '愛知県名古屋市港区寺前町');
ok($zip->set_number('4550876')->is_valid_number, '愛知県名古屋市港区福屋');
ok($zip->set_number('4550877')->is_valid_number, '愛知県名古屋市港区六軒家');
ok($zip->set_number('4550878')->is_valid_number, '愛知県名古屋市港区福前');
ok($zip->set_number('4550879')->is_valid_number, '愛知県名古屋市港区畑中');
ok($zip->set_number('4550881')->is_valid_number, '愛知県名古屋市港区船頭場');
ok($zip->set_number('4550882')->is_valid_number, '愛知県名古屋市港区小賀須');
ok($zip->set_number('4550883')->is_valid_number, '愛知県名古屋市港区知多');
ok($zip->set_number('4550884')->is_valid_number, '愛知県名古屋市港区七反野');
ok($zip->set_number('4550885')->is_valid_number, '愛知県名古屋市港区八百島');
ok($zip->set_number('4550886')->is_valid_number, '愛知県名古屋市港区東蟹田');
ok($zip->set_number('4550887')->is_valid_number, '愛知県名古屋市港区福田');
ok($zip->set_number('4560000')->is_valid_number, '愛知県名古屋市熱田区以下に掲載がない場合');
ok($zip->set_number('4560001')->is_valid_number, '愛知県名古屋市熱田区金山');
ok($zip->set_number('4560002')->is_valid_number, '愛知県名古屋市熱田区金山町');
ok($zip->set_number('4560003')->is_valid_number, '愛知県名古屋市熱田区波寄町');
ok($zip->set_number('4560004')->is_valid_number, '愛知県名古屋市熱田区桜田町');
ok($zip->set_number('4560005')->is_valid_number, '愛知県名古屋市熱田区池内町');
ok($zip->set_number('4560006')->is_valid_number, '愛知県名古屋市熱田区沢下町');
ok($zip->set_number('4560011')->is_valid_number, '愛知県名古屋市熱田区花町');
ok($zip->set_number('4560012')->is_valid_number, '愛知県名古屋市熱田区沢上');
ok($zip->set_number('4560013')->is_valid_number, '愛知県名古屋市熱田区外土居町');
ok($zip->set_number('4560014')->is_valid_number, '愛知県名古屋市熱田区中田町');
ok($zip->set_number('4560015')->is_valid_number, '愛知県名古屋市熱田区高蔵町');
ok($zip->set_number('4560016')->is_valid_number, '愛知県名古屋市熱田区五本松町');
ok($zip->set_number('4560017')->is_valid_number, '愛知県名古屋市熱田区尾頭町');
ok($zip->set_number('4560018')->is_valid_number, '愛知県名古屋市熱田区新尾頭');
ok($zip->set_number('4560021')->is_valid_number, '愛知県名古屋市熱田区夜寒町');
ok($zip->set_number('4560022')->is_valid_number, '愛知県名古屋市熱田区横田');
ok($zip->set_number('4560023')->is_valid_number, '愛知県名古屋市熱田区六野');
ok($zip->set_number('4560024')->is_valid_number, '愛知県名古屋市熱田区森後町');
ok($zip->set_number('4560025')->is_valid_number, '愛知県名古屋市熱田区玉の井町');
ok($zip->set_number('4560026')->is_valid_number, '愛知県名古屋市熱田区旗屋町');
ok($zip->set_number('4560027')->is_valid_number, '愛知県名古屋市熱田区旗屋');
ok($zip->set_number('4560031')->is_valid_number, '愛知県名古屋市熱田区神宮');
ok($zip->set_number('4560032')->is_valid_number, '愛知県名古屋市熱田区三本松町');
ok($zip->set_number('4560033')->is_valid_number, '愛知県名古屋市熱田区花表町');
ok($zip->set_number('4560034')->is_valid_number, '愛知県名古屋市熱田区伝馬');
ok($zip->set_number('4560035')->is_valid_number, '愛知県名古屋市熱田区白鳥');
ok($zip->set_number('4560036')->is_valid_number, '愛知県名古屋市熱田区熱田西町');
ok($zip->set_number('4560037')->is_valid_number, '愛知県名古屋市熱田区熱田新田東組');
ok($zip->set_number('4560041')->is_valid_number, '愛知県名古屋市熱田区中瀬町');
ok($zip->set_number('4560042')->is_valid_number, '愛知県名古屋市熱田区須賀町');
ok($zip->set_number('4560043')->is_valid_number, '愛知県名古屋市熱田区神戸町');
ok($zip->set_number('4560044')->is_valid_number, '愛知県名古屋市熱田区内田町');
ok($zip->set_number('4560045')->is_valid_number, '愛知県名古屋市熱田区大瀬子町');
ok($zip->set_number('4560046')->is_valid_number, '愛知県名古屋市熱田区木之免町');
ok($zip->set_number('4560047')->is_valid_number, '愛知県名古屋市熱田区田中町');
ok($zip->set_number('4560048')->is_valid_number, '愛知県名古屋市熱田区白鳥町');
ok($zip->set_number('4560051')->is_valid_number, '愛知県名古屋市熱田区四番');
ok($zip->set_number('4560052')->is_valid_number, '愛知県名古屋市熱田区二番');
ok($zip->set_number('4560053')->is_valid_number, '愛知県名古屋市熱田区一番');
ok($zip->set_number('4560054')->is_valid_number, '愛知県名古屋市熱田区千年');
ok($zip->set_number('4560055')->is_valid_number, '愛知県名古屋市熱田区南一番町');
ok($zip->set_number('4560056')->is_valid_number, '愛知県名古屋市熱田区三番町');
ok($zip->set_number('4560057')->is_valid_number, '愛知県名古屋市熱田区五番町');
ok($zip->set_number('4560058')->is_valid_number, '愛知県名古屋市熱田区六番');
ok($zip->set_number('4560059')->is_valid_number, '愛知県名古屋市熱田区八番');
ok($zip->set_number('4560061')->is_valid_number, '愛知県名古屋市熱田区西郊通');
ok($zip->set_number('4560062')->is_valid_number, '愛知県名古屋市熱田区大宝');
ok($zip->set_number('4560063')->is_valid_number, '愛知県名古屋市熱田区西野町');
ok($zip->set_number('4560064')->is_valid_number, '愛知県名古屋市熱田区古新町');
ok($zip->set_number('4560065')->is_valid_number, '愛知県名古屋市熱田区河田町');
ok($zip->set_number('4560066')->is_valid_number, '愛知県名古屋市熱田区野立町');
ok($zip->set_number('4560067')->is_valid_number, '愛知県名古屋市熱田区中出町');
ok($zip->set_number('4560068')->is_valid_number, '愛知県名古屋市熱田区神野町');
ok($zip->set_number('4560069')->is_valid_number, '愛知県名古屋市熱田区中野新町');
ok($zip->set_number('4560071')->is_valid_number, '愛知県名古屋市熱田区明野町');
ok($zip->set_number('4560072')->is_valid_number, '愛知県名古屋市熱田区川並町');
ok($zip->set_number('4560073')->is_valid_number, '愛知県名古屋市熱田区千代田町');
ok($zip->set_number('4560074')->is_valid_number, '愛知県名古屋市熱田区比々野町');
ok($zip->set_number('4560075')->is_valid_number, '愛知県名古屋市熱田区青池町');
ok($zip->set_number('4560076')->is_valid_number, '愛知県名古屋市熱田区切戸町');
ok($zip->set_number('4560077')->is_valid_number, '愛知県名古屋市熱田区幡野町');
ok($zip->set_number('4560078')->is_valid_number, '愛知県名古屋市熱田区南八熊町');
ok($zip->set_number('4570000')->is_valid_number, '愛知県名古屋市南区以下に掲載がない場合');
ok($zip->set_number('4570001')->is_valid_number, '愛知県名古屋市南区平子');
ok($zip->set_number('4570002')->is_valid_number, '愛知県名古屋市南区大堀町');
ok($zip->set_number('4570003')->is_valid_number, '愛知県名古屋市南区鶴田');
ok($zip->set_number('4570004')->is_valid_number, '愛知県名古屋市南区中江');
ok($zip->set_number('4570005')->is_valid_number, '愛知県名古屋市南区桜台');
ok($zip->set_number('4570006')->is_valid_number, '愛知県名古屋市南区鳥栖');
ok($zip->set_number('4570007')->is_valid_number, '愛知県名古屋市南区駈上');
ok($zip->set_number('4570008')->is_valid_number, '愛知県名古屋市南区外山');
ok($zip->set_number('4570011')->is_valid_number, '愛知県名古屋市南区呼続元町');
ok($zip->set_number('4570012')->is_valid_number, '愛知県名古屋市南区菊住');
ok($zip->set_number('4570013')->is_valid_number, '愛知県名古屋市南区寺崎町');
ok($zip->set_number('4570014')->is_valid_number, '愛知県名古屋市南区呼続');
ok($zip->set_number('4570015')->is_valid_number, '愛知県名古屋市南区岩戸町');
ok($zip->set_number('4570016')->is_valid_number, '愛知県名古屋市南区汐田町');
ok($zip->set_number('4570021')->is_valid_number, '愛知県名古屋市南区鶴里町');
ok($zip->set_number('4570022')->is_valid_number, '愛知県名古屋市南区明円町');
ok($zip->set_number('4570023')->is_valid_number, '愛知県名古屋市南区芝町');
ok($zip->set_number('4570024')->is_valid_number, '愛知県名古屋市南区赤坪町');
ok($zip->set_number('4570025')->is_valid_number, '愛知県名古屋市南区白雲町');
ok($zip->set_number('4570026')->is_valid_number, '愛知県名古屋市南区見晴町');
ok($zip->set_number('4570027')->is_valid_number, '愛知県名古屋市南区弥生町');
ok($zip->set_number('4570028')->is_valid_number, '愛知県名古屋市南区楠町');
ok($zip->set_number('4570031')->is_valid_number, '愛知県名古屋市南区鯛取通');
ok($zip->set_number('4570032')->is_valid_number, '愛知県名古屋市南区元桜田町');
ok($zip->set_number('4570033')->is_valid_number, '愛知県名古屋市南区霞町');
ok($zip->set_number('4570034')->is_valid_number, '愛知県名古屋市南区春日野町');
ok($zip->set_number('4570035')->is_valid_number, '愛知県名古屋市南区貝塚町');
ok($zip->set_number('4570036')->is_valid_number, '愛知県名古屋市南区若草町');
ok($zip->set_number('4570037')->is_valid_number, '愛知県名古屋市南区扇田町');
ok($zip->set_number('4570038')->is_valid_number, '愛知県名古屋市南区桜本町');
ok($zip->set_number('4570039')->is_valid_number, '愛知県名古屋市南区西桜町');
ok($zip->set_number('4570041')->is_valid_number, '愛知県名古屋市南区薬師通');
ok($zip->set_number('4570042')->is_valid_number, '愛知県名古屋市南区曽池町');
ok($zip->set_number('4570043')->is_valid_number, '愛知県名古屋市南区戸部町');
ok($zip->set_number('4570044')->is_valid_number, '愛知県名古屋市南区柵下町');
ok($zip->set_number('4570045')->is_valid_number, '愛知県名古屋市南区松城町');
ok($zip->set_number('4570046')->is_valid_number, '愛知県名古屋市南区松池町');
ok($zip->set_number('4570047')->is_valid_number, '愛知県名古屋市南区城下町');
ok($zip->set_number('4570048')->is_valid_number, '愛知県名古屋市南区大磯通');
ok($zip->set_number('4570049')->is_valid_number, '愛知県名古屋市南区北内町');
ok($zip->set_number('4570051')->is_valid_number, '愛知県名古屋市南区笠寺町');
ok($zip->set_number('4570052')->is_valid_number, '愛知県名古屋市南区粕畠町');
ok($zip->set_number('4570053')->is_valid_number, '愛知県名古屋市南区本城町');
ok($zip->set_number('4570054')->is_valid_number, '愛知県名古屋市南区砂口町');
ok($zip->set_number('4570055')->is_valid_number, '愛知県名古屋市南区星宮町');
ok($zip->set_number('4570056')->is_valid_number, '愛知県名古屋市南区本星崎町');
ok($zip->set_number('4570057')->is_valid_number, '愛知県名古屋市南区鳥山町');
ok($zip->set_number('4570058')->is_valid_number, '愛知県名古屋市南区前浜通');
ok($zip->set_number('4570061')->is_valid_number, '愛知県名古屋市南区星崎町(殿海道)');
ok($zip->set_number('4570062')->is_valid_number, '愛知県名古屋市南区星崎町(阿原)');
ok($zip->set_number('4570063')->is_valid_number, '愛知県名古屋市南区阿原町');
ok($zip->set_number('4570064')->is_valid_number, '愛知県名古屋市南区星崎');
ok($zip->set_number('4570065')->is_valid_number, '愛知県名古屋市南区元鳴尾町');
ok($zip->set_number('4570066')->is_valid_number, '愛知県名古屋市南区鳴尾');
ok($zip->set_number('4570067')->is_valid_number, '愛知県名古屋市南区上浜町');
ok($zip->set_number('4570068')->is_valid_number, '愛知県名古屋市南区南野');
ok($zip->set_number('4570069')->is_valid_number, '愛知県名古屋市南区星園町');
ok($zip->set_number('4570071')->is_valid_number, '愛知県名古屋市南区千竈通');
ok($zip->set_number('4570072')->is_valid_number, '愛知県名古屋市南区寺部通');
ok($zip->set_number('4570073')->is_valid_number, '愛知県名古屋市南区西田町');
ok($zip->set_number('4570074')->is_valid_number, '愛知県名古屋市南区本地通');
ok($zip->set_number('4570075')->is_valid_number, '愛知県名古屋市南区石元町');
ok($zip->set_number('4570076')->is_valid_number, '愛知県名古屋市南区道全町');
ok($zip->set_number('4570077')->is_valid_number, '愛知県名古屋市南区立脇町');
ok($zip->set_number('4570078')->is_valid_number, '愛知県名古屋市南区塩屋町');
ok($zip->set_number('4570801')->is_valid_number, '愛知県名古屋市南区丹後通');
ok($zip->set_number('4570802')->is_valid_number, '愛知県名古屋市南区要町');
ok($zip->set_number('4570803')->is_valid_number, '愛知県名古屋市南区天白町');
ok($zip->set_number('4570804')->is_valid_number, '愛知県名古屋市南区源兵衛町');
ok($zip->set_number('4570805')->is_valid_number, '愛知県名古屋市南区三吉町');
ok($zip->set_number('4570806')->is_valid_number, '愛知県名古屋市南区鳴浜町');
ok($zip->set_number('4570807')->is_valid_number, '愛知県名古屋市南区鶴見通');
ok($zip->set_number('4570808')->is_valid_number, '愛知県名古屋市南区松下町');
ok($zip->set_number('4570811')->is_valid_number, '愛知県名古屋市南区大同町');
ok($zip->set_number('4570812')->is_valid_number, '愛知県名古屋市南区星崎町');
ok($zip->set_number('4570813')->is_valid_number, '愛知県名古屋市南区鳴尾町(丹後江)');
ok($zip->set_number('4570814')->is_valid_number, '愛知県名古屋市南区柴田本通');
ok($zip->set_number('4570815')->is_valid_number, '愛知県名古屋市南区柴田町');
ok($zip->set_number('4570816')->is_valid_number, '愛知県名古屋市南区元柴田東町');
ok($zip->set_number('4570817')->is_valid_number, '愛知県名古屋市南区元柴田西町');
ok($zip->set_number('4570818')->is_valid_number, '愛知県名古屋市南区白水町');
ok($zip->set_number('4570819')->is_valid_number, '愛知県名古屋市南区滝春町');
ok($zip->set_number('4570821')->is_valid_number, '愛知県名古屋市南区弥次ヱ町');
ok($zip->set_number('4570822')->is_valid_number, '愛知県名古屋市南区浜田町');
ok($zip->set_number('4570823')->is_valid_number, '愛知県名古屋市南区元塩町');
ok($zip->set_number('4570824')->is_valid_number, '愛知県名古屋市南区神松町');
ok($zip->set_number('4570825')->is_valid_number, '愛知県名古屋市南区堤起町');
ok($zip->set_number('4570826')->is_valid_number, '愛知県名古屋市南区中割町');
ok($zip->set_number('4570827')->is_valid_number, '愛知県名古屋市南区北頭町');
ok($zip->set_number('4570828')->is_valid_number, '愛知県名古屋市南区宝生町');
ok($zip->set_number('4570831')->is_valid_number, '愛知県名古屋市南区荒浜町');
ok($zip->set_number('4570832')->is_valid_number, '愛知県名古屋市南区浜中町');
ok($zip->set_number('4570833')->is_valid_number, '愛知県名古屋市南区東又兵ヱ町');
ok($zip->set_number('4570834')->is_valid_number, '愛知県名古屋市南区港東通');
ok($zip->set_number('4570835')->is_valid_number, '愛知県名古屋市南区西又兵ヱ町');
ok($zip->set_number('4570836')->is_valid_number, '愛知県名古屋市南区加福本通');
ok($zip->set_number('4570837')->is_valid_number, '愛知県名古屋市南区加福町');
ok($zip->set_number('4570841')->is_valid_number, '愛知県名古屋市南区豊田');
ok($zip->set_number('4570842')->is_valid_number, '愛知県名古屋市南区戸部下');
ok($zip->set_number('4570843')->is_valid_number, '愛知県名古屋市南区忠次');
ok($zip->set_number('4570844')->is_valid_number, '愛知県名古屋市南区堤町');
ok($zip->set_number('4570845')->is_valid_number, '愛知県名古屋市南区観音町');
ok($zip->set_number('4570846')->is_valid_number, '愛知県名古屋市南区道徳通');
ok($zip->set_number('4570847')->is_valid_number, '愛知県名古屋市南区道徳新町');
ok($zip->set_number('4570851')->is_valid_number, '愛知県名古屋市南区五条町');
ok($zip->set_number('4570852')->is_valid_number, '愛知県名古屋市南区泉楽通');
ok($zip->set_number('4570853')->is_valid_number, '愛知県名古屋市南区六条町');
ok($zip->set_number('4570854')->is_valid_number, '愛知県名古屋市南区七条町');
ok($zip->set_number('4570855')->is_valid_number, '愛知県名古屋市南区豊田町');
ok($zip->set_number('4570856')->is_valid_number, '愛知県名古屋市南区南陽通');
ok($zip->set_number('4570861')->is_valid_number, '愛知県名古屋市南区明治');
ok($zip->set_number('4570862')->is_valid_number, '愛知県名古屋市南区内田橋');
ok($zip->set_number('4570863')->is_valid_number, '愛知県名古屋市南区豊');
ok($zip->set_number('4570864')->is_valid_number, '愛知県名古屋市南区道徳北町');
ok($zip->set_number('4570865')->is_valid_number, '愛知県名古屋市南区氷室町');
ok($zip->set_number('4570866')->is_valid_number, '愛知県名古屋市南区三条');
ok($zip->set_number('4580000')->is_valid_number, '愛知県名古屋市緑区以下に掲載がない場合');
ok($zip->set_number('4580001')->is_valid_number, '愛知県名古屋市緑区梅里');
ok($zip->set_number('4580002')->is_valid_number, '愛知県名古屋市緑区桃山');
ok($zip->set_number('4580003')->is_valid_number, '愛知県名古屋市緑区黒沢台');
ok($zip->set_number('4580004')->is_valid_number, '愛知県名古屋市緑区乗鞍');
ok($zip->set_number('4580005')->is_valid_number, '愛知県名古屋市緑区鳴丘');
ok($zip->set_number('4580006')->is_valid_number, '愛知県名古屋市緑区細口');
ok($zip->set_number('4580007')->is_valid_number, '愛知県名古屋市緑区篭山');
ok($zip->set_number('4580008')->is_valid_number, '愛知県名古屋市緑区平手北');
ok($zip->set_number('4580009')->is_valid_number, '愛知県名古屋市緑区平手南');
ok($zip->set_number('4580011')->is_valid_number, '愛知県名古屋市緑区相川');
ok($zip->set_number('4580012')->is_valid_number, '愛知県名古屋市緑区久方');
ok($zip->set_number('4580013')->is_valid_number, '愛知県名古屋市緑区ほら貝');
ok($zip->set_number('4580014')->is_valid_number, '愛知県名古屋市緑区神沢');
ok($zip->set_number('4580015')->is_valid_number, '愛知県名古屋市緑区篠の風');
ok($zip->set_number('4580016')->is_valid_number, '愛知県名古屋市緑区上旭');
ok($zip->set_number('4580021')->is_valid_number, '愛知県名古屋市緑区滝ノ水');
ok($zip->set_number('4580022')->is_valid_number, '愛知県名古屋市緑区小坂');
ok($zip->set_number('4580023')->is_valid_number, '愛知県名古屋市緑区鴻仏目');
ok($zip->set_number('4580024')->is_valid_number, '愛知県名古屋市緑区尾崎山');
ok($zip->set_number('4580025')->is_valid_number, '愛知県名古屋市緑区鳥澄');
ok($zip->set_number('4580031')->is_valid_number, '愛知県名古屋市緑区旭出');
ok($zip->set_number('4580032')->is_valid_number, '愛知県名古屋市緑区大形山');
ok($zip->set_number('4580033')->is_valid_number, '愛知県名古屋市緑区相原郷');
ok($zip->set_number('4580034')->is_valid_number, '愛知県名古屋市緑区若田');
ok($zip->set_number('4580035')->is_valid_number, '愛知県名古屋市緑区曽根');
ok($zip->set_number('4580036')->is_valid_number, '愛知県名古屋市緑区六田');
ok($zip->set_number('4580037')->is_valid_number, '愛知県名古屋市緑区潮見が丘');
ok($zip->set_number('4580038')->is_valid_number, '愛知県名古屋市緑区作の山町');
ok($zip->set_number('4580039')->is_valid_number, '愛知県名古屋市緑区四本木');
ok($zip->set_number('4580041')->is_valid_number, '愛知県名古屋市緑区鳴子町');
ok($zip->set_number('4580042')->is_valid_number, '愛知県名古屋市緑区高根台');
ok($zip->set_number('4580043')->is_valid_number, '愛知県名古屋市緑区万場山');
ok($zip->set_number('4580044')->is_valid_number, '愛知県名古屋市緑区池上台');
ok($zip->set_number('4580045')->is_valid_number, '愛知県名古屋市緑区鹿山');
ok($zip->set_number('4580046')->is_valid_number, '愛知県名古屋市緑区長根町');
ok($zip->set_number('4580047')->is_valid_number, '愛知県名古屋市緑区古鳴海');
ok($zip->set_number('4580801')->is_valid_number, '愛知県名古屋市緑区鳴海町(その他)');
ok($zip->set_number('4580802')->is_valid_number, '愛知県名古屋市緑区兵庫');
ok($zip->set_number('4580803')->is_valid_number, '愛知県名古屋市緑区鏡田');
ok($zip->set_number('4580804')->is_valid_number, '愛知県名古屋市緑区亀が洞');
ok($zip->set_number('4580805')->is_valid_number, '愛知県名古屋市緑区大清水');
ok($zip->set_number('4580806')->is_valid_number, '愛知県名古屋市緑区大清水西');
ok($zip->set_number('4580807')->is_valid_number, '愛知県名古屋市緑区砂田');
ok($zip->set_number('4580808')->is_valid_number, '愛知県名古屋市緑区東神の倉');
ok($zip->set_number('4580809')->is_valid_number, '愛知県名古屋市緑区西神の倉');
ok($zip->set_number('4580810')->is_valid_number, '愛知県名古屋市緑区八つ松');
ok($zip->set_number('4580811')->is_valid_number, '愛知県名古屋市緑区鳴海町(神ノ倉)');
ok($zip->set_number('4580812')->is_valid_number, '愛知県名古屋市緑区神の倉');
ok($zip->set_number('4580813')->is_valid_number, '愛知県名古屋市緑区藤塚');
ok($zip->set_number('4580814')->is_valid_number, '愛知県名古屋市緑区鶴が沢');
ok($zip->set_number('4580815')->is_valid_number, '愛知県名古屋市緑区徳重');
ok($zip->set_number('4580816')->is_valid_number, '愛知県名古屋市緑区横吹町');
ok($zip->set_number('4580817')->is_valid_number, '愛知県名古屋市緑区鳴海町(諸の木)');
ok($zip->set_number('4580817')->is_valid_number, '愛知県名古屋市緑区諸の木');
ok($zip->set_number('4580818')->is_valid_number, '愛知県名古屋市緑区鳴海町(大清水)');
ok($zip->set_number('4580819')->is_valid_number, '愛知県名古屋市緑区鳴海町(八ツ松)');
ok($zip->set_number('4580820')->is_valid_number, '愛知県名古屋市緑区境松');
ok($zip->set_number('4580821')->is_valid_number, '愛知県名古屋市緑区鳴海町(尾崎山)');
ok($zip->set_number('4580822')->is_valid_number, '愛知県名古屋市緑区大将ケ根');
ok($zip->set_number('4580823')->is_valid_number, '愛知県名古屋市緑区太子');
ok($zip->set_number('4580824')->is_valid_number, '愛知県名古屋市緑区鳴海町(有松裏)');
ok($zip->set_number('4580825')->is_valid_number, '愛知県名古屋市緑区左京山');
ok($zip->set_number('4580826')->is_valid_number, '愛知県名古屋市緑区平子が丘');
ok($zip->set_number('4580827')->is_valid_number, '愛知県名古屋市緑区鳴海町(細根)');
ok($zip->set_number('4580828')->is_valid_number, '愛知県名古屋市緑区鳴海町(姥子山)');
ok($zip->set_number('4580829')->is_valid_number, '愛知県名古屋市緑区鎌倉台');
ok($zip->set_number('4580830')->is_valid_number, '愛知県名古屋市緑区姥子山');
ok($zip->set_number('4580831')->is_valid_number, '愛知県名古屋市緑区鳴海町(向田)');
ok($zip->set_number('4580832')->is_valid_number, '愛知県名古屋市緑区漆山');
ok($zip->set_number('4580833')->is_valid_number, '愛知県名古屋市緑区青山');
ok($zip->set_number('4580834')->is_valid_number, '愛知県名古屋市緑区鳴海町(前之輪)');
ok($zip->set_number('4580835')->is_valid_number, '愛知県名古屋市緑区鳴海町(上汐田)');
ok($zip->set_number('4580836')->is_valid_number, '愛知県名古屋市緑区白土');
ok($zip->set_number('4580837')->is_valid_number, '愛知県名古屋市緑区赤松');
ok($zip->set_number('4580841')->is_valid_number, '愛知県名古屋市緑区鳴海町(小森)');
ok($zip->set_number('4580842')->is_valid_number, '愛知県名古屋市緑区鳴海町(上ノ山)');
ok($zip->set_number('4580843')->is_valid_number, '愛知県名古屋市緑区松が根台');
ok($zip->set_number('4580844')->is_valid_number, '愛知県名古屋市緑区鳴海町(伝治山)');
ok($zip->set_number('4580845')->is_valid_number, '愛知県名古屋市緑区鳴海町(赤塚)');
ok($zip->set_number('4580846')->is_valid_number, '愛知県名古屋市緑区鳴海町(薬師山)');
ok($zip->set_number('4580847')->is_valid_number, '愛知県名古屋市緑区浦里');
ok($zip->set_number('4580848')->is_valid_number, '愛知県名古屋市緑区水広');
ok($zip->set_number('4580849')->is_valid_number, '愛知県名古屋市緑区大清水東');
ok($zip->set_number('4580851')->is_valid_number, '愛知県名古屋市緑区熊の前');
ok($zip->set_number('4580852')->is_valid_number, '愛知県名古屋市緑区元徳重');
ok($zip->set_number('4580901')->is_valid_number, '愛知県名古屋市緑区有松町有松');
ok($zip->set_number('4580902')->is_valid_number, '愛知県名古屋市緑区有松三丁山');
ok($zip->set_number('4580903')->is_valid_number, '愛知県名古屋市緑区有松愛宕');
ok($zip->set_number('4580910')->is_valid_number, '愛知県名古屋市緑区桶狭間森前');
ok($zip->set_number('4580911')->is_valid_number, '愛知県名古屋市緑区有松町桶狭間(その他)');
ok($zip->set_number('4580912')->is_valid_number, '愛知県名古屋市緑区有松町桶狭間(生山)');
ok($zip->set_number('4580913')->is_valid_number, '愛知県名古屋市緑区桶狭間北');
ok($zip->set_number('4580915')->is_valid_number, '愛知県名古屋市緑区野末町');
ok($zip->set_number('4580916')->is_valid_number, '愛知県名古屋市緑区有松町桶狭間(愛宕西)');
ok($zip->set_number('4580917')->is_valid_number, '愛知県名古屋市緑区武路町');
ok($zip->set_number('4580918')->is_valid_number, '愛知県名古屋市緑区南陵');
ok($zip->set_number('4580919')->is_valid_number, '愛知県名古屋市緑区桶狭間神明');
ok($zip->set_number('4580920')->is_valid_number, '愛知県名古屋市緑区桶狭間巻山');
ok($zip->set_number('4580921')->is_valid_number, '愛知県名古屋市緑区桶狭間清水山');
ok($zip->set_number('4580922')->is_valid_number, '愛知県名古屋市緑区桶狭間切戸');
ok($zip->set_number('4580924')->is_valid_number, '愛知県名古屋市緑区有松');
ok($zip->set_number('4580925')->is_valid_number, '愛知県名古屋市緑区桶狭間');
ok($zip->set_number('4580926')->is_valid_number, '愛知県名古屋市緑区桶狭間上の山');
ok($zip->set_number('4580927')->is_valid_number, '愛知県名古屋市緑区桶狭間南');
ok($zip->set_number('4580928')->is_valid_number, '愛知県名古屋市緑区有松幕山');
ok($zip->set_number('4580929')->is_valid_number, '愛知県名古屋市緑区桶狭間西');
ok($zip->set_number('4598001')->is_valid_number, '愛知県名古屋市緑区大高町');
ok($zip->set_number('4598002')->is_valid_number, '愛知県名古屋市緑区森の里');
ok($zip->set_number('4598003')->is_valid_number, '愛知県名古屋市緑区大高台');
ok($zip->set_number('4598004')->is_valid_number, '愛知県名古屋市緑区有松南');
ok($zip->set_number('4598005')->is_valid_number, '愛知県名古屋市緑区緑花台');
ok($zip->set_number('4598006')->is_valid_number, '愛知県名古屋市緑区倉坂');
ok($zip->set_number('4598007')->is_valid_number, '愛知県名古屋市緑区大根山');
ok($zip->set_number('4598008')->is_valid_number, '愛知県名古屋市緑区文久山');
ok($zip->set_number('4598009')->is_valid_number, '愛知県名古屋市緑区清水山');
ok($zip->set_number('4598011')->is_valid_number, '愛知県名古屋市緑区定納山');
ok($zip->set_number('4598012')->is_valid_number, '愛知県名古屋市緑区茨谷山');
ok($zip->set_number('4598013')->is_valid_number, '愛知県名古屋市緑区高根山');
ok($zip->set_number('4598014')->is_valid_number, '愛知県名古屋市緑区忠治山');
ok($zip->set_number('4598015')->is_valid_number, '愛知県名古屋市緑区別所山');
ok($zip->set_number('4598016')->is_valid_number, '愛知県名古屋市緑区南大高');
ok($zip->set_number('4598017')->is_valid_number, '愛知県名古屋市緑区瀬木南');
ok($zip->set_number('4600000')->is_valid_number, '愛知県名古屋市中区以下に掲載がない場合');
ok($zip->set_number('4600001')->is_valid_number, '愛知県名古屋市中区三の丸');
ok($zip->set_number('4600002')->is_valid_number, '愛知県名古屋市中区丸の内');
ok($zip->set_number('4600003')->is_valid_number, '愛知県名古屋市中区錦');
ok($zip->set_number('4600004')->is_valid_number, '愛知県名古屋市中区新栄町');
ok($zip->set_number('4600005')->is_valid_number, '愛知県名古屋市中区東桜');
ok($zip->set_number('4600006')->is_valid_number, '愛知県名古屋市中区葵');
ok($zip->set_number('4600007')->is_valid_number, '愛知県名古屋市中区新栄');
ok($zip->set_number('4600008')->is_valid_number, '愛知県名古屋市中区栄');
ok($zip->set_number('4600011')->is_valid_number, '愛知県名古屋市中区大須');
ok($zip->set_number('4600012')->is_valid_number, '愛知県名古屋市中区千代田');
ok($zip->set_number('4600013')->is_valid_number, '愛知県名古屋市中区上前津');
ok($zip->set_number('4600014')->is_valid_number, '愛知県名古屋市中区富士見町');
ok($zip->set_number('4600015')->is_valid_number, '愛知県名古屋市中区大井町');
ok($zip->set_number('4600016')->is_valid_number, '愛知県名古屋市中区橘');
ok($zip->set_number('4600017')->is_valid_number, '愛知県名古屋市中区松原');
ok($zip->set_number('4600018')->is_valid_number, '愛知県名古屋市中区門前町');
ok($zip->set_number('4600021')->is_valid_number, '愛知県名古屋市中区平和');
ok($zip->set_number('4600022')->is_valid_number, '愛知県名古屋市中区金山');
ok($zip->set_number('4600023')->is_valid_number, '愛知県名古屋市中区金山町');
ok($zip->set_number('4600024')->is_valid_number, '愛知県名古屋市中区正木');
ok($zip->set_number('4600025')->is_valid_number, '愛知県名古屋市中区古渡町');
ok($zip->set_number('4600026')->is_valid_number, '愛知県名古屋市中区伊勢山');
ok($zip->set_number('4600031')->is_valid_number, '愛知県名古屋市中区本丸');
ok($zip->set_number('4600032')->is_valid_number, '愛知県名古屋市中区二の丸');
ok($zip->set_number('4610000')->is_valid_number, '愛知県名古屋市東区以下に掲載がない場合');
ok($zip->set_number('4610001')->is_valid_number, '愛知県名古屋市東区泉');
ok($zip->set_number('4610002')->is_valid_number, '愛知県名古屋市東区代官町');
ok($zip->set_number('4610003')->is_valid_number, '愛知県名古屋市東区筒井');
ok($zip->set_number('4610003')->is_valid_number, '愛知県名古屋市東区筒井町');
ok($zip->set_number('4610004')->is_valid_number, '愛知県名古屋市東区葵');
ok($zip->set_number('4610005')->is_valid_number, '愛知県名古屋市東区東桜');
ok($zip->set_number('4610006')->is_valid_number, '愛知県名古屋市東区東新町');
ok($zip->set_number('4610007')->is_valid_number, '愛知県名古屋市東区西新町');
ok($zip->set_number('4610008')->is_valid_number, '愛知県名古屋市東区武平町');
ok($zip->set_number('4610009')->is_valid_number, '愛知県名古屋市東区久屋町');
ok($zip->set_number('4610011')->is_valid_number, '愛知県名古屋市東区白壁');
ok($zip->set_number('4610012')->is_valid_number, '愛知県名古屋市東区相生町');
ok($zip->set_number('4610013')->is_valid_number, '愛知県名古屋市東区飯田町');
ok($zip->set_number('4610014')->is_valid_number, '愛知県名古屋市東区橦木町');
ok($zip->set_number('4610015')->is_valid_number, '愛知県名古屋市東区東片端町');
ok($zip->set_number('4610016')->is_valid_number, '愛知県名古屋市東区上竪杉町');
ok($zip->set_number('4610017')->is_valid_number, '愛知県名古屋市東区東外堀町');
ok($zip->set_number('4610018')->is_valid_number, '愛知県名古屋市東区主税町');
ok($zip->set_number('4610019')->is_valid_number, '愛知県名古屋市東区三の丸');
ok($zip->set_number('4610021')->is_valid_number, '愛知県名古屋市東区大曽根');
ok($zip->set_number('4610022')->is_valid_number, '愛知県名古屋市東区東大曽根町');
ok($zip->set_number('4610023')->is_valid_number, '愛知県名古屋市東区徳川町');
ok($zip->set_number('4610024')->is_valid_number, '愛知県名古屋市東区山口町');
ok($zip->set_number('4610025')->is_valid_number, '愛知県名古屋市東区徳川');
ok($zip->set_number('4610026')->is_valid_number, '愛知県名古屋市東区赤塚町');
ok($zip->set_number('4610027')->is_valid_number, '愛知県名古屋市東区芳野');
ok($zip->set_number('4610031')->is_valid_number, '愛知県名古屋市東区明倫町');
ok($zip->set_number('4610032')->is_valid_number, '愛知県名古屋市東区出来町');
ok($zip->set_number('4610033')->is_valid_number, '愛知県名古屋市東区大松町');
ok($zip->set_number('4610034')->is_valid_number, '愛知県名古屋市東区豊前町');
ok($zip->set_number('4610035')->is_valid_number, '愛知県名古屋市東区黒門町');
ok($zip->set_number('4610036')->is_valid_number, '愛知県名古屋市東区車道町');
ok($zip->set_number('4610037')->is_valid_number, '愛知県名古屋市東区百人町');
ok($zip->set_number('4610038')->is_valid_number, '愛知県名古屋市東区新出来');
ok($zip->set_number('4610040')->is_valid_number, '愛知県名古屋市東区矢田');
ok($zip->set_number('4610043')->is_valid_number, '愛知県名古屋市東区大幸');
ok($zip->set_number('4610044')->is_valid_number, '愛知県名古屋市東区矢田東');
ok($zip->set_number('4610045')->is_valid_number, '愛知県名古屋市東区砂田橋');
ok($zip->set_number('4610046')->is_valid_number, '愛知県名古屋市東区前浪町');
ok($zip->set_number('4610047')->is_valid_number, '愛知県名古屋市東区大幸南');
ok($zip->set_number('4610048')->is_valid_number, '愛知県名古屋市東区矢田南');
ok($zip->set_number('4610049')->is_valid_number, '愛知県名古屋市東区古出来');
ok($zip->set_number('4620000')->is_valid_number, '愛知県名古屋市北区以下に掲載がない場合');
ok($zip->set_number('4620001')->is_valid_number, '愛知県名古屋市北区北久手町');
ok($zip->set_number('4620002')->is_valid_number, '愛知県名古屋市北区六が池町');
ok($zip->set_number('4620003')->is_valid_number, '愛知県名古屋市北区桐畑町');
ok($zip->set_number('4620004')->is_valid_number, '愛知県名古屋市北区三軒町');
ok($zip->set_number('4620005')->is_valid_number, '愛知県名古屋市北区池花町');
ok($zip->set_number('4620006')->is_valid_number, '愛知県名古屋市北区若鶴町');
ok($zip->set_number('4620007')->is_valid_number, '愛知県名古屋市北区如意');
ok($zip->set_number('4620008')->is_valid_number, '愛知県名古屋市北区如来町');
ok($zip->set_number('4620009')->is_valid_number, '愛知県名古屋市北区苗田町');
ok($zip->set_number('4620011')->is_valid_number, '愛知県名古屋市北区五反田町');
ok($zip->set_number('4620012')->is_valid_number, '愛知県名古屋市北区楠');
ok($zip->set_number('4620013')->is_valid_number, '愛知県名古屋市北区東味鋺');
ok($zip->set_number('4620014')->is_valid_number, '愛知県名古屋市北区楠味鋺');
ok($zip->set_number('4620015')->is_valid_number, '愛知県名古屋市北区中味鋺');
ok($zip->set_number('4620016')->is_valid_number, '愛知県名古屋市北区西味鋺');
ok($zip->set_number('4620017')->is_valid_number, '愛知県名古屋市北区落合町');
ok($zip->set_number('4620018')->is_valid_number, '愛知県名古屋市北区玄馬町');
ok($zip->set_number('4620021')->is_valid_number, '愛知県名古屋市北区成願寺');
ok($zip->set_number('4620022')->is_valid_number, '愛知県名古屋市北区川中町');
ok($zip->set_number('4620023')->is_valid_number, '愛知県名古屋市北区安井');
ok($zip->set_number('4620024')->is_valid_number, '愛知県名古屋市北区鳩岡');
ok($zip->set_number('4620025')->is_valid_number, '愛知県名古屋市北区鳩岡町');
ok($zip->set_number('4620026')->is_valid_number, '愛知県名古屋市北区萩野通');
ok($zip->set_number('4620031')->is_valid_number, '愛知県名古屋市北区米が瀬町');
ok($zip->set_number('4620032')->is_valid_number, '愛知県名古屋市北区辻町');
ok($zip->set_number('4620033')->is_valid_number, '愛知県名古屋市北区金田町');
ok($zip->set_number('4620034')->is_valid_number, '愛知県名古屋市北区天道町');
ok($zip->set_number('4620035')->is_valid_number, '愛知県名古屋市北区大野町');
ok($zip->set_number('4620036')->is_valid_number, '愛知県名古屋市北区長喜町');
ok($zip->set_number('4620037')->is_valid_number, '愛知県名古屋市北区志賀町');
ok($zip->set_number('4620038')->is_valid_number, '愛知県名古屋市北区稚児宮通');
ok($zip->set_number('4620041')->is_valid_number, '愛知県名古屋市北区浪打町');
ok($zip->set_number('4620042')->is_valid_number, '愛知県名古屋市北区水草町');
ok($zip->set_number('4620043')->is_valid_number, '愛知県名古屋市北区八代町');
ok($zip->set_number('4620044')->is_valid_number, '愛知県名古屋市北区元志賀町');
ok($zip->set_number('4620045')->is_valid_number, '愛知県名古屋市北区敷島町');
ok($zip->set_number('4620046')->is_valid_number, '愛知県名古屋市北区城見通');
ok($zip->set_number('4620047')->is_valid_number, '愛知県名古屋市北区金城町');
ok($zip->set_number('4620051')->is_valid_number, '愛知県名古屋市北区中切町');
ok($zip->set_number('4620052')->is_valid_number, '愛知県名古屋市北区福徳町');
ok($zip->set_number('4620053')->is_valid_number, '愛知県名古屋市北区光音寺町');
ok($zip->set_number('4620054')->is_valid_number, '愛知県名古屋市北区野方通');
ok($zip->set_number('4620055')->is_valid_number, '愛知県名古屋市北区桝形町');
ok($zip->set_number('4620056')->is_valid_number, '愛知県名古屋市北区中丸町');
ok($zip->set_number('4620057')->is_valid_number, '愛知県名古屋市北区平手町');
ok($zip->set_number('4620058')->is_valid_number, '愛知県名古屋市北区西志賀町');
ok($zip->set_number('4620059')->is_valid_number, '愛知県名古屋市北区駒止町');
ok($zip->set_number('4620061')->is_valid_number, '愛知県名古屋市北区会所町');
ok($zip->set_number('4620062')->is_valid_number, '愛知県名古屋市北区新沼町');
ok($zip->set_number('4620063')->is_valid_number, '愛知県名古屋市北区丸新町');
ok($zip->set_number('4620064')->is_valid_number, '愛知県名古屋市北区大我麻町');
ok($zip->set_number('4620065')->is_valid_number, '愛知県名古屋市北区喜惣治');
ok($zip->set_number('4620066')->is_valid_number, '愛知県名古屋市北区楠町喜惣治新田');
ok($zip->set_number('4620801')->is_valid_number, '愛知県名古屋市北区新堀町');
ok($zip->set_number('4620802')->is_valid_number, '愛知県名古屋市北区上飯田北町');
ok($zip->set_number('4620803')->is_valid_number, '愛知県名古屋市北区上飯田東町');
ok($zip->set_number('4620804')->is_valid_number, '愛知県名古屋市北区上飯田南町');
ok($zip->set_number('4620805')->is_valid_number, '愛知県名古屋市北区八龍町');
ok($zip->set_number('4620807')->is_valid_number, '愛知県名古屋市北区御成通');
ok($zip->set_number('4620808')->is_valid_number, '愛知県名古屋市北区上飯田通');
ok($zip->set_number('4620809')->is_valid_number, '愛知県名古屋市北区上飯田西町');
ok($zip->set_number('4620810')->is_valid_number, '愛知県名古屋市北区山田');
ok($zip->set_number('4620811')->is_valid_number, '愛知県名古屋市北区山田北町');
ok($zip->set_number('4620812')->is_valid_number, '愛知県名古屋市北区矢田町');
ok($zip->set_number('4620813')->is_valid_number, '愛知県名古屋市北区山田町');
ok($zip->set_number('4620814')->is_valid_number, '愛知県名古屋市北区山田西町');
ok($zip->set_number('4620816')->is_valid_number, '愛知県名古屋市北区平安通');
ok($zip->set_number('4620818')->is_valid_number, '愛知県名古屋市北区彩紅橋通');
ok($zip->set_number('4620819')->is_valid_number, '愛知県名古屋市北区平安');
ok($zip->set_number('4620823')->is_valid_number, '愛知県名古屋市北区東大曽根町上');
ok($zip->set_number('4620824')->is_valid_number, '愛知県名古屋市北区芳野');
ok($zip->set_number('4620825')->is_valid_number, '愛知県名古屋市北区大曽根');
ok($zip->set_number('4620826')->is_valid_number, '愛知県名古屋市北区東大杉町');
ok($zip->set_number('4620827')->is_valid_number, '愛知県名古屋市北区東長田町');
ok($zip->set_number('4620828')->is_valid_number, '愛知県名古屋市北区東水切町');
ok($zip->set_number('4620829')->is_valid_number, '愛知県名古屋市北区杉栄町');
ok($zip->set_number('4620831')->is_valid_number, '愛知県名古屋市北区城東町');
ok($zip->set_number('4620832')->is_valid_number, '愛知県名古屋市北区生駒町');
ok($zip->set_number('4620833')->is_valid_number, '愛知県名古屋市北区水切町');
ok($zip->set_number('4620834')->is_valid_number, '愛知県名古屋市北区長田町');
ok($zip->set_number('4620835')->is_valid_number, '愛知県名古屋市北区杉村');
ok($zip->set_number('4620836')->is_valid_number, '愛知県名古屋市北区大杉町');
ok($zip->set_number('4620837')->is_valid_number, '愛知県名古屋市北区大杉');
ok($zip->set_number('4620838')->is_valid_number, '愛知県名古屋市北区中杉町');
ok($zip->set_number('4620841')->is_valid_number, '愛知県名古屋市北区黒川本通');
ok($zip->set_number('4620842')->is_valid_number, '愛知県名古屋市北区志賀南通');
ok($zip->set_number('4620843')->is_valid_number, '愛知県名古屋市北区田幡');
ok($zip->set_number('4620844')->is_valid_number, '愛知県名古屋市北区清水');
ok($zip->set_number('4620845')->is_valid_number, '愛知県名古屋市北区柳原');
ok($zip->set_number('4620846')->is_valid_number, '愛知県名古屋市北区名城');
ok($zip->set_number('4620847')->is_valid_number, '愛知県名古屋市北区金城');
ok($zip->set_number('4620851')->is_valid_number, '愛知県名古屋市北区木津根町');
ok($zip->set_number('4620852')->is_valid_number, '愛知県名古屋市北区猿投町');
ok($zip->set_number('4620853')->is_valid_number, '愛知県名古屋市北区志賀本通');
ok($zip->set_number('4620854')->is_valid_number, '愛知県名古屋市北区若葉通');
ok($zip->set_number('4620855')->is_valid_number, '愛知県名古屋市北区石園町');
ok($zip->set_number('4620856')->is_valid_number, '愛知県名古屋市北区芦辺町');
ok($zip->set_number('4620857')->is_valid_number, '愛知県名古屋市北区紅雲町');
ok($zip->set_number('4620858')->is_valid_number, '愛知県名古屋市北区大蔵町');
ok($zip->set_number('4620859')->is_valid_number, '愛知県名古屋市北区神明町');
ok($zip->set_number('4620861')->is_valid_number, '愛知県名古屋市北区辻本通');
ok($zip->set_number('4620862')->is_valid_number, '愛知県名古屋市北区真畔町');
ok($zip->set_number('4620863')->is_valid_number, '愛知県名古屋市北区尾上町');
ok($zip->set_number('4620864')->is_valid_number, '愛知県名古屋市北区織部町');
ok($zip->set_number('4620865')->is_valid_number, '愛知県名古屋市北区下飯田町');
ok($zip->set_number('4620866')->is_valid_number, '愛知県名古屋市北区瑠璃光町');
ok($zip->set_number('4620867')->is_valid_number, '愛知県名古屋市北区垣戸町');
ok($zip->set_number('4620868')->is_valid_number, '愛知県名古屋市北区憧旛町');
ok($zip->set_number('4620869')->is_valid_number, '愛知県名古屋市北区龍ノ口町');
ok($zip->set_number('4630000')->is_valid_number, '愛知県名古屋市守山区以下に掲載がない場合');
ok($zip->set_number('4630001')->is_valid_number, '愛知県名古屋市守山区上志段味');
ok($zip->set_number('4630002')->is_valid_number, '愛知県名古屋市守山区中志段味');
ok($zip->set_number('4630003')->is_valid_number, '愛知県名古屋市守山区下志段味');
ok($zip->set_number('4630004')->is_valid_number, '愛知県名古屋市守山区吉根');
ok($zip->set_number('4630005')->is_valid_number, '愛知県名古屋市守山区川');
ok($zip->set_number('4630006')->is_valid_number, '愛知県名古屋市守山区川東山');
ok($zip->set_number('4630007')->is_valid_number, '愛知県名古屋市守山区松坂町');
ok($zip->set_number('4630008')->is_valid_number, '愛知県名古屋市守山区小幡北');
ok($zip->set_number('4630009')->is_valid_number, '愛知県名古屋市守山区緑ケ丘');
ok($zip->set_number('4630010')->is_valid_number, '愛知県名古屋市守山区翠松園');
ok($zip->set_number('4630011')->is_valid_number, '愛知県名古屋市守山区小幡');
ok($zip->set_number('4630012')->is_valid_number, '愛知県名古屋市守山区茶臼前');
ok($zip->set_number('4630013')->is_valid_number, '愛知県名古屋市守山区小幡中');
ok($zip->set_number('4630014')->is_valid_number, '愛知県名古屋市守山区城南町');
ok($zip->set_number('4630015')->is_valid_number, '愛知県名古屋市守山区西島町');
ok($zip->set_number('4630016')->is_valid_number, '愛知県名古屋市守山区大屋敷');
ok($zip->set_number('4630017')->is_valid_number, '愛知県名古屋市守山区喜多山');
ok($zip->set_number('4630018')->is_valid_number, '愛知県名古屋市守山区桜坂');
ok($zip->set_number('4630019')->is_valid_number, '愛知県名古屋市守山区東禅寺');
ok($zip->set_number('4630021')->is_valid_number, '愛知県名古屋市守山区大森');
ok($zip->set_number('4630022')->is_valid_number, '愛知県名古屋市守山区八剣');
ok($zip->set_number('4630023')->is_valid_number, '愛知県名古屋市守山区今尻町');
ok($zip->set_number('4630024')->is_valid_number, '愛知県名古屋市守山区脇田町');
ok($zip->set_number('4630025')->is_valid_number, '愛知県名古屋市守山区元郷');
ok($zip->set_number('4630026')->is_valid_number, '愛知県名古屋市守山区藪田町');
ok($zip->set_number('4630027')->is_valid_number, '愛知県名古屋市守山区弁天が丘');
ok($zip->set_number('4630028')->is_valid_number, '愛知県名古屋市守山区大森八龍');
ok($zip->set_number('4630029')->is_valid_number, '愛知県名古屋市守山区御膳洞');
ok($zip->set_number('4630031')->is_valid_number, '愛知県名古屋市守山区本地が丘');
ok($zip->set_number('4630032')->is_valid_number, '愛知県名古屋市守山区白山');
ok($zip->set_number('4630033')->is_valid_number, '愛知県名古屋市守山区森孝東');
ok($zip->set_number('4630034')->is_valid_number, '愛知県名古屋市守山区四軒家');
ok($zip->set_number('4630035')->is_valid_number, '愛知県名古屋市守山区森孝');
ok($zip->set_number('4630036')->is_valid_number, '愛知県名古屋市守山区向台');
ok($zip->set_number('4630037')->is_valid_number, '愛知県名古屋市守山区天子田');
ok($zip->set_number('4630038')->is_valid_number, '愛知県名古屋市守山区原境町');
ok($zip->set_number('4630041')->is_valid_number, '愛知県名古屋市守山区大谷町');
ok($zip->set_number('4630042')->is_valid_number, '愛知県名古屋市守山区野萩町');
ok($zip->set_number('4630043')->is_valid_number, '愛知県名古屋市守山区喜多山南');
ok($zip->set_number('4630044')->is_valid_number, '愛知県名古屋市守山区太田井');
ok($zip->set_number('4630045')->is_valid_number, '愛知県名古屋市守山区菱池町');
ok($zip->set_number('4630046')->is_valid_number, '愛知県名古屋市守山区苗代');
ok($zip->set_number('4630047')->is_valid_number, '愛知県名古屋市守山区小幡常燈');
ok($zip->set_number('4630048')->is_valid_number, '愛知県名古屋市守山区小幡南');
ok($zip->set_number('4630051')->is_valid_number, '愛知県名古屋市守山区小幡太田');
ok($zip->set_number('4630052')->is_valid_number, '愛知県名古屋市守山区小幡宮ノ腰');
ok($zip->set_number('4630053')->is_valid_number, '愛知県名古屋市守山区小幡千代田');
ok($zip->set_number('4630054')->is_valid_number, '愛知県名古屋市守山区小六町');
ok($zip->set_number('4630055')->is_valid_number, '愛知県名古屋市守山区西新');
ok($zip->set_number('4630056')->is_valid_number, '愛知県名古屋市守山区新城');
ok($zip->set_number('4630057')->is_valid_number, '愛知県名古屋市守山区中新');
ok($zip->set_number('4630061')->is_valid_number, '愛知県名古屋市守山区東山町');
ok($zip->set_number('4630062')->is_valid_number, '愛知県名古屋市守山区長栄');
ok($zip->set_number('4630063')->is_valid_number, '愛知県名古屋市守山区八反');
ok($zip->set_number('4630064')->is_valid_number, '愛知県名古屋市守山区更屋敷');
ok($zip->set_number('4630065')->is_valid_number, '愛知県名古屋市守山区廿軒家');
ok($zip->set_number('4630066')->is_valid_number, '愛知県名古屋市守山区町南');
ok($zip->set_number('4630067')->is_valid_number, '愛知県名古屋市守山区守山(丁目)');
ok($zip->set_number('4630068')->is_valid_number, '愛知県名古屋市守山区瀬古(丁目)');
ok($zip->set_number('4630069')->is_valid_number, '愛知県名古屋市守山区新守西');
ok($zip->set_number('4630070')->is_valid_number, '愛知県名古屋市守山区新守山');
ok($zip->set_number('4630071')->is_valid_number, '愛知県名古屋市守山区新守町');
ok($zip->set_number('4630072')->is_valid_number, '愛知県名古屋市守山区金屋');
ok($zip->set_number('4630073')->is_valid_number, '愛知県名古屋市守山区守牧町');
ok($zip->set_number('4630074')->is_valid_number, '愛知県名古屋市守山区町北');
ok($zip->set_number('4630075')->is_valid_number, '愛知県名古屋市守山区市場');
ok($zip->set_number('4630076')->is_valid_number, '愛知県名古屋市守山区鳥羽見');
ok($zip->set_number('4630077')->is_valid_number, '愛知県名古屋市守山区守山(番地)');
ok($zip->set_number('4630078')->is_valid_number, '愛知県名古屋市守山区瀬古(大字)');
ok($zip->set_number('4630079')->is_valid_number, '愛知県名古屋市守山区幸心');
ok($zip->set_number('4630080')->is_valid_number, '愛知県名古屋市守山区川西');
ok($zip->set_number('4630081')->is_valid_number, '愛知県名古屋市守山区川宮町');
ok($zip->set_number('4630082')->is_valid_number, '愛知県名古屋市守山区村前町');
ok($zip->set_number('4630083')->is_valid_number, '愛知県名古屋市守山区村合町');
ok($zip->set_number('4630084')->is_valid_number, '愛知県名古屋市守山区西城');
ok($zip->set_number('4630085')->is_valid_number, '愛知県名古屋市守山区大牧町');
ok($zip->set_number('4630086')->is_valid_number, '愛知県名古屋市守山区永森町');
ok($zip->set_number('4630087')->is_valid_number, '愛知県名古屋市守山区大永寺町');
ok($zip->set_number('4630088')->is_valid_number, '愛知県名古屋市守山区鳥神町');
ok($zip->set_number('4630089')->is_valid_number, '愛知県名古屋市守山区西川原町');
ok($zip->set_number('4630090')->is_valid_number, '愛知県名古屋市守山区瀬古東');
ok($zip->set_number('4630091')->is_valid_number, '愛知県名古屋市守山区川上町');
ok($zip->set_number('4630092')->is_valid_number, '愛知県名古屋市守山区白沢町');
ok($zip->set_number('4630093')->is_valid_number, '愛知県名古屋市守山区城土町');
ok($zip->set_number('4630094')->is_valid_number, '愛知県名古屋市守山区牛牧');
ok($zip->set_number('4630095')->is_valid_number, '愛知県名古屋市守山区高島町');
ok($zip->set_number('4630096')->is_valid_number, '愛知県名古屋市守山区森宮町');
ok($zip->set_number('4630097')->is_valid_number, '愛知県名古屋市守山区川村町');
ok($zip->set_number('4630098')->is_valid_number, '愛知県名古屋市守山区川北町');
ok($zip->set_number('4630801')->is_valid_number, '愛知県名古屋市守山区竜泉寺');
ok($zip->set_number('4630802')->is_valid_number, '愛知県名古屋市守山区大森北');
ok($zip->set_number('4630803')->is_valid_number, '愛知県名古屋市守山区日の後');
ok($zip->set_number('4630804')->is_valid_number, '愛知県名古屋市守山区泉が丘');
ok($zip->set_number('4630805')->is_valid_number, '愛知県名古屋市守山区青山台');
ok($zip->set_number('4630806')->is_valid_number, '愛知県名古屋市守山区百合が丘');
ok($zip->set_number('4630807')->is_valid_number, '愛知県名古屋市守山区鼓が丘');
ok($zip->set_number('4630808')->is_valid_number, '愛知県名古屋市守山区花咲台');
ok($zip->set_number('4630809')->is_valid_number, '愛知県名古屋市守山区平池東');
ok($zip->set_number('4630811')->is_valid_number, '愛知県名古屋市守山区深沢');
ok($zip->set_number('4630812')->is_valid_number, '愛知県名古屋市守山区笹ヶ根');
ok($zip->set_number('4630813')->is_valid_number, '愛知県名古屋市守山区吉根南');
ok($zip->set_number('4630814')->is_valid_number, '愛知県名古屋市守山区桔梗平');
ok($zip->set_number('4630815')->is_valid_number, '愛知県名古屋市守山区青葉台');
ok($zip->set_number('4640000')->is_valid_number, '愛知県名古屋市千種区以下に掲載がない場合');
ok($zip->set_number('4640001')->is_valid_number, '愛知県名古屋市千種区東千種台');
ok($zip->set_number('4640002')->is_valid_number, '愛知県名古屋市千種区香流橋');
ok($zip->set_number('4640003')->is_valid_number, '愛知県名古屋市千種区新西');
ok($zip->set_number('4640004')->is_valid_number, '愛知県名古屋市千種区京命');
ok($zip->set_number('4640005')->is_valid_number, '愛知県名古屋市千種区千代が丘');
ok($zip->set_number('4640006')->is_valid_number, '愛知県名古屋市千種区光が丘');
ok($zip->set_number('4640007')->is_valid_number, '愛知県名古屋市千種区竹越');
ok($zip->set_number('4640008')->is_valid_number, '愛知県名古屋市千種区宮根台');
ok($zip->set_number('4640011')->is_valid_number, '愛知県名古屋市千種区千代田橋');
ok($zip->set_number('4640012')->is_valid_number, '愛知県名古屋市千種区猪高町猪子石猪々道');
ok($zip->set_number('4640013')->is_valid_number, '愛知県名古屋市千種区汁谷町');
ok($zip->set_number('4640014')->is_valid_number, '愛知県名古屋市千種区御影町');
ok($zip->set_number('4640015')->is_valid_number, '愛知県名古屋市千種区富士見台');
ok($zip->set_number('4640016')->is_valid_number, '愛知県名古屋市千種区希望ケ丘');
ok($zip->set_number('4640017')->is_valid_number, '愛知県名古屋市千種区鍋屋上野町(汁谷)');
ok($zip->set_number('4640018')->is_valid_number, '愛知県名古屋市千種区鍋屋上野町(北山)');
ok($zip->set_number('4640019')->is_valid_number, '愛知県名古屋市千種区揚羽町');
ok($zip->set_number('4640021')->is_valid_number, '愛知県名古屋市千種区鹿子殿');
ok($zip->set_number('4640022')->is_valid_number, '愛知県名古屋市千種区平和公園');
ok($zip->set_number('4640023')->is_valid_number, '愛知県名古屋市千種区田代町(鹿子殿)');
ok($zip->set_number('4640024')->is_valid_number, '愛知県名古屋市千種区平和が丘');
ok($zip->set_number('4640025')->is_valid_number, '愛知県名古屋市千種区桜が丘');
ok($zip->set_number('4640026')->is_valid_number, '愛知県名古屋市千種区井上町');
ok($zip->set_number('4640027')->is_valid_number, '愛知県名古屋市千種区新池町');
ok($zip->set_number('4640028')->is_valid_number, '愛知県名古屋市千種区東明町');
ok($zip->set_number('4640029')->is_valid_number, '愛知県名古屋市千種区池上町');
ok($zip->set_number('4640031')->is_valid_number, '愛知県名古屋市千種区徳川山町');
ok($zip->set_number('4640032')->is_valid_number, '愛知県名古屋市千種区猫洞通');
ok($zip->set_number('4640033')->is_valid_number, '愛知県名古屋市千種区鹿子町');
ok($zip->set_number('4640034')->is_valid_number, '愛知県名古屋市千種区清住町');
ok($zip->set_number('4640035')->is_valid_number, '愛知県名古屋市千種区橋本町');
ok($zip->set_number('4640036')->is_valid_number, '愛知県名古屋市千種区本山町');
ok($zip->set_number('4640037')->is_valid_number, '愛知県名古屋市千種区楠元町');
ok($zip->set_number('4640038')->is_valid_number, '愛知県名古屋市千種区春里町');
ok($zip->set_number('4640039')->is_valid_number, '愛知県名古屋市千種区日和町');
ok($zip->set_number('4640041')->is_valid_number, '愛知県名古屋市千種区霞ケ丘');
ok($zip->set_number('4640042')->is_valid_number, '愛知県名古屋市千種区南ケ丘');
ok($zip->set_number('4640043')->is_valid_number, '愛知県名古屋市千種区月ケ丘');
ok($zip->set_number('4640044')->is_valid_number, '愛知県名古屋市千種区自由ケ丘');
ok($zip->set_number('4640045')->is_valid_number, '愛知県名古屋市千種区城山町');
ok($zip->set_number('4640046')->is_valid_number, '愛知県名古屋市千種区城山新町');
ok($zip->set_number('4640051')->is_valid_number, '愛知県名古屋市千種区田代町(四観音道東)');
ok($zip->set_number('4640052')->is_valid_number, '愛知県名古屋市千種区田代町(四観音道西)');
ok($zip->set_number('4640053')->is_valid_number, '愛知県名古屋市千種区田代町(岩谷)');
ok($zip->set_number('4640054')->is_valid_number, '愛知県名古屋市千種区田代町(蝮ケ池上)');
ok($zip->set_number('4640055')->is_valid_number, '愛知県名古屋市千種区姫池通');
ok($zip->set_number('4640056')->is_valid_number, '愛知県名古屋市千種区月見坂町');
ok($zip->set_number('4640057')->is_valid_number, '愛知県名古屋市千種区法王町');
ok($zip->set_number('4640061')->is_valid_number, '愛知県名古屋市千種区向陽');
ok($zip->set_number('4640062')->is_valid_number, '愛知県名古屋市千種区向陽町');
ok($zip->set_number('4640063')->is_valid_number, '愛知県名古屋市千種区西山元町');
ok($zip->set_number('4640064')->is_valid_number, '愛知県名古屋市千種区山門町');
ok($zip->set_number('4640065')->is_valid_number, '愛知県名古屋市千種区堀割町');
ok($zip->set_number('4640066')->is_valid_number, '愛知県名古屋市千種区池下町');
ok($zip->set_number('4640067')->is_valid_number, '愛知県名古屋市千種区池下');
ok($zip->set_number('4640071')->is_valid_number, '愛知県名古屋市千種区若水');
ok($zip->set_number('4640072')->is_valid_number, '愛知県名古屋市千種区振甫町');
ok($zip->set_number('4640073')->is_valid_number, '愛知県名古屋市千種区高見');
ok($zip->set_number('4640074')->is_valid_number, '愛知県名古屋市千種区仲田');
ok($zip->set_number('4640075')->is_valid_number, '愛知県名古屋市千種区内山');
ok($zip->set_number('4640076')->is_valid_number, '愛知県名古屋市千種区豊年町');
ok($zip->set_number('4640077')->is_valid_number, '愛知県名古屋市千種区神田町');
ok($zip->set_number('4640081')->is_valid_number, '愛知県名古屋市千種区谷口町');
ok($zip->set_number('4640082')->is_valid_number, '愛知県名古屋市千種区上野');
ok($zip->set_number('4640083')->is_valid_number, '愛知県名古屋市千種区北千種');
ok($zip->set_number('4640084')->is_valid_number, '愛知県名古屋市千種区松軒');
ok($zip->set_number('4640085')->is_valid_number, '愛知県名古屋市千種区古出来');
ok($zip->set_number('4640086')->is_valid_number, '愛知県名古屋市千種区萱場');
ok($zip->set_number('4640087')->is_valid_number, '愛知県名古屋市千種区清明山');
ok($zip->set_number('4640091')->is_valid_number, '愛知県名古屋市千種区宮の腰町');
ok($zip->set_number('4640092')->is_valid_number, '愛知県名古屋市千種区茶屋が坂');
ok($zip->set_number('4640093')->is_valid_number, '愛知県名古屋市千種区茶屋坂通');
ok($zip->set_number('4640094')->is_valid_number, '愛知県名古屋市千種区赤坂町');
ok($zip->set_number('4640095')->is_valid_number, '愛知県名古屋市千種区天満通');
ok($zip->set_number('4640096')->is_valid_number, '愛知県名古屋市千種区下方町');
ok($zip->set_number('4640097')->is_valid_number, '愛知県名古屋市千種区鍋屋上野町(東脇)');
ok($zip->set_number('4640801')->is_valid_number, '愛知県名古屋市千種区星ケ丘');
ok($zip->set_number('4640802')->is_valid_number, '愛知県名古屋市千種区星が丘元町');
ok($zip->set_number('4640803')->is_valid_number, '愛知県名古屋市千種区田代町(瓶杁)');
ok($zip->set_number('4640804')->is_valid_number, '愛知県名古屋市千種区東山元町');
ok($zip->set_number('4640805')->is_valid_number, '愛知県名古屋市千種区萩岡町');
ok($zip->set_number('4640806')->is_valid_number, '愛知県名古屋市千種区唐山町');
ok($zip->set_number('4640807')->is_valid_number, '愛知県名古屋市千種区東山通');
ok($zip->set_number('4640808')->is_valid_number, '愛知県名古屋市千種区星が丘山手');
ok($zip->set_number('4640811')->is_valid_number, '愛知県名古屋市千種区朝岡町');
ok($zip->set_number('4640812')->is_valid_number, '愛知県名古屋市千種区園山町');
ok($zip->set_number('4640813')->is_valid_number, '愛知県名古屋市千種区仁座町');
ok($zip->set_number('4640814')->is_valid_number, '愛知県名古屋市千種区不老町');
ok($zip->set_number('4640815')->is_valid_number, '愛知県名古屋市千種区幸川町');
ok($zip->set_number('4640816')->is_valid_number, '愛知県名古屋市千種区鏡池通');
ok($zip->set_number('4640817')->is_valid_number, '愛知県名古屋市千種区見附町');
ok($zip->set_number('4640818')->is_valid_number, '愛知県名古屋市千種区池園町');
ok($zip->set_number('4640819')->is_valid_number, '愛知県名古屋市千種区四谷通');
ok($zip->set_number('4640821')->is_valid_number, '愛知県名古屋市千種区末盛通');
ok($zip->set_number('4640822')->is_valid_number, '愛知県名古屋市千種区穂波町');
ok($zip->set_number('4640823')->is_valid_number, '愛知県名古屋市千種区松竹町');
ok($zip->set_number('4640824')->is_valid_number, '愛知県名古屋市千種区稲舟通');
ok($zip->set_number('4640825')->is_valid_number, '愛知県名古屋市千種区西崎町');
ok($zip->set_number('4640826')->is_valid_number, '愛知県名古屋市千種区川崎町');
ok($zip->set_number('4640827')->is_valid_number, '愛知県名古屋市千種区田代本通');
ok($zip->set_number('4640831')->is_valid_number, '愛知県名古屋市千種区観月町');
ok($zip->set_number('4640832')->is_valid_number, '愛知県名古屋市千種区山添町');
ok($zip->set_number('4640833')->is_valid_number, '愛知県名古屋市千種区大島町');
ok($zip->set_number('4640834')->is_valid_number, '愛知県名古屋市千種区日岡町');
ok($zip->set_number('4640835')->is_valid_number, '愛知県名古屋市千種区御棚町');
ok($zip->set_number('4640836')->is_valid_number, '愛知県名古屋市千種区菊坂町');
ok($zip->set_number('4640837')->is_valid_number, '愛知県名古屋市千種区丘上町');
ok($zip->set_number('4640841')->is_valid_number, '愛知県名古屋市千種区覚王山通');
ok($zip->set_number('4640842')->is_valid_number, '愛知県名古屋市千種区桐林町');
ok($zip->set_number('4640843')->is_valid_number, '愛知県名古屋市千種区丸山町');
ok($zip->set_number('4640844')->is_valid_number, '愛知県名古屋市千種区日進通');
ok($zip->set_number('4640845')->is_valid_number, '愛知県名古屋市千種区南明町');
ok($zip->set_number('4640846')->is_valid_number, '愛知県名古屋市千種区城木町');
ok($zip->set_number('4640847')->is_valid_number, '愛知県名古屋市千種区春岡通');
ok($zip->set_number('4640848')->is_valid_number, '愛知県名古屋市千種区春岡');
ok($zip->set_number('4640850')->is_valid_number, '愛知県名古屋市千種区今池');
ok($zip->set_number('4640851')->is_valid_number, '愛知県名古屋市千種区今池南');
ok($zip->set_number('4640852')->is_valid_number, '愛知県名古屋市千種区青柳町');
ok($zip->set_number('4640853')->is_valid_number, '愛知県名古屋市千種区小松町');
ok($zip->set_number('4640854')->is_valid_number, '愛知県名古屋市千種区大久手町');
ok($zip->set_number('4640855')->is_valid_number, '愛知県名古屋市千種区千種通');
ok($zip->set_number('4640856')->is_valid_number, '愛知県名古屋市千種区吹上');
ok($zip->set_number('4640857')->is_valid_number, '愛知県名古屋市千種区花田町');
ok($zip->set_number('4640858')->is_valid_number, '愛知県名古屋市千種区千種');
ok($zip->set_number('4640859')->is_valid_number, '愛知県名古屋市千種区新栄(3丁目)');
ok($zip->set_number('4640871')->is_valid_number, '愛知県名古屋市千種区天白町植田');
ok($zip->set_number('4650000')->is_valid_number, '愛知県名古屋市名東区以下に掲載がない場合');
ok($zip->set_number('4650002')->is_valid_number, '愛知県名古屋市名東区引山');
ok($zip->set_number('4650003')->is_valid_number, '愛知県名古屋市名東区延珠町');
ok($zip->set_number('4650004')->is_valid_number, '愛知県名古屋市名東区香南');
ok($zip->set_number('4650005')->is_valid_number, '愛知県名古屋市名東区香流');
ok($zip->set_number('4650006')->is_valid_number, '愛知県名古屋市名東区神月町');
ok($zip->set_number('4650007')->is_valid_number, '愛知県名古屋市名東区香坂');
ok($zip->set_number('4650008')->is_valid_number, '愛知県名古屋市名東区猪子石原');
ok($zip->set_number('4650009')->is_valid_number, '愛知県名古屋市名東区天神下');
ok($zip->set_number('4650011')->is_valid_number, '愛知県名古屋市名東区山の手');
ok($zip->set_number('4650012')->is_valid_number, '愛知県名古屋市名東区文教台');
ok($zip->set_number('4650013')->is_valid_number, '愛知県名古屋市名東区社口');
ok($zip->set_number('4650014')->is_valid_number, '愛知県名古屋市名東区上菅');
ok($zip->set_number('4650015')->is_valid_number, '愛知県名古屋市名東区若葉台');
ok($zip->set_number('4650016')->is_valid_number, '愛知県名古屋市名東区赤松台');
ok($zip->set_number('4650017')->is_valid_number, '愛知県名古屋市名東区つつじが丘');
ok($zip->set_number('4650018')->is_valid_number, '愛知県名古屋市名東区八前');
ok($zip->set_number('4650021')->is_valid_number, '愛知県名古屋市名東区猪子石');
ok($zip->set_number('4650022')->is_valid_number, '愛知県名古屋市名東区藤森西町');
ok($zip->set_number('4650023')->is_valid_number, '愛知県名古屋市名東区石が根町');
ok($zip->set_number('4650024')->is_valid_number, '愛知県名古屋市名東区本郷');
ok($zip->set_number('4650025')->is_valid_number, '愛知県名古屋市名東区上社');
ok($zip->set_number('4650026')->is_valid_number, '愛知県名古屋市名東区藤森');
ok($zip->set_number('4650027')->is_valid_number, '愛知県名古屋市名東区丁田町');
ok($zip->set_number('4650028')->is_valid_number, '愛知県名古屋市名東区猪高台');
ok($zip->set_number('4650031')->is_valid_number, '愛知県名古屋市名東区富が丘');
ok($zip->set_number('4650032')->is_valid_number, '愛知県名古屋市名東区藤が丘');
ok($zip->set_number('4650033')->is_valid_number, '愛知県名古屋市名東区明が丘');
ok($zip->set_number('4650034')->is_valid_number, '愛知県名古屋市名東区高柳町');
ok($zip->set_number('4650035')->is_valid_number, '愛知県名古屋市名東区豊が丘');
ok($zip->set_number('4650036')->is_valid_number, '愛知県名古屋市名東区藤里町');
ok($zip->set_number('4650037')->is_valid_number, '愛知県名古屋市名東区藤香町');
ok($zip->set_number('4650041')->is_valid_number, '愛知県名古屋市名東区朝日が丘');
ok($zip->set_number('4650042')->is_valid_number, '愛知県名古屋市名東区照が丘');
ok($zip->set_number('4650043')->is_valid_number, '愛知県名古屋市名東区宝が丘');
ok($zip->set_number('4650044')->is_valid_number, '愛知県名古屋市名東区小井堀町');
ok($zip->set_number('4650045')->is_valid_number, '愛知県名古屋市名東区姫若町');
ok($zip->set_number('4650046')->is_valid_number, '愛知県名古屋市名東区望が丘');
ok($zip->set_number('4650047')->is_valid_number, '愛知県名古屋市名東区小池町');
ok($zip->set_number('4650048')->is_valid_number, '愛知県名古屋市名東区藤見が丘');
ok($zip->set_number('4650051')->is_valid_number, '愛知県名古屋市名東区社が丘');
ok($zip->set_number('4650052')->is_valid_number, '愛知県名古屋市名東区猪高町上社');
ok($zip->set_number('4650053')->is_valid_number, '愛知県名古屋市名東区極楽');
ok($zip->set_number('4650054')->is_valid_number, '愛知県名古屋市名東区高針台');
ok($zip->set_number('4650055')->is_valid_number, '愛知県名古屋市名東区勢子坊');
ok($zip->set_number('4650056')->is_valid_number, '愛知県名古屋市名東区野間町');
ok($zip->set_number('4650057')->is_valid_number, '愛知県名古屋市名東区陸前町');
ok($zip->set_number('4650058')->is_valid_number, '愛知県名古屋市名東区貴船');
ok($zip->set_number('4650061')->is_valid_number, '愛知県名古屋市名東区高針');
ok($zip->set_number('4650062')->is_valid_number, '愛知県名古屋市名東区松井町');
ok($zip->set_number('4650063')->is_valid_number, '愛知県名古屋市名東区新宿');
ok($zip->set_number('4650064')->is_valid_number, '愛知県名古屋市名東区大針');
ok($zip->set_number('4650065')->is_valid_number, '愛知県名古屋市名東区梅森坂');
ok($zip->set_number('4650066')->is_valid_number, '愛知県名古屋市名東区梅森坂西');
ok($zip->set_number('4650067')->is_valid_number, '愛知県名古屋市名東区猪高町高針');
ok($zip->set_number('4650068')->is_valid_number, '愛知県名古屋市名東区牧の里');
ok($zip->set_number('4650069')->is_valid_number, '愛知県名古屋市名東区高針荒田');
ok($zip->set_number('4650071')->is_valid_number, '愛知県名古屋市名東区西山台');
ok($zip->set_number('4650072')->is_valid_number, '愛知県名古屋市名東区牧の原');
ok($zip->set_number('4650073')->is_valid_number, '愛知県名古屋市名東区高針原');
ok($zip->set_number('4650074')->is_valid_number, '愛知県名古屋市名東区山香町');
ok($zip->set_number('4650075')->is_valid_number, '愛知県名古屋市名東区藤巻町');
ok($zip->set_number('4650076')->is_valid_number, '愛知県名古屋市名東区扇町');
ok($zip->set_number('4650077')->is_valid_number, '愛知県名古屋市名東区植園町');
ok($zip->set_number('4650078')->is_valid_number, '愛知県名古屋市名東区にじが丘');
ok($zip->set_number('4650081')->is_valid_number, '愛知県名古屋市名東区高間町');
ok($zip->set_number('4650082')->is_valid_number, '愛知県名古屋市名東区神里');
ok($zip->set_number('4650083')->is_valid_number, '愛知県名古屋市名東区神丘町');
ok($zip->set_number('4650084')->is_valid_number, '愛知県名古屋市名東区西里町');
ok($zip->set_number('4650085')->is_valid_number, '愛知県名古屋市名東区西山本通');
ok($zip->set_number('4650086')->is_valid_number, '愛知県名古屋市名東区代万町');
ok($zip->set_number('4650087')->is_valid_number, '愛知県名古屋市名東区名東本通');
ok($zip->set_number('4650088')->is_valid_number, '愛知県名古屋市名東区名東本町');
ok($zip->set_number('4650091')->is_valid_number, '愛知県名古屋市名東区よもぎ台');
ok($zip->set_number('4650092')->is_valid_number, '愛知県名古屋市名東区社台');
ok($zip->set_number('4650093')->is_valid_number, '愛知県名古屋市名東区一社');
ok($zip->set_number('4650094')->is_valid_number, '愛知県名古屋市名東区亀の井');
ok($zip->set_number('4650095')->is_valid_number, '愛知県名古屋市名東区高社');
ok($zip->set_number('4650096')->is_valid_number, '愛知県名古屋市名東区桜が丘');
ok($zip->set_number('4650097')->is_valid_number, '愛知県名古屋市名東区平和が丘');
ok($zip->set_number('4660000')->is_valid_number, '愛知県名古屋市昭和区以下に掲載がない場合');
ok($zip->set_number('4660001')->is_valid_number, '愛知県名古屋市昭和区車田町');
ok($zip->set_number('4660002')->is_valid_number, '愛知県名古屋市昭和区吹上町');
ok($zip->set_number('4660003')->is_valid_number, '愛知県名古屋市昭和区曙町');
ok($zip->set_number('4660004')->is_valid_number, '愛知県名古屋市昭和区広瀬町');
ok($zip->set_number('4660005')->is_valid_number, '愛知県名古屋市昭和区雪見町');
ok($zip->set_number('4660006')->is_valid_number, '愛知県名古屋市昭和区北山町');
ok($zip->set_number('4660011')->is_valid_number, '愛知県名古屋市昭和区鶴羽町');
ok($zip->set_number('4660012')->is_valid_number, '愛知県名古屋市昭和区小桜町');
ok($zip->set_number('4660013')->is_valid_number, '愛知県名古屋市昭和区緑町');
ok($zip->set_number('4660014')->is_valid_number, '愛知県名古屋市昭和区東畑町');
ok($zip->set_number('4660015')->is_valid_number, '愛知県名古屋市昭和区御器所通');
ok($zip->set_number('4660016')->is_valid_number, '愛知県名古屋市昭和区北山本町');
ok($zip->set_number('4660021')->is_valid_number, '愛知県名古屋市昭和区小坂町');
ok($zip->set_number('4660022')->is_valid_number, '愛知県名古屋市昭和区塩付通');
ok($zip->set_number('4660023')->is_valid_number, '愛知県名古屋市昭和区石仏町');
ok($zip->set_number('4660024')->is_valid_number, '愛知県名古屋市昭和区大和町');
ok($zip->set_number('4660025')->is_valid_number, '愛知県名古屋市昭和区下構町');
ok($zip->set_number('4660026')->is_valid_number, '愛知県名古屋市昭和区陶生町');
ok($zip->set_number('4660027')->is_valid_number, '愛知県名古屋市昭和区阿由知通');
ok($zip->set_number('4660031')->is_valid_number, '愛知県名古屋市昭和区紅梅町');
ok($zip->set_number('4660032')->is_valid_number, '愛知県名古屋市昭和区天神町');
ok($zip->set_number('4660033')->is_valid_number, '愛知県名古屋市昭和区台町');
ok($zip->set_number('4660034')->is_valid_number, '愛知県名古屋市昭和区明月町');
ok($zip->set_number('4660035')->is_valid_number, '愛知県名古屋市昭和区松風町');
ok($zip->set_number('4660036')->is_valid_number, '愛知県名古屋市昭和区若柳町');
ok($zip->set_number('4660037')->is_valid_number, '愛知県名古屋市昭和区恵方町');
ok($zip->set_number('4660041')->is_valid_number, '愛知県名古屋市昭和区出口町');
ok($zip->set_number('4660042')->is_valid_number, '愛知県名古屋市昭和区広池町');
ok($zip->set_number('4660043')->is_valid_number, '愛知県名古屋市昭和区池端町');
ok($zip->set_number('4660044')->is_valid_number, '愛知県名古屋市昭和区桜山町');
ok($zip->set_number('4660045')->is_valid_number, '愛知県名古屋市昭和区丸屋町');
ok($zip->set_number('4660046')->is_valid_number, '愛知県名古屋市昭和区広見町');
ok($zip->set_number('4660047')->is_valid_number, '愛知県名古屋市昭和区永金町');
ok($zip->set_number('4660051')->is_valid_number, '愛知県名古屋市昭和区御器所');
ok($zip->set_number('4660052')->is_valid_number, '愛知県名古屋市昭和区村雲町');
ok($zip->set_number('4660053')->is_valid_number, '愛知県名古屋市昭和区滝子町');
ok($zip->set_number('4660054')->is_valid_number, '愛知県名古屋市昭和区円上町');
ok($zip->set_number('4660055')->is_valid_number, '愛知県名古屋市昭和区滝子通');
ok($zip->set_number('4660056')->is_valid_number, '愛知県名古屋市昭和区東郊通');
ok($zip->set_number('4660057')->is_valid_number, '愛知県名古屋市昭和区高辻町');
ok($zip->set_number('4660058')->is_valid_number, '愛知県名古屋市昭和区白金');
ok($zip->set_number('4660059')->is_valid_number, '愛知県名古屋市昭和区福江');
ok($zip->set_number('4660061')->is_valid_number, '愛知県名古屋市昭和区御器所町');
ok($zip->set_number('4660062')->is_valid_number, '愛知県名古屋市昭和区狭間町');
ok($zip->set_number('4660063')->is_valid_number, '愛知県名古屋市昭和区山脇町');
ok($zip->set_number('4660064')->is_valid_number, '愛知県名古屋市昭和区鶴舞');
ok($zip->set_number('4660065')->is_valid_number, '愛知県名古屋市昭和区鶴舞町');
ok($zip->set_number('4660801')->is_valid_number, '愛知県名古屋市昭和区田面町');
ok($zip->set_number('4660802')->is_valid_number, '愛知県名古屋市昭和区神村町');
ok($zip->set_number('4660803')->is_valid_number, '愛知県名古屋市昭和区福原町');
ok($zip->set_number('4660804')->is_valid_number, '愛知県名古屋市昭和区宮東町');
ok($zip->set_number('4660805')->is_valid_number, '愛知県名古屋市昭和区伊勝町');
ok($zip->set_number('4660806')->is_valid_number, '愛知県名古屋市昭和区西畑町');
ok($zip->set_number('4660807')->is_valid_number, '愛知県名古屋市昭和区山花町');
ok($zip->set_number('4660811')->is_valid_number, '愛知県名古屋市昭和区高峯町');
ok($zip->set_number('4660812')->is_valid_number, '愛知県名古屋市昭和区八事富士見');
ok($zip->set_number('4660814')->is_valid_number, '愛知県名古屋市昭和区妙見町');
ok($zip->set_number('4660815')->is_valid_number, '愛知県名古屋市昭和区山手通');
ok($zip->set_number('4660821')->is_valid_number, '愛知県名古屋市昭和区前山町');
ok($zip->set_number('4660822')->is_valid_number, '愛知県名古屋市昭和区楽園町');
ok($zip->set_number('4660823')->is_valid_number, '愛知県名古屋市昭和区八雲町');
ok($zip->set_number('4660824')->is_valid_number, '愛知県名古屋市昭和区山里町');
ok($zip->set_number('4660825')->is_valid_number, '愛知県名古屋市昭和区八事本町');
ok($zip->set_number('4660826')->is_valid_number, '愛知県名古屋市昭和区滝川町');
ok($zip->set_number('4660827')->is_valid_number, '愛知県名古屋市昭和区川名山町');
ok($zip->set_number('4660828')->is_valid_number, '愛知県名古屋市昭和区山中町');
ok($zip->set_number('4660829')->is_valid_number, '愛知県名古屋市昭和区向山町');
ok($zip->set_number('4660831')->is_valid_number, '愛知県名古屋市昭和区花見通');
ok($zip->set_number('4660832')->is_valid_number, '愛知県名古屋市昭和区駒方町');
ok($zip->set_number('4660833')->is_valid_number, '愛知県名古屋市昭和区隼人町');
ok($zip->set_number('4660834')->is_valid_number, '愛知県名古屋市昭和区広路町');
ok($zip->set_number('4660835')->is_valid_number, '愛知県名古屋市昭和区南山町');
ok($zip->set_number('4660836')->is_valid_number, '愛知県名古屋市昭和区上山町');
ok($zip->set_number('4660837')->is_valid_number, '愛知県名古屋市昭和区汐見町');
ok($zip->set_number('4660838')->is_valid_number, '愛知県名古屋市昭和区五軒家町');
ok($zip->set_number('4660841')->is_valid_number, '愛知県名古屋市昭和区広路本町');
ok($zip->set_number('4660842')->is_valid_number, '愛知県名古屋市昭和区檀溪通');
ok($zip->set_number('4660843')->is_valid_number, '愛知県名古屋市昭和区菊園町');
ok($zip->set_number('4660844')->is_valid_number, '愛知県名古屋市昭和区荒田町');
ok($zip->set_number('4660845')->is_valid_number, '愛知県名古屋市昭和区藤成通');
ok($zip->set_number('4660846')->is_valid_number, '愛知県名古屋市昭和区戸田町');
ok($zip->set_number('4660847')->is_valid_number, '愛知県名古屋市昭和区長池町');
ok($zip->set_number('4660848')->is_valid_number, '愛知県名古屋市昭和区長戸町');
ok($zip->set_number('4660849')->is_valid_number, '愛知県名古屋市昭和区南分町');
ok($zip->set_number('4660851')->is_valid_number, '愛知県名古屋市昭和区元宮町');
ok($zip->set_number('4660852')->is_valid_number, '愛知県名古屋市昭和区萩原町');
ok($zip->set_number('4660853')->is_valid_number, '愛知県名古屋市昭和区川原通');
ok($zip->set_number('4660854')->is_valid_number, '愛知県名古屋市昭和区広路通');
ok($zip->set_number('4660855')->is_valid_number, '愛知県名古屋市昭和区川名本町');
ok($zip->set_number('4660856')->is_valid_number, '愛知県名古屋市昭和区川名町');
ok($zip->set_number('4660857')->is_valid_number, '愛知県名古屋市昭和区安田通');
ok($zip->set_number('4660858')->is_valid_number, '愛知県名古屋市昭和区折戸町');
ok($zip->set_number('4670000')->is_valid_number, '愛知県名古屋市瑞穂区以下に掲載がない場合');
ok($zip->set_number('4670001')->is_valid_number, '愛知県名古屋市瑞穂区瑞穂町(川澄)');
ok($zip->set_number('4670002')->is_valid_number, '愛知県名古屋市瑞穂区川澄町');
ok($zip->set_number('4670003')->is_valid_number, '愛知県名古屋市瑞穂区汐路町');
ok($zip->set_number('4670004')->is_valid_number, '愛知県名古屋市瑞穂区松月町');
ok($zip->set_number('4670005')->is_valid_number, '愛知県名古屋市瑞穂区石川町');
ok($zip->set_number('4670006')->is_valid_number, '愛知県名古屋市瑞穂区御莨町');
ok($zip->set_number('4670007')->is_valid_number, '愛知県名古屋市瑞穂区大殿町');
ok($zip->set_number('4670008')->is_valid_number, '愛知県名古屋市瑞穂区村上町');
ok($zip->set_number('4670011')->is_valid_number, '愛知県名古屋市瑞穂区萩山町');
ok($zip->set_number('4670012')->is_valid_number, '愛知県名古屋市瑞穂区豊岡通');
ok($zip->set_number('4670013')->is_valid_number, '愛知県名古屋市瑞穂区膳棚町');
ok($zip->set_number('4670014')->is_valid_number, '愛知県名古屋市瑞穂区白羽根町');
ok($zip->set_number('4670015')->is_valid_number, '愛知県名古屋市瑞穂区十六町');
ok($zip->set_number('4670016')->is_valid_number, '愛知県名古屋市瑞穂区佐渡町');
ok($zip->set_number('4670017')->is_valid_number, '愛知県名古屋市瑞穂区東栄町');
ok($zip->set_number('4670021')->is_valid_number, '愛知県名古屋市瑞穂区檀渓通');
ok($zip->set_number('4670022')->is_valid_number, '愛知県名古屋市瑞穂区上山町');
ok($zip->set_number('4670023')->is_valid_number, '愛知県名古屋市瑞穂区南山町');
ok($zip->set_number('4670024')->is_valid_number, '愛知県名古屋市瑞穂区春山町');
ok($zip->set_number('4670025')->is_valid_number, '愛知県名古屋市瑞穂区松栄町');
ok($zip->set_number('4670026')->is_valid_number, '愛知県名古屋市瑞穂区陽明町');
ok($zip->set_number('4670027')->is_valid_number, '愛知県名古屋市瑞穂区田辺通');
ok($zip->set_number('4670028')->is_valid_number, '愛知県名古屋市瑞穂区初日町');
ok($zip->set_number('4670031')->is_valid_number, '愛知県名古屋市瑞穂区弥富町緑ケ岡');
ok($zip->set_number('4670032')->is_valid_number, '愛知県名古屋市瑞穂区弥富町紅葉園');
ok($zip->set_number('4670033')->is_valid_number, '愛知県名古屋市瑞穂区弥富町円山');
ok($zip->set_number('4670034')->is_valid_number, '愛知県名古屋市瑞穂区弥富町桜ケ岡');
ok($zip->set_number('4670035')->is_valid_number, '愛知県名古屋市瑞穂区弥富町月見ケ岡');
ok($zip->set_number('4670036')->is_valid_number, '愛知県名古屋市瑞穂区弥富町密柑山');
ok($zip->set_number('4670037')->is_valid_number, '愛知県名古屋市瑞穂区弥富町上山');
ok($zip->set_number('4670038')->is_valid_number, '愛知県名古屋市瑞穂区弥富町清水ケ岡');
ok($zip->set_number('4670039')->is_valid_number, '愛知県名古屋市瑞穂区弥富町茨山');
ok($zip->set_number('4670041')->is_valid_number, '愛知県名古屋市瑞穂区密柑山町');
ok($zip->set_number('4670042')->is_valid_number, '愛知県名古屋市瑞穂区八勝通');
ok($zip->set_number('4670043')->is_valid_number, '愛知県名古屋市瑞穂区岳見町');
ok($zip->set_number('4670044')->is_valid_number, '愛知県名古屋市瑞穂区柏木町');
ok($zip->set_number('4670045')->is_valid_number, '愛知県名古屋市瑞穂区茨木町');
ok($zip->set_number('4670046')->is_valid_number, '愛知県名古屋市瑞穂区玉水町');
ok($zip->set_number('4670047')->is_valid_number, '愛知県名古屋市瑞穂区日向町');
ok($zip->set_number('4670048')->is_valid_number, '愛知県名古屋市瑞穂区弥富ケ丘町');
ok($zip->set_number('4670049')->is_valid_number, '愛知県名古屋市瑞穂区下山町');
ok($zip->set_number('4670051')->is_valid_number, '愛知県名古屋市瑞穂区釜塚町');
ok($zip->set_number('4670052')->is_valid_number, '愛知県名古屋市瑞穂区片坂町');
ok($zip->set_number('4670053')->is_valid_number, '愛知県名古屋市瑞穂区仁所町');
ok($zip->set_number('4670054')->is_valid_number, '愛知県名古屋市瑞穂区丸根町');
ok($zip->set_number('4670055')->is_valid_number, '愛知県名古屋市瑞穂区中根町');
ok($zip->set_number('4670056')->is_valid_number, '愛知県名古屋市瑞穂区白砂町');
ok($zip->set_number('4670057')->is_valid_number, '愛知県名古屋市瑞穂区井の元町');
ok($zip->set_number('4670058')->is_valid_number, '愛知県名古屋市瑞穂区関取町');
ok($zip->set_number('4670059')->is_valid_number, '愛知県名古屋市瑞穂区軍水町');
ok($zip->set_number('4670061')->is_valid_number, '愛知県名古屋市瑞穂区師長町');
ok($zip->set_number('4670062')->is_valid_number, '愛知県名古屋市瑞穂区山下通');
ok($zip->set_number('4670063')->is_valid_number, '愛知県名古屋市瑞穂区市丘町');
ok($zip->set_number('4670064')->is_valid_number, '愛知県名古屋市瑞穂区弥富通');
ok($zip->set_number('4670065')->is_valid_number, '愛知県名古屋市瑞穂区松園町');
ok($zip->set_number('4670066')->is_valid_number, '愛知県名古屋市瑞穂区洲山町');
ok($zip->set_number('4670067')->is_valid_number, '愛知県名古屋市瑞穂区石田町');
ok($zip->set_number('4670068')->is_valid_number, '愛知県名古屋市瑞穂区内方町');
ok($zip->set_number('4670801')->is_valid_number, '愛知県名古屋市瑞穂区瑞穂町(西藤塚)');
ok($zip->set_number('4670802')->is_valid_number, '愛知県名古屋市瑞穂区瑞穂町(山の畑)');
ok($zip->set_number('4670803')->is_valid_number, '愛知県名古屋市瑞穂区中山町');
ok($zip->set_number('4670804')->is_valid_number, '愛知県名古屋市瑞穂区洲雲町');
ok($zip->set_number('4670805')->is_valid_number, '愛知県名古屋市瑞穂区桜見町');
ok($zip->set_number('4670806')->is_valid_number, '愛知県名古屋市瑞穂区瑞穂通');
ok($zip->set_number('4670807')->is_valid_number, '愛知県名古屋市瑞穂区駒場町');
ok($zip->set_number('4670808')->is_valid_number, '愛知県名古屋市瑞穂区高田町');
ok($zip->set_number('4670811')->is_valid_number, '愛知県名古屋市瑞穂区北原町');
ok($zip->set_number('4670812')->is_valid_number, '愛知県名古屋市瑞穂区薩摩町');
ok($zip->set_number('4670813')->is_valid_number, '愛知県名古屋市瑞穂区西ノ割町');
ok($zip->set_number('4670814')->is_valid_number, '愛知県名古屋市瑞穂区本願寺町');
ok($zip->set_number('4670815')->is_valid_number, '愛知県名古屋市瑞穂区前田町');
ok($zip->set_number('4670816')->is_valid_number, '愛知県名古屋市瑞穂区牧町');
ok($zip->set_number('4670821')->is_valid_number, '愛知県名古屋市瑞穂区上坂町');
ok($zip->set_number('4670822')->is_valid_number, '愛知県名古屋市瑞穂区大喜町');
ok($zip->set_number('4670823')->is_valid_number, '愛知県名古屋市瑞穂区津賀田町');
ok($zip->set_number('4670824')->is_valid_number, '愛知県名古屋市瑞穂区甲山町');
ok($zip->set_number('4670825')->is_valid_number, '愛知県名古屋市瑞穂区柳ケ枝町');
ok($zip->set_number('4670826')->is_valid_number, '愛知県名古屋市瑞穂区白龍町');
ok($zip->set_number('4670827')->is_valid_number, '愛知県名古屋市瑞穂区下坂町');
ok($zip->set_number('4670828')->is_valid_number, '愛知県名古屋市瑞穂区田光町');
ok($zip->set_number('4670831')->is_valid_number, '愛知県名古屋市瑞穂区惣作町');
ok($zip->set_number('4670832')->is_valid_number, '愛知県名古屋市瑞穂区神前町');
ok($zip->set_number('4670833')->is_valid_number, '愛知県名古屋市瑞穂区鍵田町');
ok($zip->set_number('4670834')->is_valid_number, '愛知県名古屋市瑞穂区姫宮町');
ok($zip->set_number('4670835')->is_valid_number, '愛知県名古屋市瑞穂区井戸田町');
ok($zip->set_number('4670836')->is_valid_number, '愛知県名古屋市瑞穂区佃町');
ok($zip->set_number('4670837')->is_valid_number, '愛知県名古屋市瑞穂区花目町');
ok($zip->set_number('4670841')->is_valid_number, '愛知県名古屋市瑞穂区苗代町');
ok($zip->set_number('4670842')->is_valid_number, '愛知県名古屋市瑞穂区妙音通');
ok($zip->set_number('4670843')->is_valid_number, '愛知県名古屋市瑞穂区土市町');
ok($zip->set_number('4670844')->is_valid_number, '愛知県名古屋市瑞穂区河岸町');
ok($zip->set_number('4670845')->is_valid_number, '愛知県名古屋市瑞穂区河岸');
ok($zip->set_number('4670846')->is_valid_number, '愛知県名古屋市瑞穂区荒崎町');
ok($zip->set_number('4670847')->is_valid_number, '愛知県名古屋市瑞穂区神穂町');
ok($zip->set_number('4670851')->is_valid_number, '愛知県名古屋市瑞穂区塩入町');
ok($zip->set_number('4670852')->is_valid_number, '愛知県名古屋市瑞穂区明前町');
ok($zip->set_number('4670853')->is_valid_number, '愛知県名古屋市瑞穂区内浜町');
ok($zip->set_number('4670854')->is_valid_number, '愛知県名古屋市瑞穂区浮島町');
ok($zip->set_number('4670855')->is_valid_number, '愛知県名古屋市瑞穂区桃園町');
ok($zip->set_number('4670856')->is_valid_number, '愛知県名古屋市瑞穂区新開町');
ok($zip->set_number('4670861')->is_valid_number, '愛知県名古屋市瑞穂区二野町');
ok($zip->set_number('4670862')->is_valid_number, '愛知県名古屋市瑞穂区堀田通');
ok($zip->set_number('4670863')->is_valid_number, '愛知県名古屋市瑞穂区牛巻町');
ok($zip->set_number('4670864')->is_valid_number, '愛知県名古屋市瑞穂区豆田町');
ok($zip->set_number('4670865')->is_valid_number, '愛知県名古屋市瑞穂区直来町');
ok($zip->set_number('4670866')->is_valid_number, '愛知県名古屋市瑞穂区宝田町');
ok($zip->set_number('4670867')->is_valid_number, '愛知県名古屋市瑞穂区春敲町');
ok($zip->set_number('4670868')->is_valid_number, '愛知県名古屋市瑞穂区大喜新町');
ok($zip->set_number('4670871')->is_valid_number, '愛知県名古屋市瑞穂区須田町');
ok($zip->set_number('4670872')->is_valid_number, '愛知県名古屋市瑞穂区高辻町');
ok($zip->set_number('4670873')->is_valid_number, '愛知県名古屋市瑞穂区竹田町');
ok($zip->set_number('4670874')->is_valid_number, '愛知県名古屋市瑞穂区太田町');
ok($zip->set_number('4670875')->is_valid_number, '愛知県名古屋市瑞穂区御劔町');
ok($zip->set_number('4670876')->is_valid_number, '愛知県名古屋市瑞穂区亀城町');
ok($zip->set_number('4670877')->is_valid_number, '愛知県名古屋市瑞穂区雁道町');
ok($zip->set_number('4670878')->is_valid_number, '愛知県名古屋市瑞穂区船原町');
ok($zip->set_number('4670879')->is_valid_number, '愛知県名古屋市瑞穂区平郷町');
ok($zip->set_number('4680000')->is_valid_number, '愛知県名古屋市天白区以下に掲載がない場合');
ok($zip->set_number('4680001')->is_valid_number, '愛知県名古屋市天白区植田山');
ok($zip->set_number('4680002')->is_valid_number, '愛知県名古屋市天白区焼山');
ok($zip->set_number('4680003')->is_valid_number, '愛知県名古屋市天白区鴻の巣');
ok($zip->set_number('4680004')->is_valid_number, '愛知県名古屋市天白区梅が丘');
ok($zip->set_number('4680005')->is_valid_number, '愛知県名古屋市天白区天白町植田');
ok($zip->set_number('4680006')->is_valid_number, '愛知県名古屋市天白区植田東');
ok($zip->set_number('4680007')->is_valid_number, '愛知県名古屋市天白区植田本町');
ok($zip->set_number('4680008')->is_valid_number, '愛知県名古屋市天白区一本松');
ok($zip->set_number('4680009')->is_valid_number, '愛知県名古屋市天白区元植田');
ok($zip->set_number('4680011')->is_valid_number, '愛知県名古屋市天白区平針');
ok($zip->set_number('4680012')->is_valid_number, '愛知県名古屋市天白区向が丘');
ok($zip->set_number('4680013')->is_valid_number, '愛知県名古屋市天白区荒池');
ok($zip->set_number('4680014')->is_valid_number, '愛知県名古屋市天白区中平');
ok($zip->set_number('4680015')->is_valid_number, '愛知県名古屋市天白区原');
ok($zip->set_number('4680020')->is_valid_number, '愛知県名古屋市天白区平針南');
ok($zip->set_number('4680021')->is_valid_number, '愛知県名古屋市天白区天白町平針');
ok($zip->set_number('4680022')->is_valid_number, '愛知県名古屋市天白区高島');
ok($zip->set_number('4680023')->is_valid_number, '愛知県名古屋市天白区御前場町');
ok($zip->set_number('4680024')->is_valid_number, '愛知県名古屋市天白区大根町');
ok($zip->set_number('4680025')->is_valid_number, '愛知県名古屋市天白区高坂町');
ok($zip->set_number('4680026')->is_valid_number, '愛知県名古屋市天白区土原');
ok($zip->set_number('4680027')->is_valid_number, '愛知県名古屋市天白区天白町島田');
ok($zip->set_number('4680028')->is_valid_number, '愛知県名古屋市天白区島田黒石');
ok($zip->set_number('4680029')->is_valid_number, '愛知県名古屋市天白区島田が丘');
ok($zip->set_number('4680030')->is_valid_number, '愛知県名古屋市天白区平針台');
ok($zip->set_number('4680031')->is_valid_number, '愛知県名古屋市天白区高宮町');
ok($zip->set_number('4680032')->is_valid_number, '愛知県名古屋市天白区山郷町');
ok($zip->set_number('4680033')->is_valid_number, '愛知県名古屋市天白区一つ山');
ok($zip->set_number('4680034')->is_valid_number, '愛知県名古屋市天白区久方');
ok($zip->set_number('4680035')->is_valid_number, '愛知県名古屋市天白区境根町');
ok($zip->set_number('4680037')->is_valid_number, '愛知県名古屋市天白区天白町野並');
ok($zip->set_number('4680038')->is_valid_number, '愛知県名古屋市天白区山根町');
ok($zip->set_number('4680039')->is_valid_number, '愛知県名古屋市天白区西入町');
ok($zip->set_number('4680041')->is_valid_number, '愛知県名古屋市天白区保呂町');
ok($zip->set_number('4680042')->is_valid_number, '愛知県名古屋市天白区海老山町');
ok($zip->set_number('4680043')->is_valid_number, '愛知県名古屋市天白区菅田');
ok($zip->set_number('4680044')->is_valid_number, '愛知県名古屋市天白区笹原町');
ok($zip->set_number('4680045')->is_valid_number, '愛知県名古屋市天白区野並');
ok($zip->set_number('4680046')->is_valid_number, '愛知県名古屋市天白区古川町');
ok($zip->set_number('4680047')->is_valid_number, '愛知県名古屋市天白区井の森町');
ok($zip->set_number('4680048')->is_valid_number, '愛知県名古屋市天白区中坪町');
ok($zip->set_number('4680049')->is_valid_number, '愛知県名古屋市天白区福池');
ok($zip->set_number('4680051')->is_valid_number, '愛知県名古屋市天白区植田');
ok($zip->set_number('4680052')->is_valid_number, '愛知県名古屋市天白区井口');
ok($zip->set_number('4680053')->is_valid_number, '愛知県名古屋市天白区植田南');
ok($zip->set_number('4680054')->is_valid_number, '愛知県名古屋市天白区横町');
ok($zip->set_number('4680055')->is_valid_number, '愛知県名古屋市天白区池場');
ok($zip->set_number('4680056')->is_valid_number, '愛知県名古屋市天白区島田');
ok($zip->set_number('4680058')->is_valid_number, '愛知県名古屋市天白区植田西');
ok($zip->set_number('4680061')->is_valid_number, '愛知県名古屋市天白区八事天道');
ok($zip->set_number('4680062')->is_valid_number, '愛知県名古屋市天白区弥生が岡');
ok($zip->set_number('4680063')->is_valid_number, '愛知県名古屋市天白区音聞山');
ok($zip->set_number('4680064')->is_valid_number, '愛知県名古屋市天白区道明町');
ok($zip->set_number('4680065')->is_valid_number, '愛知県名古屋市天白区中砂町');
ok($zip->set_number('4680066')->is_valid_number, '愛知県名古屋市天白区元八事');
ok($zip->set_number('4680067')->is_valid_number, '愛知県名古屋市天白区池見');
ok($zip->set_number('4680068')->is_valid_number, '愛知県名古屋市天白区表台');
ok($zip->set_number('4680069')->is_valid_number, '愛知県名古屋市天白区表山');
ok($zip->set_number('4680071')->is_valid_number, '愛知県名古屋市天白区天白町八事');
ok($zip->set_number('4680072')->is_valid_number, '愛知県名古屋市天白区大坪');
ok($zip->set_number('4680073')->is_valid_number, '愛知県名古屋市天白区塩釜口');
ok($zip->set_number('4680074')->is_valid_number, '愛知県名古屋市天白区八幡山');
ok($zip->set_number('4680075')->is_valid_number, '愛知県名古屋市天白区御幸山');
ok($zip->set_number('4680076')->is_valid_number, '愛知県名古屋市天白区八事石坂');
ok($zip->set_number('4680077')->is_valid_number, '愛知県名古屋市天白区八事山');
ok($zip->set_number('4680836')->is_valid_number, '愛知県名古屋市天白区相川');
ok($zip->set_number('4700100')->is_valid_number, '愛知県日進市以下に掲載がない場合');
ok($zip->set_number('4700100')->is_valid_number, '愛知県愛知郡東郷町以下に掲載がない場合');
ok($zip->set_number('4700101')->is_valid_number, '愛知県日進市三本木町');
ok($zip->set_number('4700102')->is_valid_number, '愛知県日進市藤島町');
ok($zip->set_number('4700103')->is_valid_number, '愛知県日進市北新町');
ok($zip->set_number('4700104')->is_valid_number, '愛知県日進市岩藤町');
ok($zip->set_number('4700105')->is_valid_number, '愛知県日進市五色園');
ok($zip->set_number('4700111')->is_valid_number, '愛知県日進市米野木町');
ok($zip->set_number('4700112')->is_valid_number, '愛知県日進市藤枝町');
ok($zip->set_number('4700113')->is_valid_number, '愛知県日進市栄');
ok($zip->set_number('4700114')->is_valid_number, '愛知県日進市南ケ丘');
ok($zip->set_number('4700115')->is_valid_number, '愛知県日進市折戸町');
ok($zip->set_number('4700116')->is_valid_number, '愛知県日進市東山');
ok($zip->set_number('4700117')->is_valid_number, '愛知県日進市藤塚');
ok($zip->set_number('4700118')->is_valid_number, '愛知県日進市米野木台');
ok($zip->set_number('4700121')->is_valid_number, '愛知県日進市本郷町');
ok($zip->set_number('4700122')->is_valid_number, '愛知県日進市蟹甲町');
ok($zip->set_number('4700123')->is_valid_number, '愛知県日進市野方町');
ok($zip->set_number('4700124')->is_valid_number, '愛知県日進市浅田町');
ok($zip->set_number('4700125')->is_valid_number, '愛知県日進市赤池');
ok($zip->set_number('4700126')->is_valid_number, '愛知県日進市赤池町');
ok($zip->set_number('4700127')->is_valid_number, '愛知県日進市赤池南');
ok($zip->set_number('4700128')->is_valid_number, '愛知県日進市浅田平子');
ok($zip->set_number('4700131')->is_valid_number, '愛知県日進市岩崎町');
ok($zip->set_number('4700132')->is_valid_number, '愛知県日進市梅森町');
ok($zip->set_number('4700133')->is_valid_number, '愛知県日進市梅森台');
ok($zip->set_number('4700134')->is_valid_number, '愛知県日進市香久山');
ok($zip->set_number('4700135')->is_valid_number, '愛知県日進市岩崎台');
ok($zip->set_number('4700136')->is_valid_number, '愛知県日進市竹の山');
ok($zip->set_number('4700151')->is_valid_number, '愛知県愛知郡東郷町諸輪');
ok($zip->set_number('4700152')->is_valid_number, '愛知県愛知郡東郷町北山台');
ok($zip->set_number('4700153')->is_valid_number, '愛知県愛知郡東郷町和合');
ok($zip->set_number('4700154')->is_valid_number, '愛知県愛知郡東郷町和合ケ丘');
ok($zip->set_number('4700155')->is_valid_number, '愛知県愛知郡東郷町白鳥');
ok($zip->set_number('4700156')->is_valid_number, '愛知県愛知郡東郷町御岳');
ok($zip->set_number('4700161')->is_valid_number, '愛知県愛知郡東郷町春木台');
ok($zip->set_number('4700162')->is_valid_number, '愛知県愛知郡東郷町春木');
ok($zip->set_number('4700163')->is_valid_number, '愛知県愛知郡東郷町涼松');
ok($zip->set_number('4700164')->is_valid_number, '愛知県愛知郡東郷町三ツ池');
ok($zip->set_number('4700165')->is_valid_number, '愛知県愛知郡東郷町清水');
ok($zip->set_number('4700166')->is_valid_number, '愛知県愛知郡東郷町兵庫');
ok($zip->set_number('4700200')->is_valid_number, '愛知県みよし市以下に掲載がない場合');
ok($zip->set_number('4700201')->is_valid_number, '愛知県みよし市黒笹町');
ok($zip->set_number('4700202')->is_valid_number, '愛知県みよし市三好丘');
ok($zip->set_number('4700203')->is_valid_number, '愛知県みよし市三好丘旭');
ok($zip->set_number('4700204')->is_valid_number, '愛知県みよし市三好丘桜');
ok($zip->set_number('4700205')->is_valid_number, '愛知県みよし市三好丘緑');
ok($zip->set_number('4700206')->is_valid_number, '愛知県みよし市莇生町');
ok($zip->set_number('4700207')->is_valid_number, '愛知県みよし市福谷町');
ok($zip->set_number('4700208')->is_valid_number, '愛知県みよし市ひばりヶ丘');
ok($zip->set_number('4700209')->is_valid_number, '愛知県みよし市潮見');
ok($zip->set_number('4700211')->is_valid_number, '愛知県みよし市天王台');
ok($zip->set_number('4700212')->is_valid_number, '愛知県みよし市東山台');
ok($zip->set_number('4700213')->is_valid_number, '愛知県みよし市打越町');
ok($zip->set_number('4700214')->is_valid_number, '愛知県みよし市明知町');
ok($zip->set_number('4700215')->is_valid_number, '愛知県みよし市みなよし台');
ok($zip->set_number('4700216')->is_valid_number, '愛知県みよし市南台');
ok($zip->set_number('4700217')->is_valid_number, '愛知県みよし市根浦町');
ok($zip->set_number('4700218')->is_valid_number, '愛知県みよし市黒笹山手');
ok($zip->set_number('4700221')->is_valid_number, '愛知県みよし市西陣取山');
ok($zip->set_number('4700222')->is_valid_number, '愛知県みよし市東陣取山');
ok($zip->set_number('4700223')->is_valid_number, '愛知県みよし市東蜂ヶ池');
ok($zip->set_number('4700224')->is_valid_number, '愛知県みよし市三好町');
ok($zip->set_number('4700225')->is_valid_number, '愛知県みよし市福田町');
ok($zip->set_number('4700226')->is_valid_number, '愛知県みよし市西一色町');
ok($zip->set_number('4700227')->is_valid_number, '愛知県みよし市園原');
ok($zip->set_number('4700228')->is_valid_number, '愛知県みよし市新前田');
ok($zip->set_number('4700231')->is_valid_number, '愛知県みよし市黒笹');
ok($zip->set_number('4700232')->is_valid_number, '愛知県みよし市黒笹いずみ');
ok($zip->set_number('4700233')->is_valid_number, '愛知県みよし市三好丘あおば');
ok($zip->set_number('4700301')->is_valid_number, '愛知県豊田市松嶺町');
ok($zip->set_number('4700302')->is_valid_number, '愛知県豊田市藤沢町');
ok($zip->set_number('4700303')->is_valid_number, '愛知県豊田市押沢町');
ok($zip->set_number('4700304')->is_valid_number, '愛知県豊田市富田町');
ok($zip->set_number('4700305')->is_valid_number, '愛知県豊田市国附町');
ok($zip->set_number('4700306')->is_valid_number, '愛知県豊田市小峯町');
ok($zip->set_number('4700307')->is_valid_number, '愛知県豊田市東広瀬町');
ok($zip->set_number('4700308')->is_valid_number, '愛知県豊田市枝下町');
ok($zip->set_number('4700309')->is_valid_number, '愛知県豊田市西広瀬町');
ok($zip->set_number('4700311')->is_valid_number, '愛知県豊田市芳友町');
ok($zip->set_number('4700312')->is_valid_number, '愛知県豊田市中金町');
ok($zip->set_number('4700313')->is_valid_number, '愛知県豊田市城見町');
ok($zip->set_number('4700314')->is_valid_number, '愛知県豊田市野口町');
ok($zip->set_number('4700315')->is_valid_number, '愛知県豊田市中切町');
ok($zip->set_number('4700316')->is_valid_number, '愛知県豊田市千鳥町');
ok($zip->set_number('4700317')->is_valid_number, '愛知県豊田市成合町');
ok($zip->set_number('4700318')->is_valid_number, '愛知県豊田市力石町');
ok($zip->set_number('4700319')->is_valid_number, '愛知県豊田市下室町');
ok($zip->set_number('4700321')->is_valid_number, '愛知県豊田市山中町');
ok($zip->set_number('4700322')->is_valid_number, '愛知県豊田市上高町');
ok($zip->set_number('4700323')->is_valid_number, '愛知県豊田市小呂町');
ok($zip->set_number('4700324')->is_valid_number, '愛知県豊田市滝見町');
ok($zip->set_number('4700325')->is_valid_number, '愛知県豊田市手呂町');
ok($zip->set_number('4700326')->is_valid_number, '愛知県豊田市手呂町樋田');
ok($zip->set_number('4700327')->is_valid_number, '愛知県豊田市寺下町');
ok($zip->set_number('4700328')->is_valid_number, '愛知県豊田市勘八町');
ok($zip->set_number('4700329')->is_valid_number, '愛知県豊田市石野町');
ok($zip->set_number('4700331')->is_valid_number, '愛知県豊田市平戸橋町');
ok($zip->set_number('4700332')->is_valid_number, '愛知県豊田市越戸町');
ok($zip->set_number('4700333')->is_valid_number, '愛知県豊田市荒井町');
ok($zip->set_number('4700334')->is_valid_number, '愛知県豊田市花本町');
ok($zip->set_number('4700335')->is_valid_number, '愛知県豊田市青木町');
ok($zip->set_number('4700341')->is_valid_number, '愛知県豊田市上原町');
ok($zip->set_number('4700342')->is_valid_number, '愛知県豊田市大清水町');
ok($zip->set_number('4700343')->is_valid_number, '愛知県豊田市浄水町');
ok($zip->set_number('4700344')->is_valid_number, '愛知県豊田市保見町');
ok($zip->set_number('4700345')->is_valid_number, '愛知県豊田市東保見町');
ok($zip->set_number('4700346')->is_valid_number, '愛知県豊田市乙部ケ丘');
ok($zip->set_number('4700347')->is_valid_number, '愛知県豊田市乙部町');
ok($zip->set_number('4700348')->is_valid_number, '愛知県豊田市貝津町');
ok($zip->set_number('4700351')->is_valid_number, '愛知県豊田市広幡町');
ok($zip->set_number('4700352')->is_valid_number, '愛知県豊田市篠原町');
ok($zip->set_number('4700353')->is_valid_number, '愛知県豊田市保見ケ丘');
ok($zip->set_number('4700354')->is_valid_number, '愛知県豊田市田籾町');
ok($zip->set_number('4700355')->is_valid_number, '愛知県豊田市大畑町');
ok($zip->set_number('4700356')->is_valid_number, '愛知県豊田市八草町');
ok($zip->set_number('4700361')->is_valid_number, '愛知県豊田市猿投町');
ok($zip->set_number('4700362')->is_valid_number, '愛知県豊田市舞木町');
ok($zip->set_number('4700363')->is_valid_number, '愛知県豊田市本徳町');
ok($zip->set_number('4700364')->is_valid_number, '愛知県豊田市加納町');
ok($zip->set_number('4700371')->is_valid_number, '愛知県豊田市御船町');
ok($zip->set_number('4700372')->is_valid_number, '愛知県豊田市井上町');
ok($zip->set_number('4700373')->is_valid_number, '愛知県豊田市四郷町');
ok($zip->set_number('4700374')->is_valid_number, '愛知県豊田市伊保町');
ok($zip->set_number('4700375')->is_valid_number, '愛知県豊田市亀首町');
ok($zip->set_number('4700376')->is_valid_number, '愛知県豊田市高町');
ok($zip->set_number('4700401')->is_valid_number, '愛知県豊田市大岩町');
ok($zip->set_number('4700402')->is_valid_number, '愛知県豊田市三箇町');
ok($zip->set_number('4700403')->is_valid_number, '愛知県豊田市白川町');
ok($zip->set_number('4700404')->is_valid_number, '愛知県豊田市西市野々町');
ok($zip->set_number('4700411')->is_valid_number, '愛知県豊田市木瀬町');
ok($zip->set_number('4700421')->is_valid_number, '愛知県豊田市上川口町');
ok($zip->set_number('4700422')->is_valid_number, '愛知県豊田市下川口町');
ok($zip->set_number('4700423')->is_valid_number, '愛知県豊田市田茂平町');
ok($zip->set_number('4700424')->is_valid_number, '愛知県豊田市御作町');
ok($zip->set_number('4700431')->is_valid_number, '愛知県豊田市西中山町');
ok($zip->set_number('4700441')->is_valid_number, '愛知県豊田市深見町');
ok($zip->set_number('4700451')->is_valid_number, '愛知県豊田市藤岡飯野町');
ok($zip->set_number('4700452')->is_valid_number, '愛知県豊田市迫町');
ok($zip->set_number('4700453')->is_valid_number, '愛知県豊田市北一色町');
ok($zip->set_number('4700461')->is_valid_number, '愛知県豊田市北曽木町');
ok($zip->set_number('4700462')->is_valid_number, '愛知県豊田市上渡合町');
ok($zip->set_number('4700463')->is_valid_number, '愛知県豊田市石飛町');
ok($zip->set_number('4700464')->is_valid_number, '愛知県豊田市折平町');
ok($zip->set_number('4700471')->is_valid_number, '愛知県豊田市石畳町');
ok($zip->set_number('4700501')->is_valid_number, '愛知県豊田市小原田代町');
ok($zip->set_number('4700502')->is_valid_number, '愛知県豊田市小原北町');
ok($zip->set_number('4700503')->is_valid_number, '愛知県豊田市前洞町');
ok($zip->set_number('4700504')->is_valid_number, '愛知県豊田市雑敷町');
ok($zip->set_number('4700505')->is_valid_number, '愛知県豊田市柏ケ洞町');
ok($zip->set_number('4700506')->is_valid_number, '愛知県豊田市川見町');
ok($zip->set_number('4700511')->is_valid_number, '愛知県豊田市大ケ蔵連町');
ok($zip->set_number('4700512')->is_valid_number, '愛知県豊田市東郷町');
ok($zip->set_number('4700513')->is_valid_number, '愛知県豊田市苅萱町');
ok($zip->set_number('4700514')->is_valid_number, '愛知県豊田市平岩町');
ok($zip->set_number('4700515')->is_valid_number, '愛知県豊田市岩下町');
ok($zip->set_number('4700516')->is_valid_number, '愛知県豊田市宮代町');
ok($zip->set_number('4700521')->is_valid_number, '愛知県豊田市西丹波町');
ok($zip->set_number('4700522')->is_valid_number, '愛知県豊田市榑俣町');
ok($zip->set_number('4700523')->is_valid_number, '愛知県豊田市平畑町');
ok($zip->set_number('4700524')->is_valid_number, '愛知県豊田市日面町');
ok($zip->set_number('4700525')->is_valid_number, '愛知県豊田市簗平町');
ok($zip->set_number('4700526')->is_valid_number, '愛知県豊田市西細田町');
ok($zip->set_number('4700531')->is_valid_number, '愛知県豊田市小原町');
ok($zip->set_number('4700532')->is_valid_number, '愛知県豊田市大坂町');
ok($zip->set_number('4700533')->is_valid_number, '愛知県豊田市鍛治屋敷町');
ok($zip->set_number('4700534')->is_valid_number, '愛知県豊田市李町');
ok($zip->set_number('4700535')->is_valid_number, '愛知県豊田市百月町');
ok($zip->set_number('4700541')->is_valid_number, '愛知県豊田市西萩平町');
ok($zip->set_number('4700542')->is_valid_number, '愛知県豊田市喜佐平町');
ok($zip->set_number('4700543')->is_valid_number, '愛知県豊田市北篠平町');
ok($zip->set_number('4700544')->is_valid_number, '愛知県豊田市寺平町');
ok($zip->set_number('4700545')->is_valid_number, '愛知県豊田市千洗町');
ok($zip->set_number('4700551')->is_valid_number, '愛知県豊田市三ツ久保町');
ok($zip->set_number('4700552')->is_valid_number, '愛知県豊田市乙ケ林町');
ok($zip->set_number('4700553')->is_valid_number, '愛知県豊田市大洞町');
ok($zip->set_number('4700554')->is_valid_number, '愛知県豊田市荷掛町');
ok($zip->set_number('4700555')->is_valid_number, '愛知県豊田市大平町');
ok($zip->set_number('4700561')->is_valid_number, '愛知県豊田市上仁木町');
ok($zip->set_number('4700562')->is_valid_number, '愛知県豊田市永太郎町');
ok($zip->set_number('4700563')->is_valid_number, '愛知県豊田市遊屋町');
ok($zip->set_number('4700564')->is_valid_number, '愛知県豊田市沢田町');
ok($zip->set_number('4700565')->is_valid_number, '愛知県豊田市下仁木町');
ok($zip->set_number('4700571')->is_valid_number, '愛知県豊田市松名町');
ok($zip->set_number('4700572')->is_valid_number, '愛知県豊田市小原大倉町');
ok($zip->set_number('4700573')->is_valid_number, '愛知県豊田市北大野町');
ok($zip->set_number('4700574')->is_valid_number, '愛知県豊田市市場町');
ok($zip->set_number('4700575')->is_valid_number, '愛知県豊田市川下町');
ok($zip->set_number('4701100')->is_valid_number, '愛知県豊明市以下に掲載がない場合');
ok($zip->set_number('4701101')->is_valid_number, '愛知県豊明市沓掛町');
ok($zip->set_number('4701102')->is_valid_number, '愛知県豊明市沓掛町(勅使)');
ok($zip->set_number('4701103')->is_valid_number, '愛知県豊明市沓掛町(小廻間)');
ok($zip->set_number('4701104')->is_valid_number, '愛知県豊明市沓掛町(五反田)');
ok($zip->set_number('4701105')->is_valid_number, '愛知県豊明市沓掛町(上高根)');
ok($zip->set_number('4701106')->is_valid_number, '愛知県豊明市沓掛町(下高根)');
ok($zip->set_number('4701107')->is_valid_number, '愛知県豊明市沓掛町(泉)');
ok($zip->set_number('4701108')->is_valid_number, '愛知県豊明市沓掛町(荒井)');
ok($zip->set_number('4701109')->is_valid_number, '愛知県豊明市沓掛町(宿)');
ok($zip->set_number('4701111')->is_valid_number, '愛知県豊明市大久伝町');
ok($zip->set_number('4701112')->is_valid_number, '愛知県豊明市新田町');
ok($zip->set_number('4701113')->is_valid_number, '愛知県豊明市新田町(錦)');
ok($zip->set_number('4701114')->is_valid_number, '愛知県豊明市新田町(広長)');
ok($zip->set_number('4701115')->is_valid_number, '愛知県豊明市新田町(前原)');
ok($zip->set_number('4701116')->is_valid_number, '愛知県豊明市新田町(吉池)');
ok($zip->set_number('4701121')->is_valid_number, '愛知県豊明市西川町');
ok($zip->set_number('4701122')->is_valid_number, '愛知県豊明市西川町(長田)');
ok($zip->set_number('4701123')->is_valid_number, '愛知県豊明市西川町(笹原)');
ok($zip->set_number('4701124')->is_valid_number, '愛知県豊明市三崎町');
ok($zip->set_number('4701125')->is_valid_number, '愛知県豊明市三崎町(中ノ坪)');
ok($zip->set_number('4701126')->is_valid_number, '愛知県豊明市三崎町(高鴨)');
ok($zip->set_number('4701127')->is_valid_number, '愛知県豊明市三崎町(ゆたか台)');
ok($zip->set_number('4701131')->is_valid_number, '愛知県豊明市二村台');
ok($zip->set_number('4701132')->is_valid_number, '愛知県豊明市間米町');
ok($zip->set_number('4701133')->is_valid_number, '愛知県豊明市間米町(鶴根)');
ok($zip->set_number('4701141')->is_valid_number, '愛知県豊明市阿野町');
ok($zip->set_number('4701142')->is_valid_number, '愛知県豊明市阿野町(東阿野)');
ok($zip->set_number('4701143')->is_valid_number, '愛知県豊明市阿野町(上納)');
ok($zip->set_number('4701144')->is_valid_number, '愛知県豊明市阿野町(稲葉)');
ok($zip->set_number('4701145')->is_valid_number, '愛知県豊明市阿野町(北上ノ山)');
ok($zip->set_number('4701146')->is_valid_number, '愛知県豊明市阿野町(黒部)');
ok($zip->set_number('4701147')->is_valid_number, '愛知県豊明市阿野町(坂部)');
ok($zip->set_number('4701148')->is_valid_number, '愛知県豊明市阿野町(滑)');
ok($zip->set_number('4701151')->is_valid_number, '愛知県豊明市前後町');
ok($zip->set_number('4701152')->is_valid_number, '愛知県豊明市前後町(仙人塚)');
ok($zip->set_number('4701153')->is_valid_number, '愛知県豊明市前後町(三ツ谷)');
ok($zip->set_number('4701154')->is_valid_number, '愛知県豊明市新栄町');
ok($zip->set_number('4701161')->is_valid_number, '愛知県豊明市栄町');
ok($zip->set_number('4701162')->is_valid_number, '愛知県豊明市栄町(上姥子)');
ok($zip->set_number('4701163')->is_valid_number, '愛知県豊明市栄町(姥子)');
ok($zip->set_number('4701164')->is_valid_number, '愛知県豊明市栄町(大蔵下)');
ok($zip->set_number('4701165')->is_valid_number, '愛知県豊明市栄町(内山)');
ok($zip->set_number('4701166')->is_valid_number, '愛知県豊明市栄町(大根)');
ok($zip->set_number('4701167')->is_valid_number, '愛知県豊明市栄町(西大根)');
ok($zip->set_number('4701168')->is_valid_number, '愛知県豊明市栄町(南舘)');
ok($zip->set_number('4701201')->is_valid_number, '愛知県豊田市豊栄町');
ok($zip->set_number('4701202')->is_valid_number, '愛知県豊田市渡刈町');
ok($zip->set_number('4701203')->is_valid_number, '愛知県豊田市幸町');
ok($zip->set_number('4701204')->is_valid_number, '愛知県豊田市配津町');
ok($zip->set_number('4701205')->is_valid_number, '愛知県豊田市永覚町');
ok($zip->set_number('4701206')->is_valid_number, '愛知県豊田市永覚新町');
ok($zip->set_number('4701207')->is_valid_number, '愛知県豊田市鴛鴨町');
ok($zip->set_number('4701211')->is_valid_number, '愛知県豊田市畝部東町');
ok($zip->set_number('4701212')->is_valid_number, '愛知県豊田市桝塚東町');
ok($zip->set_number('4701213')->is_valid_number, '愛知県豊田市桝塚西町');
ok($zip->set_number('4701214')->is_valid_number, '愛知県豊田市福受町');
ok($zip->set_number('4701215')->is_valid_number, '愛知県豊田市広美町');
ok($zip->set_number('4701216')->is_valid_number, '愛知県豊田市和会町');
ok($zip->set_number('4701217')->is_valid_number, '愛知県豊田市大成町');
ok($zip->set_number('4701218')->is_valid_number, '愛知県豊田市上郷町');
ok($zip->set_number('4701219')->is_valid_number, '愛知県豊田市畝部西町');
ok($zip->set_number('4702100')->is_valid_number, '愛知県知多郡東浦町以下に掲載がない場合');
ok($zip->set_number('4702101')->is_valid_number, '愛知県知多郡東浦町森岡');
ok($zip->set_number('4702102')->is_valid_number, '愛知県知多郡東浦町緒川');
ok($zip->set_number('4702103')->is_valid_number, '愛知県知多郡東浦町石浜');
ok($zip->set_number('4702104')->is_valid_number, '愛知県知多郡東浦町生路');
ok($zip->set_number('4702105')->is_valid_number, '愛知県知多郡東浦町藤江');
ok($zip->set_number('4702200')->is_valid_number, '愛知県知多郡阿久比町以下に掲載がない場合');
ok($zip->set_number('4702201')->is_valid_number, '愛知県知多郡阿久比町白沢');
ok($zip->set_number('4702202')->is_valid_number, '愛知県知多郡阿久比町福住');
ok($zip->set_number('4702203')->is_valid_number, '愛知県知多郡阿久比町板山');
ok($zip->set_number('4702204')->is_valid_number, '愛知県知多郡阿久比町宮津');
ok($zip->set_number('4702205')->is_valid_number, '愛知県知多郡阿久比町萩');
ok($zip->set_number('4702206')->is_valid_number, '愛知県知多郡阿久比町横松');
ok($zip->set_number('4702207')->is_valid_number, '愛知県知多郡阿久比町陽なたの丘');
ok($zip->set_number('4702211')->is_valid_number, '愛知県知多郡阿久比町草木');
ok($zip->set_number('4702212')->is_valid_number, '愛知県知多郡阿久比町卯坂');
ok($zip->set_number('4702213')->is_valid_number, '愛知県知多郡阿久比町阿久比');
ok($zip->set_number('4702214')->is_valid_number, '愛知県知多郡阿久比町椋岡');
ok($zip->set_number('4702215')->is_valid_number, '愛知県知多郡阿久比町矢高');
ok($zip->set_number('4702216')->is_valid_number, '愛知県知多郡阿久比町植大');
ok($zip->set_number('4702217')->is_valid_number, '愛知県知多郡阿久比町卯坂南');
ok($zip->set_number('4702300')->is_valid_number, '愛知県知多郡武豊町以下に掲載がない場合');
ok($zip->set_number('4702301')->is_valid_number, '愛知県知多郡武豊町壱町田');
ok($zip->set_number('4702302')->is_valid_number, '愛知県知多郡武豊町鹿ノ子田');
ok($zip->set_number('4702303')->is_valid_number, '愛知県知多郡武豊町祠峯');
ok($zip->set_number('4702304')->is_valid_number, '愛知県知多郡武豊町平井田');
ok($zip->set_number('4702305')->is_valid_number, '愛知県知多郡武豊町下山ノ田');
ok($zip->set_number('4702306')->is_valid_number, '愛知県知多郡武豊町上山ノ田');
ok($zip->set_number('4702307')->is_valid_number, '愛知県知多郡武豊町蛇ケ谷');
ok($zip->set_number('4702308')->is_valid_number, '愛知県知多郡武豊町二ツ峯');
ok($zip->set_number('4702309')->is_valid_number, '愛知県知多郡武豊町梨子ノ木');
ok($zip->set_number('4702311')->is_valid_number, '愛知県知多郡武豊町石川');
ok($zip->set_number('4702312')->is_valid_number, '愛知県知多郡武豊町北曲輪');
ok($zip->set_number('4702313')->is_valid_number, '愛知県知多郡武豊町九号地');
ok($zip->set_number('4702314')->is_valid_number, '愛知県知多郡武豊町浅水');
ok($zip->set_number('4702315')->is_valid_number, '愛知県知多郡武豊町中狭');
ok($zip->set_number('4702316')->is_valid_number, '愛知県知多郡武豊町二ケ崎');
ok($zip->set_number('4702317')->is_valid_number, '愛知県知多郡武豊町砂川');
ok($zip->set_number('4702318')->is_valid_number, '愛知県知多郡武豊町豊成');
ok($zip->set_number('4702319')->is_valid_number, '愛知県知多郡武豊町中蓮');
ok($zip->set_number('4702321')->is_valid_number, '愛知県知多郡武豊町七号地');
ok($zip->set_number('4702322')->is_valid_number, '愛知県知多郡武豊町塩田');
ok($zip->set_number('4702323')->is_valid_number, '愛知県知多郡武豊町口田');
ok($zip->set_number('4702324')->is_valid_number, '愛知県知多郡武豊町内鉋');
ok($zip->set_number('4702325')->is_valid_number, '愛知県知多郡武豊町若宮');
ok($zip->set_number('4702326')->is_valid_number, '愛知県知多郡武豊町平井畑');
ok($zip->set_number('4702327')->is_valid_number, '愛知県知多郡武豊町天神前');
ok($zip->set_number('4702328')->is_valid_number, '愛知県知多郡武豊町蛇渕');
ok($zip->set_number('4702329')->is_valid_number, '愛知県知多郡武豊町池田');
ok($zip->set_number('4702331')->is_valid_number, '愛知県知多郡武豊町ヒジリ田');
ok($zip->set_number('4702332')->is_valid_number, '愛知県知多郡武豊町上ケ');
ok($zip->set_number('4702333')->is_valid_number, '愛知県知多郡武豊町高野前');
ok($zip->set_number('4702334')->is_valid_number, '愛知県知多郡武豊町中根');
ok($zip->set_number('4702335')->is_valid_number, '愛知県知多郡武豊町谷口');
ok($zip->set_number('4702336')->is_valid_number, '愛知県知多郡武豊町山ノ神');
ok($zip->set_number('4702337')->is_valid_number, '愛知県知多郡武豊町ヱケ屋敷');
ok($zip->set_number('4702338')->is_valid_number, '愛知県知多郡武豊町前田');
ok($zip->set_number('4702339')->is_valid_number, '愛知県知多郡武豊町下門');
ok($zip->set_number('4702341')->is_valid_number, '愛知県知多郡武豊町五号地');
ok($zip->set_number('4702342')->is_valid_number, '愛知県知多郡武豊町沢田新田');
ok($zip->set_number('4702343')->is_valid_number, '愛知県知多郡武豊町小迎');
ok($zip->set_number('4702344')->is_valid_number, '愛知県知多郡武豊町金下');
ok($zip->set_number('4702345')->is_valid_number, '愛知県知多郡武豊町西門');
ok($zip->set_number('4702346')->is_valid_number, '愛知県知多郡武豊町長尾山');
ok($zip->set_number('4702347')->is_valid_number, '愛知県知多郡武豊町道崎');
ok($zip->set_number('4702348')->is_valid_number, '愛知県知多郡武豊町瀬木');
ok($zip->set_number('4702349')->is_valid_number, '愛知県知多郡武豊町西田崎');
ok($zip->set_number('4702351')->is_valid_number, '愛知県知多郡武豊町南中根');
ok($zip->set_number('4702352')->is_valid_number, '愛知県知多郡武豊町迎戸');
ok($zip->set_number('4702353')->is_valid_number, '愛知県知多郡武豊町道崎田');
ok($zip->set_number('4702354')->is_valid_number, '愛知県知多郡武豊町川尻');
ok($zip->set_number('4702355')->is_valid_number, '愛知県知多郡武豊町向田');
ok($zip->set_number('4702356')->is_valid_number, '愛知県知多郡武豊町下起');
ok($zip->set_number('4702357')->is_valid_number, '愛知県知多郡武豊町向陽');
ok($zip->set_number('4702358')->is_valid_number, '愛知県知多郡武豊町楠');
ok($zip->set_number('4702359')->is_valid_number, '愛知県知多郡武豊町桜ケ丘');
ok($zip->set_number('4702361')->is_valid_number, '愛知県知多郡武豊町多賀');
ok($zip->set_number('4702362')->is_valid_number, '愛知県知多郡武豊町六貫山');
ok($zip->set_number('4702363')->is_valid_number, '愛知県知多郡武豊町旭ケ丘');
ok($zip->set_number('4702364')->is_valid_number, '愛知県知多郡武豊町上起');
ok($zip->set_number('4702365')->is_valid_number, '愛知県知多郡武豊町壱畝町');
ok($zip->set_number('4702366')->is_valid_number, '愛知県知多郡武豊町ヲヲガケ');
ok($zip->set_number('4702371')->is_valid_number, '愛知県知多郡武豊町下原');
ok($zip->set_number('4702372')->is_valid_number, '愛知県知多郡武豊町甚田');
ok($zip->set_number('4702373')->is_valid_number, '愛知県知多郡武豊町嶋田');
ok($zip->set_number('4702374')->is_valid_number, '愛知県知多郡武豊町原田');
ok($zip->set_number('4702375')->is_valid_number, '愛知県知多郡武豊町原屋敷');
ok($zip->set_number('4702376')->is_valid_number, '愛知県知多郡武豊町上原');
ok($zip->set_number('4702377')->is_valid_number, '愛知県知多郡武豊町会下');
ok($zip->set_number('4702378')->is_valid_number, '愛知県知多郡武豊町南小松谷');
ok($zip->set_number('4702379')->is_valid_number, '愛知県知多郡武豊町北小松谷');
ok($zip->set_number('4702380')->is_valid_number, '愛知県知多郡武豊町平井');
ok($zip->set_number('4702382')->is_valid_number, '愛知県知多郡武豊町東長宗');
ok($zip->set_number('4702383')->is_valid_number, '愛知県知多郡武豊町北長宗');
ok($zip->set_number('4702384')->is_valid_number, '愛知県知多郡武豊町青木ケ丘');
ok($zip->set_number('4702385')->is_valid_number, '愛知県知多郡武豊町北中根');
ok($zip->set_number('4702386')->is_valid_number, '愛知県知多郡武豊町緑台');
ok($zip->set_number('4702387')->is_valid_number, '愛知県知多郡武豊町上山');
ok($zip->set_number('4702388')->is_valid_number, '愛知県知多郡武豊町中山');
ok($zip->set_number('4702389')->is_valid_number, '愛知県知多郡武豊町長宗');
ok($zip->set_number('4702401')->is_valid_number, '愛知県知多郡美浜町布土');
ok($zip->set_number('4702402')->is_valid_number, '愛知県知多郡美浜町時志');
ok($zip->set_number('4702403')->is_valid_number, '愛知県知多郡美浜町北方');
ok($zip->set_number('4702404')->is_valid_number, '愛知県知多郡美浜町河和');
ok($zip->set_number('4702405')->is_valid_number, '愛知県知多郡美浜町河和台');
ok($zip->set_number('4702406')->is_valid_number, '愛知県知多郡美浜町河和(北田面)');
ok($zip->set_number('4702407')->is_valid_number, '愛知県知多郡美浜町河和(北屋敷)');
ok($zip->set_number('4702408')->is_valid_number, '愛知県知多郡美浜町河和(南屋敷)');
ok($zip->set_number('4702409')->is_valid_number, '愛知県知多郡美浜町河和(上前田)');
ok($zip->set_number('4702411')->is_valid_number, '愛知県知多郡美浜町新浦戸');
ok($zip->set_number('4702412')->is_valid_number, '愛知県知多郡美浜町浦戸');
ok($zip->set_number('4702413')->is_valid_number, '愛知県知多郡美浜町古布');
ok($zip->set_number('4702414')->is_valid_number, '愛知県知多郡美浜町豊丘');
ok($zip->set_number('4702501')->is_valid_number, '愛知県知多郡武豊町堀割');
ok($zip->set_number('4702502')->is_valid_number, '愛知県知多郡武豊町明神戸');
ok($zip->set_number('4702503')->is_valid_number, '愛知県知多郡武豊町後畑');
ok($zip->set_number('4702504')->is_valid_number, '愛知県知多郡武豊町熊野');
ok($zip->set_number('4702505')->is_valid_number, '愛知県知多郡武豊町田崎');
ok($zip->set_number('4702506')->is_valid_number, '愛知県知多郡武豊町後田');
ok($zip->set_number('4702507')->is_valid_number, '愛知県知多郡武豊町平海道');
ok($zip->set_number('4702508')->is_valid_number, '愛知県知多郡武豊町川脇');
ok($zip->set_number('4702511')->is_valid_number, '愛知県知多郡武豊町道仙田');
ok($zip->set_number('4702512')->is_valid_number, '愛知県知多郡武豊町忠白田');
ok($zip->set_number('4702513')->is_valid_number, '愛知県知多郡武豊町一号地');
ok($zip->set_number('4702514')->is_valid_number, '愛知県知多郡武豊町旭');
ok($zip->set_number('4702515')->is_valid_number, '愛知県知多郡武豊町下田');
ok($zip->set_number('4702516')->is_valid_number, '愛知県知多郡武豊町廻間');
ok($zip->set_number('4702517')->is_valid_number, '愛知県知多郡武豊町長峰');
ok($zip->set_number('4702521')->is_valid_number, '愛知県知多郡武豊町東大高');
ok($zip->set_number('4702531')->is_valid_number, '愛知県知多郡武豊町冨貴');
ok($zip->set_number('4702532')->is_valid_number, '愛知県知多郡武豊町竜宮');
ok($zip->set_number('4702541')->is_valid_number, '愛知県知多郡武豊町目堀');
ok($zip->set_number('4702542')->is_valid_number, '愛知県知多郡武豊町土穴');
ok($zip->set_number('4702543')->is_valid_number, '愛知県知多郡武豊町大屋敷');
ok($zip->set_number('4702544')->is_valid_number, '愛知県知多郡武豊町里中');
ok($zip->set_number('4702545')->is_valid_number, '愛知県知多郡武豊町前畑');
ok($zip->set_number('4702546')->is_valid_number, '愛知県知多郡武豊町山起');
ok($zip->set_number('4702547')->is_valid_number, '愛知県知多郡武豊町北新田');
ok($zip->set_number('4702551')->is_valid_number, '愛知県知多郡武豊町石田');
ok($zip->set_number('4702552')->is_valid_number, '愛知県知多郡武豊町草口');
ok($zip->set_number('4702553')->is_valid_number, '愛知県知多郡武豊町四畝');
ok($zip->set_number('4702554')->is_valid_number, '愛知県知多郡武豊町白山');
ok($zip->set_number('4702555')->is_valid_number, '愛知県知多郡武豊町大門田');
ok($zip->set_number('4702556')->is_valid_number, '愛知県知多郡武豊町南起');
ok($zip->set_number('4703200')->is_valid_number, '愛知県知多郡美浜町以下に掲載がない場合');
ok($zip->set_number('4703231')->is_valid_number, '愛知県知多郡美浜町上野間');
ok($zip->set_number('4703232')->is_valid_number, '愛知県知多郡美浜町美浜緑苑');
ok($zip->set_number('4703233')->is_valid_number, '愛知県知多郡美浜町奥田');
ok($zip->set_number('4703234')->is_valid_number, '愛知県知多郡美浜町新栄');
ok($zip->set_number('4703235')->is_valid_number, '愛知県知多郡美浜町野間');
ok($zip->set_number('4703236')->is_valid_number, '愛知県知多郡美浜町小野浦');
ok($zip->set_number('4703300')->is_valid_number, '愛知県知多郡南知多町以下に掲載がない場合');
ok($zip->set_number('4703321')->is_valid_number, '愛知県知多郡南知多町内海');
ok($zip->set_number('4703322')->is_valid_number, '愛知県知多郡南知多町山海');
ok($zip->set_number('4703411')->is_valid_number, '愛知県知多郡南知多町豊丘');
ok($zip->set_number('4703412')->is_valid_number, '愛知県知多郡南知多町豊浜');
ok($zip->set_number('4703501')->is_valid_number, '愛知県知多郡南知多町大井');
ok($zip->set_number('4703502')->is_valid_number, '愛知県知多郡南知多町片名');
ok($zip->set_number('4703503')->is_valid_number, '愛知県知多郡南知多町師崎');
ok($zip->set_number('4703504')->is_valid_number, '愛知県知多郡南知多町日間賀島');
ok($zip->set_number('4703505')->is_valid_number, '愛知県知多郡南知多町篠島');
ok($zip->set_number('4710000')->is_valid_number, '愛知県豊田市以下に掲載がない場合');
ok($zip->set_number('4710001')->is_valid_number, '愛知県豊田市池田町');
ok($zip->set_number('4710002')->is_valid_number, '愛知県豊田市矢並町');
ok($zip->set_number('4710003')->is_valid_number, '愛知県豊田市岩滝町');
ok($zip->set_number('4710004')->is_valid_number, '愛知県豊田市双美町');
ok($zip->set_number('4710005')->is_valid_number, '愛知県豊田市京ケ峰');
ok($zip->set_number('4710006')->is_valid_number, '愛知県豊田市市木町');
ok($zip->set_number('4710007')->is_valid_number, '愛知県豊田市美和町');
ok($zip->set_number('4710008')->is_valid_number, '愛知県豊田市百々町');
ok($zip->set_number('4710009')->is_valid_number, '愛知県豊田市扶桑町');
ok($zip->set_number('4710011')->is_valid_number, '愛知県豊田市平井町');
ok($zip->set_number('4710012')->is_valid_number, '愛知県豊田市水間町');
ok($zip->set_number('4710013')->is_valid_number, '愛知県豊田市高上');
ok($zip->set_number('4710014')->is_valid_number, '愛知県豊田市東山町');
ok($zip->set_number('4710015')->is_valid_number, '愛知県豊田市上野町');
ok($zip->set_number('4710016')->is_valid_number, '愛知県豊田市千石町');
ok($zip->set_number('4710017')->is_valid_number, '愛知県豊田市寺部町');
ok($zip->set_number('4710018')->is_valid_number, '愛知県豊田市社町');
ok($zip->set_number('4710019')->is_valid_number, '愛知県豊田市高橋町');
ok($zip->set_number('4710021')->is_valid_number, '愛知県豊田市中島町');
ok($zip->set_number('4710022')->is_valid_number, '愛知県豊田市白浜町');
ok($zip->set_number('4710023')->is_valid_number, '愛知県豊田市挙母町');
ok($zip->set_number('4710024')->is_valid_number, '愛知県豊田市元城町');
ok($zip->set_number('4710025')->is_valid_number, '愛知県豊田市西町');
ok($zip->set_number('4710026')->is_valid_number, '愛知県豊田市若宮町');
ok($zip->set_number('4710027')->is_valid_number, '愛知県豊田市喜多町');
ok($zip->set_number('4710028')->is_valid_number, '愛知県豊田市神明町');
ok($zip->set_number('4710029')->is_valid_number, '愛知県豊田市桜町');
ok($zip->set_number('4710031')->is_valid_number, '愛知県豊田市朝日町');
ok($zip->set_number('4710032')->is_valid_number, '愛知県豊田市日南町');
ok($zip->set_number('4710033')->is_valid_number, '愛知県豊田市月見町');
ok($zip->set_number('4710034')->is_valid_number, '愛知県豊田市小坂本町');
ok($zip->set_number('4710035')->is_valid_number, '愛知県豊田市小坂町');
ok($zip->set_number('4710036')->is_valid_number, '愛知県豊田市広久手町');
ok($zip->set_number('4710037')->is_valid_number, '愛知県豊田市三軒町');
ok($zip->set_number('4710038')->is_valid_number, '愛知県豊田市宮上町');
ok($zip->set_number('4710041')->is_valid_number, '愛知県豊田市汐見町');
ok($zip->set_number('4710042')->is_valid_number, '愛知県豊田市宮口町');
ok($zip->set_number('4710043')->is_valid_number, '愛知県豊田市宮町');
ok($zip->set_number('4710044')->is_valid_number, '愛知県豊田市新町');
ok($zip->set_number('4710045')->is_valid_number, '愛知県豊田市東新町');
ok($zip->set_number('4710046')->is_valid_number, '愛知県豊田市本新町');
ok($zip->set_number('4710047')->is_valid_number, '愛知県豊田市西新町');
ok($zip->set_number('4710048')->is_valid_number, '愛知県豊田市高崎町');
ok($zip->set_number('4710049')->is_valid_number, '愛知県豊田市田町');
ok($zip->set_number('4710051')->is_valid_number, '愛知県豊田市花丘町');
ok($zip->set_number('4710052')->is_valid_number, '愛知県豊田市逢妻町');
ok($zip->set_number('4710053')->is_valid_number, '愛知県豊田市丸根町');
ok($zip->set_number('4710054')->is_valid_number, '愛知県豊田市天王町');
ok($zip->set_number('4710055')->is_valid_number, '愛知県豊田市久岡町');
ok($zip->set_number('4710056')->is_valid_number, '愛知県豊田市白山町');
ok($zip->set_number('4710057')->is_valid_number, '愛知県豊田市太平町');
ok($zip->set_number('4710058')->is_valid_number, '愛知県豊田市大池町');
ok($zip->set_number('4710059')->is_valid_number, '愛知県豊田市貞宝町');
ok($zip->set_number('4710061')->is_valid_number, '愛知県豊田市若草町');
ok($zip->set_number('4710062')->is_valid_number, '愛知県豊田市西山町');
ok($zip->set_number('4710063')->is_valid_number, '愛知県豊田市京町');
ok($zip->set_number('4710064')->is_valid_number, '愛知県豊田市梅坪町');
ok($zip->set_number('4710065')->is_valid_number, '愛知県豊田市平芝町');
ok($zip->set_number('4710066')->is_valid_number, '愛知県豊田市栄町');
ok($zip->set_number('4710067')->is_valid_number, '愛知県豊田市栄生町');
ok($zip->set_number('4710068')->is_valid_number, '愛知県豊田市横山町');
ok($zip->set_number('4710069')->is_valid_number, '愛知県豊田市高原町');
ok($zip->set_number('4710071')->is_valid_number, '愛知県豊田市東梅坪町');
ok($zip->set_number('4710072')->is_valid_number, '愛知県豊田市落合町');
ok($zip->set_number('4710073')->is_valid_number, '愛知県豊田市川田町');
ok($zip->set_number('4710074')->is_valid_number, '愛知県豊田市川端町');
ok($zip->set_number('4710075')->is_valid_number, '愛知県豊田市日之出町');
ok($zip->set_number('4710076')->is_valid_number, '愛知県豊田市久保町');
ok($zip->set_number('4710077')->is_valid_number, '愛知県豊田市竹生町');
ok($zip->set_number('4710078')->is_valid_number, '愛知県豊田市昭和町');
ok($zip->set_number('4710079')->is_valid_number, '愛知県豊田市陣中町');
ok($zip->set_number('4710801')->is_valid_number, '愛知県豊田市古瀬間町');
ok($zip->set_number('4710802')->is_valid_number, '愛知県豊田市志賀町');
ok($zip->set_number('4710803')->is_valid_number, '愛知県豊田市泉町');
ok($zip->set_number('4710804')->is_valid_number, '愛知県豊田市神池町');
ok($zip->set_number('4710805')->is_valid_number, '愛知県豊田市美里');
ok($zip->set_number('4710806')->is_valid_number, '愛知県豊田市森町');
ok($zip->set_number('4710807')->is_valid_number, '愛知県豊田市広川町');
ok($zip->set_number('4710808')->is_valid_number, '愛知県豊田市渋谷町');
ok($zip->set_number('4710809')->is_valid_number, '愛知県豊田市宝来町');
ok($zip->set_number('4710811')->is_valid_number, '愛知県豊田市御立町');
ok($zip->set_number('4710812')->is_valid_number, '愛知県豊田市野見町');
ok($zip->set_number('4710813')->is_valid_number, '愛知県豊田市野見山町');
ok($zip->set_number('4710814')->is_valid_number, '愛知県豊田市五ケ丘');
ok($zip->set_number('4710815')->is_valid_number, '愛知県豊田市大見町');
ok($zip->set_number('4710816')->is_valid_number, '愛知県豊田市琴平町');
ok($zip->set_number('4710817')->is_valid_number, '愛知県豊田市渡合町');
ok($zip->set_number('4710818')->is_valid_number, '愛知県豊田市室町');
ok($zip->set_number('4710819')->is_valid_number, '愛知県豊田市宮前町');
ok($zip->set_number('4710821')->is_valid_number, '愛知県豊田市平和町');
ok($zip->set_number('4710822')->is_valid_number, '愛知県豊田市水源町');
ok($zip->set_number('4710823')->is_valid_number, '愛知県豊田市今町');
ok($zip->set_number('4710824')->is_valid_number, '愛知県豊田市河合町');
ok($zip->set_number('4710825')->is_valid_number, '愛知県豊田市明和町');
ok($zip->set_number('4710826')->is_valid_number, '愛知県豊田市トヨタ町');
ok($zip->set_number('4710827')->is_valid_number, '愛知県豊田市平山町');
ok($zip->set_number('4710828')->is_valid_number, '愛知県豊田市前山町');
ok($zip->set_number('4710831')->is_valid_number, '愛知県豊田市司町');
ok($zip->set_number('4710832')->is_valid_number, '愛知県豊田市丸山町');
ok($zip->set_number('4710833')->is_valid_number, '愛知県豊田市山之手');
ok($zip->set_number('4710834')->is_valid_number, '愛知県豊田市寿町');
ok($zip->set_number('4710835')->is_valid_number, '愛知県豊田市曙町');
ok($zip->set_number('4710836')->is_valid_number, '愛知県豊田市鴻ノ巣町');
ok($zip->set_number('4710837')->is_valid_number, '愛知県豊田市新生町');
ok($zip->set_number('4710838')->is_valid_number, '愛知県豊田市緑ケ丘');
ok($zip->set_number('4710841')->is_valid_number, '愛知県豊田市深田町');
ok($zip->set_number('4710842')->is_valid_number, '愛知県豊田市土橋町');
ok($zip->set_number('4710843')->is_valid_number, '愛知県豊田市清水町');
ok($zip->set_number('4710844')->is_valid_number, '愛知県豊田市聖心町');
ok($zip->set_number('4710845')->is_valid_number, '愛知県豊田市田中町');
ok($zip->set_number('4710846')->is_valid_number, '愛知県豊田市田代町');
ok($zip->set_number('4710847')->is_valid_number, '愛知県豊田市千足町');
ok($zip->set_number('4710848')->is_valid_number, '愛知県豊田市本地町');
ok($zip->set_number('4710849')->is_valid_number, '愛知県豊田市美山町');
ok($zip->set_number('4710851')->is_valid_number, '愛知県豊田市樹木町');
ok($zip->set_number('4710852')->is_valid_number, '愛知県豊田市御幸町');
ok($zip->set_number('4710853')->is_valid_number, '愛知県豊田市細谷町');
ok($zip->set_number('4710854')->is_valid_number, '愛知県豊田市元町');
ok($zip->set_number('4710855')->is_valid_number, '愛知県豊田市柿本町');
ok($zip->set_number('4710856')->is_valid_number, '愛知県豊田市衣ケ原');
ok($zip->set_number('4710857')->is_valid_number, '愛知県豊田市小川町');
ok($zip->set_number('4710858')->is_valid_number, '愛知県豊田市朝日ケ丘');
ok($zip->set_number('4710861')->is_valid_number, '愛知県豊田市八幡町');
ok($zip->set_number('4710862')->is_valid_number, '愛知県豊田市砂町');
ok($zip->set_number('4710863')->is_valid_number, '愛知県豊田市瑞穂町');
ok($zip->set_number('4710864')->is_valid_number, '愛知県豊田市広路町');
ok($zip->set_number('4710865')->is_valid_number, '愛知県豊田市松ケ枝町');
ok($zip->set_number('4710866')->is_valid_number, '愛知県豊田市上挙母');
ok($zip->set_number('4710867')->is_valid_number, '愛知県豊田市常盤町');
ok($zip->set_number('4710868')->is_valid_number, '愛知県豊田市神田町');
ok($zip->set_number('4710869')->is_valid_number, '愛知県豊田市十塚町');
ok($zip->set_number('4710871')->is_valid_number, '愛知県豊田市元宮町');
ok($zip->set_number('4710872')->is_valid_number, '愛知県豊田市竜宮町');
ok($zip->set_number('4710873')->is_valid_number, '愛知県豊田市秋葉町');
ok($zip->set_number('4710874')->is_valid_number, '愛知県豊田市前田町');
ok($zip->set_number('4710875')->is_valid_number, '愛知県豊田市下市場町');
ok($zip->set_number('4710876')->is_valid_number, '愛知県豊田市金谷町');
ok($zip->set_number('4710877')->is_valid_number, '愛知県豊田市錦町');
ok($zip->set_number('4710878')->is_valid_number, '愛知県豊田市下林町');
ok($zip->set_number('4710879')->is_valid_number, '愛知県豊田市長興寺');
ok($zip->set_number('4720000')->is_valid_number, '愛知県知立市以下に掲載がない場合');
ok($zip->set_number('4720001')->is_valid_number, '愛知県知立市八橋町');
ok($zip->set_number('4720002')->is_valid_number, '愛知県知立市来迎寺町');
ok($zip->set_number('4720003')->is_valid_number, '愛知県知立市牛田');
ok($zip->set_number('4720004')->is_valid_number, '愛知県知立市南陽');
ok($zip->set_number('4720005')->is_valid_number, '愛知県知立市新池');
ok($zip->set_number('4720006')->is_valid_number, '愛知県知立市山町');
ok($zip->set_number('4720007')->is_valid_number, '愛知県知立市牛田町');
ok($zip->set_number('4720011')->is_valid_number, '愛知県知立市昭和');
ok($zip->set_number('4720012')->is_valid_number, '愛知県知立市八ツ田町');
ok($zip->set_number('4720013')->is_valid_number, '愛知県知立市谷田町');
ok($zip->set_number('4720014')->is_valid_number, '愛知県知立市谷田町西');
ok($zip->set_number('4720015')->is_valid_number, '愛知県知立市谷田町本林');
ok($zip->set_number('4720016')->is_valid_number, '愛知県知立市西中町');
ok($zip->set_number('4720017')->is_valid_number, '愛知県知立市新林町');
ok($zip->set_number('4720021')->is_valid_number, '愛知県知立市逢妻町');
ok($zip->set_number('4720022')->is_valid_number, '愛知県知立市山屋敷町');
ok($zip->set_number('4720023')->is_valid_number, '愛知県知立市西町');
ok($zip->set_number('4720024')->is_valid_number, '愛知県知立市宝町');
ok($zip->set_number('4720025')->is_valid_number, '愛知県知立市池端');
ok($zip->set_number('4720026')->is_valid_number, '愛知県知立市上重原町');
ok($zip->set_number('4720027')->is_valid_number, '愛知県知立市西丘町');
ok($zip->set_number('4720031')->is_valid_number, '愛知県知立市桜木町');
ok($zip->set_number('4720032')->is_valid_number, '愛知県知立市中山町');
ok($zip->set_number('4720033')->is_valid_number, '愛知県知立市中町');
ok($zip->set_number('4720034')->is_valid_number, '愛知県知立市弘栄');
ok($zip->set_number('4720035')->is_valid_number, '愛知県知立市長田');
ok($zip->set_number('4720036')->is_valid_number, '愛知県知立市堀切');
ok($zip->set_number('4720037')->is_valid_number, '愛知県知立市栄');
ok($zip->set_number('4720038')->is_valid_number, '愛知県知立市本町');
ok($zip->set_number('4720041')->is_valid_number, '愛知県知立市新地町');
ok($zip->set_number('4720042')->is_valid_number, '愛知県知立市内幸町');
ok($zip->set_number('4720043')->is_valid_number, '愛知県知立市東栄');
ok($zip->set_number('4720044')->is_valid_number, '愛知県知立市広見');
ok($zip->set_number('4720045')->is_valid_number, '愛知県知立市長篠町');
ok($zip->set_number('4720046')->is_valid_number, '愛知県知立市弘法町');
ok($zip->set_number('4720047')->is_valid_number, '愛知県知立市新富');
ok($zip->set_number('4720051')->is_valid_number, '愛知県知立市東長篠');
ok($zip->set_number('4720052')->is_valid_number, '愛知県知立市弘法');
ok($zip->set_number('4720053')->is_valid_number, '愛知県知立市南新地');
ok($zip->set_number('4720054')->is_valid_number, '愛知県知立市東上重原');
ok($zip->set_number('4720055')->is_valid_number, '愛知県知立市鳥居');
ok($zip->set_number('4720056')->is_valid_number, '愛知県知立市宝');
ok($zip->set_number('4720057')->is_valid_number, '愛知県知立市西');
ok($zip->set_number('4720058')->is_valid_number, '愛知県知立市上重原');
ok($zip->set_number('4730901')->is_valid_number, '愛知県豊田市御幸本町');
ok($zip->set_number('4730902')->is_valid_number, '愛知県豊田市大林町');
ok($zip->set_number('4730903')->is_valid_number, '愛知県豊田市西田町');
ok($zip->set_number('4730904')->is_valid_number, '愛知県豊田市中町');
ok($zip->set_number('4730905')->is_valid_number, '愛知県豊田市住吉町');
ok($zip->set_number('4730906')->is_valid_number, '愛知県豊田市竹町');
ok($zip->set_number('4730907')->is_valid_number, '愛知県豊田市竜神町');
ok($zip->set_number('4730908')->is_valid_number, '愛知県豊田市宝町');
ok($zip->set_number('4730911')->is_valid_number, '愛知県豊田市本町');
ok($zip->set_number('4730912')->is_valid_number, '愛知県豊田市広田町');
ok($zip->set_number('4730913')->is_valid_number, '愛知県豊田市竹元町');
ok($zip->set_number('4730914')->is_valid_number, '愛知県豊田市若林東町');
ok($zip->set_number('4730915')->is_valid_number, '愛知県豊田市若林東町中外根');
ok($zip->set_number('4730916')->is_valid_number, '愛知県豊田市吉原町');
ok($zip->set_number('4730917')->is_valid_number, '愛知県豊田市若林西町');
ok($zip->set_number('4730918')->is_valid_number, '愛知県豊田市高美町');
ok($zip->set_number('4730921')->is_valid_number, '愛知県豊田市高丘新町');
ok($zip->set_number('4730922')->is_valid_number, '愛知県豊田市高岡本町');
ok($zip->set_number('4730923')->is_valid_number, '愛知県豊田市中根町');
ok($zip->set_number('4730924')->is_valid_number, '愛知県豊田市花園町');
ok($zip->set_number('4730925')->is_valid_number, '愛知県豊田市駒場町');
ok($zip->set_number('4730926')->is_valid_number, '愛知県豊田市駒新町');
ok($zip->set_number('4730927')->is_valid_number, '愛知県豊田市中田町');
ok($zip->set_number('4730928')->is_valid_number, '愛知県豊田市生駒町');
ok($zip->set_number('4730931')->is_valid_number, '愛知県豊田市上丘町');
ok($zip->set_number('4730932')->is_valid_number, '愛知県豊田市堤町');
ok($zip->set_number('4730933')->is_valid_number, '愛知県豊田市高岡町');
ok($zip->set_number('4730934')->is_valid_number, '愛知県豊田市前林町');
ok($zip->set_number('4730935')->is_valid_number, '愛知県豊田市大島町');
ok($zip->set_number('4730936')->is_valid_number, '愛知県豊田市西岡町');
ok($zip->set_number('4730937')->is_valid_number, '愛知県豊田市西岡町星ケ丘');
ok($zip->set_number('4730938')->is_valid_number, '愛知県豊田市本田町');
ok($zip->set_number('4730939')->is_valid_number, '愛知県豊田市堤本町');
ok($zip->set_number('4740000')->is_valid_number, '愛知県大府市以下に掲載がない場合');
ok($zip->set_number('4740001')->is_valid_number, '愛知県大府市北崎町');
ok($zip->set_number('4740002')->is_valid_number, '愛知県大府市北崎町(丁目)');
ok($zip->set_number('4740003')->is_valid_number, '愛知県大府市神田町');
ok($zip->set_number('4740011')->is_valid_number, '愛知県大府市横根町');
ok($zip->set_number('4740021')->is_valid_number, '愛知県大府市長根町');
ok($zip->set_number('4740022')->is_valid_number, '愛知県大府市若草町');
ok($zip->set_number('4740023')->is_valid_number, '愛知県大府市大東町');
ok($zip->set_number('4740024')->is_valid_number, '愛知県大府市朝日町');
ok($zip->set_number('4740025')->is_valid_number, '愛知県大府市中央町');
ok($zip->set_number('4740026')->is_valid_number, '愛知県大府市桃山町');
ok($zip->set_number('4740027')->is_valid_number, '愛知県大府市追分町');
ok($zip->set_number('4740031')->is_valid_number, '愛知県大府市森岡町(その他)');
ok($zip->set_number('4740035')->is_valid_number, '愛知県大府市江端町');
ok($zip->set_number('4740036')->is_valid_number, '愛知県大府市月見町');
ok($zip->set_number('4740037')->is_valid_number, '愛知県大府市半月町');
ok($zip->set_number('4740038')->is_valid_number, '愛知県大府市森岡町(丁目)');
ok($zip->set_number('4740041')->is_valid_number, '愛知県大府市吉田町(その他)');
ok($zip->set_number('4740042')->is_valid_number, '愛知県大府市高丘町');
ok($zip->set_number('4740043')->is_valid_number, '愛知県大府市米田町');
ok($zip->set_number('4740044')->is_valid_number, '愛知県大府市桜木町');
ok($zip->set_number('4740045')->is_valid_number, '愛知県大府市馬池町');
ok($zip->set_number('4740046')->is_valid_number, '愛知県大府市吉川町');
ok($zip->set_number('4740047')->is_valid_number, '愛知県大府市宮内町');
ok($zip->set_number('4740048')->is_valid_number, '愛知県大府市吉田町(1~6丁目)');
ok($zip->set_number('4740051')->is_valid_number, '愛知県大府市大府町');
ok($zip->set_number('4740052')->is_valid_number, '愛知県大府市長草町');
ok($zip->set_number('4740053')->is_valid_number, '愛知県大府市柊山町');
ok($zip->set_number('4740055')->is_valid_number, '愛知県大府市一屋町');
ok($zip->set_number('4740056')->is_valid_number, '愛知県大府市明成町');
ok($zip->set_number('4740057')->is_valid_number, '愛知県大府市共和町(キョウワマチ)');
ok($zip->set_number('4740061')->is_valid_number, '愛知県大府市共和町(丁目)');
ok($zip->set_number('4740062')->is_valid_number, '愛知県大府市共西町');
ok($zip->set_number('4740071')->is_valid_number, '愛知県大府市梶田町');
ok($zip->set_number('4740072')->is_valid_number, '愛知県大府市北山町');
ok($zip->set_number('4740073')->is_valid_number, '愛知県大府市東新町');
ok($zip->set_number('4740074')->is_valid_number, '愛知県大府市共栄町');
ok($zip->set_number('4750000')->is_valid_number, '愛知県半田市以下に掲載がない場合');
ok($zip->set_number('4750001')->is_valid_number, '愛知県半田市石塚町');
ok($zip->set_number('4750002')->is_valid_number, '愛知県半田市緑ケ丘');
ok($zip->set_number('4750003')->is_valid_number, '愛知県半田市東大矢知町');
ok($zip->set_number('4750004')->is_valid_number, '愛知県半田市上池町');
ok($zip->set_number('4750005')->is_valid_number, '愛知県半田市横川町');
ok($zip->set_number('4750006')->is_valid_number, '愛知県半田市南大矢知町');
ok($zip->set_number('4750007')->is_valid_number, '愛知県半田市西大矢知町');
ok($zip->set_number('4750008')->is_valid_number, '愛知県半田市北大矢知町');
ok($zip->set_number('4750009')->is_valid_number, '愛知県半田市上定光町');
ok($zip->set_number('4750011')->is_valid_number, '愛知県半田市稲穂町');
ok($zip->set_number('4750012')->is_valid_number, '愛知県半田市東生見町');
ok($zip->set_number('4750013')->is_valid_number, '愛知県半田市平地馬場町');
ok($zip->set_number('4750014')->is_valid_number, '愛知県半田市一本木町');
ok($zip->set_number('4750015')->is_valid_number, '愛知県半田市大高町');
ok($zip->set_number('4750016')->is_valid_number, '愛知県半田市西生見町');
ok($zip->set_number('4750017')->is_valid_number, '愛知県半田市有脇町');
ok($zip->set_number('4750018')->is_valid_number, '愛知県半田市中生見町');
ok($zip->set_number('4750019')->is_valid_number, '愛知県半田市のぞみが丘');
ok($zip->set_number('4750021')->is_valid_number, '愛知県半田市州の崎町');
ok($zip->set_number('4750022')->is_valid_number, '愛知県半田市亀崎月見町');
ok($zip->set_number('4750023')->is_valid_number, '愛知県半田市亀崎町');
ok($zip->set_number('4750024')->is_valid_number, '愛知県半田市亀崎高根町');
ok($zip->set_number('4750025')->is_valid_number, '愛知県半田市亀崎大洞町');
ok($zip->set_number('4750026')->is_valid_number, '愛知県半田市亀崎新田町');
ok($zip->set_number('4750027')->is_valid_number, '愛知県半田市亀崎北浦町');
ok($zip->set_number('4750028')->is_valid_number, '愛知県半田市亀崎相生町');
ok($zip->set_number('4750029')->is_valid_number, '愛知県半田市亀崎常盤町');
ok($zip->set_number('4750031')->is_valid_number, '愛知県半田市阿原町');
ok($zip->set_number('4750032')->is_valid_number, '愛知県半田市潮干町');
ok($zip->set_number('4750033')->is_valid_number, '愛知県半田市日東町');
ok($zip->set_number('4750034')->is_valid_number, '愛知県半田市東億田町');
ok($zip->set_number('4750035')->is_valid_number, '愛知県半田市中億田町');
ok($zip->set_number('4750036')->is_valid_number, '愛知県半田市高砂町');
ok($zip->set_number('4750037')->is_valid_number, '愛知県半田市中午町');
ok($zip->set_number('4750038')->is_valid_number, '愛知県半田市祢宜町');
ok($zip->set_number('4750039')->is_valid_number, '愛知県半田市新居町');
ok($zip->set_number('4750041')->is_valid_number, '愛知県半田市乙川太田町');
ok($zip->set_number('4750042')->is_valid_number, '愛知県半田市乙川向田町');
ok($zip->set_number('4750043')->is_valid_number, '愛知県半田市乙川浜側町');
ok($zip->set_number('4750044')->is_valid_number, '愛知県半田市乙川八幡町');
ok($zip->set_number('4750045')->is_valid_number, '愛知県半田市乙川殿町');
ok($zip->set_number('4750046')->is_valid_number, '愛知県半田市乙川市場町');
ok($zip->set_number('4750047')->is_valid_number, '愛知県半田市乙川北側町');
ok($zip->set_number('4750048')->is_valid_number, '愛知県半田市乙川稗田町');
ok($zip->set_number('4750051')->is_valid_number, '愛知県半田市乙川栄町');
ok($zip->set_number('4750052')->is_valid_number, '愛知県半田市乙川高良町');
ok($zip->set_number('4750053')->is_valid_number, '愛知県半田市乙川内山町');
ok($zip->set_number('4750054')->is_valid_number, '愛知県半田市乙川町');
ok($zip->set_number('4750055')->is_valid_number, '愛知県半田市北浜田町');
ok($zip->set_number('4750056')->is_valid_number, '愛知県半田市乙川一色町');
ok($zip->set_number('4750057')->is_valid_number, '愛知県半田市乙川新町');
ok($zip->set_number('4750058')->is_valid_number, '愛知県半田市乙川吉野町');
ok($zip->set_number('4750061')->is_valid_number, '愛知県半田市一ノ草町');
ok($zip->set_number('4750062')->is_valid_number, '愛知県半田市飯森町');
ok($zip->set_number('4750063')->is_valid_number, '愛知県半田市乙川若宮町');
ok($zip->set_number('4750064')->is_valid_number, '愛知県半田市乙川薬師町');
ok($zip->set_number('4750065')->is_valid_number, '愛知県半田市乙川深田町');
ok($zip->set_number('4750066')->is_valid_number, '愛知県半田市乙川源内林町');
ok($zip->set_number('4750067')->is_valid_number, '愛知県半田市乙川畑田町');
ok($zip->set_number('4750068')->is_valid_number, '愛知県半田市乙川西ノ宮町');
ok($zip->set_number('4750071')->is_valid_number, '愛知県半田市大伝根町');
ok($zip->set_number('4750072')->is_valid_number, '愛知県半田市七本木町');
ok($zip->set_number('4750073')->is_valid_number, '愛知県半田市美原町');
ok($zip->set_number('4750074')->is_valid_number, '愛知県半田市長根町');
ok($zip->set_number('4750075')->is_valid_number, '愛知県半田市苗代町');
ok($zip->set_number('4750076')->is_valid_number, '愛知県半田市横松上町');
ok($zip->set_number('4750077')->is_valid_number, '愛知県半田市兀山町');
ok($zip->set_number('4750078')->is_valid_number, '愛知県半田市新池町');
ok($zip->set_number('4750081')->is_valid_number, '愛知県半田市平地町');
ok($zip->set_number('4750082')->is_valid_number, '愛知県半田市前田町');
ok($zip->set_number('4750083')->is_valid_number, '愛知県半田市大松町');
ok($zip->set_number('4750084')->is_valid_number, '愛知県半田市向山町');
ok($zip->set_number('4750085')->is_valid_number, '愛知県半田市小神町');
ok($zip->set_number('4750086')->is_valid_number, '愛知県半田市庚申町');
ok($zip->set_number('4750087')->is_valid_number, '愛知県半田市大池町');
ok($zip->set_number('4750088')->is_valid_number, '愛知県半田市花田町');
ok($zip->set_number('4750801')->is_valid_number, '愛知県半田市相賀町');
ok($zip->set_number('4750802')->is_valid_number, '愛知県半田市西億田町');
ok($zip->set_number('4750803')->is_valid_number, '愛知県半田市乙川末広町');
ok($zip->set_number('4750804')->is_valid_number, '愛知県半田市上浜町');
ok($zip->set_number('4750805')->is_valid_number, '愛知県半田市浜田町');
ok($zip->set_number('4750806')->is_valid_number, '愛知県半田市古浜町');
ok($zip->set_number('4750807')->is_valid_number, '愛知県半田市八軒町');
ok($zip->set_number('4750808')->is_valid_number, '愛知県半田市川田町');
ok($zip->set_number('4750813')->is_valid_number, '愛知県半田市東浜町');
ok($zip->set_number('4750814')->is_valid_number, '愛知県半田市幸町');
ok($zip->set_number('4750815')->is_valid_number, '愛知県半田市新栄町');
ok($zip->set_number('4750816')->is_valid_number, '愛知県半田市源平町');
ok($zip->set_number('4750817')->is_valid_number, '愛知県半田市東洋町');
ok($zip->set_number('4750819')->is_valid_number, '愛知県半田市日ノ出町');
ok($zip->set_number('4750821')->is_valid_number, '愛知県半田市船入町');
ok($zip->set_number('4750822')->is_valid_number, '愛知県半田市浜町');
ok($zip->set_number('4750823')->is_valid_number, '愛知県半田市港町');
ok($zip->set_number('4750824')->is_valid_number, '愛知県半田市新浜町');
ok($zip->set_number('4750825')->is_valid_number, '愛知県半田市前潟町');
ok($zip->set_number('4750826')->is_valid_number, '愛知県半田市神明町');
ok($zip->set_number('4750827')->is_valid_number, '愛知県半田市港本町');
ok($zip->set_number('4750828')->is_valid_number, '愛知県半田市瑞穂町');
ok($zip->set_number('4750831')->is_valid_number, '愛知県半田市十一号地');
ok($zip->set_number('4750832')->is_valid_number, '愛知県半田市川崎町');
ok($zip->set_number('4750833')->is_valid_number, '愛知県半田市花園町');
ok($zip->set_number('4750834')->is_valid_number, '愛知県半田市冨士ケ丘');
ok($zip->set_number('4750835')->is_valid_number, '愛知県半田市稲荷町');
ok($zip->set_number('4750836')->is_valid_number, '愛知県半田市青山');
ok($zip->set_number('4750837')->is_valid_number, '愛知県半田市有楽町');
ok($zip->set_number('4750838')->is_valid_number, '愛知県半田市旭町');
ok($zip->set_number('4750841')->is_valid_number, '愛知県半田市大和町');
ok($zip->set_number('4750842')->is_valid_number, '愛知県半田市郷中町');
ok($zip->set_number('4750843')->is_valid_number, '愛知県半田市中島町');
ok($zip->set_number('4750844')->is_valid_number, '愛知県半田市寺町');
ok($zip->set_number('4750845')->is_valid_number, '愛知県半田市成岩東町');
ok($zip->set_number('4750846')->is_valid_number, '愛知県半田市栄町');
ok($zip->set_number('4750847')->is_valid_number, '愛知県半田市畑合町');
ok($zip->set_number('4750848')->is_valid_number, '愛知県半田市成岩本町');
ok($zip->set_number('4750851')->is_valid_number, '愛知県半田市堀崎町');
ok($zip->set_number('4750852')->is_valid_number, '愛知県半田市北末広町');
ok($zip->set_number('4750853')->is_valid_number, '愛知県半田市南末広町');
ok($zip->set_number('4750854')->is_valid_number, '愛知県半田市協和町');
ok($zip->set_number('4750855')->is_valid_number, '愛知県半田市中町');
ok($zip->set_number('4750856')->is_valid_number, '愛知県半田市更生町');
ok($zip->set_number('4750857')->is_valid_number, '愛知県半田市広小路町');
ok($zip->set_number('4750858')->is_valid_number, '愛知県半田市泉町');
ok($zip->set_number('4750859')->is_valid_number, '愛知県半田市天王町');
ok($zip->set_number('4750861')->is_valid_number, '愛知県半田市東新町');
ok($zip->set_number('4750862')->is_valid_number, '愛知県半田市住吉町');
ok($zip->set_number('4750863')->is_valid_number, '愛知県半田市前崎東町');
ok($zip->set_number('4750864')->is_valid_number, '愛知県半田市前崎西町');
ok($zip->set_number('4750865')->is_valid_number, '愛知県半田市清水西町');
ok($zip->set_number('4750866')->is_valid_number, '愛知県半田市清水北町');
ok($zip->set_number('4750867')->is_valid_number, '愛知県半田市榎下町');
ok($zip->set_number('4750868')->is_valid_number, '愛知県半田市西新町');
ok($zip->set_number('4750869')->is_valid_number, '愛知県半田市清水東町');
ok($zip->set_number('4750871')->is_valid_number, '愛知県半田市本町');
ok($zip->set_number('4750872')->is_valid_number, '愛知県半田市東雲町');
ok($zip->set_number('4750873')->is_valid_number, '愛知県半田市中村町');
ok($zip->set_number('4750874')->is_valid_number, '愛知県半田市銀座本町');
ok($zip->set_number('4750875')->is_valid_number, '愛知県半田市山崎町');
ok($zip->set_number('4750876')->is_valid_number, '愛知県半田市東天王町');
ok($zip->set_number('4750877')->is_valid_number, '愛知県半田市勘内町');
ok($zip->set_number('4750878')->is_valid_number, '愛知県半田市東本町');
ok($zip->set_number('4750881')->is_valid_number, '愛知県半田市荒古町');
ok($zip->set_number('4750882')->is_valid_number, '愛知県半田市南本町');
ok($zip->set_number('4750883')->is_valid_number, '愛知県半田市妙見町');
ok($zip->set_number('4750884')->is_valid_number, '愛知県半田市西端町');
ok($zip->set_number('4750885')->is_valid_number, '愛知県半田市山ノ神町');
ok($zip->set_number('4750886')->is_valid_number, '愛知県半田市新川町');
ok($zip->set_number('4750887')->is_valid_number, '愛知県半田市御幸町');
ok($zip->set_number('4750901')->is_valid_number, '愛知県半田市岩滑南浜町');
ok($zip->set_number('4750902')->is_valid_number, '愛知県半田市宮路町');
ok($zip->set_number('4750903')->is_valid_number, '愛知県半田市出口町');
ok($zip->set_number('4750904')->is_valid_number, '愛知県半田市大坪町');
ok($zip->set_number('4750905')->is_valid_number, '愛知県半田市岩滑東町');
ok($zip->set_number('4750906')->is_valid_number, '愛知県半田市岩滑北浜町');
ok($zip->set_number('4750911')->is_valid_number, '愛知県半田市星崎町');
ok($zip->set_number('4750912')->is_valid_number, '愛知県半田市白山町');
ok($zip->set_number('4750914')->is_valid_number, '愛知県半田市土井山町');
ok($zip->set_number('4750915')->is_valid_number, '愛知県半田市枝山町');
ok($zip->set_number('4750916')->is_valid_number, '愛知県半田市柊町');
ok($zip->set_number('4750917')->is_valid_number, '愛知県半田市清城町');
ok($zip->set_number('4750918')->is_valid_number, '愛知県半田市雁宿町');
ok($zip->set_number('4750921')->is_valid_number, '愛知県半田市天神町');
ok($zip->set_number('4750922')->is_valid_number, '愛知県半田市昭和町');
ok($zip->set_number('4750923')->is_valid_number, '愛知県半田市春日町');
ok($zip->set_number('4750924')->is_valid_number, '愛知県半田市東郷町');
ok($zip->set_number('4750925')->is_valid_number, '愛知県半田市宮本町');
ok($zip->set_number('4750926')->is_valid_number, '愛知県半田市南二ツ坂町');
ok($zip->set_number('4750927')->is_valid_number, '愛知県半田市北二ツ坂町');
ok($zip->set_number('4750928')->is_valid_number, '愛知県半田市桐ケ丘');
ok($zip->set_number('4750929')->is_valid_number, '愛知県半田市仲田町');
ok($zip->set_number('4750931')->is_valid_number, '愛知県半田市新宮町');
ok($zip->set_number('4750932')->is_valid_number, '愛知県半田市鴉根町');
ok($zip->set_number('4750933')->is_valid_number, '愛知県半田市新野町');
ok($zip->set_number('4750934')->is_valid_number, '愛知県半田市椎ノ木町');
ok($zip->set_number('4750935')->is_valid_number, '愛知県半田市大湯町');
ok($zip->set_number('4750936')->is_valid_number, '愛知県半田市板山町');
ok($zip->set_number('4750937')->is_valid_number, '愛知県半田市神田町');
ok($zip->set_number('4750938')->is_valid_number, '愛知県半田市君ケ橋町');
ok($zip->set_number('4750939')->is_valid_number, '愛知県半田市四方木町');
ok($zip->set_number('4750941')->is_valid_number, '愛知県半田市滑楚町');
ok($zip->set_number('4750942')->is_valid_number, '愛知県半田市松堀町');
ok($zip->set_number('4750943')->is_valid_number, '愛知県半田市高峯町');
ok($zip->set_number('4750944')->is_valid_number, '愛知県半田市神代町');
ok($zip->set_number('4750945')->is_valid_number, '愛知県半田市池田町');
ok($zip->set_number('4750946')->is_valid_number, '愛知県半田市横山町');
ok($zip->set_number('4750947')->is_valid_number, '愛知県半田市砂谷町');
ok($zip->set_number('4750948')->is_valid_number, '愛知県半田市田代町');
ok($zip->set_number('4750951')->is_valid_number, '愛知県半田市宝来町');
ok($zip->set_number('4750952')->is_valid_number, '愛知県半田市馬捨町');
ok($zip->set_number('4750953')->is_valid_number, '愛知県半田市金山町');
ok($zip->set_number('4750954')->is_valid_number, '愛知県半田市十三塚町');
ok($zip->set_number('4750955')->is_valid_number, '愛知県半田市行人町');
ok($zip->set_number('4750956')->is_valid_number, '愛知県半田市三ツ池町');
ok($zip->set_number('4750957')->is_valid_number, '愛知県半田市奥町');
ok($zip->set_number('4750958')->is_valid_number, '愛知県半田市鵜ノ池町');
ok($zip->set_number('4750959')->is_valid_number, '愛知県半田市桃山町');
ok($zip->set_number('4750961')->is_valid_number, '愛知県半田市岩滑中町');
ok($zip->set_number('4750962')->is_valid_number, '愛知県半田市岩滑高山町');
ok($zip->set_number('4750963')->is_valid_number, '愛知県半田市平和町');
ok($zip->set_number('4750964')->is_valid_number, '愛知県半田市平井町');
ok($zip->set_number('4750965')->is_valid_number, '愛知県半田市新生町');
ok($zip->set_number('4750966')->is_valid_number, '愛知県半田市岩滑西町');
ok($zip->set_number('4750967')->is_valid_number, '愛知県半田市欠ケ下町');
ok($zip->set_number('4750968')->is_valid_number, '愛知県半田市丁田町');
ok($zip->set_number('4750971')->is_valid_number, '愛知県半田市深谷町');
ok($zip->set_number('4750972')->is_valid_number, '愛知県半田市北滑草町');
ok($zip->set_number('4750973')->is_valid_number, '愛知県半田市葭谷町');
ok($zip->set_number('4750974')->is_valid_number, '愛知県半田市山代町');
ok($zip->set_number('4750975')->is_valid_number, '愛知県半田市彦洲町');
ok($zip->set_number('4750976')->is_valid_number, '愛知県半田市黒石町');
ok($zip->set_number('4750977')->is_valid_number, '愛知県半田市吉田町');
ok($zip->set_number('4750978')->is_valid_number, '愛知県半田市福地町');
ok($zip->set_number('4760000')->is_valid_number, '愛知県東海市以下に掲載がない場合');
ok($zip->set_number('4760001')->is_valid_number, '愛知県東海市南柴田町');
ok($zip->set_number('4760002')->is_valid_number, '愛知県東海市名和町');
ok($zip->set_number('4760003')->is_valid_number, '愛知県東海市荒尾町');
ok($zip->set_number('4760004')->is_valid_number, '愛知県東海市荒尾町水深');
ok($zip->set_number('4760005')->is_valid_number, '愛知県東海市新宝町');
ok($zip->set_number('4760006')->is_valid_number, '愛知県東海市浅山');
ok($zip->set_number('4760011')->is_valid_number, '愛知県東海市富木島町');
ok($zip->set_number('4760012')->is_valid_number, '愛知県東海市富木島町伏見');
ok($zip->set_number('4760013')->is_valid_number, '愛知県東海市中央町');
ok($zip->set_number('4760014')->is_valid_number, '愛知県東海市富貴ノ台');
ok($zip->set_number('4760015')->is_valid_number, '愛知県東海市東海町');
ok($zip->set_number('4770031')->is_valid_number, '愛知県東海市大田町');
ok($zip->set_number('4770032')->is_valid_number, '愛知県東海市加木屋町');
ok($zip->set_number('4770033')->is_valid_number, '愛知県東海市中ノ池');
ok($zip->set_number('4770034')->is_valid_number, '愛知県東海市養父町');
ok($zip->set_number('4770035')->is_valid_number, '愛知県東海市元浜町');
ok($zip->set_number('4770036')->is_valid_number, '愛知県東海市横須賀町');
ok($zip->set_number('4770037')->is_valid_number, '愛知県東海市高横須賀町');
ok($zip->set_number('4780000')->is_valid_number, '愛知県知多市以下に掲載がない場合');
ok($zip->set_number('4780001')->is_valid_number, '愛知県知多市八幡');
ok($zip->set_number('4780002')->is_valid_number, '愛知県知多市平野');
ok($zip->set_number('4780003')->is_valid_number, '愛知県知多市寺本台');
ok($zip->set_number('4780004')->is_valid_number, '愛知県知多市伊賀坂');
ok($zip->set_number('4780005')->is_valid_number, '愛知県知多市阿原');
ok($zip->set_number('4780006')->is_valid_number, '愛知県知多市三反田');
ok($zip->set_number('4780011')->is_valid_number, '愛知県知多市原');
ok($zip->set_number('4780012')->is_valid_number, '愛知県知多市巽が丘');
ok($zip->set_number('4780013')->is_valid_number, '愛知県知多市南巽が丘');
ok($zip->set_number('4780014')->is_valid_number, '愛知県知多市西巽が丘');
ok($zip->set_number('4780015')->is_valid_number, '愛知県知多市佐布里');
ok($zip->set_number('4780016')->is_valid_number, '愛知県知多市梅が丘');
ok($zip->set_number('4780017')->is_valid_number, '愛知県知多市新知');
ok($zip->set_number('4780018')->is_valid_number, '愛知県知多市佐布里台');
ok($zip->set_number('4780021')->is_valid_number, '愛知県知多市岡田');
ok($zip->set_number('4780022')->is_valid_number, '愛知県知多市大興寺');
ok($zip->set_number('4780023')->is_valid_number, '愛知県知多市南粕谷東坂');
ok($zip->set_number('4780024')->is_valid_number, '愛知県知多市南粕谷');
ok($zip->set_number('4780025')->is_valid_number, '愛知県知多市南粕谷本町');
ok($zip->set_number('4780026')->is_valid_number, '愛知県知多市南粕谷新海');
ok($zip->set_number('4780027')->is_valid_number, '愛知県知多市新広見');
ok($zip->set_number('4780028')->is_valid_number, '愛知県知多市岡田緑が丘');
ok($zip->set_number('4780031')->is_valid_number, '愛知県知多市旭');
ok($zip->set_number('4780032')->is_valid_number, '愛知県知多市金沢');
ok($zip->set_number('4780033')->is_valid_number, '愛知県知多市神田');
ok($zip->set_number('4780034')->is_valid_number, '愛知県知多市旭南');
ok($zip->set_number('4780035')->is_valid_number, '愛知県知多市大草');
ok($zip->set_number('4780036')->is_valid_number, '愛知県知多市新舞子');
ok($zip->set_number('4780037')->is_valid_number, '愛知県知多市新舞子東町');
ok($zip->set_number('4780041')->is_valid_number, '愛知県知多市日長');
ok($zip->set_number('4780042')->is_valid_number, '愛知県知多市長浦');
ok($zip->set_number('4780043')->is_valid_number, '愛知県知多市日長台');
ok($zip->set_number('4780044')->is_valid_number, '愛知県知多市旭桃台');
ok($zip->set_number('4780045')->is_valid_number, '愛知県知多市南浜町');
ok($zip->set_number('4780046')->is_valid_number, '愛知県知多市北浜町');
ok($zip->set_number('4780047')->is_valid_number, '愛知県知多市緑町');
ok($zip->set_number('4780051')->is_valid_number, '愛知県知多市朝倉町');
ok($zip->set_number('4780052')->is_valid_number, '愛知県知多市八幡新町');
ok($zip->set_number('4780053')->is_valid_number, '愛知県知多市清水が丘');
ok($zip->set_number('4780054')->is_valid_number, '愛知県知多市つつじが丘');
ok($zip->set_number('4780055')->is_valid_number, '愛知県知多市にしの台');
ok($zip->set_number('4780056')->is_valid_number, '愛知県知多市南谷');
ok($zip->set_number('4780057')->is_valid_number, '愛知県知多市吹込');
ok($zip->set_number('4780058')->is_valid_number, '愛知県知多市上り戸');
ok($zip->set_number('4780059')->is_valid_number, '愛知県知多市新長根');
ok($zip->set_number('4780060')->is_valid_number, '愛知県知多市山屋敷');
ok($zip->set_number('4780061')->is_valid_number, '愛知県知多市東大僧');
ok($zip->set_number('4780062')->is_valid_number, '愛知県知多市岡田美里町');
ok($zip->set_number('4780063')->is_valid_number, '愛知県知多市寺本新町');
ok($zip->set_number('4780064')->is_valid_number, '愛知県知多市新知台');
ok($zip->set_number('4780065')->is_valid_number, '愛知県知多市新知東町');
ok($zip->set_number('4780066')->is_valid_number, '愛知県知多市新知西町');
ok($zip->set_number('4780067')->is_valid_number, '愛知県知多市大僧');
ok($zip->set_number('4780068')->is_valid_number, '愛知県知多市中原');
ok($zip->set_number('4780069')->is_valid_number, '愛知県知多市新刀池');
ok($zip->set_number('4790000')->is_valid_number, '愛知県常滑市以下に掲載がない場合');
ok($zip->set_number('4790001')->is_valid_number, '愛知県常滑市矢田');
ok($zip->set_number('4790002')->is_valid_number, '愛知県常滑市久米');
ok($zip->set_number('4790003')->is_valid_number, '愛知県常滑市金山');
ok($zip->set_number('4790004')->is_valid_number, '愛知県常滑市青海町');
ok($zip->set_number('4790005')->is_valid_number, '愛知県常滑市大塚町');
ok($zip->set_number('4790006')->is_valid_number, '愛知県常滑市古道');
ok($zip->set_number('4790007')->is_valid_number, '愛知県常滑市庄兵衛新田');
ok($zip->set_number('4790008')->is_valid_number, '愛知県常滑市酉新田');
ok($zip->set_number('4790009')->is_valid_number, '愛知県常滑市平池');
ok($zip->set_number('4790011')->is_valid_number, '愛知県常滑市花狭間');
ok($zip->set_number('4790012')->is_valid_number, '愛知県常滑市上納');
ok($zip->set_number('4790013')->is_valid_number, '愛知県常滑市二ノ割');
ok($zip->set_number('4790014')->is_valid_number, '愛知県常滑市一ノ割');
ok($zip->set_number('4790015')->is_valid_number, '愛知県常滑市大窯');
ok($zip->set_number('4790016')->is_valid_number, '愛知県常滑市高坂');
ok($zip->set_number('4790017')->is_valid_number, '愛知県常滑市椎池');
ok($zip->set_number('4790018')->is_valid_number, '愛知県常滑市二ノ田');
ok($zip->set_number('4790019')->is_valid_number, '愛知県常滑市柴山');
ok($zip->set_number('4790021')->is_valid_number, '愛知県常滑市大曽町');
ok($zip->set_number('4790022')->is_valid_number, '愛知県常滑市堕星');
ok($zip->set_number('4790023')->is_valid_number, '愛知県常滑市長峰一ノ切');
ok($zip->set_number('4790024')->is_valid_number, '愛知県常滑市池田口');
ok($zip->set_number('4790025')->is_valid_number, '愛知県常滑市新池');
ok($zip->set_number('4790026')->is_valid_number, '愛知県常滑市天竺');
ok($zip->set_number('4790027')->is_valid_number, '愛知県常滑市大流');
ok($zip->set_number('4790028')->is_valid_number, '愛知県常滑市長峰二ノ切');
ok($zip->set_number('4790029')->is_valid_number, '愛知県常滑市古道東割');
ok($zip->set_number('4790031')->is_valid_number, '愛知県常滑市長峰三ノ切');
ok($zip->set_number('4790032')->is_valid_number, '愛知県常滑市下隅');
ok($zip->set_number('4790033')->is_valid_number, '愛知県常滑市中椎田');
ok($zip->set_number('4790034')->is_valid_number, '愛知県常滑市椎田奥');
ok($zip->set_number('4790035')->is_valid_number, '愛知県常滑市椎草南割');
ok($zip->set_number('4790036')->is_valid_number, '愛知県常滑市椎田口');
ok($zip->set_number('4790037')->is_valid_number, '愛知県常滑市中大流');
ok($zip->set_number('4790038')->is_valid_number, '愛知県常滑市石窯');
ok($zip->set_number('4790039')->is_valid_number, '愛知県常滑市大流天竺口');
ok($zip->set_number('4790041')->is_valid_number, '愛知県常滑市千代');
ok($zip->set_number('4790042')->is_valid_number, '愛知県常滑市社辺');
ok($zip->set_number('4790043')->is_valid_number, '愛知県常滑市古社');
ok($zip->set_number('4790044')->is_valid_number, '愛知県常滑市乙田');
ok($zip->set_number('4790045')->is_valid_number, '愛知県常滑市仲井');
ok($zip->set_number('4790046')->is_valid_number, '愛知県常滑市北古千代');
ok($zip->set_number('4790047')->is_valid_number, '愛知県常滑市南古千代');
ok($zip->set_number('4790048')->is_valid_number, '愛知県常滑市中千代');
ok($zip->set_number('4790049')->is_valid_number, '愛知県常滑市長峰四ノ切');
ok($zip->set_number('4790053')->is_valid_number, '愛知県常滑市奥夏敷');
ok($zip->set_number('4790054')->is_valid_number, '愛知県常滑市西梨木');
ok($zip->set_number('4790055')->is_valid_number, '愛知県常滑市広内');
ok($zip->set_number('4790056')->is_valid_number, '愛知県常滑市椎垂木');
ok($zip->set_number('4790057')->is_valid_number, '愛知県常滑市樋掛');
ok($zip->set_number('4790058')->is_valid_number, '愛知県常滑市古千代');
ok($zip->set_number('4790059')->is_valid_number, '愛知県常滑市南蛇廻間');
ok($zip->set_number('4790061')->is_valid_number, '愛知県常滑市耳切');
ok($zip->set_number('4790062')->is_valid_number, '愛知県常滑市運内');
ok($zip->set_number('4790063')->is_valid_number, '愛知県常滑市萱苅口');
ok($zip->set_number('4790064')->is_valid_number, '愛知県常滑市斧口');
ok($zip->set_number('4790065')->is_valid_number, '愛知県常滑市長間');
ok($zip->set_number('4790066')->is_valid_number, '愛知県常滑市脇田口');
ok($zip->set_number('4790067')->is_valid_number, '愛知県常滑市小森');
ok($zip->set_number('4790068')->is_valid_number, '愛知県常滑市長田');
ok($zip->set_number('4790069')->is_valid_number, '愛知県常滑市折戸');
ok($zip->set_number('4790071')->is_valid_number, '愛知県常滑市蛇廻間');
ok($zip->set_number('4790072')->is_valid_number, '愛知県常滑市乳母子');
ok($zip->set_number('4790073')->is_valid_number, '愛知県常滑市飛渡川');
ok($zip->set_number('4790074')->is_valid_number, '愛知県常滑市池田川');
ok($zip->set_number('4790075')->is_valid_number, '愛知県常滑市菅場');
ok($zip->set_number('4790076')->is_valid_number, '愛知県常滑市鳥根');
ok($zip->set_number('4790077')->is_valid_number, '愛知県常滑市南飛渡');
ok($zip->set_number('4790079')->is_valid_number, '愛知県常滑市黒山');
ok($zip->set_number('4790801')->is_valid_number, '愛知県常滑市樽水');
ok($zip->set_number('4790802')->is_valid_number, '愛知県常滑市西阿野');
ok($zip->set_number('4790803')->is_valid_number, '愛知県常滑市桧原');
ok($zip->set_number('4790804')->is_valid_number, '愛知県常滑市古場');
ok($zip->set_number('4790805')->is_valid_number, '愛知県常滑市苅屋');
ok($zip->set_number('4790806')->is_valid_number, '愛知県常滑市大谷');
ok($zip->set_number('4790807')->is_valid_number, '愛知県常滑市小鈴谷');
ok($zip->set_number('4790808')->is_valid_number, '愛知県常滑市広目');
ok($zip->set_number('4790809')->is_valid_number, '愛知県常滑市坂井');
ok($zip->set_number('4790810')->is_valid_number, '愛知県常滑市大谷朝陽ケ丘');
ok($zip->set_number('4790811')->is_valid_number, '愛知県常滑市泉町');
ok($zip->set_number('4790812')->is_valid_number, '愛知県常滑市井戸田町');
ok($zip->set_number('4790813')->is_valid_number, '愛知県常滑市塩田町');
ok($zip->set_number('4790814')->is_valid_number, '愛知県常滑市阿野町');
ok($zip->set_number('4790815')->is_valid_number, '愛知県常滑市唐崎町');
ok($zip->set_number('4790816')->is_valid_number, '愛知県常滑市熊野');
ok($zip->set_number('4790817')->is_valid_number, '愛知県常滑市熊野町');
ok($zip->set_number('4790818')->is_valid_number, '愛知県常滑市古場町');
ok($zip->set_number('4790819')->is_valid_number, '愛知県常滑市苅屋町');
ok($zip->set_number('4790821')->is_valid_number, '愛知県常滑市瀬木町');
ok($zip->set_number('4790822')->is_valid_number, '愛知県常滑市奥条');
ok($zip->set_number('4790823')->is_valid_number, '愛知県常滑市奥栄町');
ok($zip->set_number('4790824')->is_valid_number, '愛知県常滑市白山町');
ok($zip->set_number('4790825')->is_valid_number, '愛知県常滑市山方町');
ok($zip->set_number('4790826')->is_valid_number, '愛知県常滑市樽水町');
ok($zip->set_number('4790827')->is_valid_number, '愛知県常滑市保示町');
ok($zip->set_number('4790828')->is_valid_number, '愛知県常滑市市場町');
ok($zip->set_number('4790829')->is_valid_number, '愛知県常滑市本町');
ok($zip->set_number('4790831')->is_valid_number, '愛知県常滑市錦町');
ok($zip->set_number('4790832')->is_valid_number, '愛知県常滑市原松町');
ok($zip->set_number('4790833')->is_valid_number, '愛知県常滑市北条');
ok($zip->set_number('4790834')->is_valid_number, '愛知県常滑市千代ケ丘');
ok($zip->set_number('4790835')->is_valid_number, '愛知県常滑市陶郷町');
ok($zip->set_number('4790836')->is_valid_number, '愛知県常滑市栄町');
ok($zip->set_number('4790837')->is_valid_number, '愛知県常滑市新開町');
ok($zip->set_number('4790838')->is_valid_number, '愛知県常滑市鯉江本町');
ok($zip->set_number('4790839')->is_valid_number, '愛知県常滑市多屋町');
ok($zip->set_number('4790841')->is_valid_number, '愛知県常滑市明和町');
ok($zip->set_number('4790842')->is_valid_number, '愛知県常滑市大鳥町');
ok($zip->set_number('4790843')->is_valid_number, '愛知県常滑市多屋');
ok($zip->set_number('4790844')->is_valid_number, '愛知県常滑市大和町');
ok($zip->set_number('4790845')->is_valid_number, '愛知県常滑市森西町');
ok($zip->set_number('4790846')->is_valid_number, '愛知県常滑市末広町');
ok($zip->set_number('4790847')->is_valid_number, '愛知県常滑市新浜町');
ok($zip->set_number('4790848')->is_valid_number, '愛知県常滑市港町');
ok($zip->set_number('4790849')->is_valid_number, '愛知県常滑市虹の丘');
ok($zip->set_number('4790851')->is_valid_number, '愛知県常滑市若松町');
ok($zip->set_number('4790852')->is_valid_number, '愛知県常滑市神明町');
ok($zip->set_number('4790853')->is_valid_number, '愛知県常滑市本郷町');
ok($zip->set_number('4790854')->is_valid_number, '愛知県常滑市榎戸町');
ok($zip->set_number('4790855')->is_valid_number, '愛知県常滑市新田町');
ok($zip->set_number('4790856')->is_valid_number, '愛知県常滑市蒲池町');
ok($zip->set_number('4790857')->is_valid_number, '愛知県常滑市榎戸');
ok($zip->set_number('4790858')->is_valid_number, '愛知県常滑市蒲池');
ok($zip->set_number('4790861')->is_valid_number, '愛知県常滑市晩台町');
ok($zip->set_number('4790862')->is_valid_number, '愛知県常滑市小倉町');
ok($zip->set_number('4790863')->is_valid_number, '愛知県常滑市西之口');
ok($zip->set_number('4790864')->is_valid_number, '愛知県常滑市住吉町');
ok($zip->set_number('4790865')->is_valid_number, '愛知県常滑市小林町');
ok($zip->set_number('4790866')->is_valid_number, '愛知県常滑市大野町');
ok($zip->set_number('4790867')->is_valid_number, '愛知県常滑市北汐見坂');
ok($zip->set_number('4790868')->is_valid_number, '愛知県常滑市飛香台');
ok($zip->set_number('4790871')->is_valid_number, '愛知県常滑市大曽');
ok($zip->set_number('4790873')->is_valid_number, '愛知県常滑市かじま台');
ok($zip->set_number('4790881')->is_valid_number, '愛知県常滑市セントレア');
ok($zip->set_number('4790882')->is_valid_number, '愛知県常滑市りんくう町');
ok($zip->set_number('4800100')->is_valid_number, '愛知県丹羽郡大口町以下に掲載がない場合');
ok($zip->set_number('4800100')->is_valid_number, '愛知県丹羽郡扶桑町以下に掲載がない場合');
ok($zip->set_number('4800101')->is_valid_number, '愛知県丹羽郡扶桑町山那');
ok($zip->set_number('4800102')->is_valid_number, '愛知県丹羽郡扶桑町高雄');
ok($zip->set_number('4800103')->is_valid_number, '愛知県丹羽郡扶桑町柏森');
ok($zip->set_number('4800104')->is_valid_number, '愛知県丹羽郡扶桑町斎藤');
ok($zip->set_number('4800105')->is_valid_number, '愛知県丹羽郡扶桑町南山名');
ok($zip->set_number('4800106')->is_valid_number, '愛知県丹羽郡扶桑町小淵');
ok($zip->set_number('4800107')->is_valid_number, '愛知県丹羽郡扶桑町高木');
ok($zip->set_number('4800121')->is_valid_number, '愛知県丹羽郡大口町河北');
ok($zip->set_number('4800122')->is_valid_number, '愛知県丹羽郡大口町仲沖');
ok($zip->set_number('4800123')->is_valid_number, '愛知県丹羽郡大口町二ツ屋');
ok($zip->set_number('4800124')->is_valid_number, '愛知県丹羽郡大口町萩島');
ok($zip->set_number('4800125')->is_valid_number, '愛知県丹羽郡大口町外坪');
ok($zip->set_number('4800126')->is_valid_number, '愛知県丹羽郡大口町伝右');
ok($zip->set_number('4800127')->is_valid_number, '愛知県丹羽郡大口町新宮');
ok($zip->set_number('4800131')->is_valid_number, '愛知県丹羽郡大口町高橋');
ok($zip->set_number('4800132')->is_valid_number, '愛知県丹羽郡大口町秋田');
ok($zip->set_number('4800133')->is_valid_number, '愛知県丹羽郡大口町替地');
ok($zip->set_number('4800134')->is_valid_number, '愛知県丹羽郡大口町豊田');
ok($zip->set_number('4800135')->is_valid_number, '愛知県丹羽郡大口町御供所');
ok($zip->set_number('4800136')->is_valid_number, '愛知県丹羽郡大口町堀尾跡');
ok($zip->set_number('4800137')->is_valid_number, '愛知県丹羽郡大口町大屋敷');
ok($zip->set_number('4800138')->is_valid_number, '愛知県丹羽郡大口町大御堂');
ok($zip->set_number('4800139')->is_valid_number, '愛知県丹羽郡大口町奈良子');
ok($zip->set_number('4800141')->is_valid_number, '愛知県丹羽郡大口町上小口');
ok($zip->set_number('4800142')->is_valid_number, '愛知県丹羽郡大口町中小口');
ok($zip->set_number('4800143')->is_valid_number, '愛知県丹羽郡大口町城屋敷');
ok($zip->set_number('4800144')->is_valid_number, '愛知県丹羽郡大口町下小口');
ok($zip->set_number('4800145')->is_valid_number, '愛知県丹羽郡大口町丸');
ok($zip->set_number('4800146')->is_valid_number, '愛知県丹羽郡大口町余野');
ok($zip->set_number('4800147')->is_valid_number, '愛知県丹羽郡大口町竹田');
ok($zip->set_number('4800148')->is_valid_number, '愛知県丹羽郡大口町小口');
ok($zip->set_number('4800149')->is_valid_number, '愛知県丹羽郡大口町垣田');
ok($zip->set_number('4800151')->is_valid_number, '愛知県丹羽郡大口町さつきケ丘');
ok($zip->set_number('4800200')->is_valid_number, '愛知県西春日井郡豊山町以下に掲載がない場合');
ok($zip->set_number('4800201')->is_valid_number, '愛知県西春日井郡豊山町青山');
ok($zip->set_number('4800202')->is_valid_number, '愛知県西春日井郡豊山町豊場');
ok($zip->set_number('4800301')->is_valid_number, '愛知県春日井市内津町');
ok($zip->set_number('4800302')->is_valid_number, '愛知県春日井市西尾町');
ok($zip->set_number('4800303')->is_valid_number, '愛知県春日井市明知町');
ok($zip->set_number('4800304')->is_valid_number, '愛知県春日井市神屋町');
ok($zip->set_number('4800305')->is_valid_number, '愛知県春日井市坂下町');
ok($zip->set_number('4800306')->is_valid_number, '愛知県春日井市上野町');
ok($zip->set_number('4801100')->is_valid_number, '愛知県長久手市以下に掲載がない場合');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊一ノ井');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊志水');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊下田');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊寺田');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊中井');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊西脇');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊根ノ上');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊根ノ原');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊橋ノ本');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊原山');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊広面');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊堀越');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊前山');
ok($zip->set_number('4801102')->is_valid_number, '愛知県長久手市前熊溝下');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作石田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作井戸ケ根');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作色金');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作浮江');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作内万場');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作大根');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作落合');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作折戸ケ平');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作欠花');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作壁ノ本');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作雁又');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作北山');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作狐洞');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作五反田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作権田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作権代');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作三ケ峯');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作申立花');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作下島');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作下田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作下堀越');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作蛇洞');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作白針');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作城の内');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作隅田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作高根');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作高根前');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作高山');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作塚本');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作寺田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作寺山');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作床寒');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作泥亀首');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作寅山');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作酉立花');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作長池');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作長筬');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作中権代');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作中島');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作長鶴');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作中縄手');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作中根');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作中根原');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作中立花');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作中脇');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作西浦');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作西島');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作東島');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作東中');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作平子');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作平地');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作琵琶ケ池');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作福井');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作丸根');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作溝添');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作南島');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作宮後');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作宮前');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作向田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作向畑');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作元門');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作桃ノ木洞');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作八瀬ノ木');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作籔田');
ok($zip->set_number('4801103')->is_valid_number, '愛知県長久手市岩作早稲田');
ok($zip->set_number('4801104')->is_valid_number, '愛知県長久手市棒振');
ok($zip->set_number('4801105')->is_valid_number, '愛知県長久手市丸根');
ok($zip->set_number('4801106')->is_valid_number, '愛知県長久手市大久手');
ok($zip->set_number('4801107')->is_valid_number, '愛知県長久手市下権田');
ok($zip->set_number('4801108')->is_valid_number, '愛知県長久手市中池');
ok($zip->set_number('4801111')->is_valid_number, '愛知県長久手市山越');
ok($zip->set_number('4801112')->is_valid_number, '愛知県長久手市砂子');
ok($zip->set_number('4801113')->is_valid_number, '愛知県長久手市山野田');
ok($zip->set_number('4801114')->is_valid_number, '愛知県長久手市長配');
ok($zip->set_number('4801115')->is_valid_number, '愛知県長久手市菖蒲池');
ok($zip->set_number('4801116')->is_valid_number, '愛知県長久手市杁ケ池');
ok($zip->set_number('4801117')->is_valid_number, '愛知県長久手市喜婦嶽');
ok($zip->set_number('4801118')->is_valid_number, '愛知県長久手市横道');
ok($zip->set_number('4801119')->is_valid_number, '愛知県長久手市深廻間');
ok($zip->set_number('4801121')->is_valid_number, '愛知県長久手市武蔵塚');
ok($zip->set_number('4801122')->is_valid_number, '愛知県長久手市城屋敷');
ok($zip->set_number('4801123')->is_valid_number, '愛知県長久手市東狭間');
ok($zip->set_number('4801124')->is_valid_number, '愛知県長久手市戸田谷');
ok($zip->set_number('4801125')->is_valid_number, '愛知県長久手市氏神前');
ok($zip->set_number('4801126')->is_valid_number, '愛知県長久手市深田');
ok($zip->set_number('4801127')->is_valid_number, '愛知県長久手市菅池');
ok($zip->set_number('4801128')->is_valid_number, '愛知県長久手市勝入塚');
ok($zip->set_number('4801129')->is_valid_number, '愛知県長久手市よし池');
ok($zip->set_number('4801132')->is_valid_number, '愛知県長久手市上川原');
ok($zip->set_number('4801133')->is_valid_number, '愛知県長久手市原山');
ok($zip->set_number('4801134')->is_valid_number, '愛知県長久手市南原山');
ok($zip->set_number('4801135')->is_valid_number, '愛知県長久手市下山');
ok($zip->set_number('4801136')->is_valid_number, '愛知県長久手市櫨木');
ok($zip->set_number('4801137')->is_valid_number, '愛知県長久手市下川原');
ok($zip->set_number('4801138')->is_valid_number, '愛知県長久手市西原山');
ok($zip->set_number('4801139')->is_valid_number, '愛知県長久手市中川原');
ok($zip->set_number('4801141')->is_valid_number, '愛知県長久手市根の神');
ok($zip->set_number('4801142')->is_valid_number, '愛知県長久手市蟹原');
ok($zip->set_number('4801143')->is_valid_number, '愛知県長久手市井堀');
ok($zip->set_number('4801144')->is_valid_number, '愛知県長久手市熊田');
ok($zip->set_number('4801145')->is_valid_number, '愛知県長久手市卯塚');
ok($zip->set_number('4801146')->is_valid_number, '愛知県長久手市片平');
ok($zip->set_number('4801147')->is_valid_number, '愛知県長久手市市が洞');
ok($zip->set_number('4801148')->is_valid_number, '愛知県長久手市根嶽');
ok($zip->set_number('4801151')->is_valid_number, '愛知県長久手市久保山');
ok($zip->set_number('4801152')->is_valid_number, '愛知県長久手市打越');
ok($zip->set_number('4801153')->is_valid_number, '愛知県長久手市作田');
ok($zip->set_number('4801154')->is_valid_number, '愛知県長久手市塚田');
ok($zip->set_number('4801155')->is_valid_number, '愛知県長久手市平池');
ok($zip->set_number('4801156')->is_valid_number, '愛知県長久手市五合池');
ok($zip->set_number('4801157')->is_valid_number, '愛知県長久手市桜作');
ok($zip->set_number('4801158')->is_valid_number, '愛知県長久手市東原山');
ok($zip->set_number('4801161')->is_valid_number, '愛知県長久手市荒田');
ok($zip->set_number('4801162')->is_valid_number, '愛知県長久手市段の上');
ok($zip->set_number('4801163')->is_valid_number, '愛知県長久手市原邸');
ok($zip->set_number('4801164')->is_valid_number, '愛知県長久手市山桶');
ok($zip->set_number('4801165')->is_valid_number, '愛知県長久手市鴨田');
ok($zip->set_number('4801166')->is_valid_number, '愛知県長久手市野田農');
ok($zip->set_number('4801167')->is_valid_number, '愛知県長久手市仲田');
ok($zip->set_number('4801168')->is_valid_number, '愛知県長久手市坊の後');
ok($zip->set_number('4801171')->is_valid_number, '愛知県長久手市西浦');
ok($zip->set_number('4801172')->is_valid_number, '愛知県長久手市宮脇');
ok($zip->set_number('4801173')->is_valid_number, '愛知県長久手市富士浦');
ok($zip->set_number('4801174')->is_valid_number, '愛知県長久手市東浦');
ok($zip->set_number('4801175')->is_valid_number, '愛知県長久手市先達');
ok($zip->set_number('4801176')->is_valid_number, '愛知県長久手市香桶');
ok($zip->set_number('4801177')->is_valid_number, '愛知県長久手市仏が根');
ok($zip->set_number('4801178')->is_valid_number, '愛知県長久手市丁子田');
ok($zip->set_number('4801181')->is_valid_number, '愛知県長久手市東原');
ok($zip->set_number('4801182')->is_valid_number, '愛知県長久手市池田');
ok($zip->set_number('4801183')->is_valid_number, '愛知県長久手市西原');
ok($zip->set_number('4801184')->is_valid_number, '愛知県長久手市草掛');
ok($zip->set_number('4801201')->is_valid_number, '愛知県瀬戸市定光寺町');
ok($zip->set_number('4801202')->is_valid_number, '愛知県瀬戸市下半田川町');
ok($zip->set_number('4801203')->is_valid_number, '愛知県瀬戸市広之田町');
ok($zip->set_number('4801204')->is_valid_number, '愛知県瀬戸市北丘町');
ok($zip->set_number('4801205')->is_valid_number, '愛知県瀬戸市落合町');
ok($zip->set_number('4801206')->is_valid_number, '愛知県瀬戸市八床町');
ok($zip->set_number('4801207')->is_valid_number, '愛知県瀬戸市品野町');
ok($zip->set_number('4801211')->is_valid_number, '愛知県瀬戸市上半田川町');
ok($zip->set_number('4801212')->is_valid_number, '愛知県瀬戸市片草町');
ok($zip->set_number('4801213')->is_valid_number, '愛知県瀬戸市白岩町');
ok($zip->set_number('4801214')->is_valid_number, '愛知県瀬戸市上品野町');
ok($zip->set_number('4801215')->is_valid_number, '愛知県瀬戸市岩屋町');
ok($zip->set_number('4801216')->is_valid_number, '愛知県瀬戸市鳥原町');
ok($zip->set_number('4801217')->is_valid_number, '愛知県瀬戸市井山町');
ok($zip->set_number('4801218')->is_valid_number, '愛知県瀬戸市中品野町');
ok($zip->set_number('4801219')->is_valid_number, '愛知県瀬戸市窯町');
ok($zip->set_number('4801301')->is_valid_number, '愛知県長久手市北浦');
ok($zip->set_number('4801302')->is_valid_number, '愛知県長久手市杁ノ洞');
ok($zip->set_number('4801303')->is_valid_number, '愛知県長久手市東田');
ok($zip->set_number('4801304')->is_valid_number, '愛知県長久手市郷前');
ok($zip->set_number('4801305')->is_valid_number, '愛知県長久手市中井');
ok($zip->set_number('4801306')->is_valid_number, '愛知県長久手市真行田');
ok($zip->set_number('4801307')->is_valid_number, '愛知県長久手市立花');
ok($zip->set_number('4801308')->is_valid_number, '愛知県長久手市岩廻間');
ok($zip->set_number('4801309')->is_valid_number, '愛知県長久手市溝之杁');
ok($zip->set_number('4801311')->is_valid_number, '愛知県長久手市福井');
ok($zip->set_number('4801312')->is_valid_number, '愛知県長久手市熊張深田');
ok($zip->set_number('4801313')->is_valid_number, '愛知県長久手市小深');
ok($zip->set_number('4801314')->is_valid_number, '愛知県長久手市馬堤');
ok($zip->set_number('4801315')->is_valid_number, '愛知県長久手市東平地');
ok($zip->set_number('4801316')->is_valid_number, '愛知県長久手市平地');
ok($zip->set_number('4801317')->is_valid_number, '愛知県長久手市松杁');
ok($zip->set_number('4801318')->is_valid_number, '愛知県長久手市東山');
ok($zip->set_number('4801321')->is_valid_number, '愛知県長久手市神明');
ok($zip->set_number('4801322')->is_valid_number, '愛知県長久手市汐見坂');
ok($zip->set_number('4801323')->is_valid_number, '愛知県長久手市阿畑');
ok($zip->set_number('4801324')->is_valid_number, '愛知県長久手市段留');
ok($zip->set_number('4801325')->is_valid_number, '愛知県長久手市杁ケ根');
ok($zip->set_number('4801326')->is_valid_number, '愛知県長久手市助六');
ok($zip->set_number('4801327')->is_valid_number, '愛知県長久手市観音堂');
ok($zip->set_number('4801328')->is_valid_number, '愛知県長久手市早稲田');
ok($zip->set_number('4801329')->is_valid_number, '愛知県長久手市申平');
ok($zip->set_number('4801331')->is_valid_number, '愛知県長久手市雨堤');
ok($zip->set_number('4801332')->is_valid_number, '愛知県長久手市神門前');
ok($zip->set_number('4801333')->is_valid_number, '愛知県長久手市蛭子');
ok($zip->set_number('4801334')->is_valid_number, '愛知県長久手市榎ノ下');
ok($zip->set_number('4801335')->is_valid_number, '愛知県長久手市大日');
ok($zip->set_number('4801336')->is_valid_number, '愛知県長久手市小稲葉');
ok($zip->set_number('4801337')->is_valid_number, '愛知県長久手市中屋');
ok($zip->set_number('4801338')->is_valid_number, '愛知県長久手市下田');
ok($zip->set_number('4801339')->is_valid_number, '愛知県長久手市北熊');
ok($zip->set_number('4801341')->is_valid_number, '愛知県長久手市葭ケ廻間');
ok($zip->set_number('4801342')->is_valid_number, '愛知県長久手市茨ケ廻間');
ok($zip->set_number('4801343')->is_valid_number, '愛知県長久手市石場');
ok($zip->set_number('4801344')->is_valid_number, '愛知県長久手市広田');
ok($zip->set_number('4801345')->is_valid_number, '愛知県長久手市丸山');
ok($zip->set_number('4801346')->is_valid_number, '愛知県長久手市堂脇');
ok($zip->set_number('4801347')->is_valid_number, '愛知県長久手市鯉ケ廻間');
ok($zip->set_number('4810000')->is_valid_number, '愛知県北名古屋市以下に掲載がない場合');
ok($zip->set_number('4810001')->is_valid_number, '愛知県北名古屋市六ツ師');
ok($zip->set_number('4810002')->is_valid_number, '愛知県北名古屋市片場');
ok($zip->set_number('4810003')->is_valid_number, '愛知県北名古屋市能田');
ok($zip->set_number('4810004')->is_valid_number, '愛知県北名古屋市鹿田');
ok($zip->set_number('4810005')->is_valid_number, '愛知県北名古屋市薬師寺');
ok($zip->set_number('4810006')->is_valid_number, '愛知県北名古屋市熊之庄');
ok($zip->set_number('4810011')->is_valid_number, '愛知県北名古屋市高田寺');
ok($zip->set_number('4810012')->is_valid_number, '愛知県北名古屋市久地野');
ok($zip->set_number('4810013')->is_valid_number, '愛知県北名古屋市二子');
ok($zip->set_number('4810014')->is_valid_number, '愛知県北名古屋市井瀬木');
ok($zip->set_number('4810031')->is_valid_number, '愛知県北名古屋市弥勒寺東');
ok($zip->set_number('4810032')->is_valid_number, '愛知県北名古屋市弥勒寺西');
ok($zip->set_number('4810033')->is_valid_number, '愛知県北名古屋市西之保');
ok($zip->set_number('4810034')->is_valid_number, '愛知県北名古屋市北野');
ok($zip->set_number('4810035')->is_valid_number, '愛知県北名古屋市宇福寺');
ok($zip->set_number('4810036')->is_valid_number, '愛知県北名古屋市山之腰');
ok($zip->set_number('4810037')->is_valid_number, '愛知県北名古屋市鍜治ケ一色');
ok($zip->set_number('4810038')->is_valid_number, '愛知県北名古屋市徳重');
ok($zip->set_number('4810039')->is_valid_number, '愛知県北名古屋市法成寺');
ok($zip->set_number('4810040')->is_valid_number, '愛知県北名古屋市西春駅前');
ok($zip->set_number('4810041')->is_valid_number, '愛知県北名古屋市九之坪');
ok($zip->set_number('4810042')->is_valid_number, '愛知県北名古屋市野崎');
ok($zip->set_number('4810043')->is_valid_number, '愛知県北名古屋市沖村');
ok($zip->set_number('4810044')->is_valid_number, '愛知県北名古屋市加島新田');
ok($zip->set_number('4810045')->is_valid_number, '愛知県北名古屋市中之郷');
ok($zip->set_number('4810046')->is_valid_number, '愛知県北名古屋市石橋');
ok($zip->set_number('4820000')->is_valid_number, '愛知県岩倉市以下に掲載がない場合');
ok($zip->set_number('4820001')->is_valid_number, '愛知県岩倉市東新町');
ok($zip->set_number('4820002')->is_valid_number, '愛知県岩倉市大市場町');
ok($zip->set_number('4820003')->is_valid_number, '愛知県岩倉市曽野町');
ok($zip->set_number('4820004')->is_valid_number, '愛知県岩倉市五条町');
ok($zip->set_number('4820005')->is_valid_number, '愛知県岩倉市下本町');
ok($zip->set_number('4820006')->is_valid_number, '愛知県岩倉市稲荷町羽根');
ok($zip->set_number('4820007')->is_valid_number, '愛知県岩倉市大山寺元町');
ok($zip->set_number('4820011')->is_valid_number, '愛知県岩倉市昭和町');
ok($zip->set_number('4820012')->is_valid_number, '愛知県岩倉市稲荷町');
ok($zip->set_number('4820013')->is_valid_number, '愛知県岩倉市南新町');
ok($zip->set_number('4820014')->is_valid_number, '愛知県岩倉市大山寺町');
ok($zip->set_number('4820015')->is_valid_number, '愛知県岩倉市川井町');
ok($zip->set_number('4820016')->is_valid_number, '愛知県岩倉市野寄町');
ok($zip->set_number('4820017')->is_valid_number, '愛知県岩倉市北島町');
ok($zip->set_number('4820018')->is_valid_number, '愛知県岩倉市大山寺本町');
ok($zip->set_number('4820021')->is_valid_number, '愛知県岩倉市新柳町');
ok($zip->set_number('4820022')->is_valid_number, '愛知県岩倉市栄町');
ok($zip->set_number('4820023')->is_valid_number, '愛知県岩倉市中央町');
ok($zip->set_number('4820024')->is_valid_number, '愛知県岩倉市旭町');
ok($zip->set_number('4820025')->is_valid_number, '愛知県岩倉市大地新町');
ok($zip->set_number('4820026')->is_valid_number, '愛知県岩倉市大地町');
ok($zip->set_number('4820031')->is_valid_number, '愛知県岩倉市八剱町');
ok($zip->set_number('4820032')->is_valid_number, '愛知県岩倉市井上町');
ok($zip->set_number('4820033')->is_valid_number, '愛知県岩倉市神野町');
ok($zip->set_number('4820034')->is_valid_number, '愛知県岩倉市石仏町');
ok($zip->set_number('4820035')->is_valid_number, '愛知県岩倉市鈴井町');
ok($zip->set_number('4820036')->is_valid_number, '愛知県岩倉市西市町');
ok($zip->set_number('4820041')->is_valid_number, '愛知県岩倉市東町');
ok($zip->set_number('4820042')->is_valid_number, '愛知県岩倉市中本町');
ok($zip->set_number('4820043')->is_valid_number, '愛知県岩倉市本町');
ok($zip->set_number('4820044')->is_valid_number, '愛知県岩倉市宮前町');
ok($zip->set_number('4820045')->is_valid_number, '愛知県岩倉市泉町');
ok($zip->set_number('4820046')->is_valid_number, '愛知県岩倉市中野町');
ok($zip->set_number('4830000')->is_valid_number, '愛知県江南市以下に掲載がない場合');
ok($zip->set_number('4838001')->is_valid_number, '愛知県江南市中般若町東');
ok($zip->set_number('4838002')->is_valid_number, '愛知県江南市中般若町西');
ok($zip->set_number('4838003')->is_valid_number, '愛知県江南市草井町大野');
ok($zip->set_number('4838003')->is_valid_number, '愛知県江南市中般若町(川端、北浦)');
ok($zip->set_number('4838004')->is_valid_number, '愛知県江南市草井町宮東');
ok($zip->set_number('4838005')->is_valid_number, '愛知県江南市草井町宮西');
ok($zip->set_number('4838006')->is_valid_number, '愛知県江南市草井町中');
ok($zip->set_number('4838007')->is_valid_number, '愛知県江南市草井町西');
ok($zip->set_number('4838008')->is_valid_number, '愛知県江南市鹿子島町');
ok($zip->set_number('4838011')->is_valid_number, '愛知県江南市般若町宮山');
ok($zip->set_number('4838012')->is_valid_number, '愛知県江南市般若町東山');
ok($zip->set_number('4838013')->is_valid_number, '愛知県江南市般若町南山');
ok($zip->set_number('4838014')->is_valid_number, '愛知県江南市和田町川東');
ok($zip->set_number('4838015')->is_valid_number, '愛知県江南市和田町中島');
ok($zip->set_number('4838016')->is_valid_number, '愛知県江南市和田町西島');
ok($zip->set_number('4838017')->is_valid_number, '愛知県江南市般若町前山');
ok($zip->set_number('4838018')->is_valid_number, '愛知県江南市般若町中山');
ok($zip->set_number('4838021')->is_valid_number, '愛知県江南市和田町小島');
ok($zip->set_number('4838022')->is_valid_number, '愛知県江南市和田町旭');
ok($zip->set_number('4838023')->is_valid_number, '愛知県江南市和田町二タ子');
ok($zip->set_number('4838024')->is_valid_number, '愛知県江南市和田町天神');
ok($zip->set_number('4838025')->is_valid_number, '愛知県江南市和田町宮');
ok($zip->set_number('4838026')->is_valid_number, '愛知県江南市和田町中畑');
ok($zip->set_number('4838027')->is_valid_number, '愛知県江南市和田町本郷');
ok($zip->set_number('4838028')->is_valid_number, '愛知県江南市和田町中');
ok($zip->set_number('4838029')->is_valid_number, '愛知県江南市和田町栄');
ok($zip->set_number('4838031')->is_valid_number, '愛知県江南市山尻町朝日');
ok($zip->set_number('4838032')->is_valid_number, '愛知県江南市山尻町大桑');
ok($zip->set_number('4838033')->is_valid_number, '愛知県江南市山尻町川端');
ok($zip->set_number('4838034')->is_valid_number, '愛知県江南市江森町西');
ok($zip->set_number('4838035')->is_valid_number, '愛知県江南市高屋町大門');
ok($zip->set_number('4838036')->is_valid_number, '愛知県江南市山尻町本丸西');
ok($zip->set_number('4838037')->is_valid_number, '愛知県江南市勝佐町');
ok($zip->set_number('4838038')->is_valid_number, '愛知県江南市山尻町本丸');
ok($zip->set_number('4838041')->is_valid_number, '愛知県江南市江森町上');
ok($zip->set_number('4838042')->is_valid_number, '愛知県江南市江森町東');
ok($zip->set_number('4838043')->is_valid_number, '愛知県江南市江森町南');
ok($zip->set_number('4838044')->is_valid_number, '愛知県江南市宮後町');
ok($zip->set_number('4838045')->is_valid_number, '愛知県江南市高屋町遠場');
ok($zip->set_number('4838046')->is_valid_number, '愛知県江南市高屋町花戸');
ok($zip->set_number('4838047')->is_valid_number, '愛知県江南市高屋町大師');
ok($zip->set_number('4838048')->is_valid_number, '愛知県江南市江森町中');
ok($zip->set_number('4838051')->is_valid_number, '愛知県江南市前野町新田北');
ok($zip->set_number('4838052')->is_valid_number, '愛知県江南市前野町東');
ok($zip->set_number('4838053')->is_valid_number, '愛知県江南市前野町高島');
ok($zip->set_number('4838054')->is_valid_number, '愛知県江南市前野町南');
ok($zip->set_number('4838055')->is_valid_number, '愛知県江南市山王町');
ok($zip->set_number('4838056')->is_valid_number, '愛知県江南市宮後町清水');
ok($zip->set_number('4838057')->is_valid_number, '愛知県江南市前野町新田');
ok($zip->set_number('4838058')->is_valid_number, '愛知県江南市前野町西');
ok($zip->set_number('4838061')->is_valid_number, '愛知県江南市高屋町清水');
ok($zip->set_number('4838062')->is_valid_number, '愛知県江南市高屋町神戸');
ok($zip->set_number('4838063')->is_valid_number, '愛知県江南市高屋町八幡');
ok($zip->set_number('4838064')->is_valid_number, '愛知県江南市高屋町十六田');
ok($zip->set_number('4838065')->is_valid_number, '愛知県江南市高屋町旭');
ok($zip->set_number('4838066')->is_valid_number, '愛知県江南市高屋町西町');
ok($zip->set_number('4838067')->is_valid_number, '愛知県江南市飛高町中町');
ok($zip->set_number('4838068')->is_valid_number, '愛知県江南市飛高町本町');
ok($zip->set_number('4838069')->is_valid_number, '愛知県江南市飛高町宮町');
ok($zip->set_number('4838071')->is_valid_number, '愛知県江南市草井町中野');
ok($zip->set_number('4838072')->is_valid_number, '愛知県江南市草井町若草');
ok($zip->set_number('4838074')->is_valid_number, '愛知県江南市村久野町平松');
ok($zip->set_number('4838075')->is_valid_number, '愛知県江南市村久野町平河');
ok($zip->set_number('4838076')->is_valid_number, '愛知県江南市村久野町上原');
ok($zip->set_number('4838077')->is_valid_number, '愛知県江南市草井町(南、榊戸、千代見)');
ok($zip->set_number('4838081')->is_valid_number, '愛知県江南市高屋町上本郷');
ok($zip->set_number('4838082')->is_valid_number, '愛知県江南市高屋町本郷');
ok($zip->set_number('4838083')->is_valid_number, '愛知県江南市高屋町中屋舗');
ok($zip->set_number('4838084')->is_valid_number, '愛知県江南市高屋町御日塚');
ok($zip->set_number('4838085')->is_valid_number, '愛知県江南市高屋町西里');
ok($zip->set_number('4838086')->is_valid_number, '愛知県江南市高屋町大松原');
ok($zip->set_number('4838087')->is_valid_number, '愛知県江南市高屋町北上');
ok($zip->set_number('4838088')->is_valid_number, '愛知県江南市高屋町後山');
ok($zip->set_number('4838101')->is_valid_number, '愛知県江南市力長町観音寺');
ok($zip->set_number('4838102')->is_valid_number, '愛知県江南市力長町若宮');
ok($zip->set_number('4838103')->is_valid_number, '愛知県江南市力長町宮前');
ok($zip->set_number('4838104')->is_valid_number, '愛知県江南市力長町大当寺');
ok($zip->set_number('4838105')->is_valid_number, '愛知県江南市力長町社宮司');
ok($zip->set_number('4838106')->is_valid_number, '愛知県江南市石枕町神明');
ok($zip->set_number('4838107')->is_valid_number, '愛知県江南市石枕町白山');
ok($zip->set_number('4838108')->is_valid_number, '愛知県江南市力長町神明');
ok($zip->set_number('4838109')->is_valid_number, '愛知県江南市力長町神出');
ok($zip->set_number('4838111')->is_valid_number, '愛知県江南市安良町地蔵');
ok($zip->set_number('4838112')->is_valid_number, '愛知県江南市安良町池尻');
ok($zip->set_number('4838113')->is_valid_number, '愛知県江南市天王町五反林');
ok($zip->set_number('4838114')->is_valid_number, '愛知県江南市天王町駒野');
ok($zip->set_number('4838115')->is_valid_number, '愛知県江南市安良町宮前');
ok($zip->set_number('4838116')->is_valid_number, '愛知県江南市安良町八王子');
ok($zip->set_number('4838117')->is_valid_number, '愛知県江南市安良町上郷');
ok($zip->set_number('4838118')->is_valid_number, '愛知県江南市安良町郷中');
ok($zip->set_number('4838121')->is_valid_number, '愛知県江南市曽本町二子');
ok($zip->set_number('4838122')->is_valid_number, '愛知県江南市曽本町二子前');
ok($zip->set_number('4838123')->is_valid_number, '愛知県江南市曽本町幼川添');
ok($zip->set_number('4838124')->is_valid_number, '愛知県江南市小折本町白山');
ok($zip->set_number('4838125')->is_valid_number, '愛知県江南市小折東町旭');
ok($zip->set_number('4838126')->is_valid_number, '愛知県江南市小折本町栄');
ok($zip->set_number('4838127')->is_valid_number, '愛知県江南市小折本町小松原');
ok($zip->set_number('4838128')->is_valid_number, '愛知県江南市小折本町柳橋');
ok($zip->set_number('4838131')->is_valid_number, '愛知県江南市小折町(八反畑)');
ok($zip->set_number('4838132')->is_valid_number, '愛知県江南市田代町南出');
ok($zip->set_number('4838133')->is_valid_number, '愛知県江南市田代町西ノ丸');
ok($zip->set_number('4838134')->is_valid_number, '愛知県江南市小折町(八竜西)');
ok($zip->set_number('4838135')->is_valid_number, '愛知県江南市小郷町粟田木');
ok($zip->set_number('4838136')->is_valid_number, '愛知県江南市小折町(桜雲)');
ok($zip->set_number('4838137')->is_valid_number, '愛知県江南市小折町(八竜)');
ok($zip->set_number('4838138')->is_valid_number, '愛知県江南市田代町郷中');
ok($zip->set_number('4838141')->is_valid_number, '愛知県江南市布袋町西布');
ok($zip->set_number('4838142')->is_valid_number, '愛知県江南市布袋下山町東');
ok($zip->set_number('4838143')->is_valid_number, '愛知県江南市小郷町伍大力');
ok($zip->set_number('4838144')->is_valid_number, '愛知県江南市小郷町楽ノ山');
ok($zip->set_number('4838145')->is_valid_number, '愛知県江南市小郷町西ノ山');
ok($zip->set_number('4838146')->is_valid_number, '愛知県江南市布袋下山町西');
ok($zip->set_number('4838147')->is_valid_number, '愛知県江南市布袋下山町北');
ok($zip->set_number('4838148')->is_valid_number, '愛知県江南市布袋下山町南');
ok($zip->set_number('4838149')->is_valid_number, '愛知県江南市小郷町手保ノ木');
ok($zip->set_number('4838151')->is_valid_number, '愛知県江南市寄木町白山');
ok($zip->set_number('4838152')->is_valid_number, '愛知県江南市寄木町稲木');
ok($zip->set_number('4838153')->is_valid_number, '愛知県江南市北山町東');
ok($zip->set_number('4838154')->is_valid_number, '愛知県江南市南山町東');
ok($zip->set_number('4838155')->is_valid_number, '愛知県江南市南山町中');
ok($zip->set_number('4838156')->is_valid_number, '愛知県江南市南山町西');
ok($zip->set_number('4838157')->is_valid_number, '愛知県江南市北山町西');
ok($zip->set_number('4838158')->is_valid_number, '愛知県江南市布袋町東');
ok($zip->set_number('4838159')->is_valid_number, '愛知県江南市寄木町秋葉');
ok($zip->set_number('4838161')->is_valid_number, '愛知県江南市尾崎町上田');
ok($zip->set_number('4838162')->is_valid_number, '愛知県江南市尾崎町河原');
ok($zip->set_number('4838163')->is_valid_number, '愛知県江南市木賀東町新宮');
ok($zip->set_number('4838164')->is_valid_number, '愛知県江南市木賀東町新塚');
ok($zip->set_number('4838165')->is_valid_number, '愛知県江南市赤童子町福住');
ok($zip->set_number('4838166')->is_valid_number, '愛知県江南市赤童子町南山');
ok($zip->set_number('4838167')->is_valid_number, '愛知県江南市赤童子町南野');
ok($zip->set_number('4838168')->is_valid_number, '愛知県江南市尾崎町屋敷');
ok($zip->set_number('4838171')->is_valid_number, '愛知県江南市尾崎町若竹');
ok($zip->set_number('4838172')->is_valid_number, '愛知県江南市尾崎町白山');
ok($zip->set_number('4838173')->is_valid_number, '愛知県江南市尾崎町桐野');
ok($zip->set_number('4838174')->is_valid_number, '愛知県江南市北野町小松');
ok($zip->set_number('4838175')->is_valid_number, '愛知県江南市北野町天神');
ok($zip->set_number('4838176')->is_valid_number, '愛知県江南市北野町(旭、郷浦)');
ok($zip->set_number('4838177')->is_valid_number, '愛知県江南市北野町川石');
ok($zip->set_number('4838181')->is_valid_number, '愛知県江南市今市場町秋津');
ok($zip->set_number('4838182')->is_valid_number, '愛知県江南市今市場町宮前');
ok($zip->set_number('4838183')->is_valid_number, '愛知県江南市今市場町高根');
ok($zip->set_number('4838184')->is_valid_number, '愛知県江南市寄木町天道');
ok($zip->set_number('4838185')->is_valid_number, '愛知県江南市大海道町神明');
ok($zip->set_number('4838186')->is_valid_number, '愛知県江南市大海道町中里');
ok($zip->set_number('4838187')->is_valid_number, '愛知県江南市大海道町青木');
ok($zip->set_number('4838188')->is_valid_number, '愛知県江南市今市場町美和');
ok($zip->set_number('4838201')->is_valid_number, '愛知県江南市野白町葭場');
ok($zip->set_number('4838202')->is_valid_number, '愛知県江南市野白町野白');
ok($zip->set_number('4838203')->is_valid_number, '愛知県江南市野白町西千丸');
ok($zip->set_number('4838204')->is_valid_number, '愛知県江南市野白町東千丸');
ok($zip->set_number('4838205')->is_valid_number, '愛知県江南市古知野町小金');
ok($zip->set_number('4838206')->is_valid_number, '愛知県江南市古知野町千丸');
ok($zip->set_number('4838207')->is_valid_number, '愛知県江南市古知野町熱田');
ok($zip->set_number('4838208')->is_valid_number, '愛知県江南市古知野町花霞');
ok($zip->set_number('4838211')->is_valid_number, '愛知県江南市古知野町杉山');
ok($zip->set_number('4838212')->is_valid_number, '愛知県江南市古知野町瑞穂');
ok($zip->set_number('4838213')->is_valid_number, '愛知県江南市古知野町朝日');
ok($zip->set_number('4838214')->is_valid_number, '愛知県江南市古知野町日の出');
ok($zip->set_number('4838215')->is_valid_number, '愛知県江南市古知野町大塔');
ok($zip->set_number('4838216')->is_valid_number, '愛知県江南市古知野町塔塚');
ok($zip->set_number('4838217')->is_valid_number, '愛知県江南市古知野町古渡');
ok($zip->set_number('4838221')->is_valid_number, '愛知県江南市赤童子町大堀');
ok($zip->set_number('4838222')->is_valid_number, '愛知県江南市赤童子町藤宮');
ok($zip->set_number('4838223')->is_valid_number, '愛知県江南市赤童子町御宿');
ok($zip->set_number('4838224')->is_valid_number, '愛知県江南市赤童子町白山');
ok($zip->set_number('4838225')->is_valid_number, '愛知県江南市赤童子町栄');
ok($zip->set_number('4838226')->is_valid_number, '愛知県江南市赤童子町大間');
ok($zip->set_number('4838227')->is_valid_number, '愛知県江南市赤童子町良原');
ok($zip->set_number('4838228')->is_valid_number, '愛知県江南市赤童子町桜道');
ok($zip->set_number('4838231')->is_valid_number, '愛知県江南市木賀本郷町東');
ok($zip->set_number('4838232')->is_valid_number, '愛知県江南市木賀本郷町緑');
ok($zip->set_number('4838233')->is_valid_number, '愛知県江南市木賀町大門');
ok($zip->set_number('4838234')->is_valid_number, '愛知県江南市布袋町北');
ok($zip->set_number('4838235')->is_valid_number, '愛知県江南市布袋町中');
ok($zip->set_number('4838236')->is_valid_number, '愛知県江南市布袋町南');
ok($zip->set_number('4838237')->is_valid_number, '愛知県江南市布袋町西');
ok($zip->set_number('4838238')->is_valid_number, '愛知県江南市木賀本郷町南');
ok($zip->set_number('4838239')->is_valid_number, '愛知県江南市木賀本郷町西');
ok($zip->set_number('4838241')->is_valid_number, '愛知県江南市五明町青木');
ok($zip->set_number('4838242')->is_valid_number, '愛知県江南市五明町根場');
ok($zip->set_number('4838243')->is_valid_number, '愛知県江南市五明町石橋');
ok($zip->set_number('4838244')->is_valid_number, '愛知県江南市五明町高砂');
ok($zip->set_number('4838245')->is_valid_number, '愛知県江南市五明町大膳');
ok($zip->set_number('4838246')->is_valid_number, '愛知県江南市五明町福森');
ok($zip->set_number('4838247')->is_valid_number, '愛知県江南市五明町太子堂');
ok($zip->set_number('4838248')->is_valid_number, '愛知県江南市五明町天王');
ok($zip->set_number('4838249')->is_valid_number, '愛知県江南市五明町当光地');
ok($zip->set_number('4838251')->is_valid_number, '愛知県江南市大間町新町');
ok($zip->set_number('4838252')->is_valid_number, '愛知県江南市大間町南大間');
ok($zip->set_number('4838253')->is_valid_number, '愛知県江南市木賀町杉');
ok($zip->set_number('4838254')->is_valid_number, '愛知県江南市木賀町新開');
ok($zip->set_number('4838255')->is_valid_number, '愛知県江南市木賀町定和');
ok($zip->set_number('4838256')->is_valid_number, '愛知県江南市中奈良町');
ok($zip->set_number('4838257')->is_valid_number, '愛知県江南市上奈良町(神明、豊里)');
ok($zip->set_number('4838258')->is_valid_number, '愛知県江南市上奈良町(瑞穂、観音寺、久保、郷)');
ok($zip->set_number('4838259')->is_valid_number, '愛知県江南市上奈良町(栄、旭、錦、天王、緑)');
ok($zip->set_number('4838262')->is_valid_number, '愛知県江南市島宮町吉原');
ok($zip->set_number('4838263')->is_valid_number, '愛知県江南市島宮町桐野');
ok($zip->set_number('4838264')->is_valid_number, '愛知県江南市島宮町城');
ok($zip->set_number('4838265')->is_valid_number, '愛知県江南市島宮町四日市場');
ok($zip->set_number('4838266')->is_valid_number, '愛知県江南市島宮町西之宮');
ok($zip->set_number('4838267')->is_valid_number, '愛知県江南市島宮町郷内');
ok($zip->set_number('4838268')->is_valid_number, '愛知県江南市島宮町水堀');
ok($zip->set_number('4838269')->is_valid_number, '愛知県江南市島宮町巡見');
ok($zip->set_number('4838271')->is_valid_number, '愛知県江南市古知野町桃源');
ok($zip->set_number('4838272')->is_valid_number, '愛知県江南市古知野町北屋敷');
ok($zip->set_number('4838273')->is_valid_number, '愛知県江南市古知野町本郷');
ok($zip->set_number('4838274')->is_valid_number, '愛知県江南市古知野町広見');
ok($zip->set_number('4838275')->is_valid_number, '愛知県江南市古知野町久保見');
ok($zip->set_number('4838276')->is_valid_number, '愛知県江南市古知野町宮前');
ok($zip->set_number('4838277')->is_valid_number, '愛知県江南市古知野町福寿');
ok($zip->set_number('4838278')->is_valid_number, '愛知県江南市古知野町牧森');
ok($zip->set_number('4838279')->is_valid_number, '愛知県江南市古知野町宮裏');
ok($zip->set_number('4838301')->is_valid_number, '愛知県江南市宮田神明町緑');
ok($zip->set_number('4838302')->is_valid_number, '愛知県江南市宮田神明町天王');
ok($zip->set_number('4838303')->is_valid_number, '愛知県江南市宮田神明町旭');
ok($zip->set_number('4838304')->is_valid_number, '愛知県江南市宮田神明町栄');
ok($zip->set_number('4838305')->is_valid_number, '愛知県江南市宮田町生原');
ok($zip->set_number('4838306')->is_valid_number, '愛知県江南市宮田町中島');
ok($zip->set_number('4838307')->is_valid_number, '愛知県江南市宮田町新田');
ok($zip->set_number('4838308')->is_valid_number, '愛知県江南市宮田神明町春日');
ok($zip->set_number('4838311')->is_valid_number, '愛知県江南市村久野町九郷');
ok($zip->set_number('4838312')->is_valid_number, '愛知県江南市村久野町金森');
ok($zip->set_number('4838313')->is_valid_number, '愛知県江南市村久野町中郷');
ok($zip->set_number('4838314')->is_valid_number, '愛知県江南市村久野町寺町');
ok($zip->set_number('4838315')->is_valid_number, '愛知県江南市村久野町大門');
ok($zip->set_number('4838316')->is_valid_number, '愛知県江南市村久野町河戸');
ok($zip->set_number('4838317')->is_valid_number, '愛知県江南市村久野町藤里');
ok($zip->set_number('4838318')->is_valid_number, '愛知県江南市村久野町宮出');
ok($zip->set_number('4838319')->is_valid_number, '愛知県江南市村久野町寺東');
ok($zip->set_number('4838321')->is_valid_number, '愛知県江南市村久野町瀬頭');
ok($zip->set_number('4838322')->is_valid_number, '愛知県江南市村久野町鳥附');
ok($zip->set_number('4838323')->is_valid_number, '愛知県江南市村久野町門弟山');
ok($zip->set_number('4838324')->is_valid_number, '愛知県江南市村久野町南大門');
ok($zip->set_number('4838325')->is_valid_number, '愛知県江南市村久野町冨士塚');
ok($zip->set_number('4838326')->is_valid_number, '愛知県江南市村久野町仲原');
ok($zip->set_number('4838327')->is_valid_number, '愛知県江南市村久野町平野');
ok($zip->set_number('4838328')->is_valid_number, '愛知県江南市村久野町鈴道');
ok($zip->set_number('4838331')->is_valid_number, '愛知県江南市古知野町高瀬');
ok($zip->set_number('4838332')->is_valid_number, '愛知県江南市飛高町門野');
ok($zip->set_number('4838333')->is_valid_number, '愛知県江南市飛高町泉');
ok($zip->set_number('4838334')->is_valid_number, '愛知県江南市前飛保町緑ケ丘');
ok($zip->set_number('4838335')->is_valid_number, '愛知県江南市前飛保町寺前');
ok($zip->set_number('4838336')->is_valid_number, '愛知県江南市前飛保町寺町');
ok($zip->set_number('4838337')->is_valid_number, '愛知県江南市藤ケ丘');
ok($zip->set_number('4838338')->is_valid_number, '愛知県江南市前飛保町藤町');
ok($zip->set_number('4838339')->is_valid_number, '愛知県江南市飛高町(夫見添、栄)');
ok($zip->set_number('4838341')->is_valid_number, '愛知県江南市前飛保町栄');
ok($zip->set_number('4838342')->is_valid_number, '愛知県江南市松竹町上野');
ok($zip->set_number('4838343')->is_valid_number, '愛知県江南市松竹町米野');
ok($zip->set_number('4838344')->is_valid_number, '愛知県江南市後飛保町東高瀬');
ok($zip->set_number('4838345')->is_valid_number, '愛知県江南市後飛保町高瀬');
ok($zip->set_number('4838346')->is_valid_number, '愛知県江南市後飛保町平野');
ok($zip->set_number('4838347')->is_valid_number, '愛知県江南市後飛保町神明野');
ok($zip->set_number('4838348')->is_valid_number, '愛知県江南市前飛保町河原');
ok($zip->set_number('4838349')->is_valid_number, '愛知県江南市前飛保町西町');
ok($zip->set_number('4838351')->is_valid_number, '愛知県江南市松竹町切野');
ok($zip->set_number('4838352')->is_valid_number, '愛知県江南市松竹町高山');
ok($zip->set_number('4838353')->is_valid_number, '愛知県江南市松竹町元屋敷');
ok($zip->set_number('4838354')->is_valid_number, '愛知県江南市松竹町八幡');
ok($zip->set_number('4838355')->is_valid_number, '愛知県江南市松竹町西瀬古');
ok($zip->set_number('4838356')->is_valid_number, '愛知県江南市松竹町西松竹');
ok($zip->set_number('4838357')->is_valid_number, '愛知県江南市松竹町向島');
ok($zip->set_number('4838358')->is_valid_number, '愛知県江南市松竹町郷浦');
ok($zip->set_number('4838359')->is_valid_number, '愛知県江南市松竹町東瀬古');
ok($zip->set_number('4838361')->is_valid_number, '愛知県江南市宮田町平和');
ok($zip->set_number('4838362')->is_valid_number, '愛知県江南市河野町小脇');
ok($zip->set_number('4838363')->is_valid_number, '愛知県江南市河野町五十間');
ok($zip->set_number('4838364')->is_valid_number, '愛知県江南市河野町川西');
ok($zip->set_number('4838365')->is_valid_number, '愛知県江南市河野町一色');
ok($zip->set_number('4838366')->is_valid_number, '愛知県江南市河野町管竹');
ok($zip->set_number('4838367')->is_valid_number, '愛知県江南市宮田町南野');
ok($zip->set_number('4838368')->is_valid_number, '愛知県江南市宮田町南野東');
ok($zip->set_number('4838369')->is_valid_number, '愛知県江南市河野町河野');
ok($zip->set_number('4838371')->is_valid_number, '愛知県江南市宮田町河沼');
ok($zip->set_number('4838372')->is_valid_number, '愛知県江南市宮田町宮東');
ok($zip->set_number('4838373')->is_valid_number, '愛知県江南市宮田町菖蒲池');
ok($zip->set_number('4838374')->is_valid_number, '愛知県江南市宮田町久保見');
ok($zip->set_number('4838375')->is_valid_number, '愛知県江南市宮田町泉');
ok($zip->set_number('4838376')->is_valid_number, '愛知県江南市宮田町藤ノ森');
ok($zip->set_number('4838377')->is_valid_number, '愛知県江南市宮田町本田島');
ok($zip->set_number('4838378')->is_valid_number, '愛知県江南市宮田町四ツ谷');
ok($zip->set_number('4838379')->is_valid_number, '愛知県江南市宮田町本郷');
ok($zip->set_number('4838381')->is_valid_number, '愛知県江南市後飛保町出島');
ok($zip->set_number('4838382')->is_valid_number, '愛知県江南市後飛保町薬師');
ok($zip->set_number('4838383')->is_valid_number, '愛知県江南市後飛保町前川');
ok($zip->set_number('4838384')->is_valid_number, '愛知県江南市後飛保町宮前');
ok($zip->set_number('4838385')->is_valid_number, '愛知県江南市後飛保町中町');
ok($zip->set_number('4838386')->is_valid_number, '愛知県江南市後飛保町西町');
ok($zip->set_number('4838387')->is_valid_number, '愛知県江南市後飛保町新開');
ok($zip->set_number('4838388')->is_valid_number, '愛知県江南市後飛保町本郷');
ok($zip->set_number('4838389')->is_valid_number, '愛知県江南市後飛保町両家');
ok($zip->set_number('4838401')->is_valid_number, '愛知県江南市慈光堂町北');
ok($zip->set_number('4838402')->is_valid_number, '愛知県江南市慈光堂町南');
ok($zip->set_number('4838403')->is_valid_number, '愛知県江南市小杁町千代見');
ok($zip->set_number('4838404')->is_valid_number, '愛知県江南市小杁町林');
ok($zip->set_number('4838405')->is_valid_number, '愛知県江南市小杁町鴨ケ池');
ok($zip->set_number('4838406')->is_valid_number, '愛知県江南市小脇町小脇');
ok($zip->set_number('4838407')->is_valid_number, '愛知県江南市小杁町明土');
ok($zip->set_number('4838408')->is_valid_number, '愛知県江南市小杁町長者毛東');
ok($zip->set_number('4838409')->is_valid_number, '愛知県江南市小杁町長者毛西');
ok($zip->set_number('4838411')->is_valid_number, '愛知県江南市小杁町八幡');
ok($zip->set_number('4838412')->is_valid_number, '愛知県江南市小杁町寺ノ内');
ok($zip->set_number('4838413')->is_valid_number, '愛知県江南市小杁町本郷');
ok($zip->set_number('4838414')->is_valid_number, '愛知県江南市小杁町一色');
ok($zip->set_number('4838415')->is_valid_number, '愛知県江南市東野町鐘鋳山');
ok($zip->set_number('4838416')->is_valid_number, '愛知県江南市東野町長幡寺');
ok($zip->set_number('4838417')->is_valid_number, '愛知県江南市東野町烏森');
ok($zip->set_number('4838418')->is_valid_number, '愛知県江南市東野町米野');
ok($zip->set_number('4838419')->is_valid_number, '愛知県江南市東野町七社宮');
ok($zip->set_number('4838421')->is_valid_number, '愛知県江南市東野町郷前');
ok($zip->set_number('4838422')->is_valid_number, '愛知県江南市東野町神上');
ok($zip->set_number('4838423')->is_valid_number, '愛知県江南市東野町郷前西');
ok($zip->set_number('4838424')->is_valid_number, '愛知県江南市東野町西出');
ok($zip->set_number('4838425')->is_valid_number, '愛知県江南市東野町河戸');
ok($zip->set_number('4838426')->is_valid_number, '愛知県江南市東野町河原');
ok($zip->set_number('4838427')->is_valid_number, '愛知県江南市東野町新田');
ok($zip->set_number('4838428')->is_valid_number, '愛知県江南市東野町新田東');
ok($zip->set_number('4838429')->is_valid_number, '愛知県江南市東野町西神田');
ok($zip->set_number('4838431')->is_valid_number, '愛知県江南市東野町神田');
ok($zip->set_number('4838432')->is_valid_number, '愛知県江南市東野町東神田');
ok($zip->set_number('4838433')->is_valid_number, '愛知県江南市東野町岩見');
ok($zip->set_number('4840000')->is_valid_number, '愛知県犬山市以下に掲載がない場合');
ok($zip->set_number('4840001')->is_valid_number, '愛知県犬山市垣ノ内');
ok($zip->set_number('4840002')->is_valid_number, '愛知県犬山市栗栖');
ok($zip->set_number('4840003')->is_valid_number, '愛知県犬山市善師野');
ok($zip->set_number('4840004')->is_valid_number, '愛知県犬山市善師野台');
ok($zip->set_number('4840005')->is_valid_number, '愛知県犬山市今井');
ok($zip->set_number('4840006')->is_valid_number, '愛知県犬山市八曽');
ok($zip->set_number('4840007')->is_valid_number, '愛知県犬山市十三塚');
ok($zip->set_number('4840008')->is_valid_number, '愛知県犬山市岩穴');
ok($zip->set_number('4840009')->is_valid_number, '愛知県犬山市田口');
ok($zip->set_number('4840011')->is_valid_number, '愛知県犬山市北高根');
ok($zip->set_number('4840012')->is_valid_number, '愛知県犬山市南高根');
ok($zip->set_number('4840013')->is_valid_number, '愛知県犬山市寺洞');
ok($zip->set_number('4840014')->is_valid_number, '愛知県犬山市郷中');
ok($zip->set_number('4840015')->is_valid_number, '愛知県犬山市御殿屋敷');
ok($zip->set_number('4840016')->is_valid_number, '愛知県犬山市藪ケ洞');
ok($zip->set_number('4840017')->is_valid_number, '愛知県犬山市篠平');
ok($zip->set_number('4840018')->is_valid_number, '愛知県犬山市佐ケ瀬');
ok($zip->set_number('4840019')->is_valid_number, '愛知県犬山市四季の丘');
ok($zip->set_number('4840020')->is_valid_number, '愛知県犬山市もえぎケ丘');
ok($zip->set_number('4840021')->is_valid_number, '愛知県犬山市杁下');
ok($zip->set_number('4840022')->is_valid_number, '愛知県犬山市白山洞');
ok($zip->set_number('4840023')->is_valid_number, '愛知県犬山市堤下');
ok($zip->set_number('4840024')->is_valid_number, '愛知県犬山市喜六屋敷');
ok($zip->set_number('4840025')->is_valid_number, '愛知県犬山市野中');
ok($zip->set_number('4840026')->is_valid_number, '愛知県犬山市内屋敷');
ok($zip->set_number('4840027')->is_valid_number, '愛知県犬山市倉曽洞');
ok($zip->set_number('4840028')->is_valid_number, '愛知県犬山市向田');
ok($zip->set_number('4840029')->is_valid_number, '愛知県犬山市西洞');
ok($zip->set_number('4840031')->is_valid_number, '愛知県犬山市東桑原');
ok($zip->set_number('4840032')->is_valid_number, '愛知県犬山市池野安楽寺');
ok($zip->set_number('4840033')->is_valid_number, '愛知県犬山市井ノ元');
ok($zip->set_number('4840034')->is_valid_number, '愛知県犬山市大洞');
ok($zip->set_number('4840035')->is_valid_number, '愛知県犬山市裏山');
ok($zip->set_number('4840036')->is_valid_number, '愛知県犬山市西桑原');
ok($zip->set_number('4840037')->is_valid_number, '愛知県犬山市西片草');
ok($zip->set_number('4840038')->is_valid_number, '愛知県犬山市東片草');
ok($zip->set_number('4840041')->is_valid_number, '愛知県犬山市長者町');
ok($zip->set_number('4840042')->is_valid_number, '愛知県犬山市二本木');
ok($zip->set_number('4840043')->is_valid_number, '愛知県犬山市上ノ田');
ok($zip->set_number('4840044')->is_valid_number, '愛知県犬山市下屋敷');
ok($zip->set_number('4840045')->is_valid_number, '愛知県犬山市仲畑');
ok($zip->set_number('4840046')->is_valid_number, '愛知県犬山市屋敷裏');
ok($zip->set_number('4840047')->is_valid_number, '愛知県犬山市内久保');
ok($zip->set_number('4840048')->is_valid_number, '愛知県犬山市楽田内久保');
ok($zip->set_number('4840049')->is_valid_number, '愛知県犬山市前田面');
ok($zip->set_number('4840051')->is_valid_number, '愛知県犬山市宮裏');
ok($zip->set_number('4840052')->is_valid_number, '愛知県犬山市早稲田');
ok($zip->set_number('4840053')->is_valid_number, '愛知県犬山市石畑');
ok($zip->set_number('4840054')->is_valid_number, '愛知県犬山市仲屋敷');
ok($zip->set_number('4840055')->is_valid_number, '愛知県犬山市牛岩');
ok($zip->set_number('4840056')->is_valid_number, '愛知県犬山市稲干場');
ok($zip->set_number('4840057')->is_valid_number, '愛知県犬山市富士山');
ok($zip->set_number('4840058')->is_valid_number, '愛知県犬山市大門');
ok($zip->set_number('4840059')->is_valid_number, '愛知県犬山市上坂町');
ok($zip->set_number('4840061')->is_valid_number, '愛知県犬山市前原');
ok($zip->set_number('4840062')->is_valid_number, '愛知県犬山市前原味鹿');
ok($zip->set_number('4840063')->is_valid_number, '愛知県犬山市前原南');
ok($zip->set_number('4840064')->is_valid_number, '愛知県犬山市前原西');
ok($zip->set_number('4840065')->is_valid_number, '愛知県犬山市五郎丸東');
ok($zip->set_number('4840066')->is_valid_number, '愛知県犬山市五郎丸');
ok($zip->set_number('4840071')->is_valid_number, '愛知県犬山市内田東町');
ok($zip->set_number('4840072')->is_valid_number, '愛知県犬山市丸山天白町');
ok($zip->set_number('4840073')->is_valid_number, '愛知県犬山市天神町');
ok($zip->set_number('4840074')->is_valid_number, '愛知県犬山市梅坪');
ok($zip->set_number('4840075')->is_valid_number, '愛知県犬山市橋爪東');
ok($zip->set_number('4840076')->is_valid_number, '愛知県犬山市橋爪');
ok($zip->set_number('4840077')->is_valid_number, '愛知県犬山市上野');
ok($zip->set_number('4840078')->is_valid_number, '愛知県犬山市上野新町');
ok($zip->set_number('4840079')->is_valid_number, '愛知県犬山市木津');
ok($zip->set_number('4840081')->is_valid_number, '愛知県犬山市犬山');
ok($zip->set_number('4840082')->is_valid_number, '愛知県犬山市北古券');
ok($zip->set_number('4840083')->is_valid_number, '愛知県犬山市東古券');
ok($zip->set_number('4840084')->is_valid_number, '愛知県犬山市南古券');
ok($zip->set_number('4840085')->is_valid_number, '愛知県犬山市西古券');
ok($zip->set_number('4840086')->is_valid_number, '愛知県犬山市松本町');
ok($zip->set_number('4840087')->is_valid_number, '愛知県犬山市中山町');
ok($zip->set_number('4840091')->is_valid_number, '愛知県犬山市継鹿尾');
ok($zip->set_number('4840092')->is_valid_number, '愛知県犬山市富岡');
ok($zip->set_number('4840093')->is_valid_number, '愛知県犬山市富岡東');
ok($zip->set_number('4840094')->is_valid_number, '愛知県犬山市塔野地');
ok($zip->set_number('4840095')->is_valid_number, '愛知県犬山市塔野地杉');
ok($zip->set_number('4840096')->is_valid_number, '愛知県犬山市塔野地西');
ok($zip->set_number('4840097')->is_valid_number, '愛知県犬山市塔野地北');
ok($zip->set_number('4840098')->is_valid_number, '愛知県犬山市富岡南');
ok($zip->set_number('4840099')->is_valid_number, '愛知県犬山市富岡新町');
ok($zip->set_number('4840801')->is_valid_number, '愛知県犬山市羽黒安戸南');
ok($zip->set_number('4840802')->is_valid_number, '愛知県犬山市羽黒安戸西');
ok($zip->set_number('4840803')->is_valid_number, '愛知県犬山市羽黒新赤坂');
ok($zip->set_number('4840804')->is_valid_number, '愛知県犬山市羽黒桜海道');
ok($zip->set_number('4840805')->is_valid_number, '愛知県犬山市羽黒新外山');
ok($zip->set_number('4840806')->is_valid_number, '愛知県犬山市羽黒朝日');
ok($zip->set_number('4840807')->is_valid_number, '愛知県犬山市羽黒鉾添');
ok($zip->set_number('4840811')->is_valid_number, '愛知県犬山市楽田長塚東');
ok($zip->set_number('4840812')->is_valid_number, '愛知県犬山市山ノ田');
ok($zip->set_number('4840813')->is_valid_number, '愛知県犬山市山ノ田腰');
ok($zip->set_number('4840814')->is_valid_number, '愛知県犬山市高根');
ok($zip->set_number('4840815')->is_valid_number, '愛知県犬山市郷東');
ok($zip->set_number('4840816')->is_valid_number, '愛知県犬山市楽田原東');
ok($zip->set_number('4840817')->is_valid_number, '愛知県犬山市郷西');
ok($zip->set_number('4840818')->is_valid_number, '愛知県犬山市北浦');
ok($zip->set_number('4840819')->is_valid_number, '愛知県犬山市楽田長塚西');
ok($zip->set_number('4840821')->is_valid_number, '愛知県犬山市山崎西');
ok($zip->set_number('4840822')->is_valid_number, '愛知県犬山市中切');
ok($zip->set_number('4840823')->is_valid_number, '愛知県犬山市北大門');
ok($zip->set_number('4840824')->is_valid_number, '愛知県犬山市北洞');
ok($zip->set_number('4840825')->is_valid_number, '愛知県犬山市常福寺洞');
ok($zip->set_number('4840826')->is_valid_number, '愛知県犬山市山ノ鼻');
ok($zip->set_number('4840827')->is_valid_number, '愛知県犬山市薬師前');
ok($zip->set_number('4840828')->is_valid_number, '愛知県犬山市薬師浦');
ok($zip->set_number('4840831')->is_valid_number, '愛知県犬山市堂屋敷');
ok($zip->set_number('4840832')->is_valid_number, '愛知県犬山市向山');
ok($zip->set_number('4840833')->is_valid_number, '愛知県犬山市宮西');
ok($zip->set_number('4840834')->is_valid_number, '愛知県犬山市宮山');
ok($zip->set_number('4840835')->is_valid_number, '愛知県犬山市蓮池');
ok($zip->set_number('4840836')->is_valid_number, '愛知県犬山市笛田');
ok($zip->set_number('4840837')->is_valid_number, '愛知県犬山市荒井');
ok($zip->set_number('4840838')->is_valid_number, '愛知県犬山市小路');
ok($zip->set_number('4840839')->is_valid_number, '愛知県犬山市桃山台');
ok($zip->set_number('4840841')->is_valid_number, '愛知県犬山市楽田小針');
ok($zip->set_number('4840842')->is_valid_number, '愛知県犬山市下小針');
ok($zip->set_number('4840843')->is_valid_number, '愛知県犬山市楽田打越');
ok($zip->set_number('4840844')->is_valid_number, '愛知県犬山市鷺山');
ok($zip->set_number('4840845')->is_valid_number, '愛知県犬山市高坪');
ok($zip->set_number('4840846')->is_valid_number, '愛知県犬山市楽田山ノ田');
ok($zip->set_number('4840851')->is_valid_number, '愛知県犬山市烏杜');
ok($zip->set_number('4840852')->is_valid_number, '愛知県犬山市中小針');
ok($zip->set_number('4840853')->is_valid_number, '愛知県犬山市横町');
ok($zip->set_number('4840854')->is_valid_number, '愛知県犬山市裏之門');
ok($zip->set_number('4840855')->is_valid_number, '愛知県犬山市小洞');
ok($zip->set_number('4840856')->is_valid_number, '愛知県犬山市楽田天神');
ok($zip->set_number('4840857')->is_valid_number, '愛知県犬山市外屋敷');
ok($zip->set_number('4840858')->is_valid_number, '愛知県犬山市城山');
ok($zip->set_number('4840861')->is_valid_number, '愛知県犬山市若宮');
ok($zip->set_number('4840862')->is_valid_number, '愛知県犬山市石塚');
ok($zip->set_number('4840863')->is_valid_number, '愛知県犬山市野田');
ok($zip->set_number('4840864')->is_valid_number, '愛知県犬山市番前');
ok($zip->set_number('4840865')->is_valid_number, '愛知県犬山市藪畔');
ok($zip->set_number('4840866')->is_valid_number, '愛知県犬山市寺西');
ok($zip->set_number('4840867')->is_valid_number, '愛知県犬山市九左エ門廻り');
ok($zip->set_number('4840868')->is_valid_number, '愛知県犬山市東北野');
ok($zip->set_number('4840869')->is_valid_number, '愛知県犬山市惣作');
ok($zip->set_number('4840871')->is_valid_number, '愛知県犬山市前並');
ok($zip->set_number('4840872')->is_valid_number, '愛知県犬山市岩田');
ok($zip->set_number('4840873')->is_valid_number, '愛知県犬山市天王前');
ok($zip->set_number('4840874')->is_valid_number, '愛知県犬山市楽田今村');
ok($zip->set_number('4840875')->is_valid_number, '愛知県犬山市林吾塚');
ok($zip->set_number('4840876')->is_valid_number, '愛知県犬山市山神');
ok($zip->set_number('4840877')->is_valid_number, '愛知県犬山市楽田東追分');
ok($zip->set_number('4840878')->is_valid_number, '愛知県犬山市栗林');
ok($zip->set_number('4840879')->is_valid_number, '愛知県犬山市楽田三ツ塚');
ok($zip->set_number('4840881')->is_valid_number, '愛知県犬山市羽黒成海西');
ok($zip->set_number('4840882')->is_valid_number, '愛知県犬山市羽黒菊川');
ok($zip->set_number('4840883')->is_valid_number, '愛知県犬山市羽黒成海南');
ok($zip->set_number('4840884')->is_valid_number, '愛知県犬山市羽黒起');
ok($zip->set_number('4840885')->is_valid_number, '愛知県犬山市楽田原西');
ok($zip->set_number('4840886')->is_valid_number, '愛知県犬山市宮浦');
ok($zip->set_number('4840887')->is_valid_number, '愛知県犬山市池田');
ok($zip->set_number('4840888')->is_valid_number, '愛知県犬山市羽黒新田');
ok($zip->set_number('4840889')->is_valid_number, '愛知県犬山市羽黒高橋');
ok($zip->set_number('4840891')->is_valid_number, '愛知県犬山市羽黒恩田島');
ok($zip->set_number('4840892')->is_valid_number, '愛知県犬山市羽黒惣境');
ok($zip->set_number('4840893')->is_valid_number, '愛知県犬山市羽黒栄');
ok($zip->set_number('4840894')->is_valid_number, '愛知県犬山市羽黒');
ok($zip->set_number('4840895')->is_valid_number, '愛知県犬山市羽黒摺墨');
ok($zip->set_number('4840896')->is_valid_number, '愛知県犬山市羽黒余町');
ok($zip->set_number('4840897')->is_valid_number, '愛知県犬山市羽黒堂前');
ok($zip->set_number('4840898')->is_valid_number, '愛知県犬山市羽黒稲葉西');
ok($zip->set_number('4840899')->is_valid_number, '愛知県犬山市羽黒稲葉東');
ok($zip->set_number('4840901')->is_valid_number, '愛知県犬山市柿畑');
ok($zip->set_number('4840902')->is_valid_number, '愛知県犬山市追分');
ok($zip->set_number('4840903')->is_valid_number, '愛知県犬山市追分東');
ok($zip->set_number('4840904')->is_valid_number, '愛知県犬山市楽田勝部前');
ok($zip->set_number('4840905')->is_valid_number, '愛知県犬山市西北野');
ok($zip->set_number('4840906')->is_valid_number, '愛知県犬山市焼野');
ok($zip->set_number('4840907')->is_valid_number, '愛知県犬山市楽田地蔵池');
ok($zip->set_number('4840908')->is_valid_number, '愛知県犬山市大上戸');
ok($zip->set_number('4840911')->is_valid_number, '愛知県犬山市北之門');
ok($zip->set_number('4840912')->is_valid_number, '愛知県犬山市舟田');
ok($zip->set_number('4840913')->is_valid_number, '愛知県犬山市鳥屋越');
ok($zip->set_number('4840914')->is_valid_number, '愛知県犬山市観音浦');
ok($zip->set_number('4840915')->is_valid_number, '愛知県犬山市楽田上沼');
ok($zip->set_number('4840916')->is_valid_number, '愛知県犬山市楽田西浦');
ok($zip->set_number('4840917')->is_valid_number, '愛知県犬山市土取');
ok($zip->set_number('4840918')->is_valid_number, '愛知県犬山市ニタ田');
ok($zip->set_number('4840919')->is_valid_number, '愛知県犬山市中道');
ok($zip->set_number('4840921')->is_valid_number, '愛知県犬山市味加田');
ok($zip->set_number('4840922')->is_valid_number, '愛知県犬山市北大橋');
ok($zip->set_number('4840923')->is_valid_number, '愛知県犬山市下沼');
ok($zip->set_number('4840924')->is_valid_number, '愛知県犬山市楽田大橋');
ok($zip->set_number('4840925')->is_valid_number, '愛知県犬山市楽田西野');
ok($zip->set_number('4840926')->is_valid_number, '愛知県犬山市楽田一色浦');
ok($zip->set_number('4840927')->is_valid_number, '愛知県犬山市的場');
ok($zip->set_number('4840928')->is_valid_number, '愛知県犬山市七ツ屋');
ok($zip->set_number('4840931')->is_valid_number, '愛知県犬山市南大橋');
ok($zip->set_number('4840932')->is_valid_number, '愛知県犬山市西野');
ok($zip->set_number('4840933')->is_valid_number, '愛知県犬山市東唐曽');
ok($zip->set_number('4840934')->is_valid_number, '愛知県犬山市中唐曽');
ok($zip->set_number('4840935')->is_valid_number, '愛知県犬山市西唐曽');
ok($zip->set_number('4840936')->is_valid_number, '愛知県犬山市楽田青塚');
ok($zip->set_number('4840937')->is_valid_number, '愛知県犬山市宮東');
ok($zip->set_number('4840941')->is_valid_number, '愛知県犬山市巾廻り');
ok($zip->set_number('4840942')->is_valid_number, '愛知県犬山市楽田巾');
ok($zip->set_number('4840943')->is_valid_number, '愛知県犬山市巾前');
ok($zip->set_number('4840944')->is_valid_number, '愛知県犬山市楽田安師');
ok($zip->set_number('4840945')->is_valid_number, '愛知県犬山市青塚');
ok($zip->set_number('4840946')->is_valid_number, '愛知県犬山市東大円');
ok($zip->set_number('4840947')->is_valid_number, '愛知県犬山市楽田大円');
ok($zip->set_number('4840948')->is_valid_number, '愛知県犬山市西大円');
ok($zip->set_number('4840951')->is_valid_number, '愛知県犬山市八反田');
ok($zip->set_number('4840952')->is_valid_number, '愛知県犬山市上舞台');
ok($zip->set_number('4840953')->is_valid_number, '愛知県犬山市下舞台');
ok($zip->set_number('4840954')->is_valid_number, '愛知県犬山市元散前');
ok($zip->set_number('4840955')->is_valid_number, '愛知県犬山市角池');
ok($zip->set_number('4840956')->is_valid_number, '愛知県犬山市新川');
ok($zip->set_number('4840957')->is_valid_number, '愛知県犬山市五反田');
ok($zip->set_number('4840958')->is_valid_number, '愛知県犬山市平塚');
ok($zip->set_number('4840959')->is_valid_number, '愛知県犬山市北平塚');
ok($zip->set_number('4840961')->is_valid_number, '愛知県犬山市太吉屋敷');
ok($zip->set_number('4840962')->is_valid_number, '愛知県犬山市落添');
ok($zip->set_number('4840963')->is_valid_number, '愛知県犬山市楽田鶴池');
ok($zip->set_number('4840964')->is_valid_number, '愛知県犬山市上榎島');
ok($zip->set_number('4840965')->is_valid_number, '愛知県犬山市下榎島');
ok($zip->set_number('4840966')->is_valid_number, '愛知県犬山市五郎丸二タ俣');
ok($zip->set_number('4850000')->is_valid_number, '愛知県小牧市以下に掲載がない場合');
ok($zip->set_number('4850001')->is_valid_number, '愛知県小牧市久保一色東');
ok($zip->set_number('4850002')->is_valid_number, '愛知県小牧市葭原');
ok($zip->set_number('4850003')->is_valid_number, '愛知県小牧市久保一色');
ok($zip->set_number('4850004')->is_valid_number, '愛知県小牧市田県町');
ok($zip->set_number('4850005')->is_valid_number, '愛知県小牧市久保本町');
ok($zip->set_number('4850006')->is_valid_number, '愛知県小牧市久保新町');
ok($zip->set_number('4850007')->is_valid_number, '愛知県小牧市久保一色南');
ok($zip->set_number('4850008')->is_valid_number, '愛知県小牧市寺西');
ok($zip->set_number('4850009')->is_valid_number, '愛知県小牧市久保');
ok($zip->set_number('4850011')->is_valid_number, '愛知県小牧市岩崎');
ok($zip->set_number('4850012')->is_valid_number, '愛知県小牧市小牧原新田');
ok($zip->set_number('4850013')->is_valid_number, '愛知県小牧市新町');
ok($zip->set_number('4850014')->is_valid_number, '愛知県小牧市安田町');
ok($zip->set_number('4850015')->is_valid_number, '愛知県小牧市間々');
ok($zip->set_number('4850016')->is_valid_number, '愛知県小牧市間々原新田');
ok($zip->set_number('4850017')->is_valid_number, '愛知県小牧市岩崎原');
ok($zip->set_number('4850021')->is_valid_number, '愛知県小牧市二重堀');
ok($zip->set_number('4850022')->is_valid_number, '愛知県小牧市北外山入鹿新田');
ok($zip->set_number('4850023')->is_valid_number, '愛知県小牧市北外山');
ok($zip->set_number('4850024')->is_valid_number, '愛知県小牧市南外山');
ok($zip->set_number('4850025')->is_valid_number, '愛知県小牧市春日寺');
ok($zip->set_number('4850026')->is_valid_number, '愛知県小牧市大山(小牧大山)');
ok($zip->set_number('4850027')->is_valid_number, '愛知県小牧市緑町');
ok($zip->set_number('4850028')->is_valid_number, '愛知県小牧市東新町');
ok($zip->set_number('4850029')->is_valid_number, '愛知県小牧市中央');
ok($zip->set_number('4850031')->is_valid_number, '愛知県小牧市若草町');
ok($zip->set_number('4850032')->is_valid_number, '愛知県小牧市掛割町');
ok($zip->set_number('4850033')->is_valid_number, '愛知県小牧市郷中');
ok($zip->set_number('4850034')->is_valid_number, '愛知県小牧市市之久田');
ok($zip->set_number('4850035')->is_valid_number, '愛知県小牧市多気東町');
ok($zip->set_number('4850036')->is_valid_number, '愛知県小牧市下小針天神');
ok($zip->set_number('4850037')->is_valid_number, '愛知県小牧市小針');
ok($zip->set_number('4850039')->is_valid_number, '愛知県小牧市外堀');
ok($zip->set_number('4850041')->is_valid_number, '愛知県小牧市小牧');
ok($zip->set_number('4850042')->is_valid_number, '愛知県小牧市桜井');
ok($zip->set_number('4850043')->is_valid_number, '愛知県小牧市桜井本町');
ok($zip->set_number('4850044')->is_valid_number, '愛知県小牧市常普請');
ok($zip->set_number('4850045')->is_valid_number, '愛知県小牧市川西');
ok($zip->set_number('4850046')->is_valid_number, '愛知県小牧市堀の内');
ok($zip->set_number('4850047')->is_valid_number, '愛知県小牧市曙町');
ok($zip->set_number('4850048')->is_valid_number, '愛知県小牧市間々本町');
ok($zip->set_number('4850049')->is_valid_number, '愛知県小牧市山北町');
ok($zip->set_number('4850051')->is_valid_number, '愛知県小牧市下小針中島');
ok($zip->set_number('4850052')->is_valid_number, '愛知県小牧市多気中町');
ok($zip->set_number('4850053')->is_valid_number, '愛知県小牧市多気南町');
ok($zip->set_number('4850054')->is_valid_number, '愛知県小牧市多気西町');
ok($zip->set_number('4850055')->is_valid_number, '愛知県小牧市多気北町');
ok($zip->set_number('4850056')->is_valid_number, '愛知県小牧市小木南');
ok($zip->set_number('4850057')->is_valid_number, '愛知県小牧市小木西');
ok($zip->set_number('4850058')->is_valid_number, '愛知県小牧市小木');
ok($zip->set_number('4850059')->is_valid_number, '愛知県小牧市小木東');
ok($zip->set_number('4850061')->is_valid_number, '愛知県小牧市藤島町向江');
ok($zip->set_number('4850062')->is_valid_number, '愛知県小牧市藤島町中島');
ok($zip->set_number('4850063')->is_valid_number, '愛知県小牧市藤島町鏡池');
ok($zip->set_number('4850064')->is_valid_number, '愛知県小牧市藤島町徳願寺');
ok($zip->set_number('4850065')->is_valid_number, '愛知県小牧市藤島町五才田');
ok($zip->set_number('4850066')->is_valid_number, '愛知県小牧市藤島町出口');
ok($zip->set_number('4850067')->is_valid_number, '愛知県小牧市藤島町居屋敷');
ok($zip->set_number('4850068')->is_valid_number, '愛知県小牧市藤島');
ok($zip->set_number('4850069')->is_valid_number, '愛知県小牧市藤島町梵天');
ok($zip->set_number('4850071')->is_valid_number, '愛知県小牧市弥生町');
ok($zip->set_number('4850072')->is_valid_number, '愛知県小牧市元町');
ok($zip->set_number('4850073')->is_valid_number, '愛知県小牧市舟津');
ok($zip->set_number('4850074')->is_valid_number, '愛知県小牧市新小木');
ok($zip->set_number('4850075')->is_valid_number, '愛知県小牧市三ツ渕');
ok($zip->set_number('4850076')->is_valid_number, '愛知県小牧市三ツ渕原新田');
ok($zip->set_number('4850077')->is_valid_number, '愛知県小牧市西之島');
ok($zip->set_number('4850078')->is_valid_number, '愛知県小牧市西島町');
ok($zip->set_number('4850081')->is_valid_number, '愛知県小牧市横内');
ok($zip->set_number('4850082')->is_valid_number, '愛知県小牧市村中');
ok($zip->set_number('4850083')->is_valid_number, '愛知県小牧市村中新町');
ok($zip->set_number('4850084')->is_valid_number, '愛知県小牧市入鹿出新田');
ok($zip->set_number('4850085')->is_valid_number, '愛知県小牧市河内屋新田');
ok($zip->set_number('4850801')->is_valid_number, '愛知県小牧市大山(篠岡大山)');
ok($zip->set_number('4850802')->is_valid_number, '愛知県小牧市大草');
ok($zip->set_number('4850803')->is_valid_number, '愛知県小牧市高根');
ok($zip->set_number('4850804')->is_valid_number, '愛知県小牧市池之内');
ok($zip->set_number('4850805')->is_valid_number, '愛知県小牧市林');
ok($zip->set_number('4850806')->is_valid_number, '愛知県小牧市野口');
ok($zip->set_number('4850811')->is_valid_number, '愛知県小牧市光ケ丘');
ok($zip->set_number('4850812')->is_valid_number, '愛知県小牧市城山');
ok($zip->set_number('4850813')->is_valid_number, '愛知県小牧市桃ケ丘');
ok($zip->set_number('4850814')->is_valid_number, '愛知県小牧市古雅');
ok($zip->set_number('4850815')->is_valid_number, '愛知県小牧市篠岡');
ok($zip->set_number('4850821')->is_valid_number, '愛知県小牧市本庄');
ok($zip->set_number('4850822')->is_valid_number, '愛知県小牧市上末');
ok($zip->set_number('4850823')->is_valid_number, '愛知県小牧市郷西町');
ok($zip->set_number('4850824')->is_valid_number, '愛知県小牧市長治町');
ok($zip->set_number('4850825')->is_valid_number, '愛知県小牧市下末');
ok($zip->set_number('4850826')->is_valid_number, '愛知県小牧市東田中');
ok($zip->set_number('4850827')->is_valid_number, '愛知県小牧市文津');
ok($zip->set_number('4850828')->is_valid_number, '愛知県小牧市小松寺');
ok($zip->set_number('4850829')->is_valid_number, '愛知県小牧市小牧原');
ok($zip->set_number('4850831')->is_valid_number, '愛知県小牧市東');
ok($zip->set_number('4850832')->is_valid_number, '愛知県小牧市応時');
ok($zip->set_number('4860000')->is_valid_number, '愛知県春日井市以下に掲載がない場合');
ok($zip->set_number('4860801')->is_valid_number, '愛知県春日井市上田楽町');
ok($zip->set_number('4860802')->is_valid_number, '愛知県春日井市桃山町');
ok($zip->set_number('4860803')->is_valid_number, '愛知県春日井市西山町');
ok($zip->set_number('4860804')->is_valid_number, '愛知県春日井市鷹来町');
ok($zip->set_number('4860805')->is_valid_number, '愛知県春日井市岩野町');
ok($zip->set_number('4860806')->is_valid_number, '愛知県春日井市大手田酉町');
ok($zip->set_number('4860807')->is_valid_number, '愛知県春日井市大手町');
ok($zip->set_number('4860808')->is_valid_number, '愛知県春日井市田楽町');
ok($zip->set_number('4860809')->is_valid_number, '愛知県春日井市町屋町');
ok($zip->set_number('4860811')->is_valid_number, '愛知県春日井市東山町');
ok($zip->set_number('4860812')->is_valid_number, '愛知県春日井市大泉寺町');
ok($zip->set_number('4860813')->is_valid_number, '愛知県春日井市金ケ口町');
ok($zip->set_number('4860814')->is_valid_number, '愛知県春日井市北城町');
ok($zip->set_number('4860815')->is_valid_number, '愛知県春日井市十三塚町');
ok($zip->set_number('4860816')->is_valid_number, '愛知県春日井市東野新町');
ok($zip->set_number('4860817')->is_valid_number, '愛知県春日井市東野町');
ok($zip->set_number('4860818')->is_valid_number, '愛知県春日井市東野町西');
ok($zip->set_number('4860819')->is_valid_number, '愛知県春日井市下原町');
ok($zip->set_number('4860820')->is_valid_number, '愛知県春日井市熊野町北');
ok($zip->set_number('4860821')->is_valid_number, '愛知県春日井市神領町');
ok($zip->set_number('4860822')->is_valid_number, '愛知県春日井市熊野町');
ok($zip->set_number('4860823')->is_valid_number, '愛知県春日井市桜佐町');
ok($zip->set_number('4860824')->is_valid_number, '愛知県春日井市割塚町');
ok($zip->set_number('4860825')->is_valid_number, '愛知県春日井市中央通');
ok($zip->set_number('4860826')->is_valid_number, '愛知県春日井市貴船町');
ok($zip->set_number('4860827')->is_valid_number, '愛知県春日井市小木田町');
ok($zip->set_number('4860828')->is_valid_number, '愛知県春日井市堀ノ内町北');
ok($zip->set_number('4860829')->is_valid_number, '愛知県春日井市堀ノ内町');
ok($zip->set_number('4860830')->is_valid_number, '愛知県春日井市神領町北');
ok($zip->set_number('4860831')->is_valid_number, '愛知県春日井市ことぶき町');
ok($zip->set_number('4860832')->is_valid_number, '愛知県春日井市乙輪町');
ok($zip->set_number('4860833')->is_valid_number, '愛知県春日井市上条町');
ok($zip->set_number('4860834')->is_valid_number, '愛知県春日井市王子町');
ok($zip->set_number('4860835')->is_valid_number, '愛知県春日井市月見町');
ok($zip->set_number('4860836')->is_valid_number, '愛知県春日井市八事町');
ok($zip->set_number('4860837')->is_valid_number, '愛知県春日井市春見町');
ok($zip->set_number('4860838')->is_valid_number, '愛知県春日井市弥生町');
ok($zip->set_number('4860839')->is_valid_number, '愛知県春日井市六軒屋町西');
ok($zip->set_number('4860841')->is_valid_number, '愛知県春日井市南下原町');
ok($zip->set_number('4860842')->is_valid_number, '愛知県春日井市六軒屋町');
ok($zip->set_number('4860844')->is_valid_number, '愛知県春日井市鳥居松町');
ok($zip->set_number('4860845')->is_valid_number, '愛知県春日井市瑞穂通');
ok($zip->set_number('4860846')->is_valid_number, '愛知県春日井市朝宮町');
ok($zip->set_number('4860849')->is_valid_number, '愛知県春日井市八田町');
ok($zip->set_number('4860851')->is_valid_number, '愛知県春日井市篠木町');
ok($zip->set_number('4860852')->is_valid_number, '愛知県春日井市下市場町');
ok($zip->set_number('4860853')->is_valid_number, '愛知県春日井市穴橋町');
ok($zip->set_number('4860854')->is_valid_number, '愛知県春日井市林島町');
ok($zip->set_number('4860855')->is_valid_number, '愛知県春日井市関田町');
ok($zip->set_number('4860856')->is_valid_number, '愛知県春日井市梅ケ坪町');
ok($zip->set_number('4860857')->is_valid_number, '愛知県春日井市浅山町');
ok($zip->set_number('4860858')->is_valid_number, '愛知県春日井市菅大臣町');
ok($zip->set_number('4860901')->is_valid_number, '愛知県春日井市牛山町');
ok($zip->set_number('4860902')->is_valid_number, '愛知県春日井市新開町');
ok($zip->set_number('4860903')->is_valid_number, '愛知県春日井市前並町');
ok($zip->set_number('4860904')->is_valid_number, '愛知県春日井市宮町');
ok($zip->set_number('4860905')->is_valid_number, '愛知県春日井市稲口町');
ok($zip->set_number('4860906')->is_valid_number, '愛知県春日井市下屋敷町');
ok($zip->set_number('4860907')->is_valid_number, '愛知県春日井市黒鉾町');
ok($zip->set_number('4860908')->is_valid_number, '愛知県春日井市西屋町');
ok($zip->set_number('4860909')->is_valid_number, '愛知県春日井市四ツ家町');
ok($zip->set_number('4860911')->is_valid_number, '愛知県春日井市西高山町');
ok($zip->set_number('4860912')->is_valid_number, '愛知県春日井市高山町');
ok($zip->set_number('4860913')->is_valid_number, '愛知県春日井市柏原町');
ok($zip->set_number('4860914')->is_valid_number, '愛知県春日井市若草通');
ok($zip->set_number('4860915')->is_valid_number, '愛知県春日井市八幡町');
ok($zip->set_number('4860916')->is_valid_number, '愛知県春日井市八光町');
ok($zip->set_number('4860917')->is_valid_number, '愛知県春日井市美濃町');
ok($zip->set_number('4860918')->is_valid_number, '愛知県春日井市如意申町');
ok($zip->set_number('4860921')->is_valid_number, '愛知県春日井市杁ケ島町');
ok($zip->set_number('4860922')->is_valid_number, '愛知県春日井市篠田町');
ok($zip->set_number('4860923')->is_valid_number, '愛知県春日井市下条町');
ok($zip->set_number('4860924')->is_valid_number, '愛知県春日井市下津町');
ok($zip->set_number('4860925')->is_valid_number, '愛知県春日井市中切町');
ok($zip->set_number('4860926')->is_valid_number, '愛知県春日井市小野町');
ok($zip->set_number('4860927')->is_valid_number, '愛知県春日井市柏井町');
ok($zip->set_number('4860928')->is_valid_number, '愛知県春日井市妙慶町');
ok($zip->set_number('4860929')->is_valid_number, '愛知県春日井市旭町');
ok($zip->set_number('4860931')->is_valid_number, '愛知県春日井市松新町');
ok($zip->set_number('4860932')->is_valid_number, '愛知県春日井市松河戸町');
ok($zip->set_number('4860933')->is_valid_number, '愛知県春日井市愛知町');
ok($zip->set_number('4860934')->is_valid_number, '愛知県春日井市長塚町');
ok($zip->set_number('4860935')->is_valid_number, '愛知県春日井市森山田町');
ok($zip->set_number('4860936')->is_valid_number, '愛知県春日井市町田町');
ok($zip->set_number('4860937')->is_valid_number, '愛知県春日井市細木町');
ok($zip->set_number('4860941')->is_valid_number, '愛知県春日井市勝川新町');
ok($zip->set_number('4860942')->is_valid_number, '愛知県春日井市神明町');
ok($zip->set_number('4860943')->is_valid_number, '愛知県春日井市角崎町');
ok($zip->set_number('4860944')->is_valid_number, '愛知県春日井市大和通');
ok($zip->set_number('4860945')->is_valid_number, '愛知県春日井市勝川町');
ok($zip->set_number('4860946')->is_valid_number, '愛知県春日井市勝川町西');
ok($zip->set_number('4860947')->is_valid_number, '愛知県春日井市知多町');
ok($zip->set_number('4860948')->is_valid_number, '愛知県春日井市天神町');
ok($zip->set_number('4860949')->is_valid_number, '愛知県春日井市惣中町');
ok($zip->set_number('4860951')->is_valid_number, '愛知県春日井市花長町');
ok($zip->set_number('4860952')->is_valid_number, '愛知県春日井市追進町');
ok($zip->set_number('4860953')->is_valid_number, '愛知県春日井市御幸町');
ok($zip->set_number('4860954')->is_valid_number, '愛知県春日井市南花長町');
ok($zip->set_number('4860955')->is_valid_number, '愛知県春日井市二子町');
ok($zip->set_number('4860956')->is_valid_number, '愛知県春日井市中新町');
ok($zip->set_number('4860957')->is_valid_number, '愛知県春日井市中野町');
ok($zip->set_number('4860958')->is_valid_number, '愛知県春日井市西本町');
ok($zip->set_number('4860961')->is_valid_number, '愛知県春日井市春日井上ノ町');
ok($zip->set_number('4860962')->is_valid_number, '愛知県春日井市中町');
ok($zip->set_number('4860963')->is_valid_number, '愛知県春日井市春日井町');
ok($zip->set_number('4860964')->is_valid_number, '愛知県春日井市宗法町');
ok($zip->set_number('4860965')->is_valid_number, '愛知県春日井市味美上ノ町');
ok($zip->set_number('4860966')->is_valid_number, '愛知県春日井市上ノ町');
ok($zip->set_number('4860967')->is_valid_number, '愛知県春日井市味美西本町');
ok($zip->set_number('4860968')->is_valid_number, '愛知県春日井市味美町');
ok($zip->set_number('4860969')->is_valid_number, '愛知県春日井市味美白山町');
ok($zip->set_number('4870001')->is_valid_number, '愛知県春日井市細野町');
ok($zip->set_number('4870002')->is_valid_number, '愛知県春日井市外之原町');
ok($zip->set_number('4870003')->is_valid_number, '愛知県春日井市木附町');
ok($zip->set_number('4870004')->is_valid_number, '愛知県春日井市玉野町');
ok($zip->set_number('4870005')->is_valid_number, '愛知県春日井市押沢台');
ok($zip->set_number('4870006')->is_valid_number, '愛知県春日井市石尾台');
ok($zip->set_number('4870007')->is_valid_number, '愛知県春日井市玉野台');
ok($zip->set_number('4870011')->is_valid_number, '愛知県春日井市中央台');
ok($zip->set_number('4870012')->is_valid_number, '愛知県春日井市高座町');
ok($zip->set_number('4870013')->is_valid_number, '愛知県春日井市高蔵寺町');
ok($zip->set_number('4870014')->is_valid_number, '愛知県春日井市気噴町');
ok($zip->set_number('4870015')->is_valid_number, '愛知県春日井市気噴町北');
ok($zip->set_number('4870016')->is_valid_number, '愛知県春日井市高蔵寺町北');
ok($zip->set_number('4870017')->is_valid_number, '愛知県春日井市高座台');
ok($zip->set_number('4870021')->is_valid_number, '愛知県春日井市東神明町');
ok($zip->set_number('4870022')->is_valid_number, '愛知県春日井市庄名町');
ok($zip->set_number('4870023')->is_valid_number, '愛知県春日井市不二ガ丘');
ok($zip->set_number('4870024')->is_valid_number, '愛知県春日井市大留町');
ok($zip->set_number('4870025')->is_valid_number, '愛知県春日井市出川町');
ok($zip->set_number('4870026')->is_valid_number, '愛知県春日井市不二町');
ok($zip->set_number('4870027')->is_valid_number, '愛知県春日井市松本町');
ok($zip->set_number('4870031')->is_valid_number, '愛知県春日井市廻間町');
ok($zip->set_number('4870032')->is_valid_number, '愛知県春日井市高森台');
ok($zip->set_number('4870033')->is_valid_number, '愛知県春日井市岩成台');
ok($zip->set_number('4870034')->is_valid_number, '愛知県春日井市白山町');
ok($zip->set_number('4870035')->is_valid_number, '愛知県春日井市藤山台');
ok($zip->set_number('4880000')->is_valid_number, '愛知県尾張旭市以下に掲載がない場合');
ok($zip->set_number('4880001')->is_valid_number, '愛知県尾張旭市旭台');
ok($zip->set_number('4880002')->is_valid_number, '愛知県尾張旭市根の鼻町');
ok($zip->set_number('4880003')->is_valid_number, '愛知県尾張旭市東大久手町');
ok($zip->set_number('4880004')->is_valid_number, '愛知県尾張旭市大久手町一の曾');
ok($zip->set_number('4880005')->is_valid_number, '愛知県尾張旭市大久手町上切戸');
ok($zip->set_number('4880006')->is_valid_number, '愛知県尾張旭市大久手町中松原');
ok($zip->set_number('4880007')->is_valid_number, '愛知県尾張旭市柏井町公園通');
ok($zip->set_number('4880008')->is_valid_number, '愛知県尾張旭市柏井町弥栄');
ok($zip->set_number('4880011')->is_valid_number, '愛知県尾張旭市東栄町');
ok($zip->set_number('4880012')->is_valid_number, '愛知県尾張旭市三郷町角田');
ok($zip->set_number('4880013')->is_valid_number, '愛知県尾張旭市三郷町富丘');
ok($zip->set_number('4880014')->is_valid_number, '愛知県尾張旭市三郷町中井田');
ok($zip->set_number('4880015')->is_valid_number, '愛知県尾張旭市三郷町栄');
ok($zip->set_number('4880016')->is_valid_number, '愛知県尾張旭市三郷町陶栄');
ok($zip->set_number('4880017')->is_valid_number, '愛知県尾張旭市東三郷町');
ok($zip->set_number('4880021')->is_valid_number, '愛知県尾張旭市狩宿町');
ok($zip->set_number('4880022')->is_valid_number, '愛知県尾張旭市狩宿新町');
ok($zip->set_number('4880023')->is_valid_number, '愛知県尾張旭市瀬戸川町');
ok($zip->set_number('4880024')->is_valid_number, '愛知県尾張旭市井田町');
ok($zip->set_number('4880031')->is_valid_number, '愛知県尾張旭市晴丘町東');
ok($zip->set_number('4880032')->is_valid_number, '愛知県尾張旭市晴丘町池上');
ok($zip->set_number('4880033')->is_valid_number, '愛知県尾張旭市東本地ケ原町');
ok($zip->set_number('4880034')->is_valid_number, '愛知県尾張旭市上の山町山畑');
ok($zip->set_number('4880035')->is_valid_number, '愛知県尾張旭市上の山町間口');
ok($zip->set_number('4880041')->is_valid_number, '愛知県尾張旭市南新町中畑');
ok($zip->set_number('4880042')->is_valid_number, '愛知県尾張旭市南新町白山');
ok($zip->set_number('4880043')->is_valid_number, '愛知県尾張旭市北本地ケ原町');
ok($zip->set_number('4880044')->is_valid_number, '愛知県尾張旭市南本地ケ原町');
ok($zip->set_number('4880045')->is_valid_number, '愛知県尾張旭市南栄町');
ok($zip->set_number('4880046')->is_valid_number, '愛知県尾張旭市南栄町旭ケ丘');
ok($zip->set_number('4880047')->is_valid_number, '愛知県尾張旭市南栄町黒石');
ok($zip->set_number('4880051')->is_valid_number, '愛知県尾張旭市下井町前の上');
ok($zip->set_number('4880052')->is_valid_number, '愛知県尾張旭市下井町下井');
ok($zip->set_number('4880053')->is_valid_number, '愛知県尾張旭市下井町刎内');
ok($zip->set_number('4880054')->is_valid_number, '愛知県尾張旭市稲葉町');
ok($zip->set_number('4880055')->is_valid_number, '愛知県尾張旭市北山町六反田');
ok($zip->set_number('4880056')->is_valid_number, '愛知県尾張旭市北山町北山');
ok($zip->set_number('4880057')->is_valid_number, '愛知県尾張旭市北山町北新田');
ok($zip->set_number('4880061')->is_valid_number, '愛知県尾張旭市北原山町六田池');
ok($zip->set_number('4880062')->is_valid_number, '愛知県尾張旭市北原山町平池浦');
ok($zip->set_number('4880063')->is_valid_number, '愛知県尾張旭市北原山町陀摩屋敷');
ok($zip->set_number('4880064')->is_valid_number, '愛知県尾張旭市北原山町鳴湫');
ok($zip->set_number('4880065')->is_valid_number, '愛知県尾張旭市北原山町大久保見');
ok($zip->set_number('4880066')->is_valid_number, '愛知県尾張旭市南原山町赤土');
ok($zip->set_number('4880067')->is_valid_number, '愛知県尾張旭市南原山町石原');
ok($zip->set_number('4880068')->is_valid_number, '愛知県尾張旭市南原山町南原山');
ok($zip->set_number('4880070')->is_valid_number, '愛知県尾張旭市新居町五反田');
ok($zip->set_number('4880071')->is_valid_number, '愛知県尾張旭市新居町下切戸');
ok($zip->set_number('4880072')->is_valid_number, '愛知県尾張旭市新居町諏訪南');
ok($zip->set_number('4880073')->is_valid_number, '愛知県尾張旭市新居町上の田');
ok($zip->set_number('4880074')->is_valid_number, '愛知県尾張旭市新居町明才切');
ok($zip->set_number('4880075')->is_valid_number, '愛知県尾張旭市新居町木の本');
ok($zip->set_number('4880076')->is_valid_number, '愛知県尾張旭市新居町山の田');
ok($zip->set_number('4880077')->is_valid_number, '愛知県尾張旭市新居町西浦');
ok($zip->set_number('4880078')->is_valid_number, '愛知県尾張旭市新居町寺田');
ok($zip->set_number('4880079')->is_valid_number, '愛知県尾張旭市新居町今池下');
ok($zip->set_number('4880081')->is_valid_number, '愛知県尾張旭市新居');
ok($zip->set_number('4880082')->is_valid_number, '愛知県尾張旭市旭ケ丘町森');
ok($zip->set_number('4880083')->is_valid_number, '愛知県尾張旭市旭ケ丘町旭ケ丘');
ok($zip->set_number('4880084')->is_valid_number, '愛知県尾張旭市旭ケ丘町山の手');
ok($zip->set_number('4880085')->is_valid_number, '愛知県尾張旭市旭ケ丘町濁池');
ok($zip->set_number('4880086')->is_valid_number, '愛知県尾張旭市旭ケ丘町長洞');
ok($zip->set_number('4880801')->is_valid_number, '愛知県尾張旭市東大道町原田');
ok($zip->set_number('4880802')->is_valid_number, '愛知県尾張旭市東大道町曽我廻間');
ok($zip->set_number('4880803')->is_valid_number, '愛知県尾張旭市東大道町山の内');
ok($zip->set_number('4880804')->is_valid_number, '愛知県尾張旭市西の野町');
ok($zip->set_number('4880805')->is_valid_number, '愛知県尾張旭市西の野町豆塚');
ok($zip->set_number('4880813')->is_valid_number, '愛知県尾張旭市西大道町五輪塚');
ok($zip->set_number('4880814')->is_valid_number, '愛知県尾張旭市西大道町前田');
ok($zip->set_number('4880815')->is_valid_number, '愛知県尾張旭市西大道町六兵衛前');
ok($zip->set_number('4880816')->is_valid_number, '愛知県尾張旭市西大道町下大道');
ok($zip->set_number('4880817')->is_valid_number, '愛知県尾張旭市西大道町八瀬の木前');
ok($zip->set_number('4880818')->is_valid_number, '愛知県尾張旭市向町');
ok($zip->set_number('4880821')->is_valid_number, '愛知県尾張旭市長坂町南山');
ok($zip->set_number('4880822')->is_valid_number, '愛知県尾張旭市緑町緑ケ丘');
ok($zip->set_number('4880823')->is_valid_number, '愛知県尾張旭市庄南町');
ok($zip->set_number('4880824')->is_valid_number, '愛知県尾張旭市西山町');
ok($zip->set_number('4880825')->is_valid_number, '愛知県尾張旭市東山町');
ok($zip->set_number('4880826')->is_valid_number, '愛知県尾張旭市大塚町');
ok($zip->set_number('4880827')->is_valid_number, '愛知県尾張旭市吉岡町');
ok($zip->set_number('4880830')->is_valid_number, '愛知県尾張旭市東印場町');
ok($zip->set_number('4880833')->is_valid_number, '愛知県尾張旭市東印場町二反田');
ok($zip->set_number('4880835')->is_valid_number, '愛知県尾張旭市庄中町南島');
ok($zip->set_number('4880836')->is_valid_number, '愛知県尾張旭市庄中町渋川');
ok($zip->set_number('4880838')->is_valid_number, '愛知県尾張旭市庄中町');
ok($zip->set_number('4880839')->is_valid_number, '愛知県尾張旭市渋川町');
ok($zip->set_number('4880840')->is_valid_number, '愛知県尾張旭市印場元町');
ok($zip->set_number('4880841')->is_valid_number, '愛知県尾張旭市印場元町北山');
ok($zip->set_number('4880843')->is_valid_number, '愛知県尾張旭市印場元町細田');
ok($zip->set_number('4880844')->is_valid_number, '愛知県尾張旭市東名西町');
ok($zip->set_number('4880845')->is_valid_number, '愛知県尾張旭市霞ケ丘町南');
ok($zip->set_number('4880846')->is_valid_number, '愛知県尾張旭市霞ケ丘町中');
ok($zip->set_number('4880847')->is_valid_number, '愛知県尾張旭市霞ケ丘町北');
ok($zip->set_number('4880851')->is_valid_number, '愛知県尾張旭市旭前町北');
ok($zip->set_number('4880852')->is_valid_number, '愛知県尾張旭市旭前町新田洞');
ok($zip->set_number('4880854')->is_valid_number, '愛知県尾張旭市旭前町西新田');
ok($zip->set_number('4880855')->is_valid_number, '愛知県尾張旭市旭前町');
ok($zip->set_number('4880857')->is_valid_number, '愛知県尾張旭市桜ケ丘町西');
ok($zip->set_number('4880858')->is_valid_number, '愛知県尾張旭市白鳳町');
ok($zip->set_number('4880859')->is_valid_number, '愛知県尾張旭市桜ケ丘町');
ok($zip->set_number('4880861')->is_valid_number, '愛知県尾張旭市城前町城前');
ok($zip->set_number('4880863')->is_valid_number, '愛知県尾張旭市城前町上大道');
ok($zip->set_number('4880866')->is_valid_number, '愛知県尾張旭市城前町茅池');
ok($zip->set_number('4880867')->is_valid_number, '愛知県尾張旭市城前町');
ok($zip->set_number('4880871')->is_valid_number, '愛知県尾張旭市平子町東');
ok($zip->set_number('4880872')->is_valid_number, '愛知県尾張旭市平子町長池上');
ok($zip->set_number('4880873')->is_valid_number, '愛知県尾張旭市平子町中通');
ok($zip->set_number('4880874')->is_valid_number, '愛知県尾張旭市平子町西');
ok($zip->set_number('4880875')->is_valid_number, '愛知県尾張旭市平子町北');
ok($zip->set_number('4880876')->is_valid_number, '愛知県尾張旭市平子ケ丘町');
ok($zip->set_number('4880881')->is_valid_number, '愛知県尾張旭市城山町三ツ池');
ok($zip->set_number('4880882')->is_valid_number, '愛知県尾張旭市城山町向ケ丘');
ok($zip->set_number('4880883')->is_valid_number, '愛知県尾張旭市城山町長池下');
ok($zip->set_number('4880884')->is_valid_number, '愛知県尾張旭市城山町城山');
ok($zip->set_number('4890000')->is_valid_number, '愛知県瀬戸市以下に掲載がない場合');
ok($zip->set_number('4890001')->is_valid_number, '愛知県瀬戸市川平町');
ok($zip->set_number('4890002')->is_valid_number, '愛知県瀬戸市余床町');
ok($zip->set_number('4890003')->is_valid_number, '愛知県瀬戸市穴田町');
ok($zip->set_number('4890004')->is_valid_number, '愛知県瀬戸市日の出町');
ok($zip->set_number('4890005')->is_valid_number, '愛知県瀬戸市中水野町');
ok($zip->set_number('4890006')->is_valid_number, '愛知県瀬戸市三沢町');
ok($zip->set_number('4890007')->is_valid_number, '愛知県瀬戸市鹿乗町');
ok($zip->set_number('4890008')->is_valid_number, '愛知県瀬戸市曽野町');
ok($zip->set_number('4890009')->is_valid_number, '愛知県瀬戸市水北町');
ok($zip->set_number('4890011')->is_valid_number, '愛知県瀬戸市針原町');
ok($zip->set_number('4890012')->is_valid_number, '愛知県瀬戸市長谷口町');
ok($zip->set_number('4890013')->is_valid_number, '愛知県瀬戸市中白坂町');
ok($zip->set_number('4890014')->is_valid_number, '愛知県瀬戸市北白坂町');
ok($zip->set_number('4890015')->is_valid_number, '愛知県瀬戸市東白坂町');
ok($zip->set_number('4890016')->is_valid_number, '愛知県瀬戸市南白坂町');
ok($zip->set_number('4890017')->is_valid_number, '愛知県瀬戸市白坂町');
ok($zip->set_number('4890018')->is_valid_number, '愛知県瀬戸市西白坂町');
ok($zip->set_number('4890021')->is_valid_number, '愛知県瀬戸市馬ケ城町');
ok($zip->set_number('4890022')->is_valid_number, '愛知県瀬戸市赤津町');
ok($zip->set_number('4890023')->is_valid_number, '愛知県瀬戸市窯元町');
ok($zip->set_number('4890024')->is_valid_number, '愛知県瀬戸市八王子町');
ok($zip->set_number('4890025')->is_valid_number, '愛知県瀬戸市凧山町');
ok($zip->set_number('4890026')->is_valid_number, '愛知県瀬戸市東明町');
ok($zip->set_number('4890027')->is_valid_number, '愛知県瀬戸市東拝戸町');
ok($zip->set_number('4890028')->is_valid_number, '愛知県瀬戸市西窯町');
ok($zip->set_number('4890029')->is_valid_number, '愛知県瀬戸市中畑町');
ok($zip->set_number('4890031')->is_valid_number, '愛知県瀬戸市五位塚町');
ok($zip->set_number('4890032')->is_valid_number, '愛知県瀬戸市古瀬戸町');
ok($zip->set_number('4890033')->is_valid_number, '愛知県瀬戸市須原町');
ok($zip->set_number('4890034')->is_valid_number, '愛知県瀬戸市刎田町');
ok($zip->set_number('4890035')->is_valid_number, '愛知県瀬戸市紺屋田町');
ok($zip->set_number('4890036')->is_valid_number, '愛知県瀬戸市西古瀬戸町');
ok($zip->set_number('4890037')->is_valid_number, '愛知県瀬戸市東古瀬戸町');
ok($zip->set_number('4890041')->is_valid_number, '愛知県瀬戸市背戸側町');
ok($zip->set_number('4890042')->is_valid_number, '愛知県瀬戸市仲切町');
ok($zip->set_number('4890043')->is_valid_number, '愛知県瀬戸市朝日町');
ok($zip->set_number('4890044')->is_valid_number, '愛知県瀬戸市栄町');
ok($zip->set_number('4890045')->is_valid_number, '愛知県瀬戸市陶本町');
ok($zip->set_number('4890046')->is_valid_number, '愛知県瀬戸市元町');
ok($zip->set_number('4890047')->is_valid_number, '愛知県瀬戸市西谷町');
ok($zip->set_number('4890048')->is_valid_number, '愛知県瀬戸市窯神町');
ok($zip->set_number('4890051')->is_valid_number, '愛知県瀬戸市下陣屋町');
ok($zip->set_number('4890052')->is_valid_number, '愛知県瀬戸市安戸町');
ok($zip->set_number('4890053')->is_valid_number, '愛知県瀬戸市東安戸町');
ok($zip->set_number('4890054')->is_valid_number, '愛知県瀬戸市道泉町');
ok($zip->set_number('4890055')->is_valid_number, '愛知県瀬戸市滝之湯町');
ok($zip->set_number('4890056')->is_valid_number, '愛知県瀬戸市東十三塚町');
ok($zip->set_number('4890057')->is_valid_number, '愛知県瀬戸市西十三塚町');
ok($zip->set_number('4890058')->is_valid_number, '愛知県瀬戸市進陶町');
ok($zip->set_number('4890061')->is_valid_number, '愛知県瀬戸市上本町');
ok($zip->set_number('4890062')->is_valid_number, '愛知県瀬戸市上水野町');
ok($zip->set_number('4890063')->is_valid_number, '愛知県瀬戸市上陣屋町');
ok($zip->set_number('4890064')->is_valid_number, '愛知県瀬戸市小金町');
ok($zip->set_number('4890065')->is_valid_number, '愛知県瀬戸市西追分町');
ok($zip->set_number('4890066')->is_valid_number, '愛知県瀬戸市東横山町');
ok($zip->set_number('4890067')->is_valid_number, '愛知県瀬戸市小田妻町');
ok($zip->set_number('4890068')->is_valid_number, '愛知県瀬戸市上松山町');
ok($zip->set_number('4890069')->is_valid_number, '愛知県瀬戸市東松山町');
ok($zip->set_number('4890071')->is_valid_number, '愛知県瀬戸市暁町');
ok($zip->set_number('4890072')->is_valid_number, '愛知県瀬戸市東印所町');
ok($zip->set_number('4890073')->is_valid_number, '愛知県瀬戸市泉町');
ok($zip->set_number('4890074')->is_valid_number, '愛知県瀬戸市宮脇町');
ok($zip->set_number('4890075')->is_valid_number, '愛知県瀬戸市新道町');
ok($zip->set_number('4890076')->is_valid_number, '愛知県瀬戸市深川町');
ok($zip->set_number('4890077')->is_valid_number, '愛知県瀬戸市宮里町');
ok($zip->set_number('4890078')->is_valid_number, '愛知県瀬戸市湯之根町');
ok($zip->set_number('4890079')->is_valid_number, '愛知県瀬戸市西印所町');
ok($zip->set_number('4890801')->is_valid_number, '愛知県瀬戸市汗干町');
ok($zip->set_number('4890802')->is_valid_number, '愛知県瀬戸市今池町');
ok($zip->set_number('4890803')->is_valid_number, '愛知県瀬戸市追分町');
ok($zip->set_number('4890804')->is_valid_number, '愛知県瀬戸市京町');
ok($zip->set_number('4890805')->is_valid_number, '愛知県瀬戸市陶原町');
ok($zip->set_number('4890806')->is_valid_number, '愛知県瀬戸市東吉田町');
ok($zip->set_number('4890807')->is_valid_number, '愛知県瀬戸市西吉田町');
ok($zip->set_number('4890808')->is_valid_number, '愛知県瀬戸市見付町');
ok($zip->set_number('4890809')->is_valid_number, '愛知県瀬戸市共栄通');
ok($zip->set_number('4890811')->is_valid_number, '愛知県瀬戸市山脇町');
ok($zip->set_number('4890812')->is_valid_number, '愛知県瀬戸市西蔵所町');
ok($zip->set_number('4890813')->is_valid_number, '愛知県瀬戸市蔵所町');
ok($zip->set_number('4890814')->is_valid_number, '愛知県瀬戸市末広町');
ok($zip->set_number('4890815')->is_valid_number, '愛知県瀬戸市南仲之切町');
ok($zip->set_number('4890816')->is_valid_number, '愛知県瀬戸市東本町');
ok($zip->set_number('4890817')->is_valid_number, '愛知県瀬戸市銀杏木町');
ok($zip->set_number('4890818')->is_valid_number, '愛知県瀬戸市幸町');
ok($zip->set_number('4890819')->is_valid_number, '愛知県瀬戸市西本町');
ok($zip->set_number('4890821')->is_valid_number, '愛知県瀬戸市薬師町');
ok($zip->set_number('4890822')->is_valid_number, '愛知県瀬戸市杉塚町');
ok($zip->set_number('4890823')->is_valid_number, '愛知県瀬戸市東郷町');
ok($zip->set_number('4890824')->is_valid_number, '愛知県瀬戸市仲郷町');
ok($zip->set_number('4890825')->is_valid_number, '愛知県瀬戸市祖母懐町');
ok($zip->set_number('4890826')->is_valid_number, '愛知県瀬戸市蛭子町');
ok($zip->set_number('4890827')->is_valid_number, '愛知県瀬戸市陶生町');
ok($zip->set_number('4890828')->is_valid_number, '愛知県瀬戸市前田町');
ok($zip->set_number('4890829')->is_valid_number, '愛知県瀬戸市西郷町');
ok($zip->set_number('4890831')->is_valid_number, '愛知県瀬戸市藤四郎町');
ok($zip->set_number('4890832')->is_valid_number, '愛知県瀬戸市王子沢町');
ok($zip->set_number('4890833')->is_valid_number, '愛知県瀬戸市仲洞町');
ok($zip->set_number('4890834')->is_valid_number, '愛知県瀬戸市南東町');
ok($zip->set_number('4890835')->is_valid_number, '愛知県瀬戸市中山町');
ok($zip->set_number('4890836')->is_valid_number, '愛知県瀬戸市一里塚町');
ok($zip->set_number('4890837')->is_valid_number, '愛知県瀬戸市西洞町');
ok($zip->set_number('4890838')->is_valid_number, '愛知県瀬戸市寺本町');
ok($zip->set_number('4890841')->is_valid_number, '愛知県瀬戸市東洞町');
ok($zip->set_number('4890842')->is_valid_number, '愛知県瀬戸市小空町');
ok($zip->set_number('4890843')->is_valid_number, '愛知県瀬戸市惣作町');
ok($zip->set_number('4890844')->is_valid_number, '愛知県瀬戸市門前町');
ok($zip->set_number('4890845')->is_valid_number, '愛知県瀬戸市鐘場町');
ok($zip->set_number('4890846')->is_valid_number, '愛知県瀬戸市太子町');
ok($zip->set_number('4890847')->is_valid_number, '愛知県瀬戸市東町');
ok($zip->set_number('4890848')->is_valid_number, '愛知県瀬戸市西拝戸町');
ok($zip->set_number('4890849')->is_valid_number, '愛知県瀬戸市新明町');
ok($zip->set_number('4890851')->is_valid_number, '愛知県瀬戸市西山路町');
ok($zip->set_number('4890852')->is_valid_number, '愛知県瀬戸市巡間町');
ok($zip->set_number('4890853')->is_valid_number, '愛知県瀬戸市上山路町');
ok($zip->set_number('4890854')->is_valid_number, '愛知県瀬戸市東山路町');
ok($zip->set_number('4890855')->is_valid_number, '愛知県瀬戸市海上町');
ok($zip->set_number('4890856')->is_valid_number, '愛知県瀬戸市広久手町');
ok($zip->set_number('4890857')->is_valid_number, '愛知県瀬戸市吉野町');
ok($zip->set_number('4890858')->is_valid_number, '愛知県瀬戸市屋戸町');
ok($zip->set_number('4890859')->is_valid_number, '愛知県瀬戸市山路町');
ok($zip->set_number('4890861')->is_valid_number, '愛知県瀬戸市八幡台');
ok($zip->set_number('4890862')->is_valid_number, '愛知県瀬戸市八幡町');
ok($zip->set_number('4890863')->is_valid_number, '愛知県瀬戸市せいれい町');
ok($zip->set_number('4890864')->is_valid_number, '愛知県瀬戸市若宮町');
ok($zip->set_number('4890865')->is_valid_number, '愛知県瀬戸市山口町');
ok($zip->set_number('4890866')->is_valid_number, '愛知県瀬戸市矢形町');
ok($zip->set_number('4890867')->is_valid_number, '愛知県瀬戸市大坂町');
ok($zip->set_number('4890868')->is_valid_number, '愛知県瀬戸市今林町');
ok($zip->set_number('4890871')->is_valid_number, '愛知県瀬戸市東長根町');
ok($zip->set_number('4890872')->is_valid_number, '愛知県瀬戸市水無瀬町');
ok($zip->set_number('4890873')->is_valid_number, '愛知県瀬戸市新郷町');
ok($zip->set_number('4890874')->is_valid_number, '愛知県瀬戸市幡野町');
ok($zip->set_number('4890875')->is_valid_number, '愛知県瀬戸市緑町');
ok($zip->set_number('4890876')->is_valid_number, '愛知県瀬戸市白山町');
ok($zip->set_number('4890877')->is_valid_number, '愛知県瀬戸市東赤重町');
ok($zip->set_number('4890878')->is_valid_number, '愛知県瀬戸市赤重町');
ok($zip->set_number('4890879')->is_valid_number, '愛知県瀬戸市瘤木町');
ok($zip->set_number('4890881')->is_valid_number, '愛知県瀬戸市熊野町');
ok($zip->set_number('4890882')->is_valid_number, '愛知県瀬戸市西権現町');
ok($zip->set_number('4890883')->is_valid_number, '愛知県瀬戸市東権現町');
ok($zip->set_number('4890884')->is_valid_number, '愛知県瀬戸市西茨町');
ok($zip->set_number('4890885')->is_valid_number, '愛知県瀬戸市萩殿町');
ok($zip->set_number('4890886')->is_valid_number, '愛知県瀬戸市萩山台');
ok($zip->set_number('4890887')->is_valid_number, '愛知県瀬戸市菱野台');
ok($zip->set_number('4890888')->is_valid_number, '愛知県瀬戸市原山台');
ok($zip->set_number('4890889')->is_valid_number, '愛知県瀬戸市原山町');
ok($zip->set_number('4890891')->is_valid_number, '愛知県瀬戸市陶栄町');
ok($zip->set_number('4890892')->is_valid_number, '愛知県瀬戸市上ノ切町');
ok($zip->set_number('4890893')->is_valid_number, '愛知県瀬戸市春雨町');
ok($zip->set_number('4890894')->is_valid_number, '愛知県瀬戸市川合町');
ok($zip->set_number('4890895')->is_valid_number, '愛知県瀬戸市塩草町');
ok($zip->set_number('4890896')->is_valid_number, '愛知県瀬戸市宝ケ丘町');
ok($zip->set_number('4890897')->is_valid_number, '愛知県瀬戸市東茨町');
ok($zip->set_number('4890898')->is_valid_number, '愛知県瀬戸市秋葉町');
ok($zip->set_number('4890899')->is_valid_number, '愛知県瀬戸市塩草が丘');
ok($zip->set_number('4890901')->is_valid_number, '愛知県瀬戸市十軒町');
ok($zip->set_number('4890902')->is_valid_number, '愛知県瀬戸市内田町');
ok($zip->set_number('4890903')->is_valid_number, '愛知県瀬戸市ゆりの台');
ok($zip->set_number('4890904')->is_valid_number, '愛知県瀬戸市すみれ台');
ok($zip->set_number('4890905')->is_valid_number, '愛知県瀬戸市はぎの台');
ok($zip->set_number('4890906')->is_valid_number, '愛知県瀬戸市本郷町');
ok($zip->set_number('4890907')->is_valid_number, '愛知県瀬戸市ふじの台');
ok($zip->set_number('4890908')->is_valid_number, '愛知県瀬戸市ききょう台');
ok($zip->set_number('4890909')->is_valid_number, '愛知県瀬戸市みずの坂');
ok($zip->set_number('4890910')->is_valid_number, '愛知県瀬戸市北みずの坂');
ok($zip->set_number('4890911')->is_valid_number, '愛知県瀬戸市北松山町');
ok($zip->set_number('4890912')->is_valid_number, '愛知県瀬戸市西松山町');
ok($zip->set_number('4890913')->is_valid_number, '愛知県瀬戸市水南町');
ok($zip->set_number('4890914')->is_valid_number, '愛知県瀬戸市孫田町');
ok($zip->set_number('4890915')->is_valid_number, '愛知県瀬戸市北浦町');
ok($zip->set_number('4890916')->is_valid_number, '愛知県瀬戸市平町');
ok($zip->set_number('4890917')->is_valid_number, '愛知県瀬戸市效範町');
ok($zip->set_number('4890918')->is_valid_number, '愛知県瀬戸市北脇町');
ok($zip->set_number('4890919')->is_valid_number, '愛知県瀬戸市川端町');
ok($zip->set_number('4890921')->is_valid_number, '愛知県瀬戸市田端町');
ok($zip->set_number('4890922')->is_valid_number, '愛知県瀬戸市市場町');
ok($zip->set_number('4890923')->is_valid_number, '愛知県瀬戸市城屋敷町');
ok($zip->set_number('4890924')->is_valid_number, '愛知県瀬戸市城ケ根町');
ok($zip->set_number('4890925')->is_valid_number, '愛知県瀬戸市西寺山町');
ok($zip->set_number('4890926')->is_valid_number, '愛知県瀬戸市川西町');
ok($zip->set_number('4890927')->is_valid_number, '愛知県瀬戸市川北町');
ok($zip->set_number('4890928')->is_valid_number, '愛知県瀬戸市東寺山町');
ok($zip->set_number('4890929')->is_valid_number, '愛知県瀬戸市西長根町');
ok($zip->set_number('4890931')->is_valid_number, '愛知県瀬戸市高根町');
ok($zip->set_number('4890932')->is_valid_number, '愛知県瀬戸市美濃池町');
ok($zip->set_number('4890933')->is_valid_number, '愛知県瀬戸市神川町');
ok($zip->set_number('4890934')->is_valid_number, '愛知県瀬戸市菱野町');
ok($zip->set_number('4890935')->is_valid_number, '愛知県瀬戸市福元町');
ok($zip->set_number('4890936')->is_valid_number, '愛知県瀬戸市西脇町');
ok($zip->set_number('4890937')->is_valid_number, '愛知県瀬戸市南菱野町');
ok($zip->set_number('4890938')->is_valid_number, '愛知県瀬戸市幡西町');
ok($zip->set_number('4890941')->is_valid_number, '愛知県瀬戸市瀬戸口町');
ok($zip->set_number('4890942')->is_valid_number, '愛知県瀬戸市東菱野町');
ok($zip->set_number('4890943')->is_valid_number, '愛知県瀬戸市西米泉町');
ok($zip->set_number('4890944')->is_valid_number, '愛知県瀬戸市東米泉町');
ok($zip->set_number('4890945')->is_valid_number, '愛知県瀬戸市弁天町');
ok($zip->set_number('4890946')->is_valid_number, '愛知県瀬戸市幡中町');
ok($zip->set_number('4890947')->is_valid_number, '愛知県瀬戸市羽根町');
ok($zip->set_number('4890948')->is_valid_number, '愛知県瀬戸市幡山町');
ok($zip->set_number('4890949')->is_valid_number, '愛知県瀬戸市新田町');
ok($zip->set_number('4890951')->is_valid_number, '愛知県瀬戸市石田町');
ok($zip->set_number('4890952')->is_valid_number, '愛知県瀬戸市池田町');
ok($zip->set_number('4890953')->is_valid_number, '愛知県瀬戸市柳ケ坪町');
ok($zip->set_number('4890954')->is_valid_number, '愛知県瀬戸市台六町');
ok($zip->set_number('4890955')->is_valid_number, '愛知県瀬戸市南ケ丘町');
ok($zip->set_number('4890961')->is_valid_number, '愛知県瀬戸市田中町');
ok($zip->set_number('4890962')->is_valid_number, '愛知県瀬戸市大坪町');
ok($zip->set_number('4890963')->is_valid_number, '愛知県瀬戸市宮地町');
ok($zip->set_number('4890964')->is_valid_number, '愛知県瀬戸市上之山町');
ok($zip->set_number('4890965')->is_valid_number, '愛知県瀬戸市南山口町');
ok($zip->set_number('4890966')->is_valid_number, '愛知県瀬戸市掛下町');
ok($zip->set_number('4890971')->is_valid_number, '愛知県瀬戸市西本地町');
ok($zip->set_number('4890972')->is_valid_number, '愛知県瀬戸市西原町');
ok($zip->set_number('4890973')->is_valid_number, '愛知県瀬戸市東本地町');
ok($zip->set_number('4890974')->is_valid_number, '愛知県瀬戸市駒前町');
ok($zip->set_number('4890975')->is_valid_number, '愛知県瀬戸市山の田町');
ok($zip->set_number('4890976')->is_valid_number, '愛知県瀬戸市井戸金町');
ok($zip->set_number('4890977')->is_valid_number, '愛知県瀬戸市坂上町');
ok($zip->set_number('4890978')->is_valid_number, '愛知県瀬戸市小坂町');
ok($zip->set_number('4890979')->is_valid_number, '愛知県瀬戸市坊金町');
ok($zip->set_number('4890980')->is_valid_number, '愛知県瀬戸市やまて坂');
ok($zip->set_number('4890981')->is_valid_number, '愛知県瀬戸市ひまわり台');
ok($zip->set_number('4890982')->is_valid_number, '愛知県瀬戸市さつき台');
ok($zip->set_number('4890983')->is_valid_number, '愛知県瀬戸市苗場町');
ok($zip->set_number('4890984')->is_valid_number, '愛知県瀬戸市北山町');
ok($zip->set_number('4890985')->is_valid_number, '愛知県瀬戸市松原町');
ok($zip->set_number('4890986')->is_valid_number, '愛知県瀬戸市南山町');
ok($zip->set_number('4890987')->is_valid_number, '愛知県瀬戸市西山町');
ok($zip->set_number('4890988')->is_valid_number, '愛知県瀬戸市東山町');
ok($zip->set_number('4890989')->is_valid_number, '愛知県瀬戸市山手町');
ok($zip->set_number('4901100')->is_valid_number, '愛知県海部郡大治町以下に掲載がない場合');
ok($zip->set_number('4901101')->is_valid_number, '愛知県あま市方領');
ok($zip->set_number('4901102')->is_valid_number, '愛知県あま市石作');
ok($zip->set_number('4901103')->is_valid_number, '愛知県あま市栄');
ok($zip->set_number('4901104')->is_valid_number, '愛知県あま市西今宿');
ok($zip->set_number('4901105')->is_valid_number, '愛知県あま市新居屋');
ok($zip->set_number('4901106')->is_valid_number, '愛知県あま市小路');
ok($zip->set_number('4901107')->is_valid_number, '愛知県あま市森');
ok($zip->set_number('4901111')->is_valid_number, '愛知県あま市甚目寺');
ok($zip->set_number('4901112')->is_valid_number, '愛知県あま市上萱津');
ok($zip->set_number('4901113')->is_valid_number, '愛知県あま市中萱津');
ok($zip->set_number('4901114')->is_valid_number, '愛知県あま市下萱津');
ok($zip->set_number('4901115')->is_valid_number, '愛知県あま市坂牧');
ok($zip->set_number('4901116')->is_valid_number, '愛知県あま市本郷');
ok($zip->set_number('4901131')->is_valid_number, '愛知県海部郡大治町長牧');
ok($zip->set_number('4901132')->is_valid_number, '愛知県海部郡大治町北間島');
ok($zip->set_number('4901133')->is_valid_number, '愛知県海部郡大治町八ツ屋');
ok($zip->set_number('4901134')->is_valid_number, '愛知県海部郡大治町東條');
ok($zip->set_number('4901135')->is_valid_number, '愛知県海部郡大治町鎌須賀');
ok($zip->set_number('4901136')->is_valid_number, '愛知県海部郡大治町花常');
ok($zip->set_number('4901137')->is_valid_number, '愛知県海部郡大治町堀之内');
ok($zip->set_number('4901141')->is_valid_number, '愛知県海部郡大治町馬島');
ok($zip->set_number('4901142')->is_valid_number, '愛知県海部郡大治町三本木');
ok($zip->set_number('4901143')->is_valid_number, '愛知県海部郡大治町砂子');
ok($zip->set_number('4901144')->is_valid_number, '愛知県海部郡大治町西條');
ok($zip->set_number('4901145')->is_valid_number, '愛知県海部郡大治町中島');
ok($zip->set_number('4901200')->is_valid_number, '愛知県あま市以下に掲載がない場合');
ok($zip->set_number('4901201')->is_valid_number, '愛知県あま市古道');
ok($zip->set_number('4901202')->is_valid_number, '愛知県あま市富塚');
ok($zip->set_number('4901203')->is_valid_number, '愛知県あま市木折');
ok($zip->set_number('4901204')->is_valid_number, '愛知県あま市花長');
ok($zip->set_number('4901205')->is_valid_number, '愛知県あま市花正');
ok($zip->set_number('4901206')->is_valid_number, '愛知県あま市東溝口');
ok($zip->set_number('4901207')->is_valid_number, '愛知県あま市二ツ寺');
ok($zip->set_number('4901211')->is_valid_number, '愛知県あま市篠田');
ok($zip->set_number('4901212')->is_valid_number, '愛知県あま市小橋方');
ok($zip->set_number('4901213')->is_valid_number, '愛知県あま市乙之子');
ok($zip->set_number('4901214')->is_valid_number, '愛知県あま市北苅');
ok($zip->set_number('4901221')->is_valid_number, '愛知県あま市金岩');
ok($zip->set_number('4901222')->is_valid_number, '愛知県あま市木田');
ok($zip->set_number('4901223')->is_valid_number, '愛知県あま市森山');
ok($zip->set_number('4901224')->is_valid_number, '愛知県あま市丹波');
ok($zip->set_number('4901225')->is_valid_number, '愛知県あま市蜂須賀');
ok($zip->set_number('4901226')->is_valid_number, '愛知県あま市中橋');
ok($zip->set_number('4901301')->is_valid_number, '愛知県稲沢市平和町須ケ谷');
ok($zip->set_number('4901302')->is_valid_number, '愛知県稲沢市平和町観音堂');
ok($zip->set_number('4901303')->is_valid_number, '愛知県稲沢市平和町上三宅');
ok($zip->set_number('4901304')->is_valid_number, '愛知県稲沢市平和町法立');
ok($zip->set_number('4901305')->is_valid_number, '愛知県稲沢市平和町(丸渕上、丸渕下、鷲尾)');
ok($zip->set_number('4901311')->is_valid_number, '愛知県稲沢市平和町中三宅');
ok($zip->set_number('4901312')->is_valid_number, '愛知県稲沢市平和町下三宅');
ok($zip->set_number('4901313')->is_valid_number, '愛知県稲沢市平和町横池');
ok($zip->set_number('4901314')->is_valid_number, '愛知県稲沢市平和町西光坊');
ok($zip->set_number('4901315')->is_valid_number, '愛知県稲沢市平和町平池');
ok($zip->set_number('4901321')->is_valid_number, '愛知県稲沢市平和町東城');
ok($zip->set_number('4901322')->is_valid_number, '愛知県稲沢市平和町(上前浪、下前浪)');
ok($zip->set_number('4901323')->is_valid_number, '愛知県稲沢市平和町(光和、塩川、下起北、下起中、下起東、下起南、勝幡新田、城西、');
ok($zip->set_number('4901323')->is_valid_number, '愛知県稲沢市城之内、須ケ脇、那古良、平六、前平、明和、嫁振、嫁振北、嫁振東、領内)');
ok($zip->set_number('4901400')->is_valid_number, '愛知県海部郡飛島村以下に掲載がない場合');
ok($zip->set_number('4901401')->is_valid_number, '愛知県弥富市六條町');
ok($zip->set_number('4901402')->is_valid_number, '愛知県弥富市五斗山');
ok($zip->set_number('4901403')->is_valid_number, '愛知県弥富市鳥ケ地');
ok($zip->set_number('4901403')->is_valid_number, '愛知県弥富市鳥ケ地町');
ok($zip->set_number('4901404')->is_valid_number, '愛知県弥富市桴場');
ok($zip->set_number('4901405')->is_valid_number, '愛知県弥富市神戸');
ok($zip->set_number('4901405')->is_valid_number, '愛知県弥富市神戸町');
ok($zip->set_number('4901406')->is_valid_number, '愛知県弥富市鍋平');
ok($zip->set_number('4901407')->is_valid_number, '愛知県弥富市三百島');
ok($zip->set_number('4901411')->is_valid_number, '愛知県弥富市善太町');
ok($zip->set_number('4901412')->is_valid_number, '愛知県弥富市馬ケ地');
ok($zip->set_number('4901413')->is_valid_number, '愛知県弥富市子宝');
ok($zip->set_number('4901413')->is_valid_number, '愛知県弥富市子宝町');
ok($zip->set_number('4901414')->is_valid_number, '愛知県弥富市坂中地');
ok($zip->set_number('4901414')->is_valid_number, '愛知県弥富市坂中地町');
ok($zip->set_number('4901415')->is_valid_number, '愛知県弥富市鮫ケ地');
ok($zip->set_number('4901415')->is_valid_number, '愛知県弥富市鮫ケ地町');
ok($zip->set_number('4901421')->is_valid_number, '愛知県弥富市上押萩');
ok($zip->set_number('4901421')->is_valid_number, '愛知県弥富市上押萩町');
ok($zip->set_number('4901422')->is_valid_number, '愛知県弥富市下押萩');
ok($zip->set_number('4901422')->is_valid_number, '愛知県弥富市下押萩町');
ok($zip->set_number('4901423')->is_valid_number, '愛知県弥富市海屋');
ok($zip->set_number('4901423')->is_valid_number, '愛知県弥富市海屋町');
ok($zip->set_number('4901424')->is_valid_number, '愛知県弥富市亀ケ地');
ok($zip->set_number('4901425')->is_valid_number, '愛知県弥富市東蜆');
ok($zip->set_number('4901426')->is_valid_number, '愛知県弥富市四郎兵衛');
ok($zip->set_number('4901426')->is_valid_number, '愛知県弥富市四郎兵衛町');
ok($zip->set_number('4901427')->is_valid_number, '愛知県弥富市西蜆');
ok($zip->set_number('4901428')->is_valid_number, '愛知県弥富市竹田');
ok($zip->set_number('4901431')->is_valid_number, '愛知県海部郡飛島村服岡');
ok($zip->set_number('4901432')->is_valid_number, '愛知県海部郡飛島村三福');
ok($zip->set_number('4901433')->is_valid_number, '愛知県海部郡飛島村渚');
ok($zip->set_number('4901434')->is_valid_number, '愛知県海部郡飛島村松之郷');
ok($zip->set_number('4901435')->is_valid_number, '愛知県海部郡飛島村梅之郷');
ok($zip->set_number('4901436')->is_valid_number, '愛知県海部郡飛島村竹之郷');
ok($zip->set_number('4901437')->is_valid_number, '愛知県海部郡飛島村飛島新田(元起之郷)');
ok($zip->set_number('4901437')->is_valid_number, '愛知県海部郡飛島村元起');
ok($zip->set_number('4901438')->is_valid_number, '愛知県海部郡飛島村大宝');
ok($zip->set_number('4901441')->is_valid_number, '愛知県海部郡飛島村政成');
ok($zip->set_number('4901442')->is_valid_number, '愛知県海部郡飛島村古政成');
ok($zip->set_number('4901443')->is_valid_number, '愛知県海部郡飛島村新政成');
ok($zip->set_number('4901444')->is_valid_number, '愛知県海部郡飛島村木場');
ok($zip->set_number('4901445')->is_valid_number, '愛知県海部郡飛島村金岡');
ok($zip->set_number('4901446')->is_valid_number, '愛知県海部郡飛島村東浜');
ok($zip->set_number('4901447')->is_valid_number, '愛知県海部郡飛島村西浜');
ok($zip->set_number('4910000')->is_valid_number, '愛知県一宮市以下に掲載がない場合');
ok($zip->set_number('4910001')->is_valid_number, '愛知県一宮市瀬部');
ok($zip->set_number('4910002')->is_valid_number, '愛知県一宮市時之島');
ok($zip->set_number('4910003')->is_valid_number, '愛知県一宮市春明');
ok($zip->set_number('4910004')->is_valid_number, '愛知県一宮市定水寺');
ok($zip->set_number('4910005')->is_valid_number, '愛知県一宮市西大海道');
ok($zip->set_number('4910011')->is_valid_number, '愛知県一宮市柚木颪');
ok($zip->set_number('4910012')->is_valid_number, '愛知県一宮市小赤見');
ok($zip->set_number('4910013')->is_valid_number, '愛知県一宮市北小渕');
ok($zip->set_number('4910014')->is_valid_number, '愛知県一宮市南小渕');
ok($zip->set_number('4910015')->is_valid_number, '愛知県一宮市大赤見');
ok($zip->set_number('4910021')->is_valid_number, '愛知県一宮市東両郷町');
ok($zip->set_number('4910022')->is_valid_number, '愛知県一宮市両郷町');
ok($zip->set_number('4910023')->is_valid_number, '愛知県一宮市赤見');
ok($zip->set_number('4910024')->is_valid_number, '愛知県一宮市富士');
ok($zip->set_number('4910025')->is_valid_number, '愛知県一宮市羽衣');
ok($zip->set_number('4910026')->is_valid_number, '愛知県一宮市和光');
ok($zip->set_number('4910027')->is_valid_number, '愛知県一宮市藤塚町');
ok($zip->set_number('4910028')->is_valid_number, '愛知県一宮市朝日');
ok($zip->set_number('4910031')->is_valid_number, '愛知県一宮市観音町');
ok($zip->set_number('4910032')->is_valid_number, '愛知県一宮市下沼町');
ok($zip->set_number('4910033')->is_valid_number, '愛知県一宮市別明町');
ok($zip->set_number('4910034')->is_valid_number, '愛知県一宮市浜町');
ok($zip->set_number('4910035')->is_valid_number, '愛知県一宮市大浜');
ok($zip->set_number('4910036')->is_valid_number, '愛知県一宮市桜');
ok($zip->set_number('4910037')->is_valid_number, '愛知県一宮市貴船');
ok($zip->set_number('4910041')->is_valid_number, '愛知県一宮市文京');
ok($zip->set_number('4910042')->is_valid_number, '愛知県一宮市松降');
ok($zip->set_number('4910043')->is_valid_number, '愛知県一宮市真清田');
ok($zip->set_number('4910044')->is_valid_number, '愛知県一宮市大宮');
ok($zip->set_number('4910045')->is_valid_number, '愛知県一宮市音羽');
ok($zip->set_number('4910046')->is_valid_number, '愛知県一宮市天王');
ok($zip->set_number('4910051')->is_valid_number, '愛知県一宮市今伊勢町馬寄(その他)');
ok($zip->set_number('4910052')->is_valid_number, '愛知県一宮市今伊勢町新神戸');
ok($zip->set_number('4910053')->is_valid_number, '愛知県一宮市今伊勢町本神戸');
ok($zip->set_number('4910054')->is_valid_number, '愛知県一宮市大正通');
ok($zip->set_number('4910055')->is_valid_number, '愛知県一宮市神戸町');
ok($zip->set_number('4910056')->is_valid_number, '愛知県一宮市東出町');
ok($zip->set_number('4910057')->is_valid_number, '愛知県一宮市今伊勢町宮後');
ok($zip->set_number('4910058')->is_valid_number, '愛知県一宮市今伊勢町馬寄(舟入)');
ok($zip->set_number('4910059')->is_valid_number, '愛知県一宮市一宮');
ok($zip->set_number('4910061')->is_valid_number, '愛知県一宮市乾町');
ok($zip->set_number('4910062')->is_valid_number, '愛知県一宮市西島町');
ok($zip->set_number('4910063')->is_valid_number, '愛知県一宮市常願通');
ok($zip->set_number('4910064')->is_valid_number, '愛知県一宮市宮西通');
ok($zip->set_number('4910065')->is_valid_number, '愛知県一宮市水落町');
ok($zip->set_number('4910066')->is_valid_number, '愛知県一宮市三丹町');
ok($zip->set_number('4910067')->is_valid_number, '愛知県一宮市北丹町');
ok($zip->set_number('4910068')->is_valid_number, '愛知県一宮市小栗町');
ok($zip->set_number('4910069')->is_valid_number, '愛知県一宮市北神明町');
ok($zip->set_number('4910071')->is_valid_number, '愛知県一宮市長島町');
ok($zip->set_number('4910072')->is_valid_number, '愛知県一宮市中島通');
ok($zip->set_number('4910073')->is_valid_number, '愛知県一宮市高畑町');
ok($zip->set_number('4910074')->is_valid_number, '愛知県一宮市東島町');
ok($zip->set_number('4910075')->is_valid_number, '愛知県一宮市寺島町');
ok($zip->set_number('4910076')->is_valid_number, '愛知県一宮市貴船町');
ok($zip->set_number('4910077')->is_valid_number, '愛知県一宮市枠杁町');
ok($zip->set_number('4910078')->is_valid_number, '愛知県一宮市松降通');
ok($zip->set_number('4910079')->is_valid_number, '愛知県一宮市九品町');
ok($zip->set_number('4910081')->is_valid_number, '愛知県一宮市西小原町');
ok($zip->set_number('4910082')->is_valid_number, '愛知県一宮市小原町');
ok($zip->set_number('4910083')->is_valid_number, '愛知県一宮市丹羽');
ok($zip->set_number('4910084')->is_valid_number, '愛知県一宮市古見町');
ok($zip->set_number('4910085')->is_valid_number, '愛知県一宮市松山町');
ok($zip->set_number('4910086')->is_valid_number, '愛知県一宮市田島町');
ok($zip->set_number('4910101')->is_valid_number, '愛知県一宮市浅井町尾関');
ok($zip->set_number('4910102')->is_valid_number, '愛知県一宮市浅井町尾関(長田)');
ok($zip->set_number('4910103')->is_valid_number, '愛知県一宮市浅井町前野');
ok($zip->set_number('4910104')->is_valid_number, '愛知県一宮市浅井町小日比野');
ok($zip->set_number('4910105')->is_valid_number, '愛知県一宮市浅井町大日比野');
ok($zip->set_number('4910111')->is_valid_number, '愛知県一宮市浅井町河端');
ok($zip->set_number('4910112')->is_valid_number, '愛知県一宮市浅井町東浅井');
ok($zip->set_number('4910113')->is_valid_number, '愛知県一宮市浅井町西浅井');
ok($zip->set_number('4910114')->is_valid_number, '愛知県一宮市浅井町江森');
ok($zip->set_number('4910115')->is_valid_number, '愛知県一宮市浅井町西海戸');
ok($zip->set_number('4910121')->is_valid_number, '愛知県一宮市島村');
ok($zip->set_number('4910122')->is_valid_number, '愛知県一宮市島村(西山)');
ok($zip->set_number('4910123')->is_valid_number, '愛知県一宮市富塚');
ok($zip->set_number('4910124')->is_valid_number, '愛知県一宮市佐千原');
ok($zip->set_number('4910125')->is_valid_number, '愛知県一宮市高田');
ok($zip->set_number('4910131')->is_valid_number, '愛知県一宮市笹野');
ok($zip->set_number('4910132')->is_valid_number, '愛知県一宮市大毛');
ok($zip->set_number('4910133')->is_valid_number, '愛知県一宮市田所');
ok($zip->set_number('4910134')->is_valid_number, '愛知県一宮市更屋敷');
ok($zip->set_number('4910135')->is_valid_number, '愛知県一宮市光明寺');
ok($zip->set_number('4910136')->is_valid_number, '愛知県一宮市杉山');
ok($zip->set_number('4910141')->is_valid_number, '愛知県一宮市浅井町黒岩');
ok($zip->set_number('4910142')->is_valid_number, '愛知県一宮市浅井町河田');
ok($zip->set_number('4910143')->is_valid_number, '愛知県一宮市浅井町大野');
ok($zip->set_number('4910144')->is_valid_number, '愛知県一宮市浅井町極楽寺');
ok($zip->set_number('4910201')->is_valid_number, '愛知県一宮市奥町');
ok($zip->set_number('4910351')->is_valid_number, '愛知県一宮市萩原町花井方');
ok($zip->set_number('4910352')->is_valid_number, '愛知県一宮市萩原町富田方');
ok($zip->set_number('4910353')->is_valid_number, '愛知県一宮市萩原町萩原');
ok($zip->set_number('4910354')->is_valid_number, '愛知県一宮市萩原町朝宮');
ok($zip->set_number('4910361')->is_valid_number, '愛知県一宮市萩原町林野');
ok($zip->set_number('4910362')->is_valid_number, '愛知県一宮市萩原町西宮重');
ok($zip->set_number('4910363')->is_valid_number, '愛知県一宮市萩原町東宮重');
ok($zip->set_number('4910364')->is_valid_number, '愛知県一宮市萩原町中島');
ok($zip->set_number('4910365')->is_valid_number, '愛知県一宮市萩原町西御堂');
ok($zip->set_number('4910366')->is_valid_number, '愛知県一宮市萩原町河田方');
ok($zip->set_number('4910371')->is_valid_number, '愛知県一宮市萩原町高木');
ok($zip->set_number('4910372')->is_valid_number, '愛知県一宮市萩原町滝');
ok($zip->set_number('4910373')->is_valid_number, '愛知県一宮市萩原町高松');
ok($zip->set_number('4910374')->is_valid_number, '愛知県一宮市萩原町築込');
ok($zip->set_number('4910375')->is_valid_number, '愛知県一宮市萩原町戸苅');
ok($zip->set_number('4910376')->is_valid_number, '愛知県一宮市萩原町串作');
ok($zip->set_number('4910801')->is_valid_number, '愛知県一宮市千秋町加茂');
ok($zip->set_number('4910802')->is_valid_number, '愛知県一宮市千秋町勝栗');
ok($zip->set_number('4910803')->is_valid_number, '愛知県一宮市千秋町穂積塚本');
ok($zip->set_number('4910804')->is_valid_number, '愛知県一宮市千秋町佐野');
ok($zip->set_number('4910805')->is_valid_number, '愛知県一宮市千秋町一色');
ok($zip->set_number('4910806')->is_valid_number, '愛知県一宮市千秋町浮野');
ok($zip->set_number('4910811')->is_valid_number, '愛知県一宮市千秋町加納馬場');
ok($zip->set_number('4910812')->is_valid_number, '愛知県一宮市千秋町芝原');
ok($zip->set_number('4910813')->is_valid_number, '愛知県一宮市千秋町町屋');
ok($zip->set_number('4910814')->is_valid_number, '愛知県一宮市千秋町小山');
ok($zip->set_number('4910815')->is_valid_number, '愛知県一宮市千秋町塩尻');
ok($zip->set_number('4910816')->is_valid_number, '愛知県一宮市千秋町浅野羽根');
ok($zip->set_number('4910817')->is_valid_number, '愛知県一宮市千秋町天摩');
ok($zip->set_number('4910821')->is_valid_number, '愛知県一宮市丹陽町重吉');
ok($zip->set_number('4910823')->is_valid_number, '愛知県一宮市丹陽町五日市場');
ok($zip->set_number('4910824')->is_valid_number, '愛知県一宮市丹陽町九日市場');
ok($zip->set_number('4910825')->is_valid_number, '愛知県一宮市丹陽町外崎');
ok($zip->set_number('4910826')->is_valid_number, '愛知県一宮市丹陽町三ツ井');
ok($zip->set_number('4910827')->is_valid_number, '愛知県一宮市丹陽町森本');
ok($zip->set_number('4910827')->is_valid_number, '愛知県一宮市三ツ井');
ok($zip->set_number('4910828')->is_valid_number, '愛知県一宮市伝法寺');
ok($zip->set_number('4910831')->is_valid_number, '愛知県一宮市森本');
ok($zip->set_number('4910832')->is_valid_number, '愛知県一宮市若竹');
ok($zip->set_number('4910833')->is_valid_number, '愛知県一宮市平島');
ok($zip->set_number('4910834')->is_valid_number, '愛知県一宮市島崎');
ok($zip->set_number('4910835')->is_valid_number, '愛知県一宮市あずら');
ok($zip->set_number('4910836')->is_valid_number, '愛知県一宮市丹陽町多加木');
ok($zip->set_number('4910837')->is_valid_number, '愛知県一宮市多加木');
ok($zip->set_number('4910838')->is_valid_number, '愛知県一宮市猿海道');
ok($zip->set_number('4910838')->is_valid_number, '愛知県一宮市丹陽町猿海道');
ok($zip->set_number('4910841')->is_valid_number, '愛知県一宮市松島町');
ok($zip->set_number('4910842')->is_valid_number, '愛知県一宮市公園通');
ok($zip->set_number('4910843')->is_valid_number, '愛知県一宮市柳戸町');
ok($zip->set_number('4910844')->is_valid_number, '愛知県一宮市八町通');
ok($zip->set_number('4910845')->is_valid_number, '愛知県一宮市下川田町');
ok($zip->set_number('4910846')->is_valid_number, '愛知県一宮市牛野通');
ok($zip->set_number('4910847')->is_valid_number, '愛知県一宮市大和町宮地花池');
ok($zip->set_number('4910848')->is_valid_number, '愛知県一宮市殿町');
ok($zip->set_number('4910851')->is_valid_number, '愛知県一宮市大江');
ok($zip->set_number('4910852')->is_valid_number, '愛知県一宮市大志');
ok($zip->set_number('4910853')->is_valid_number, '愛知県一宮市川田町');
ok($zip->set_number('4910854')->is_valid_number, '愛知県一宮市北園通');
ok($zip->set_number('4910855')->is_valid_number, '愛知県一宮市石山町');
ok($zip->set_number('4910856')->is_valid_number, '愛知県一宮市本町通');
ok($zip->set_number('4910857')->is_valid_number, '愛知県一宮市明治通');
ok($zip->set_number('4910858')->is_valid_number, '愛知県一宮市栄');
ok($zip->set_number('4910859')->is_valid_number, '愛知県一宮市本町');
ok($zip->set_number('4910861')->is_valid_number, '愛知県一宮市泉');
ok($zip->set_number('4910862')->is_valid_number, '愛知県一宮市緑');
ok($zip->set_number('4910863')->is_valid_number, '愛知県一宮市東印田町');
ok($zip->set_number('4910865')->is_valid_number, '愛知県一宮市印田通');
ok($zip->set_number('4910866')->is_valid_number, '愛知県一宮市城崎通');
ok($zip->set_number('4910867')->is_valid_number, '愛知県一宮市古金町');
ok($zip->set_number('4910868')->is_valid_number, '愛知県一宮市向山南');
ok($zip->set_number('4910869')->is_valid_number, '愛知県一宮市向山町');
ok($zip->set_number('4910871')->is_valid_number, '愛知県一宮市浅野');
ok($zip->set_number('4910872')->is_valid_number, '愛知県一宮市平安');
ok($zip->set_number('4910873')->is_valid_number, '愛知県一宮市せんい');
ok($zip->set_number('4910874')->is_valid_number, '愛知県一宮市馬見塚');
ok($zip->set_number('4910878')->is_valid_number, '愛知県一宮市水附町');
ok($zip->set_number('4910879')->is_valid_number, '愛知県一宮市白旗通');
ok($zip->set_number('4910881')->is_valid_number, '愛知県一宮市南印田');
ok($zip->set_number('4910882')->is_valid_number, '愛知県一宮市相生');
ok($zip->set_number('4910883')->is_valid_number, '愛知県一宮市下田');
ok($zip->set_number('4910901')->is_valid_number, '愛知県一宮市北浦町');
ok($zip->set_number('4910902')->is_valid_number, '愛知県一宮市一色町');
ok($zip->set_number('4910903')->is_valid_number, '愛知県一宮市八幡');
ok($zip->set_number('4910904')->is_valid_number, '愛知県一宮市神山');
ok($zip->set_number('4910905')->is_valid_number, '愛知県一宮市平和');
ok($zip->set_number('4910906')->is_valid_number, '愛知県一宮市南出町');
ok($zip->set_number('4910907')->is_valid_number, '愛知県一宮市西出町');
ok($zip->set_number('4910908')->is_valid_number, '愛知県一宮市深坪町');
ok($zip->set_number('4910911')->is_valid_number, '愛知県一宮市野口');
ok($zip->set_number('4910912')->is_valid_number, '愛知県一宮市新生');
ok($zip->set_number('4910913')->is_valid_number, '愛知県一宮市中町');
ok($zip->set_number('4910914')->is_valid_number, '愛知県一宮市花池');
ok($zip->set_number('4910915')->is_valid_number, '愛知県一宮市宮地');
ok($zip->set_number('4910916')->is_valid_number, '愛知県一宮市観音寺');
ok($zip->set_number('4910917')->is_valid_number, '愛知県一宮市昭和');
ok($zip->set_number('4910918')->is_valid_number, '愛知県一宮市末広');
ok($zip->set_number('4910919')->is_valid_number, '愛知県一宮市住吉');
ok($zip->set_number('4910921')->is_valid_number, '愛知県一宮市妙興寺');
ok($zip->set_number('4910922')->is_valid_number, '愛知県一宮市大和町妙興寺');
ok($zip->set_number('4910923')->is_valid_number, '愛知県一宮市大和町氏永');
ok($zip->set_number('4910924')->is_valid_number, '愛知県一宮市大和町於保');
ok($zip->set_number('4910925')->is_valid_number, '愛知県一宮市大和町南高井');
ok($zip->set_number('4910926')->is_valid_number, '愛知県一宮市大和町北高井');
ok($zip->set_number('4910927')->is_valid_number, '愛知県一宮市大和町戸塚');
ok($zip->set_number('4910931')->is_valid_number, '愛知県一宮市大和町馬引');
ok($zip->set_number('4910932')->is_valid_number, '愛知県一宮市大和町毛受');
ok($zip->set_number('4910933')->is_valid_number, '愛知県一宮市苅安賀');
ok($zip->set_number('4910934')->is_valid_number, '愛知県一宮市大和町苅安賀');
ok($zip->set_number('4910935')->is_valid_number, '愛知県一宮市大和町福森');
ok($zip->set_number('4910936')->is_valid_number, '愛知県一宮市寺前町');
ok($zip->set_number('4910937')->is_valid_number, '愛知県一宮市竹橋町');
ok($zip->set_number('4910938')->is_valid_number, '愛知県一宮市日光町');
ok($zip->set_number('4920000')->is_valid_number, '愛知県稲沢市以下に掲載がない場合');
ok($zip->set_number('4928001')->is_valid_number, '愛知県稲沢市赤池池田町');
ok($zip->set_number('4928002')->is_valid_number, '愛知県稲沢市赤池居道町');
ok($zip->set_number('4928003')->is_valid_number, '愛知県稲沢市赤池西出町');
ok($zip->set_number('4928004')->is_valid_number, '愛知県稲沢市赤池裏田町');
ok($zip->set_number('4928005')->is_valid_number, '愛知県稲沢市赤池陣出町');
ok($zip->set_number('4928006')->is_valid_number, '愛知県稲沢市赤池真崎町');
ok($zip->set_number('4928007')->is_valid_number, '愛知県稲沢市赤池山中町');
ok($zip->set_number('4928008')->is_valid_number, '愛知県稲沢市赤池町');
ok($zip->set_number('4928011')->is_valid_number, '愛知県稲沢市赤池前山町');
ok($zip->set_number('4928012')->is_valid_number, '愛知県稲沢市赤池天王町');
ok($zip->set_number('4928013')->is_valid_number, '愛知県稲沢市赤池寺東町');
ok($zip->set_number('4928014')->is_valid_number, '愛知県稲沢市赤池北町');
ok($zip->set_number('4928015')->is_valid_number, '愛知県稲沢市赤池北池田町');
ok($zip->set_number('4928016')->is_valid_number, '愛知県稲沢市赤池宮西町');
ok($zip->set_number('4928017')->is_valid_number, '愛知県稲沢市赤池旗屋町');
ok($zip->set_number('4928021')->is_valid_number, '愛知県稲沢市赤池東山町');
ok($zip->set_number('4928022')->is_valid_number, '愛知県稲沢市赤池坂畑町');
ok($zip->set_number('4928023')->is_valid_number, '愛知県稲沢市赤池広畑町');
ok($zip->set_number('4928024')->is_valid_number, '愛知県稲沢市赤池南町');
ok($zip->set_number('4928025')->is_valid_number, '愛知県稲沢市赤池中町');
ok($zip->set_number('4928031')->is_valid_number, '愛知県稲沢市陸田高畑町');
ok($zip->set_number('4928032')->is_valid_number, '愛知県稲沢市陸田東出町');
ok($zip->set_number('4928033')->is_valid_number, '愛知県稲沢市陸田一里山町');
ok($zip->set_number('4928034')->is_valid_number, '愛知県稲沢市陸田栗林町');
ok($zip->set_number('4928036')->is_valid_number, '愛知県稲沢市陸田本町');
ok($zip->set_number('4928037')->is_valid_number, '愛知県稲沢市陸田白山町');
ok($zip->set_number('4928038')->is_valid_number, '愛知県稲沢市陸田町');
ok($zip->set_number('4928041')->is_valid_number, '愛知県稲沢市陸田丸之内町');
ok($zip->set_number('4928042')->is_valid_number, '愛知県稲沢市陸田花塚町');
ok($zip->set_number('4928043')->is_valid_number, '愛知県稲沢市陸田馬山町');
ok($zip->set_number('4928044')->is_valid_number, '愛知県稲沢市陸田宮前');
ok($zip->set_number('4928045')->is_valid_number, '愛知県稲沢市陸田栗林');
ok($zip->set_number('4928051')->is_valid_number, '愛知県稲沢市下津光明寺町');
ok($zip->set_number('4928052')->is_valid_number, '愛知県稲沢市下津ふじ塚町');
ok($zip->set_number('4928053')->is_valid_number, '愛知県稲沢市下津蛇池町');
ok($zip->set_number('4928054')->is_valid_number, '愛知県稲沢市下津片町');
ok($zip->set_number('4928055')->is_valid_number, '愛知県稲沢市下津穂所町');
ok($zip->set_number('4928056')->is_valid_number, '愛知県稲沢市下津鞍掛町');
ok($zip->set_number('4928057')->is_valid_number, '愛知県稲沢市下津長田町');
ok($zip->set_number('4928058')->is_valid_number, '愛知県稲沢市下津牛洗町');
ok($zip->set_number('4928061')->is_valid_number, '愛知県稲沢市下津高戸町');
ok($zip->set_number('4928062')->is_valid_number, '愛知県稲沢市下津住吉町');
ok($zip->set_number('4928063')->is_valid_number, '愛知県稲沢市下津矢口町');
ok($zip->set_number('4928064')->is_valid_number, '愛知県稲沢市下津二本杉町');
ok($zip->set_number('4928065')->is_valid_number, '愛知県稲沢市下津大門町');
ok($zip->set_number('4928066')->is_valid_number, '愛知県稲沢市下津新町');
ok($zip->set_number('4928068')->is_valid_number, '愛知県稲沢市下津小井戸町');
ok($zip->set_number('4928071')->is_valid_number, '愛知県稲沢市下津本郷町');
ok($zip->set_number('4928072')->is_valid_number, '愛知県稲沢市下津北信正寺町');
ok($zip->set_number('4928073')->is_valid_number, '愛知県稲沢市下津南信正寺町');
ok($zip->set_number('4928074')->is_valid_number, '愛知県稲沢市下津下町東');
ok($zip->set_number('4928075')->is_valid_number, '愛知県稲沢市下津町');
ok($zip->set_number('4928076')->is_valid_number, '愛知県稲沢市下津宮西町');
ok($zip->set_number('4928077')->is_valid_number, '愛知県稲沢市下津土山町');
ok($zip->set_number('4928078')->is_valid_number, '愛知県稲沢市下津寺前町');
ok($zip->set_number('4928081')->is_valid_number, '愛知県稲沢市下津油田町');
ok($zip->set_number('4928082')->is_valid_number, '愛知県稲沢市下津下町西');
ok($zip->set_number('4928083')->is_valid_number, '愛知県稲沢市下津森町');
ok($zip->set_number('4928084')->is_valid_number, '愛知県稲沢市下津南山町');
ok($zip->set_number('4928085')->is_valid_number, '愛知県稲沢市下津丹下田町');
ok($zip->set_number('4928091')->is_valid_number, '愛知県稲沢市下津鞍掛');
ok($zip->set_number('4928092')->is_valid_number, '愛知県稲沢市下津穂所');
ok($zip->set_number('4928093')->is_valid_number, '愛知県稲沢市下津小井戸');
ok($zip->set_number('4928094')->is_valid_number, '愛知県稲沢市下津北山');
ok($zip->set_number('4928095')->is_valid_number, '愛知県稲沢市下津南山');
ok($zip->set_number('4928101')->is_valid_number, '愛知県稲沢市子生和池田町');
ok($zip->set_number('4928102')->is_valid_number, '愛知県稲沢市子生和神明町');
ok($zip->set_number('4928103')->is_valid_number, '愛知県稲沢市子生和溝師町');
ok($zip->set_number('4928104')->is_valid_number, '愛知県稲沢市子生和八島町');
ok($zip->set_number('4928105')->is_valid_number, '愛知県稲沢市子生和円場町');
ok($zip->set_number('4928106')->is_valid_number, '愛知県稲沢市子生和町');
ok($zip->set_number('4928107')->is_valid_number, '愛知県稲沢市子生和住吉町');
ok($zip->set_number('4928108')->is_valid_number, '愛知県稲沢市子生和子安賀町');
ok($zip->set_number('4928109')->is_valid_number, '愛知県稲沢市子生和山王町');
ok($zip->set_number('4928111')->is_valid_number, '愛知県稲沢市子生和小原町');
ok($zip->set_number('4928112')->is_valid_number, '愛知県稲沢市子生和坂田町');
ok($zip->set_number('4928113')->is_valid_number, '愛知県稲沢市治郎丸神木町');
ok($zip->set_number('4928114')->is_valid_number, '愛知県稲沢市治郎丸椿町');
ok($zip->set_number('4928115')->is_valid_number, '愛知県稲沢市治郎丸東町');
ok($zip->set_number('4928116')->is_valid_number, '愛知県稲沢市治郎丸西町');
ok($zip->set_number('4928117')->is_valid_number, '愛知県稲沢市治郎丸高須町');
ok($zip->set_number('4928118')->is_valid_number, '愛知県稲沢市治郎丸北町');
ok($zip->set_number('4928119')->is_valid_number, '愛知県稲沢市治郎丸大明町');
ok($zip->set_number('4928121')->is_valid_number, '愛知県稲沢市治郎丸柳町');
ok($zip->set_number('4928122')->is_valid_number, '愛知県稲沢市治郎丸元町');
ok($zip->set_number('4928123')->is_valid_number, '愛知県稲沢市治郎丸白山町');
ok($zip->set_number('4928124')->is_valid_number, '愛知県稲沢市治郎丸土井町');
ok($zip->set_number('4928125')->is_valid_number, '愛知県稲沢市治郎丸清敷町');
ok($zip->set_number('4928126')->is_valid_number, '愛知県稲沢市治郎丸郷前町');
ok($zip->set_number('4928127')->is_valid_number, '愛知県稲沢市治郎丸南町');
ok($zip->set_number('4928128')->is_valid_number, '愛知県稲沢市治郎丸中町');
ok($zip->set_number('4928131')->is_valid_number, '愛知県稲沢市治郎丸古江町');
ok($zip->set_number('4928132')->is_valid_number, '愛知県稲沢市治郎丸天神町');
ok($zip->set_number('4928133')->is_valid_number, '愛知県稲沢市治郎丸細道町');
ok($zip->set_number('4928134')->is_valid_number, '愛知県稲沢市治郎丸大角町');
ok($zip->set_number('4928135')->is_valid_number, '愛知県稲沢市治郎丸石塚町');
ok($zip->set_number('4928136')->is_valid_number, '愛知県稲沢市小池正明寺町北街道');
ok($zip->set_number('4928137')->is_valid_number, '愛知県稲沢市国府宮');
ok($zip->set_number('4928138')->is_valid_number, '愛知県稲沢市国府宮町');
ok($zip->set_number('4928139')->is_valid_number, '愛知県稲沢市国府宮神田町');
ok($zip->set_number('4928141')->is_valid_number, '愛知県稲沢市長野町');
ok($zip->set_number('4928142')->is_valid_number, '愛知県稲沢市長野');
ok($zip->set_number('4928143')->is_valid_number, '愛知県稲沢市駅前');
ok($zip->set_number('4928144')->is_valid_number, '愛知県稲沢市小池');
ok($zip->set_number('4928145')->is_valid_number, '愛知県稲沢市正明寺');
ok($zip->set_number('4928146')->is_valid_number, '愛知県稲沢市御供所町');
ok($zip->set_number('4928147')->is_valid_number, '愛知県稲沢市小池正明寺町');
ok($zip->set_number('4928151')->is_valid_number, '愛知県稲沢市井之口北畑町');
ok($zip->set_number('4928152')->is_valid_number, '愛知県稲沢市井之口大宮町');
ok($zip->set_number('4928153')->is_valid_number, '愛知県稲沢市井之口町');
ok($zip->set_number('4928154')->is_valid_number, '愛知県稲沢市井之口本町');
ok($zip->set_number('4928155')->is_valid_number, '愛知県稲沢市井之口四家町');
ok($zip->set_number('4928156')->is_valid_number, '愛知県稲沢市井之口親畑町');
ok($zip->set_number('4928157')->is_valid_number, '愛知県稲沢市井之口柿ノ木町');
ok($zip->set_number('4928158')->is_valid_number, '愛知県稲沢市井之口白山町');
ok($zip->set_number('4928161')->is_valid_number, '愛知県稲沢市菱町');
ok($zip->set_number('4928162')->is_valid_number, '愛知県稲沢市井之口小番戸町');
ok($zip->set_number('4928163')->is_valid_number, '愛知県稲沢市井之口石塚町');
ok($zip->set_number('4928164')->is_valid_number, '愛知県稲沢市井之口大坪町');
ok($zip->set_number('4928165')->is_valid_number, '愛知県稲沢市井之口鶴田町');
ok($zip->set_number('4928166')->is_valid_number, '愛知県稲沢市井之口沖ノ田町');
ok($zip->set_number('4928167')->is_valid_number, '愛知県稲沢市長束町');
ok($zip->set_number('4928171')->is_valid_number, '愛知県稲沢市六角堂西町');
ok($zip->set_number('4928172')->is_valid_number, '愛知県稲沢市六角堂東町');
ok($zip->set_number('4928173')->is_valid_number, '愛知県稲沢市北市場町');
ok($zip->set_number('4928174')->is_valid_number, '愛知県稲沢市北市場西町');
ok($zip->set_number('4928175')->is_valid_number, '愛知県稲沢市北市場南町');
ok($zip->set_number('4928176')->is_valid_number, '愛知県稲沢市日下部花ノ木町');
ok($zip->set_number('4928177')->is_valid_number, '愛知県稲沢市日下部東町');
ok($zip->set_number('4928178')->is_valid_number, '愛知県稲沢市北市場本町');
ok($zip->set_number('4928181')->is_valid_number, '愛知県稲沢市日下部北町');
ok($zip->set_number('4928182')->is_valid_number, '愛知県稲沢市日下部中町');
ok($zip->set_number('4928183')->is_valid_number, '愛知県稲沢市日下部南町');
ok($zip->set_number('4928184')->is_valid_number, '愛知県稲沢市日下部松野町');
ok($zip->set_number('4928185')->is_valid_number, '愛知県稲沢市日下部西町');
ok($zip->set_number('4928186')->is_valid_number, '愛知県稲沢市日下部町');
ok($zip->set_number('4928201')->is_valid_number, '愛知県稲沢市島子安賀町');
ok($zip->set_number('4928202')->is_valid_number, '愛知県稲沢市島東之郷町');
ok($zip->set_number('4928203')->is_valid_number, '愛知県稲沢市島小原町');
ok($zip->set_number('4928204')->is_valid_number, '愛知県稲沢市島高須賀町');
ok($zip->set_number('4928205')->is_valid_number, '愛知県稲沢市島町');
ok($zip->set_number('4928206')->is_valid_number, '愛知県稲沢市稲島法成寺町');
ok($zip->set_number('4928207')->is_valid_number, '愛知県稲沢市稲島町');
ok($zip->set_number('4928208')->is_valid_number, '愛知県稲沢市松下');
ok($zip->set_number('4928209')->is_valid_number, '愛知県稲沢市木全町');
ok($zip->set_number('4928210')->is_valid_number, '愛知県稲沢市木全');
ok($zip->set_number('4928211')->is_valid_number, '愛知県稲沢市稲沢町北山');
ok($zip->set_number('4928212')->is_valid_number, '愛知県稲沢市小沢');
ok($zip->set_number('4928213')->is_valid_number, '愛知県稲沢市高御堂');
ok($zip->set_number('4928214')->is_valid_number, '愛知県稲沢市大塚南');
ok($zip->set_number('4928215')->is_valid_number, '愛知県稲沢市大塚北');
ok($zip->set_number('4928216')->is_valid_number, '愛知県稲沢市大塚町');
ok($zip->set_number('4928217')->is_valid_number, '愛知県稲沢市稲沢町');
ok($zip->set_number('4928218')->is_valid_number, '愛知県稲沢市西町');
ok($zip->set_number('4928219')->is_valid_number, '愛知県稲沢市稲葉');
ok($zip->set_number('4928220')->is_valid_number, '愛知県稲沢市前田');
ok($zip->set_number('4928221')->is_valid_number, '愛知県稲沢市幸町');
ok($zip->set_number('4928222')->is_valid_number, '愛知県稲沢市奥田天目寺町');
ok($zip->set_number('4928223')->is_valid_number, '愛知県稲沢市奥田井之下町');
ok($zip->set_number('4928224')->is_valid_number, '愛知県稲沢市奥田大沢町');
ok($zip->set_number('4928225')->is_valid_number, '愛知県稲沢市奥田膳棚町');
ok($zip->set_number('4928226')->is_valid_number, '愛知県稲沢市奥田大門町');
ok($zip->set_number('4928227')->is_valid_number, '愛知県稲沢市奥田白山町');
ok($zip->set_number('4928228')->is_valid_number, '愛知県稲沢市奥田長角町');
ok($zip->set_number('4928229')->is_valid_number, '愛知県稲沢市稲島');
ok($zip->set_number('4928230')->is_valid_number, '愛知県稲沢市稲島東');
ok($zip->set_number('4928231')->is_valid_number, '愛知県稲沢市奥田流町');
ok($zip->set_number('4928232')->is_valid_number, '愛知県稲沢市奥田酒伊町');
ok($zip->set_number('4928233')->is_valid_number, '愛知県稲沢市奥田町');
ok($zip->set_number('4928234')->is_valid_number, '愛知県稲沢市奥田切田町');
ok($zip->set_number('4928235')->is_valid_number, '愛知県稲沢市奥田立長町');
ok($zip->set_number('4928236')->is_valid_number, '愛知県稲沢市奥田寺切町');
ok($zip->set_number('4928237')->is_valid_number, '愛知県稲沢市奥田馬場町');
ok($zip->set_number('4928238')->is_valid_number, '愛知県稲沢市奥田堀畑町');
ok($zip->set_number('4928239')->is_valid_number, '愛知県稲沢市奥田中切町');
ok($zip->set_number('4928240')->is_valid_number, '愛知県稲沢市島下畑町');
ok($zip->set_number('4928241')->is_valid_number, '愛知県稲沢市奥田田畑町');
ok($zip->set_number('4928242')->is_valid_number, '愛知県稲沢市奥田町田畑切');
ok($zip->set_number('4928242')->is_valid_number, '愛知県稲沢市奥田町文七西');
ok($zip->set_number('4928243')->is_valid_number, '愛知県稲沢市奥田木塚町');
ok($zip->set_number('4928244')->is_valid_number, '愛知県稲沢市奥田下河町');
ok($zip->set_number('4928245')->is_valid_number, '愛知県稲沢市奥田南花ノ木町');
ok($zip->set_number('4928246')->is_valid_number, '愛知県稲沢市奥田計用町');
ok($zip->set_number('4928247')->is_valid_number, '愛知県稲沢市東畑');
ok($zip->set_number('4928248')->is_valid_number, '愛知県稲沢市島寺西町');
ok($zip->set_number('4928249')->is_valid_number, '愛知県稲沢市島新田町');
ok($zip->set_number('4928251')->is_valid_number, '愛知県稲沢市東緑町');
ok($zip->set_number('4928252')->is_valid_number, '愛知県稲沢市緑町');
ok($zip->set_number('4928253')->is_valid_number, '愛知県稲沢市奥田神ノ木町');
ok($zip->set_number('4928254')->is_valid_number, '愛知県稲沢市奥田宮長町');
ok($zip->set_number('4928255')->is_valid_number, '愛知県稲沢市奥田天神町');
ok($zip->set_number('4928256')->is_valid_number, '愛知県稲沢市奥田北花ノ木町');
ok($zip->set_number('4928257')->is_valid_number, '愛知県稲沢市奥田島崎町');
ok($zip->set_number('4928258')->is_valid_number, '愛知県稲沢市島本郷町');
ok($zip->set_number('4928259')->is_valid_number, '愛知県稲沢市島北浦町');
ok($zip->set_number('4928261')->is_valid_number, '愛知県稲沢市重本');
ok($zip->set_number('4928262')->is_valid_number, '愛知県稲沢市池部町');
ok($zip->set_number('4928263')->is_valid_number, '愛知県稲沢市平野');
ok($zip->set_number('4928264')->is_valid_number, '愛知県稲沢市平野町');
ok($zip->set_number('4928265')->is_valid_number, '愛知県稲沢市小寺町');
ok($zip->set_number('4928266')->is_valid_number, '愛知県稲沢市横地');
ok($zip->set_number('4928267')->is_valid_number, '愛知県稲沢市船橋町');
ok($zip->set_number('4928268')->is_valid_number, '愛知県稲沢市朝府町');
ok($zip->set_number('4928269')->is_valid_number, '愛知県稲沢市稲府町');
ok($zip->set_number('4928271')->is_valid_number, '愛知県稲沢市石橋');
ok($zip->set_number('4928272')->is_valid_number, '愛知県稲沢市桜木');
ok($zip->set_number('4928273')->is_valid_number, '愛知県稲沢市桜木宮前町');
ok($zip->set_number('4928274')->is_valid_number, '愛知県稲沢市天池光田町');
ok($zip->set_number('4928275')->is_valid_number, '愛知県稲沢市天池五反田町');
ok($zip->set_number('4928276')->is_valid_number, '愛知県稲沢市天池町');
ok($zip->set_number('4928277')->is_valid_number, '愛知県稲沢市天池牧作町');
ok($zip->set_number('4928278')->is_valid_number, '愛知県稲沢市天池金山町');
ok($zip->set_number('4928279')->is_valid_number, '愛知県稲沢市天池遠松町');
ok($zip->set_number('4928281')->is_valid_number, '愛知県稲沢市天池伝代町');
ok($zip->set_number('4928282')->is_valid_number, '愛知県稲沢市天池東町');
ok($zip->set_number('4928283')->is_valid_number, '愛知県稲沢市天池浪寄町');
ok($zip->set_number('4928284')->is_valid_number, '愛知県稲沢市天池西町');
ok($zip->set_number('4928285')->is_valid_number, '愛知県稲沢市竹腰東町');
ok($zip->set_number('4928286')->is_valid_number, '愛知県稲沢市竹腰中町');
ok($zip->set_number('4928287')->is_valid_number, '愛知県稲沢市竹腰西町');
ok($zip->set_number('4928288')->is_valid_number, '愛知県稲沢市竹腰北町');
ok($zip->set_number('4928289')->is_valid_number, '愛知県稲沢市竹腰本町');
ok($zip->set_number('4928301')->is_valid_number, '愛知県稲沢市生出本町');
ok($zip->set_number('4928302')->is_valid_number, '愛知県稲沢市生出西道根町');
ok($zip->set_number('4928303')->is_valid_number, '愛知県稲沢市生出東道根町');
ok($zip->set_number('4928304')->is_valid_number, '愛知県稲沢市生出山田町');
ok($zip->set_number('4928305')->is_valid_number, '愛知県稲沢市生出郷前町');
ok($zip->set_number('4928306')->is_valid_number, '愛知県稲沢市生出横西町');
ok($zip->set_number('4928307')->is_valid_number, '愛知県稲沢市生出上山町');
ok($zip->set_number('4928308')->is_valid_number, '愛知県稲沢市生出河戸町');
ok($zip->set_number('4928310')->is_valid_number, '愛知県稲沢市下屋');
ok($zip->set_number('4928311')->is_valid_number, '愛知県稲沢市清水西川原町');
ok($zip->set_number('4928312')->is_valid_number, '愛知県稲沢市清水八尻町');
ok($zip->set_number('4928313')->is_valid_number, '愛知県稲沢市清水阿原町');
ok($zip->set_number('4928314')->is_valid_number, '愛知県稲沢市清水町');
ok($zip->set_number('4928315')->is_valid_number, '愛知県稲沢市清水郷西町');
ok($zip->set_number('4928316')->is_valid_number, '愛知県稲沢市清水寺前町');
ok($zip->set_number('4928317')->is_valid_number, '愛知県稲沢市清水八神町');
ok($zip->set_number('4928318')->is_valid_number, '愛知県稲沢市浅井町');
ok($zip->set_number('4928319')->is_valid_number, '愛知県稲沢市下屋町');
ok($zip->set_number('4928321')->is_valid_number, '愛知県稲沢市西島北町');
ok($zip->set_number('4928322')->is_valid_number, '愛知県稲沢市西島出町');
ok($zip->set_number('4928323')->is_valid_number, '愛知県稲沢市西島新町');
ok($zip->set_number('4928325')->is_valid_number, '愛知県稲沢市西島東町');
ok($zip->set_number('4928326')->is_valid_number, '愛知県稲沢市西島本町');
ok($zip->set_number('4928327')->is_valid_number, '愛知県稲沢市西島中町');
ok($zip->set_number('4928328')->is_valid_number, '愛知県稲沢市西島');
ok($zip->set_number('4928329')->is_valid_number, '愛知県稲沢市西島町');
ok($zip->set_number('4928331')->is_valid_number, '愛知県稲沢市平佛供田町');
ok($zip->set_number('4928332')->is_valid_number, '愛知県稲沢市平尾苅町');
ok($zip->set_number('4928333')->is_valid_number, '愛知県稲沢市平蜂ノ坪町');
ok($zip->set_number('4928334')->is_valid_number, '愛知県稲沢市平高道町');
ok($zip->set_number('4928335')->is_valid_number, '愛知県稲沢市法花寺町');
ok($zip->set_number('4928336')->is_valid_number, '愛知県稲沢市平苅田町');
ok($zip->set_number('4928337')->is_valid_number, '愛知県稲沢市平細工蔵町');
ok($zip->set_number('4928338')->is_valid_number, '愛知県稲沢市平金森町');
ok($zip->set_number('4928339')->is_valid_number, '愛知県稲沢市平江向町');
ok($zip->set_number('4928341')->is_valid_number, '愛知県稲沢市馬場町');
ok($zip->set_number('4928342')->is_valid_number, '愛知県稲沢市矢合町');
ok($zip->set_number('4928344')->is_valid_number, '愛知県稲沢市山口南町');
ok($zip->set_number('4928345')->is_valid_number, '愛知県稲沢市山口宮前町');
ok($zip->set_number('4928346')->is_valid_number, '愛知県稲沢市山口本町');
ok($zip->set_number('4928347')->is_valid_number, '愛知県稲沢市山口町');
ok($zip->set_number('4928348')->is_valid_number, '愛知県稲沢市馬場');
ok($zip->set_number('4928349')->is_valid_number, '愛知県稲沢市儀長');
ok($zip->set_number('4928351')->is_valid_number, '愛知県稲沢市一色竹橋町');
ok($zip->set_number('4928352')->is_valid_number, '愛知県稲沢市一色神宮町');
ok($zip->set_number('4928353')->is_valid_number, '愛知県稲沢市一色藤塚町');
ok($zip->set_number('4928354')->is_valid_number, '愛知県稲沢市一色三反田町');
ok($zip->set_number('4928355')->is_valid_number, '愛知県稲沢市片原一色町');
ok($zip->set_number('4928356')->is_valid_number, '愛知県稲沢市一色市場町');
ok($zip->set_number('4928357')->is_valid_number, '愛知県稲沢市一色道上町');
ok($zip->set_number('4928358')->is_valid_number, '愛知県稲沢市一色白山町');
ok($zip->set_number('4928361')->is_valid_number, '愛知県稲沢市一色長畑町');
ok($zip->set_number('4928362')->is_valid_number, '愛知県稲沢市一色青海町');
ok($zip->set_number('4928363')->is_valid_number, '愛知県稲沢市一色跡之口町');
ok($zip->set_number('4928364')->is_valid_number, '愛知県稲沢市一色森山町');
ok($zip->set_number('4928365')->is_valid_number, '愛知県稲沢市一色下方町');
ok($zip->set_number('4928366')->is_valid_number, '愛知県稲沢市一色川俣町');
ok($zip->set_number('4928371')->is_valid_number, '愛知県稲沢市一色上方町');
ok($zip->set_number('4928372')->is_valid_number, '愛知県稲沢市一色中屋敷町');
ok($zip->set_number('4928373')->is_valid_number, '愛知県稲沢市一色中通町');
ok($zip->set_number('4928374')->is_valid_number, '愛知県稲沢市一色西町');
ok($zip->set_number('4928375')->is_valid_number, '愛知県稲沢市一色巡見町');
ok($zip->set_number('4928381')->is_valid_number, '愛知県稲沢市横野西郷町');
ok($zip->set_number('4928382')->is_valid_number, '愛知県稲沢市横野堂根町');
ok($zip->set_number('4928383')->is_valid_number, '愛知県稲沢市横野東出町');
ok($zip->set_number('4928384')->is_valid_number, '愛知県稲沢市横野東郷町');
ok($zip->set_number('4928385')->is_valid_number, '愛知県稲沢市横野河原町');
ok($zip->set_number('4928386')->is_valid_number, '愛知県稲沢市横野松前町');
ok($zip->set_number('4928387')->is_valid_number, '愛知県稲沢市横野神田町');
ok($zip->set_number('4928388')->is_valid_number, '愛知県稲沢市横野境塚町');
ok($zip->set_number('4928389')->is_valid_number, '愛知県稲沢市横野町');
ok($zip->set_number('4928391')->is_valid_number, '愛知県稲沢市中野川端町');
ok($zip->set_number('4928392')->is_valid_number, '愛知県稲沢市中野元町');
ok($zip->set_number('4928393')->is_valid_number, '愛知県稲沢市中野宮町');
ok($zip->set_number('4928401')->is_valid_number, '愛知県稲沢市梅須賀町');
ok($zip->set_number('4928402')->is_valid_number, '愛知県稲沢市千代町');
ok($zip->set_number('4928403')->is_valid_number, '愛知県稲沢市千代');
ok($zip->set_number('4928404')->is_valid_number, '愛知県稲沢市千代西町');
ok($zip->set_number('4928405')->is_valid_number, '愛知県稲沢市堀之内町');
ok($zip->set_number('4928406')->is_valid_number, '愛知県稲沢市井堀大縄町');
ok($zip->set_number('4928407')->is_valid_number, '愛知県稲沢市井堀宿塚町');
ok($zip->set_number('4928408')->is_valid_number, '愛知県稲沢市井堀川東町');
ok($zip->set_number('4928409')->is_valid_number, '愛知県稲沢市井堀橋下町');
ok($zip->set_number('4928410')->is_valid_number, '愛知県稲沢市北島');
ok($zip->set_number('4928411')->is_valid_number, '愛知県稲沢市北島町');
ok($zip->set_number('4928412')->is_valid_number, '愛知県稲沢市大矢町');
ok($zip->set_number('4928413')->is_valid_number, '愛知県稲沢市大矢江西町');
ok($zip->set_number('4928414')->is_valid_number, '愛知県稲沢市大矢浄土寺町');
ok($zip->set_number('4928415')->is_valid_number, '愛知県稲沢市大矢青山町');
ok($zip->set_number('4928416')->is_valid_number, '愛知県稲沢市大矢白山町');
ok($zip->set_number('4928417')->is_valid_number, '愛知県稲沢市大矢仙口町');
ok($zip->set_number('4928418')->is_valid_number, '愛知県稲沢市大矢高田町');
ok($zip->set_number('4928419')->is_valid_number, '愛知県稲沢市大矢真宮町');
ok($zip->set_number('4928421')->is_valid_number, '愛知県稲沢市高重西町');
ok($zip->set_number('4928422')->is_valid_number, '愛知県稲沢市高重町');
ok($zip->set_number('4928423')->is_valid_number, '愛知県稲沢市高重中町');
ok($zip->set_number('4928424')->is_valid_number, '愛知県稲沢市高重東町');
ok($zip->set_number('4928425')->is_valid_number, '愛知県稲沢市増田北町');
ok($zip->set_number('4928426')->is_valid_number, '愛知県稲沢市増田東町');
ok($zip->set_number('4928427')->is_valid_number, '愛知県稲沢市増田南町');
ok($zip->set_number('4928428')->is_valid_number, '愛知県稲沢市増田町');
ok($zip->set_number('4928429')->is_valid_number, '愛知県稲沢市増田西町');
ok($zip->set_number('4928431')->is_valid_number, '愛知県稲沢市中之庄高畑町');
ok($zip->set_number('4928432')->is_valid_number, '愛知県稲沢市中之庄半田町');
ok($zip->set_number('4928433')->is_valid_number, '愛知県稲沢市中之庄元屋敷町');
ok($zip->set_number('4928434')->is_valid_number, '愛知県稲沢市中之庄堤畔町');
ok($zip->set_number('4928435')->is_valid_number, '愛知県稲沢市中之庄町');
ok($zip->set_number('4928436')->is_valid_number, '愛知県稲沢市中之庄海道町');
ok($zip->set_number('4928437')->is_valid_number, '愛知県稲沢市中之庄長堤町');
ok($zip->set_number('4928438')->is_valid_number, '愛知県稲沢市堀田町');
ok($zip->set_number('4928439')->is_valid_number, '愛知県稲沢市七ツ寺町');
ok($zip->set_number('4928441')->is_valid_number, '愛知県稲沢市福島町');
ok($zip->set_number('4928442')->is_valid_number, '愛知県稲沢市附島町');
ok($zip->set_number('4928443')->is_valid_number, '愛知県稲沢市牛踏町');
ok($zip->set_number('4928444')->is_valid_number, '愛知県稲沢市込野町');
ok($zip->set_number('4928445')->is_valid_number, '愛知県稲沢市南麻績町');
ok($zip->set_number('4928446')->is_valid_number, '愛知県稲沢市目比町');
ok($zip->set_number('4928447')->is_valid_number, '愛知県稲沢市野崎町');
ok($zip->set_number('4928448')->is_valid_number, '愛知県稲沢市北麻績町');
ok($zip->set_number('4928451')->is_valid_number, '愛知県稲沢市板葺町');
ok($zip->set_number('4928452')->is_valid_number, '愛知県稲沢市西溝口町');
ok($zip->set_number('4928453')->is_valid_number, '愛知県稲沢市今村町');
ok($zip->set_number('4928454')->is_valid_number, '愛知県稲沢市坂田町');
ok($zip->set_number('4928455')->is_valid_number, '愛知県稲沢市田代');
ok($zip->set_number('4928456')->is_valid_number, '愛知県稲沢市氷室町');
ok($zip->set_number('4928461')->is_valid_number, '愛知県稲沢市井堀北出町');
ok($zip->set_number('4928462')->is_valid_number, '愛知県稲沢市井堀高見町');
ok($zip->set_number('4928463')->is_valid_number, '愛知県稲沢市井堀中郷町');
ok($zip->set_number('4928464')->is_valid_number, '愛知県稲沢市井堀下郷町');
ok($zip->set_number('4928465')->is_valid_number, '愛知県稲沢市井堀犬城町');
ok($zip->set_number('4928466')->is_valid_number, '愛知県稲沢市井堀江西町');
ok($zip->set_number('4928467')->is_valid_number, '愛知県稲沢市井堀蒲六町');
ok($zip->set_number('4928468')->is_valid_number, '愛知県稲沢市井堀野口町');
ok($zip->set_number('4930001')->is_valid_number, '愛知県一宮市木曽川町黒田');
ok($zip->set_number('4930002')->is_valid_number, '愛知県一宮市木曽川町門間');
ok($zip->set_number('4930003')->is_valid_number, '愛知県一宮市木曽川町三ツ法寺');
ok($zip->set_number('4930004')->is_valid_number, '愛知県一宮市木曽川町玉ノ井');
ok($zip->set_number('4930005')->is_valid_number, '愛知県一宮市木曽川町里小牧');
ok($zip->set_number('4930006')->is_valid_number, '愛知県一宮市木曽川町内割田');
ok($zip->set_number('4930007')->is_valid_number, '愛知県一宮市木曽川町外割田');
ok($zip->set_number('4938001')->is_valid_number, '愛知県一宮市北方町北方');
ok($zip->set_number('4938002')->is_valid_number, '愛知県一宮市北方町曽根');
ok($zip->set_number('4938003')->is_valid_number, '愛知県一宮市北方町中島');
ok($zip->set_number('4940001')->is_valid_number, '愛知県一宮市開明');
ok($zip->set_number('4940002')->is_valid_number, '愛知県一宮市篭屋');
ok($zip->set_number('4940003')->is_valid_number, '愛知県一宮市三条');
ok($zip->set_number('4940004')->is_valid_number, '愛知県一宮市北今');
ok($zip->set_number('4940005')->is_valid_number, '愛知県一宮市西五城');
ok($zip->set_number('4940006')->is_valid_number, '愛知県一宮市起');
ok($zip->set_number('4940007')->is_valid_number, '愛知県一宮市小信中島');
ok($zip->set_number('4940008')->is_valid_number, '愛知県一宮市東五城');
ok($zip->set_number('4940011')->is_valid_number, '愛知県一宮市西萩原');
ok($zip->set_number('4940012')->is_valid_number, '愛知県一宮市明地');
ok($zip->set_number('4940013')->is_valid_number, '愛知県一宮市玉野');
ok($zip->set_number('4940014')->is_valid_number, '愛知県一宮市上祖父江');
ok($zip->set_number('4940015')->is_valid_number, '愛知県一宮市西中野');
ok($zip->set_number('4940016')->is_valid_number, '愛知県一宮市東加賀野井');
ok($zip->set_number('4940017')->is_valid_number, '愛知県一宮市祐久');
ok($zip->set_number('4940018')->is_valid_number, '愛知県一宮市冨田');
ok($zip->set_number('4940019')->is_valid_number, '愛知県一宮市蓮池');
ok($zip->set_number('4950001')->is_valid_number, '愛知県稲沢市祖父江町祖父江');
ok($zip->set_number('4950002')->is_valid_number, '愛知県稲沢市祖父江町山崎');
ok($zip->set_number('4950003')->is_valid_number, '愛知県稲沢市祖父江町高熊西');
ok($zip->set_number('4950011')->is_valid_number, '愛知県稲沢市祖父江町森上');
ok($zip->set_number('4950012')->is_valid_number, '愛知県稲沢市祖父江町本甲');
ok($zip->set_number('4950013')->is_valid_number, '愛知県稲沢市祖父江町二俣');
ok($zip->set_number('4950014')->is_valid_number, '愛知県稲沢市祖父江町大牧');
ok($zip->set_number('4950015')->is_valid_number, '愛知県稲沢市祖父江町桜方');
ok($zip->set_number('4950021')->is_valid_number, '愛知県稲沢市祖父江町三丸渕');
ok($zip->set_number('4950022')->is_valid_number, '愛知県稲沢市祖父江町甲新田');
ok($zip->set_number('4950023')->is_valid_number, '愛知県稲沢市祖父江町島本');
ok($zip->set_number('4950024')->is_valid_number, '愛知県稲沢市祖父江町野田');
ok($zip->set_number('4950025')->is_valid_number, '愛知県稲沢市祖父江町両寺内');
ok($zip->set_number('4950031')->is_valid_number, '愛知県稲沢市祖父江町上牧');
ok($zip->set_number('4950032')->is_valid_number, '愛知県稲沢市祖父江町中牧');
ok($zip->set_number('4950033')->is_valid_number, '愛知県稲沢市祖父江町四貫');
ok($zip->set_number('4950034')->is_valid_number, '愛知県稲沢市祖父江町西鵜之本');
ok($zip->set_number('4950035')->is_valid_number, '愛知県稲沢市祖父江町神明津');
ok($zip->set_number('4950036')->is_valid_number, '愛知県稲沢市祖父江町馬飼');
ok($zip->set_number('4950037')->is_valid_number, '愛知県稲沢市祖父江町拾町野');
ok($zip->set_number('4960000')->is_valid_number, '愛知県津島市以下に掲載がない場合');
ok($zip->set_number('4960000')->is_valid_number, '愛知県愛西市以下に掲載がない場合');
ok($zip->set_number('4960001')->is_valid_number, '愛知県津島市青塚町');
ok($zip->set_number('4960002')->is_valid_number, '愛知県津島市牧野町');
ok($zip->set_number('4960003')->is_valid_number, '愛知県津島市寺野町');
ok($zip->set_number('4960004')->is_valid_number, '愛知県津島市蛭間町');
ok($zip->set_number('4960005')->is_valid_number, '愛知県津島市神守町');
ok($zip->set_number('4960006')->is_valid_number, '愛知県津島市大木町');
ok($zip->set_number('4960007')->is_valid_number, '愛知県津島市光正寺町');
ok($zip->set_number('4960008')->is_valid_number, '愛知県津島市宇治町');
ok($zip->set_number('4960009')->is_valid_number, '愛知県津島市葉苅町');
ok($zip->set_number('4960011')->is_valid_number, '愛知県津島市莪原町');
ok($zip->set_number('4960012')->is_valid_number, '愛知県津島市大坪町');
ok($zip->set_number('4960013')->is_valid_number, '愛知県津島市神尾町');
ok($zip->set_number('4960014')->is_valid_number, '愛知県津島市金柳町');
ok($zip->set_number('4960015')->is_valid_number, '愛知県津島市高台寺町');
ok($zip->set_number('4960016')->is_valid_number, '愛知県津島市白浜町');
ok($zip->set_number('4960017')->is_valid_number, '愛知県津島市百町');
ok($zip->set_number('4960018')->is_valid_number, '愛知県津島市牛田町');
ok($zip->set_number('4960019')->is_valid_number, '愛知県津島市百島町');
ok($zip->set_number('4960021')->is_valid_number, '愛知県津島市椿市町');
ok($zip->set_number('4960022')->is_valid_number, '愛知県津島市越津町');
ok($zip->set_number('4960023')->is_valid_number, '愛知県津島市鹿伏兎町');
ok($zip->set_number('4960024')->is_valid_number, '愛知県津島市半頭町');
ok($zip->set_number('4960025')->is_valid_number, '愛知県津島市中一色町');
ok($zip->set_number('4960026')->is_valid_number, '愛知県津島市唐臼町');
ok($zip->set_number('4960027')->is_valid_number, '愛知県津島市新開');
ok($zip->set_number('4960027')->is_valid_number, '愛知県津島市津島');
ok($zip->set_number('4960028')->is_valid_number, '愛知県津島市日光');
ok($zip->set_number('4960029')->is_valid_number, '愛知県津島市下切町');
ok($zip->set_number('4960031')->is_valid_number, '愛知県津島市埋田町');
ok($zip->set_number('4960032')->is_valid_number, '愛知県津島市深坪町');
ok($zip->set_number('4960033')->is_valid_number, '愛知県津島市杁前町');
ok($zip->set_number('4960034')->is_valid_number, '愛知県津島市元寺町');
ok($zip->set_number('4960035')->is_valid_number, '愛知県津島市東愛宕町');
ok($zip->set_number('4960036')->is_valid_number, '愛知県津島市愛宕町');
ok($zip->set_number('4960037')->is_valid_number, '愛知県津島市西愛宕町');
ok($zip->set_number('4960038')->is_valid_number, '愛知県津島市橘町');
ok($zip->set_number('4960041')->is_valid_number, '愛知県津島市高畑町');
ok($zip->set_number('4960042')->is_valid_number, '愛知県津島市寺前町');
ok($zip->set_number('4960043')->is_valid_number, '愛知県津島市古川');
ok($zip->set_number('4960043')->is_valid_number, '愛知県津島市古川町');
ok($zip->set_number('4960044')->is_valid_number, '愛知県津島市立込町');
ok($zip->set_number('4960045')->is_valid_number, '愛知県津島市東柳原町');
ok($zip->set_number('4960046')->is_valid_number, '愛知県津島市柳原町');
ok($zip->set_number('4960047')->is_valid_number, '愛知県津島市西柳原町');
ok($zip->set_number('4960048')->is_valid_number, '愛知県津島市藤里町');
ok($zip->set_number('4960071')->is_valid_number, '愛知県津島市新開町');
ok($zip->set_number('4960072')->is_valid_number, '愛知県津島市南新開町');
ok($zip->set_number('4960801')->is_valid_number, '愛知県津島市藤浪町');
ok($zip->set_number('4960802')->is_valid_number, '愛知県津島市錦町');
ok($zip->set_number('4960803')->is_valid_number, '愛知県津島市今市場町');
ok($zip->set_number('4960804')->is_valid_number, '愛知県津島市弥生町');
ok($zip->set_number('4960805')->is_valid_number, '愛知県津島市本町');
ok($zip->set_number('4960806')->is_valid_number, '愛知県津島市池麩町');
ok($zip->set_number('4960807')->is_valid_number, '愛知県津島市天王通');
ok($zip->set_number('4960808')->is_valid_number, '愛知県津島市宝町');
ok($zip->set_number('4960809')->is_valid_number, '愛知県津島市昭和町');
ok($zip->set_number('4960811')->is_valid_number, '愛知県津島市喜楽町');
ok($zip->set_number('4960812')->is_valid_number, '愛知県津島市兼平町');
ok($zip->set_number('4960813')->is_valid_number, '愛知県津島市片岡町');
ok($zip->set_number('4960814')->is_valid_number, '愛知県津島市良王町');
ok($zip->set_number('4960815')->is_valid_number, '愛知県津島市米之座町');
ok($zip->set_number('4960816')->is_valid_number, '愛知県津島市米町');
ok($zip->set_number('4960817')->is_valid_number, '愛知県津島市北町');
ok($zip->set_number('4960818')->is_valid_number, '愛知県津島市松原町');
ok($zip->set_number('4960819')->is_valid_number, '愛知県津島市又吉町');
ok($zip->set_number('4960821')->is_valid_number, '愛知県津島市城之越町');
ok($zip->set_number('4960822')->is_valid_number, '愛知県津島市高屋敷町');
ok($zip->set_number('4960823')->is_valid_number, '愛知県津島市上河原町');
ok($zip->set_number('4960824')->is_valid_number, '愛知県津島市金町');
ok($zip->set_number('4960825')->is_valid_number, '愛知県津島市橋詰町');
ok($zip->set_number('4960826')->is_valid_number, '愛知県津島市片町');
ok($zip->set_number('4960827')->is_valid_number, '愛知県津島市浦方町');
ok($zip->set_number('4960828')->is_valid_number, '愛知県津島市池須町');
ok($zip->set_number('4960829')->is_valid_number, '愛知県津島市寿町');
ok($zip->set_number('4960831')->is_valid_number, '愛知県津島市瑞穂町');
ok($zip->set_number('4960832')->is_valid_number, '愛知県津島市東洋町');
ok($zip->set_number('4960833')->is_valid_number, '愛知県津島市常盤町');
ok($zip->set_number('4960834')->is_valid_number, '愛知県津島市南本町');
ok($zip->set_number('4960835')->is_valid_number, '愛知県津島市皆戸町');
ok($zip->set_number('4960836')->is_valid_number, '愛知県津島市中野町');
ok($zip->set_number('4960837')->is_valid_number, '愛知県津島市大政町');
ok($zip->set_number('4960838')->is_valid_number, '愛知県津島市明天町');
ok($zip->set_number('4960839')->is_valid_number, '愛知県津島市藤川町');
ok($zip->set_number('4960841')->is_valid_number, '愛知県津島市横町');
ok($zip->set_number('4960842')->is_valid_number, '愛知県津島市筏場町');
ok($zip->set_number('4960843')->is_valid_number, '愛知県津島市舟戸町');
ok($zip->set_number('4960844')->is_valid_number, '愛知県津島市薬師町');
ok($zip->set_number('4960845')->is_valid_number, '愛知県津島市永楽町');
ok($zip->set_number('4960846')->is_valid_number, '愛知県津島市東中地町');
ok($zip->set_number('4960847')->is_valid_number, '愛知県津島市中地町');
ok($zip->set_number('4960848')->is_valid_number, '愛知県津島市大慶寺町');
ok($zip->set_number('4960849')->is_valid_number, '愛知県津島市西御堂町');
ok($zip->set_number('4960851')->is_valid_number, '愛知県津島市神明町');
ok($zip->set_number('4960852')->is_valid_number, '愛知県津島市祢宜町');
ok($zip->set_number('4960853')->is_valid_number, '愛知県津島市宮川町');
ok($zip->set_number('4960854')->is_valid_number, '愛知県津島市老松町');
ok($zip->set_number('4960855')->is_valid_number, '愛知県津島市江東町');
ok($zip->set_number('4960856')->is_valid_number, '愛知県津島市瑠璃小路町');
ok($zip->set_number('4960857')->is_valid_number, '愛知県津島市南門前町');
ok($zip->set_number('4960861')->is_valid_number, '愛知県津島市観音町');
ok($zip->set_number('4960862')->is_valid_number, '愛知県津島市城山町');
ok($zip->set_number('4960863')->is_valid_number, '愛知県津島市上之町');
ok($zip->set_number('4960864')->is_valid_number, '愛知県津島市中之町');
ok($zip->set_number('4960865')->is_valid_number, '愛知県津島市馬場町');
ok($zip->set_number('4960866')->is_valid_number, '愛知県津島市大和町');
ok($zip->set_number('4960867')->is_valid_number, '愛知県津島市江川町');
ok($zip->set_number('4960868')->is_valid_number, '愛知県津島市申塚町');
ok($zip->set_number('4960869')->is_valid_number, '愛知県津島市河原町');
ok($zip->set_number('4960871')->is_valid_number, '愛知県津島市上新田町');
ok($zip->set_number('4960872')->is_valid_number, '愛知県津島市松ケ下町');
ok($zip->set_number('4960873')->is_valid_number, '愛知県津島市一本木町');
ok($zip->set_number('4960874')->is_valid_number, '愛知県津島市江西町');
ok($zip->set_number('4960875')->is_valid_number, '愛知県津島市下新田町');
ok($zip->set_number('4960876')->is_valid_number, '愛知県津島市大縄町');
ok($zip->set_number('4960877')->is_valid_number, '愛知県津島市河田町');
ok($zip->set_number('4960901')->is_valid_number, '愛知県愛西市佐屋町');
ok($zip->set_number('4960902')->is_valid_number, '愛知県愛西市須依町');
ok($zip->set_number('4960903')->is_valid_number, '愛知県愛西市内佐屋町');
ok($zip->set_number('4960904')->is_valid_number, '愛知県愛西市柚木町');
ok($zip->set_number('4960905')->is_valid_number, '愛知県愛西市北一色町');
ok($zip->set_number('4960906')->is_valid_number, '愛知県愛西市日置町');
ok($zip->set_number('4960907')->is_valid_number, '愛知県愛西市稲葉町');
ok($zip->set_number('4960908')->is_valid_number, '愛知県愛西市金棒町');
ok($zip->set_number('4960908')->is_valid_number, '愛知県愛西市甘村井町');
ok($zip->set_number('4960909')->is_valid_number, '愛知県愛西市落合町');
ok($zip->set_number('4960911')->is_valid_number, '愛知県愛西市西保町');
ok($zip->set_number('4960912')->is_valid_number, '愛知県愛西市東保町');
ok($zip->set_number('4960913')->is_valid_number, '愛知県愛西市西條町');
ok($zip->set_number('4960914')->is_valid_number, '愛知県愛西市東條町');
ok($zip->set_number('4960915')->is_valid_number, '愛知県愛西市本部田町');
ok($zip->set_number('4960921')->is_valid_number, '愛知県愛西市大井町');
ok($zip->set_number('4960922')->is_valid_number, '愛知県愛西市大野町');
ok($zip->set_number('4960923')->is_valid_number, '愛知県愛西市鰯江町');
ok($zip->set_number('4960924')->is_valid_number, '愛知県愛西市善太新田町');
ok($zip->set_number('4960931')->is_valid_number, '愛知県愛西市早尾町');
ok($zip->set_number('4960932')->is_valid_number, '愛知県愛西市葛木町');
ok($zip->set_number('4960933')->is_valid_number, '愛知県愛西市戸倉町');
ok($zip->set_number('4960934')->is_valid_number, '愛知県愛西市新右エ門新田町');
ok($zip->set_number('4960935')->is_valid_number, '愛知県愛西市下一色町');
ok($zip->set_number('4960936')->is_valid_number, '愛知県愛西市四会町');
ok($zip->set_number('4960937')->is_valid_number, '愛知県愛西市宮地町');
ok($zip->set_number('4960938')->is_valid_number, '愛知県愛西市石田町');
ok($zip->set_number('4960939')->is_valid_number, '愛知県愛西市後江町');
ok($zip->set_number('4960941')->is_valid_number, '愛知県愛西市雀ケ森町');
ok($zip->set_number('4960942')->is_valid_number, '愛知県愛西市山路町');
ok($zip->set_number('4960943')->is_valid_number, '愛知県愛西市森川町');
ok($zip->set_number('4960944')->is_valid_number, '愛知県愛西市小茂井町');
ok($zip->set_number('4960945')->is_valid_number, '愛知県愛西市三和町');
ok($zip->set_number('4960946')->is_valid_number, '愛知県愛西市立田町');
ok($zip->set_number('4960947')->is_valid_number, '愛知県愛西市福原新田町');
ok($zip->set_number('4968001')->is_valid_number, '愛知県愛西市勝幡町');
ok($zip->set_number('4968002')->is_valid_number, '愛知県愛西市佐折町');
ok($zip->set_number('4968003')->is_valid_number, '愛知県愛西市千引町');
ok($zip->set_number('4968004')->is_valid_number, '愛知県愛西市古瀬町');
ok($zip->set_number('4968005')->is_valid_number, '愛知県愛西市諸桑町');
ok($zip->set_number('4968006')->is_valid_number, '愛知県愛西市持中町');
ok($zip->set_number('4968007')->is_valid_number, '愛知県愛西市南河田町');
ok($zip->set_number('4968008')->is_valid_number, '愛知県愛西市北河田町');
ok($zip->set_number('4968009')->is_valid_number, '愛知県愛西市小津町');
ok($zip->set_number('4968010')->is_valid_number, '愛知県愛西市六輪町');
ok($zip->set_number('4968011')->is_valid_number, '愛知県愛西市諏訪町');
ok($zip->set_number('4968012')->is_valid_number, '愛知県愛西市根高町');
ok($zip->set_number('4968013')->is_valid_number, '愛知県愛西市見越町');
ok($zip->set_number('4968014')->is_valid_number, '愛知県愛西市町方町');
ok($zip->set_number('4968015')->is_valid_number, '愛知県愛西市草平町');
ok($zip->set_number('4968016')->is_valid_number, '愛知県愛西市鷹場町');
ok($zip->set_number('4968017')->is_valid_number, '愛知県愛西市大野山町');
ok($zip->set_number('4968018')->is_valid_number, '愛知県愛西市渕高町');
ok($zip->set_number('4968019')->is_valid_number, '愛知県愛西市西川端町');
ok($zip->set_number('4968020')->is_valid_number, '愛知県愛西市平和町');
ok($zip->set_number('4968030')->is_valid_number, '愛知県愛西市二子町柳原');
ok($zip->set_number('4968031')->is_valid_number, '愛知県愛西市上東川町');
ok($zip->set_number('4968032')->is_valid_number, '愛知県愛西市下東川町');
ok($zip->set_number('4968033')->is_valid_number, '愛知県愛西市鵜多須町');
ok($zip->set_number('4968034')->is_valid_number, '愛知県愛西市二子町小判山');
ok($zip->set_number('4968035')->is_valid_number, '愛知県愛西市二子町上丸島');
ok($zip->set_number('4968036')->is_valid_number, '愛知県愛西市二子町丸島');
ok($zip->set_number('4968037')->is_valid_number, '愛知県愛西市二子町新田');
ok($zip->set_number('4968038')->is_valid_number, '愛知県愛西市二子町定納');
ok($zip->set_number('4968039')->is_valid_number, '愛知県愛西市川北町');
ok($zip->set_number('4968040')->is_valid_number, '愛知県愛西市二子町松原');
ok($zip->set_number('4968041')->is_valid_number, '愛知県愛西市藤ケ瀬町');
ok($zip->set_number('4968042')->is_valid_number, '愛知県愛西市給父町');
ok($zip->set_number('4968043')->is_valid_number, '愛知県愛西市高畑町');
ok($zip->set_number('4968044')->is_valid_number, '愛知県愛西市江西町');
ok($zip->set_number('4968045')->is_valid_number, '愛知県愛西市元赤目町');
ok($zip->set_number('4968046')->is_valid_number, '愛知県愛西市赤目町');
ok($zip->set_number('4968047')->is_valid_number, '愛知県愛西市立石町');
ok($zip->set_number('4968048')->is_valid_number, '愛知県愛西市下大牧町');
ok($zip->set_number('4968049')->is_valid_number, '愛知県愛西市塩田町');
ok($zip->set_number('4970000')->is_valid_number, '愛知県海部郡蟹江町以下に掲載がない場合');
ok($zip->set_number('4970001')->is_valid_number, '愛知県あま市七宝町沖之島');
ok($zip->set_number('4970002')->is_valid_number, '愛知県あま市七宝町遠島');
ok($zip->set_number('4970003')->is_valid_number, '愛知県あま市七宝町秋竹');
ok($zip->set_number('4970004')->is_valid_number, '愛知県あま市七宝町桂');
ok($zip->set_number('4970005')->is_valid_number, '愛知県あま市七宝町伊福');
ok($zip->set_number('4970006')->is_valid_number, '愛知県あま市七宝町下之森');
ok($zip->set_number('4970011')->is_valid_number, '愛知県あま市七宝町安松');
ok($zip->set_number('4970012')->is_valid_number, '愛知県あま市七宝町下田');
ok($zip->set_number('4970013')->is_valid_number, '愛知県あま市七宝町川部');
ok($zip->set_number('4970014')->is_valid_number, '愛知県あま市七宝町鷹居');
ok($zip->set_number('4970015')->is_valid_number, '愛知県あま市七宝町鯰橋');
ok($zip->set_number('4970016')->is_valid_number, '愛知県あま市七宝町徳実');
ok($zip->set_number('4970030')->is_valid_number, '愛知県海部郡蟹江町宝');
ok($zip->set_number('4970031')->is_valid_number, '愛知県海部郡蟹江町須成');
ok($zip->set_number('4970032')->is_valid_number, '愛知県海部郡蟹江町今');
ok($zip->set_number('4970033')->is_valid_number, '愛知県海部郡蟹江町蟹江本町');
ok($zip->set_number('4970034')->is_valid_number, '愛知県海部郡蟹江町本町');
ok($zip->set_number('4970035')->is_valid_number, '愛知県海部郡蟹江町蟹江新町');
ok($zip->set_number('4970036')->is_valid_number, '愛知県海部郡蟹江町須成西');
ok($zip->set_number('4970037')->is_valid_number, '愛知県海部郡蟹江町今西');
ok($zip->set_number('4970038')->is_valid_number, '愛知県海部郡蟹江町桜');
ok($zip->set_number('4970040')->is_valid_number, '愛知県海部郡蟹江町城');
ok($zip->set_number('4970041')->is_valid_number, '愛知県海部郡蟹江町南');
ok($zip->set_number('4970042')->is_valid_number, '愛知県海部郡蟹江町鍋蓋新田');
ok($zip->set_number('4970043')->is_valid_number, '愛知県海部郡蟹江町新千秋');
ok($zip->set_number('4970044')->is_valid_number, '愛知県海部郡蟹江町蟹江新田');
ok($zip->set_number('4970045')->is_valid_number, '愛知県海部郡蟹江町緑');
ok($zip->set_number('4970046')->is_valid_number, '愛知県海部郡蟹江町旭');
ok($zip->set_number('4970047')->is_valid_number, '愛知県海部郡蟹江町泉');
ok($zip->set_number('4970048')->is_valid_number, '愛知県海部郡蟹江町舟入');
ok($zip->set_number('4970050')->is_valid_number, '愛知県海部郡蟹江町学戸');
ok($zip->set_number('4970051')->is_valid_number, '愛知県海部郡蟹江町北新田');
ok($zip->set_number('4970052')->is_valid_number, '愛知県海部郡蟹江町西之森');
ok($zip->set_number('4970053')->is_valid_number, '愛知県海部郡蟹江町平安');
ok($zip->set_number('4970054')->is_valid_number, '愛知県海部郡蟹江町錦');
ok($zip->set_number('4970055')->is_valid_number, '愛知県海部郡蟹江町源氏');
ok($zip->set_number('4970056')->is_valid_number, '愛知県海部郡蟹江町八幡');
ok($zip->set_number('4970057')->is_valid_number, '愛知県海部郡蟹江町上川田');
ok($zip->set_number('4970058')->is_valid_number, '愛知県海部郡蟹江町富吉');
ok($zip->set_number('4980000')->is_valid_number, '愛知県弥富市以下に掲載がない場合');
ok($zip->set_number('4980000')->is_valid_number, '三重県桑名郡木曽岬町以下に掲載がない場合');
ok($zip->set_number('4980001')->is_valid_number, '愛知県弥富市西中地町');
ok($zip->set_number('4980002')->is_valid_number, '愛知県弥富市東中地');
ok($zip->set_number('4980003')->is_valid_number, '愛知県弥富市前ケ平');
ok($zip->set_number('4980004')->is_valid_number, '愛知県弥富市又八');
ok($zip->set_number('4980004')->is_valid_number, '愛知県弥富市又八町');
ok($zip->set_number('4980005')->is_valid_number, '愛知県弥富市楽平');
ok($zip->set_number('4980006')->is_valid_number, '愛知県弥富市佐古木');
ok($zip->set_number('4980007')->is_valid_number, '愛知県弥富市鎌倉町');
ok($zip->set_number('4980011')->is_valid_number, '愛知県弥富市荷之上町');
ok($zip->set_number('4980012')->is_valid_number, '愛知県弥富市五之三町');
ok($zip->set_number('4980013')->is_valid_number, '愛知県弥富市川平');
ok($zip->set_number('4980014')->is_valid_number, '愛知県弥富市五明');
ok($zip->set_number('4980014')->is_valid_number, '愛知県弥富市五明町');
ok($zip->set_number('4980015')->is_valid_number, '愛知県弥富市海老江');
ok($zip->set_number('4980016')->is_valid_number, '愛知県弥富市小島町');
ok($zip->set_number('4980017')->is_valid_number, '愛知県弥富市前ケ須町');
ok($zip->set_number('4980018')->is_valid_number, '愛知県弥富市五之三川平');
ok($zip->set_number('4980021')->is_valid_number, '愛知県弥富市鯏浦町(その他)');
ok($zip->set_number('4980022')->is_valid_number, '愛知県弥富市鯏浦町(下六)');
ok($zip->set_number('4980023')->is_valid_number, '愛知県弥富市鯏浦町(上六)');
ok($zip->set_number('4980024')->is_valid_number, '愛知県弥富市鯏浦町(気開)');
ok($zip->set_number('4980025')->is_valid_number, '愛知県弥富市平島町(喜右味名)');
ok($zip->set_number('4980026')->is_valid_number, '愛知県弥富市鯏浦町(西前新田)');
ok($zip->set_number('4980027')->is_valid_number, '愛知県弥富市鯏浦町(南前新田)');
ok($zip->set_number('4980028')->is_valid_number, '愛知県弥富市鯏浦町(中六)');
ok($zip->set_number('4980031')->is_valid_number, '愛知県弥富市平島町(その他)');
ok($zip->set_number('4980032')->is_valid_number, '愛知県弥富市平島中');
ok($zip->set_number('4980033')->is_valid_number, '愛知県弥富市平島西');
ok($zip->set_number('4980034')->is_valid_number, '愛知県弥富市平島東');
ok($zip->set_number('4980035')->is_valid_number, '愛知県弥富市鎌島');
ok($zip->set_number('4980036')->is_valid_number, '愛知県弥富市森津');
ok($zip->set_number('4980036')->is_valid_number, '愛知県弥富市森津町');
ok($zip->set_number('4980037')->is_valid_number, '愛知県弥富市川原欠');
ok($zip->set_number('4980037')->is_valid_number, '愛知県弥富市川原欠町');
ok($zip->set_number('4980038')->is_valid_number, '愛知県弥富市中山町');
ok($zip->set_number('4980039')->is_valid_number, '愛知県弥富市大藤町');
ok($zip->set_number('4980040')->is_valid_number, '愛知県弥富市栄南町');
ok($zip->set_number('4980041')->is_valid_number, '愛知県弥富市芝井');
ok($zip->set_number('4980041')->is_valid_number, '愛知県弥富市芝井町');
ok($zip->set_number('4980042')->is_valid_number, '愛知県弥富市松名');
ok($zip->set_number('4980042')->is_valid_number, '愛知県弥富市松名町');
ok($zip->set_number('4980043')->is_valid_number, '愛知県弥富市寛延');
ok($zip->set_number('4980044')->is_valid_number, '愛知県弥富市間崎');
ok($zip->set_number('4980044')->is_valid_number, '愛知県弥富市間崎町');
ok($zip->set_number('4980045')->is_valid_number, '愛知県弥富市稲元');
ok($zip->set_number('4980045')->is_valid_number, '愛知県弥富市稲元町');
ok($zip->set_number('4980046')->is_valid_number, '愛知県弥富市三好');
ok($zip->set_number('4980046')->is_valid_number, '愛知県弥富市三好町');
ok($zip->set_number('4980047')->is_valid_number, '愛知県弥富市加稲');
ok($zip->set_number('4980048')->is_valid_number, '愛知県弥富市稲吉');
ok($zip->set_number('4980049')->is_valid_number, '愛知県弥富市大縄場町');
ok($zip->set_number('4980051')->is_valid_number, '愛知県弥富市狐地');
ok($zip->set_number('4980051')->is_valid_number, '愛知県弥富市狐地町');
ok($zip->set_number('4980052')->is_valid_number, '愛知県弥富市稲荷');
ok($zip->set_number('4980052')->is_valid_number, '愛知県弥富市稲荷町');
ok($zip->set_number('4980053')->is_valid_number, '愛知県弥富市稲狐町');
ok($zip->set_number('4980054')->is_valid_number, '愛知県弥富市三稲');
ok($zip->set_number('4980054')->is_valid_number, '愛知県弥富市三稲町');
ok($zip->set_number('4980055')->is_valid_number, '愛知県弥富市境町');
ok($zip->set_number('4980056')->is_valid_number, '愛知県弥富市稲荷崎');
ok($zip->set_number('4980056')->is_valid_number, '愛知県弥富市稲荷崎町');
ok($zip->set_number('4980057')->is_valid_number, '愛知県弥富市中原');
ok($zip->set_number('4980057')->is_valid_number, '愛知県弥富市中原町');
ok($zip->set_number('4980058')->is_valid_number, '愛知県弥富市富島');
ok($zip->set_number('4980058')->is_valid_number, '愛知県弥富市富島町');
ok($zip->set_number('4980060')->is_valid_number, '愛知県弥富市曙');
ok($zip->set_number('4980061')->is_valid_number, '愛知県弥富市操出');
ok($zip->set_number('4980062')->is_valid_number, '愛知県弥富市大谷');
ok($zip->set_number('4980063')->is_valid_number, '愛知県弥富市東末広');
ok($zip->set_number('4980064')->is_valid_number, '愛知県弥富市西末広');
ok($zip->set_number('4980065')->is_valid_number, '愛知県弥富市駒野町');
ok($zip->set_number('4980066')->is_valid_number, '愛知県弥富市楠');
ok($zip->set_number('4980067')->is_valid_number, '愛知県弥富市上野町');
ok($zip->set_number('4980068')->is_valid_number, '愛知県弥富市鍋田町');
ok($zip->set_number('4980069')->is_valid_number, '愛知県弥富市富浜');
ok($zip->set_number('4980801')->is_valid_number, '三重県桑名郡木曽岬町加路戸');
ok($zip->set_number('4980802')->is_valid_number, '三重県桑名郡木曽岬町見入');
ok($zip->set_number('4980803')->is_valid_number, '三重県桑名郡木曽岬町和泉');
ok($zip->set_number('4980804')->is_valid_number, '三重県桑名郡木曽岬町小和泉');
ok($zip->set_number('4980805')->is_valid_number, '三重県桑名郡木曽岬町小林');
ok($zip->set_number('4980806')->is_valid_number, '三重県桑名郡木曽岬町外平喜');
ok($zip->set_number('4980807')->is_valid_number, '三重県桑名郡木曽岬町西対海地');
ok($zip->set_number('4980808')->is_valid_number, '三重県桑名郡木曽岬町近江島');
ok($zip->set_number('4980810')->is_valid_number, '三重県桑名郡木曽岬町川先');
ok($zip->set_number('4980811')->is_valid_number, '三重県桑名郡木曽岬町栄');
ok($zip->set_number('4980812')->is_valid_number, '三重県桑名郡木曽岬町中和泉');
ok($zip->set_number('4980813')->is_valid_number, '三重県桑名郡木曽岬町富田子');
ok($zip->set_number('4980814')->is_valid_number, '三重県桑名郡木曽岬町三崎');
ok($zip->set_number('4980815')->is_valid_number, '三重県桑名郡木曽岬町白鷺');
ok($zip->set_number('4980816')->is_valid_number, '三重県桑名郡木曽岬町源緑輪中');
ok($zip->set_number('4980817')->is_valid_number, '三重県桑名郡木曽岬町松永');
ok($zip->set_number('4980818')->is_valid_number, '三重県桑名郡木曽岬町雁ケ地');
ok($zip->set_number('4980819')->is_valid_number, '三重県桑名郡木曽岬町田代');
ok($zip->set_number('4980821')->is_valid_number, '三重県桑名郡木曽岬町新加路戸');
ok($zip->set_number('4980822')->is_valid_number, '三重県桑名郡木曽岬町見入流作');
ok($zip->set_number('4980823')->is_valid_number, '三重県桑名郡木曽岬町和富');
ok($zip->set_number('4980824')->is_valid_number, '三重県桑名郡木曽岬町新輪');
ok($zip->set_number('5000000')->is_valid_number, '岐阜県岐阜市以下に掲載がない場合');
ok($zip->set_number('5008001')->is_valid_number, '岐阜県岐阜市鏡岩');
ok($zip->set_number('5008002')->is_valid_number, '岐阜県岐阜市御手洗');
ok($zip->set_number('5008003')->is_valid_number, '岐阜県岐阜市大宮町');
ok($zip->set_number('5008004')->is_valid_number, '岐阜県岐阜市千畳敷');
ok($zip->set_number('5008005')->is_valid_number, '岐阜県岐阜市上材木町');
ok($zip->set_number('5008006')->is_valid_number, '岐阜県岐阜市堤外');
ok($zip->set_number('5008007')->is_valid_number, '岐阜県岐阜市元浜町');
ok($zip->set_number('5008008')->is_valid_number, '岐阜県岐阜市玉井町');
ok($zip->set_number('5008009')->is_valid_number, '岐阜県岐阜市湊町');
ok($zip->set_number('5008011')->is_valid_number, '岐阜県岐阜市木挽町');
ok($zip->set_number('5008012')->is_valid_number, '岐阜県岐阜市山口町');
ok($zip->set_number('5008013')->is_valid_number, '岐阜県岐阜市松下町');
ok($zip->set_number('5008014')->is_valid_number, '岐阜県岐阜市夕陽ケ丘');
ok($zip->set_number('5008015')->is_valid_number, '岐阜県岐阜市松山町');
ok($zip->set_number('5008016')->is_valid_number, '岐阜県岐阜市松ケ枝町');
ok($zip->set_number('5008017')->is_valid_number, '岐阜県岐阜市梶川町');
ok($zip->set_number('5008018')->is_valid_number, '岐阜県岐阜市大仏町');
ok($zip->set_number('5008019')->is_valid_number, '岐阜県岐阜市益屋町');
ok($zip->set_number('5008021')->is_valid_number, '岐阜県岐阜市上茶屋町');
ok($zip->set_number('5008022')->is_valid_number, '岐阜県岐阜市下茶屋町');
ok($zip->set_number('5008023')->is_valid_number, '岐阜県岐阜市今町');
ok($zip->set_number('5008024')->is_valid_number, '岐阜県岐阜市上新町');
ok($zip->set_number('5008025')->is_valid_number, '岐阜県岐阜市久屋町');
ok($zip->set_number('5008026')->is_valid_number, '岐阜県岐阜市上大久和町');
ok($zip->set_number('5008027')->is_valid_number, '岐阜県岐阜市中大桑町');
ok($zip->set_number('5008028')->is_valid_number, '岐阜県岐阜市西材木町');
ok($zip->set_number('5008029')->is_valid_number, '岐阜県岐阜市東材木町');
ok($zip->set_number('5008031')->is_valid_number, '岐阜県岐阜市蜂屋町');
ok($zip->set_number('5008032')->is_valid_number, '岐阜県岐阜市中新町');
ok($zip->set_number('5008033')->is_valid_number, '岐阜県岐阜市魚屋町');
ok($zip->set_number('5008034')->is_valid_number, '岐阜県岐阜市本町');
ok($zip->set_number('5008035')->is_valid_number, '岐阜県岐阜市布屋町');
ok($zip->set_number('5008036')->is_valid_number, '岐阜県岐阜市甚衛町');
ok($zip->set_number('5008037')->is_valid_number, '岐阜県岐阜市下新町');
ok($zip->set_number('5008038')->is_valid_number, '岐阜県岐阜市大工町');
ok($zip->set_number('5008039')->is_valid_number, '岐阜県岐阜市下大桑町');
ok($zip->set_number('5008041')->is_valid_number, '岐阜県岐阜市靱屋町');
ok($zip->set_number('5008042')->is_valid_number, '岐阜県岐阜市末広町');
ok($zip->set_number('5008043')->is_valid_number, '岐阜県岐阜市伊奈波通');
ok($zip->set_number('5008044')->is_valid_number, '岐阜県岐阜市万力町');
ok($zip->set_number('5008045')->is_valid_number, '岐阜県岐阜市新桜町');
ok($zip->set_number('5008046')->is_valid_number, '岐阜県岐阜市米屋町');
ok($zip->set_number('5008047')->is_valid_number, '岐阜県岐阜市中竹屋町');
ok($zip->set_number('5008048')->is_valid_number, '岐阜県岐阜市大和町');
ok($zip->set_number('5008049')->is_valid_number, '岐阜県岐阜市上竹屋町');
ok($zip->set_number('5008051')->is_valid_number, '岐阜県岐阜市駿河山');
ok($zip->set_number('5008052')->is_valid_number, '岐阜県岐阜市鶯谷');
ok($zip->set_number('5008053')->is_valid_number, '岐阜県岐阜市鶯谷町');
ok($zip->set_number('5008054')->is_valid_number, '岐阜県岐阜市大門町');
ok($zip->set_number('5008055')->is_valid_number, '岐阜県岐阜市笹土居町');
ok($zip->set_number('5008056')->is_valid_number, '岐阜県岐阜市下竹町');
ok($zip->set_number('5008057')->is_valid_number, '岐阜県岐阜市上竹町');
ok($zip->set_number('5008058')->is_valid_number, '岐阜県岐阜市常盤町');
ok($zip->set_number('5008059')->is_valid_number, '岐阜県岐阜市栄扇町');
ok($zip->set_number('5008061')->is_valid_number, '岐阜県岐阜市小熊町');
ok($zip->set_number('5008062')->is_valid_number, '岐阜県岐阜市初音町');
ok($zip->set_number('5008063')->is_valid_number, '岐阜県岐阜市金屋横町');
ok($zip->set_number('5008064')->is_valid_number, '岐阜県岐阜市柳沢町');
ok($zip->set_number('5008065')->is_valid_number, '岐阜県岐阜市金屋町');
ok($zip->set_number('5008066')->is_valid_number, '岐阜県岐阜市下太田町');
ok($zip->set_number('5008067')->is_valid_number, '岐阜県岐阜市秋津町');
ok($zip->set_number('5008068')->is_valid_number, '岐阜県岐阜市上太田町');
ok($zip->set_number('5008069')->is_valid_number, '岐阜県岐阜市今小町');
ok($zip->set_number('5008071')->is_valid_number, '岐阜県岐阜市柳町');
ok($zip->set_number('5008072')->is_valid_number, '岐阜県岐阜市緑町');
ok($zip->set_number('5008073')->is_valid_number, '岐阜県岐阜市泉町');
ok($zip->set_number('5008074')->is_valid_number, '岐阜県岐阜市七軒町');
ok($zip->set_number('5008075')->is_valid_number, '岐阜県岐阜市室町');
ok($zip->set_number('5008076')->is_valid_number, '岐阜県岐阜市司町');
ok($zip->set_number('5008077')->is_valid_number, '岐阜県岐阜市伊吹町');
ok($zip->set_number('5008078')->is_valid_number, '岐阜県岐阜市柳生町');
ok($zip->set_number('5008079')->is_valid_number, '岐阜県岐阜市御杉町');
ok($zip->set_number('5008081')->is_valid_number, '岐阜県岐阜市啓運町');
ok($zip->set_number('5008082')->is_valid_number, '岐阜県岐阜市矢島町');
ok($zip->set_number('5008083')->is_valid_number, '岐阜県岐阜市間之町');
ok($zip->set_number('5008084')->is_valid_number, '岐阜県岐阜市松屋町');
ok($zip->set_number('5008085')->is_valid_number, '岐阜県岐阜市白木町');
ok($zip->set_number('5008086')->is_valid_number, '岐阜県岐阜市木造町');
ok($zip->set_number('5008087')->is_valid_number, '岐阜県岐阜市堀江町');
ok($zip->set_number('5008088')->is_valid_number, '岐阜県岐阜市四屋町');
ok($zip->set_number('5008089')->is_valid_number, '岐阜県岐阜市若松町');
ok($zip->set_number('5008101')->is_valid_number, '岐阜県岐阜市多賀町');
ok($zip->set_number('5008102')->is_valid_number, '岐阜県岐阜市粕森町');
ok($zip->set_number('5008103')->is_valid_number, '岐阜県岐阜市藍川町');
ok($zip->set_number('5008104')->is_valid_number, '岐阜県岐阜市美園町');
ok($zip->set_number('5008105')->is_valid_number, '岐阜県岐阜市西園町');
ok($zip->set_number('5008106')->is_valid_number, '岐阜県岐阜市東高岩町');
ok($zip->set_number('5008107')->is_valid_number, '岐阜県岐阜市高岩町');
ok($zip->set_number('5008108')->is_valid_number, '岐阜県岐阜市川端町');
ok($zip->set_number('5008109')->is_valid_number, '岐阜県岐阜市朝日町');
ok($zip->set_number('5008111')->is_valid_number, '岐阜県岐阜市梅林');
ok($zip->set_number('5008112')->is_valid_number, '岐阜県岐阜市梅林南町');
ok($zip->set_number('5008113')->is_valid_number, '岐阜県岐阜市金園町');
ok($zip->set_number('5008114')->is_valid_number, '岐阜県岐阜市金竜町');
ok($zip->set_number('5008115')->is_valid_number, '岐阜県岐阜市田端町');
ok($zip->set_number('5008116')->is_valid_number, '岐阜県岐阜市殿町');
ok($zip->set_number('5008117')->is_valid_number, '岐阜県岐阜市南殿町');
ok($zip->set_number('5008118')->is_valid_number, '岐阜県岐阜市寺町');
ok($zip->set_number('5008119')->is_valid_number, '岐阜県岐阜市梅林西町');
ok($zip->set_number('5008121')->is_valid_number, '岐阜県岐阜市上加納山');
ok($zip->set_number('5008122')->is_valid_number, '岐阜県岐阜市旭見ケ池町');
ok($zip->set_number('5008123')->is_valid_number, '岐阜県岐阜市雲竜町');
ok($zip->set_number('5008124')->is_valid_number, '岐阜県岐阜市宝来町');
ok($zip->set_number('5008125')->is_valid_number, '岐阜県岐阜市城望町');
ok($zip->set_number('5008126')->is_valid_number, '岐阜県岐阜市隆城町');
ok($zip->set_number('5008127')->is_valid_number, '岐阜県岐阜市塩町');
ok($zip->set_number('5008128')->is_valid_number, '岐阜県岐阜市花月町');
ok($zip->set_number('5008129')->is_valid_number, '岐阜県岐阜市鶴見町');
ok($zip->set_number('5008131')->is_valid_number, '岐阜県岐阜市月ノ会町');
ok($zip->set_number('5008132')->is_valid_number, '岐阜県岐阜市尼ケ崎町');
ok($zip->set_number('5008133')->is_valid_number, '岐阜県岐阜市永楽町');
ok($zip->set_number('5008134')->is_valid_number, '岐阜県岐阜市岩栄町');
ok($zip->set_number('5008135')->is_valid_number, '岐阜県岐阜市織田塚町');
ok($zip->set_number('5008136')->is_valid_number, '岐阜県岐阜市雪見町');
ok($zip->set_number('5008137')->is_valid_number, '岐阜県岐阜市東興町');
ok($zip->set_number('5008138')->is_valid_number, '岐阜県岐阜市中道北');
ok($zip->set_number('5008139')->is_valid_number, '岐阜県岐阜市庵町');
ok($zip->set_number('5008141')->is_valid_number, '岐阜県岐阜市月丘町');
ok($zip->set_number('5008142')->is_valid_number, '岐阜県岐阜市花沢町');
ok($zip->set_number('5008143')->is_valid_number, '岐阜県岐阜市瑞雲町');
ok($zip->set_number('5008144')->is_valid_number, '岐阜県岐阜市東栄町');
ok($zip->set_number('5008145')->is_valid_number, '岐阜県岐阜市雲井町');
ok($zip->set_number('5008146')->is_valid_number, '岐阜県岐阜市九重町');
ok($zip->set_number('5008147')->is_valid_number, '岐阜県岐阜市三笠町');
ok($zip->set_number('5008148')->is_valid_number, '岐阜県岐阜市曙町');
ok($zip->set_number('5008149')->is_valid_number, '岐阜県岐阜市戎町');
ok($zip->set_number('5008151')->is_valid_number, '岐阜県岐阜市大黒町');
ok($zip->set_number('5008152')->is_valid_number, '岐阜県岐阜市入舟町');
ok($zip->set_number('5008153')->is_valid_number, '岐阜県岐阜市石長町');
ok($zip->set_number('5008154')->is_valid_number, '岐阜県岐阜市木ノ下町');
ok($zip->set_number('5008155')->is_valid_number, '岐阜県岐阜市市ノ坪町');
ok($zip->set_number('5008156')->is_valid_number, '岐阜県岐阜市祈年町');
ok($zip->set_number('5008157')->is_valid_number, '岐阜県岐阜市五坪');
ok($zip->set_number('5008157')->is_valid_number, '岐阜県岐阜市五坪町');
ok($zip->set_number('5008158')->is_valid_number, '岐阜県岐阜市田神');
ok($zip->set_number('5008159')->is_valid_number, '岐阜県岐阜市田神町');
ok($zip->set_number('5008161')->is_valid_number, '岐阜県岐阜市茨木町');
ok($zip->set_number('5008162')->is_valid_number, '岐阜県岐阜市高尾町');
ok($zip->set_number('5008163')->is_valid_number, '岐阜県岐阜市鶴舞町');
ok($zip->set_number('5008164')->is_valid_number, '岐阜県岐阜市鶴田町');
ok($zip->set_number('5008165')->is_valid_number, '岐阜県岐阜市老松町');
ok($zip->set_number('5008166')->is_valid_number, '岐阜県岐阜市天王町');
ok($zip->set_number('5008167')->is_valid_number, '岐阜県岐阜市東金宝町');
ok($zip->set_number('5008168')->is_valid_number, '岐阜県岐阜市東駒爪町');
ok($zip->set_number('5008169')->is_valid_number, '岐阜県岐阜市溝旗町');
ok($zip->set_number('5008171')->is_valid_number, '岐阜県岐阜市高森町');
ok($zip->set_number('5008172')->is_valid_number, '岐阜県岐阜市白山町');
ok($zip->set_number('5008173')->is_valid_number, '岐阜県岐阜市田生越町');
ok($zip->set_number('5008174')->is_valid_number, '岐阜県岐阜市栗矢田町');
ok($zip->set_number('5008175')->is_valid_number, '岐阜県岐阜市長住町');
ok($zip->set_number('5008176')->is_valid_number, '岐阜県岐阜市県町');
ok($zip->set_number('5008177')->is_valid_number, '岐阜県岐阜市長旗町');
ok($zip->set_number('5008178')->is_valid_number, '岐阜県岐阜市清住町');
ok($zip->set_number('5008179')->is_valid_number, '岐阜県岐阜市元住町');
ok($zip->set_number('5008181')->is_valid_number, '岐阜県岐阜市御浪町');
ok($zip->set_number('5008182')->is_valid_number, '岐阜県岐阜市美殿町');
ok($zip->set_number('5008183')->is_valid_number, '岐阜県岐阜市一番町');
ok($zip->set_number('5008184')->is_valid_number, '岐阜県岐阜市西駒爪町');
ok($zip->set_number('5008185')->is_valid_number, '岐阜県岐阜市元町');
ok($zip->set_number('5008186')->is_valid_number, '岐阜県岐阜市霞町');
ok($zip->set_number('5008187')->is_valid_number, '岐阜県岐阜市吉津町');
ok($zip->set_number('5008188')->is_valid_number, '岐阜県岐阜市二番町');
ok($zip->set_number('5008189')->is_valid_number, '岐阜県岐阜市三番町');
ok($zip->set_number('5008207')->is_valid_number, '岐阜県岐阜市日野北');
ok($zip->set_number('5008211')->is_valid_number, '岐阜県岐阜市日野東');
ok($zip->set_number('5008212')->is_valid_number, '岐阜県岐阜市日野南');
ok($zip->set_number('5008213')->is_valid_number, '岐阜県岐阜市日野西');
ok($zip->set_number('5008221')->is_valid_number, '岐阜県岐阜市天池');
ok($zip->set_number('5008222')->is_valid_number, '岐阜県岐阜市琴塚');
ok($zip->set_number('5008223')->is_valid_number, '岐阜県岐阜市水海道');
ok($zip->set_number('5008224')->is_valid_number, '岐阜県岐阜市高田');
ok($zip->set_number('5008225')->is_valid_number, '岐阜県岐阜市岩地');
ok($zip->set_number('5008226')->is_valid_number, '岐阜県岐阜市野一色');
ok($zip->set_number('5008227')->is_valid_number, '岐阜県岐阜市北一色');
ok($zip->set_number('5008228')->is_valid_number, '岐阜県岐阜市長森本町');
ok($zip->set_number('5008229')->is_valid_number, '岐阜県岐阜市長森岩戸');
ok($zip->set_number('5008231')->is_valid_number, '岐阜県岐阜市前一色西町');
ok($zip->set_number('5008232')->is_valid_number, '岐阜県岐阜市前一色');
ok($zip->set_number('5008233')->is_valid_number, '岐阜県岐阜市蔵前');
ok($zip->set_number('5008234')->is_valid_number, '岐阜県岐阜市芋島');
ok($zip->set_number('5008235')->is_valid_number, '岐阜県岐阜市東中島');
ok($zip->set_number('5008236')->is_valid_number, '岐阜県岐阜市手力町');
ok($zip->set_number('5008237')->is_valid_number, '岐阜県岐阜市切通');
ok($zip->set_number('5008238')->is_valid_number, '岐阜県岐阜市細畑');
ok($zip->set_number('5008241')->is_valid_number, '岐阜県岐阜市領下');
ok($zip->set_number('5008242')->is_valid_number, '岐阜県岐阜市細畑野寄');
ok($zip->set_number('5008243')->is_valid_number, '岐阜県岐阜市細畑華南');
ok($zip->set_number('5008244')->is_valid_number, '岐阜県岐阜市細畑塚浦');
ok($zip->set_number('5008245')->is_valid_number, '岐阜県岐阜市上川手');
ok($zip->set_number('5008246')->is_valid_number, '岐阜県岐阜市下川手');
ok($zip->set_number('5008247')->is_valid_number, '岐阜県岐阜市長森細畑');
ok($zip->set_number('5008251')->is_valid_number, '岐阜県岐阜市加納御車町');
ok($zip->set_number('5008252')->is_valid_number, '岐阜県岐阜市加納舟田町');
ok($zip->set_number('5008253')->is_valid_number, '岐阜県岐阜市薬師町');
ok($zip->set_number('5008254')->is_valid_number, '岐阜県岐阜市光樹町');
ok($zip->set_number('5008255')->is_valid_number, '岐阜県岐阜市朝霧町');
ok($zip->set_number('5008256')->is_valid_number, '岐阜県岐阜市八坂町');
ok($zip->set_number('5008257')->is_valid_number, '岐阜県岐阜市東川手');
ok($zip->set_number('5008258')->is_valid_number, '岐阜県岐阜市西川手');
ok($zip->set_number('5008259')->is_valid_number, '岐阜県岐阜市水主町');
ok($zip->set_number('5008261')->is_valid_number, '岐阜県岐阜市茜部大野');
ok($zip->set_number('5008262')->is_valid_number, '岐阜県岐阜市茜部本郷');
ok($zip->set_number('5008263')->is_valid_number, '岐阜県岐阜市茜部新所');
ok($zip->set_number('5008264')->is_valid_number, '岐阜県岐阜市茜部辰新');
ok($zip->set_number('5008265')->is_valid_number, '岐阜県岐阜市茜部神清寺');
ok($zip->set_number('5008266')->is_valid_number, '岐阜県岐阜市境川');
ok($zip->set_number('5008267')->is_valid_number, '岐阜県岐阜市茜部寺屋敷');
ok($zip->set_number('5008268')->is_valid_number, '岐阜県岐阜市茜部菱野');
ok($zip->set_number('5008269')->is_valid_number, '岐阜県岐阜市茜部中島');
ok($zip->set_number('5008271')->is_valid_number, '岐阜県岐阜市加納堀田町');
ok($zip->set_number('5008272')->is_valid_number, '岐阜県岐阜市加納奥平町');
ok($zip->set_number('5008273')->is_valid_number, '岐阜県岐阜市加納矢場町');
ok($zip->set_number('5008274')->is_valid_number, '岐阜県岐阜市加納鷹匠町');
ok($zip->set_number('5008275')->is_valid_number, '岐阜県岐阜市加納花ノ木町');
ok($zip->set_number('5008276')->is_valid_number, '岐阜県岐阜市加納南陽町');
ok($zip->set_number('5008277')->is_valid_number, '岐阜県岐阜市加納立花町');
ok($zip->set_number('5008278')->is_valid_number, '岐阜県岐阜市加納西山町');
ok($zip->set_number('5008279')->is_valid_number, '岐阜県岐阜市加納梅田町');
ok($zip->set_number('5008281')->is_valid_number, '岐阜県岐阜市東鶉');
ok($zip->set_number('5008282')->is_valid_number, '岐阜県岐阜市茜部大川');
ok($zip->set_number('5008283')->is_valid_number, '岐阜県岐阜市茜部野瀬');
ok($zip->set_number('5008284')->is_valid_number, '岐阜県岐阜市茜町');
ok($zip->set_number('5008285')->is_valid_number, '岐阜県岐阜市南鶉');
ok($zip->set_number('5008286')->is_valid_number, '岐阜県岐阜市西鶉');
ok($zip->set_number('5008287')->is_valid_number, '岐阜県岐阜市北鶉');
ok($zip->set_number('5008288')->is_valid_number, '岐阜県岐阜市中鶉');
ok($zip->set_number('5008289')->is_valid_number, '岐阜県岐阜市須賀');
ok($zip->set_number('5008301')->is_valid_number, '岐阜県岐阜市浪花町');
ok($zip->set_number('5008302')->is_valid_number, '岐阜県岐阜市本郷町');
ok($zip->set_number('5008303')->is_valid_number, '岐阜県岐阜市春日町');
ok($zip->set_number('5008304')->is_valid_number, '岐阜県岐阜市柳川町');
ok($zip->set_number('5008305')->is_valid_number, '岐阜県岐阜市沖ノ橋町');
ok($zip->set_number('5008306')->is_valid_number, '岐阜県岐阜市鍵屋東町');
ok($zip->set_number('5008307')->is_valid_number, '岐阜県岐阜市弁天町');
ok($zip->set_number('5008308')->is_valid_number, '岐阜県岐阜市三橋町');
ok($zip->set_number('5008309')->is_valid_number, '岐阜県岐阜市都通');
ok($zip->set_number('5008311')->is_valid_number, '岐阜県岐阜市長者町');
ok($zip->set_number('5008312')->is_valid_number, '岐阜県岐阜市村雨町');
ok($zip->set_number('5008313')->is_valid_number, '岐阜県岐阜市鍵屋中町');
ok($zip->set_number('5008314')->is_valid_number, '岐阜県岐阜市鍵屋西町');
ok($zip->set_number('5008315')->is_valid_number, '岐阜県岐阜市島田東町');
ok($zip->set_number('5008316')->is_valid_number, '岐阜県岐阜市島田中町');
ok($zip->set_number('5008317')->is_valid_number, '岐阜県岐阜市島田西町');
ok($zip->set_number('5008318')->is_valid_number, '岐阜県岐阜市桜通');
ok($zip->set_number('5008319')->is_valid_number, '岐阜県岐阜市桜木町');
ok($zip->set_number('5008319')->is_valid_number, '岐阜県岐阜市早田(1973~2009番地)');
ok($zip->set_number('5008321')->is_valid_number, '岐阜県岐阜市菊井町');
ok($zip->set_number('5008322')->is_valid_number, '岐阜県岐阜市香取町');
ok($zip->set_number('5008323')->is_valid_number, '岐阜県岐阜市鹿島町');
ok($zip->set_number('5008324')->is_valid_number, '岐阜県岐阜市早苗町');
ok($zip->set_number('5008325')->is_valid_number, '岐阜県岐阜市寿町');
ok($zip->set_number('5008326')->is_valid_number, '岐阜県岐阜市吹上町');
ok($zip->set_number('5008327')->is_valid_number, '岐阜県岐阜市如月町');
ok($zip->set_number('5008328')->is_valid_number, '岐阜県岐阜市五反田町');
ok($zip->set_number('5008329')->is_valid_number, '岐阜県岐阜市本荘町');
ok($zip->set_number('5008331')->is_valid_number, '岐阜県岐阜市錦町');
ok($zip->set_number('5008332')->is_valid_number, '岐阜県岐阜市羽衣町');
ok($zip->set_number('5008333')->is_valid_number, '岐阜県岐阜市此花町');
ok($zip->set_number('5008334')->is_valid_number, '岐阜県岐阜市葭町');
ok($zip->set_number('5008335')->is_valid_number, '岐阜県岐阜市三歳町');
ok($zip->set_number('5008336')->is_valid_number, '岐阜県岐阜市稲荷町');
ok($zip->set_number('5008337')->is_valid_number, '岐阜県岐阜市雨踊町');
ok($zip->set_number('5008339')->is_valid_number, '岐阜県岐阜市千鳥町');
ok($zip->set_number('5008341')->is_valid_number, '岐阜県岐阜市南本荘四条通');
ok($zip->set_number('5008342')->is_valid_number, '岐阜県岐阜市南本荘三条通');
ok($zip->set_number('5008343')->is_valid_number, '岐阜県岐阜市南本荘二条通');
ok($zip->set_number('5008344')->is_valid_number, '岐阜県岐阜市南本荘一条通');
ok($zip->set_number('5008345')->is_valid_number, '岐阜県岐阜市菊地町');
ok($zip->set_number('5008346')->is_valid_number, '岐阜県岐阜市清');
ok($zip->set_number('5008347')->is_valid_number, '岐阜県岐阜市松原町');
ok($zip->set_number('5008348')->is_valid_number, '岐阜県岐阜市三ツ又町');
ok($zip->set_number('5008349')->is_valid_number, '岐阜県岐阜市久保見町');
ok($zip->set_number('5008351')->is_valid_number, '岐阜県岐阜市清本町');
ok($zip->set_number('5008352')->is_valid_number, '岐阜県岐阜市六条');
ok($zip->set_number('5008353')->is_valid_number, '岐阜県岐阜市六条東');
ok($zip->set_number('5008354')->is_valid_number, '岐阜県岐阜市六条福寿町');
ok($zip->set_number('5008355')->is_valid_number, '岐阜県岐阜市六条片田');
ok($zip->set_number('5008356')->is_valid_number, '岐阜県岐阜市六条江東');
ok($zip->set_number('5008357')->is_valid_number, '岐阜県岐阜市六条大溝');
ok($zip->set_number('5008358')->is_valid_number, '岐阜県岐阜市六条南');
ok($zip->set_number('5008359')->is_valid_number, '岐阜県岐阜市六条北');
ok($zip->set_number('5008361')->is_valid_number, '岐阜県岐阜市本荘西');
ok($zip->set_number('5008362')->is_valid_number, '岐阜県岐阜市西荘');
ok($zip->set_number('5008363')->is_valid_number, '岐阜県岐阜市爪');
ok($zip->set_number('5008364')->is_valid_number, '岐阜県岐阜市本荘中ノ町');
ok($zip->set_number('5008365')->is_valid_number, '岐阜県岐阜市柳森町');
ok($zip->set_number('5008366')->is_valid_number, '岐阜県岐阜市宇佐東町');
ok($zip->set_number('5008367')->is_valid_number, '岐阜県岐阜市宇佐南');
ok($zip->set_number('5008368')->is_valid_number, '岐阜県岐阜市宇佐');
ok($zip->set_number('5008369')->is_valid_number, '岐阜県岐阜市敷島町');
ok($zip->set_number('5008371')->is_valid_number, '岐阜県岐阜市梅園町');
ok($zip->set_number('5008372')->is_valid_number, '岐阜県岐阜市熊野町');
ok($zip->set_number('5008373')->is_valid_number, '岐阜県岐阜市大池町');
ok($zip->set_number('5008374')->is_valid_number, '岐阜県岐阜市豊岡町');
ok($zip->set_number('5008375')->is_valid_number, '岐阜県岐阜市新興町');
ok($zip->set_number('5008376')->is_valid_number, '岐阜県岐阜市富沢町');
ok($zip->set_number('5008377')->is_valid_number, '岐阜県岐阜市瑞穂町');
ok($zip->set_number('5008378')->is_valid_number, '岐阜県岐阜市雲雀ケ丘');
ok($zip->set_number('5008379')->is_valid_number, '岐阜県岐阜市権現町');
ok($zip->set_number('5008381')->is_valid_number, '岐阜県岐阜市市橋');
ok($zip->set_number('5008382')->is_valid_number, '岐阜県岐阜市薮田東');
ok($zip->set_number('5008383')->is_valid_number, '岐阜県岐阜市江添');
ok($zip->set_number('5008384')->is_valid_number, '岐阜県岐阜市薮田南');
ok($zip->set_number('5008385')->is_valid_number, '岐阜県岐阜市下奈良');
ok($zip->set_number('5008386')->is_valid_number, '岐阜県岐阜市薮田西');
ok($zip->set_number('5008387')->is_valid_number, '岐阜県岐阜市薮田中');
ok($zip->set_number('5008388')->is_valid_number, '岐阜県岐阜市今嶺');
ok($zip->set_number('5008389')->is_valid_number, '岐阜県岐阜市本荘');
ok($zip->set_number('5008401')->is_valid_number, '岐阜県岐阜市安良田町');
ok($zip->set_number('5008402')->is_valid_number, '岐阜県岐阜市竜田町');
ok($zip->set_number('5008403')->is_valid_number, '岐阜県岐阜市一松道');
ok($zip->set_number('5008404')->is_valid_number, '岐阜県岐阜市華陽');
ok($zip->set_number('5008405')->is_valid_number, '岐阜県岐阜市生田町');
ok($zip->set_number('5008406')->is_valid_number, '岐阜県岐阜市平安町');
ok($zip->set_number('5008407')->is_valid_number, '岐阜県岐阜市高砂町');
ok($zip->set_number('5008408')->is_valid_number, '岐阜県岐阜市住ノ江町');
ok($zip->set_number('5008409')->is_valid_number, '岐阜県岐阜市幸ノ町');
ok($zip->set_number('5008411')->is_valid_number, '岐阜県岐阜市安宅町');
ok($zip->set_number('5008412')->is_valid_number, '岐阜県岐阜市松鴻町');
ok($zip->set_number('5008413')->is_valid_number, '岐阜県岐阜市加納東陽町');
ok($zip->set_number('5008414')->is_valid_number, '岐阜県岐阜市加納東広江町');
ok($zip->set_number('5008415')->is_valid_number, '岐阜県岐阜市加納中広江町');
ok($zip->set_number('5008416')->is_valid_number, '岐阜県岐阜市加納徳川町');
ok($zip->set_number('5008417')->is_valid_number, '岐阜県岐阜市加納清田町');
ok($zip->set_number('5008418')->is_valid_number, '岐阜県岐阜市加納西広江町');
ok($zip->set_number('5008419')->is_valid_number, '岐阜県岐阜市加納北広江町');
ok($zip->set_number('5008421')->is_valid_number, '岐阜県岐阜市加納新柳町');
ok($zip->set_number('5008422')->is_valid_number, '岐阜県岐阜市加納安良町');
ok($zip->set_number('5008423')->is_valid_number, '岐阜県岐阜市渋谷町');
ok($zip->set_number('5008424')->is_valid_number, '岐阜県岐阜市加納柳町');
ok($zip->set_number('5008425')->is_valid_number, '岐阜県岐阜市加納新町');
ok($zip->set_number('5008426')->is_valid_number, '岐阜県岐阜市加納南広江町');
ok($zip->set_number('5008427')->is_valid_number, '岐阜県岐阜市加納大石町');
ok($zip->set_number('5008428')->is_valid_number, '岐阜県岐阜市加納桜道');
ok($zip->set_number('5008429')->is_valid_number, '岐阜県岐阜市加納清水町');
ok($zip->set_number('5008431')->is_valid_number, '岐阜県岐阜市加納八幡町');
ok($zip->set_number('5008432')->is_valid_number, '岐阜県岐阜市畷町');
ok($zip->set_number('5008433')->is_valid_number, '岐阜県岐阜市若杉町');
ok($zip->set_number('5008434')->is_valid_number, '岐阜県岐阜市向陽町');
ok($zip->set_number('5008435')->is_valid_number, '岐阜県岐阜市宮北町');
ok($zip->set_number('5008436')->is_valid_number, '岐阜県岐阜市東明見町');
ok($zip->set_number('5008437')->is_valid_number, '岐阜県岐阜市石切町');
ok($zip->set_number('5008438')->is_valid_number, '岐阜県岐阜市島原町');
ok($zip->set_number('5008439')->is_valid_number, '岐阜県岐阜市村里町');
ok($zip->set_number('5008441')->is_valid_number, '岐阜県岐阜市城東通');
ok($zip->set_number('5008442')->is_valid_number, '岐阜県岐阜市正法寺町');
ok($zip->set_number('5008443')->is_valid_number, '岐阜県岐阜市神楽町');
ok($zip->set_number('5008444')->is_valid_number, '岐阜県岐阜市西明見町');
ok($zip->set_number('5008445')->is_valid_number, '岐阜県岐阜市八島町');
ok($zip->set_number('5008446')->is_valid_number, '岐阜県岐阜市矢倉町');
ok($zip->set_number('5008447')->is_valid_number, '岐阜県岐阜市大倉町');
ok($zip->set_number('5008448')->is_valid_number, '岐阜県岐阜市中洲町');
ok($zip->set_number('5008449')->is_valid_number, '岐阜県岐阜市荒川町');
ok($zip->set_number('5008451')->is_valid_number, '岐阜県岐阜市加納上本町');
ok($zip->set_number('5008452')->is_valid_number, '岐阜県岐阜市加納朝日町');
ok($zip->set_number('5008453')->is_valid_number, '岐阜県岐阜市加納鉄砲町');
ok($zip->set_number('5008454')->is_valid_number, '岐阜県岐阜市加納永井町');
ok($zip->set_number('5008455')->is_valid_number, '岐阜県岐阜市加納栄町通');
ok($zip->set_number('5008456')->is_valid_number, '岐阜県岐阜市加納大黒町');
ok($zip->set_number('5008457')->is_valid_number, '岐阜県岐阜市加納青藤町');
ok($zip->set_number('5008458')->is_valid_number, '岐阜県岐阜市加納村松町');
ok($zip->set_number('5008459')->is_valid_number, '岐阜県岐阜市加納高柳町');
ok($zip->set_number('5008461')->is_valid_number, '岐阜県岐阜市加納黒木町');
ok($zip->set_number('5008462')->is_valid_number, '岐阜県岐阜市加納神明町');
ok($zip->set_number('5008463')->is_valid_number, '岐阜県岐阜市加納新本町');
ok($zip->set_number('5008464')->is_valid_number, '岐阜県岐阜市加納前田町');
ok($zip->set_number('5008465')->is_valid_number, '岐阜県岐阜市加納寿町');
ok($zip->set_number('5008466')->is_valid_number, '岐阜県岐阜市加納本石町');
ok($zip->set_number('5008467')->is_valid_number, '岐阜県岐阜市加納三笠町');
ok($zip->set_number('5008468')->is_valid_number, '岐阜県岐阜市加納桜田町');
ok($zip->set_number('5008469')->is_valid_number, '岐阜県岐阜市加納竜興町');
ok($zip->set_number('5008471')->is_valid_number, '岐阜県岐阜市加納富士町');
ok($zip->set_number('5008472')->is_valid_number, '岐阜県岐阜市加納清野町');
ok($zip->set_number('5008473')->is_valid_number, '岐阜県岐阜市加納天神町');
ok($zip->set_number('5008474')->is_valid_number, '岐阜県岐阜市加納本町');
ok($zip->set_number('5008475')->is_valid_number, '岐阜県岐阜市加納坂井町');
ok($zip->set_number('5008476')->is_valid_number, '岐阜県岐阜市加納愛宕町');
ok($zip->set_number('5008477')->is_valid_number, '岐阜県岐阜市加納水野町');
ok($zip->set_number('5008478')->is_valid_number, '岐阜県岐阜市加納伏見町');
ok($zip->set_number('5008479')->is_valid_number, '岐阜県岐阜市加納菱野町');
ok($zip->set_number('5008481')->is_valid_number, '岐阜県岐阜市加納沓井町');
ok($zip->set_number('5008482')->is_valid_number, '岐阜県岐阜市加納大手町');
ok($zip->set_number('5008483')->is_valid_number, '岐阜県岐阜市加納東丸町');
ok($zip->set_number('5008484')->is_valid_number, '岐阜県岐阜市加納二之丸');
ok($zip->set_number('5008485')->is_valid_number, '岐阜県岐阜市加納丸之内');
ok($zip->set_number('5008486')->is_valid_number, '岐阜県岐阜市加納城南通');
ok($zip->set_number('5008487')->is_valid_number, '岐阜県岐阜市加納長刀堀');
ok($zip->set_number('5008488')->is_valid_number, '岐阜県岐阜市加納西丸町');
ok($zip->set_number('5008489')->is_valid_number, '岐阜県岐阜市稲荷山');
ok($zip->set_number('5008801')->is_valid_number, '岐阜県岐阜市忠節町');
ok($zip->set_number('5008802')->is_valid_number, '岐阜県岐阜市不動町');
ok($zip->set_number('5008803')->is_valid_number, '岐阜県岐阜市佐久間町');
ok($zip->set_number('5008804')->is_valid_number, '岐阜県岐阜市京町');
ok($zip->set_number('5008805')->is_valid_number, '岐阜県岐阜市忠節三丁目南町');
ok($zip->set_number('5008806')->is_valid_number, '岐阜県岐阜市天神町');
ok($zip->set_number('5008807')->is_valid_number, '岐阜県岐阜市北野町');
ok($zip->set_number('5008808')->is_valid_number, '岐阜県岐阜市永田町');
ok($zip->set_number('5008809')->is_valid_number, '岐阜県岐阜市平河町');
ok($zip->set_number('5008811')->is_valid_number, '岐阜県岐阜市端詰町');
ok($zip->set_number('5008812')->is_valid_number, '岐阜県岐阜市美江寺町');
ok($zip->set_number('5008813')->is_valid_number, '岐阜県岐阜市明徳町');
ok($zip->set_number('5008814')->is_valid_number, '岐阜県岐阜市今川町');
ok($zip->set_number('5008815')->is_valid_number, '岐阜県岐阜市梅河町');
ok($zip->set_number('5008816')->is_valid_number, '岐阜県岐阜市菅原町');
ok($zip->set_number('5008817')->is_valid_number, '岐阜県岐阜市八ツ梅町');
ok($zip->set_number('5008818')->is_valid_number, '岐阜県岐阜市梅ケ枝町');
ok($zip->set_number('5008819')->is_valid_number, '岐阜県岐阜市千石町');
ok($zip->set_number('5008821')->is_valid_number, '岐阜県岐阜市鷹見町');
ok($zip->set_number('5008822')->is_valid_number, '岐阜県岐阜市今沢町');
ok($zip->set_number('5008823')->is_valid_number, '岐阜県岐阜市江川町');
ok($zip->set_number('5008824')->is_valid_number, '岐阜県岐阜市北八ツ寺町');
ok($zip->set_number('5008825')->is_valid_number, '岐阜県岐阜市八ツ寺町');
ok($zip->set_number('5008826')->is_valid_number, '岐阜県岐阜市住吉町');
ok($zip->set_number('5008827')->is_valid_number, '岐阜県岐阜市弥八町');
ok($zip->set_number('5008828')->is_valid_number, '岐阜県岐阜市若宮町');
ok($zip->set_number('5008829')->is_valid_number, '岐阜県岐阜市杉山町');
ok($zip->set_number('5008831')->is_valid_number, '岐阜県岐阜市弥生町');
ok($zip->set_number('5008832')->is_valid_number, '岐阜県岐阜市小柳町');
ok($zip->set_number('5008833')->is_valid_number, '岐阜県岐阜市神田町');
ok($zip->set_number('5008834')->is_valid_number, '岐阜県岐阜市羽根町');
ok($zip->set_number('5008835')->is_valid_number, '岐阜県岐阜市玉宮町');
ok($zip->set_number('5008836')->is_valid_number, '岐阜県岐阜市西玉宮町');
ok($zip->set_number('5008837')->is_valid_number, '岐阜県岐阜市玉森町');
ok($zip->set_number('5008838')->is_valid_number, '岐阜県岐阜市八幡町');
ok($zip->set_number('5008839')->is_valid_number, '岐阜県岐阜市蕪城町');
ok($zip->set_number('5008841')->is_valid_number, '岐阜県岐阜市高野町');
ok($zip->set_number('5008842')->is_valid_number, '岐阜県岐阜市金町');
ok($zip->set_number('5008843')->is_valid_number, '岐阜県岐阜市住田町');
ok($zip->set_number('5008844')->is_valid_number, '岐阜県岐阜市吉野町');
ok($zip->set_number('5008845')->is_valid_number, '岐阜県岐阜市問屋町');
ok($zip->set_number('5008846')->is_valid_number, '岐阜県岐阜市玉姓町');
ok($zip->set_number('5008847')->is_valid_number, '岐阜県岐阜市金宝町');
ok($zip->set_number('5008848')->is_valid_number, '岐阜県岐阜市神明町');
ok($zip->set_number('5008849')->is_valid_number, '岐阜県岐阜市金岡町');
ok($zip->set_number('5008851')->is_valid_number, '岐阜県岐阜市大宝町');
ok($zip->set_number('5008852')->is_valid_number, '岐阜県岐阜市日ノ本町');
ok($zip->set_number('5008853')->is_valid_number, '岐阜県岐阜市西問屋町');
ok($zip->set_number('5008854')->is_valid_number, '岐阜県岐阜市花園町');
ok($zip->set_number('5008855')->is_valid_number, '岐阜県岐阜市新栄町');
ok($zip->set_number('5008856')->is_valid_number, '岐阜県岐阜市橋本町');
ok($zip->set_number('5008857')->is_valid_number, '岐阜県岐阜市坂井町');
ok($zip->set_number('5008858')->is_valid_number, '岐阜県岐阜市福住町');
ok($zip->set_number('5008859')->is_valid_number, '岐阜県岐阜市室津町');
ok($zip->set_number('5008861')->is_valid_number, '岐阜県岐阜市千手堂北町');
ok($zip->set_number('5008862')->is_valid_number, '岐阜県岐阜市千手堂中町');
ok($zip->set_number('5008863')->is_valid_number, '岐阜県岐阜市千手堂南町');
ok($zip->set_number('5008864')->is_valid_number, '岐阜県岐阜市真砂町');
ok($zip->set_number('5008865')->is_valid_number, '岐阜県岐阜市昭和町');
ok($zip->set_number('5008866')->is_valid_number, '岐阜県岐阜市寺島町');
ok($zip->set_number('5008867')->is_valid_number, '岐阜県岐阜市木ノ本町');
ok($zip->set_number('5008868')->is_valid_number, '岐阜県岐阜市光明町');
ok($zip->set_number('5008869')->is_valid_number, '岐阜県岐阜市元宮町');
ok($zip->set_number('5008871')->is_valid_number, '岐阜県岐阜市大正町');
ok($zip->set_number('5008872')->is_valid_number, '岐阜県岐阜市栄枝町');
ok($zip->set_number('5008873')->is_valid_number, '岐阜県岐阜市大富町');
ok($zip->set_number('5008874')->is_valid_number, '岐阜県岐阜市銀町');
ok($zip->set_number('5008875')->is_valid_number, '岐阜県岐阜市柳ケ瀬通');
ok($zip->set_number('5008876')->is_valid_number, '岐阜県岐阜市日ノ出町');
ok($zip->set_number('5008877')->is_valid_number, '岐阜県岐阜市雲雀町');
ok($zip->set_number('5008878')->is_valid_number, '岐阜県岐阜市神室町');
ok($zip->set_number('5008879')->is_valid_number, '岐阜県岐阜市徹明通');
ok($zip->set_number('5008881')->is_valid_number, '岐阜県岐阜市青柳町');
ok($zip->set_number('5008882')->is_valid_number, '岐阜県岐阜市西野町');
ok($zip->set_number('5008883')->is_valid_number, '岐阜県岐阜市吾妻町');
ok($zip->set_number('5008884')->is_valid_number, '岐阜県岐阜市池田町');
ok($zip->set_number('5008885')->is_valid_number, '岐阜県岐阜市大柳町');
ok($zip->set_number('5008886')->is_valid_number, '岐阜県岐阜市西野町七丁目北町');
ok($zip->set_number('5008887')->is_valid_number, '岐阜県岐阜市西野町六丁目北町');
ok($zip->set_number('5008888')->is_valid_number, '岐阜県岐阜市万年町');
ok($zip->set_number('5008889')->is_valid_number, '岐阜県岐阜市大縄場');
ok($zip->set_number('5008891')->is_valid_number, '岐阜県岐阜市香蘭');
ok($zip->set_number('5010101')->is_valid_number, '岐阜県岐阜市曽我屋');
ok($zip->set_number('5010102')->is_valid_number, '岐阜県岐阜市一日市場北町');
ok($zip->set_number('5010103')->is_valid_number, '岐阜県岐阜市一日市場');
ok($zip->set_number('5010104')->is_valid_number, '岐阜県岐阜市寺田');
ok($zip->set_number('5010105')->is_valid_number, '岐阜県岐阜市河渡');
ok($zip->set_number('5010106')->is_valid_number, '岐阜県岐阜市西河渡');
ok($zip->set_number('5010111')->is_valid_number, '岐阜県岐阜市鏡島');
ok($zip->set_number('5010111')->is_valid_number, '岐阜県岐阜市鏡島町');
ok($zip->set_number('5010111')->is_valid_number, '岐阜県岐阜市川原畑');
ok($zip->set_number('5010112')->is_valid_number, '岐阜県岐阜市鏡島精華');
ok($zip->set_number('5010113')->is_valid_number, '岐阜県岐阜市鏡島市場');
ok($zip->set_number('5010115')->is_valid_number, '岐阜県岐阜市鏡島南');
ok($zip->set_number('5010117')->is_valid_number, '岐阜県岐阜市江崎');
ok($zip->set_number('5010118')->is_valid_number, '岐阜県岐阜市大菅北');
ok($zip->set_number('5010119')->is_valid_number, '岐阜県岐阜市大菅南');
ok($zip->set_number('5010121')->is_valid_number, '岐阜県岐阜市江崎北');
ok($zip->set_number('5010122')->is_valid_number, '岐阜県岐阜市江崎南');
ok($zip->set_number('5010123')->is_valid_number, '岐阜県岐阜市鏡島西');
ok($zip->set_number('5010124')->is_valid_number, '岐阜県岐阜市鏡島中');
ok($zip->set_number('5010200')->is_valid_number, '岐阜県瑞穂市以下に掲載がない場合');
ok($zip->set_number('5010201')->is_valid_number, '岐阜県瑞穂市馬場');
ok($zip->set_number('5010202')->is_valid_number, '岐阜県瑞穂市馬場前畑町');
ok($zip->set_number('5010203')->is_valid_number, '岐阜県瑞穂市馬場上光町');
ok($zip->set_number('5010204')->is_valid_number, '岐阜県瑞穂市馬場春雨町');
ok($zip->set_number('5010205')->is_valid_number, '岐阜県瑞穂市馬場小城町');
ok($zip->set_number('5010206')->is_valid_number, '岐阜県瑞穂市馬場北町');
ok($zip->set_number('5010211')->is_valid_number, '岐阜県瑞穂市生津');
ok($zip->set_number('5010212')->is_valid_number, '岐阜県瑞穂市生津滝坪町');
ok($zip->set_number('5010213')->is_valid_number, '岐阜県瑞穂市生津内宮町');
ok($zip->set_number('5010214')->is_valid_number, '岐阜県瑞穂市生津外宮東町');
ok($zip->set_number('5010215')->is_valid_number, '岐阜県瑞穂市生津天王東町');
ok($zip->set_number('5010216')->is_valid_number, '岐阜県瑞穂市生津天王町');
ok($zip->set_number('5010217')->is_valid_number, '岐阜県瑞穂市生津外宮前町');
ok($zip->set_number('5010221')->is_valid_number, '岐阜県瑞穂市只越');
ok($zip->set_number('5010222')->is_valid_number, '岐阜県瑞穂市別府');
ok($zip->set_number('5010223')->is_valid_number, '岐阜県瑞穂市穂積');
ok($zip->set_number('5010224')->is_valid_number, '岐阜県瑞穂市稲里');
ok($zip->set_number('5010225')->is_valid_number, '岐阜県瑞穂市祖父江');
ok($zip->set_number('5010231')->is_valid_number, '岐阜県瑞穂市野白新田');
ok($zip->set_number('5010232')->is_valid_number, '岐阜県瑞穂市野田新田');
ok($zip->set_number('5010233')->is_valid_number, '岐阜県瑞穂市宝江');
ok($zip->set_number('5010234')->is_valid_number, '岐阜県瑞穂市牛牧');
ok($zip->set_number('5010235')->is_valid_number, '岐阜県瑞穂市十九条');
ok($zip->set_number('5010236')->is_valid_number, '岐阜県瑞穂市本田');
ok($zip->set_number('5010237')->is_valid_number, '岐阜県瑞穂市犀川');
ok($zip->set_number('5010301')->is_valid_number, '岐阜県瑞穂市七崎');
ok($zip->set_number('5010302')->is_valid_number, '岐阜県瑞穂市居倉');
ok($zip->set_number('5010303')->is_valid_number, '岐阜県瑞穂市森');
ok($zip->set_number('5010304')->is_valid_number, '岐阜県瑞穂市田之上');
ok($zip->set_number('5010305')->is_valid_number, '岐阜県瑞穂市宮田');
ok($zip->set_number('5010306')->is_valid_number, '岐阜県瑞穂市大月');
ok($zip->set_number('5010307')->is_valid_number, '岐阜県瑞穂市唐栗');
ok($zip->set_number('5010311')->is_valid_number, '岐阜県瑞穂市重里');
ok($zip->set_number('5010312')->is_valid_number, '岐阜県瑞穂市美江寺');
ok($zip->set_number('5010313')->is_valid_number, '岐阜県瑞穂市十七条');
ok($zip->set_number('5010314')->is_valid_number, '岐阜県瑞穂市十八条');
ok($zip->set_number('5010321')->is_valid_number, '岐阜県瑞穂市横屋');
ok($zip->set_number('5010322')->is_valid_number, '岐阜県瑞穂市古橋');
ok($zip->set_number('5010323')->is_valid_number, '岐阜県瑞穂市中宮');
ok($zip->set_number('5010324')->is_valid_number, '岐阜県瑞穂市呂久');
ok($zip->set_number('5010400')->is_valid_number, '岐阜県本巣市以下に掲載がない場合');
ok($zip->set_number('5010400')->is_valid_number, '岐阜県本巣郡北方町以下に掲載がない場合');
ok($zip->set_number('5010401')->is_valid_number, '岐阜県本巣市上保');
ok($zip->set_number('5010402')->is_valid_number, '岐阜県本巣市郡府');
ok($zip->set_number('5010403')->is_valid_number, '岐阜県本巣市北野');
ok($zip->set_number('5010404')->is_valid_number, '岐阜県本巣市春近');
ok($zip->set_number('5010405')->is_valid_number, '岐阜県本巣市石原');
ok($zip->set_number('5010406')->is_valid_number, '岐阜県本巣市三橋');
ok($zip->set_number('5010407')->is_valid_number, '岐阜県本巣市仏生寺');
ok($zip->set_number('5010410')->is_valid_number, '岐阜県本巣市石神');
ok($zip->set_number('5010411')->is_valid_number, '岐阜県本巣市上高屋');
ok($zip->set_number('5010412')->is_valid_number, '岐阜県本巣市長屋');
ok($zip->set_number('5010413')->is_valid_number, '岐阜県本巣市見延');
ok($zip->set_number('5010414')->is_valid_number, '岐阜県本巣市数屋');
ok($zip->set_number('5010415')->is_valid_number, '岐阜県本巣市有里');
ok($zip->set_number('5010416')->is_valid_number, '岐阜県本巣市随原');
ok($zip->set_number('5010417')->is_valid_number, '岐阜県本巣市屋井');
ok($zip->set_number('5010418')->is_valid_number, '岐阜県本巣市七五三');
ok($zip->set_number('5010419')->is_valid_number, '岐阜県本巣市早野');
ok($zip->set_number('5010421')->is_valid_number, '岐阜県本巣郡北方町芝原西町');
ok($zip->set_number('5010422')->is_valid_number, '岐阜県本巣郡北方町芝原中町');
ok($zip->set_number('5010423')->is_valid_number, '岐阜県本巣郡北方町芝原東町');
ok($zip->set_number('5010424')->is_valid_number, '岐阜県本巣郡北方町朝日町');
ok($zip->set_number('5010425')->is_valid_number, '岐阜県本巣郡北方町加茂');
ok($zip->set_number('5010426')->is_valid_number, '岐阜県本巣郡北方町東加茂');
ok($zip->set_number('5010427')->is_valid_number, '岐阜県本巣郡北方町栄町');
ok($zip->set_number('5010428')->is_valid_number, '岐阜県本巣郡北方町若宮');
ok($zip->set_number('5010431')->is_valid_number, '岐阜県本巣郡北方町北方');
ok($zip->set_number('5010432')->is_valid_number, '岐阜県本巣郡北方町一本松');
ok($zip->set_number('5010433')->is_valid_number, '岐阜県本巣郡北方町天狗堂');
ok($zip->set_number('5010434')->is_valid_number, '岐阜県本巣郡北方町小柳');
ok($zip->set_number('5010435')->is_valid_number, '岐阜県本巣郡北方町春来町');
ok($zip->set_number('5010436')->is_valid_number, '岐阜県本巣郡北方町長谷川西');
ok($zip->set_number('5010437')->is_valid_number, '岐阜県本巣郡北方町清水');
ok($zip->set_number('5010438')->is_valid_number, '岐阜県本巣郡北方町平成');
ok($zip->set_number('5010439')->is_valid_number, '岐阜県本巣郡北方町長谷川');
ok($zip->set_number('5010441')->is_valid_number, '岐阜県本巣郡北方町曲路');
ok($zip->set_number('5010442')->is_valid_number, '岐阜県本巣郡北方町曲路東');
ok($zip->set_number('5010443')->is_valid_number, '岐阜県本巣郡北方町柱本池之頭');
ok($zip->set_number('5010444')->is_valid_number, '岐阜県本巣郡北方町柱本白坪');
ok($zip->set_number('5010445')->is_valid_number, '岐阜県本巣郡北方町柱本南');
ok($zip->set_number('5010446')->is_valid_number, '岐阜県本巣郡北方町柱本');
ok($zip->set_number('5010451')->is_valid_number, '岐阜県本巣郡北方町高屋勅使');
ok($zip->set_number('5010452')->is_valid_number, '岐阜県本巣郡北方町高屋石末');
ok($zip->set_number('5010453')->is_valid_number, '岐阜県本巣郡北方町高屋分木');
ok($zip->set_number('5010454')->is_valid_number, '岐阜県本巣郡北方町高屋白木');
ok($zip->set_number('5010455')->is_valid_number, '岐阜県本巣郡北方町高屋伊勢田');
ok($zip->set_number('5010456')->is_valid_number, '岐阜県本巣郡北方町高屋条里');
ok($zip->set_number('5010457')->is_valid_number, '岐阜県本巣郡北方町高屋太子');
ok($zip->set_number('5010458')->is_valid_number, '岐阜県本巣郡北方町高屋');
ok($zip->set_number('5010461')->is_valid_number, '岐阜県本巣市上真桑');
ok($zip->set_number('5010462')->is_valid_number, '岐阜県本巣市宗慶');
ok($zip->set_number('5010463')->is_valid_number, '岐阜県本巣市小柿');
ok($zip->set_number('5010464')->is_valid_number, '岐阜県本巣市十四条');
ok($zip->set_number('5010465')->is_valid_number, '岐阜県本巣市軽海');
ok($zip->set_number('5010466')->is_valid_number, '岐阜県本巣市下真桑');
ok($zip->set_number('5010471')->is_valid_number, '岐阜県本巣市政田');
ok($zip->set_number('5010472')->is_valid_number, '岐阜県本巣市下福島');
ok($zip->set_number('5010473')->is_valid_number, '岐阜県本巣市温井');
ok($zip->set_number('5010474')->is_valid_number, '岐阜県本巣市国領');
ok($zip->set_number('5010475')->is_valid_number, '岐阜県本巣市浅木');
ok($zip->set_number('5010476')->is_valid_number, '岐阜県本巣市海老');
ok($zip->set_number('5010500')->is_valid_number, '岐阜県揖斐郡大野町以下に掲載がない場合');
ok($zip->set_number('5010501')->is_valid_number, '岐阜県揖斐郡大野町稲富');
ok($zip->set_number('5010502')->is_valid_number, '岐阜県揖斐郡大野町古川');
ok($zip->set_number('5010503')->is_valid_number, '岐阜県揖斐郡大野町寺内');
ok($zip->set_number('5010504')->is_valid_number, '岐阜県揖斐郡大野町野');
ok($zip->set_number('5010511')->is_valid_number, '岐阜県揖斐郡大野町稲畑');
ok($zip->set_number('5010512')->is_valid_number, '岐阜県揖斐郡大野町上秋');
ok($zip->set_number('5010513')->is_valid_number, '岐阜県揖斐郡大野町大野');
ok($zip->set_number('5010514')->is_valid_number, '岐阜県揖斐郡大野町西方');
ok($zip->set_number('5010515')->is_valid_number, '岐阜県揖斐郡大野町桜大門');
ok($zip->set_number('5010521')->is_valid_number, '岐阜県揖斐郡大野町黒野');
ok($zip->set_number('5010522')->is_valid_number, '岐阜県揖斐郡大野町相羽');
ok($zip->set_number('5010523')->is_valid_number, '岐阜県揖斐郡大野町下方');
ok($zip->set_number('5010524')->is_valid_number, '岐阜県揖斐郡大野町郡家');
ok($zip->set_number('5010525')->is_valid_number, '岐阜県揖斐郡大野町六里');
ok($zip->set_number('5010531')->is_valid_number, '岐阜県揖斐郡大野町上磯');
ok($zip->set_number('5010532')->is_valid_number, '岐阜県揖斐郡大野町下磯');
ok($zip->set_number('5010533')->is_valid_number, '岐阜県揖斐郡大野町本庄');
ok($zip->set_number('5010534')->is_valid_number, '岐阜県揖斐郡大野町下座倉');
ok($zip->set_number('5010535')->is_valid_number, '岐阜県揖斐郡大野町加納');
ok($zip->set_number('5010551')->is_valid_number, '岐阜県揖斐郡大野町小衣斐');
ok($zip->set_number('5010552')->is_valid_number, '岐阜県揖斐郡大野町大衣斐');
ok($zip->set_number('5010553')->is_valid_number, '岐阜県揖斐郡大野町南方');
ok($zip->set_number('5010554')->is_valid_number, '岐阜県揖斐郡大野町五之里');
ok($zip->set_number('5010555')->is_valid_number, '岐阜県揖斐郡大野町公郷');
ok($zip->set_number('5010556')->is_valid_number, '岐阜県揖斐郡大野町領家');
ok($zip->set_number('5010561')->is_valid_number, '岐阜県揖斐郡大野町牛洞');
ok($zip->set_number('5010562')->is_valid_number, '岐阜県揖斐郡大野町松山');
ok($zip->set_number('5010563')->is_valid_number, '岐阜県揖斐郡大野町瀬古');
ok($zip->set_number('5010564')->is_valid_number, '岐阜県揖斐郡大野町麻生');
ok($zip->set_number('5010565')->is_valid_number, '岐阜県揖斐郡大野町中之元');
ok($zip->set_number('5010600')->is_valid_number, '岐阜県揖斐郡揖斐川町以下に掲載がない場合');
ok($zip->set_number('5010601')->is_valid_number, '岐阜県揖斐郡揖斐川町北方');
ok($zip->set_number('5010602')->is_valid_number, '岐阜県揖斐郡揖斐川町若松');
ok($zip->set_number('5010603')->is_valid_number, '岐阜県揖斐郡揖斐川町上南方');
ok($zip->set_number('5010604')->is_valid_number, '岐阜県揖斐郡揖斐川町大光寺');
ok($zip->set_number('5010605')->is_valid_number, '岐阜県揖斐郡揖斐川町極楽寺');
ok($zip->set_number('5010606')->is_valid_number, '岐阜県揖斐郡揖斐川町房島');
ok($zip->set_number('5010607')->is_valid_number, '岐阜県揖斐郡揖斐川町桂');
ok($zip->set_number('5010611')->is_valid_number, '岐阜県揖斐郡揖斐川町小谷');
ok($zip->set_number('5010612')->is_valid_number, '岐阜県揖斐郡揖斐川町小野');
ok($zip->set_number('5010613')->is_valid_number, '岐阜県揖斐郡揖斐川町志津山');
ok($zip->set_number('5010614')->is_valid_number, '岐阜県揖斐郡揖斐川町長良');
ok($zip->set_number('5010615')->is_valid_number, '岐阜県揖斐郡揖斐川町清水');
ok($zip->set_number('5010616')->is_valid_number, '岐阜県揖斐郡揖斐川町福島');
ok($zip->set_number('5010617')->is_valid_number, '岐阜県揖斐郡揖斐川町島');
ok($zip->set_number('5010618')->is_valid_number, '岐阜県揖斐郡揖斐川町上ミ野');
ok($zip->set_number('5010619')->is_valid_number, '岐阜県揖斐郡揖斐川町三輪');
ok($zip->set_number('5010621')->is_valid_number, '岐阜県揖斐郡揖斐川町下岡島');
ok($zip->set_number('5010622')->is_valid_number, '岐阜県揖斐郡揖斐川町脛永');
ok($zip->set_number('5010623')->is_valid_number, '岐阜県揖斐郡揖斐川町和田');
ok($zip->set_number('5010624')->is_valid_number, '岐阜県揖斐郡揖斐川町岡');
ok($zip->set_number('5010625')->is_valid_number, '岐阜県揖斐郡揖斐川町黒田');
ok($zip->set_number('5010626')->is_valid_number, '岐阜県揖斐郡揖斐川町瑞岩寺');
ok($zip->set_number('5010627')->is_valid_number, '岐阜県揖斐郡揖斐川町市場');
ok($zip->set_number('5010628')->is_valid_number, '岐阜県揖斐郡揖斐川町新宮');
ok($zip->set_number('5010631')->is_valid_number, '岐阜県揖斐郡揖斐川町上岡島');
ok($zip->set_number('5010632')->is_valid_number, '岐阜県揖斐郡揖斐川町上東野');
ok($zip->set_number('5010633')->is_valid_number, '岐阜県揖斐郡揖斐川町小島');
ok($zip->set_number('5010634')->is_valid_number, '岐阜県揖斐郡揖斐川町上野');
ok($zip->set_number('5010635')->is_valid_number, '岐阜県揖斐郡揖斐川町白樫');
ok($zip->set_number('5010701')->is_valid_number, '岐阜県揖斐郡揖斐川町小津');
ok($zip->set_number('5010702')->is_valid_number, '岐阜県揖斐郡揖斐川町東津汲');
ok($zip->set_number('5010703')->is_valid_number, '岐阜県揖斐郡揖斐川町乙原');
ok($zip->set_number('5010704')->is_valid_number, '岐阜県揖斐郡揖斐川町三倉');
ok($zip->set_number('5010705')->is_valid_number, '岐阜県揖斐郡揖斐川町外津汲');
ok($zip->set_number('5010706')->is_valid_number, '岐阜県揖斐郡揖斐川町西津汲');
ok($zip->set_number('5010707')->is_valid_number, '岐阜県揖斐郡揖斐川町日坂');
ok($zip->set_number('5010708')->is_valid_number, '岐阜県揖斐郡揖斐川町樫原');
ok($zip->set_number('5010802')->is_valid_number, '岐阜県揖斐郡揖斐川町鶴見');
ok($zip->set_number('5010803')->is_valid_number, '岐阜県揖斐郡揖斐川町東杉原');
ok($zip->set_number('5010804')->is_valid_number, '岐阜県揖斐郡揖斐川町東横山');
ok($zip->set_number('5010805')->is_valid_number, '岐阜県揖斐郡揖斐川町西横山');
ok($zip->set_number('5010811')->is_valid_number, '岐阜県揖斐郡揖斐川町塚');
ok($zip->set_number('5010812')->is_valid_number, '岐阜県揖斐郡揖斐川町櫨原');
ok($zip->set_number('5010813')->is_valid_number, '岐阜県揖斐郡揖斐川町山手');
ok($zip->set_number('5010814')->is_valid_number, '岐阜県揖斐郡揖斐川町徳山');
ok($zip->set_number('5010815')->is_valid_number, '岐阜県揖斐郡揖斐川町開田');
ok($zip->set_number('5010816')->is_valid_number, '岐阜県揖斐郡揖斐川町戸入');
ok($zip->set_number('5010817')->is_valid_number, '岐阜県揖斐郡揖斐川町門入');
ok($zip->set_number('5010901')->is_valid_number, '岐阜県揖斐郡揖斐川町坂内川上');
ok($zip->set_number('5010902')->is_valid_number, '岐阜県揖斐郡揖斐川町坂内広瀬');
ok($zip->set_number('5010903')->is_valid_number, '岐阜県揖斐郡揖斐川町坂内坂本');
ok($zip->set_number('5011101')->is_valid_number, '岐阜県岐阜市佐野');
ok($zip->set_number('5011102')->is_valid_number, '岐阜県岐阜市岩利');
ok($zip->set_number('5011103')->is_valid_number, '岐阜県岐阜市彦坂川北');
ok($zip->set_number('5011104')->is_valid_number, '岐阜県岐阜市彦坂川上');
ok($zip->set_number('5011105')->is_valid_number, '岐阜県岐阜市彦坂');
ok($zip->set_number('5011106')->is_valid_number, '岐阜県岐阜市石谷');
ok($zip->set_number('5011107')->is_valid_number, '岐阜県岐阜市村山');
ok($zip->set_number('5011108')->is_valid_number, '岐阜県岐阜市安食志良古');
ok($zip->set_number('5011109')->is_valid_number, '岐阜県岐阜市安食');
ok($zip->set_number('5011111')->is_valid_number, '岐阜県岐阜市大学北');
ok($zip->set_number('5011112')->is_valid_number, '岐阜県岐阜市柳戸');
ok($zip->set_number('5011113')->is_valid_number, '岐阜県岐阜市大学西');
ok($zip->set_number('5011114')->is_valid_number, '岐阜県岐阜市今川');
ok($zip->set_number('5011115')->is_valid_number, '岐阜県岐阜市交人');
ok($zip->set_number('5011116')->is_valid_number, '岐阜県岐阜市深坂');
ok($zip->set_number('5011121')->is_valid_number, '岐阜県岐阜市古市場');
ok($zip->set_number('5011122')->is_valid_number, '岐阜県岐阜市古市場老ノ上');
ok($zip->set_number('5011123')->is_valid_number, '岐阜県岐阜市古市場高田');
ok($zip->set_number('5011124')->is_valid_number, '岐阜県岐阜市古市場中原');
ok($zip->set_number('5011125')->is_valid_number, '岐阜県岐阜市古市場東町田');
ok($zip->set_number('5011126')->is_valid_number, '岐阜県岐阜市古市場高宮');
ok($zip->set_number('5011127')->is_valid_number, '岐阜県岐阜市古市場神田');
ok($zip->set_number('5011128')->is_valid_number, '岐阜県岐阜市洞');
ok($zip->set_number('5011131')->is_valid_number, '岐阜県岐阜市黒野');
ok($zip->set_number('5011132')->is_valid_number, '岐阜県岐阜市折立');
ok($zip->set_number('5011133')->is_valid_number, '岐阜県岐阜市北柿ケ瀬');
ok($zip->set_number('5011134')->is_valid_number, '岐阜県岐阜市南柿ケ瀬');
ok($zip->set_number('5011135')->is_valid_number, '岐阜県岐阜市木田');
ok($zip->set_number('5011136')->is_valid_number, '岐阜県岐阜市黒野南');
ok($zip->set_number('5011141')->is_valid_number, '岐阜県岐阜市東板谷');
ok($zip->set_number('5011142')->is_valid_number, '岐阜県岐阜市東改田');
ok($zip->set_number('5011143')->is_valid_number, '岐阜県岐阜市東改田鶴田');
ok($zip->set_number('5011144')->is_valid_number, '岐阜県岐阜市東改田再勝');
ok($zip->set_number('5011145')->is_valid_number, '岐阜県岐阜市東改田腰前田');
ok($zip->set_number('5011146')->is_valid_number, '岐阜県岐阜市下尻毛');
ok($zip->set_number('5011147')->is_valid_number, '岐阜県岐阜市尻毛');
ok($zip->set_number('5011148')->is_valid_number, '岐阜県岐阜市上尻毛日吉');
ok($zip->set_number('5011149')->is_valid_number, '岐阜県岐阜市上尻毛八幡');
ok($zip->set_number('5011150')->is_valid_number, '岐阜県岐阜市上尻毛');
ok($zip->set_number('5011151')->is_valid_number, '岐阜県岐阜市川部');
ok($zip->set_number('5011152')->is_valid_number, '岐阜県岐阜市又丸');
ok($zip->set_number('5011153')->is_valid_number, '岐阜県岐阜市又丸町畑');
ok($zip->set_number('5011154')->is_valid_number, '岐阜県岐阜市又丸柳町');
ok($zip->set_number('5011155')->is_valid_number, '岐阜県岐阜市又丸宮東');
ok($zip->set_number('5011156')->is_valid_number, '岐阜県岐阜市又丸津島');
ok($zip->set_number('5011157')->is_valid_number, '岐阜県岐阜市又丸村中');
ok($zip->set_number('5011158')->is_valid_number, '岐阜県岐阜市西改田先道');
ok($zip->set_number('5011159')->is_valid_number, '岐阜県岐阜市西改田');
ok($zip->set_number('5011159')->is_valid_number, '岐阜県岐阜市西改田松の木');
ok($zip->set_number('5011161')->is_valid_number, '岐阜県岐阜市西改田川向');
ok($zip->set_number('5011162')->is_valid_number, '岐阜県岐阜市西改田若宮');
ok($zip->set_number('5011163')->is_valid_number, '岐阜県岐阜市西改田米野');
ok($zip->set_number('5011164')->is_valid_number, '岐阜県岐阜市西改田東改田入会地');
ok($zip->set_number('5011165')->is_valid_number, '岐阜県岐阜市西改田宮西');
ok($zip->set_number('5011166')->is_valid_number, '岐阜県岐阜市西改田村前');
ok($zip->set_number('5011167')->is_valid_number, '岐阜県岐阜市西改田夏梅');
ok($zip->set_number('5011168')->is_valid_number, '岐阜県岐阜市西改田上の町');
ok($zip->set_number('5011169')->is_valid_number, '岐阜県岐阜市西改田七石');
ok($zip->set_number('5011171')->is_valid_number, '岐阜県岐阜市御望');
ok($zip->set_number('5011172')->is_valid_number, '岐阜県岐阜市下鵜飼');
ok($zip->set_number('5011173')->is_valid_number, '岐阜県岐阜市中');
ok($zip->set_number('5011174')->is_valid_number, '岐阜県岐阜市小野');
ok($zip->set_number('5011175')->is_valid_number, '岐阜県岐阜市下西郷');
ok($zip->set_number('5011176')->is_valid_number, '岐阜県岐阜市小西郷');
ok($zip->set_number('5011177')->is_valid_number, '岐阜県岐阜市中西郷');
ok($zip->set_number('5011178')->is_valid_number, '岐阜県岐阜市上西郷');
ok($zip->set_number('5011181')->is_valid_number, '岐阜県岐阜市雛倉');
ok($zip->set_number('5011182')->is_valid_number, '岐阜県岐阜市秋沢');
ok($zip->set_number('5011183')->is_valid_number, '岐阜県岐阜市則松');
ok($zip->set_number('5011184')->is_valid_number, '岐阜県岐阜市西秋沢');
ok($zip->set_number('5011185')->is_valid_number, '岐阜県岐阜市奥');
ok($zip->set_number('5011186')->is_valid_number, '岐阜県岐阜市外山');
ok($zip->set_number('5011201')->is_valid_number, '岐阜県本巣市山口');
ok($zip->set_number('5011202')->is_valid_number, '岐阜県本巣市法林寺');
ok($zip->set_number('5011203')->is_valid_number, '岐阜県本巣市宝珠ハイツ');
ok($zip->set_number('5011203')->is_valid_number, '岐阜県本巣市文殊');
ok($zip->set_number('5011205')->is_valid_number, '岐阜県本巣市曽井中島');
ok($zip->set_number('5011231')->is_valid_number, '岐阜県本巣市日当');
ok($zip->set_number('5011232')->is_valid_number, '岐阜県本巣市金原');
ok($zip->set_number('5011233')->is_valid_number, '岐阜県本巣市外山');
ok($zip->set_number('5011234')->is_valid_number, '岐阜県本巣市木知原');
ok($zip->set_number('5011235')->is_valid_number, '岐阜県本巣市神海');
ok($zip->set_number('5011236')->is_valid_number, '岐阜県本巣市佐原');
ok($zip->set_number('5011236')->is_valid_number, '岐阜県本巣市鍋原');
ok($zip->set_number('5011301')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲高科');
ok($zip->set_number('5011302')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲岐礼');
ok($zip->set_number('5011303')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲長瀬');
ok($zip->set_number('5011311')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲徳積');
ok($zip->set_number('5011312')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲大洞');
ok($zip->set_number('5011313')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲深坂');
ok($zip->set_number('5011314')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲名礼');
ok($zip->set_number('5011315')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲有鳥');
ok($zip->set_number('5011316')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲木曽屋');
ok($zip->set_number('5011317')->is_valid_number, '岐阜県揖斐郡揖斐川町谷汲神原');
ok($zip->set_number('5011501')->is_valid_number, '岐阜県本巣市根尾越波');
ok($zip->set_number('5011502')->is_valid_number, '岐阜県本巣市根尾黒津');
ok($zip->set_number('5011503')->is_valid_number, '岐阜県本巣市根尾長嶺');
ok($zip->set_number('5011504')->is_valid_number, '岐阜県本巣市根尾天神堂');
ok($zip->set_number('5011505')->is_valid_number, '岐阜県本巣市根尾長島');
ok($zip->set_number('5011506')->is_valid_number, '岐阜県本巣市根尾能郷');
ok($zip->set_number('5011507')->is_valid_number, '岐阜県本巣市根尾大河原');
ok($zip->set_number('5011511')->is_valid_number, '岐阜県本巣市根尾上大須');
ok($zip->set_number('5011512')->is_valid_number, '岐阜県本巣市根尾下大須');
ok($zip->set_number('5011513')->is_valid_number, '岐阜県本巣市根尾松田');
ok($zip->set_number('5011514')->is_valid_number, '岐阜県本巣市根尾奥谷');
ok($zip->set_number('5011515')->is_valid_number, '岐阜県本巣市根尾口谷');
ok($zip->set_number('5011516')->is_valid_number, '岐阜県本巣市根尾東板屋');
ok($zip->set_number('5011517')->is_valid_number, '岐阜県本巣市根尾西板屋');
ok($zip->set_number('5011518')->is_valid_number, '岐阜県本巣市根尾小鹿');
ok($zip->set_number('5011521')->is_valid_number, '岐阜県本巣市根尾市場');
ok($zip->set_number('5011522')->is_valid_number, '岐阜県本巣市根尾樽見');
ok($zip->set_number('5011523')->is_valid_number, '岐阜県本巣市根尾川原');
ok($zip->set_number('5011524')->is_valid_number, '岐阜県本巣市根尾板所');
ok($zip->set_number('5011525')->is_valid_number, '岐阜県本巣市根尾今村');
ok($zip->set_number('5011526')->is_valid_number, '岐阜県本巣市根尾平野');
ok($zip->set_number('5011527')->is_valid_number, '岐阜県本巣市根尾宇津志');
ok($zip->set_number('5011528')->is_valid_number, '岐阜県本巣市根尾高尾');
ok($zip->set_number('5011529')->is_valid_number, '岐阜県本巣市根尾水鳥');
ok($zip->set_number('5011531')->is_valid_number, '岐阜県本巣市根尾門脇');
ok($zip->set_number('5011532')->is_valid_number, '岐阜県本巣市根尾越卒');
ok($zip->set_number('5011533')->is_valid_number, '岐阜県本巣市根尾中');
ok($zip->set_number('5011534')->is_valid_number, '岐阜県本巣市根尾神所');
ok($zip->set_number('5011535')->is_valid_number, '岐阜県本巣市根尾大井');
ok($zip->set_number('5011536')->is_valid_number, '岐阜県本巣市根尾八谷');
ok($zip->set_number('5012100')->is_valid_number, '岐阜県山県市以下に掲載がない場合');
ok($zip->set_number('5012101')->is_valid_number, '岐阜県山県市大桑');
ok($zip->set_number('5012102')->is_valid_number, '岐阜県山県市伊佐美');
ok($zip->set_number('5012103')->is_valid_number, '岐阜県山県市椎倉');
ok($zip->set_number('5012104')->is_valid_number, '岐阜県山県市東深瀬');
ok($zip->set_number('5012105')->is_valid_number, '岐阜県山県市高富');
ok($zip->set_number('5012111')->is_valid_number, '岐阜県山県市赤尾');
ok($zip->set_number('5012112')->is_valid_number, '岐阜県山県市西深瀬');
ok($zip->set_number('5012113')->is_valid_number, '岐阜県山県市高木');
ok($zip->set_number('5012114')->is_valid_number, '岐阜県山県市佐賀');
ok($zip->set_number('5012115')->is_valid_number, '岐阜県山県市梅原');
ok($zip->set_number('5012121')->is_valid_number, '岐阜県山県市大門');
ok($zip->set_number('5012122')->is_valid_number, '岐阜県山県市藤倉');
ok($zip->set_number('5012123')->is_valid_number, '岐阜県山県市大森');
ok($zip->set_number('5012124')->is_valid_number, '岐阜県山県市小倉');
ok($zip->set_number('5012125')->is_valid_number, '岐阜県山県市洞田');
ok($zip->set_number('5012131')->is_valid_number, '岐阜県山県市平井');
ok($zip->set_number('5012132')->is_valid_number, '岐阜県山県市掛');
ok($zip->set_number('5012133')->is_valid_number, '岐阜県山県市上願');
ok($zip->set_number('5012134')->is_valid_number, '岐阜県山県市松尾');
ok($zip->set_number('5012135')->is_valid_number, '岐阜県山県市長滝');
ok($zip->set_number('5012251')->is_valid_number, '岐阜県山県市柿野');
ok($zip->set_number('5012252')->is_valid_number, '岐阜県山県市相戸');
ok($zip->set_number('5012253')->is_valid_number, '岐阜県山県市日永');
ok($zip->set_number('5012254')->is_valid_number, '岐阜県山県市出戸');
ok($zip->set_number('5012255')->is_valid_number, '岐阜県山県市船越');
ok($zip->set_number('5012256')->is_valid_number, '岐阜県山県市青波');
ok($zip->set_number('5012257')->is_valid_number, '岐阜県山県市富永');
ok($zip->set_number('5012258')->is_valid_number, '岐阜県山県市中洞');
ok($zip->set_number('5012259')->is_valid_number, '岐阜県山県市岩佐');
ok($zip->set_number('5012301')->is_valid_number, '岐阜県山県市神崎');
ok($zip->set_number('5012302')->is_valid_number, '岐阜県山県市円原');
ok($zip->set_number('5012303')->is_valid_number, '岐阜県山県市片原');
ok($zip->set_number('5012311')->is_valid_number, '岐阜県山県市椿');
ok($zip->set_number('5012312')->is_valid_number, '岐阜県山県市佐野');
ok($zip->set_number('5012313')->is_valid_number, '岐阜県山県市徳永');
ok($zip->set_number('5012314')->is_valid_number, '岐阜県山県市笹賀');
ok($zip->set_number('5012315')->is_valid_number, '岐阜県山県市田栗');
ok($zip->set_number('5012321')->is_valid_number, '岐阜県山県市谷合');
ok($zip->set_number('5012331')->is_valid_number, '岐阜県山県市葛原');
ok($zip->set_number('5012501')->is_valid_number, '岐阜県岐阜市出屋敷');
ok($zip->set_number('5012502')->is_valid_number, '岐阜県岐阜市山県北野');
ok($zip->set_number('5012503')->is_valid_number, '岐阜県岐阜市北野阿原');
ok($zip->set_number('5012504')->is_valid_number, '岐阜県岐阜市山県岩');
ok($zip->set_number('5012505')->is_valid_number, '岐阜県岐阜市山県岩東');
ok($zip->set_number('5012506')->is_valid_number, '岐阜県岐阜市山県岩南');
ok($zip->set_number('5012507')->is_valid_number, '岐阜県岐阜市山県岩中');
ok($zip->set_number('5012508')->is_valid_number, '岐阜県岐阜市山県岩明光');
ok($zip->set_number('5012509')->is_valid_number, '岐阜県岐阜市山県岩西');
ok($zip->set_number('5012511')->is_valid_number, '岐阜県岐阜市北野北');
ok($zip->set_number('5012512')->is_valid_number, '岐阜県岐阜市北野東');
ok($zip->set_number('5012513')->is_valid_number, '岐阜県岐阜市三輪');
ok($zip->set_number('5012514')->is_valid_number, '岐阜県岐阜市三輪宮前');
ok($zip->set_number('5012515')->is_valid_number, '岐阜県岐阜市三輪宮西');
ok($zip->set_number('5012516')->is_valid_number, '岐阜県岐阜市北野南');
ok($zip->set_number('5012517')->is_valid_number, '岐阜県岐阜市三輪ぷりんとぴあ');
ok($zip->set_number('5012518')->is_valid_number, '岐阜県岐阜市北野西');
ok($zip->set_number('5012519')->is_valid_number, '岐阜県岐阜市北野西山');
ok($zip->set_number('5012521')->is_valid_number, '岐阜県岐阜市門屋');
ok($zip->set_number('5012522')->is_valid_number, '岐阜県岐阜市門屋溝上');
ok($zip->set_number('5012523')->is_valid_number, '岐阜県岐阜市茂地');
ok($zip->set_number('5012524')->is_valid_number, '岐阜県岐阜市春近古市場北');
ok($zip->set_number('5012525')->is_valid_number, '岐阜県岐阜市春近古市場南');
ok($zip->set_number('5012526')->is_valid_number, '岐阜県岐阜市門屋野崎');
ok($zip->set_number('5012527')->is_valid_number, '岐阜県岐阜市門屋勢引');
ok($zip->set_number('5012528')->is_valid_number, '岐阜県岐阜市門屋門');
ok($zip->set_number('5012531')->is_valid_number, '岐阜県岐阜市中屋東');
ok($zip->set_number('5012532')->is_valid_number, '岐阜県岐阜市中屋西');
ok($zip->set_number('5012533')->is_valid_number, '岐阜県岐阜市森東');
ok($zip->set_number('5012534')->is_valid_number, '岐阜県岐阜市森西');
ok($zip->set_number('5012535')->is_valid_number, '岐阜県岐阜市石原(1~3丁目)');
ok($zip->set_number('5012536')->is_valid_number, '岐阜県岐阜市太郎丸樫木');
ok($zip->set_number('5012541')->is_valid_number, '岐阜県岐阜市世保');
ok($zip->set_number('5012542')->is_valid_number, '岐阜県岐阜市世保東');
ok($zip->set_number('5012543')->is_valid_number, '岐阜県岐阜市世保南');
ok($zip->set_number('5012544')->is_valid_number, '岐阜県岐阜市世保西');
ok($zip->set_number('5012545')->is_valid_number, '岐阜県岐阜市世保北');
ok($zip->set_number('5012551')->is_valid_number, '岐阜県岐阜市溝口');
ok($zip->set_number('5012552')->is_valid_number, '岐阜県岐阜市溝口東');
ok($zip->set_number('5012553')->is_valid_number, '岐阜県岐阜市溝口中野');
ok($zip->set_number('5012554')->is_valid_number, '岐阜県岐阜市溝口童子');
ok($zip->set_number('5012555')->is_valid_number, '岐阜県岐阜市溝口下');
ok($zip->set_number('5012556')->is_valid_number, '岐阜県岐阜市溝口中');
ok($zip->set_number('5012557')->is_valid_number, '岐阜県岐阜市溝口上');
ok($zip->set_number('5012561')->is_valid_number, '岐阜県岐阜市福富笠海道');
ok($zip->set_number('5012562')->is_valid_number, '岐阜県岐阜市福富出口');
ok($zip->set_number('5012563')->is_valid_number, '岐阜県岐阜市福富迎田');
ok($zip->set_number('5012564')->is_valid_number, '岐阜県岐阜市福富永田');
ok($zip->set_number('5012565')->is_valid_number, '岐阜県岐阜市福富');
ok($zip->set_number('5012566')->is_valid_number, '岐阜県岐阜市福富天神前');
ok($zip->set_number('5012567')->is_valid_number, '岐阜県岐阜市福富町田');
ok($zip->set_number('5012571')->is_valid_number, '岐阜県岐阜市太郎丸向良');
ok($zip->set_number('5012572')->is_valid_number, '岐阜県岐阜市太郎丸北郷');
ok($zip->set_number('5012573')->is_valid_number, '岐阜県岐阜市太郎丸諏訪');
ok($zip->set_number('5012574')->is_valid_number, '岐阜県岐阜市太郎丸北浦');
ok($zip->set_number('5012575')->is_valid_number, '岐阜県岐阜市太郎丸中島');
ok($zip->set_number('5012576')->is_valid_number, '岐阜県岐阜市太郎丸新屋敷');
ok($zip->set_number('5012577')->is_valid_number, '岐阜県岐阜市太郎丸');
ok($zip->set_number('5012578')->is_valid_number, '岐阜県岐阜市太郎丸野田');
ok($zip->set_number('5012579')->is_valid_number, '岐阜県岐阜市太郎丸知之道');
ok($zip->set_number('5012601')->is_valid_number, '岐阜県関市武芸川町谷口');
ok($zip->set_number('5012602')->is_valid_number, '岐阜県関市武芸川町小知野');
ok($zip->set_number('5012603')->is_valid_number, '岐阜県関市武芸川町八幡');
ok($zip->set_number('5012604')->is_valid_number, '岐阜県関市武芸川町高野');
ok($zip->set_number('5012605')->is_valid_number, '岐阜県関市武芸川町跡部');
ok($zip->set_number('5012606')->is_valid_number, '岐阜県関市武芸川町平');
ok($zip->set_number('5012607')->is_valid_number, '岐阜県関市武芸川町宇多院');
ok($zip->set_number('5012801')->is_valid_number, '岐阜県関市洞戸栗原');
ok($zip->set_number('5012802')->is_valid_number, '岐阜県関市洞戸通元寺');
ok($zip->set_number('5012803')->is_valid_number, '岐阜県関市洞戸飛瀬');
ok($zip->set_number('5012805')->is_valid_number, '岐阜県関市洞戸尾倉');
ok($zip->set_number('5012806')->is_valid_number, '岐阜県関市洞戸高賀');
ok($zip->set_number('5012807')->is_valid_number, '岐阜県関市洞戸阿部');
ok($zip->set_number('5012808')->is_valid_number, '岐阜県関市洞戸高見');
ok($zip->set_number('5012809')->is_valid_number, '岐阜県関市洞戸小瀬見');
ok($zip->set_number('5012811')->is_valid_number, '岐阜県関市洞戸片');
ok($zip->set_number('5012812')->is_valid_number, '岐阜県関市洞戸市場');
ok($zip->set_number('5012814')->is_valid_number, '岐阜県関市洞戸菅谷');
ok($zip->set_number('5012815')->is_valid_number, '岐阜県関市洞戸黒谷');
ok($zip->set_number('5012816')->is_valid_number, '岐阜県関市洞戸大野');
ok($zip->set_number('5012817')->is_valid_number, '岐阜県関市洞戸小坂');
ok($zip->set_number('5012901')->is_valid_number, '岐阜県関市板取');
ok($zip->set_number('5013101')->is_valid_number, '岐阜県岐阜市岩井');
ok($zip->set_number('5013102')->is_valid_number, '岐阜県岐阜市岩井万場');
ok($zip->set_number('5013104')->is_valid_number, '岐阜県岐阜市石原(その他)');
ok($zip->set_number('5013107')->is_valid_number, '岐阜県岐阜市加野');
ok($zip->set_number('5013108')->is_valid_number, '岐阜県岐阜市大蔵台');
ok($zip->set_number('5013109')->is_valid_number, '岐阜県岐阜市向加野');
ok($zip->set_number('5013111')->is_valid_number, '岐阜県岐阜市芥見大退');
ok($zip->set_number('5013112')->is_valid_number, '岐阜県岐阜市芥見東山');
ok($zip->set_number('5013113')->is_valid_number, '岐阜県岐阜市北山');
ok($zip->set_number('5013114')->is_valid_number, '岐阜県岐阜市芥見大船');
ok($zip->set_number('5013115')->is_valid_number, '岐阜県岐阜市上芥見');
ok($zip->set_number('5013116')->is_valid_number, '岐阜県岐阜市芥見町屋');
ok($zip->set_number('5013117')->is_valid_number, '岐阜県岐阜市コモンヒルズ北山');
ok($zip->set_number('5013121')->is_valid_number, '岐阜県岐阜市大洞桐が丘');
ok($zip->set_number('5013122')->is_valid_number, '岐阜県岐阜市大洞紅葉が丘');
ok($zip->set_number('5013123')->is_valid_number, '岐阜県岐阜市大洞柏台');
ok($zip->set_number('5013124')->is_valid_number, '岐阜県岐阜市大洞');
ok($zip->set_number('5013125')->is_valid_number, '岐阜県岐阜市大洞緑山');
ok($zip->set_number('5013126')->is_valid_number, '岐阜県岐阜市大洞西');
ok($zip->set_number('5013127')->is_valid_number, '岐阜県岐阜市大洞桜台');
ok($zip->set_number('5013131')->is_valid_number, '岐阜県岐阜市祇園');
ok($zip->set_number('5013132')->is_valid_number, '岐阜県岐阜市芥見長山');
ok($zip->set_number('5013133')->is_valid_number, '岐阜県岐阜市芥見南山');
ok($zip->set_number('5013134')->is_valid_number, '岐阜県岐阜市芥見');
ok($zip->set_number('5013135')->is_valid_number, '岐阜県岐阜市芥見清水');
ok($zip->set_number('5013136')->is_valid_number, '岐阜県岐阜市芥見海戸山');
ok($zip->set_number('5013141')->is_valid_number, '岐阜県岐阜市芥見中野畑');
ok($zip->set_number('5013142')->is_valid_number, '岐阜県岐阜市諏訪山');
ok($zip->set_number('5013143')->is_valid_number, '岐阜県岐阜市芥見影山');
ok($zip->set_number('5013144')->is_valid_number, '岐阜県岐阜市芥見大般若');
ok($zip->set_number('5013145')->is_valid_number, '岐阜県岐阜市芥見野畑');
ok($zip->set_number('5013146')->is_valid_number, '岐阜県岐阜市芥見嵯峨');
ok($zip->set_number('5013147')->is_valid_number, '岐阜県岐阜市芥見堀田');
ok($zip->set_number('5013151')->is_valid_number, '岐阜県岐阜市岩滝東');
ok($zip->set_number('5013152')->is_valid_number, '岐阜県岐阜市岩滝西');
ok($zip->set_number('5013153')->is_valid_number, '岐阜県岐阜市静が丘町');
ok($zip->set_number('5013154')->is_valid_number, '岐阜県岐阜市岩田東');
ok($zip->set_number('5013155')->is_valid_number, '岐阜県岐阜市岩田坂');
ok($zip->set_number('5013156')->is_valid_number, '岐阜県岐阜市岩田西');
ok($zip->set_number('5013200')->is_valid_number, '岐阜県関市以下に掲載がない場合');
ok($zip->set_number('5013201')->is_valid_number, '岐阜県関市小野');
ok($zip->set_number('5013202')->is_valid_number, '岐阜県関市西神野');
ok($zip->set_number('5013203')->is_valid_number, '岐阜県関市神野');
ok($zip->set_number('5013204')->is_valid_number, '岐阜県関市上大野');
ok($zip->set_number('5013205')->is_valid_number, '岐阜県関市志津野');
ok($zip->set_number('5013206')->is_valid_number, '岐阜県関市塔ノ洞');
ok($zip->set_number('5013207')->is_valid_number, '岐阜県関市黒屋');
ok($zip->set_number('5013210')->is_valid_number, '岐阜県関市尾太町');
ok($zip->set_number('5013211')->is_valid_number, '岐阜県関市関ノ上');
ok($zip->set_number('5013212')->is_valid_number, '岐阜県関市寺田');
ok($zip->set_number('5013213')->is_valid_number, '岐阜県関市東貸上');
ok($zip->set_number('5013214')->is_valid_number, '岐阜県関市貸上町');
ok($zip->set_number('5013215')->is_valid_number, '岐阜県関市西境松町');
ok($zip->set_number('5013216')->is_valid_number, '岐阜県関市水ノ輪町');
ok($zip->set_number('5013217')->is_valid_number, '岐阜県関市下有知');
ok($zip->set_number('5013218')->is_valid_number, '岐阜県関市東志摩');
ok($zip->set_number('5013219')->is_valid_number, '岐阜県関市のぞみケ丘');
ok($zip->set_number('5013221')->is_valid_number, '岐阜県関市西貸上');
ok($zip->set_number('5013222')->is_valid_number, '岐阜県関市南貸上');
ok($zip->set_number('5013223')->is_valid_number, '岐阜県関市竪切南');
ok($zip->set_number('5013224')->is_valid_number, '岐阜県関市東仙房');
ok($zip->set_number('5013225')->is_valid_number, '岐阜県関市南仙房');
ok($zip->set_number('5013226')->is_valid_number, '岐阜県関市向西仙房');
ok($zip->set_number('5013227')->is_valid_number, '岐阜県関市北仙房');
ok($zip->set_number('5013228')->is_valid_number, '岐阜県関市竪切北');
ok($zip->set_number('5013231')->is_valid_number, '岐阜県関市東桜町');
ok($zip->set_number('5013232')->is_valid_number, '岐阜県関市桜本町');
ok($zip->set_number('5013233')->is_valid_number, '岐阜県関市西木戸町');
ok($zip->set_number('5013234')->is_valid_number, '岐阜県関市若宮町');
ok($zip->set_number('5013235')->is_valid_number, '岐阜県関市川間町');
ok($zip->set_number('5013236')->is_valid_number, '岐阜県関市辻井戸町');
ok($zip->set_number('5013237')->is_valid_number, '岐阜県関市緑町');
ok($zip->set_number('5013241')->is_valid_number, '岐阜県関市西仙房');
ok($zip->set_number('5013242')->is_valid_number, '岐阜県関市東福野町');
ok($zip->set_number('5013243')->is_valid_number, '岐阜県関市中福野町');
ok($zip->set_number('5013244')->is_valid_number, '岐阜県関市西福野町');
ok($zip->set_number('5013245')->is_valid_number, '岐阜県関市北福野町');
ok($zip->set_number('5013246')->is_valid_number, '岐阜県関市緑ケ丘');
ok($zip->set_number('5013247')->is_valid_number, '岐阜県関市池田町');
ok($zip->set_number('5013250')->is_valid_number, '岐阜県関市十三塚町');
ok($zip->set_number('5013251')->is_valid_number, '岐阜県関市山王通西');
ok($zip->set_number('5013252')->is_valid_number, '岐阜県関市山王通');
ok($zip->set_number('5013253')->is_valid_number, '岐阜県関市栄町');
ok($zip->set_number('5013254')->is_valid_number, '岐阜県関市雄飛ケ丘');
ok($zip->set_number('5013255')->is_valid_number, '岐阜県関市段下');
ok($zip->set_number('5013256')->is_valid_number, '岐阜県関市巾');
ok($zip->set_number('5013257')->is_valid_number, '岐阜県関市新田');
ok($zip->set_number('5013258')->is_valid_number, '岐阜県関市十三塚南');
ok($zip->set_number('5013259')->is_valid_number, '岐阜県関市十三塚北');
ok($zip->set_number('5013261')->is_valid_number, '岐阜県関市広見北町');
ok($zip->set_number('5013262')->is_valid_number, '岐阜県関市広見東町');
ok($zip->set_number('5013263')->is_valid_number, '岐阜県関市広見');
ok($zip->set_number('5013264')->is_valid_number, '岐阜県関市池尻');
ok($zip->set_number('5013265')->is_valid_number, '岐阜県関市小瀬');
ok($zip->set_number('5013266')->is_valid_number, '岐阜県関市小瀬南');
ok($zip->set_number('5013267')->is_valid_number, '岐阜県関市星ケ丘');
ok($zip->set_number('5013268')->is_valid_number, '岐阜県関市小瀬長池町');
ok($zip->set_number('5013300')->is_valid_number, '岐阜県加茂郡富加町以下に掲載がない場合');
ok($zip->set_number('5013301')->is_valid_number, '岐阜県加茂郡富加町加治田');
ok($zip->set_number('5013302')->is_valid_number, '岐阜県加茂郡富加町夕田');
ok($zip->set_number('5013303')->is_valid_number, '岐阜県加茂郡富加町羽生');
ok($zip->set_number('5013304')->is_valid_number, '岐阜県加茂郡富加町高畑');
ok($zip->set_number('5013305')->is_valid_number, '岐阜県加茂郡富加町滝田');
ok($zip->set_number('5013306')->is_valid_number, '岐阜県加茂郡富加町大山');
ok($zip->set_number('5013307')->is_valid_number, '岐阜県加茂郡富加町大平賀');
ok($zip->set_number('5013501')->is_valid_number, '岐阜県関市富之保');
ok($zip->set_number('5013511')->is_valid_number, '岐阜県関市中之保');
ok($zip->set_number('5013521')->is_valid_number, '岐阜県関市下之保');
ok($zip->set_number('5013601')->is_valid_number, '岐阜県関市上之保');
ok($zip->set_number('5013700')->is_valid_number, '岐阜県美濃市以下に掲載がない場合');
ok($zip->set_number('5013701')->is_valid_number, '岐阜県美濃市美濃市の次に番地がくる場合');
ok($zip->set_number('5013702')->is_valid_number, '岐阜県美濃市上河和');
ok($zip->set_number('5013703')->is_valid_number, '岐阜県美濃市下河和');
ok($zip->set_number('5013704')->is_valid_number, '岐阜県美濃市保木脇');
ok($zip->set_number('5013705')->is_valid_number, '岐阜県美濃市立花');
ok($zip->set_number('5013706')->is_valid_number, '岐阜県美濃市須原');
ok($zip->set_number('5013711')->is_valid_number, '岐阜県美濃市樋ケ洞');
ok($zip->set_number('5013712')->is_valid_number, '岐阜県美濃市口野々');
ok($zip->set_number('5013713')->is_valid_number, '岐阜県美濃市富野');
ok($zip->set_number('5013714')->is_valid_number, '岐阜県美濃市曽代');
ok($zip->set_number('5013715')->is_valid_number, '岐阜県美濃市梅山町');
ok($zip->set_number('5013716')->is_valid_number, '岐阜県美濃市前野');
ok($zip->set_number('5013717')->is_valid_number, '岐阜県美濃市安毛');
ok($zip->set_number('5013721')->is_valid_number, '岐阜県美濃市吉川町');
ok($zip->set_number('5013722')->is_valid_number, '岐阜県美濃市常盤町');
ok($zip->set_number('5013723')->is_valid_number, '岐阜県美濃市相生町');
ok($zip->set_number('5013724')->is_valid_number, '岐阜県美濃市魚屋町');
ok($zip->set_number('5013725')->is_valid_number, '岐阜県美濃市俵町');
ok($zip->set_number('5013726')->is_valid_number, '岐阜県美濃市加治屋町');
ok($zip->set_number('5013727')->is_valid_number, '岐阜県美濃市永重町');
ok($zip->set_number('5013728')->is_valid_number, '岐阜県美濃市本住町');
ok($zip->set_number('5013729')->is_valid_number, '岐阜県美濃市泉町');
ok($zip->set_number('5013731')->is_valid_number, '岐阜県美濃市東市場町');
ok($zip->set_number('5013732')->is_valid_number, '岐阜県美濃市広岡町');
ok($zip->set_number('5013733')->is_valid_number, '岐阜県美濃市亀野町');
ok($zip->set_number('5013734')->is_valid_number, '岐阜県美濃市千畝町');
ok($zip->set_number('5013735')->is_valid_number, '岐阜県美濃市西市場町');
ok($zip->set_number('5013736')->is_valid_number, '岐阜県美濃市米屋町');
ok($zip->set_number('5013737')->is_valid_number, '岐阜県美濃市新町');
ok($zip->set_number('5013741')->is_valid_number, '岐阜県美濃市港町');
ok($zip->set_number('5013742')->is_valid_number, '岐阜県美濃市殿町');
ok($zip->set_number('5013743')->is_valid_number, '岐阜県美濃市上条');
ok($zip->set_number('5013744')->is_valid_number, '岐阜県美濃市段町');
ok($zip->set_number('5013745')->is_valid_number, '岐阜県美濃市下渡');
ok($zip->set_number('5013746')->is_valid_number, '岐阜県美濃市中央');
ok($zip->set_number('5013751')->is_valid_number, '岐阜県美濃市松倉台');
ok($zip->set_number('5013752')->is_valid_number, '岐阜県美濃市松栄町');
ok($zip->set_number('5013753')->is_valid_number, '岐阜県美濃市松森');
ok($zip->set_number('5013754')->is_valid_number, '岐阜県美濃市さくらケ丘');
ok($zip->set_number('5013755')->is_valid_number, '岐阜県美濃市志摩');
ok($zip->set_number('5013756')->is_valid_number, '岐阜県美濃市生櫛');
ok($zip->set_number('5013761')->is_valid_number, '岐阜県美濃市横越');
ok($zip->set_number('5013762')->is_valid_number, '岐阜県美濃市藍川');
ok($zip->set_number('5013763')->is_valid_number, '岐阜県美濃市極楽寺');
ok($zip->set_number('5013764')->is_valid_number, '岐阜県美濃市笠神');
ok($zip->set_number('5013771')->is_valid_number, '岐阜県美濃市大矢田');
ok($zip->set_number('5013772')->is_valid_number, '岐阜県美濃市楓台');
ok($zip->set_number('5013773')->is_valid_number, '岐阜県美濃市もみじが丘');
ok($zip->set_number('5013781')->is_valid_number, '岐阜県美濃市片知');
ok($zip->set_number('5013782')->is_valid_number, '岐阜県美濃市長瀬');
ok($zip->set_number('5013783')->is_valid_number, '岐阜県美濃市神洞');
ok($zip->set_number('5013784')->is_valid_number, '岐阜県美濃市御手洗');
ok($zip->set_number('5013785')->is_valid_number, '岐阜県美濃市小倉');
ok($zip->set_number('5013786')->is_valid_number, '岐阜県美濃市乙狩');
ok($zip->set_number('5013787')->is_valid_number, '岐阜県美濃市上野');
ok($zip->set_number('5013788')->is_valid_number, '岐阜県美濃市蕨生');
ok($zip->set_number('5013801')->is_valid_number, '岐阜県関市大坪');
ok($zip->set_number('5013802')->is_valid_number, '岐阜県関市若草通');
ok($zip->set_number('5013803')->is_valid_number, '岐阜県関市西本郷通');
ok($zip->set_number('5013804')->is_valid_number, '岐阜県関市円保通');
ok($zip->set_number('5013805')->is_valid_number, '岐阜県関市本郷町');
ok($zip->set_number('5013806')->is_valid_number, '岐阜県関市観音山');
ok($zip->set_number('5013807')->is_valid_number, '岐阜県関市安桜山');
ok($zip->set_number('5013808')->is_valid_number, '岐阜県関市安桜台');
ok($zip->set_number('5013811')->is_valid_number, '岐阜県関市東本郷通');
ok($zip->set_number('5013812')->is_valid_number, '岐阜県関市東本郷');
ok($zip->set_number('5013813')->is_valid_number, '岐阜県関市東野町');
ok($zip->set_number('5013814')->is_valid_number, '岐阜県関市東山');
ok($zip->set_number('5013815')->is_valid_number, '岐阜県関市東町');
ok($zip->set_number('5013816')->is_valid_number, '岐阜県関市吉野町');
ok($zip->set_number('5013817')->is_valid_number, '岐阜県関市仲町');
ok($zip->set_number('5013818')->is_valid_number, '岐阜県関市吉本町');
ok($zip->set_number('5013819')->is_valid_number, '岐阜県関市西町');
ok($zip->set_number('5013821')->is_valid_number, '岐阜県関市平賀町');
ok($zip->set_number('5013822')->is_valid_number, '岐阜県関市市平賀');
ok($zip->set_number('5013823')->is_valid_number, '岐阜県関市東出町');
ok($zip->set_number('5013824')->is_valid_number, '岐阜県関市東新町');
ok($zip->set_number('5013825')->is_valid_number, '岐阜県関市南出');
ok($zip->set_number('5013826')->is_valid_number, '岐阜県関市関口町');
ok($zip->set_number('5013827')->is_valid_number, '岐阜県関市宮地町');
ok($zip->set_number('5013828')->is_valid_number, '岐阜県関市西旭ケ丘');
ok($zip->set_number('5013829')->is_valid_number, '岐阜県関市旭ケ丘');
ok($zip->set_number('5013831')->is_valid_number, '岐阜県関市長谷寺町');
ok($zip->set_number('5013832')->is_valid_number, '岐阜県関市花園町');
ok($zip->set_number('5013833')->is_valid_number, '岐阜県関市大平町');
ok($zip->set_number('5013834')->is_valid_number, '岐阜県関市大門町');
ok($zip->set_number('5013835')->is_valid_number, '岐阜県関市観音前');
ok($zip->set_number('5013836')->is_valid_number, '岐阜県関市美園町');
ok($zip->set_number('5013837')->is_valid_number, '岐阜県関市西門前町');
ok($zip->set_number('5013838')->is_valid_number, '岐阜県関市東門前町');
ok($zip->set_number('5013839')->is_valid_number, '岐阜県関市長住町');
ok($zip->set_number('5013841')->is_valid_number, '岐阜県関市伊勢町');
ok($zip->set_number('5013842')->is_valid_number, '岐阜県関市出来町');
ok($zip->set_number('5013843')->is_valid_number, '岐阜県関市吉田町');
ok($zip->set_number('5013844')->is_valid_number, '岐阜県関市美和町');
ok($zip->set_number('5013845')->is_valid_number, '岐阜県関市吾妻町');
ok($zip->set_number('5013846')->is_valid_number, '岐阜県関市住吉町');
ok($zip->set_number('5013847')->is_valid_number, '岐阜県関市新町');
ok($zip->set_number('5013848')->is_valid_number, '岐阜県関市末広町');
ok($zip->set_number('5013851')->is_valid_number, '岐阜県関市相生町');
ok($zip->set_number('5013852')->is_valid_number, '岐阜県関市上利町');
ok($zip->set_number('5013853')->is_valid_number, '岐阜県関市朝倉町');
ok($zip->set_number('5013854')->is_valid_number, '岐阜県関市月見町');
ok($zip->set_number('5013855')->is_valid_number, '岐阜県関市いろは町');
ok($zip->set_number('5013856')->is_valid_number, '岐阜県関市桜木町');
ok($zip->set_number('5013857')->is_valid_number, '岐阜県関市南春日町');
ok($zip->set_number('5013861')->is_valid_number, '岐阜県関市小柳町');
ok($zip->set_number('5013862')->is_valid_number, '岐阜県関市兼永町');
ok($zip->set_number('5013863')->is_valid_number, '岐阜県関市富本町');
ok($zip->set_number('5013864')->is_valid_number, '岐阜県関市前町');
ok($zip->set_number('5013865')->is_valid_number, '岐阜県関市春日町');
ok($zip->set_number('5013866')->is_valid_number, '岐阜県関市千年町');
ok($zip->set_number('5013867')->is_valid_number, '岐阜県関市常盤町');
ok($zip->set_number('5013868')->is_valid_number, '岐阜県関市白川町');
ok($zip->set_number('5013871')->is_valid_number, '岐阜県関市鍛冶町');
ok($zip->set_number('5013872')->is_valid_number, '岐阜県関市金屋町');
ok($zip->set_number('5013873')->is_valid_number, '岐阜県関市日ノ出町');
ok($zip->set_number('5013874')->is_valid_number, '岐阜県関市平和通');
ok($zip->set_number('5013875')->is_valid_number, '岐阜県関市森西町');
ok($zip->set_number('5013876')->is_valid_number, '岐阜県関市貴船町');
ok($zip->set_number('5013877')->is_valid_number, '岐阜県関市河合町');
ok($zip->set_number('5013878')->is_valid_number, '岐阜県関市十軒町');
ok($zip->set_number('5013881')->is_valid_number, '岐阜県関市元重町');
ok($zip->set_number('5013882')->is_valid_number, '岐阜県関市西日吉町');
ok($zip->set_number('5013883')->is_valid_number, '岐阜県関市東日吉町');
ok($zip->set_number('5013884')->is_valid_number, '岐阜県関市孫六町');
ok($zip->set_number('5013885')->is_valid_number, '岐阜県関市山ノ手');
ok($zip->set_number('5013886')->is_valid_number, '岐阜県関市本町');
ok($zip->set_number('5013887')->is_valid_number, '岐阜県関市吐月町');
ok($zip->set_number('5013888')->is_valid_number, '岐阜県関市坂下町');
ok($zip->set_number('5013901')->is_valid_number, '岐阜県関市春里町');
ok($zip->set_number('5013902')->is_valid_number, '岐阜県関市弥生町');
ok($zip->set_number('5013903')->is_valid_number, '岐阜県関市桜ケ丘');
ok($zip->set_number('5013904')->is_valid_number, '岐阜県関市明生町');
ok($zip->set_number('5013905')->is_valid_number, '岐阜県関市神明町');
ok($zip->set_number('5013906')->is_valid_number, '岐阜県関市西欠ノ下');
ok($zip->set_number('5013907')->is_valid_number, '岐阜県関市南町');
ok($zip->set_number('5013908')->is_valid_number, '岐阜県関市寿町');
ok($zip->set_number('5013909')->is_valid_number, '岐阜県関市新堀町');
ok($zip->set_number('5013910')->is_valid_number, '岐阜県関市笠屋');
ok($zip->set_number('5013911')->is_valid_number, '岐阜県関市肥田瀬');
ok($zip->set_number('5013912')->is_valid_number, '岐阜県関市宮河町');
ok($zip->set_number('5013913')->is_valid_number, '岐阜県関市稲河町');
ok($zip->set_number('5013914')->is_valid_number, '岐阜県関市鋳物師屋');
ok($zip->set_number('5013915')->is_valid_number, '岐阜県関市天徳町');
ok($zip->set_number('5013916')->is_valid_number, '岐阜県関市豊岡町');
ok($zip->set_number('5013917')->is_valid_number, '岐阜県関市北天神');
ok($zip->set_number('5013918')->is_valid_number, '岐阜県関市南天神');
ok($zip->set_number('5013919')->is_valid_number, '岐阜県関市平成通');
ok($zip->set_number('5013921')->is_valid_number, '岐阜県関市東田原');
ok($zip->set_number('5013922')->is_valid_number, '岐阜県関市大杉');
ok($zip->set_number('5013923')->is_valid_number, '岐阜県関市新迫間');
ok($zip->set_number('5013924')->is_valid_number, '岐阜県関市迫間');
ok($zip->set_number('5013925')->is_valid_number, '岐阜県関市迫間台');
ok($zip->set_number('5013926')->is_valid_number, '岐阜県関市小迫間');
ok($zip->set_number('5013927')->is_valid_number, '岐阜県関市向陽台');
ok($zip->set_number('5013928')->is_valid_number, '岐阜県関市西田原');
ok($zip->set_number('5013930')->is_valid_number, '岐阜県関市倉知南');
ok($zip->set_number('5013931')->is_valid_number, '岐阜県関市桜台');
ok($zip->set_number('5013932')->is_valid_number, '岐阜県関市稲口');
ok($zip->set_number('5013933')->is_valid_number, '岐阜県関市向山町');
ok($zip->set_number('5013934')->is_valid_number, '岐阜県関市桐谷台');
ok($zip->set_number('5013935')->is_valid_number, '岐阜県関市四季ノ台');
ok($zip->set_number('5013936')->is_valid_number, '岐阜県関市倉知');
ok($zip->set_number('5013937')->is_valid_number, '岐阜県関市前山町');
ok($zip->set_number('5013938')->is_valid_number, '岐阜県関市桐ヶ丘');
ok($zip->set_number('5013939')->is_valid_number, '岐阜県関市桃紅大地');
ok($zip->set_number('5013941')->is_valid_number, '岐阜県関市小屋名');
ok($zip->set_number('5013942')->is_valid_number, '岐阜県関市希望ケ丘');
ok($zip->set_number('5013943')->is_valid_number, '岐阜県関市虹ケ丘南');
ok($zip->set_number('5013944')->is_valid_number, '岐阜県関市山田');
ok($zip->set_number('5013945')->is_valid_number, '岐阜県関市虹ケ丘北');
ok($zip->set_number('5013946')->is_valid_number, '岐阜県関市津保川台');
ok($zip->set_number('5013947')->is_valid_number, '岐阜県関市上白金');
ok($zip->set_number('5013951')->is_valid_number, '岐阜県関市植野');
ok($zip->set_number('5013952')->is_valid_number, '岐阜県関市大平台');
ok($zip->set_number('5013953')->is_valid_number, '岐阜県関市千疋北');
ok($zip->set_number('5013954')->is_valid_number, '岐阜県関市千疋');
ok($zip->set_number('5013955')->is_valid_number, '岐阜県関市下白金');
ok($zip->set_number('5013956')->is_valid_number, '岐阜県関市保明');
ok($zip->set_number('5013957')->is_valid_number, '岐阜県関市側島');
ok($zip->set_number('5013958')->is_valid_number, '岐阜県関市戸田');
ok($zip->set_number('5013961')->is_valid_number, '岐阜県関市清蔵寺');
ok($zip->set_number('5013962')->is_valid_number, '岐阜県関市柳町');
ok($zip->set_number('5013963')->is_valid_number, '岐阜県関市片倉町');
ok($zip->set_number('5013964')->is_valid_number, '岐阜県関市宝山町');
ok($zip->set_number('5013965')->is_valid_number, '岐阜県関市十六所');
ok($zip->set_number('5013966')->is_valid_number, '岐阜県関市居敷町');
ok($zip->set_number('5013967')->is_valid_number, '岐阜県関市西居敷');
ok($zip->set_number('5013968')->is_valid_number, '岐阜県関市力山');
ok($zip->set_number('5013969')->is_valid_number, '岐阜県関市馬場出');
ok($zip->set_number('5013971')->is_valid_number, '岐阜県関市古屋敷町');
ok($zip->set_number('5013972')->is_valid_number, '岐阜県関市寺内町');
ok($zip->set_number('5013973')->is_valid_number, '岐阜県関市一ツ山町');
ok($zip->set_number('5013974')->is_valid_number, '岐阜県関市梅ケ枝町');
ok($zip->set_number('5013975')->is_valid_number, '岐阜県関市豊川町');
ok($zip->set_number('5013976')->is_valid_number, '岐阜県関市梅竜寺山');
ok($zip->set_number('5013977')->is_valid_number, '岐阜県関市清水町');
ok($zip->set_number('5013978')->is_valid_number, '岐阜県関市赤渕');
ok($zip->set_number('5013979')->is_valid_number, '岐阜県関市一本木町');
ok($zip->set_number('5014101')->is_valid_number, '岐阜県郡上市美並町上田');
ok($zip->set_number('5014102')->is_valid_number, '岐阜県郡上市美並町高砂');
ok($zip->set_number('5014103')->is_valid_number, '岐阜県郡上市美並町山田');
ok($zip->set_number('5014104')->is_valid_number, '岐阜県郡上市美並町梅原');
ok($zip->set_number('5014105')->is_valid_number, '岐阜県郡上市美並町三戸');
ok($zip->set_number('5014106')->is_valid_number, '岐阜県郡上市美並町白山');
ok($zip->set_number('5014107')->is_valid_number, '岐阜県郡上市美並町大原');
ok($zip->set_number('5014200')->is_valid_number, '岐阜県郡上市以下に掲載がない場合');
ok($zip->set_number('5014201')->is_valid_number, '岐阜県郡上市八幡町有穂');
ok($zip->set_number('5014202')->is_valid_number, '岐阜県郡上市八幡町市島');
ok($zip->set_number('5014203')->is_valid_number, '岐阜県郡上市八幡町初納');
ok($zip->set_number('5014204')->is_valid_number, '岐阜県郡上市八幡町旭');
ok($zip->set_number('5014205')->is_valid_number, '岐阜県郡上市八幡町安久田');
ok($zip->set_number('5014206')->is_valid_number, '岐阜県郡上市八幡町吉野');
ok($zip->set_number('5014207')->is_valid_number, '岐阜県郡上市八幡町西乙原');
ok($zip->set_number('5014211')->is_valid_number, '岐阜県郡上市八幡町中坪');
ok($zip->set_number('5014212')->is_valid_number, '岐阜県郡上市八幡町職人町');
ok($zip->set_number('5014213')->is_valid_number, '岐阜県郡上市八幡町殿町');
ok($zip->set_number('5014214')->is_valid_number, '岐阜県郡上市八幡町柳町');
ok($zip->set_number('5014215')->is_valid_number, '岐阜県郡上市八幡町肴町');
ok($zip->set_number('5014216')->is_valid_number, '岐阜県郡上市八幡町本町');
ok($zip->set_number('5014217')->is_valid_number, '岐阜県郡上市八幡町尾崎町');
ok($zip->set_number('5014218')->is_valid_number, '岐阜県郡上市八幡町鍛冶屋町');
ok($zip->set_number('5014219')->is_valid_number, '岐阜県郡上市八幡町大手町');
ok($zip->set_number('5014221')->is_valid_number, '岐阜県郡上市八幡町小野');
ok($zip->set_number('5014222')->is_valid_number, '岐阜県郡上市八幡町島谷');
ok($zip->set_number('5014223')->is_valid_number, '岐阜県郡上市八幡町稲成');
ok($zip->set_number('5014224')->is_valid_number, '岐阜県郡上市八幡町城南町');
ok($zip->set_number('5014225')->is_valid_number, '岐阜県郡上市八幡町大正町');
ok($zip->set_number('5014226')->is_valid_number, '岐阜県郡上市八幡町新町');
ok($zip->set_number('5014227')->is_valid_number, '岐阜県郡上市八幡町橋本町');
ok($zip->set_number('5014228')->is_valid_number, '岐阜県郡上市八幡町桜町');
ok($zip->set_number('5014231')->is_valid_number, '岐阜県郡上市八幡町河鹿');
ok($zip->set_number('5014232')->is_valid_number, '岐阜県郡上市八幡町初音');
ok($zip->set_number('5014233')->is_valid_number, '岐阜県郡上市八幡町瀬取');
ok($zip->set_number('5014234')->is_valid_number, '岐阜県郡上市八幡町五町');
ok($zip->set_number('5014235')->is_valid_number, '岐阜県郡上市八幡町有坂');
ok($zip->set_number('5014236')->is_valid_number, '岐阜県郡上市八幡町相生');
ok($zip->set_number('5014237')->is_valid_number, '岐阜県郡上市八幡町那比');
ok($zip->set_number('5014238')->is_valid_number, '岐阜県郡上市八幡町島');
ok($zip->set_number('5014241')->is_valid_number, '岐阜県郡上市八幡町向山');
ok($zip->set_number('5014301')->is_valid_number, '岐阜県郡上市明宝大谷');
ok($zip->set_number('5014302')->is_valid_number, '岐阜県郡上市明宝寒水');
ok($zip->set_number('5014303')->is_valid_number, '岐阜県郡上市明宝気良');
ok($zip->set_number('5014304')->is_valid_number, '岐阜県郡上市明宝奥住');
ok($zip->set_number('5014305')->is_valid_number, '岐阜県郡上市明宝小川');
ok($zip->set_number('5014306')->is_valid_number, '岐阜県郡上市明宝畑佐');
ok($zip->set_number('5014307')->is_valid_number, '岐阜県郡上市明宝二間手');
ok($zip->set_number('5014451')->is_valid_number, '岐阜県郡上市八幡町入間');
ok($zip->set_number('5014452')->is_valid_number, '岐阜県郡上市八幡町美山');
ok($zip->set_number('5014453')->is_valid_number, '岐阜県郡上市八幡町洲河');
ok($zip->set_number('5014454')->is_valid_number, '岐阜県郡上市八幡町野々倉');
ok($zip->set_number('5014455')->is_valid_number, '岐阜県郡上市八幡町小那比');
ok($zip->set_number('5014501')->is_valid_number, '岐阜県郡上市和良町鹿倉');
ok($zip->set_number('5014502')->is_valid_number, '岐阜県郡上市和良町宮代');
ok($zip->set_number('5014503')->is_valid_number, '岐阜県郡上市和良町野尻');
ok($zip->set_number('5014504')->is_valid_number, '岐阜県郡上市和良町田平');
ok($zip->set_number('5014505')->is_valid_number, '岐阜県郡上市和良町東野');
ok($zip->set_number('5014506')->is_valid_number, '岐阜県郡上市和良町横野');
ok($zip->set_number('5014507')->is_valid_number, '岐阜県郡上市和良町宮地');
ok($zip->set_number('5014508')->is_valid_number, '岐阜県郡上市和良町上沢');
ok($zip->set_number('5014509')->is_valid_number, '岐阜県郡上市和良町下沢');
ok($zip->set_number('5014510')->is_valid_number, '岐阜県郡上市和良町法師丸');
ok($zip->set_number('5014511')->is_valid_number, '岐阜県郡上市和良町下洞');
ok($zip->set_number('5014512')->is_valid_number, '岐阜県郡上市和良町上土京');
ok($zip->set_number('5014513')->is_valid_number, '岐阜県郡上市和良町下土京');
ok($zip->set_number('5014514')->is_valid_number, '岐阜県郡上市和良町安郷野');
ok($zip->set_number('5014515')->is_valid_number, '岐阜県郡上市和良町方須');
ok($zip->set_number('5014516')->is_valid_number, '岐阜県郡上市和良町三庫');
ok($zip->set_number('5014517')->is_valid_number, '岐阜県郡上市和良町沢');
ok($zip->set_number('5014518')->is_valid_number, '岐阜県郡上市和良町土京');
ok($zip->set_number('5014601')->is_valid_number, '岐阜県郡上市大和町大間見');
ok($zip->set_number('5014602')->is_valid_number, '岐阜県郡上市大和町小間見');
ok($zip->set_number('5014603')->is_valid_number, '岐阜県郡上市大和町栗巣');
ok($zip->set_number('5014604')->is_valid_number, '岐阜県郡上市大和町古道');
ok($zip->set_number('5014605')->is_valid_number, '岐阜県郡上市大和町神路');
ok($zip->set_number('5014606')->is_valid_number, '岐阜県郡上市大和町河辺');
ok($zip->set_number('5014607')->is_valid_number, '岐阜県郡上市大和町徳永');
ok($zip->set_number('5014608')->is_valid_number, '岐阜県郡上市大和町牧');
ok($zip->set_number('5014610')->is_valid_number, '岐阜県郡上市大和町島');
ok($zip->set_number('5014611')->is_valid_number, '岐阜県郡上市大和町万場');
ok($zip->set_number('5014612')->is_valid_number, '岐阜県郡上市大和町剣');
ok($zip->set_number('5014613')->is_valid_number, '岐阜県郡上市大和町名皿部');
ok($zip->set_number('5014614')->is_valid_number, '岐阜県郡上市大和町野口');
ok($zip->set_number('5014615')->is_valid_number, '岐阜県郡上市大和町場皿');
ok($zip->set_number('5014616')->is_valid_number, '岐阜県郡上市大和町福田');
ok($zip->set_number('5014617')->is_valid_number, '岐阜県郡上市大和町洞口');
ok($zip->set_number('5014618')->is_valid_number, '岐阜県郡上市大和町内ケ谷');
ok($zip->set_number('5014619')->is_valid_number, '岐阜県郡上市大和町落部');
ok($zip->set_number('5015101')->is_valid_number, '岐阜県郡上市白鳥町前谷');
ok($zip->set_number('5015102')->is_valid_number, '岐阜県郡上市白鳥町歩岐島');
ok($zip->set_number('5015103')->is_valid_number, '岐阜県郡上市白鳥町二日町');
ok($zip->set_number('5015104')->is_valid_number, '岐阜県郡上市白鳥町長滝');
ok($zip->set_number('5015105')->is_valid_number, '岐阜県郡上市白鳥町干田野');
ok($zip->set_number('5015111')->is_valid_number, '岐阜県郡上市白鳥町阿多岐');
ok($zip->set_number('5015112')->is_valid_number, '岐阜県郡上市白鳥町六ノ里');
ok($zip->set_number('5015113')->is_valid_number, '岐阜県郡上市白鳥町野添');
ok($zip->set_number('5015114')->is_valid_number, '岐阜県郡上市白鳥町那留');
ok($zip->set_number('5015115')->is_valid_number, '岐阜県郡上市白鳥町恩地');
ok($zip->set_number('5015116')->is_valid_number, '岐阜県郡上市白鳥町中西');
ok($zip->set_number('5015121')->is_valid_number, '岐阜県郡上市白鳥町白鳥');
ok($zip->set_number('5015122')->is_valid_number, '岐阜県郡上市白鳥町為真');
ok($zip->set_number('5015123')->is_valid_number, '岐阜県郡上市白鳥町中津屋');
ok($zip->set_number('5015124')->is_valid_number, '岐阜県郡上市白鳥町大島');
ok($zip->set_number('5015125')->is_valid_number, '岐阜県郡上市白鳥町越佐');
ok($zip->set_number('5015126')->is_valid_number, '岐阜県郡上市白鳥町向小駄良');
ok($zip->set_number('5015231')->is_valid_number, '岐阜県郡上市白鳥町石徹白');
ok($zip->set_number('5015301')->is_valid_number, '岐阜県郡上市高鷲町ひるがの');
ok($zip->set_number('5015302')->is_valid_number, '岐阜県郡上市高鷲町鷲見');
ok($zip->set_number('5015302')->is_valid_number, '岐阜県郡上市高鷲町鷲見(上野)');
ok($zip->set_number('5015303')->is_valid_number, '岐阜県郡上市高鷲町大鷲');
ok($zip->set_number('5015304')->is_valid_number, '岐阜県郡上市高鷲町鮎立');
ok($zip->set_number('5015304')->is_valid_number, '岐阜県郡上市高鷲町切立');
ok($zip->set_number('5015305')->is_valid_number, '岐阜県郡上市高鷲町西洞');
ok($zip->set_number('5015401')->is_valid_number, '岐阜県高山市荘川町六厩');
ok($zip->set_number('5015402')->is_valid_number, '岐阜県高山市荘川町三谷');
ok($zip->set_number('5015403')->is_valid_number, '岐阜県高山市荘川町三尾河');
ok($zip->set_number('5015404')->is_valid_number, '岐阜県高山市荘川町黒谷');
ok($zip->set_number('5015405')->is_valid_number, '岐阜県高山市荘川町寺河戸');
ok($zip->set_number('5015406')->is_valid_number, '岐阜県高山市荘川町惣則');
ok($zip->set_number('5015411')->is_valid_number, '岐阜県高山市荘川町牧戸');
ok($zip->set_number('5015412')->is_valid_number, '岐阜県高山市荘川町中畑');
ok($zip->set_number('5015413')->is_valid_number, '岐阜県高山市荘川町新渕');
ok($zip->set_number('5015414')->is_valid_number, '岐阜県高山市荘川町猿丸');
ok($zip->set_number('5015415')->is_valid_number, '岐阜県高山市荘川町一色');
ok($zip->set_number('5015416')->is_valid_number, '岐阜県高山市荘川町町屋');
ok($zip->set_number('5015417')->is_valid_number, '岐阜県高山市荘川町野々俣');
ok($zip->set_number('5015421')->is_valid_number, '岐阜県高山市荘川町赤谷');
ok($zip->set_number('5015422')->is_valid_number, '岐阜県高山市荘川町牛丸');
ok($zip->set_number('5015423')->is_valid_number, '岐阜県高山市荘川町岩瀬');
ok($zip->set_number('5015424')->is_valid_number, '岐阜県高山市荘川町中野');
ok($zip->set_number('5015425')->is_valid_number, '岐阜県高山市荘川町海上');
ok($zip->set_number('5015426')->is_valid_number, '岐阜県高山市荘川町尾上郷');
ok($zip->set_number('5015501')->is_valid_number, '岐阜県大野郡白川村保木脇');
ok($zip->set_number('5015502')->is_valid_number, '岐阜県大野郡白川村木谷');
ok($zip->set_number('5015503')->is_valid_number, '岐阜県大野郡白川村長瀬');
ok($zip->set_number('5015504')->is_valid_number, '岐阜県大野郡白川村福島');
ok($zip->set_number('5015505')->is_valid_number, '岐阜県大野郡白川村牧');
ok($zip->set_number('5015506')->is_valid_number, '岐阜県大野郡白川村御母衣');
ok($zip->set_number('5015507')->is_valid_number, '岐阜県大野郡白川村平瀬');
ok($zip->set_number('5015600')->is_valid_number, '岐阜県大野郡白川村以下に掲載がない場合');
ok($zip->set_number('5015620')->is_valid_number, '岐阜県大野郡白川村馬狩');
ok($zip->set_number('5015621')->is_valid_number, '岐阜県大野郡白川村小白川');
ok($zip->set_number('5015622')->is_valid_number, '岐阜県大野郡白川村芦倉');
ok($zip->set_number('5015623')->is_valid_number, '岐阜県大野郡白川村椿原');
ok($zip->set_number('5015624')->is_valid_number, '岐阜県大野郡白川村有家ケ原');
ok($zip->set_number('5015625')->is_valid_number, '岐阜県大野郡白川村飯島');
ok($zip->set_number('5015626')->is_valid_number, '岐阜県大野郡白川村島');
ok($zip->set_number('5015627')->is_valid_number, '岐阜県大野郡白川村荻町');
ok($zip->set_number('5015628')->is_valid_number, '岐阜県大野郡白川村大牧');
ok($zip->set_number('5015629')->is_valid_number, '岐阜県大野郡白川村鳩谷');
ok($zip->set_number('5016001')->is_valid_number, '岐阜県羽島郡岐南町上印食');
ok($zip->set_number('5016002')->is_valid_number, '岐阜県羽島郡岐南町三宅');
ok($zip->set_number('5016003')->is_valid_number, '岐阜県羽島郡岐南町平島');
ok($zip->set_number('5016004')->is_valid_number, '岐阜県羽島郡岐南町野中');
ok($zip->set_number('5016005')->is_valid_number, '岐阜県羽島郡岐南町若宮地');
ok($zip->set_number('5016006')->is_valid_number, '岐阜県羽島郡岐南町伏屋');
ok($zip->set_number('5016011')->is_valid_number, '岐阜県羽島郡岐南町八剣北');
ok($zip->set_number('5016012')->is_valid_number, '岐阜県羽島郡岐南町八剣');
ok($zip->set_number('5016013')->is_valid_number, '岐阜県羽島郡岐南町平成');
ok($zip->set_number('5016014')->is_valid_number, '岐阜県羽島郡岐南町薬師寺');
ok($zip->set_number('5016015')->is_valid_number, '岐阜県羽島郡岐南町石原瀬');
ok($zip->set_number('5016016')->is_valid_number, '岐阜県羽島郡岐南町徳田');
ok($zip->set_number('5016017')->is_valid_number, '岐阜県羽島郡岐南町徳田西');
ok($zip->set_number('5016018')->is_valid_number, '岐阜県羽島郡岐南町下印食');
ok($zip->set_number('5016019')->is_valid_number, '岐阜県羽島郡岐南町みやまち');
ok($zip->set_number('5016021')->is_valid_number, '岐阜県各務原市川島笠田町');
ok($zip->set_number('5016022')->is_valid_number, '岐阜県各務原市川島松倉町');
ok($zip->set_number('5016023')->is_valid_number, '岐阜県各務原市川島小網町');
ok($zip->set_number('5016024')->is_valid_number, '岐阜県各務原市川島竹早町');
ok($zip->set_number('5016025')->is_valid_number, '岐阜県各務原市川島河田町');
ok($zip->set_number('5016026')->is_valid_number, '岐阜県各務原市川島松原町');
ok($zip->set_number('5016027')->is_valid_number, '岐阜県各務原市川島緑町');
ok($zip->set_number('5016028')->is_valid_number, '岐阜県各務原市川島渡町');
ok($zip->set_number('5016029')->is_valid_number, '岐阜県各務原市川島北山町');
ok($zip->set_number('5016031')->is_valid_number, '岐阜県羽島郡笠松町米野');
ok($zip->set_number('5016032')->is_valid_number, '岐阜県羽島郡笠松町江川');
ok($zip->set_number('5016033')->is_valid_number, '岐阜県羽島郡笠松町無動寺');
ok($zip->set_number('5016034')->is_valid_number, '岐阜県羽島郡笠松町中野');
ok($zip->set_number('5016035')->is_valid_number, '岐阜県羽島郡笠松町円城寺');
ok($zip->set_number('5016036')->is_valid_number, '岐阜県羽島郡笠松町若葉町');
ok($zip->set_number('5016037')->is_valid_number, '岐阜県羽島郡笠松町西金池町');
ok($zip->set_number('5016038')->is_valid_number, '岐阜県羽島郡笠松町東金池町');
ok($zip->set_number('5016041')->is_valid_number, '岐阜県羽島郡笠松町奈良町');
ok($zip->set_number('5016042')->is_valid_number, '岐阜県羽島郡笠松町八幡町');
ok($zip->set_number('5016043')->is_valid_number, '岐阜県羽島郡笠松町県町');
ok($zip->set_number('5016044')->is_valid_number, '岐阜県羽島郡笠松町相生町');
ok($zip->set_number('5016045')->is_valid_number, '岐阜県羽島郡笠松町司町');
ok($zip->set_number('5016046')->is_valid_number, '岐阜県羽島郡笠松町宮川町');
ok($zip->set_number('5016047')->is_valid_number, '岐阜県羽島郡笠松町二見町');
ok($zip->set_number('5016051')->is_valid_number, '岐阜県羽島郡笠松町上本町');
ok($zip->set_number('5016052')->is_valid_number, '岐阜県羽島郡笠松町下本町');
ok($zip->set_number('5016053')->is_valid_number, '岐阜県羽島郡笠松町港町');
ok($zip->set_number('5016054')->is_valid_number, '岐阜県羽島郡笠松町柳原町');
ok($zip->set_number('5016055')->is_valid_number, '岐阜県羽島郡笠松町西町');
ok($zip->set_number('5016056')->is_valid_number, '岐阜県羽島郡笠松町朝日町');
ok($zip->set_number('5016057')->is_valid_number, '岐阜県羽島郡笠松町下柳川町');
ok($zip->set_number('5016058')->is_valid_number, '岐阜県羽島郡笠松町上柳川町');
ok($zip->set_number('5016059')->is_valid_number, '岐阜県羽島郡笠松町東宮町');
ok($zip->set_number('5016061')->is_valid_number, '岐阜県羽島郡笠松町泉町');
ok($zip->set_number('5016062')->is_valid_number, '岐阜県羽島郡笠松町田代');
ok($zip->set_number('5016063')->is_valid_number, '岐阜県羽島郡笠松町長池');
ok($zip->set_number('5016064')->is_valid_number, '岐阜県羽島郡笠松町北及');
ok($zip->set_number('5016065')->is_valid_number, '岐阜県羽島郡笠松町門間');
ok($zip->set_number('5016071')->is_valid_number, '岐阜県羽島郡笠松町上新町');
ok($zip->set_number('5016072')->is_valid_number, '岐阜県羽島郡笠松町中新町');
ok($zip->set_number('5016073')->is_valid_number, '岐阜県羽島郡笠松町下新町');
ok($zip->set_number('5016074')->is_valid_number, '岐阜県羽島郡笠松町新町');
ok($zip->set_number('5016075')->is_valid_number, '岐阜県羽島郡笠松町西宮町');
ok($zip->set_number('5016076')->is_valid_number, '岐阜県羽島郡笠松町門前町');
ok($zip->set_number('5016077')->is_valid_number, '岐阜県羽島郡笠松町天王町');
ok($zip->set_number('5016081')->is_valid_number, '岐阜県羽島郡笠松町東陽町');
ok($zip->set_number('5016082')->is_valid_number, '岐阜県羽島郡笠松町春日町');
ok($zip->set_number('5016083')->is_valid_number, '岐阜県羽島郡笠松町常盤町');
ok($zip->set_number('5016084')->is_valid_number, '岐阜県羽島郡笠松町如月町');
ok($zip->set_number('5016085')->is_valid_number, '岐阜県羽島郡笠松町弥生町');
ok($zip->set_number('5016086')->is_valid_number, '岐阜県羽島郡笠松町清住町');
ok($zip->set_number('5016087')->is_valid_number, '岐阜県羽島郡笠松町大池町');
ok($zip->set_number('5016088')->is_valid_number, '岐阜県羽島郡笠松町美笠通');
ok($zip->set_number('5016091')->is_valid_number, '岐阜県羽島郡笠松町松栄町');
ok($zip->set_number('5016092')->is_valid_number, '岐阜県羽島郡笠松町月美町');
ok($zip->set_number('5016093')->is_valid_number, '岐阜県羽島郡笠松町緑町');
ok($zip->set_number('5016094')->is_valid_number, '岐阜県羽島郡笠松町羽衣町');
ok($zip->set_number('5016095')->is_valid_number, '岐阜県羽島郡笠松町中川町');
ok($zip->set_number('5016096')->is_valid_number, '岐阜県羽島郡笠松町友楽町');
ok($zip->set_number('5016097')->is_valid_number, '岐阜県羽島郡笠松町瓢町');
ok($zip->set_number('5016098')->is_valid_number, '岐阜県羽島郡笠松町桜町');
ok($zip->set_number('5016100')->is_valid_number, '岐阜県羽島郡岐南町以下に掲載がない場合');
ok($zip->set_number('5016100')->is_valid_number, '岐阜県羽島郡笠松町以下に掲載がない場合');
ok($zip->set_number('5016101')->is_valid_number, '岐阜県岐阜市柳津町栄町');
ok($zip->set_number('5016102')->is_valid_number, '岐阜県岐阜市柳津町東塚');
ok($zip->set_number('5016103')->is_valid_number, '岐阜県岐阜市柳津町蓮池');
ok($zip->set_number('5016104')->is_valid_number, '岐阜県岐阜市柳津町本郷');
ok($zip->set_number('5016105')->is_valid_number, '岐阜県岐阜市柳津町梅松');
ok($zip->set_number('5016111')->is_valid_number, '岐阜県岐阜市柳津町宮東');
ok($zip->set_number('5016112')->is_valid_number, '岐阜県岐阜市柳津町北塚');
ok($zip->set_number('5016113')->is_valid_number, '岐阜県岐阜市柳津町南塚');
ok($zip->set_number('5016115')->is_valid_number, '岐阜県岐阜市柳津町丸野');
ok($zip->set_number('5016121')->is_valid_number, '岐阜県岐阜市柳津町上佐波');
ok($zip->set_number('5016121')->is_valid_number, '岐阜県岐阜市柳津町上佐波西');
ok($zip->set_number('5016121')->is_valid_number, '岐阜県岐阜市柳津町上佐波東');
ok($zip->set_number('5016121')->is_valid_number, '岐阜県岐阜市柳津町佐波');
ok($zip->set_number('5016121')->is_valid_number, '岐阜県岐阜市柳津町下佐波');
ok($zip->set_number('5016121')->is_valid_number, '岐阜県岐阜市柳津町下佐波西');
ok($zip->set_number('5016122')->is_valid_number, '岐阜県岐阜市柳津町高桑');
ok($zip->set_number('5016122')->is_valid_number, '岐阜県岐阜市柳津町高桑西');
ok($zip->set_number('5016122')->is_valid_number, '岐阜県岐阜市柳津町高桑東');
ok($zip->set_number('5016123')->is_valid_number, '岐阜県岐阜市柳津町流通センター');
ok($zip->set_number('5016131')->is_valid_number, '岐阜県岐阜市高河原');
ok($zip->set_number('5016132')->is_valid_number, '岐阜県岐阜市次木');
ok($zip->set_number('5016133')->is_valid_number, '岐阜県岐阜市日置江');
ok($zip->set_number('5016134')->is_valid_number, '岐阜県岐阜市大脇');
ok($zip->set_number('5016135')->is_valid_number, '岐阜県岐阜市茶屋新田');
ok($zip->set_number('5016200')->is_valid_number, '岐阜県羽島市以下に掲載がない場合');
ok($zip->set_number('5016201')->is_valid_number, '岐阜県羽島市足近町北宿');
ok($zip->set_number('5016202')->is_valid_number, '岐阜県羽島市足近町市場');
ok($zip->set_number('5016203')->is_valid_number, '岐阜県羽島市足近町南宿');
ok($zip->set_number('5016204')->is_valid_number, '岐阜県羽島市足近町小荒井');
ok($zip->set_number('5016205')->is_valid_number, '岐阜県羽島市足近町南之川');
ok($zip->set_number('5016206')->is_valid_number, '岐阜県羽島市新生町');
ok($zip->set_number('5016207')->is_valid_number, '岐阜県羽島市足近町');
ok($zip->set_number('5016208')->is_valid_number, '岐阜県羽島市足近町坂井');
ok($zip->set_number('5016209')->is_valid_number, '岐阜県羽島市足近町直道');
ok($zip->set_number('5016211')->is_valid_number, '岐阜県羽島市正木町南及');
ok($zip->set_number('5016212')->is_valid_number, '岐阜県羽島市正木町上大浦');
ok($zip->set_number('5016213')->is_valid_number, '岐阜県羽島市正木町光法寺');
ok($zip->set_number('5016214')->is_valid_number, '岐阜県羽島市正木町須賀池端');
ok($zip->set_number('5016215')->is_valid_number, '岐阜県羽島市正木町須賀赤松');
ok($zip->set_number('5016216')->is_valid_number, '岐阜県羽島市正木町須賀');
ok($zip->set_number('5016217')->is_valid_number, '岐阜県羽島市正木町須賀小松');
ok($zip->set_number('5016218')->is_valid_number, '岐阜県羽島市正木町須賀本村');
ok($zip->set_number('5016221')->is_valid_number, '岐阜県羽島市正木町森');
ok($zip->set_number('5016222')->is_valid_number, '岐阜県羽島市正木町森新田');
ok($zip->set_number('5016223')->is_valid_number, '岐阜県羽島市正木町大浦新田');
ok($zip->set_number('5016224')->is_valid_number, '岐阜県羽島市正木町大浦');
ok($zip->set_number('5016225')->is_valid_number, '岐阜県羽島市正木町新井');
ok($zip->set_number('5016226')->is_valid_number, '岐阜県羽島市正木町三ツ柳');
ok($zip->set_number('5016227')->is_valid_number, '岐阜県羽島市正木町曲利');
ok($zip->set_number('5016228')->is_valid_number, '岐阜県羽島市正木町不破一色');
ok($zip->set_number('5016229')->is_valid_number, '岐阜県羽島市正木町坂丸');
ok($zip->set_number('5016231')->is_valid_number, '岐阜県羽島市竹鼻町神楽');
ok($zip->set_number('5016232')->is_valid_number, '岐阜県羽島市竹鼻町狐穴');
ok($zip->set_number('5016233')->is_valid_number, '岐阜県羽島市竹鼻町飯柄');
ok($zip->set_number('5016234')->is_valid_number, '岐阜県羽島市竹鼻町駒塚');
ok($zip->set_number('5016235')->is_valid_number, '岐阜県羽島市竹鼻町蜂尻');
ok($zip->set_number('5016236')->is_valid_number, '岐阜県羽島市江吉良町');
ok($zip->set_number('5016237')->is_valid_number, '岐阜県羽島市江吉良町江西');
ok($zip->set_number('5016238')->is_valid_number, '岐阜県羽島市江吉良町江中');
ok($zip->set_number('5016239')->is_valid_number, '岐阜県羽島市江吉良町江南');
ok($zip->set_number('5016241')->is_valid_number, '岐阜県羽島市竹鼻町');
ok($zip->set_number('5016242')->is_valid_number, '岐阜県羽島市竹鼻町錦町');
ok($zip->set_number('5016243')->is_valid_number, '岐阜県羽島市竹鼻町西野町');
ok($zip->set_number('5016244')->is_valid_number, '岐阜県羽島市竹鼻町丸の内');
ok($zip->set_number('5016251')->is_valid_number, '岐阜県羽島市福寿町間島');
ok($zip->set_number('5016252')->is_valid_number, '岐阜県羽島市小熊町島前');
ok($zip->set_number('5016253')->is_valid_number, '岐阜県羽島市小熊町島新道');
ok($zip->set_number('5016254')->is_valid_number, '岐阜県羽島市福寿町本郷');
ok($zip->set_number('5016255')->is_valid_number, '岐阜県羽島市福寿町浅平');
ok($zip->set_number('5016256')->is_valid_number, '岐阜県羽島市福寿町千代田');
ok($zip->set_number('5016257')->is_valid_number, '岐阜県羽島市福寿町平方');
ok($zip->set_number('5016261')->is_valid_number, '岐阜県羽島市小熊町外粟野');
ok($zip->set_number('5016262')->is_valid_number, '岐阜県羽島市小熊町内粟野');
ok($zip->set_number('5016263')->is_valid_number, '岐阜県羽島市小熊町江頭');
ok($zip->set_number('5016264')->is_valid_number, '岐阜県羽島市小熊町島');
ok($zip->set_number('5016265')->is_valid_number, '岐阜県羽島市小熊町川口前');
ok($zip->set_number('5016266')->is_valid_number, '岐阜県羽島市小熊町川口');
ok($zip->set_number('5016267')->is_valid_number, '岐阜県羽島市小熊町天王');
ok($zip->set_number('5016271')->is_valid_number, '岐阜県羽島市小熊町東小熊');
ok($zip->set_number('5016272')->is_valid_number, '岐阜県羽島市小熊町相田');
ok($zip->set_number('5016273')->is_valid_number, '岐阜県羽島市小熊町');
ok($zip->set_number('5016274')->is_valid_number, '岐阜県羽島市小熊町西小熊');
ok($zip->set_number('5016301')->is_valid_number, '岐阜県羽島市舟橋町宮北');
ok($zip->set_number('5016302')->is_valid_number, '岐阜県羽島市舟橋町');
ok($zip->set_number('5016303')->is_valid_number, '岐阜県羽島市舟橋町本町');
ok($zip->set_number('5016304')->is_valid_number, '岐阜県羽島市舟橋町出須賀');
ok($zip->set_number('5016311')->is_valid_number, '岐阜県羽島市上中町長間');
ok($zip->set_number('5016312')->is_valid_number, '岐阜県羽島市上中町一色');
ok($zip->set_number('5016313')->is_valid_number, '岐阜県羽島市下中町加賀野井');
ok($zip->set_number('5016314')->is_valid_number, '岐阜県羽島市下中町城屋敷');
ok($zip->set_number('5016315')->is_valid_number, '岐阜県羽島市下中町石田');
ok($zip->set_number('5016316')->is_valid_number, '岐阜県羽島市下中町市之枝');
ok($zip->set_number('5016317')->is_valid_number, '岐阜県羽島市上中町午北');
ok($zip->set_number('5016318')->is_valid_number, '岐阜県羽島市上中町沖');
ok($zip->set_number('5016319')->is_valid_number, '岐阜県羽島市上中町中');
ok($zip->set_number('5016321')->is_valid_number, '岐阜県羽島市桑原町八神');
ok($zip->set_number('5016322')->is_valid_number, '岐阜県羽島市桑原町前野');
ok($zip->set_number('5016323')->is_valid_number, '岐阜県羽島市桑原町午南');
ok($zip->set_number('5016324')->is_valid_number, '岐阜県羽島市桑原町小薮');
ok($zip->set_number('5016325')->is_valid_number, '岐阜県羽島市桑原町大須');
ok($zip->set_number('5016326')->is_valid_number, '岐阜県羽島市桑原町東方');
ok($zip->set_number('5016327')->is_valid_number, '岐阜県羽島市桑原町西小薮');
ok($zip->set_number('5016328')->is_valid_number, '岐阜県羽島市桑原町平太');
ok($zip->set_number('5016330')->is_valid_number, '岐阜県羽島市堀津町(その他)');
ok($zip->set_number('5016331')->is_valid_number, '岐阜県羽島市堀津町横手');
ok($zip->set_number('5016332')->is_valid_number, '岐阜県羽島市堀津町須賀北');
ok($zip->set_number('5016333')->is_valid_number, '岐阜県羽島市堀津町東山');
ok($zip->set_number('5016334')->is_valid_number, '岐阜県羽島市堀津町前谷');
ok($zip->set_number('5016335')->is_valid_number, '岐阜県羽島市堀津町須賀南');
ok($zip->set_number('5016336')->is_valid_number, '岐阜県羽島市堀津町須賀西');
ok($zip->set_number('5016337')->is_valid_number, '岐阜県羽島市堀津町中屋敷');
ok($zip->set_number('5016338')->is_valid_number, '岐阜県羽島市堀津町須賀中');
ok($zip->set_number('5020001')->is_valid_number, '岐阜県岐阜市粟野');
ok($zip->set_number('5020002')->is_valid_number, '岐阜県岐阜市粟野東');
ok($zip->set_number('5020003')->is_valid_number, '岐阜県岐阜市三田洞東');
ok($zip->set_number('5020004')->is_valid_number, '岐阜県岐阜市三田洞');
ok($zip->set_number('5020005')->is_valid_number, '岐阜県岐阜市岩崎');
ok($zip->set_number('5020006')->is_valid_number, '岐阜県岐阜市粟野西');
ok($zip->set_number('5020007')->is_valid_number, '岐阜県岐阜市粟野台');
ok($zip->set_number('5020011')->is_valid_number, '岐阜県岐阜市長良古津');
ok($zip->set_number('5020012')->is_valid_number, '岐阜県岐阜市長良志段見');
ok($zip->set_number('5020013')->is_valid_number, '岐阜県岐阜市中川原');
ok($zip->set_number('5020014')->is_valid_number, '岐阜県岐阜市雄総緑町');
ok($zip->set_number('5020015')->is_valid_number, '岐阜県岐阜市雄総柳町');
ok($zip->set_number('5020016')->is_valid_number, '岐阜県岐阜市雄総桜町');
ok($zip->set_number('5020017')->is_valid_number, '岐阜県岐阜市長良雄総');
ok($zip->set_number('5020021')->is_valid_number, '岐阜県岐阜市西後町');
ok($zip->set_number('5020022')->is_valid_number, '岐阜県岐阜市長良東郷町');
ok($zip->set_number('5020023')->is_valid_number, '岐阜県岐阜市城前町');
ok($zip->set_number('5020024')->is_valid_number, '岐阜県岐阜市堀田町');
ok($zip->set_number('5020025')->is_valid_number, '岐阜県岐阜市山先町');
ok($zip->set_number('5020026')->is_valid_number, '岐阜県岐阜市長良桜井町');
ok($zip->set_number('5020027')->is_valid_number, '岐阜県岐阜市長良宮口町');
ok($zip->set_number('5020028')->is_valid_number, '岐阜県岐阜市長良白妙町');
ok($zip->set_number('5020029')->is_valid_number, '岐阜県岐阜市長良若葉町');
ok($zip->set_number('5020031')->is_valid_number, '岐阜県岐阜市長良大路');
ok($zip->set_number('5020032')->is_valid_number, '岐阜県岐阜市長良高嶺町');
ok($zip->set_number('5020033')->is_valid_number, '岐阜県岐阜市長良有楽町');
ok($zip->set_number('5020034')->is_valid_number, '岐阜県岐阜市長良有明町');
ok($zip->set_number('5020035')->is_valid_number, '岐阜県岐阜市長良南陽町');
ok($zip->set_number('5020036')->is_valid_number, '岐阜県岐阜市長良大前町');
ok($zip->set_number('5020037')->is_valid_number, '岐阜県岐阜市長良金碧町');
ok($zip->set_number('5020038')->is_valid_number, '岐阜県岐阜市長良法久寺町');
ok($zip->set_number('5020041')->is_valid_number, '岐阜県岐阜市長良海用町');
ok($zip->set_number('5020042')->is_valid_number, '岐阜県岐阜市長良城西町');
ok($zip->set_number('5020043')->is_valid_number, '岐阜県岐阜市長良東町');
ok($zip->set_number('5020044')->is_valid_number, '岐阜県岐阜市長良校文町');
ok($zip->set_number('5020045')->is_valid_number, '岐阜県岐阜市長良校前町');
ok($zip->set_number('5020046')->is_valid_number, '岐阜県岐阜市長良杉乃町');
ok($zip->set_number('5020047')->is_valid_number, '岐阜県岐阜市長良葵町');
ok($zip->set_number('5020051')->is_valid_number, '岐阜県岐阜市長良幸和町');
ok($zip->set_number('5020052')->is_valid_number, '岐阜県岐阜市長良小松町');
ok($zip->set_number('5020053')->is_valid_number, '岐阜県岐阜市長良宮路町');
ok($zip->set_number('5020054')->is_valid_number, '岐阜県岐阜市長良井田');
ok($zip->set_number('5020055')->is_valid_number, '岐阜県岐阜市長良福江町');
ok($zip->set_number('5020056')->is_valid_number, '岐阜県岐阜市長良真生町');
ok($zip->set_number('5020061')->is_valid_number, '岐阜県岐阜市長良竜東町');
ok($zip->set_number('5020062')->is_valid_number, '岐阜県岐阜市長良春田');
ok($zip->set_number('5020063')->is_valid_number, '岐阜県岐阜市長良一楽');
ok($zip->set_number('5020064')->is_valid_number, '岐阜県岐阜市長良田中前');
ok($zip->set_number('5020065')->is_valid_number, '岐阜県岐阜市長良森町');
ok($zip->set_number('5020066')->is_valid_number, '岐阜県岐阜市長良仙田町');
ok($zip->set_number('5020067')->is_valid_number, '岐阜県岐阜市長良西野前');
ok($zip->set_number('5020071')->is_valid_number, '岐阜県岐阜市長良(番地)');
ok($zip->set_number('5020072')->is_valid_number, '岐阜県岐阜市長良福泉');
ok($zip->set_number('5020073')->is_valid_number, '岐阜県岐阜市長良田中');
ok($zip->set_number('5020074')->is_valid_number, '岐阜県岐阜市長良西山前');
ok($zip->set_number('5020075')->is_valid_number, '岐阜県岐阜市長良子正賀');
ok($zip->set_number('5020076')->is_valid_number, '岐阜県岐阜市長良友瀬');
ok($zip->set_number('5020077')->is_valid_number, '岐阜県岐阜市長良奥郷');
ok($zip->set_number('5020081')->is_valid_number, '岐阜県岐阜市長良(丁目)');
ok($zip->set_number('5020082')->is_valid_number, '岐阜県岐阜市長良東');
ok($zip->set_number('5020801')->is_valid_number, '岐阜県岐阜市椿洞');
ok($zip->set_number('5020802')->is_valid_number, '岐阜県岐阜市打越');
ok($zip->set_number('5020803')->is_valid_number, '岐阜県岐阜市上土居');
ok($zip->set_number('5020811')->is_valid_number, '岐阜県岐阜市若福町');
ok($zip->set_number('5020812')->is_valid_number, '岐阜県岐阜市八代');
ok($zip->set_number('5020813')->is_valid_number, '岐阜県岐阜市福光東');
ok($zip->set_number('5020814')->is_valid_number, '岐阜県岐阜市福光西');
ok($zip->set_number('5020815')->is_valid_number, '岐阜県岐阜市福光南町');
ok($zip->set_number('5020816')->is_valid_number, '岐阜県岐阜市道三町');
ok($zip->set_number('5020817')->is_valid_number, '岐阜県岐阜市長良福光');
ok($zip->set_number('5020821')->is_valid_number, '岐阜県岐阜市太平町');
ok($zip->set_number('5020822')->is_valid_number, '岐阜県岐阜市福田町');
ok($zip->set_number('5020823')->is_valid_number, '岐阜県岐阜市光栄町');
ok($zip->set_number('5020824')->is_valid_number, '岐阜県岐阜市花ノ木町');
ok($zip->set_number('5020825')->is_valid_number, '岐阜県岐阜市初日町');
ok($zip->set_number('5020826')->is_valid_number, '岐阜県岐阜市楠町');
ok($zip->set_number('5020827')->is_valid_number, '岐阜県岐阜市平和通');
ok($zip->set_number('5020828')->is_valid_number, '岐阜県岐阜市金華町');
ok($zip->set_number('5020829')->is_valid_number, '岐阜県岐阜市万代町');
ok($zip->set_number('5020831')->is_valid_number, '岐阜県岐阜市菊水町');
ok($zip->set_number('5020832')->is_valid_number, '岐阜県岐阜市千代田町');
ok($zip->set_number('5020833')->is_valid_number, '岐阜県岐阜市松風町');
ok($zip->set_number('5020834')->is_valid_number, '岐阜県岐阜市養老町');
ok($zip->set_number('5020835')->is_valid_number, '岐阜県岐阜市織田町');
ok($zip->set_number('5020836')->is_valid_number, '岐阜県岐阜市若竹町');
ok($zip->set_number('5020837')->is_valid_number, '岐阜県岐阜市鵜川町');
ok($zip->set_number('5020838')->is_valid_number, '岐阜県岐阜市長良丘');
ok($zip->set_number('5020841')->is_valid_number, '岐阜県岐阜市学園町');
ok($zip->set_number('5020842')->is_valid_number, '岐阜県岐阜市早田(その他)');
ok($zip->set_number('5020843')->is_valid_number, '岐阜県岐阜市早田東町');
ok($zip->set_number('5020844')->is_valid_number, '岐阜県岐阜市岩倉町');
ok($zip->set_number('5020845')->is_valid_number, '岐阜県岐阜市早田町');
ok($zip->set_number('5020846')->is_valid_number, '岐阜県岐阜市津島町');
ok($zip->set_number('5020847')->is_valid_number, '岐阜県岐阜市早田栄町');
ok($zip->set_number('5020848')->is_valid_number, '岐阜県岐阜市早田本町');
ok($zip->set_number('5020849')->is_valid_number, '岐阜県岐阜市栄新町');
ok($zip->set_number('5020850')->is_valid_number, '岐阜県岐阜市鷺山東');
ok($zip->set_number('5020851')->is_valid_number, '岐阜県岐阜市鷺山');
ok($zip->set_number('5020852')->is_valid_number, '岐阜県岐阜市南蝉');
ok($zip->set_number('5020853')->is_valid_number, '岐阜県岐阜市鷺山清洲町');
ok($zip->set_number('5020854')->is_valid_number, '岐阜県岐阜市鷺山向井町');
ok($zip->set_number('5020855')->is_valid_number, '岐阜県岐阜市鷺山緑ケ丘');
ok($zip->set_number('5020856')->is_valid_number, '岐阜県岐阜市鷺山緑ケ丘新町');
ok($zip->set_number('5020857')->is_valid_number, '岐阜県岐阜市正木');
ok($zip->set_number('5020858')->is_valid_number, '岐阜県岐阜市下土居');
ok($zip->set_number('5020859')->is_valid_number, '岐阜県岐阜市城田寺');
ok($zip->set_number('5020861')->is_valid_number, '岐阜県岐阜市上城田寺南');
ok($zip->set_number('5020862')->is_valid_number, '岐阜県岐阜市上城田寺中');
ok($zip->set_number('5020863')->is_valid_number, '岐阜県岐阜市上城田寺西');
ok($zip->set_number('5020864')->is_valid_number, '岐阜県岐阜市上城田寺東');
ok($zip->set_number('5020865')->is_valid_number, '岐阜県岐阜市正木西町');
ok($zip->set_number('5020866')->is_valid_number, '岐阜県岐阜市正木南');
ok($zip->set_number('5020867')->is_valid_number, '岐阜県岐阜市鷺山南');
ok($zip->set_number('5020871')->is_valid_number, '岐阜県岐阜市鷺山新町');
ok($zip->set_number('5020872')->is_valid_number, '岐阜県岐阜市鷺山北町');
ok($zip->set_number('5020881')->is_valid_number, '岐阜県岐阜市正木北町');
ok($zip->set_number('5020882')->is_valid_number, '岐阜県岐阜市正木中');
ok($zip->set_number('5020901')->is_valid_number, '岐阜県岐阜市光町');
ok($zip->set_number('5020902')->is_valid_number, '岐阜県岐阜市早田大通');
ok($zip->set_number('5020903')->is_valid_number, '岐阜県岐阜市美島町');
ok($zip->set_number('5020904')->is_valid_number, '岐阜県岐阜市島栄町');
ok($zip->set_number('5020905')->is_valid_number, '岐阜県岐阜市山吹町');
ok($zip->set_number('5020906')->is_valid_number, '岐阜県岐阜市池ノ上町');
ok($zip->set_number('5020907')->is_valid_number, '岐阜県岐阜市島新町');
ok($zip->set_number('5020908')->is_valid_number, '岐阜県岐阜市近島');
ok($zip->set_number('5020909')->is_valid_number, '岐阜県岐阜市白菊町');
ok($zip->set_number('5020911')->is_valid_number, '岐阜県岐阜市北島');
ok($zip->set_number('5020912')->is_valid_number, '岐阜県岐阜市西島町');
ok($zip->set_number('5020913')->is_valid_number, '岐阜県岐阜市東島');
ok($zip->set_number('5020914')->is_valid_number, '岐阜県岐阜市菅生');
ok($zip->set_number('5020915')->is_valid_number, '岐阜県岐阜市江口');
ok($zip->set_number('5020916')->is_valid_number, '岐阜県岐阜市西中島');
ok($zip->set_number('5020917')->is_valid_number, '岐阜県岐阜市島田');
ok($zip->set_number('5020921')->is_valid_number, '岐阜県岐阜市守口町');
ok($zip->set_number('5020922')->is_valid_number, '岐阜県岐阜市明神町');
ok($zip->set_number('5020923')->is_valid_number, '岐阜県岐阜市宮浦町');
ok($zip->set_number('5020924')->is_valid_number, '岐阜県岐阜市旦島宮町');
ok($zip->set_number('5020925')->is_valid_number, '岐阜県岐阜市旦島中町');
ok($zip->set_number('5020926')->is_valid_number, '岐阜県岐阜市旦島');
ok($zip->set_number('5020927')->is_valid_number, '岐阜県岐阜市旦島西町');
ok($zip->set_number('5020928')->is_valid_number, '岐阜県岐阜市旦島中');
ok($zip->set_number('5020929')->is_valid_number, '岐阜県岐阜市則武東');
ok($zip->set_number('5020931')->is_valid_number, '岐阜県岐阜市則武');
ok($zip->set_number('5020932')->is_valid_number, '岐阜県岐阜市則武中');
ok($zip->set_number('5020933')->is_valid_number, '岐阜県岐阜市日光町');
ok($zip->set_number('5020934')->is_valid_number, '岐阜県岐阜市大福町');
ok($zip->set_number('5020935')->is_valid_number, '岐阜県岐阜市萱場東町');
ok($zip->set_number('5020936')->is_valid_number, '岐阜県岐阜市萱場南');
ok($zip->set_number('5020937')->is_valid_number, '岐阜県岐阜市萱場町');
ok($zip->set_number('5020938')->is_valid_number, '岐阜県岐阜市萱場北町');
ok($zip->set_number('5020939')->is_valid_number, '岐阜県岐阜市則武西');
ok($zip->set_number('5030000')->is_valid_number, '岐阜県大垣市以下に掲載がない場合');
ok($zip->set_number('5030001')->is_valid_number, '岐阜県大垣市大島町');
ok($zip->set_number('5030002')->is_valid_number, '岐阜県大垣市開発町');
ok($zip->set_number('5030003')->is_valid_number, '岐阜県大垣市津村町');
ok($zip->set_number('5030004')->is_valid_number, '岐阜県大垣市新開町');
ok($zip->set_number('5030005')->is_valid_number, '岐阜県大垣市和合本町');
ok($zip->set_number('5030006')->is_valid_number, '岐阜県大垣市加賀野');
ok($zip->set_number('5030007')->is_valid_number, '岐阜県大垣市貝曽根町');
ok($zip->set_number('5030008')->is_valid_number, '岐阜県大垣市楽田町');
ok($zip->set_number('5030009')->is_valid_number, '岐阜県大垣市坂下町');
ok($zip->set_number('5030011')->is_valid_number, '岐阜県大垣市曽根町');
ok($zip->set_number('5030012')->is_valid_number, '岐阜県大垣市三津屋町');
ok($zip->set_number('5030013')->is_valid_number, '岐阜県大垣市赤花町');
ok($zip->set_number('5030014')->is_valid_number, '岐阜県大垣市領家町');
ok($zip->set_number('5030015')->is_valid_number, '岐阜県大垣市林町');
ok($zip->set_number('5030016')->is_valid_number, '岐阜県大垣市八島町');
ok($zip->set_number('5030017')->is_valid_number, '岐阜県大垣市中川町');
ok($zip->set_number('5030018')->is_valid_number, '岐阜県大垣市西之川町');
ok($zip->set_number('5030019')->is_valid_number, '岐阜県大垣市北方町');
ok($zip->set_number('5030021')->is_valid_number, '岐阜県大垣市河間町');
ok($zip->set_number('5030022')->is_valid_number, '岐阜県大垣市中野町');
ok($zip->set_number('5030023')->is_valid_number, '岐阜県大垣市笠木町');
ok($zip->set_number('5030024')->is_valid_number, '岐阜県大垣市宿地町');
ok($zip->set_number('5030025')->is_valid_number, '岐阜県大垣市見取町');
ok($zip->set_number('5030026')->is_valid_number, '岐阜県大垣市室村町');
ok($zip->set_number('5030027')->is_valid_number, '岐阜県大垣市笠縫町');
ok($zip->set_number('5030031')->is_valid_number, '岐阜県大垣市牧野町');
ok($zip->set_number('5030032')->is_valid_number, '岐阜県大垣市熊野町');
ok($zip->set_number('5030033')->is_valid_number, '岐阜県大垣市福田町');
ok($zip->set_number('5030034')->is_valid_number, '岐阜県大垣市荒尾町');
ok($zip->set_number('5030035')->is_valid_number, '岐阜県大垣市荒尾玉池');
ok($zip->set_number('5030036')->is_valid_number, '岐阜県大垣市古知丸');
ok($zip->set_number('5030100')->is_valid_number, '岐阜県安八郡安八町以下に掲載がない場合');
ok($zip->set_number('5030101')->is_valid_number, '岐阜県大垣市墨俣町先入方');
ok($zip->set_number('5030102')->is_valid_number, '岐阜県大垣市墨俣町墨俣');
ok($zip->set_number('5030103')->is_valid_number, '岐阜県大垣市墨俣町上宿');
ok($zip->set_number('5030104')->is_valid_number, '岐阜県大垣市墨俣町下宿');
ok($zip->set_number('5030105')->is_valid_number, '岐阜県大垣市墨俣町二ツ木');
ok($zip->set_number('5030106')->is_valid_number, '岐阜県大垣市墨俣町さい川');
ok($zip->set_number('5030111')->is_valid_number, '岐阜県安八郡安八町西結');
ok($zip->set_number('5030112')->is_valid_number, '岐阜県安八郡安八町芝原');
ok($zip->set_number('5030112')->is_valid_number, '岐阜県安八郡安八町東結');
ok($zip->set_number('5030113')->is_valid_number, '岐阜県安八郡安八町北今ケ渕');
ok($zip->set_number('5030114')->is_valid_number, '岐阜県安八郡安八町森部');
ok($zip->set_number('5030115')->is_valid_number, '岐阜県安八郡安八町南今ケ渕');
ok($zip->set_number('5030116')->is_valid_number, '岐阜県安八郡安八町大森');
ok($zip->set_number('5030117')->is_valid_number, '岐阜県安八郡安八町大明神');
ok($zip->set_number('5030118')->is_valid_number, '岐阜県安八郡安八町宝江');
ok($zip->set_number('5030121')->is_valid_number, '岐阜県安八郡安八町氷取');
ok($zip->set_number('5030122')->is_valid_number, '岐阜県安八郡安八町善光');
ok($zip->set_number('5030123')->is_valid_number, '岐阜県安八郡安八町南條');
ok($zip->set_number('5030124')->is_valid_number, '岐阜県安八郡安八町中');
ok($zip->set_number('5030125')->is_valid_number, '岐阜県安八郡安八町牧');
ok($zip->set_number('5030126')->is_valid_number, '岐阜県安八郡安八町中須');
ok($zip->set_number('5030127')->is_valid_number, '岐阜県安八郡安八町城');
ok($zip->set_number('5030128')->is_valid_number, '岐阜県安八郡安八町大野');
ok($zip->set_number('5030129')->is_valid_number, '岐阜県安八郡安八町外善光');
ok($zip->set_number('5030141')->is_valid_number, '岐阜県大垣市平町(揖斐川東)');
ok($zip->set_number('5030200')->is_valid_number, '岐阜県安八郡輪之内町以下に掲載がない場合');
ok($zip->set_number('5030201')->is_valid_number, '岐阜県安八郡輪之内町楡俣');
ok($zip->set_number('5030202')->is_valid_number, '岐阜県安八郡輪之内町大藪');
ok($zip->set_number('5030203')->is_valid_number, '岐阜県安八郡輪之内町楡俣新田');
ok($zip->set_number('5030204')->is_valid_number, '岐阜県安八郡輪之内町四郷');
ok($zip->set_number('5030205')->is_valid_number, '岐阜県安八郡輪之内町下大榑');
ok($zip->set_number('5030206')->is_valid_number, '岐阜県安八郡輪之内町下大榑新田');
ok($zip->set_number('5030211')->is_valid_number, '岐阜県安八郡輪之内町福束新田');
ok($zip->set_number('5030212')->is_valid_number, '岐阜県安八郡輪之内町中郷新田');
ok($zip->set_number('5030213')->is_valid_number, '岐阜県安八郡輪之内町藻池新田');
ok($zip->set_number('5030214')->is_valid_number, '岐阜県安八郡輪之内町海松新田');
ok($zip->set_number('5030215')->is_valid_number, '岐阜県安八郡輪之内町松内');
ok($zip->set_number('5030216')->is_valid_number, '岐阜県安八郡輪之内町大吉新田');
ok($zip->set_number('5030231')->is_valid_number, '岐阜県安八郡輪之内町南波');
ok($zip->set_number('5030232')->is_valid_number, '岐阜県安八郡輪之内町本戸');
ok($zip->set_number('5030233')->is_valid_number, '岐阜県安八郡輪之内町中郷');
ok($zip->set_number('5030234')->is_valid_number, '岐阜県安八郡輪之内町里');
ok($zip->set_number('5030235')->is_valid_number, '岐阜県安八郡輪之内町福束');
ok($zip->set_number('5030236')->is_valid_number, '岐阜県安八郡輪之内町塩喰');
ok($zip->set_number('5030301')->is_valid_number, '岐阜県海津市平田町須賀');
ok($zip->set_number('5030302')->is_valid_number, '岐阜県海津市平田町勝賀');
ok($zip->set_number('5030303')->is_valid_number, '岐阜県海津市平田町野寺');
ok($zip->set_number('5030304')->is_valid_number, '岐阜県海津市平田町幡長');
ok($zip->set_number('5030305')->is_valid_number, '岐阜県海津市平田町者結');
ok($zip->set_number('5030306')->is_valid_number, '岐阜県海津市平田町蛇池');
ok($zip->set_number('5030307')->is_valid_number, '岐阜県海津市平田町岡');
ok($zip->set_number('5030311')->is_valid_number, '岐阜県海津市平田町仏師川');
ok($zip->set_number('5030312')->is_valid_number, '岐阜県海津市平田町三郷');
ok($zip->set_number('5030313')->is_valid_number, '岐阜県海津市平田町高田');
ok($zip->set_number('5030314')->is_valid_number, '岐阜県海津市平田町西島');
ok($zip->set_number('5030321')->is_valid_number, '岐阜県海津市平田町今尾');
ok($zip->set_number('5030322')->is_valid_number, '岐阜県海津市平田町土倉');
ok($zip->set_number('5030323')->is_valid_number, '岐阜県海津市平田町脇野');
ok($zip->set_number('5030401')->is_valid_number, '岐阜県海津市南濃町津屋');
ok($zip->set_number('5030402')->is_valid_number, '岐阜県海津市南濃町志津新田');
ok($zip->set_number('5030403')->is_valid_number, '岐阜県海津市南濃町志津');
ok($zip->set_number('5030404')->is_valid_number, '岐阜県海津市南濃町早瀬');
ok($zip->set_number('5030405')->is_valid_number, '岐阜県海津市南濃町駒野新田');
ok($zip->set_number('5030406')->is_valid_number, '岐阜県海津市南濃町戸田');
ok($zip->set_number('5030407')->is_valid_number, '岐阜県海津市南濃町徳田');
ok($zip->set_number('5030408')->is_valid_number, '岐阜県海津市南濃町庭田');
ok($zip->set_number('5030411')->is_valid_number, '岐阜県海津市南濃町駒野');
ok($zip->set_number('5030412')->is_valid_number, '岐阜県海津市南濃町奥条');
ok($zip->set_number('5030413')->is_valid_number, '岐阜県海津市南濃町羽沢');
ok($zip->set_number('5030414')->is_valid_number, '岐阜県海津市南濃町上野河戸');
ok($zip->set_number('5030415')->is_valid_number, '岐阜県海津市南濃町山崎');
ok($zip->set_number('5030531')->is_valid_number, '岐阜県海津市南濃町安江');
ok($zip->set_number('5030532')->is_valid_number, '岐阜県海津市南濃町太田');
ok($zip->set_number('5030533')->is_valid_number, '岐阜県海津市南濃町田鶴');
ok($zip->set_number('5030534')->is_valid_number, '岐阜県海津市南濃町境');
ok($zip->set_number('5030535')->is_valid_number, '岐阜県海津市南濃町松山');
ok($zip->set_number('5030536')->is_valid_number, '岐阜県海津市南濃町吉田');
ok($zip->set_number('5030600')->is_valid_number, '岐阜県海津市以下に掲載がない場合');
ok($zip->set_number('5030601')->is_valid_number, '岐阜県海津市海津町松木');
ok($zip->set_number('5030602')->is_valid_number, '岐阜県海津市海津町瀬古');
ok($zip->set_number('5030603')->is_valid_number, '岐阜県海津市海津町神桐');
ok($zip->set_number('5030604')->is_valid_number, '岐阜県海津市海津町成戸');
ok($zip->set_number('5030605')->is_valid_number, '岐阜県海津市海津町福一色');
ok($zip->set_number('5030606')->is_valid_number, '岐阜県海津市海津町田中');
ok($zip->set_number('5030608')->is_valid_number, '岐阜県海津市海津町鹿野');
ok($zip->set_number('5030611')->is_valid_number, '岐阜県海津市海津町秋江');
ok($zip->set_number('5030612')->is_valid_number, '岐阜県海津市海津町大和田');
ok($zip->set_number('5030613')->is_valid_number, '岐阜県海津市海津町駒ケ江');
ok($zip->set_number('5030614')->is_valid_number, '岐阜県海津市海津町長瀬');
ok($zip->set_number('5030615')->is_valid_number, '岐阜県海津市海津町日原');
ok($zip->set_number('5030616')->is_valid_number, '岐阜県海津市海津町長久保');
ok($zip->set_number('5030617')->is_valid_number, '岐阜県海津市海津町立野');
ok($zip->set_number('5030618')->is_valid_number, '岐阜県海津市海津町草場');
ok($zip->set_number('5030621')->is_valid_number, '岐阜県海津市海津町外浜');
ok($zip->set_number('5030622')->is_valid_number, '岐阜県海津市海津町森下');
ok($zip->set_number('5030623')->is_valid_number, '岐阜県海津市海津町古中島');
ok($zip->set_number('5030624')->is_valid_number, '岐阜県海津市海津町金廻');
ok($zip->set_number('5030625')->is_valid_number, '岐阜県海津市海津町油島');
ok($zip->set_number('5030626')->is_valid_number, '岐阜県海津市海津町万寿新田');
ok($zip->set_number('5030627')->is_valid_number, '岐阜県海津市海津町七右衛門新田');
ok($zip->set_number('5030628')->is_valid_number, '岐阜県海津市海津町福江');
ok($zip->set_number('5030629')->is_valid_number, '岐阜県海津市海津町石亀');
ok($zip->set_number('5030631')->is_valid_number, '岐阜県海津市海津町稲山');
ok($zip->set_number('5030632')->is_valid_number, '岐阜県海津市海津町宮地');
ok($zip->set_number('5030633')->is_valid_number, '岐阜県海津市海津町本阿弥新田');
ok($zip->set_number('5030634')->is_valid_number, '岐阜県海津市海津町沼新田');
ok($zip->set_number('5030635')->is_valid_number, '岐阜県海津市海津町江東');
ok($zip->set_number('5030636')->is_valid_number, '岐阜県海津市海津町帆引新田');
ok($zip->set_number('5030637')->is_valid_number, '岐阜県海津市海津町安田');
ok($zip->set_number('5030638')->is_valid_number, '岐阜県海津市海津町安田新田');
ok($zip->set_number('5030641')->is_valid_number, '岐阜県海津市海津町内記');
ok($zip->set_number('5030643')->is_valid_number, '岐阜県海津市海津町札野');
ok($zip->set_number('5030644')->is_valid_number, '岐阜県海津市海津町深浜');
ok($zip->set_number('5030645')->is_valid_number, '岐阜県海津市海津町五町');
ok($zip->set_number('5030646')->is_valid_number, '岐阜県海津市海津町萱野');
ok($zip->set_number('5030647')->is_valid_number, '岐阜県海津市海津町東小島');
ok($zip->set_number('5030648')->is_valid_number, '岐阜県海津市海津町西小島');
ok($zip->set_number('5030651')->is_valid_number, '岐阜県海津市海津町平原');
ok($zip->set_number('5030652')->is_valid_number, '岐阜県海津市海津町馬目');
ok($zip->set_number('5030653')->is_valid_number, '岐阜県海津市海津町高須町');
ok($zip->set_number('5030654')->is_valid_number, '岐阜県海津市海津町高須');
ok($zip->set_number('5030655')->is_valid_number, '岐阜県海津市海津町福岡');
ok($zip->set_number('5030801')->is_valid_number, '岐阜県大垣市和合新町');
ok($zip->set_number('5030802')->is_valid_number, '岐阜県大垣市東町');
ok($zip->set_number('5030803')->is_valid_number, '岐阜県大垣市小野');
ok($zip->set_number('5030804')->is_valid_number, '岐阜県大垣市中ノ江');
ok($zip->set_number('5030805')->is_valid_number, '岐阜県大垣市鶴見町');
ok($zip->set_number('5030806')->is_valid_number, '岐阜県大垣市緑園');
ok($zip->set_number('5030807')->is_valid_number, '岐阜県大垣市今宿');
ok($zip->set_number('5030808')->is_valid_number, '岐阜県大垣市三塚町');
ok($zip->set_number('5030811')->is_valid_number, '岐阜県大垣市波須');
ok($zip->set_number('5030812')->is_valid_number, '岐阜県大垣市万石');
ok($zip->set_number('5030813')->is_valid_number, '岐阜県大垣市三本木');
ok($zip->set_number('5030814')->is_valid_number, '岐阜県大垣市大村');
ok($zip->set_number('5030815')->is_valid_number, '岐阜県大垣市直江町');
ok($zip->set_number('5030816')->is_valid_number, '岐阜県大垣市小泉町');
ok($zip->set_number('5030817')->is_valid_number, '岐阜県大垣市上面');
ok($zip->set_number('5030821')->is_valid_number, '岐阜県大垣市早苗町');
ok($zip->set_number('5030822')->is_valid_number, '岐阜県大垣市住吉町');
ok($zip->set_number('5030823')->is_valid_number, '岐阜県大垣市鹿島町');
ok($zip->set_number('5030824')->is_valid_number, '岐阜県大垣市旭町');
ok($zip->set_number('5030825')->is_valid_number, '岐阜県大垣市花園町');
ok($zip->set_number('5030826')->is_valid_number, '岐阜県大垣市恵比寿町北');
ok($zip->set_number('5030827')->is_valid_number, '岐阜県大垣市恵比寿町南');
ok($zip->set_number('5030828')->is_valid_number, '岐阜県大垣市恵比寿町');
ok($zip->set_number('5030831')->is_valid_number, '岐阜県大垣市新長沢町');
ok($zip->set_number('5030832')->is_valid_number, '岐阜県大垣市寿町');
ok($zip->set_number('5030833')->is_valid_number, '岐阜県大垣市長沢町');
ok($zip->set_number('5030834')->is_valid_number, '岐阜県大垣市犬ケ渕町');
ok($zip->set_number('5030835')->is_valid_number, '岐阜県大垣市東前');
ok($zip->set_number('5030836')->is_valid_number, '岐阜県大垣市大井');
ok($zip->set_number('5030837')->is_valid_number, '岐阜県大垣市安井町');
ok($zip->set_number('5030838')->is_valid_number, '岐阜県大垣市江崎町');
ok($zip->set_number('5030839')->is_valid_number, '岐阜県大垣市長井町');
ok($zip->set_number('5030841')->is_valid_number, '岐阜県大垣市平町(その他)');
ok($zip->set_number('5030842')->is_valid_number, '岐阜県大垣市馬の瀬町');
ok($zip->set_number('5030843')->is_valid_number, '岐阜県大垣市今福町');
ok($zip->set_number('5030844')->is_valid_number, '岐阜県大垣市難波野町');
ok($zip->set_number('5030845')->is_valid_number, '岐阜県大垣市牧新田町');
ok($zip->set_number('5030846')->is_valid_number, '岐阜県大垣市深池町');
ok($zip->set_number('5030847')->is_valid_number, '岐阜県大垣市米野町');
ok($zip->set_number('5030848')->is_valid_number, '岐阜県大垣市古宮町');
ok($zip->set_number('5030849')->is_valid_number, '岐阜県大垣市東前町');
ok($zip->set_number('5030851')->is_valid_number, '岐阜県大垣市禾森');
ok($zip->set_number('5030852')->is_valid_number, '岐阜県大垣市禾森町');
ok($zip->set_number('5030853')->is_valid_number, '岐阜県大垣市田口町');
ok($zip->set_number('5030854')->is_valid_number, '岐阜県大垣市築捨町');
ok($zip->set_number('5030855')->is_valid_number, '岐阜県大垣市問屋町');
ok($zip->set_number('5030856')->is_valid_number, '岐阜県大垣市新田町');
ok($zip->set_number('5030857')->is_valid_number, '岐阜県大垣市美和町');
ok($zip->set_number('5030858')->is_valid_number, '岐阜県大垣市世安町');
ok($zip->set_number('5030861')->is_valid_number, '岐阜県大垣市羽衣町');
ok($zip->set_number('5030862')->is_valid_number, '岐阜県大垣市二葉町');
ok($zip->set_number('5030863')->is_valid_number, '岐阜県大垣市大池町');
ok($zip->set_number('5030864')->is_valid_number, '岐阜県大垣市南頬町');
ok($zip->set_number('5030865')->is_valid_number, '岐阜県大垣市寺内町');
ok($zip->set_number('5030871')->is_valid_number, '岐阜県大垣市魚屋町');
ok($zip->set_number('5030872')->is_valid_number, '岐阜県大垣市新町');
ok($zip->set_number('5030873')->is_valid_number, '岐阜県大垣市南高橋町');
ok($zip->set_number('5030874')->is_valid_number, '岐阜県大垣市今岡町');
ok($zip->set_number('5030875')->is_valid_number, '岐阜県大垣市田町');
ok($zip->set_number('5030876')->is_valid_number, '岐阜県大垣市俵町');
ok($zip->set_number('5030877')->is_valid_number, '岐阜県大垣市御殿町');
ok($zip->set_number('5030878')->is_valid_number, '岐阜県大垣市竹島町');
ok($zip->set_number('5030881')->is_valid_number, '岐阜県大垣市岐阜町');
ok($zip->set_number('5030882')->is_valid_number, '岐阜県大垣市東長町');
ok($zip->set_number('5030883')->is_valid_number, '岐阜県大垣市清水町');
ok($zip->set_number('5030884')->is_valid_number, '岐阜県大垣市中町');
ok($zip->set_number('5030885')->is_valid_number, '岐阜県大垣市本町');
ok($zip->set_number('5030886')->is_valid_number, '岐阜県大垣市郭町東');
ok($zip->set_number('5030887')->is_valid_number, '岐阜県大垣市郭町');
ok($zip->set_number('5030888')->is_valid_number, '岐阜県大垣市丸の内');
ok($zip->set_number('5030889')->is_valid_number, '岐阜県大垣市高砂町');
ok($zip->set_number('5030891')->is_valid_number, '岐阜県大垣市千鳥町');
ok($zip->set_number('5030892')->is_valid_number, '岐阜県大垣市橘町');
ok($zip->set_number('5030893')->is_valid_number, '岐阜県大垣市藤江町');
ok($zip->set_number('5030894')->is_valid_number, '岐阜県大垣市新地町');
ok($zip->set_number('5030895')->is_valid_number, '岐阜県大垣市代官町');
ok($zip->set_number('5030896')->is_valid_number, '岐阜県大垣市高橋町');
ok($zip->set_number('5030897')->is_valid_number, '岐阜県大垣市伝馬町');
ok($zip->set_number('5030898')->is_valid_number, '岐阜県大垣市歩行町');
ok($zip->set_number('5030899')->is_valid_number, '岐阜県大垣市錦町');
ok($zip->set_number('5030901')->is_valid_number, '岐阜県大垣市高屋町');
ok($zip->set_number('5030902')->is_valid_number, '岐阜県大垣市栗屋町');
ok($zip->set_number('5030903')->is_valid_number, '岐阜県大垣市東外側町');
ok($zip->set_number('5030904')->is_valid_number, '岐阜県大垣市桐ケ崎町');
ok($zip->set_number('5030905')->is_valid_number, '岐阜県大垣市宮町');
ok($zip->set_number('5030906')->is_valid_number, '岐阜県大垣市室町');
ok($zip->set_number('5030907')->is_valid_number, '岐阜県大垣市番組町');
ok($zip->set_number('5030908')->is_valid_number, '岐阜県大垣市西外側町');
ok($zip->set_number('5030911')->is_valid_number, '岐阜県大垣市室本町');
ok($zip->set_number('5030912')->is_valid_number, '岐阜県大垣市鳩部屋町');
ok($zip->set_number('5030913')->is_valid_number, '岐阜県大垣市鷹匠町');
ok($zip->set_number('5030914')->is_valid_number, '岐阜県大垣市西長町');
ok($zip->set_number('5030915')->is_valid_number, '岐阜県大垣市北切石町');
ok($zip->set_number('5030916')->is_valid_number, '岐阜県大垣市日の出町');
ok($zip->set_number('5030917')->is_valid_number, '岐阜県大垣市神田町');
ok($zip->set_number('5030918')->is_valid_number, '岐阜県大垣市西崎町');
ok($zip->set_number('5030921')->is_valid_number, '岐阜県大垣市新馬場町');
ok($zip->set_number('5030922')->is_valid_number, '岐阜県大垣市馬場町');
ok($zip->set_number('5030923')->is_valid_number, '岐阜県大垣市船町');
ok($zip->set_number('5030924')->is_valid_number, '岐阜県大垣市今町');
ok($zip->set_number('5030925')->is_valid_number, '岐阜県大垣市南切石町');
ok($zip->set_number('5030926')->is_valid_number, '岐阜県大垣市切石町');
ok($zip->set_number('5030931')->is_valid_number, '岐阜県大垣市本今');
ok($zip->set_number('5030932')->is_valid_number, '岐阜県大垣市本今町');
ok($zip->set_number('5030933')->is_valid_number, '岐阜県大垣市外野');
ok($zip->set_number('5030934')->is_valid_number, '岐阜県大垣市外渕');
ok($zip->set_number('5030935')->is_valid_number, '岐阜県大垣市島里');
ok($zip->set_number('5030936')->is_valid_number, '岐阜県大垣市内原');
ok($zip->set_number('5030937')->is_valid_number, '岐阜県大垣市釜笛');
ok($zip->set_number('5030941')->is_valid_number, '岐阜県大垣市川口');
ok($zip->set_number('5030942')->is_valid_number, '岐阜県大垣市昭和');
ok($zip->set_number('5030943')->is_valid_number, '岐阜県大垣市横曽根町');
ok($zip->set_number('5030944')->is_valid_number, '岐阜県大垣市横曽根');
ok($zip->set_number('5030945')->is_valid_number, '岐阜県大垣市浅西');
ok($zip->set_number('5030946')->is_valid_number, '岐阜県大垣市浅中');
ok($zip->set_number('5030947')->is_valid_number, '岐阜県大垣市浅草');
ok($zip->set_number('5030951')->is_valid_number, '岐阜県大垣市外野町');
ok($zip->set_number('5030952')->is_valid_number, '岐阜県大垣市割田町');
ok($zip->set_number('5030953')->is_valid_number, '岐阜県大垣市割田');
ok($zip->set_number('5030954')->is_valid_number, '岐阜県大垣市外花');
ok($zip->set_number('5030955')->is_valid_number, '岐阜県大垣市友江');
ok($zip->set_number('5030956')->is_valid_number, '岐阜県大垣市大外羽');
ok($zip->set_number('5030957')->is_valid_number, '岐阜県大垣市上屋');
ok($zip->set_number('5030958')->is_valid_number, '岐阜県大垣市高渕');
ok($zip->set_number('5030959')->is_valid_number, '岐阜県大垣市高渕町');
ok($zip->set_number('5030961')->is_valid_number, '岐阜県大垣市青柳町');
ok($zip->set_number('5030962')->is_valid_number, '岐阜県大垣市入方');
ok($zip->set_number('5030963')->is_valid_number, '岐阜県大垣市西大外羽');
ok($zip->set_number('5030964')->is_valid_number, '岐阜県大垣市上笠');
ok($zip->set_number('5030965')->is_valid_number, '岐阜県大垣市多芸島');
ok($zip->set_number('5030971')->is_valid_number, '岐阜県大垣市南一色町');
ok($zip->set_number('5030972')->is_valid_number, '岐阜県大垣市宝和町');
ok($zip->set_number('5030973')->is_valid_number, '岐阜県大垣市木戸町');
ok($zip->set_number('5030974')->is_valid_number, '岐阜県大垣市久瀬川町');
ok($zip->set_number('5030975')->is_valid_number, '岐阜県大垣市若森町');
ok($zip->set_number('5030976')->is_valid_number, '岐阜県大垣市南若森町');
ok($zip->set_number('5030977')->is_valid_number, '岐阜県大垣市南若森');
ok($zip->set_number('5030981')->is_valid_number, '岐阜県大垣市桧町');
ok($zip->set_number('5030982')->is_valid_number, '岐阜県大垣市久徳町');
ok($zip->set_number('5030983')->is_valid_number, '岐阜県大垣市静里町');
ok($zip->set_number('5030984')->is_valid_number, '岐阜県大垣市綾野');
ok($zip->set_number('5030985')->is_valid_number, '岐阜県大垣市野口');
ok($zip->set_number('5030986')->is_valid_number, '岐阜県大垣市中曽根町');
ok($zip->set_number('5030991')->is_valid_number, '岐阜県大垣市木呂町');
ok($zip->set_number('5030992')->is_valid_number, '岐阜県大垣市新長松');
ok($zip->set_number('5030993')->is_valid_number, '岐阜県大垣市荒川町');
ok($zip->set_number('5030994')->is_valid_number, '岐阜県大垣市綾野町');
ok($zip->set_number('5030995')->is_valid_number, '岐阜県大垣市十六町');
ok($zip->set_number('5030996')->is_valid_number, '岐阜県大垣市島町');
ok($zip->set_number('5030997')->is_valid_number, '岐阜県大垣市長松町');
ok($zip->set_number('5031241')->is_valid_number, '岐阜県養老郡養老町沢田');
ok($zip->set_number('5031242')->is_valid_number, '岐阜県養老郡養老町桜井');
ok($zip->set_number('5031243')->is_valid_number, '岐阜県養老郡養老町五日市');
ok($zip->set_number('5031244')->is_valid_number, '岐阜県養老郡養老町竜泉寺');
ok($zip->set_number('5031245')->is_valid_number, '岐阜県養老郡養老町上方');
ok($zip->set_number('5031251')->is_valid_number, '岐阜県養老郡養老町石畑');
ok($zip->set_number('5031252')->is_valid_number, '岐阜県養老郡養老町明徳');
ok($zip->set_number('5031253')->is_valid_number, '岐阜県養老郡養老町柏尾');
ok($zip->set_number('5031254')->is_valid_number, '岐阜県養老郡養老町養老公園');
ok($zip->set_number('5031255')->is_valid_number, '岐阜県養老郡養老町養老');
ok($zip->set_number('5031256')->is_valid_number, '岐阜県養老郡養老町勢至');
ok($zip->set_number('5031261')->is_valid_number, '岐阜県養老郡養老町鷲巣');
ok($zip->set_number('5031262')->is_valid_number, '岐阜県養老郡養老町小倉');
ok($zip->set_number('5031263')->is_valid_number, '岐阜県養老郡養老町船見');
ok($zip->set_number('5031264')->is_valid_number, '岐阜県養老郡養老町一色');
ok($zip->set_number('5031265')->is_valid_number, '岐阜県養老郡養老町若宮');
ok($zip->set_number('5031266')->is_valid_number, '岐阜県養老郡養老町京ケ脇');
ok($zip->set_number('5031267')->is_valid_number, '岐阜県養老郡養老町高林');
ok($zip->set_number('5031268')->is_valid_number, '岐阜県養老郡養老町西小倉');
ok($zip->set_number('5031271')->is_valid_number, '岐阜県養老郡養老町田');
ok($zip->set_number('5031272')->is_valid_number, '岐阜県養老郡養老町大場');
ok($zip->set_number('5031273')->is_valid_number, '岐阜県養老郡養老町根古地');
ok($zip->set_number('5031274')->is_valid_number, '岐阜県養老郡養老町瑞穂');
ok($zip->set_number('5031275')->is_valid_number, '岐阜県養老郡養老町大巻');
ok($zip->set_number('5031276')->is_valid_number, '岐阜県養老郡養老町釜段');
ok($zip->set_number('5031277')->is_valid_number, '岐阜県養老郡養老町有尾');
ok($zip->set_number('5031278')->is_valid_number, '岐阜県養老郡養老町横屋');
ok($zip->set_number('5031300')->is_valid_number, '岐阜県養老郡養老町以下に掲載がない場合');
ok($zip->set_number('5031301')->is_valid_number, '岐阜県養老郡養老町室原');
ok($zip->set_number('5031302')->is_valid_number, '岐阜県養老郡養老町大坪');
ok($zip->set_number('5031303')->is_valid_number, '岐阜県養老郡養老町蛇持');
ok($zip->set_number('5031304')->is_valid_number, '岐阜県養老郡養老町飯田');
ok($zip->set_number('5031305')->is_valid_number, '岐阜県養老郡養老町祖父江');
ok($zip->set_number('5031306')->is_valid_number, '岐阜県養老郡養老町江月');
ok($zip->set_number('5031311')->is_valid_number, '岐阜県養老郡養老町泉町');
ok($zip->set_number('5031312')->is_valid_number, '岐阜県養老郡養老町三神町');
ok($zip->set_number('5031313')->is_valid_number, '岐阜県養老郡養老町高田馬場町');
ok($zip->set_number('5031314')->is_valid_number, '岐阜県養老郡養老町高田');
ok($zip->set_number('5031315')->is_valid_number, '岐阜県養老郡養老町烏江');
ok($zip->set_number('5031316')->is_valid_number, '岐阜県養老郡養老町押越');
ok($zip->set_number('5031317')->is_valid_number, '岐阜県養老郡養老町滝見町');
ok($zip->set_number('5031321')->is_valid_number, '岐阜県養老郡養老町岩道');
ok($zip->set_number('5031322')->is_valid_number, '岐阜県養老郡養老町西岩道');
ok($zip->set_number('5031323')->is_valid_number, '岐阜県養老郡養老町口ケ島');
ok($zip->set_number('5031324')->is_valid_number, '岐阜県養老郡養老町大跡');
ok($zip->set_number('5031325')->is_valid_number, '岐阜県養老郡養老町飯ノ木');
ok($zip->set_number('5031331')->is_valid_number, '岐阜県養老郡養老町橋爪');
ok($zip->set_number('5031332')->is_valid_number, '岐阜県養老郡養老町中');
ok($zip->set_number('5031333')->is_valid_number, '岐阜県養老郡養老町色目');
ok($zip->set_number('5031334')->is_valid_number, '岐阜県養老郡養老町豊');
ok($zip->set_number('5031335')->is_valid_number, '岐阜県養老郡養老町宇田');
ok($zip->set_number('5031336')->is_valid_number, '岐阜県養老郡養老町飯積');
ok($zip->set_number('5031337')->is_valid_number, '岐阜県養老郡養老町直江');
ok($zip->set_number('5031338')->is_valid_number, '岐阜県養老郡養老町安久');
ok($zip->set_number('5031339')->is_valid_number, '岐阜県養老郡養老町金屋');
ok($zip->set_number('5031381')->is_valid_number, '岐阜県養老郡養老町栗笠');
ok($zip->set_number('5031382')->is_valid_number, '岐阜県養老郡養老町船附');
ok($zip->set_number('5031383')->is_valid_number, '岐阜県養老郡養老町大野');
ok($zip->set_number('5031384')->is_valid_number, '岐阜県養老郡養老町下笠');
ok($zip->set_number('5031385')->is_valid_number, '岐阜県養老郡養老町上之郷');
ok($zip->set_number('5031500')->is_valid_number, '岐阜県不破郡関ケ原町以下に掲載がない場合');
ok($zip->set_number('5031501')->is_valid_number, '岐阜県不破郡関ケ原町関ケ原');
ok($zip->set_number('5031511')->is_valid_number, '岐阜県不破郡関ケ原町東町');
ok($zip->set_number('5031512')->is_valid_number, '岐阜県不破郡関ケ原町公門');
ok($zip->set_number('5031513')->is_valid_number, '岐阜県不破郡関ケ原町中山');
ok($zip->set_number('5031514')->is_valid_number, '岐阜県不破郡関ケ原町稲荷');
ok($zip->set_number('5031514')->is_valid_number, '岐阜県不破郡関ケ原町西町');
ok($zip->set_number('5031515')->is_valid_number, '岐阜県不破郡関ケ原町中町');
ok($zip->set_number('5031521')->is_valid_number, '岐阜県不破郡関ケ原町宝有');
ok($zip->set_number('5031522')->is_valid_number, '岐阜県不破郡関ケ原町陣場野');
ok($zip->set_number('5031523')->is_valid_number, '岐阜県不破郡関ケ原町小池');
ok($zip->set_number('5031523')->is_valid_number, '岐阜県不破郡関ケ原町小関');
ok($zip->set_number('5031524')->is_valid_number, '岐阜県不破郡関ケ原町御祭田');
ok($zip->set_number('5031524')->is_valid_number, '岐阜県不破郡関ケ原町笹尾');
ok($zip->set_number('5031524')->is_valid_number, '岐阜県不破郡関ケ原町緑ケ丘');
ok($zip->set_number('5031531')->is_valid_number, '岐阜県不破郡関ケ原町大高');
ok($zip->set_number('5031532')->is_valid_number, '岐阜県不破郡関ケ原町野上');
ok($zip->set_number('5031541')->is_valid_number, '岐阜県不破郡関ケ原町松尾');
ok($zip->set_number('5031542')->is_valid_number, '岐阜県不破郡関ケ原町藤下');
ok($zip->set_number('5031543')->is_valid_number, '岐阜県不破郡関ケ原町今須');
ok($zip->set_number('5031544')->is_valid_number, '岐阜県不破郡関ケ原町山中');
ok($zip->set_number('5031545')->is_valid_number, '岐阜県不破郡関ケ原町玉');
ok($zip->set_number('5031601')->is_valid_number, '岐阜県大垣市上石津町乙坂');
ok($zip->set_number('5031602')->is_valid_number, '岐阜県大垣市上石津町牧田');
ok($zip->set_number('5031611')->is_valid_number, '岐阜県大垣市上石津町奥');
ok($zip->set_number('5031612')->is_valid_number, '岐阜県大垣市上石津町谷畑');
ok($zip->set_number('5031613')->is_valid_number, '岐阜県大垣市上石津町上鍛治屋');
ok($zip->set_number('5031614')->is_valid_number, '岐阜県大垣市上石津町一之瀬');
ok($zip->set_number('5031621')->is_valid_number, '岐阜県大垣市上石津町下多良');
ok($zip->set_number('5031622')->is_valid_number, '岐阜県大垣市上石津町上原');
ok($zip->set_number('5031623')->is_valid_number, '岐阜県大垣市上石津町上多良');
ok($zip->set_number('5031624')->is_valid_number, '岐阜県大垣市上石津町三ツ里');
ok($zip->set_number('5031625')->is_valid_number, '岐阜県大垣市上石津町宮');
ok($zip->set_number('5031626')->is_valid_number, '岐阜県大垣市上石津町祢宜上');
ok($zip->set_number('5031631')->is_valid_number, '岐阜県大垣市上石津町前ケ瀬');
ok($zip->set_number('5031632')->is_valid_number, '岐阜県大垣市上石津町下山');
ok($zip->set_number('5031633')->is_valid_number, '岐阜県大垣市上石津町打上');
ok($zip->set_number('5031634')->is_valid_number, '岐阜県大垣市上石津町細野');
ok($zip->set_number('5031635')->is_valid_number, '岐阜県大垣市上石津町時山');
ok($zip->set_number('5031636')->is_valid_number, '岐阜県大垣市上石津町西山');
ok($zip->set_number('5031637')->is_valid_number, '岐阜県大垣市上石津町堂之上');
ok($zip->set_number('5031638')->is_valid_number, '岐阜県大垣市上石津町上');
ok($zip->set_number('5032100')->is_valid_number, '岐阜県不破郡垂井町以下に掲載がない場合');
ok($zip->set_number('5032101')->is_valid_number, '岐阜県不破郡垂井町大滝');
ok($zip->set_number('5032102')->is_valid_number, '岐阜県不破郡垂井町敷原');
ok($zip->set_number('5032103')->is_valid_number, '岐阜県不破郡垂井町梅谷');
ok($zip->set_number('5032104')->is_valid_number, '岐阜県不破郡垂井町市之尾');
ok($zip->set_number('5032105')->is_valid_number, '岐阜県不破郡垂井町新井');
ok($zip->set_number('5032106')->is_valid_number, '岐阜県不破郡垂井町伊吹');
ok($zip->set_number('5032107')->is_valid_number, '岐阜県不破郡垂井町岩手');
ok($zip->set_number('5032108')->is_valid_number, '岐阜県不破郡垂井町大石');
ok($zip->set_number('5032109')->is_valid_number, '岐阜県不破郡垂井町南新井');
ok($zip->set_number('5032111')->is_valid_number, '岐阜県不破郡垂井町平尾');
ok($zip->set_number('5032112')->is_valid_number, '岐阜県不破郡垂井町綾戸');
ok($zip->set_number('5032113')->is_valid_number, '岐阜県不破郡垂井町清水');
ok($zip->set_number('5032114')->is_valid_number, '岐阜県不破郡垂井町府中');
ok($zip->set_number('5032121')->is_valid_number, '岐阜県不破郡垂井町垂井町の次に番地がくる場合');
ok($zip->set_number('5032122')->is_valid_number, '岐阜県不破郡垂井町表佐');
ok($zip->set_number('5032123')->is_valid_number, '岐阜県不破郡垂井町栗原');
ok($zip->set_number('5032124')->is_valid_number, '岐阜県不破郡垂井町宮代');
ok($zip->set_number('5032125')->is_valid_number, '岐阜県不破郡垂井町東神田');
ok($zip->set_number('5032201')->is_valid_number, '岐阜県大垣市草道島町');
ok($zip->set_number('5032202')->is_valid_number, '岐阜県大垣市青木町');
ok($zip->set_number('5032203')->is_valid_number, '岐阜県大垣市興福地町');
ok($zip->set_number('5032204')->is_valid_number, '岐阜県大垣市池尻町');
ok($zip->set_number('5032205')->is_valid_number, '岐阜県大垣市神明');
ok($zip->set_number('5032206')->is_valid_number, '岐阜県大垣市赤坂新町');
ok($zip->set_number('5032207')->is_valid_number, '岐阜県大垣市枝郷');
ok($zip->set_number('5032208')->is_valid_number, '岐阜県大垣市菅野');
ok($zip->set_number('5032211')->is_valid_number, '岐阜県大垣市南市橋町');
ok($zip->set_number('5032212')->is_valid_number, '岐阜県大垣市赤坂東町');
ok($zip->set_number('5032213')->is_valid_number, '岐阜県大垣市赤坂町');
ok($zip->set_number('5032214')->is_valid_number, '岐阜県大垣市赤坂新田');
ok($zip->set_number('5032215')->is_valid_number, '岐阜県大垣市赤坂大門');
ok($zip->set_number('5032216')->is_valid_number, '岐阜県大垣市昼飯町');
ok($zip->set_number('5032221')->is_valid_number, '岐阜県大垣市青墓町');
ok($zip->set_number('5032222')->is_valid_number, '岐阜県大垣市榎戸町');
ok($zip->set_number('5032223')->is_valid_number, '岐阜県大垣市矢道町');
ok($zip->set_number('5032224')->is_valid_number, '岐阜県大垣市稲葉東');
ok($zip->set_number('5032225')->is_valid_number, '岐阜県大垣市稲葉西');
ok($zip->set_number('5032226')->is_valid_number, '岐阜県大垣市稲葉北');
ok($zip->set_number('5032227')->is_valid_number, '岐阜県大垣市青野町');
ok($zip->set_number('5032300')->is_valid_number, '岐阜県安八郡神戸町以下に掲載がない場合');
ok($zip->set_number('5032301')->is_valid_number, '岐阜県安八郡神戸町横井');
ok($zip->set_number('5032302')->is_valid_number, '岐阜県安八郡神戸町田');
ok($zip->set_number('5032303')->is_valid_number, '岐阜県安八郡神戸町安次');
ok($zip->set_number('5032304')->is_valid_number, '岐阜県安八郡神戸町丈六道');
ok($zip->set_number('5032305')->is_valid_number, '岐阜県安八郡神戸町神戸');
ok($zip->set_number('5032306')->is_valid_number, '岐阜県安八郡神戸町北一色');
ok($zip->set_number('5032311')->is_valid_number, '岐阜県安八郡神戸町川西');
ok($zip->set_number('5032312')->is_valid_number, '岐阜県安八郡神戸町下宮');
ok($zip->set_number('5032313')->is_valid_number, '岐阜県安八郡神戸町新屋敷');
ok($zip->set_number('5032314')->is_valid_number, '岐阜県安八郡神戸町落合');
ok($zip->set_number('5032315')->is_valid_number, '岐阜県安八郡神戸町付寄');
ok($zip->set_number('5032316')->is_valid_number, '岐阜県安八郡神戸町斉田');
ok($zip->set_number('5032317')->is_valid_number, '岐阜県安八郡神戸町柳瀬');
ok($zip->set_number('5032318')->is_valid_number, '岐阜県安八郡神戸町瀬古');
ok($zip->set_number('5032319')->is_valid_number, '岐阜県安八郡神戸町前田');
ok($zip->set_number('5032321')->is_valid_number, '岐阜県安八郡神戸町末守');
ok($zip->set_number('5032322')->is_valid_number, '岐阜県安八郡神戸町更屋敷');
ok($zip->set_number('5032323')->is_valid_number, '岐阜県安八郡神戸町西保');
ok($zip->set_number('5032324')->is_valid_number, '岐阜県安八郡神戸町八条');
ok($zip->set_number('5032325')->is_valid_number, '岐阜県安八郡神戸町加納');
ok($zip->set_number('5032326')->is_valid_number, '岐阜県安八郡神戸町中沢');
ok($zip->set_number('5032327')->is_valid_number, '岐阜県安八郡神戸町和泉');
ok($zip->set_number('5032328')->is_valid_number, '岐阜県安八郡神戸町南方');
ok($zip->set_number('5032341')->is_valid_number, '岐阜県安八郡神戸町西座倉');
ok($zip->set_number('5032400')->is_valid_number, '岐阜県揖斐郡池田町以下に掲載がない場合');
ok($zip->set_number('5032401')->is_valid_number, '岐阜県揖斐郡池田町沓井');
ok($zip->set_number('5032402')->is_valid_number, '岐阜県揖斐郡池田町粕ケ原');
ok($zip->set_number('5032403')->is_valid_number, '岐阜県揖斐郡池田町田中');
ok($zip->set_number('5032404')->is_valid_number, '岐阜県揖斐郡池田町小牛');
ok($zip->set_number('5032405')->is_valid_number, '岐阜県揖斐郡池田町願成寺');
ok($zip->set_number('5032406')->is_valid_number, '岐阜県揖斐郡池田町宮地');
ok($zip->set_number('5032407')->is_valid_number, '岐阜県揖斐郡池田町般若畑');
ok($zip->set_number('5032408')->is_valid_number, '岐阜県揖斐郡池田町段');
ok($zip->set_number('5032409')->is_valid_number, '岐阜県揖斐郡池田町舟子');
ok($zip->set_number('5032411')->is_valid_number, '岐阜県揖斐郡池田町杉野');
ok($zip->set_number('5032412')->is_valid_number, '岐阜県揖斐郡池田町砂畑');
ok($zip->set_number('5032413')->is_valid_number, '岐阜県揖斐郡池田町白鳥');
ok($zip->set_number('5032414')->is_valid_number, '岐阜県揖斐郡池田町下東野');
ok($zip->set_number('5032415')->is_valid_number, '岐阜県揖斐郡池田町上田');
ok($zip->set_number('5032416')->is_valid_number, '岐阜県揖斐郡池田町萩原');
ok($zip->set_number('5032417')->is_valid_number, '岐阜県揖斐郡池田町本郷');
ok($zip->set_number('5032418')->is_valid_number, '岐阜県揖斐郡池田町草深');
ok($zip->set_number('5032419')->is_valid_number, '岐阜県揖斐郡池田町小寺');
ok($zip->set_number('5032421')->is_valid_number, '岐阜県揖斐郡池田町山洞');
ok($zip->set_number('5032422')->is_valid_number, '岐阜県揖斐郡池田町田畑');
ok($zip->set_number('5032423')->is_valid_number, '岐阜県揖斐郡池田町青柳');
ok($zip->set_number('5032424')->is_valid_number, '岐阜県揖斐郡池田町池野');
ok($zip->set_number('5032425')->is_valid_number, '岐阜県揖斐郡池田町六之井');
ok($zip->set_number('5032426')->is_valid_number, '岐阜県揖斐郡池田町八幡');
ok($zip->set_number('5032427')->is_valid_number, '岐阜県揖斐郡池田町市橋');
ok($zip->set_number('5032428')->is_valid_number, '岐阜県揖斐郡池田町片山');
ok($zip->set_number('5032429')->is_valid_number, '岐阜県揖斐郡池田町藤代');
ok($zip->set_number('5032501')->is_valid_number, '岐阜県揖斐郡揖斐川町春日美束');
ok($zip->set_number('5032502')->is_valid_number, '岐阜県揖斐郡揖斐川町春日六合');
ok($zip->set_number('5032503')->is_valid_number, '岐阜県揖斐郡揖斐川町春日川合');
ok($zip->set_number('5032504')->is_valid_number, '岐阜県揖斐郡揖斐川町春日中山');
ok($zip->set_number('5032505')->is_valid_number, '岐阜県揖斐郡揖斐川町春日小宮神');
ok($zip->set_number('5032506')->is_valid_number, '岐阜県揖斐郡揖斐川町春日香六');
ok($zip->set_number('5040000')->is_valid_number, '岐阜県各務原市以下に掲載がない場合');
ok($zip->set_number('5040001')->is_valid_number, '岐阜県各務原市那加大洞');
ok($zip->set_number('5040002')->is_valid_number, '岐阜県各務原市尾崎北町');
ok($zip->set_number('5040003')->is_valid_number, '岐阜県各務原市尾崎南町');
ok($zip->set_number('5040004')->is_valid_number, '岐阜県各務原市尾崎西町');
ok($zip->set_number('5040005')->is_valid_number, '岐阜県各務原市那加柄山町');
ok($zip->set_number('5040006')->is_valid_number, '岐阜県各務原市那加琴が丘町');
ok($zip->set_number('5040007')->is_valid_number, '岐阜県各務原市那加芦原町');
ok($zip->set_number('5040008')->is_valid_number, '岐阜県各務原市那加桐野町');
ok($zip->set_number('5040009')->is_valid_number, '岐阜県各務原市那加扇平');
ok($zip->set_number('5040011')->is_valid_number, '岐阜県各務原市那加北洞町');
ok($zip->set_number('5040012')->is_valid_number, '岐阜県各務原市蘇原宮代町');
ok($zip->set_number('5040013')->is_valid_number, '岐阜県各務原市蘇原宮塚町');
ok($zip->set_number('5040014')->is_valid_number, '岐阜県各務原市那加山崎町');
ok($zip->set_number('5040015')->is_valid_number, '岐阜県各務原市那加東野町');
ok($zip->set_number('5040016')->is_valid_number, '岐阜県各務原市那加御屋敷町');
ok($zip->set_number('5040017')->is_valid_number, '岐阜県各務原市那加山下町');
ok($zip->set_number('5040018')->is_valid_number, '岐阜県各務原市那加西市場町');
ok($zip->set_number('5040021')->is_valid_number, '岐阜県各務原市那加前洞新町');
ok($zip->set_number('5040022')->is_valid_number, '岐阜県各務原市那加東亜町');
ok($zip->set_number('5040023')->is_valid_number, '岐阜県各務原市那加太平町');
ok($zip->set_number('5040024')->is_valid_number, '岐阜県各務原市那加幸町');
ok($zip->set_number('5040025')->is_valid_number, '岐阜県各務原市那加野畑町');
ok($zip->set_number('5040026')->is_valid_number, '岐阜県各務原市那加前野町');
ok($zip->set_number('5040031')->is_valid_number, '岐阜県各務原市那加兼橋町');
ok($zip->set_number('5040032')->is_valid_number, '岐阜県各務原市那加神田町');
ok($zip->set_number('5040033')->is_valid_number, '岐阜県各務原市那加大谷町');
ok($zip->set_number('5040034')->is_valid_number, '岐阜県各務原市那加浜見町');
ok($zip->set_number('5040035')->is_valid_number, '岐阜県各務原市那加宮浦町');
ok($zip->set_number('5040036')->is_valid_number, '岐阜県各務原市那加荒田町');
ok($zip->set_number('5040037')->is_valid_number, '岐阜県各務原市那加五反田町');
ok($zip->set_number('5040038')->is_valid_number, '岐阜県各務原市那加大門町');
ok($zip->set_number('5040041')->is_valid_number, '岐阜県各務原市那加土山町');
ok($zip->set_number('5040042')->is_valid_number, '岐阜県各務原市那加山後町');
ok($zip->set_number('5040043')->is_valid_number, '岐阜県各務原市那加手力町');
ok($zip->set_number('5040044')->is_valid_number, '岐阜県各務原市那加石山町');
ok($zip->set_number('5040045')->is_valid_number, '岐阜県各務原市那加新田町');
ok($zip->set_number('5040046')->is_valid_number, '岐阜県各務原市那加長塚町');
ok($zip->set_number('5040047')->is_valid_number, '岐阜県各務原市那加岩地町');
ok($zip->set_number('5040801')->is_valid_number, '岐阜県各務原市蘇原北山町');
ok($zip->set_number('5040802')->is_valid_number, '岐阜県各務原市蘇原持田町');
ok($zip->set_number('5040803')->is_valid_number, '岐阜県各務原市蘇原東門町');
ok($zip->set_number('5040804')->is_valid_number, '岐阜県各務原市蘇原新生町');
ok($zip->set_number('5040805')->is_valid_number, '岐阜県各務原市蘇原昭栄町');
ok($zip->set_number('5040806')->is_valid_number, '岐阜県各務原市蘇原外山町');
ok($zip->set_number('5040807')->is_valid_number, '岐阜県各務原市蘇原清住町');
ok($zip->set_number('5040808')->is_valid_number, '岐阜県各務原市蘇原飛鳥町');
ok($zip->set_number('5040809')->is_valid_number, '岐阜県各務原市蘇原北陽町');
ok($zip->set_number('5040811')->is_valid_number, '岐阜県各務原市蘇原和合町');
ok($zip->set_number('5040812')->is_valid_number, '岐阜県各務原市蘇原坂井町');
ok($zip->set_number('5040813')->is_valid_number, '岐阜県各務原市蘇原中央町');
ok($zip->set_number('5040814')->is_valid_number, '岐阜県各務原市蘇原興亜町');
ok($zip->set_number('5040815')->is_valid_number, '岐阜県各務原市蘇原東栄町');
ok($zip->set_number('5040816')->is_valid_number, '岐阜県各務原市蘇原東島町');
ok($zip->set_number('5040821')->is_valid_number, '岐阜県各務原市蘇原瑞雲町');
ok($zip->set_number('5040822')->is_valid_number, '岐阜県各務原市蘇原栄町');
ok($zip->set_number('5040823')->is_valid_number, '岐阜県各務原市蘇原菊園町');
ok($zip->set_number('5040824')->is_valid_number, '岐阜県各務原市蘇原旭町');
ok($zip->set_number('5040825')->is_valid_number, '岐阜県各務原市蘇原柿沢町');
ok($zip->set_number('5040826')->is_valid_number, '岐阜県各務原市蘇原早苗町');
ok($zip->set_number('5040827')->is_valid_number, '岐阜県各務原市蘇原沢上町');
ok($zip->set_number('5040828')->is_valid_number, '岐阜県各務原市蘇原村雨町');
ok($zip->set_number('5040829')->is_valid_number, '岐阜県各務原市蘇原希望町');
ok($zip->set_number('5040831')->is_valid_number, '岐阜県各務原市蘇原瑞穂町');
ok($zip->set_number('5040832')->is_valid_number, '岐阜県各務原市蘇原花園町');
ok($zip->set_number('5040833')->is_valid_number, '岐阜県各務原市入会町');
ok($zip->set_number('5040834')->is_valid_number, '岐阜県各務原市那加昭南町');
ok($zip->set_number('5040835')->is_valid_number, '岐阜県各務原市那加雄飛ケ丘町');
ok($zip->set_number('5040836')->is_valid_number, '岐阜県各務原市那加雲雀町');
ok($zip->set_number('5040837')->is_valid_number, '岐阜県各務原市那加甥田町');
ok($zip->set_number('5040838')->is_valid_number, '岐阜県各務原市那加不動丘');
ok($zip->set_number('5040839')->is_valid_number, '岐阜県各務原市那加巾下町');
ok($zip->set_number('5040841')->is_valid_number, '岐阜県各務原市蘇原赤羽根町');
ok($zip->set_number('5040842')->is_valid_number, '岐阜県各務原市蘇原寺島町');
ok($zip->set_number('5040843')->is_valid_number, '岐阜県各務原市蘇原青雲町');
ok($zip->set_number('5040844')->is_valid_number, '岐阜県各務原市蘇原吉新町');
ok($zip->set_number('5040845')->is_valid_number, '岐阜県各務原市蘇原申子町');
ok($zip->set_number('5040846')->is_valid_number, '岐阜県各務原市蘇原吉野町');
ok($zip->set_number('5040847')->is_valid_number, '岐阜県各務原市蘇原大島町');
ok($zip->set_number('5040851')->is_valid_number, '岐阜県各務原市蘇原伊吹町');
ok($zip->set_number('5040852')->is_valid_number, '岐阜県各務原市蘇原古市場町');
ok($zip->set_number('5040853')->is_valid_number, '岐阜県各務原市蘇原熊田町');
ok($zip->set_number('5040854')->is_valid_number, '岐阜県各務原市蘇原野口町');
ok($zip->set_number('5040855')->is_valid_number, '岐阜県各務原市蘇原新栄町');
ok($zip->set_number('5040856')->is_valid_number, '岐阜県各務原市蘇原島崎町');
ok($zip->set_number('5040861')->is_valid_number, '岐阜県各務原市東山');
ok($zip->set_number('5040901')->is_valid_number, '岐阜県各務原市那加東新町');
ok($zip->set_number('5040902')->is_valid_number, '岐阜県各務原市蘇原緑町');
ok($zip->set_number('5040903')->is_valid_number, '岐阜県各務原市蘇原月丘町');
ok($zip->set_number('5040904')->is_valid_number, '岐阜県各務原市蘇原三柿野町');
ok($zip->set_number('5040905')->is_valid_number, '岐阜県各務原市蘇原六軒町');
ok($zip->set_number('5040906')->is_valid_number, '岐阜県各務原市那加桐野外二ケ所大字入会地');
ok($zip->set_number('5040907')->is_valid_number, '岐阜県各務原市那加住吉町');
ok($zip->set_number('5040908')->is_valid_number, '岐阜県各務原市那加織田町');
ok($zip->set_number('5040909')->is_valid_number, '岐阜県各務原市那加信長町');
ok($zip->set_number('5040911')->is_valid_number, '岐阜県各務原市那加門前町');
ok($zip->set_number('5040912')->is_valid_number, '岐阜県各務原市那加桜町');
ok($zip->set_number('5040913')->is_valid_number, '岐阜県各務原市那加大東町');
ok($zip->set_number('5040914')->is_valid_number, '岐阜県各務原市三井東町');
ok($zip->set_number('5040915')->is_valid_number, '岐阜県各務原市三井山町');
ok($zip->set_number('5040916')->is_valid_number, '岐阜県各務原市那加楠町');
ok($zip->set_number('5040921')->is_valid_number, '岐阜県各務原市前渡北町');
ok($zip->set_number('5040922')->is_valid_number, '岐阜県各務原市前渡東町');
ok($zip->set_number('5040923')->is_valid_number, '岐阜県各務原市前渡西町');
ok($zip->set_number('5040924')->is_valid_number, '岐阜県各務原市下切町');
ok($zip->set_number('5040925')->is_valid_number, '岐阜県各務原市松本町');
ok($zip->set_number('5040926')->is_valid_number, '岐阜県各務原市上中屋町');
ok($zip->set_number('5040927')->is_valid_number, '岐阜県各務原市上戸町');
ok($zip->set_number('5040928')->is_valid_number, '岐阜県各務原市山脇町');
ok($zip->set_number('5040931')->is_valid_number, '岐阜県各務原市大佐野町');
ok($zip->set_number('5040932')->is_valid_number, '岐阜県各務原市下中屋町');
ok($zip->set_number('5040933')->is_valid_number, '岐阜県各務原市神置町');
ok($zip->set_number('5040934')->is_valid_number, '岐阜県各務原市大野町');
ok($zip->set_number('5040935')->is_valid_number, '岐阜県各務原市成清町');
ok($zip->set_number('5040941')->is_valid_number, '岐阜県各務原市三井町');
ok($zip->set_number('5040942')->is_valid_number, '岐阜県各務原市小佐野町');
ok($zip->set_number('5040943')->is_valid_number, '岐阜県各務原市那加萱場町');
ok($zip->set_number('5040944')->is_valid_number, '岐阜県各務原市那加緑町');
ok($zip->set_number('5040945')->is_valid_number, '岐阜県各務原市那加日新町');
ok($zip->set_number('5040951')->is_valid_number, '岐阜県各務原市那加日吉町');
ok($zip->set_number('5040952')->is_valid_number, '岐阜県各務原市那加西那加町');
ok($zip->set_number('5040953')->is_valid_number, '岐阜県各務原市那加東那加町');
ok($zip->set_number('5040954')->is_valid_number, '岐阜県各務原市那加栄町');
ok($zip->set_number('5040955')->is_valid_number, '岐阜県各務原市那加南栄町');
ok($zip->set_number('5040956')->is_valid_number, '岐阜県各務原市三井北町');
ok($zip->set_number('5040957')->is_valid_number, '岐阜県各務原市金属団地');
ok($zip->set_number('5040958')->is_valid_number, '岐阜県各務原市那加新加納町');
ok($zip->set_number('5040959')->is_valid_number, '岐阜県各務原市那加西浦町');
ok($zip->set_number('5040961')->is_valid_number, '岐阜県各務原市那加新那加町');
ok($zip->set_number('5040962')->is_valid_number, '岐阜県各務原市那加吾妻町');
ok($zip->set_number('5040963')->is_valid_number, '岐阜県各務原市那加北栄町');
ok($zip->set_number('5040964')->is_valid_number, '岐阜県各務原市那加元町');
ok($zip->set_number('5040965')->is_valid_number, '岐阜県各務原市那加日之出町');
ok($zip->set_number('5040966')->is_valid_number, '岐阜県各務原市那加本町');
ok($zip->set_number('5040967')->is_valid_number, '岐阜県各務原市那加楽天地町');
ok($zip->set_number('5040968')->is_valid_number, '岐阜県各務原市那加西野町');
ok($zip->set_number('5040971')->is_valid_number, '岐阜県各務原市川崎町');
ok($zip->set_number('5050000')->is_valid_number, '岐阜県美濃加茂市以下に掲載がない場合');
ok($zip->set_number('5050000')->is_valid_number, '岐阜県加茂郡坂祝町以下に掲載がない場合');
ok($zip->set_number('5050001')->is_valid_number, '岐阜県美濃加茂市三和町廿屋');
ok($zip->set_number('5050002')->is_valid_number, '岐阜県美濃加茂市三和町川浦');
ok($zip->set_number('5050003')->is_valid_number, '岐阜県美濃加茂市山之上町');
ok($zip->set_number('5050004')->is_valid_number, '岐阜県美濃加茂市蜂屋町上蜂屋');
ok($zip->set_number('5050005')->is_valid_number, '岐阜県美濃加茂市蜂屋町中蜂屋');
ok($zip->set_number('5050006')->is_valid_number, '岐阜県美濃加茂市蜂屋町伊瀬');
ok($zip->set_number('5050007')->is_valid_number, '岐阜県美濃加茂市蜂屋町下蜂屋');
ok($zip->set_number('5050008')->is_valid_number, '岐阜県美濃加茂市伊深町');
ok($zip->set_number('5050009')->is_valid_number, '岐阜県美濃加茂市蜂屋町矢田');
ok($zip->set_number('5050010')->is_valid_number, '岐阜県美濃加茂市健康のまち');
ok($zip->set_number('5050011')->is_valid_number, '岐阜県美濃加茂市下米田町東栃井');
ok($zip->set_number('5050012')->is_valid_number, '岐阜県美濃加茂市下米田町山本');
ok($zip->set_number('5050013')->is_valid_number, '岐阜県美濃加茂市下米田町信友');
ok($zip->set_number('5050014')->is_valid_number, '岐阜県美濃加茂市下米田町則光');
ok($zip->set_number('5050015')->is_valid_number, '岐阜県美濃加茂市下米田町今');
ok($zip->set_number('5050016')->is_valid_number, '岐阜県美濃加茂市牧野');
ok($zip->set_number('5050017')->is_valid_number, '岐阜県美濃加茂市下米田町小山');
ok($zip->set_number('5050018')->is_valid_number, '岐阜県美濃加茂市下米田町西脇');
ok($zip->set_number('5050019')->is_valid_number, '岐阜県美濃加茂市下米田町為岡');
ok($zip->set_number('5050021')->is_valid_number, '岐阜県美濃加茂市森山町');
ok($zip->set_number('5050022')->is_valid_number, '岐阜県美濃加茂市川合町');
ok($zip->set_number('5050023')->is_valid_number, '岐阜県美濃加茂市野笹町');
ok($zip->set_number('5050024')->is_valid_number, '岐阜県美濃加茂市御門町');
ok($zip->set_number('5050025')->is_valid_number, '岐阜県美濃加茂市島町');
ok($zip->set_number('5050026')->is_valid_number, '岐阜県美濃加茂市清水町');
ok($zip->set_number('5050027')->is_valid_number, '岐阜県美濃加茂市本郷町');
ok($zip->set_number('5050028')->is_valid_number, '岐阜県美濃加茂市山崎町');
ok($zip->set_number('5050029')->is_valid_number, '岐阜県美濃加茂市あじさいヶ丘');
ok($zip->set_number('5050031')->is_valid_number, '岐阜県美濃加茂市新池町');
ok($zip->set_number('5050032')->is_valid_number, '岐阜県美濃加茂市田島町');
ok($zip->set_number('5050033')->is_valid_number, '岐阜県美濃加茂市中富町');
ok($zip->set_number('5050034')->is_valid_number, '岐阜県美濃加茂市古井町下古井');
ok($zip->set_number('5050035')->is_valid_number, '岐阜県美濃加茂市大手町');
ok($zip->set_number('5050036')->is_valid_number, '岐阜県美濃加茂市山手町');
ok($zip->set_number('5050037')->is_valid_number, '岐阜県美濃加茂市前平町');
ok($zip->set_number('5050038')->is_valid_number, '岐阜県美濃加茂市中部台');
ok($zip->set_number('5050039')->is_valid_number, '岐阜県美濃加茂市蜂屋台');
ok($zip->set_number('5050041')->is_valid_number, '岐阜県美濃加茂市太田町');
ok($zip->set_number('5050042')->is_valid_number, '岐阜県美濃加茂市太田本町');
ok($zip->set_number('5050043')->is_valid_number, '岐阜県美濃加茂市深田町');
ok($zip->set_number('5050044')->is_valid_number, '岐阜県美濃加茂市加茂川町');
ok($zip->set_number('5050045')->is_valid_number, '岐阜県美濃加茂市草笛町');
ok($zip->set_number('5050046')->is_valid_number, '岐阜県美濃加茂市西町');
ok($zip->set_number('5050051')->is_valid_number, '岐阜県美濃加茂市加茂野町鷹之巣');
ok($zip->set_number('5050052')->is_valid_number, '岐阜県美濃加茂市加茂野町今泉');
ok($zip->set_number('5050053')->is_valid_number, '岐阜県美濃加茂市加茂野町木野');
ok($zip->set_number('5050054')->is_valid_number, '岐阜県美濃加茂市加茂野町加茂野');
ok($zip->set_number('5050055')->is_valid_number, '岐阜県美濃加茂市加茂野町稲辺');
ok($zip->set_number('5050056')->is_valid_number, '岐阜県美濃加茂市加茂野町市橋');
ok($zip->set_number('5050071')->is_valid_number, '岐阜県加茂郡坂祝町黒岩');
ok($zip->set_number('5050072')->is_valid_number, '岐阜県加茂郡坂祝町大針');
ok($zip->set_number('5050073')->is_valid_number, '岐阜県加茂郡坂祝町加茂山');
ok($zip->set_number('5050074')->is_valid_number, '岐阜県加茂郡坂祝町酒倉');
ok($zip->set_number('5050075')->is_valid_number, '岐阜県加茂郡坂祝町取組');
ok($zip->set_number('5050076')->is_valid_number, '岐阜県加茂郡坂祝町勝山');
ok($zip->set_number('5050077')->is_valid_number, '岐阜県加茂郡坂祝町深萱');
ok($zip->set_number('5050100')->is_valid_number, '岐阜県可児郡御嵩町以下に掲載がない場合');
ok($zip->set_number('5050101')->is_valid_number, '岐阜県可児郡御嵩町大久後');
ok($zip->set_number('5050102')->is_valid_number, '岐阜県可児郡御嵩町前沢');
ok($zip->set_number('5050103')->is_valid_number, '岐阜県可児郡御嵩町津橋');
ok($zip->set_number('5050104')->is_valid_number, '岐阜県可児郡御嵩町謡坂');
ok($zip->set_number('5050105')->is_valid_number, '岐阜県可児郡御嵩町西洞');
ok($zip->set_number('5050106')->is_valid_number, '岐阜県可児郡御嵩町小原');
ok($zip->set_number('5050107')->is_valid_number, '岐阜県可児郡御嵩町上之郷');
ok($zip->set_number('5050108')->is_valid_number, '岐阜県可児郡御嵩町小和沢');
ok($zip->set_number('5050111')->is_valid_number, '岐阜県可児郡御嵩町次月');
ok($zip->set_number('5050112')->is_valid_number, '岐阜県可児郡御嵩町美佐野');
ok($zip->set_number('5050113')->is_valid_number, '岐阜県可児郡御嵩町宿');
ok($zip->set_number('5050114')->is_valid_number, '岐阜県可児郡御嵩町中切');
ok($zip->set_number('5050115')->is_valid_number, '岐阜県可児郡御嵩町井尻');
ok($zip->set_number('5050116')->is_valid_number, '岐阜県可児郡御嵩町御嵩');
ok($zip->set_number('5050121')->is_valid_number, '岐阜県可児郡御嵩町中');
ok($zip->set_number('5050122')->is_valid_number, '岐阜県可児郡御嵩町顔戸');
ok($zip->set_number('5050123')->is_valid_number, '岐阜県可児郡御嵩町古屋敷');
ok($zip->set_number('5050124')->is_valid_number, '岐阜県可児郡御嵩町比衣');
ok($zip->set_number('5050125')->is_valid_number, '岐阜県可児郡御嵩町伏見');
ok($zip->set_number('5050126')->is_valid_number, '岐阜県可児郡御嵩町上恵土');
ok($zip->set_number('5050130')->is_valid_number, '岐阜県可児市兼山');
ok($zip->set_number('5050300')->is_valid_number, '岐阜県加茂郡八百津町以下に掲載がない場合');
ok($zip->set_number('5050301')->is_valid_number, '岐阜県加茂郡八百津町八百津');
ok($zip->set_number('5050302')->is_valid_number, '岐阜県加茂郡八百津町錦織');
ok($zip->set_number('5050303')->is_valid_number, '岐阜県加茂郡八百津町伊岐津志');
ok($zip->set_number('5050304')->is_valid_number, '岐阜県加茂郡八百津町上牧野');
ok($zip->set_number('5050305')->is_valid_number, '岐阜県加茂郡八百津町和知');
ok($zip->set_number('5050306')->is_valid_number, '岐阜県加茂郡八百津町上飯田');
ok($zip->set_number('5050307')->is_valid_number, '岐阜県加茂郡八百津町野上');
ok($zip->set_number('5050421')->is_valid_number, '岐阜県加茂郡八百津町福地');
ok($zip->set_number('5050422')->is_valid_number, '岐阜県加茂郡八百津町久田見');
ok($zip->set_number('5050423')->is_valid_number, '岐阜県加茂郡八百津町上吉田');
ok($zip->set_number('5050531')->is_valid_number, '岐阜県加茂郡八百津町潮見');
ok($zip->set_number('5050532')->is_valid_number, '岐阜県加茂郡八百津町南戸');
ok($zip->set_number('5060000')->is_valid_number, '岐阜県高山市以下に掲載がない場合');
ok($zip->set_number('5060001')->is_valid_number, '岐阜県高山市冬頭町');
ok($zip->set_number('5060002')->is_valid_number, '岐阜県高山市問屋町');
ok($zip->set_number('5060003')->is_valid_number, '岐阜県高山市本母町');
ok($zip->set_number('5060004')->is_valid_number, '岐阜県高山市桐生町');
ok($zip->set_number('5060005')->is_valid_number, '岐阜県高山市七日町');
ok($zip->set_number('5060006')->is_valid_number, '岐阜県高山市神田町');
ok($zip->set_number('5060007')->is_valid_number, '岐阜県高山市総和町');
ok($zip->set_number('5060008')->is_valid_number, '岐阜県高山市初田町');
ok($zip->set_number('5060009')->is_valid_number, '岐阜県高山市花岡町');
ok($zip->set_number('5060011')->is_valid_number, '岐阜県高山市本町');
ok($zip->set_number('5060012')->is_valid_number, '岐阜県高山市八軒町');
ok($zip->set_number('5060013')->is_valid_number, '岐阜県高山市有楽町');
ok($zip->set_number('5060014')->is_valid_number, '岐阜県高山市相生町');
ok($zip->set_number('5060015')->is_valid_number, '岐阜県高山市花川町');
ok($zip->set_number('5060016')->is_valid_number, '岐阜県高山市末広町');
ok($zip->set_number('5060017')->is_valid_number, '岐阜県高山市朝日町');
ok($zip->set_number('5060021')->is_valid_number, '岐阜県高山市名田町');
ok($zip->set_number('5060022')->is_valid_number, '岐阜県高山市西町');
ok($zip->set_number('5060023')->is_valid_number, '岐阜県高山市川原町');
ok($zip->set_number('5060024')->is_valid_number, '岐阜県高山市上川原町');
ok($zip->set_number('5060025')->is_valid_number, '岐阜県高山市天満町');
ok($zip->set_number('5060026')->is_valid_number, '岐阜県高山市花里町');
ok($zip->set_number('5060031')->is_valid_number, '岐阜県高山市西之一色町');
ok($zip->set_number('5060032')->is_valid_number, '岐阜県高山市千島町');
ok($zip->set_number('5060033')->is_valid_number, '岐阜県高山市越後町');
ok($zip->set_number('5060034')->is_valid_number, '岐阜県高山市松倉町');
ok($zip->set_number('5060035')->is_valid_number, '岐阜県高山市新宮町');
ok($zip->set_number('5060041')->is_valid_number, '岐阜県高山市下切町');
ok($zip->set_number('5060042')->is_valid_number, '岐阜県高山市旭ケ丘町');
ok($zip->set_number('5060043')->is_valid_number, '岐阜県高山市中切町');
ok($zip->set_number('5060044')->is_valid_number, '岐阜県高山市上切町');
ok($zip->set_number('5060045')->is_valid_number, '岐阜県高山市赤保木町');
ok($zip->set_number('5060046')->is_valid_number, '岐阜県高山市下之切町');
ok($zip->set_number('5060047')->is_valid_number, '岐阜県高山市八日町');
ok($zip->set_number('5060048')->is_valid_number, '岐阜県高山市前原町');
ok($zip->set_number('5060051')->is_valid_number, '岐阜県高山市中山町');
ok($zip->set_number('5060052')->is_valid_number, '岐阜県高山市下岡本町');
ok($zip->set_number('5060053')->is_valid_number, '岐阜県高山市昭和町');
ok($zip->set_number('5060054')->is_valid_number, '岐阜県高山市岡本町');
ok($zip->set_number('5060055')->is_valid_number, '岐阜県高山市上岡本町');
ok($zip->set_number('5060056')->is_valid_number, '岐阜県高山市緑ケ丘町');
ok($zip->set_number('5060057')->is_valid_number, '岐阜県高山市匠ケ丘町');
ok($zip->set_number('5060058')->is_valid_number, '岐阜県高山市山田町');
ok($zip->set_number('5060059')->is_valid_number, '岐阜県高山市下林町');
ok($zip->set_number('5060101')->is_valid_number, '岐阜県高山市清見町牧ケ洞');
ok($zip->set_number('5060102')->is_valid_number, '岐阜県高山市清見町三日町');
ok($zip->set_number('5060103')->is_valid_number, '岐阜県高山市清見町藤瀬');
ok($zip->set_number('5060104')->is_valid_number, '岐阜県高山市清見町福寄');
ok($zip->set_number('5060105')->is_valid_number, '岐阜県高山市清見町三ツ谷');
ok($zip->set_number('5060106')->is_valid_number, '岐阜県高山市清見町坂下');
ok($zip->set_number('5060107')->is_valid_number, '岐阜県高山市清見町巣野俣');
ok($zip->set_number('5060201')->is_valid_number, '岐阜県高山市清見町江黒');
ok($zip->set_number('5060202')->is_valid_number, '岐阜県高山市清見町大谷');
ok($zip->set_number('5060203')->is_valid_number, '岐阜県高山市清見町池本');
ok($zip->set_number('5060204')->is_valid_number, '岐阜県高山市清見町二本木');
ok($zip->set_number('5060205')->is_valid_number, '岐阜県高山市清見町夏厩');
ok($zip->set_number('5060206')->is_valid_number, '岐阜県高山市清見町上小鳥');
ok($zip->set_number('5060207')->is_valid_number, '岐阜県高山市清見町森茂');
ok($zip->set_number('5060271')->is_valid_number, '岐阜県飛騨市河合町舟原');
ok($zip->set_number('5060801')->is_valid_number, '岐阜県高山市上野町');
ok($zip->set_number('5060802')->is_valid_number, '岐阜県高山市松之木町');
ok($zip->set_number('5060803')->is_valid_number, '岐阜県高山市日の出町');
ok($zip->set_number('5060804')->is_valid_number, '岐阜県高山市長坂町');
ok($zip->set_number('5060805')->is_valid_number, '岐阜県高山市東山町');
ok($zip->set_number('5060806')->is_valid_number, '岐阜県高山市曙町');
ok($zip->set_number('5060807')->is_valid_number, '岐阜県高山市三福寺町');
ok($zip->set_number('5060808')->is_valid_number, '岐阜県高山市松本町');
ok($zip->set_number('5060811')->is_valid_number, '岐阜県高山市大洞町');
ok($zip->set_number('5060812')->is_valid_number, '岐阜県高山市漆垣内町');
ok($zip->set_number('5060813')->is_valid_number, '岐阜県高山市塩屋町');
ok($zip->set_number('5060814')->is_valid_number, '岐阜県高山市滝町');
ok($zip->set_number('5060815')->is_valid_number, '岐阜県高山市岩井町');
ok($zip->set_number('5060816')->is_valid_number, '岐阜県高山市大島町');
ok($zip->set_number('5060817')->is_valid_number, '岐阜県高山市山口町');
ok($zip->set_number('5060818')->is_valid_number, '岐阜県高山市江名子町');
ok($zip->set_number('5060821')->is_valid_number, '岐阜県高山市神明町');
ok($zip->set_number('5060822')->is_valid_number, '岐阜県高山市城山');
ok($zip->set_number('5060823')->is_valid_number, '岐阜県高山市森下町');
ok($zip->set_number('5060824')->is_valid_number, '岐阜県高山市片野町');
ok($zip->set_number('5060825')->is_valid_number, '岐阜県高山市石浦町');
ok($zip->set_number('5060831')->is_valid_number, '岐阜県高山市吹屋町');
ok($zip->set_number('5060832')->is_valid_number, '岐阜県高山市天性寺町');
ok($zip->set_number('5060833')->is_valid_number, '岐阜県高山市西洞町');
ok($zip->set_number('5060834')->is_valid_number, '岐阜県高山市宗猷寺町');
ok($zip->set_number('5060835')->is_valid_number, '岐阜県高山市春日町');
ok($zip->set_number('5060836')->is_valid_number, '岐阜県高山市島川原町');
ok($zip->set_number('5060837')->is_valid_number, '岐阜県高山市堀端町');
ok($zip->set_number('5060838')->is_valid_number, '岐阜県高山市馬場町');
ok($zip->set_number('5060841')->is_valid_number, '岐阜県高山市下三之町');
ok($zip->set_number('5060842')->is_valid_number, '岐阜県高山市下二之町');
ok($zip->set_number('5060843')->is_valid_number, '岐阜県高山市下一之町');
ok($zip->set_number('5060844')->is_valid_number, '岐阜県高山市上一之町');
ok($zip->set_number('5060845')->is_valid_number, '岐阜県高山市上二之町');
ok($zip->set_number('5060846')->is_valid_number, '岐阜県高山市上三之町');
ok($zip->set_number('5060847')->is_valid_number, '岐阜県高山市片原町');
ok($zip->set_number('5060851')->is_valid_number, '岐阜県高山市大新町');
ok($zip->set_number('5060852')->is_valid_number, '岐阜県高山市八幡町');
ok($zip->set_number('5060853')->is_valid_number, '岐阜県高山市左京町');
ok($zip->set_number('5060854')->is_valid_number, '岐阜県高山市若達町');
ok($zip->set_number('5060855')->is_valid_number, '岐阜県高山市愛宕町');
ok($zip->set_number('5060856')->is_valid_number, '岐阜県高山市大門町');
ok($zip->set_number('5060857')->is_valid_number, '岐阜県高山市鉄砲町');
ok($zip->set_number('5060858')->is_valid_number, '岐阜県高山市桜町');
ok($zip->set_number('5061100')->is_valid_number, '岐阜県飛騨市以下に掲載がない場合');
ok($zip->set_number('5061101')->is_valid_number, '岐阜県飛騨市神岡町和佐府');
ok($zip->set_number('5061102')->is_valid_number, '岐阜県飛騨市神岡町打保');
ok($zip->set_number('5061103')->is_valid_number, '岐阜県飛騨市神岡町岩井谷');
ok($zip->set_number('5061104')->is_valid_number, '岐阜県飛騨市神岡町森茂');
ok($zip->set_number('5061105')->is_valid_number, '岐阜県飛騨市神岡町和佐保');
ok($zip->set_number('5061106')->is_valid_number, '岐阜県飛騨市神岡町伊西');
ok($zip->set_number('5061107')->is_valid_number, '岐阜県飛騨市神岡町下之本');
ok($zip->set_number('5061108')->is_valid_number, '岐阜県飛騨市神岡町瀬戸');
ok($zip->set_number('5061111')->is_valid_number, '岐阜県飛騨市神岡町東町');
ok($zip->set_number('5061111')->is_valid_number, '岐阜県飛騨市神岡町六郎');
ok($zip->set_number('5061112')->is_valid_number, '岐阜県飛騨市神岡町割石');
ok($zip->set_number('5061113')->is_valid_number, '岐阜県飛騨市神岡町吉ケ原');
ok($zip->set_number('5061114')->is_valid_number, '岐阜県飛騨市神岡町鹿間');
ok($zip->set_number('5061121')->is_valid_number, '岐阜県飛騨市神岡町旭ケ丘');
ok($zip->set_number('5061121')->is_valid_number, '岐阜県飛騨市神岡町殿');
ok($zip->set_number('5061122')->is_valid_number, '岐阜県飛騨市神岡町坂富町');
ok($zip->set_number('5061123')->is_valid_number, '岐阜県飛騨市神岡町城ケ丘');
ok($zip->set_number('5061124')->is_valid_number, '岐阜県飛騨市神岡町夕陽ケ丘');
ok($zip->set_number('5061125')->is_valid_number, '岐阜県飛騨市神岡町江馬町');
ok($zip->set_number('5061126')->is_valid_number, '岐阜県飛騨市神岡町桜ケ丘');
ok($zip->set_number('5061131')->is_valid_number, '岐阜県飛騨市神岡町麻生野');
ok($zip->set_number('5061132')->is_valid_number, '岐阜県飛騨市神岡町石神');
ok($zip->set_number('5061133')->is_valid_number, '岐阜県飛騨市神岡町数河');
ok($zip->set_number('5061141')->is_valid_number, '岐阜県飛騨市神岡町野首');
ok($zip->set_number('5061142')->is_valid_number, '岐阜県飛騨市神岡町丸山');
ok($zip->set_number('5061143')->is_valid_number, '岐阜県飛騨市神岡町小萱');
ok($zip->set_number('5061144')->is_valid_number, '岐阜県飛騨市神岡町吉田');
ok($zip->set_number('5061145')->is_valid_number, '岐阜県飛騨市神岡町釜崎');
ok($zip->set_number('5061146')->is_valid_number, '岐阜県飛騨市神岡町緑ケ丘');
ok($zip->set_number('5061147')->is_valid_number, '岐阜県飛騨市神岡町東雲');
ok($zip->set_number('5061148')->is_valid_number, '岐阜県飛騨市神岡町館野町');
ok($zip->set_number('5061149')->is_valid_number, '岐阜県飛騨市神岡町阿曽保');
ok($zip->set_number('5061151')->is_valid_number, '岐阜県飛騨市神岡町梨ケ根');
ok($zip->set_number('5061152')->is_valid_number, '岐阜県飛騨市神岡町寺林');
ok($zip->set_number('5061153')->is_valid_number, '岐阜県飛騨市神岡町堀之内');
ok($zip->set_number('5061154')->is_valid_number, '岐阜県飛騨市神岡町伏方');
ok($zip->set_number('5061155')->is_valid_number, '岐阜県飛騨市神岡町西');
ok($zip->set_number('5061156')->is_valid_number, '岐阜県飛騨市神岡町山田');
ok($zip->set_number('5061157')->is_valid_number, '岐阜県飛騨市神岡町巣山');
ok($zip->set_number('5061158')->is_valid_number, '岐阜県飛騨市神岡町柏原');
ok($zip->set_number('5061161')->is_valid_number, '岐阜県飛騨市神岡町船津');
ok($zip->set_number('5061161')->is_valid_number, '岐阜県飛騨市神岡町牧ケ平');
ok($zip->set_number('5061162')->is_valid_number, '岐阜県飛騨市神岡町朝浦');
ok($zip->set_number('5061201')->is_valid_number, '岐阜県飛騨市神岡町谷');
ok($zip->set_number('5061202')->is_valid_number, '岐阜県飛騨市神岡町中山');
ok($zip->set_number('5061203')->is_valid_number, '岐阜県飛騨市神岡町横山');
ok($zip->set_number('5061204')->is_valid_number, '岐阜県飛騨市神岡町杉山');
ok($zip->set_number('5061205')->is_valid_number, '岐阜県飛騨市神岡町東茂住');
ok($zip->set_number('5061206')->is_valid_number, '岐阜県飛騨市神岡町西茂住');
ok($zip->set_number('5061211')->is_valid_number, '岐阜県飛騨市神岡町佐古');
ok($zip->set_number('5061212')->is_valid_number, '岐阜県飛騨市神岡町跡津川');
ok($zip->set_number('5061213')->is_valid_number, '岐阜県飛騨市神岡町土');
ok($zip->set_number('5061214')->is_valid_number, '岐阜県飛騨市神岡町牧');
ok($zip->set_number('5061215')->is_valid_number, '岐阜県飛騨市神岡町西漆山');
ok($zip->set_number('5061216')->is_valid_number, '岐阜県飛騨市神岡町東漆山');
ok($zip->set_number('5061217')->is_valid_number, '岐阜県飛騨市神岡町二ツ屋');
ok($zip->set_number('5061301')->is_valid_number, '岐阜県高山市上宝町葛山');
ok($zip->set_number('5061302')->is_valid_number, '岐阜県高山市上宝町長倉');
ok($zip->set_number('5061303')->is_valid_number, '岐阜県高山市上宝町岩井戸');
ok($zip->set_number('5061304')->is_valid_number, '岐阜県高山市上宝町宮原');
ok($zip->set_number('5061305')->is_valid_number, '岐阜県高山市上宝町中山');
ok($zip->set_number('5061306')->is_valid_number, '岐阜県高山市上宝町見座');
ok($zip->set_number('5061307')->is_valid_number, '岐阜県高山市上宝町双六');
ok($zip->set_number('5061308')->is_valid_number, '岐阜県高山市上宝町金木戸');
ok($zip->set_number('5061311')->is_valid_number, '岐阜県高山市上宝町鼠餅');
ok($zip->set_number('5061312')->is_valid_number, '岐阜県高山市上宝町新田');
ok($zip->set_number('5061313')->is_valid_number, '岐阜県高山市上宝町在家');
ok($zip->set_number('5061314')->is_valid_number, '岐阜県高山市上宝町蔵柱');
ok($zip->set_number('5061315')->is_valid_number, '岐阜県高山市上宝町荒原');
ok($zip->set_number('5061316')->is_valid_number, '岐阜県高山市上宝町吉野');
ok($zip->set_number('5061317')->is_valid_number, '岐阜県高山市上宝町本郷');
ok($zip->set_number('5061318')->is_valid_number, '岐阜県高山市上宝町芋生茂');
ok($zip->set_number('5061319')->is_valid_number, '岐阜県高山市上宝町下佐谷');
ok($zip->set_number('5061421')->is_valid_number, '岐阜県高山市奥飛騨温泉郷神坂(新穂高)');
ok($zip->set_number('5061422')->is_valid_number, '岐阜県高山市奥飛騨温泉郷中尾');
ok($zip->set_number('5061423')->is_valid_number, '岐阜県高山市奥飛騨温泉郷栃尾');
ok($zip->set_number('5061424')->is_valid_number, '岐阜県高山市奥飛騨温泉郷柏当');
ok($zip->set_number('5061425')->is_valid_number, '岐阜県高山市奥飛騨温泉郷今見');
ok($zip->set_number('5061426')->is_valid_number, '岐阜県高山市奥飛騨温泉郷蓼之俣');
ok($zip->set_number('5061427')->is_valid_number, '岐阜県高山市奥飛騨温泉郷田頃家');
ok($zip->set_number('5061428')->is_valid_number, '岐阜県高山市奥飛騨温泉郷笹嶋');
ok($zip->set_number('5061429')->is_valid_number, '岐阜県高山市奥飛騨温泉郷赤桶');
ok($zip->set_number('5061431')->is_valid_number, '岐阜県高山市奥飛騨温泉郷村上');
ok($zip->set_number('5061432')->is_valid_number, '岐阜県高山市奥飛騨温泉郷一重ケ根');
ok($zip->set_number('5061433')->is_valid_number, '岐阜県高山市奥飛騨温泉郷平湯');
ok($zip->set_number('5061434')->is_valid_number, '岐阜県高山市奥飛騨温泉郷福地');
ok($zip->set_number('5062101')->is_valid_number, '岐阜県高山市丹生川町森部');
ok($zip->set_number('5062103')->is_valid_number, '岐阜県高山市丹生川町折敷地');
ok($zip->set_number('5062104')->is_valid_number, '岐阜県高山市丹生川町大沼');
ok($zip->set_number('5062105')->is_valid_number, '岐阜県高山市丹生川町三之瀬');
ok($zip->set_number('5062106')->is_valid_number, '岐阜県高山市丹生川町柏原');
ok($zip->set_number('5062111')->is_valid_number, '岐阜県高山市丹生川町瓜田');
ok($zip->set_number('5062112')->is_valid_number, '岐阜県高山市丹生川町板殿');
ok($zip->set_number('5062113')->is_valid_number, '岐阜県高山市丹生川町芦谷');
ok($zip->set_number('5062114')->is_valid_number, '岐阜県高山市丹生川町日影');
ok($zip->set_number('5062115')->is_valid_number, '岐阜県高山市丹生川町小野');
ok($zip->set_number('5062116')->is_valid_number, '岐阜県高山市丹生川町大谷');
ok($zip->set_number('5062117')->is_valid_number, '岐阜県高山市丹生川町根方');
ok($zip->set_number('5062118')->is_valid_number, '岐阜県高山市丹生川町白井');
ok($zip->set_number('5062121')->is_valid_number, '岐阜県高山市丹生川町坊方');
ok($zip->set_number('5062122')->is_valid_number, '岐阜県高山市丹生川町山口');
ok($zip->set_number('5062123')->is_valid_number, '岐阜県高山市丹生川町町方');
ok($zip->set_number('5062124')->is_valid_number, '岐阜県高山市丹生川町新張');
ok($zip->set_number('5062125')->is_valid_number, '岐阜県高山市丹生川町細越');
ok($zip->set_number('5062131')->is_valid_number, '岐阜県高山市丹生川町大萱');
ok($zip->set_number('5062132')->is_valid_number, '岐阜県高山市丹生川町法力');
ok($zip->set_number('5062133')->is_valid_number, '岐阜県高山市丹生川町北方');
ok($zip->set_number('5062134')->is_valid_number, '岐阜県高山市丹生川町桐山');
ok($zip->set_number('5062135')->is_valid_number, '岐阜県高山市丹生川町下保');
ok($zip->set_number('5062251')->is_valid_number, '岐阜県高山市丹生川町旗鉾');
ok($zip->set_number('5062252')->is_valid_number, '岐阜県高山市丹生川町久手');
ok($zip->set_number('5062253')->is_valid_number, '岐阜県高山市丹生川町池之俣');
ok($zip->set_number('5062254')->is_valid_number, '岐阜県高山市丹生川町岩井谷');
ok($zip->set_number('5062255')->is_valid_number, '岐阜県高山市丹生川町駄吉');
ok($zip->set_number('5062256')->is_valid_number, '岐阜県高山市丹生川町日面');
ok($zip->set_number('5062257')->is_valid_number, '岐阜県高山市丹生川町曽手');
ok($zip->set_number('5062258')->is_valid_number, '岐阜県高山市丹生川町塩屋');
ok($zip->set_number('5070000')->is_valid_number, '岐阜県多治見市以下に掲載がない場合');
ok($zip->set_number('5070001')->is_valid_number, '岐阜県多治見市小名田町小滝');
ok($zip->set_number('5070002')->is_valid_number, '岐阜県多治見市小名田町別山');
ok($zip->set_number('5070003')->is_valid_number, '岐阜県多治見市小名田町東谷');
ok($zip->set_number('5070004')->is_valid_number, '岐阜県多治見市小名田町');
ok($zip->set_number('5070005')->is_valid_number, '岐阜県多治見市小名田町岩ケ根');
ok($zip->set_number('5070006')->is_valid_number, '岐阜県多治見市小名田町西山');
ok($zip->set_number('5070007')->is_valid_number, '岐阜県多治見市小名田町西ケ洞');
ok($zip->set_number('5070008')->is_valid_number, '岐阜県多治見市希望ケ丘');
ok($zip->set_number('5070011')->is_valid_number, '岐阜県多治見市高田町岩曽根');
ok($zip->set_number('5070012')->is_valid_number, '岐阜県多治見市高田町白粉');
ok($zip->set_number('5070013')->is_valid_number, '岐阜県多治見市東栄町');
ok($zip->set_number('5070014')->is_valid_number, '岐阜県多治見市虎渓山町');
ok($zip->set_number('5070015')->is_valid_number, '岐阜県多治見市住吉町');
ok($zip->set_number('5070016')->is_valid_number, '岐阜県多治見市金岡町');
ok($zip->set_number('5070017')->is_valid_number, '岐阜県多治見市長瀬町');
ok($zip->set_number('5070018')->is_valid_number, '岐阜県多治見市高田町');
ok($zip->set_number('5070019')->is_valid_number, '岐阜県多治見市東山');
ok($zip->set_number('5070021')->is_valid_number, '岐阜県多治見市緑ケ丘');
ok($zip->set_number('5070022')->is_valid_number, '岐阜県多治見市上山町');
ok($zip->set_number('5070023')->is_valid_number, '岐阜県多治見市小田町');
ok($zip->set_number('5070024')->is_valid_number, '岐阜県多治見市大正町');
ok($zip->set_number('5070025')->is_valid_number, '岐阜県多治見市宮前町');
ok($zip->set_number('5070026')->is_valid_number, '岐阜県多治見市虎渓町');
ok($zip->set_number('5070027')->is_valid_number, '岐阜県多治見市上野町');
ok($zip->set_number('5070028')->is_valid_number, '岐阜県多治見市弁天町');
ok($zip->set_number('5070031')->is_valid_number, '岐阜県多治見市精華町');
ok($zip->set_number('5070032')->is_valid_number, '岐阜県多治見市大日町');
ok($zip->set_number('5070033')->is_valid_number, '岐阜県多治見市本町');
ok($zip->set_number('5070034')->is_valid_number, '岐阜県多治見市豊岡町');
ok($zip->set_number('5070035')->is_valid_number, '岐阜県多治見市栄町');
ok($zip->set_number('5070036')->is_valid_number, '岐阜県多治見市田代町');
ok($zip->set_number('5070037')->is_valid_number, '岐阜県多治見市音羽町');
ok($zip->set_number('5070038')->is_valid_number, '岐阜県多治見市白山町');
ok($zip->set_number('5070039')->is_valid_number, '岐阜県多治見市十九田町');
ok($zip->set_number('5070041')->is_valid_number, '岐阜県多治見市太平町');
ok($zip->set_number('5070042')->is_valid_number, '岐阜県多治見市前畑町');
ok($zip->set_number('5070043')->is_valid_number, '岐阜県多治見市月見町');
ok($zip->set_number('5070044')->is_valid_number, '岐阜県多治見市諏訪町');
ok($zip->set_number('5070045')->is_valid_number, '岐阜県多治見市三の倉町');
ok($zip->set_number('5070046')->is_valid_number, '岐阜県多治見市廿原町');
ok($zip->set_number('5070047')->is_valid_number, '岐阜県多治見市富士見町');
ok($zip->set_number('5070048')->is_valid_number, '岐阜県多治見市池田町');
ok($zip->set_number('5070051')->is_valid_number, '岐阜県多治見市西坂町');
ok($zip->set_number('5070052')->is_valid_number, '岐阜県多治見市光ケ丘');
ok($zip->set_number('5070053')->is_valid_number, '岐阜県多治見市若松町');
ok($zip->set_number('5070054')->is_valid_number, '岐阜県多治見市宝町');
ok($zip->set_number('5070055')->is_valid_number, '岐阜県多治見市喜多町');
ok($zip->set_number('5070056')->is_valid_number, '岐阜県多治見市美山町');
ok($zip->set_number('5070057')->is_valid_number, '岐阜県多治見市赤坂町');
ok($zip->set_number('5070058')->is_valid_number, '岐阜県多治見市平井町');
ok($zip->set_number('5070061')->is_valid_number, '岐阜県多治見市姫町');
ok($zip->set_number('5070062')->is_valid_number, '岐阜県多治見市大針町');
ok($zip->set_number('5070063')->is_valid_number, '岐阜県多治見市松坂町');
ok($zip->set_number('5070064')->is_valid_number, '岐阜県多治見市北丘町');
ok($zip->set_number('5070065')->is_valid_number, '岐阜県多治見市根本町');
ok($zip->set_number('5070066')->is_valid_number, '岐阜県多治見市西山町');
ok($zip->set_number('5070067')->is_valid_number, '岐阜県多治見市北小木町');
ok($zip->set_number('5070068')->is_valid_number, '岐阜県多治見市大薮町');
ok($zip->set_number('5070071')->is_valid_number, '岐阜県多治見市旭ケ丘');
ok($zip->set_number('5070072')->is_valid_number, '岐阜県多治見市明和町');
ok($zip->set_number('5070073')->is_valid_number, '岐阜県多治見市小泉町');
ok($zip->set_number('5070074')->is_valid_number, '岐阜県多治見市大原町');
ok($zip->set_number('5070075')->is_valid_number, '岐阜県多治見市大沢町');
ok($zip->set_number('5070076')->is_valid_number, '岐阜県多治見市昭栄町');
ok($zip->set_number('5070077')->is_valid_number, '岐阜県多治見市幸町');
ok($zip->set_number('5070078')->is_valid_number, '岐阜県多治見市高根町');
ok($zip->set_number('5070801')->is_valid_number, '岐阜県多治見市東町');
ok($zip->set_number('5070802')->is_valid_number, '岐阜県多治見市山吹町');
ok($zip->set_number('5070803')->is_valid_number, '岐阜県多治見市美坂町');
ok($zip->set_number('5070804')->is_valid_number, '岐阜県多治見市坂上町');
ok($zip->set_number('5070805')->is_valid_number, '岐阜県多治見市新富町');
ok($zip->set_number('5070806')->is_valid_number, '岐阜県多治見市上町');
ok($zip->set_number('5070807')->is_valid_number, '岐阜県多治見市生田町');
ok($zip->set_number('5070811')->is_valid_number, '岐阜県多治見市星ケ台');
ok($zip->set_number('5070812')->is_valid_number, '岐阜県多治見市下沢町');
ok($zip->set_number('5070813')->is_valid_number, '岐阜県多治見市滝呂町');
ok($zip->set_number('5070814')->is_valid_number, '岐阜県多治見市市之倉町');
ok($zip->set_number('5070815')->is_valid_number, '岐阜県多治見市大畑町赤松');
ok($zip->set_number('5070816')->is_valid_number, '岐阜県多治見市大畑町西仲根');
ok($zip->set_number('5070817')->is_valid_number, '岐阜県多治見市大畑町大洞');
ok($zip->set_number('5070818')->is_valid_number, '岐阜県多治見市大畑町');
ok($zip->set_number('5070821')->is_valid_number, '岐阜県多治見市窯町');
ok($zip->set_number('5070822')->is_valid_number, '岐阜県多治見市奥川町');
ok($zip->set_number('5070823')->is_valid_number, '岐阜県多治見市平野町');
ok($zip->set_number('5070824')->is_valid_number, '岐阜県多治見市元町');
ok($zip->set_number('5070825')->is_valid_number, '岐阜県多治見市京町');
ok($zip->set_number('5070826')->is_valid_number, '岐阜県多治見市脇之島町');
ok($zip->set_number('5070827')->is_valid_number, '岐阜県多治見市平和町');
ok($zip->set_number('5070828')->is_valid_number, '岐阜県多治見市三笠町');
ok($zip->set_number('5070831')->is_valid_number, '岐阜県多治見市新町');
ok($zip->set_number('5070832')->is_valid_number, '岐阜県多治見市金山町');
ok($zip->set_number('5070833')->is_valid_number, '岐阜県多治見市広小路');
ok($zip->set_number('5070834')->is_valid_number, '岐阜県多治見市御幸町');
ok($zip->set_number('5070835')->is_valid_number, '岐阜県多治見市錦町');
ok($zip->set_number('5070836')->is_valid_number, '岐阜県多治見市昭和町');
ok($zip->set_number('5070837')->is_valid_number, '岐阜県多治見市青木町');
ok($zip->set_number('5070838')->is_valid_number, '岐阜県多治見市末広町');
ok($zip->set_number('5070841')->is_valid_number, '岐阜県多治見市明治町');
ok($zip->set_number('5070842')->is_valid_number, '岐阜県多治見市中町');
ok($zip->set_number('5070843')->is_valid_number, '岐阜県多治見市常盤町');
ok($zip->set_number('5070844')->is_valid_number, '岐阜県多治見市陶元町');
ok($zip->set_number('5070845')->is_valid_number, '岐阜県多治見市山下町');
ok($zip->set_number('5070846')->is_valid_number, '岐阜県多治見市神楽町');
ok($zip->set_number('5070847')->is_valid_number, '岐阜県多治見市小路町');
ok($zip->set_number('5070848')->is_valid_number, '岐阜県多治見市日ノ出町');
ok($zip->set_number('5070901')->is_valid_number, '岐阜県多治見市笠原町');
ok($zip->set_number('5080000')->is_valid_number, '岐阜県中津川市以下に掲載がない場合');
ok($zip->set_number('5080001')->is_valid_number, '岐阜県中津川市中津川');
ok($zip->set_number('5080002')->is_valid_number, '岐阜県中津川市阿木(7637~7985)');
ok($zip->set_number('5080002')->is_valid_number, '岐阜県中津川市阿木川上');
ok($zip->set_number('5080003')->is_valid_number, '岐阜県中津川市中一色町');
ok($zip->set_number('5080004')->is_valid_number, '岐阜県中津川市花戸町');
ok($zip->set_number('5080005')->is_valid_number, '岐阜県中津川市日の出町');
ok($zip->set_number('5080006')->is_valid_number, '岐阜県中津川市落合');
ok($zip->set_number('5080007')->is_valid_number, '岐阜県中津川市神坂');
ok($zip->set_number('5080011')->is_valid_number, '岐阜県中津川市駒場');
ok($zip->set_number('5080012')->is_valid_number, '岐阜県中津川市津島町');
ok($zip->set_number('5080013')->is_valid_number, '岐阜県中津川市柳町');
ok($zip->set_number('5080014')->is_valid_number, '岐阜県中津川市駒場町');
ok($zip->set_number('5080015')->is_valid_number, '岐阜県中津川市手賀野');
ok($zip->set_number('5080021')->is_valid_number, '岐阜県中津川市中川町');
ok($zip->set_number('5080022')->is_valid_number, '岐阜県中津川市北野町');
ok($zip->set_number('5080023')->is_valid_number, '岐阜県中津川市小川町');
ok($zip->set_number('5080024')->is_valid_number, '岐阜県中津川市桃山町');
ok($zip->set_number('5080031')->is_valid_number, '岐阜県中津川市宮前町');
ok($zip->set_number('5080032')->is_valid_number, '岐阜県中津川市栄町');
ok($zip->set_number('5080033')->is_valid_number, '岐阜県中津川市太田町');
ok($zip->set_number('5080034')->is_valid_number, '岐阜県中津川市淀川町');
ok($zip->set_number('5080035')->is_valid_number, '岐阜県中津川市東町');
ok($zip->set_number('5080036')->is_valid_number, '岐阜県中津川市東宮町');
ok($zip->set_number('5080037')->is_valid_number, '岐阜県中津川市えびす町');
ok($zip->set_number('5080038')->is_valid_number, '岐阜県中津川市新町');
ok($zip->set_number('5080041')->is_valid_number, '岐阜県中津川市本町');
ok($zip->set_number('5080042')->is_valid_number, '岐阜県中津川市西宮町');
ok($zip->set_number('5080043')->is_valid_number, '岐阜県中津川市八幡町');
ok($zip->set_number('5080044')->is_valid_number, '岐阜県中津川市昭和町');
ok($zip->set_number('5080045')->is_valid_number, '岐阜県中津川市かやの木町');
ok($zip->set_number('5080101')->is_valid_number, '岐阜県中津川市苗木');
ok($zip->set_number('5080111')->is_valid_number, '岐阜県中津川市瀬戸');
ok($zip->set_number('5080201')->is_valid_number, '岐阜県中津川市田瀬');
ok($zip->set_number('5080202')->is_valid_number, '岐阜県中津川市下野');
ok($zip->set_number('5080203')->is_valid_number, '岐阜県中津川市福岡');
ok($zip->set_number('5080204')->is_valid_number, '岐阜県中津川市高山');
ok($zip->set_number('5080351')->is_valid_number, '岐阜県中津川市付知町');
ok($zip->set_number('5080421')->is_valid_number, '岐阜県中津川市加子母');
ok($zip->set_number('5080501')->is_valid_number, '岐阜県中津川市山口');
ok($zip->set_number('5080502')->is_valid_number, '岐阜県中津川市馬籠');
ok($zip->set_number('5090101')->is_valid_number, '岐阜県各務原市須衛');
ok($zip->set_number('5090102')->is_valid_number, '岐阜県各務原市各務車洞');
ok($zip->set_number('5090103')->is_valid_number, '岐阜県各務原市各務東町');
ok($zip->set_number('5090104')->is_valid_number, '岐阜県各務原市各務おがせ町');
ok($zip->set_number('5090105')->is_valid_number, '岐阜県各務原市各務山の前町');
ok($zip->set_number('5090106')->is_valid_number, '岐阜県各務原市各務西町');
ok($zip->set_number('5090107')->is_valid_number, '岐阜県各務原市各務船山町');
ok($zip->set_number('5090108')->is_valid_number, '岐阜県各務原市須衛町');
ok($zip->set_number('5090109')->is_valid_number, '岐阜県各務原市テクノプラザ');
ok($zip->set_number('5090111')->is_valid_number, '岐阜県各務原市鵜沼');
ok($zip->set_number('5090112')->is_valid_number, '岐阜県各務原市緑苑北');
ok($zip->set_number('5090113')->is_valid_number, '岐阜県各務原市緑苑東');
ok($zip->set_number('5090114')->is_valid_number, '岐阜県各務原市緑苑中');
ok($zip->set_number('5090115')->is_valid_number, '岐阜県各務原市緑苑南');
ok($zip->set_number('5090116')->is_valid_number, '岐阜県各務原市緑苑西');
ok($zip->set_number('5090117')->is_valid_number, '岐阜県各務原市鵜沼大安寺町');
ok($zip->set_number('5090118')->is_valid_number, '岐阜県各務原市各務山');
ok($zip->set_number('5090121')->is_valid_number, '岐阜県各務原市鵜沼台');
ok($zip->set_number('5090122')->is_valid_number, '岐阜県各務原市新鵜沼台');
ok($zip->set_number('5090123')->is_valid_number, '岐阜県各務原市鵜沼宝積寺町');
ok($zip->set_number('5090124')->is_valid_number, '岐阜県各務原市鵜沼山崎町');
ok($zip->set_number('5090125')->is_valid_number, '岐阜県各務原市鵜沼南町');
ok($zip->set_number('5090126')->is_valid_number, '岐阜県各務原市鵜沼東町');
ok($zip->set_number('5090127')->is_valid_number, '岐阜県各務原市桜木町');
ok($zip->set_number('5090131')->is_valid_number, '岐阜県各務原市つつじが丘');
ok($zip->set_number('5090132')->is_valid_number, '岐阜県各務原市鵜沼西町');
ok($zip->set_number('5090133')->is_valid_number, '岐阜県各務原市鵜沼古市場町');
ok($zip->set_number('5090134')->is_valid_number, '岐阜県各務原市鵜沼真名越町');
ok($zip->set_number('5090135')->is_valid_number, '岐阜県各務原市鵜沼羽場町');
ok($zip->set_number('5090136')->is_valid_number, '岐阜県各務原市松が丘');
ok($zip->set_number('5090141')->is_valid_number, '岐阜県各務原市鵜沼各務原町');
ok($zip->set_number('5090142')->is_valid_number, '岐阜県各務原市鵜沼丸子町');
ok($zip->set_number('5090143')->is_valid_number, '岐阜県各務原市鵜沼小伊木町');
ok($zip->set_number('5090144')->is_valid_number, '岐阜県各務原市鵜沼大伊木町');
ok($zip->set_number('5090145')->is_valid_number, '岐阜県各務原市鵜沼朝日町');
ok($zip->set_number('5090146')->is_valid_number, '岐阜県各務原市鵜沼三ツ池町');
ok($zip->set_number('5090147')->is_valid_number, '岐阜県各務原市鵜沼川崎町');
ok($zip->set_number('5090200')->is_valid_number, '岐阜県可児市以下に掲載がない場合');
ok($zip->set_number('5090201')->is_valid_number, '岐阜県可児市川合');
ok($zip->set_number('5090202')->is_valid_number, '岐阜県可児市中恵土');
ok($zip->set_number('5090203')->is_valid_number, '岐阜県可児市下恵土');
ok($zip->set_number('5090204')->is_valid_number, '岐阜県可児市禅台寺');
ok($zip->set_number('5090205')->is_valid_number, '岐阜県可児市徳野南');
ok($zip->set_number('5090206')->is_valid_number, '岐阜県可児市土田');
ok($zip->set_number('5090207')->is_valid_number, '岐阜県可児市今渡');
ok($zip->set_number('5090208')->is_valid_number, '岐阜県可児市川合北');
ok($zip->set_number('5090209')->is_valid_number, '岐阜県可児市下恵土(1、2丁目)');
ok($zip->set_number('5090211')->is_valid_number, '岐阜県可児市渕之上');
ok($zip->set_number('5090212')->is_valid_number, '岐阜県可児市柿田');
ok($zip->set_number('5090213')->is_valid_number, '岐阜県可児市瀬田');
ok($zip->set_number('5090214')->is_valid_number, '岐阜県可児市広見');
ok($zip->set_number('5090215')->is_valid_number, '岐阜県可児市石井');
ok($zip->set_number('5090216')->is_valid_number, '岐阜県可児市石森');
ok($zip->set_number('5090217')->is_valid_number, '岐阜県可児市平貝戸');
ok($zip->set_number('5090218')->is_valid_number, '岐阜県可児市松伏');
ok($zip->set_number('5090221')->is_valid_number, '岐阜県可児市広眺ケ丘');
ok($zip->set_number('5090222')->is_valid_number, '岐阜県可児市羽崎');
ok($zip->set_number('5090223')->is_valid_number, '岐阜県可児市羽生ケ丘');
ok($zip->set_number('5090224')->is_valid_number, '岐阜県可児市久々利');
ok($zip->set_number('5090230')->is_valid_number, '岐阜県可児市星見台');
ok($zip->set_number('5090231')->is_valid_number, '岐阜県可児市緑ケ丘');
ok($zip->set_number('5090232')->is_valid_number, '岐阜県可児市二野');
ok($zip->set_number('5090233')->is_valid_number, '岐阜県可児市柿下');
ok($zip->set_number('5090234')->is_valid_number, '岐阜県可児市久々利柿下入会');
ok($zip->set_number('5090235')->is_valid_number, '岐阜県可児市桜ケ丘');
ok($zip->set_number('5090236')->is_valid_number, '岐阜県可児市皐ケ丘');
ok($zip->set_number('5090237')->is_valid_number, '岐阜県可児市桂ケ丘');
ok($zip->set_number('5090238')->is_valid_number, '岐阜県可児市大森');
ok($zip->set_number('5090239')->is_valid_number, '岐阜県可児市大森台');
ok($zip->set_number('5090240')->is_valid_number, '岐阜県可児市みずきケ丘');
ok($zip->set_number('5090241')->is_valid_number, '岐阜県可児市坂戸');
ok($zip->set_number('5090242')->is_valid_number, '岐阜県可児市谷迫間');
ok($zip->set_number('5090245')->is_valid_number, '岐阜県可児市下切');
ok($zip->set_number('5090246')->is_valid_number, '岐阜県可児市今');
ok($zip->set_number('5090247')->is_valid_number, '岐阜県可児市塩河');
ok($zip->set_number('5090248')->is_valid_number, '岐阜県可児市清水ケ丘');
ok($zip->set_number('5090249')->is_valid_number, '岐阜県可児市姫ケ丘');
ok($zip->set_number('5090250')->is_valid_number, '岐阜県可児市美里ケ丘');
ok($zip->set_number('5090251')->is_valid_number, '岐阜県可児市塩');
ok($zip->set_number('5090252')->is_valid_number, '岐阜県可児市矢戸');
ok($zip->set_number('5090253')->is_valid_number, '岐阜県可児市室原');
ok($zip->set_number('5090254')->is_valid_number, '岐阜県可児市長洞');
ok($zip->set_number('5090255')->is_valid_number, '岐阜県可児市光陽台');
ok($zip->set_number('5090256')->is_valid_number, '岐阜県可児市東帷子');
ok($zip->set_number('5090257')->is_valid_number, '岐阜県可児市長坂');
ok($zip->set_number('5090258')->is_valid_number, '岐阜県可児市若葉台');
ok($zip->set_number('5090259')->is_valid_number, '岐阜県可児市愛岐ケ丘');
ok($zip->set_number('5090261')->is_valid_number, '岐阜県可児市虹ケ丘');
ok($zip->set_number('5090262')->is_valid_number, '岐阜県可児市菅刈');
ok($zip->set_number('5090263')->is_valid_number, '岐阜県可児市緑');
ok($zip->set_number('5090264')->is_valid_number, '岐阜県可児市鳩吹台');
ok($zip->set_number('5090265')->is_valid_number, '岐阜県可児市西帷子');
ok($zip->set_number('5090266')->is_valid_number, '岐阜県可児市帷子新町');
ok($zip->set_number('5090300')->is_valid_number, '岐阜県加茂郡川辺町以下に掲載がない場合');
ok($zip->set_number('5090301')->is_valid_number, '岐阜県加茂郡川辺町下麻生');
ok($zip->set_number('5090302')->is_valid_number, '岐阜県加茂郡川辺町上川辺');
ok($zip->set_number('5090303')->is_valid_number, '岐阜県加茂郡川辺町石神');
ok($zip->set_number('5090304')->is_valid_number, '岐阜県加茂郡川辺町中川辺');
ok($zip->set_number('5090305')->is_valid_number, '岐阜県加茂郡川辺町西栃井');
ok($zip->set_number('5090306')->is_valid_number, '岐阜県加茂郡川辺町下川辺');
ok($zip->set_number('5090307')->is_valid_number, '岐阜県加茂郡川辺町鹿塩');
ok($zip->set_number('5090311')->is_valid_number, '岐阜県加茂郡川辺町下吉田');
ok($zip->set_number('5090312')->is_valid_number, '岐阜県加茂郡川辺町中野');
ok($zip->set_number('5090313')->is_valid_number, '岐阜県加茂郡川辺町下飯田');
ok($zip->set_number('5090314')->is_valid_number, '岐阜県加茂郡川辺町福島');
ok($zip->set_number('5090315')->is_valid_number, '岐阜県加茂郡川辺町比久見');
ok($zip->set_number('5090400')->is_valid_number, '岐阜県加茂郡七宗町以下に掲載がない場合');
ok($zip->set_number('5090401')->is_valid_number, '岐阜県加茂郡七宗町上麻生');
ok($zip->set_number('5090402')->is_valid_number, '岐阜県加茂郡七宗町川並');
ok($zip->set_number('5090403')->is_valid_number, '岐阜県加茂郡七宗町中麻生');
ok($zip->set_number('5090511')->is_valid_number, '岐阜県加茂郡七宗町神渕');
ok($zip->set_number('5091100')->is_valid_number, '岐阜県加茂郡白川町以下に掲載がない場合');
ok($zip->set_number('5091101')->is_valid_number, '岐阜県加茂郡白川町白山');
ok($zip->set_number('5091102')->is_valid_number, '岐阜県加茂郡白川町中川');
ok($zip->set_number('5091103')->is_valid_number, '岐阜県加茂郡白川町水戸野');
ok($zip->set_number('5091104')->is_valid_number, '岐阜県加茂郡白川町和泉');
ok($zip->set_number('5091105')->is_valid_number, '岐阜県加茂郡白川町河岐');
ok($zip->set_number('5091106')->is_valid_number, '岐阜県加茂郡白川町坂ノ東');
ok($zip->set_number('5091107')->is_valid_number, '岐阜県加茂郡白川町河東');
ok($zip->set_number('5091108')->is_valid_number, '岐阜県加茂郡白川町広野');
ok($zip->set_number('5091111')->is_valid_number, '岐阜県加茂郡白川町切井');
ok($zip->set_number('5091112')->is_valid_number, '岐阜県加茂郡白川町赤河');
ok($zip->set_number('5091113')->is_valid_number, '岐阜県加茂郡白川町三川');
ok($zip->set_number('5091221')->is_valid_number, '岐阜県加茂郡白川町上佐見');
ok($zip->set_number('5091222')->is_valid_number, '岐阜県加茂郡白川町下佐見');
ok($zip->set_number('5091300')->is_valid_number, '岐阜県加茂郡東白川村以下に掲載がない場合');
ok($zip->set_number('5091301')->is_valid_number, '岐阜県加茂郡東白川村越原');
ok($zip->set_number('5091302')->is_valid_number, '岐阜県加茂郡東白川村神土');
ok($zip->set_number('5091303')->is_valid_number, '岐阜県加茂郡東白川村五加');
ok($zip->set_number('5091431')->is_valid_number, '岐阜県加茂郡白川町黒川');
ok($zip->set_number('5091601')->is_valid_number, '岐阜県下呂市金山町弓掛');
ok($zip->set_number('5091602')->is_valid_number, '岐阜県下呂市金山町卯野原');
ok($zip->set_number('5091603')->is_valid_number, '岐阜県下呂市金山町岩瀬');
ok($zip->set_number('5091604')->is_valid_number, '岐阜県下呂市金山町東沓部');
ok($zip->set_number('5091605')->is_valid_number, '岐阜県下呂市金山町戸部');
ok($zip->set_number('5091606')->is_valid_number, '岐阜県下呂市金山町祖師野');
ok($zip->set_number('5091607')->is_valid_number, '岐阜県下呂市金山町乙原');
ok($zip->set_number('5091611')->is_valid_number, '岐阜県下呂市金山町中切');
ok($zip->set_number('5091612')->is_valid_number, '岐阜県下呂市金山町福来');
ok($zip->set_number('5091613')->is_valid_number, '岐阜県下呂市金山町中津原');
ok($zip->set_number('5091614')->is_valid_number, '岐阜県下呂市金山町大船渡');
ok($zip->set_number('5091615')->is_valid_number, '岐阜県下呂市金山町田島');
ok($zip->set_number('5091616')->is_valid_number, '岐阜県下呂市金山町下原町');
ok($zip->set_number('5091621')->is_valid_number, '岐阜県下呂市金山町渡');
ok($zip->set_number('5091622')->is_valid_number, '岐阜県下呂市金山町金山');
ok($zip->set_number('5091623')->is_valid_number, '岐阜県下呂市金山町菅田桐洞');
ok($zip->set_number('5091624')->is_valid_number, '岐阜県下呂市金山町菅田笹洞');
ok($zip->set_number('5092131')->is_valid_number, '岐阜県下呂市久野川');
ok($zip->set_number('5092132')->is_valid_number, '岐阜県下呂市火打');
ok($zip->set_number('5092133')->is_valid_number, '岐阜県下呂市和佐');
ok($zip->set_number('5092134')->is_valid_number, '岐阜県下呂市焼石');
ok($zip->set_number('5092135')->is_valid_number, '岐阜県下呂市三ツ渕');
ok($zip->set_number('5092136')->is_valid_number, '岐阜県下呂市瀬戸');
ok($zip->set_number('5092137')->is_valid_number, '岐阜県下呂市保井戸');
ok($zip->set_number('5092138')->is_valid_number, '岐阜県下呂市門原');
ok($zip->set_number('5092200')->is_valid_number, '岐阜県下呂市以下に掲載がない場合');
ok($zip->set_number('5092201')->is_valid_number, '岐阜県下呂市東上田');
ok($zip->set_number('5092202')->is_valid_number, '岐阜県下呂市森');
ok($zip->set_number('5092203')->is_valid_number, '岐阜県下呂市小川');
ok($zip->set_number('5092204')->is_valid_number, '岐阜県下呂市三原');
ok($zip->set_number('5092205')->is_valid_number, '岐阜県下呂市少ケ野');
ok($zip->set_number('5092206')->is_valid_number, '岐阜県下呂市幸田');
ok($zip->set_number('5092207')->is_valid_number, '岐阜県下呂市湯之島');
ok($zip->set_number('5092311')->is_valid_number, '岐阜県下呂市乗政');
ok($zip->set_number('5092312')->is_valid_number, '岐阜県下呂市御厩野');
ok($zip->set_number('5092313')->is_valid_number, '岐阜県下呂市野尻');
ok($zip->set_number('5092314')->is_valid_number, '岐阜県下呂市宮地');
ok($zip->set_number('5092421')->is_valid_number, '岐阜県下呂市夏焼');
ok($zip->set_number('5092422')->is_valid_number, '岐阜県下呂市田口');
ok($zip->set_number('5092423')->is_valid_number, '岐阜県下呂市蛇之尾');
ok($zip->set_number('5092424')->is_valid_number, '岐阜県下呂市門和佐');
ok($zip->set_number('5092501')->is_valid_number, '岐阜県下呂市萩原町山之口');
ok($zip->set_number('5092502')->is_valid_number, '岐阜県下呂市萩原町四美');
ok($zip->set_number('5092503')->is_valid_number, '岐阜県下呂市萩原町西上田');
ok($zip->set_number('5092504')->is_valid_number, '岐阜県下呂市萩原町跡津');
ok($zip->set_number('5092505')->is_valid_number, '岐阜県下呂市萩原町古関');
ok($zip->set_number('5092506')->is_valid_number, '岐阜県下呂市萩原町羽根');
ok($zip->set_number('5092507')->is_valid_number, '岐阜県下呂市萩原町野上');
ok($zip->set_number('5092508')->is_valid_number, '岐阜県下呂市萩原町尾崎');
ok($zip->set_number('5092511')->is_valid_number, '岐阜県下呂市萩原町宮田');
ok($zip->set_number('5092512')->is_valid_number, '岐阜県下呂市萩原町大ヶ洞');
ok($zip->set_number('5092513')->is_valid_number, '岐阜県下呂市萩原町桜洞');
ok($zip->set_number('5092514')->is_valid_number, '岐阜県下呂市萩原町中呂');
ok($zip->set_number('5092515')->is_valid_number, '岐阜県下呂市萩原町花池');
ok($zip->set_number('5092516')->is_valid_number, '岐阜県下呂市萩原町上村');
ok($zip->set_number('5092517')->is_valid_number, '岐阜県下呂市萩原町萩原');
ok($zip->set_number('5092518')->is_valid_number, '岐阜県下呂市萩原町上呂');
ok($zip->set_number('5092519')->is_valid_number, '岐阜県下呂市萩原町奥田洞');
ok($zip->set_number('5092601')->is_valid_number, '岐阜県下呂市馬瀬川上');
ok($zip->set_number('5092602')->is_valid_number, '岐阜県下呂市馬瀬黒石');
ok($zip->set_number('5092603')->is_valid_number, '岐阜県下呂市馬瀬数河');
ok($zip->set_number('5092604')->is_valid_number, '岐阜県下呂市馬瀬中切');
ok($zip->set_number('5092611')->is_valid_number, '岐阜県下呂市馬瀬堀之内');
ok($zip->set_number('5092612')->is_valid_number, '岐阜県下呂市馬瀬名丸');
ok($zip->set_number('5092613')->is_valid_number, '岐阜県下呂市馬瀬井谷');
ok($zip->set_number('5092614')->is_valid_number, '岐阜県下呂市馬瀬惣島');
ok($zip->set_number('5092615')->is_valid_number, '岐阜県下呂市馬瀬西村');
ok($zip->set_number('5092701')->is_valid_number, '岐阜県高山市清見町楢谷');
ok($zip->set_number('5092702')->is_valid_number, '岐阜県高山市清見町大原');
ok($zip->set_number('5093101')->is_valid_number, '岐阜県下呂市小坂町岩崎');
ok($zip->set_number('5093102')->is_valid_number, '岐阜県下呂市小坂町門坂');
ok($zip->set_number('5093103')->is_valid_number, '岐阜県下呂市小坂町大垣内');
ok($zip->set_number('5093104')->is_valid_number, '岐阜県下呂市小坂町小坂町');
ok($zip->set_number('5093105')->is_valid_number, '岐阜県下呂市小坂町坂下');
ok($zip->set_number('5093106')->is_valid_number, '岐阜県下呂市小坂町大島');
ok($zip->set_number('5093107')->is_valid_number, '岐阜県下呂市小坂町無数原');
ok($zip->set_number('5093111')->is_valid_number, '岐阜県下呂市小坂町落合');
ok($zip->set_number('5093112')->is_valid_number, '岐阜県下呂市小坂町大洞');
ok($zip->set_number('5093113')->is_valid_number, '岐阜県下呂市小坂町湯屋');
ok($zip->set_number('5093114')->is_valid_number, '岐阜県下呂市小坂町赤沼田');
ok($zip->set_number('5093115')->is_valid_number, '岐阜県下呂市小坂町長瀬');
ok($zip->set_number('5093201')->is_valid_number, '岐阜県高山市久々野町大西');
ok($zip->set_number('5093202')->is_valid_number, '岐阜県高山市久々野町小屋名');
ok($zip->set_number('5093203')->is_valid_number, '岐阜県高山市久々野町柳島');
ok($zip->set_number('5093204')->is_valid_number, '岐阜県高山市久々野町久須母');
ok($zip->set_number('5093205')->is_valid_number, '岐阜県高山市久々野町久々野');
ok($zip->set_number('5093206')->is_valid_number, '岐阜県高山市久々野町山梨');
ok($zip->set_number('5093207')->is_valid_number, '岐阜県高山市久々野町辻');
ok($zip->set_number('5093211')->is_valid_number, '岐阜県高山市久々野町小坊');
ok($zip->set_number('5093212')->is_valid_number, '岐阜県高山市久々野町阿多粕');
ok($zip->set_number('5093213')->is_valid_number, '岐阜県高山市久々野町渚');
ok($zip->set_number('5093214')->is_valid_number, '岐阜県高山市久々野町無数河');
ok($zip->set_number('5093215')->is_valid_number, '岐阜県高山市久々野町引下');
ok($zip->set_number('5093216')->is_valid_number, '岐阜県高山市久々野町木賊洞');
ok($zip->set_number('5093217')->is_valid_number, '岐阜県高山市久々野町長淀');
ok($zip->set_number('5093218')->is_valid_number, '岐阜県高山市久々野町有道');
ok($zip->set_number('5093301')->is_valid_number, '岐阜県高山市朝日町青屋');
ok($zip->set_number('5093302')->is_valid_number, '岐阜県高山市朝日町寺附');
ok($zip->set_number('5093303')->is_valid_number, '岐阜県高山市朝日町浅井');
ok($zip->set_number('5093304')->is_valid_number, '岐阜県高山市朝日町立岩');
ok($zip->set_number('5093305')->is_valid_number, '岐阜県高山市朝日町小瀬');
ok($zip->set_number('5093306')->is_valid_number, '岐阜県高山市朝日町見座');
ok($zip->set_number('5093311')->is_valid_number, '岐阜県高山市朝日町一之宿');
ok($zip->set_number('5093312')->is_valid_number, '岐阜県高山市朝日町桑之島');
ok($zip->set_number('5093313')->is_valid_number, '岐阜県高山市朝日町胡桃島');
ok($zip->set_number('5093314')->is_valid_number, '岐阜県高山市朝日町西洞(スズラン高原)');
ok($zip->set_number('5093315')->is_valid_number, '岐阜県高山市朝日町宮之前');
ok($zip->set_number('5093316')->is_valid_number, '岐阜県高山市朝日町黍生谷');
ok($zip->set_number('5093317')->is_valid_number, '岐阜県高山市朝日町小瀬ケ洞');
ok($zip->set_number('5093321')->is_valid_number, '岐阜県高山市朝日町黒川');
ok($zip->set_number('5093322')->is_valid_number, '岐阜県高山市朝日町大廣');
ok($zip->set_number('5093323')->is_valid_number, '岐阜県高山市朝日町寺澤');
ok($zip->set_number('5093324')->is_valid_number, '岐阜県高山市朝日町上ケ見');
ok($zip->set_number('5093325')->is_valid_number, '岐阜県高山市朝日町万石');
ok($zip->set_number('5093326')->is_valid_number, '岐阜県高山市朝日町甲');
ok($zip->set_number('5093327')->is_valid_number, '岐阜県高山市朝日町小谷');
ok($zip->set_number('5093401')->is_valid_number, '岐阜県高山市高根町阿多野郷');
ok($zip->set_number('5093402')->is_valid_number, '岐阜県高山市高根町野麦');
ok($zip->set_number('5093403')->is_valid_number, '岐阜県高山市高根町日和田');
ok($zip->set_number('5093404')->is_valid_number, '岐阜県高山市高根町小日和田');
ok($zip->set_number('5093405')->is_valid_number, '岐阜県高山市高根町留之原');
ok($zip->set_number('5093411')->is_valid_number, '岐阜県高山市高根町上ケ洞');
ok($zip->set_number('5093412')->is_valid_number, '岐阜県高山市高根町大古井');
ok($zip->set_number('5093413')->is_valid_number, '岐阜県高山市高根町下之向');
ok($zip->set_number('5093414')->is_valid_number, '岐阜県高山市高根町中之宿');
ok($zip->set_number('5093415')->is_valid_number, '岐阜県高山市高根町猪之鼻');
ok($zip->set_number('5093416')->is_valid_number, '岐阜県高山市高根町中洞');
ok($zip->set_number('5093417')->is_valid_number, '岐阜県高山市高根町池ケ洞');
ok($zip->set_number('5093418')->is_valid_number, '岐阜県高山市高根町黍生');
ok($zip->set_number('5093419')->is_valid_number, '岐阜県高山市高根町日影');
ok($zip->set_number('5093505')->is_valid_number, '岐阜県高山市一之宮町');
ok($zip->set_number('5094101')->is_valid_number, '岐阜県高山市国府町桐谷');
ok($zip->set_number('5094102')->is_valid_number, '岐阜県高山市国府町八日町');
ok($zip->set_number('5094103')->is_valid_number, '岐阜県高山市国府町宮地');
ok($zip->set_number('5094104')->is_valid_number, '岐阜県高山市国府町今');
ok($zip->set_number('5094105')->is_valid_number, '岐阜県高山市国府町蓑輪');
ok($zip->set_number('5094106')->is_valid_number, '岐阜県高山市国府町漆垣内');
ok($zip->set_number('5094107')->is_valid_number, '岐阜県高山市国府町西門前');
ok($zip->set_number('5094108')->is_valid_number, '岐阜県高山市国府町東門前');
ok($zip->set_number('5094111')->is_valid_number, '岐阜県高山市国府町山本');
ok($zip->set_number('5094112')->is_valid_number, '岐阜県高山市国府町鶴巣');
ok($zip->set_number('5094113')->is_valid_number, '岐阜県高山市国府町木曽垣内');
ok($zip->set_number('5094114')->is_valid_number, '岐阜県高山市国府町半田');
ok($zip->set_number('5094115')->is_valid_number, '岐阜県高山市国府町三日町');
ok($zip->set_number('5094116')->is_valid_number, '岐阜県高山市国府町上広瀬');
ok($zip->set_number('5094117')->is_valid_number, '岐阜県高山市国府町三川');
ok($zip->set_number('5094119')->is_valid_number, '岐阜県高山市国府町広瀬町(桜野)');
ok($zip->set_number('5094121')->is_valid_number, '岐阜県高山市国府町宇津江');
ok($zip->set_number('5094122')->is_valid_number, '岐阜県高山市国府町名張');
ok($zip->set_number('5094123')->is_valid_number, '岐阜県高山市国府町金桶');
ok($zip->set_number('5094124')->is_valid_number, '岐阜県高山市国府町村山');
ok($zip->set_number('5094125')->is_valid_number, '岐阜県高山市国府町糠塚');
ok($zip->set_number('5094126')->is_valid_number, '岐阜県高山市国府町瓜巣');
ok($zip->set_number('5094201')->is_valid_number, '岐阜県飛騨市古川町数河');
ok($zip->set_number('5094202')->is_valid_number, '岐阜県飛騨市古川町戸市');
ok($zip->set_number('5094203')->is_valid_number, '岐阜県飛騨市古川町袈裟丸');
ok($zip->set_number('5094204')->is_valid_number, '岐阜県飛騨市古川町野口');
ok($zip->set_number('5094205')->is_valid_number, '岐阜県飛騨市古川町末真');
ok($zip->set_number('5094211')->is_valid_number, '岐阜県飛騨市古川町太江');
ok($zip->set_number('5094212')->is_valid_number, '岐阜県飛騨市古川町上気多');
ok($zip->set_number('5094213')->is_valid_number, '岐阜県飛騨市古川町下気多');
ok($zip->set_number('5094214')->is_valid_number, '岐阜県飛騨市古川町沼町');
ok($zip->set_number('5094215')->is_valid_number, '岐阜県飛騨市古川町杉崎');
ok($zip->set_number('5094221')->is_valid_number, '岐阜県飛騨市古川町若宮');
ok($zip->set_number('5094222')->is_valid_number, '岐阜県飛騨市古川町片原町');
ok($zip->set_number('5094223')->is_valid_number, '岐阜県飛騨市古川町東町');
ok($zip->set_number('5094224')->is_valid_number, '岐阜県飛騨市古川町殿町');
ok($zip->set_number('5094225')->is_valid_number, '岐阜県飛騨市古川町金森町');
ok($zip->set_number('5094231')->is_valid_number, '岐阜県飛騨市古川町新栄町');
ok($zip->set_number('5094232')->is_valid_number, '岐阜県飛騨市古川町本町');
ok($zip->set_number('5094233')->is_valid_number, '岐阜県飛騨市古川町末広町');
ok($zip->set_number('5094234')->is_valid_number, '岐阜県飛騨市古川町壱之町');
ok($zip->set_number('5094235')->is_valid_number, '岐阜県飛騨市古川町弐之町');
ok($zip->set_number('5094236')->is_valid_number, '岐阜県飛騨市古川町三之町');
ok($zip->set_number('5094237')->is_valid_number, '岐阜県飛騨市古川町栄');
ok($zip->set_number('5094241')->is_valid_number, '岐阜県飛騨市古川町向町');
ok($zip->set_number('5094242')->is_valid_number, '岐阜県飛騨市古川町増島町');
ok($zip->set_number('5094243')->is_valid_number, '岐阜県飛騨市古川町貴船町');
ok($zip->set_number('5094244')->is_valid_number, '岐阜県飛騨市古川町是重');
ok($zip->set_number('5094245')->is_valid_number, '岐阜県飛騨市古川町幸栄町');
ok($zip->set_number('5094251')->is_valid_number, '岐阜県飛騨市古川町宮城町');
ok($zip->set_number('5094252')->is_valid_number, '岐阜県飛騨市古川町朝開町');
ok($zip->set_number('5094253')->is_valid_number, '岐阜県飛騨市古川町南成町');
ok($zip->set_number('5094254')->is_valid_number, '岐阜県飛騨市古川町上町');
ok($zip->set_number('5094255')->is_valid_number, '岐阜県飛騨市古川町大野町');
ok($zip->set_number('5094256')->is_valid_number, '岐阜県飛騨市古川町高野');
ok($zip->set_number('5094261')->is_valid_number, '岐阜県飛騨市古川町下野');
ok($zip->set_number('5094262')->is_valid_number, '岐阜県飛騨市古川町中野');
ok($zip->set_number('5094263')->is_valid_number, '岐阜県飛騨市古川町上野');
ok($zip->set_number('5094264')->is_valid_number, '岐阜県飛騨市古川町平岩');
ok($zip->set_number('5094265')->is_valid_number, '岐阜県飛騨市古川町畦畑');
ok($zip->set_number('5094271')->is_valid_number, '岐阜県飛騨市古川町谷');
ok($zip->set_number('5094272')->is_valid_number, '岐阜県飛騨市古川町信包');
ok($zip->set_number('5094273')->is_valid_number, '岐阜県飛騨市古川町寺地');
ok($zip->set_number('5094274')->is_valid_number, '岐阜県飛騨市古川町笹ケ洞');
ok($zip->set_number('5094275')->is_valid_number, '岐阜県飛騨市古川町黒内');
ok($zip->set_number('5094301')->is_valid_number, '岐阜県飛騨市河合町角川');
ok($zip->set_number('5094302')->is_valid_number, '岐阜県飛騨市河合町小無雁');
ok($zip->set_number('5094303')->is_valid_number, '岐阜県飛騨市河合町有家');
ok($zip->set_number('5094304')->is_valid_number, '岐阜県飛騨市河合町羽根');
ok($zip->set_number('5094305')->is_valid_number, '岐阜県飛騨市河合町保木林');
ok($zip->set_number('5094306')->is_valid_number, '岐阜県飛騨市河合町中沢上');
ok($zip->set_number('5094311')->is_valid_number, '岐阜県飛騨市河合町大谷');
ok($zip->set_number('5094312')->is_valid_number, '岐阜県飛騨市河合町稲越');
ok($zip->set_number('5094313')->is_valid_number, '岐阜県飛騨市河合町保');
ok($zip->set_number('5094314')->is_valid_number, '岐阜県飛騨市河合町月ケ瀬');
ok($zip->set_number('5094315')->is_valid_number, '岐阜県飛騨市河合町天生');
ok($zip->set_number('5094316')->is_valid_number, '岐阜県飛騨市河合町元田');
ok($zip->set_number('5094317')->is_valid_number, '岐阜県飛騨市河合町上ケ島');
ok($zip->set_number('5094318')->is_valid_number, '岐阜県飛騨市河合町新名');
ok($zip->set_number('5094401')->is_valid_number, '岐阜県飛騨市宮川町菅沼');
ok($zip->set_number('5094402')->is_valid_number, '岐阜県飛騨市宮川町種蔵');
ok($zip->set_number('5094403')->is_valid_number, '岐阜県飛騨市宮川町三川原');
ok($zip->set_number('5094404')->is_valid_number, '岐阜県飛騨市宮川町巣之内');
ok($zip->set_number('5094405')->is_valid_number, '岐阜県飛騨市宮川町丸山');
ok($zip->set_number('5094406')->is_valid_number, '岐阜県飛騨市宮川町牧戸');
ok($zip->set_number('5094411')->is_valid_number, '岐阜県飛騨市宮川町野首');
ok($zip->set_number('5094412')->is_valid_number, '岐阜県飛騨市宮川町岸奥');
ok($zip->set_number('5094413')->is_valid_number, '岐阜県飛騨市宮川町小谷');
ok($zip->set_number('5094414')->is_valid_number, '岐阜県飛騨市宮川町大無雁');
ok($zip->set_number('5094415')->is_valid_number, '岐阜県飛騨市宮川町落合');
ok($zip->set_number('5094421')->is_valid_number, '岐阜県飛騨市宮川町高牧');
ok($zip->set_number('5094422')->is_valid_number, '岐阜県飛騨市宮川町西忍');
ok($zip->set_number('5094423')->is_valid_number, '岐阜県飛騨市宮川町林');
ok($zip->set_number('5094424')->is_valid_number, '岐阜県飛騨市宮川町森安');
ok($zip->set_number('5094531')->is_valid_number, '岐阜県飛騨市宮川町鮎飛');
ok($zip->set_number('5094531')->is_valid_number, '岐阜県飛騨市宮川町巣納谷');
ok($zip->set_number('5094532')->is_valid_number, '岐阜県飛騨市宮川町洞');
ok($zip->set_number('5094533')->is_valid_number, '岐阜県飛騨市宮川町塩屋');
ok($zip->set_number('5094534')->is_valid_number, '岐阜県飛騨市宮川町中沢上');
ok($zip->set_number('5094535')->is_valid_number, '岐阜県飛騨市宮川町祢宜ケ沢上');
ok($zip->set_number('5094541')->is_valid_number, '岐阜県飛騨市宮川町小豆沢');
ok($zip->set_number('5094542')->is_valid_number, '岐阜県飛騨市宮川町杉原');
ok($zip->set_number('5094543')->is_valid_number, '岐阜県飛騨市宮川町桑野');
ok($zip->set_number('5094544')->is_valid_number, '岐阜県飛騨市宮川町戸谷');
ok($zip->set_number('5094545')->is_valid_number, '岐阜県飛騨市宮川町打保');
ok($zip->set_number('5095100')->is_valid_number, '岐阜県土岐市以下に掲載がない場合');
ok($zip->set_number('5095101')->is_valid_number, '岐阜県土岐市泉町河合');
ok($zip->set_number('5095102')->is_valid_number, '岐阜県土岐市泉町定林寺');
ok($zip->set_number('5095103')->is_valid_number, '岐阜県土岐市泉東窯町');
ok($zip->set_number('5095104')->is_valid_number, '岐阜県土岐市泉中窯町');
ok($zip->set_number('5095105')->is_valid_number, '岐阜県土岐市泉西窯町');
ok($zip->set_number('5095106')->is_valid_number, '岐阜県土岐市泉仲森町');
ok($zip->set_number('5095107')->is_valid_number, '岐阜県土岐市泉梅ノ木町');
ok($zip->set_number('5095111')->is_valid_number, '岐阜県土岐市肥田浅野双葉町');
ok($zip->set_number('5095112')->is_valid_number, '岐阜県土岐市肥田浅野笠神町');
ok($zip->set_number('5095113')->is_valid_number, '岐阜県土岐市肥田浅野元町');
ok($zip->set_number('5095114')->is_valid_number, '岐阜県土岐市肥田町浅野');
ok($zip->set_number('5095115')->is_valid_number, '岐阜県土岐市肥田町肥田(その他)');
ok($zip->set_number('5095116')->is_valid_number, '岐阜県土岐市肥田浅野矢落町');
ok($zip->set_number('5095117')->is_valid_number, '岐阜県土岐市肥田浅野朝日町');
ok($zip->set_number('5095118')->is_valid_number, '岐阜県土岐市肥田浅野梅ノ木町');
ok($zip->set_number('5095121')->is_valid_number, '岐阜県土岐市土岐津町高山');
ok($zip->set_number('5095122')->is_valid_number, '岐阜県土岐市土岐津町土岐口');
ok($zip->set_number('5095123')->is_valid_number, '岐阜県土岐市土岐口南町');
ok($zip->set_number('5095124')->is_valid_number, '岐阜県土岐市土岐口中町');
ok($zip->set_number('5095125')->is_valid_number, '岐阜県土岐市御幸町');
ok($zip->set_number('5095126')->is_valid_number, '岐阜県土岐市土岐口北町');
ok($zip->set_number('5095127')->is_valid_number, '岐阜県土岐市土岐ヶ丘');
ok($zip->set_number('5095131')->is_valid_number, '岐阜県土岐市泉寺田町');
ok($zip->set_number('5095132')->is_valid_number, '岐阜県土岐市泉町大富');
ok($zip->set_number('5095133')->is_valid_number, '岐阜県土岐市泉神栄町');
ok($zip->set_number('5095134')->is_valid_number, '岐阜県土岐市泉島田町');
ok($zip->set_number('5095135')->is_valid_number, '岐阜県土岐市泉森下町');
ok($zip->set_number('5095136')->is_valid_number, '岐阜県土岐市泉大島町');
ok($zip->set_number('5095141')->is_valid_number, '岐阜県土岐市泉岩畑町');
ok($zip->set_number('5095142')->is_valid_number, '岐阜県土岐市泉町久尻');
ok($zip->set_number('5095143')->is_valid_number, '岐阜県土岐市泉日之出町');
ok($zip->set_number('5095144')->is_valid_number, '岐阜県土岐市泉池ノ上町');
ok($zip->set_number('5095145')->is_valid_number, '岐阜県土岐市泉大沼町');
ok($zip->set_number('5095146')->is_valid_number, '岐阜県土岐市泉明治町');
ok($zip->set_number('5095147')->is_valid_number, '岐阜県土岐市泉郷町');
ok($zip->set_number('5095151')->is_valid_number, '岐阜県土岐市泉大坪町');
ok($zip->set_number('5095152')->is_valid_number, '岐阜県土岐市泉寺下町');
ok($zip->set_number('5095153')->is_valid_number, '岐阜県土岐市泉西原町');
ok($zip->set_number('5095154')->is_valid_number, '岐阜県土岐市泉西山町');
ok($zip->set_number('5095161')->is_valid_number, '岐阜県土岐市泉が丘町');
ok($zip->set_number('5095171')->is_valid_number, '岐阜県土岐市泉北山町');
ok($zip->set_number('5095201')->is_valid_number, '岐阜県土岐市下石阿庄町');
ok($zip->set_number('5095202')->is_valid_number, '岐阜県土岐市下石町');
ok($zip->set_number('5095203')->is_valid_number, '岐阜県土岐市下石陶史台');
ok($zip->set_number('5095301')->is_valid_number, '岐阜県土岐市妻木町');
ok($zip->set_number('5095302')->is_valid_number, '岐阜県土岐市妻木平成町');
ok($zip->set_number('5095311')->is_valid_number, '岐阜県土岐市鶴里町細野');
ok($zip->set_number('5095312')->is_valid_number, '岐阜県土岐市鶴里町柿野');
ok($zip->set_number('5095401')->is_valid_number, '岐阜県土岐市駄知町');
ok($zip->set_number('5095402')->is_valid_number, '岐阜県土岐市曽木町');
ok($zip->set_number('5095403')->is_valid_number, '岐阜県土岐市旭ケ丘町');
ok($zip->set_number('5095403')->is_valid_number, '岐阜県土岐市肥田町肥田(286~287番地)');
ok($zip->set_number('5096100')->is_valid_number, '岐阜県瑞浪市以下に掲載がない場合');
ok($zip->set_number('5096101')->is_valid_number, '岐阜県瑞浪市土岐町');
ok($zip->set_number('5096102')->is_valid_number, '岐阜県瑞浪市稲津町萩原');
ok($zip->set_number('5096103')->is_valid_number, '岐阜県瑞浪市稲津町小里');
ok($zip->set_number('5096104')->is_valid_number, '岐阜県瑞浪市山田町');
ok($zip->set_number('5096105')->is_valid_number, '岐阜県瑞浪市明賀台');
ok($zip->set_number('5096106')->is_valid_number, '岐阜県瑞浪市学園台');
ok($zip->set_number('5096107')->is_valid_number, '岐阜県瑞浪市穂並');
ok($zip->set_number('5096108')->is_valid_number, '岐阜県瑞浪市益見町');
ok($zip->set_number('5096111')->is_valid_number, '岐阜県瑞浪市下沖町');
ok($zip->set_number('5096112')->is_valid_number, '岐阜県瑞浪市小田町');
ok($zip->set_number('5096113')->is_valid_number, '岐阜県瑞浪市和合町');
ok($zip->set_number('5096114')->is_valid_number, '岐阜県瑞浪市西小田町');
ok($zip->set_number('5096115')->is_valid_number, '岐阜県瑞浪市北小田町');
ok($zip->set_number('5096116')->is_valid_number, '岐阜県瑞浪市南小田町');
ok($zip->set_number('5096121')->is_valid_number, '岐阜県瑞浪市寺河戸町');
ok($zip->set_number('5096122')->is_valid_number, '岐阜県瑞浪市上平町');
ok($zip->set_number('5096123')->is_valid_number, '岐阜県瑞浪市樽上町');
ok($zip->set_number('5096124')->is_valid_number, '岐阜県瑞浪市一色町');
ok($zip->set_number('5096125')->is_valid_number, '岐阜県瑞浪市上野町');
ok($zip->set_number('5096126')->is_valid_number, '岐阜県瑞浪市高月町');
ok($zip->set_number('5096127')->is_valid_number, '岐阜県瑞浪市須野志町');
ok($zip->set_number('5096128')->is_valid_number, '岐阜県瑞浪市宮前町');
ok($zip->set_number('5096131')->is_valid_number, '岐阜県瑞浪市明世町月吉');
ok($zip->set_number('5096132')->is_valid_number, '岐阜県瑞浪市明世町山野内');
ok($zip->set_number('5096133')->is_valid_number, '岐阜県瑞浪市明世町戸狩');
ok($zip->set_number('5096134')->is_valid_number, '岐阜県瑞浪市松ケ瀬町');
ok($zip->set_number('5096135')->is_valid_number, '岐阜県瑞浪市薬師町');
ok($zip->set_number('5096251')->is_valid_number, '岐阜県瑞浪市日吉町');
ok($zip->set_number('5096361')->is_valid_number, '岐阜県瑞浪市陶町猿爪');
ok($zip->set_number('5096362')->is_valid_number, '岐阜県瑞浪市陶町水上');
ok($zip->set_number('5096363')->is_valid_number, '岐阜県瑞浪市陶町大川');
ok($zip->set_number('5096471')->is_valid_number, '岐阜県瑞浪市大湫町');
ok($zip->set_number('5096472')->is_valid_number, '岐阜県瑞浪市釜戸町');
ok($zip->set_number('5097121')->is_valid_number, '岐阜県恵那市武並町藤');
ok($zip->set_number('5097122')->is_valid_number, '岐阜県恵那市武並町竹折');
ok($zip->set_number('5097123')->is_valid_number, '岐阜県恵那市三郷町野井');
ok($zip->set_number('5097124')->is_valid_number, '岐阜県恵那市三郷町佐々良木');
ok($zip->set_number('5097125')->is_valid_number, '岐阜県恵那市三郷町椋実');
ok($zip->set_number('5097126')->is_valid_number, '岐阜県恵那市武並町新竹折');
ok($zip->set_number('5097200')->is_valid_number, '岐阜県恵那市以下に掲載がない場合');
ok($zip->set_number('5097201')->is_valid_number, '岐阜県恵那市大井町');
ok($zip->set_number('5097202')->is_valid_number, '岐阜県恵那市東野');
ok($zip->set_number('5097203')->is_valid_number, '岐阜県恵那市長島町正家');
ok($zip->set_number('5097204')->is_valid_number, '岐阜県恵那市長島町永田');
ok($zip->set_number('5097205')->is_valid_number, '岐阜県恵那市長島町中野');
ok($zip->set_number('5097206')->is_valid_number, '岐阜県恵那市長島町久須見');
ok($zip->set_number('5097207')->is_valid_number, '岐阜県恵那市笠置町河合');
ok($zip->set_number('5097208')->is_valid_number, '岐阜県恵那市笠置町姫栗');
ok($zip->set_number('5097209')->is_valid_number, '岐阜県恵那市笠置町毛呂窪');
ok($zip->set_number('5097211')->is_valid_number, '岐阜県恵那市長島町鍋山');
ok($zip->set_number('5097321')->is_valid_number, '岐阜県中津川市阿木(その他)');
ok($zip->set_number('5097322')->is_valid_number, '岐阜県中津川市飯沼');
ok($zip->set_number('5097401')->is_valid_number, '岐阜県恵那市岩村町飯羽間');
ok($zip->set_number('5097402')->is_valid_number, '岐阜県恵那市岩村町富田');
ok($zip->set_number('5097403')->is_valid_number, '岐阜県恵那市岩村町');
ok($zip->set_number('5097501')->is_valid_number, '岐阜県恵那市上矢作町(木ノ実)');
ok($zip->set_number('5097502')->is_valid_number, '岐阜県恵那市上矢作町(飯田洞)');
ok($zip->set_number('5097503')->is_valid_number, '岐阜県恵那市上矢作町(達原)');
ok($zip->set_number('5097504')->is_valid_number, '岐阜県恵那市上矢作町(小笹原)');
ok($zip->set_number('5097505')->is_valid_number, '岐阜県恵那市上矢作町(島)');
ok($zip->set_number('5097506')->is_valid_number, '岐阜県恵那市上矢作町(本郷)');
ok($zip->set_number('5097507')->is_valid_number, '岐阜県恵那市上矢作町(横道)');
ok($zip->set_number('5097511')->is_valid_number, '岐阜県恵那市上矢作町漆原');
ok($zip->set_number('5097512')->is_valid_number, '岐阜県恵那市上矢作町下');
ok($zip->set_number('5097513')->is_valid_number, '岐阜県恵那市上矢作町小田子');
ok($zip->set_number('5097521')->is_valid_number, '岐阜県恵那市上矢作町');
ok($zip->set_number('5097601')->is_valid_number, '岐阜県恵那市山岡町久保原');
ok($zip->set_number('5097602')->is_valid_number, '岐阜県恵那市山岡町馬場山田');
ok($zip->set_number('5097603')->is_valid_number, '岐阜県恵那市山岡町上手向');
ok($zip->set_number('5097604')->is_valid_number, '岐阜県恵那市山岡町釜屋');
ok($zip->set_number('5097605')->is_valid_number, '岐阜県恵那市山岡町原');
ok($zip->set_number('5097606')->is_valid_number, '岐阜県恵那市山岡町田代');
ok($zip->set_number('5097607')->is_valid_number, '岐阜県恵那市山岡町下手向');
ok($zip->set_number('5097608')->is_valid_number, '岐阜県恵那市山岡町田沢');
ok($zip->set_number('5097701')->is_valid_number, '岐阜県恵那市明智町野志');
ok($zip->set_number('5097702')->is_valid_number, '岐阜県恵那市明智町杉野');
ok($zip->set_number('5097703')->is_valid_number, '岐阜県恵那市明智町(市場町)');
ok($zip->set_number('5097704')->is_valid_number, '岐阜県恵那市明智町(駅前町)');
ok($zip->set_number('5097705')->is_valid_number, '岐阜県恵那市明智町(新町)');
ok($zip->set_number('5097706')->is_valid_number, '岐阜県恵那市明智町(向町)');
ok($zip->set_number('5097707')->is_valid_number, '岐阜県恵那市明智町(滝坂住宅)');
ok($zip->set_number('5097708')->is_valid_number, '岐阜県恵那市明智町(新井町)');
ok($zip->set_number('5097711')->is_valid_number, '岐阜県恵那市明智町東方');
ok($zip->set_number('5097712')->is_valid_number, '岐阜県恵那市明智町(的場町)');
ok($zip->set_number('5097713')->is_valid_number, '岐阜県恵那市明智町(片平町)');
ok($zip->set_number('5097714')->is_valid_number, '岐阜県恵那市明智町(常盤町)');
ok($zip->set_number('5097715')->is_valid_number, '岐阜県恵那市明智町(東町)');
ok($zip->set_number('5097716')->is_valid_number, '岐阜県恵那市明智町(本町)');
ok($zip->set_number('5097717')->is_valid_number, '岐阜県恵那市明智町(宮町)');
ok($zip->set_number('5097718')->is_valid_number, '岐阜県恵那市明智町(東山町)');
ok($zip->set_number('5097721')->is_valid_number, '岐阜県恵那市明智町大泉');
ok($zip->set_number('5097722')->is_valid_number, '岐阜県恵那市明智町(徳間町)');
ok($zip->set_number('5097723')->is_valid_number, '岐阜県恵那市明智町大田');
ok($zip->set_number('5097724')->is_valid_number, '岐阜県恵那市明智町横通');
ok($zip->set_number('5097725')->is_valid_number, '岐阜県恵那市明智町阿妻');
ok($zip->set_number('5097726')->is_valid_number, '岐阜県恵那市明智町吉良見');
ok($zip->set_number('5097731')->is_valid_number, '岐阜県恵那市明智町');
ok($zip->set_number('5097801')->is_valid_number, '岐阜県恵那市串原(中沢)');
ok($zip->set_number('5097802')->is_valid_number, '岐阜県恵那市串原(平山)');
ok($zip->set_number('5097803')->is_valid_number, '岐阜県恵那市串原(松本)');
ok($zip->set_number('5097804')->is_valid_number, '岐阜県恵那市串原(戸中)');
ok($zip->set_number('5097805')->is_valid_number, '岐阜県恵那市串原(峯)');
ok($zip->set_number('5097806')->is_valid_number, '岐阜県恵那市串原(松林)');
ok($zip->set_number('5097811')->is_valid_number, '岐阜県恵那市串原(福原)');
ok($zip->set_number('5097812')->is_valid_number, '岐阜県恵那市串原(森上)');
ok($zip->set_number('5097813')->is_valid_number, '岐阜県恵那市串原(大竹)');
ok($zip->set_number('5097814')->is_valid_number, '岐阜県恵那市串原(相走)');
ok($zip->set_number('5097815')->is_valid_number, '岐阜県恵那市串原(大野)');
ok($zip->set_number('5097816')->is_valid_number, '岐阜県恵那市串原(岩倉)');
ok($zip->set_number('5097821')->is_valid_number, '岐阜県恵那市串原(大平)');
ok($zip->set_number('5097822')->is_valid_number, '岐阜県恵那市串原(柿畑)');
ok($zip->set_number('5097823')->is_valid_number, '岐阜県恵那市串原(閑羅瀬)');
ok($zip->set_number('5097824')->is_valid_number, '岐阜県恵那市串原(大簗)');
ok($zip->set_number('5097825')->is_valid_number, '岐阜県恵那市串原(川ケ渡)');
ok($zip->set_number('5097826')->is_valid_number, '岐阜県恵那市串原(木根)');
ok($zip->set_number('5097831')->is_valid_number, '岐阜県恵那市串原');
ok($zip->set_number('5098231')->is_valid_number, '岐阜県恵那市中野方町');
ok($zip->set_number('5098232')->is_valid_number, '岐阜県恵那市飯地町');
ok($zip->set_number('5098301')->is_valid_number, '岐阜県中津川市蛭川');
ok($zip->set_number('5099131')->is_valid_number, '岐阜県中津川市千旦林');
ok($zip->set_number('5099132')->is_valid_number, '岐阜県中津川市茄子川');
ok($zip->set_number('5099201')->is_valid_number, '岐阜県中津川市川上');
ok($zip->set_number('5099231')->is_valid_number, '岐阜県中津川市上野');
ok($zip->set_number('5099232')->is_valid_number, '岐阜県中津川市坂下');
ok($zip->set_number('5100000')->is_valid_number, '三重県四日市市以下に掲載がない場合');
ok($zip->set_number('5100000')->is_valid_number, '三重県三重郡朝日町以下に掲載がない場合');
ok($zip->set_number('5100000')->is_valid_number, '三重県三重郡川越町以下に掲載がない場合');
ok($zip->set_number('5100001')->is_valid_number, '三重県四日市市八田');
ok($zip->set_number('5100002')->is_valid_number, '三重県四日市市羽津中');
ok($zip->set_number('5100003')->is_valid_number, '三重県四日市市大宮町');
ok($zip->set_number('5100004')->is_valid_number, '三重県四日市市大宮西町');
ok($zip->set_number('5100005')->is_valid_number, '三重県四日市市山手町');
ok($zip->set_number('5100006')->is_valid_number, '三重県四日市市緑丘町');
ok($zip->set_number('5100007')->is_valid_number, '三重県四日市市別名');
ok($zip->set_number('5100008')->is_valid_number, '三重県四日市市南いかるが町');
ok($zip->set_number('5100011')->is_valid_number, '三重県四日市市霞');
ok($zip->set_number('5100012')->is_valid_number, '三重県四日市市羽津');
ok($zip->set_number('5100013')->is_valid_number, '三重県四日市市富士町');
ok($zip->set_number('5100014')->is_valid_number, '三重県四日市市金場町');
ok($zip->set_number('5100015')->is_valid_number, '三重県四日市市城山町');
ok($zip->set_number('5100016')->is_valid_number, '三重県四日市市羽津山町');
ok($zip->set_number('5100017')->is_valid_number, '三重県四日市市羽津町');
ok($zip->set_number('5100018')->is_valid_number, '三重県四日市市白須賀');
ok($zip->set_number('5100021')->is_valid_number, '三重県四日市市三郎町');
ok($zip->set_number('5100022')->is_valid_number, '三重県四日市市大協町');
ok($zip->set_number('5100023')->is_valid_number, '三重県四日市市午起');
ok($zip->set_number('5100024')->is_valid_number, '三重県四日市市新浜町');
ok($zip->set_number('5100025')->is_valid_number, '三重県四日市市東新町');
ok($zip->set_number('5100026')->is_valid_number, '三重県四日市市高浜町');
ok($zip->set_number('5100027')->is_valid_number, '三重県四日市市高浜新町');
ok($zip->set_number('5100031')->is_valid_number, '三重県四日市市浜一色町');
ok($zip->set_number('5100032')->is_valid_number, '三重県四日市市京町');
ok($zip->set_number('5100033')->is_valid_number, '三重県四日市市川原町');
ok($zip->set_number('5100034')->is_valid_number, '三重県四日市市滝川町');
ok($zip->set_number('5100035')->is_valid_number, '三重県四日市市陶栄町');
ok($zip->set_number('5100041')->is_valid_number, '三重県四日市市稲葉町');
ok($zip->set_number('5100042')->is_valid_number, '三重県四日市市高砂町');
ok($zip->set_number('5100043')->is_valid_number, '三重県四日市市南納屋町');
ok($zip->set_number('5100044')->is_valid_number, '三重県四日市市相生町');
ok($zip->set_number('5100045')->is_valid_number, '三重県四日市市蔵町');
ok($zip->set_number('5100046')->is_valid_number, '三重県四日市市浜町');
ok($zip->set_number('5100047')->is_valid_number, '三重県四日市市北納屋町');
ok($zip->set_number('5100048')->is_valid_number, '三重県四日市市中納屋町');
ok($zip->set_number('5100051')->is_valid_number, '三重県四日市市千歳町');
ok($zip->set_number('5100052')->is_valid_number, '三重県四日市市末広町');
ok($zip->set_number('5100053')->is_valid_number, '三重県四日市市曙');
ok($zip->set_number('5100054')->is_valid_number, '三重県四日市市曙町');
ok($zip->set_number('5100055')->is_valid_number, '三重県四日市市寿町');
ok($zip->set_number('5100056')->is_valid_number, '三重県四日市市南起町');
ok($zip->set_number('5100057')->is_valid_number, '三重県四日市市昌栄町');
ok($zip->set_number('5100058')->is_valid_number, '三重県四日市市西末広町');
ok($zip->set_number('5100059')->is_valid_number, '三重県四日市市尾上町');
ok($zip->set_number('5100061')->is_valid_number, '三重県四日市市朝日町');
ok($zip->set_number('5100062')->is_valid_number, '三重県四日市市北浜田町');
ok($zip->set_number('5100063')->is_valid_number, '三重県四日市市十七軒町');
ok($zip->set_number('5100064')->is_valid_number, '三重県四日市市新正');
ok($zip->set_number('5100065')->is_valid_number, '三重県四日市市中浜田町');
ok($zip->set_number('5100066')->is_valid_number, '三重県四日市市南浜田町');
ok($zip->set_number('5100067')->is_valid_number, '三重県四日市市浜田町');
ok($zip->set_number('5100068')->is_valid_number, '三重県四日市市三栄町');
ok($zip->set_number('5100069')->is_valid_number, '三重県四日市市幸町');
ok($zip->set_number('5100071')->is_valid_number, '三重県四日市市西浦');
ok($zip->set_number('5100072')->is_valid_number, '三重県四日市市九の城町');
ok($zip->set_number('5100073')->is_valid_number, '三重県四日市市西浜田町');
ok($zip->set_number('5100074')->is_valid_number, '三重県四日市市鵜の森');
ok($zip->set_number('5100075')->is_valid_number, '三重県四日市市安島');
ok($zip->set_number('5100076')->is_valid_number, '三重県四日市市堀木');
ok($zip->set_number('5100081')->is_valid_number, '三重県四日市市北町');
ok($zip->set_number('5100082')->is_valid_number, '三重県四日市市中部');
ok($zip->set_number('5100083')->is_valid_number, '三重県四日市市沖の島町');
ok($zip->set_number('5100084')->is_valid_number, '三重県四日市市栄町');
ok($zip->set_number('5100085')->is_valid_number, '三重県四日市市諏訪町');
ok($zip->set_number('5100086')->is_valid_number, '三重県四日市市諏訪栄町');
ok($zip->set_number('5100087')->is_valid_number, '三重県四日市市西新地');
ok($zip->set_number('5100088')->is_valid_number, '三重県四日市市元町');
ok($zip->set_number('5100089')->is_valid_number, '三重県四日市市西町');
ok($zip->set_number('5100091')->is_valid_number, '三重県四日市市北浜町');
ok($zip->set_number('5100092')->is_valid_number, '三重県四日市市新町');
ok($zip->set_number('5100093')->is_valid_number, '三重県四日市市本町');
ok($zip->set_number('5100094')->is_valid_number, '三重県四日市市新々町');
ok($zip->set_number('5100095')->is_valid_number, '三重県四日市市元新町');
ok($zip->set_number('5100096')->is_valid_number, '三重県四日市市中町');
ok($zip->set_number('5100097')->is_valid_number, '三重県四日市市八幡町');
ok($zip->set_number('5100098')->is_valid_number, '三重県四日市市北条町');
ok($zip->set_number('5100101')->is_valid_number, '三重県四日市市楠町小倉');
ok($zip->set_number('5100102')->is_valid_number, '三重県四日市市楠町吉崎');
ok($zip->set_number('5100103')->is_valid_number, '三重県四日市市楠町北五味塚');
ok($zip->set_number('5100104')->is_valid_number, '三重県四日市市楠町南五味塚');
ok($zip->set_number('5100105')->is_valid_number, '三重県四日市市楠町南川');
ok($zip->set_number('5100106')->is_valid_number, '三重県四日市市楠町本郷');
ok($zip->set_number('5100107')->is_valid_number, '三重県四日市市楠町北一色');
ok($zip->set_number('5100201')->is_valid_number, '三重県鈴鹿市稲生町');
ok($zip->set_number('5100202')->is_valid_number, '三重県鈴鹿市野町');
ok($zip->set_number('5100203')->is_valid_number, '三重県鈴鹿市野村町');
ok($zip->set_number('5100204')->is_valid_number, '三重県鈴鹿市稲生西');
ok($zip->set_number('5100205')->is_valid_number, '三重県鈴鹿市稲生');
ok($zip->set_number('5100206')->is_valid_number, '三重県鈴鹿市稲生こがね園');
ok($zip->set_number('5100207')->is_valid_number, '三重県鈴鹿市稲生塩屋');
ok($zip->set_number('5100208')->is_valid_number, '三重県鈴鹿市鈴鹿ハイツ');
ok($zip->set_number('5100211')->is_valid_number, '三重県鈴鹿市東旭が丘');
ok($zip->set_number('5100212')->is_valid_number, '三重県鈴鹿市中旭が丘');
ok($zip->set_number('5100213')->is_valid_number, '三重県鈴鹿市南旭が丘');
ok($zip->set_number('5100216')->is_valid_number, '三重県鈴鹿市野町中');
ok($zip->set_number('5100217')->is_valid_number, '三重県鈴鹿市野町東');
ok($zip->set_number('5100218')->is_valid_number, '三重県鈴鹿市野町西');
ok($zip->set_number('5100219')->is_valid_number, '三重県鈴鹿市野町南');
ok($zip->set_number('5100221')->is_valid_number, '三重県鈴鹿市北若松町');
ok($zip->set_number('5100222')->is_valid_number, '三重県鈴鹿市若松西');
ok($zip->set_number('5100223')->is_valid_number, '三重県鈴鹿市若松北');
ok($zip->set_number('5100224')->is_valid_number, '三重県鈴鹿市若松中');
ok($zip->set_number('5100225')->is_valid_number, '三重県鈴鹿市若松東');
ok($zip->set_number('5100226')->is_valid_number, '三重県鈴鹿市岸岡町');
ok($zip->set_number('5100227')->is_valid_number, '三重県鈴鹿市南若松町');
ok($zip->set_number('5100231')->is_valid_number, '三重県鈴鹿市江島台');
ok($zip->set_number('5100232')->is_valid_number, '三重県鈴鹿市北江島町');
ok($zip->set_number('5100233')->is_valid_number, '三重県鈴鹿市東江島町');
ok($zip->set_number('5100234')->is_valid_number, '三重県鈴鹿市江島本町');
ok($zip->set_number('5100235')->is_valid_number, '三重県鈴鹿市南江島町');
ok($zip->set_number('5100236')->is_valid_number, '三重県鈴鹿市中江島町');
ok($zip->set_number('5100237')->is_valid_number, '三重県鈴鹿市江島町');
ok($zip->set_number('5100241')->is_valid_number, '三重県鈴鹿市白子駅前');
ok($zip->set_number('5100242')->is_valid_number, '三重県鈴鹿市白子本町');
ok($zip->set_number('5100243')->is_valid_number, '三重県鈴鹿市白子');
ok($zip->set_number('5100244')->is_valid_number, '三重県鈴鹿市白子町');
ok($zip->set_number('5100251')->is_valid_number, '三重県鈴鹿市徳田町');
ok($zip->set_number('5100252')->is_valid_number, '三重県鈴鹿市五祝町');
ok($zip->set_number('5100253')->is_valid_number, '三重県鈴鹿市寺家町');
ok($zip->set_number('5100254')->is_valid_number, '三重県鈴鹿市寺家');
ok($zip->set_number('5100255')->is_valid_number, '三重県鈴鹿市磯山町');
ok($zip->set_number('5100256')->is_valid_number, '三重県鈴鹿市磯山');
ok($zip->set_number('5100257')->is_valid_number, '三重県鈴鹿市東磯山');
ok($zip->set_number('5100258')->is_valid_number, '三重県鈴鹿市秋永町');
ok($zip->set_number('5100259')->is_valid_number, '三重県鈴鹿市中瀬古町');
ok($zip->set_number('5100261')->is_valid_number, '三重県鈴鹿市御薗町');
ok($zip->set_number('5100262')->is_valid_number, '三重県鈴鹿市越知町');
ok($zip->set_number('5100263')->is_valid_number, '三重県鈴鹿市郡山町');
ok($zip->set_number('5100264')->is_valid_number, '三重県鈴鹿市徳居町');
ok($zip->set_number('5100265')->is_valid_number, '三重県鈴鹿市三宅町');
ok($zip->set_number('5100266')->is_valid_number, '三重県鈴鹿市長法寺町');
ok($zip->set_number('5100301')->is_valid_number, '三重県津市河芸町西千里');
ok($zip->set_number('5100302')->is_valid_number, '三重県津市河芸町千里ケ丘');
ok($zip->set_number('5100303')->is_valid_number, '三重県津市河芸町東千里');
ok($zip->set_number('5100304')->is_valid_number, '三重県津市河芸町上野');
ok($zip->set_number('5100305')->is_valid_number, '三重県津市河芸町中別保');
ok($zip->set_number('5100306')->is_valid_number, '三重県津市河芸町一色');
ok($zip->set_number('5100307')->is_valid_number, '三重県津市河芸町影重');
ok($zip->set_number('5100308')->is_valid_number, '三重県津市河芸町中瀬');
ok($zip->set_number('5100311')->is_valid_number, '三重県津市河芸町三行');
ok($zip->set_number('5100312')->is_valid_number, '三重県津市河芸町久知野');
ok($zip->set_number('5100313')->is_valid_number, '三重県津市河芸町赤部');
ok($zip->set_number('5100314')->is_valid_number, '三重県津市河芸町浜田');
ok($zip->set_number('5100315')->is_valid_number, '三重県津市河芸町高佐');
ok($zip->set_number('5100316')->is_valid_number, '三重県津市河芸町南黒田');
ok($zip->set_number('5100317')->is_valid_number, '三重県津市河芸町北黒田');
ok($zip->set_number('5100318')->is_valid_number, '三重県津市河芸町杜の街');
ok($zip->set_number('5100801')->is_valid_number, '三重県四日市市三ツ谷東町');
ok($zip->set_number('5100802')->is_valid_number, '三重県四日市市三ツ谷町');
ok($zip->set_number('5100803')->is_valid_number, '三重県四日市市阿倉川町');
ok($zip->set_number('5100804')->is_valid_number, '三重県四日市市万古町');
ok($zip->set_number('5100805')->is_valid_number, '三重県四日市市東阿倉川');
ok($zip->set_number('5100806')->is_valid_number, '三重県四日市市本郷町');
ok($zip->set_number('5100807')->is_valid_number, '三重県四日市市末永町');
ok($zip->set_number('5100810')->is_valid_number, '三重県四日市市阿倉川新町');
ok($zip->set_number('5100811')->is_valid_number, '三重県四日市市みゆきケ丘');
ok($zip->set_number('5100812')->is_valid_number, '三重県四日市市西阿倉川');
ok($zip->set_number('5100813')->is_valid_number, '三重県四日市市末永');
ok($zip->set_number('5100814')->is_valid_number, '三重県四日市市清水町');
ok($zip->set_number('5100815')->is_valid_number, '三重県四日市市野田');
ok($zip->set_number('5100821')->is_valid_number, '三重県四日市市久保田');
ok($zip->set_number('5100822')->is_valid_number, '三重県四日市市芝田');
ok($zip->set_number('5100823')->is_valid_number, '三重県四日市市城北町');
ok($zip->set_number('5100824')->is_valid_number, '三重県四日市市城東町');
ok($zip->set_number('5100825')->is_valid_number, '三重県四日市市赤堀新町');
ok($zip->set_number('5100826')->is_valid_number, '三重県四日市市赤堀');
ok($zip->set_number('5100827')->is_valid_number, '三重県四日市市赤堀南町');
ok($zip->set_number('5100828')->is_valid_number, '三重県四日市市石塚町');
ok($zip->set_number('5100829')->is_valid_number, '三重県四日市市城西町');
ok($zip->set_number('5100831')->is_valid_number, '三重県四日市市西伊倉町');
ok($zip->set_number('5100832')->is_valid_number, '三重県四日市市伊倉');
ok($zip->set_number('5100833')->is_valid_number, '三重県四日市市中川原');
ok($zip->set_number('5100834')->is_valid_number, '三重県四日市市ときわ');
ok($zip->set_number('5100835')->is_valid_number, '三重県四日市市大井手');
ok($zip->set_number('5100836')->is_valid_number, '三重県四日市市松本');
ok($zip->set_number('5100837')->is_valid_number, '三重県四日市市西松本町');
ok($zip->set_number('5100838')->is_valid_number, '三重県四日市市南松本町');
ok($zip->set_number('5100839')->is_valid_number, '三重県四日市市青葉町');
ok($zip->set_number('5100841')->is_valid_number, '三重県四日市市三田町');
ok($zip->set_number('5100842')->is_valid_number, '三重県四日市市石原町');
ok($zip->set_number('5100843')->is_valid_number, '三重県四日市市宮東町');
ok($zip->set_number('5100844')->is_valid_number, '三重県四日市市宝町');
ok($zip->set_number('5100845')->is_valid_number, '三重県四日市市海山道町');
ok($zip->set_number('5100846')->is_valid_number, '三重県四日市市大井の川町');
ok($zip->set_number('5100847')->is_valid_number, '三重県四日市市大浜町');
ok($zip->set_number('5100848')->is_valid_number, '三重県四日市市東邦町');
ok($zip->set_number('5100851')->is_valid_number, '三重県四日市市塩浜町');
ok($zip->set_number('5100852')->is_valid_number, '三重県四日市市浜旭町');
ok($zip->set_number('5100853')->is_valid_number, '三重県四日市市川合町');
ok($zip->set_number('5100854')->is_valid_number, '三重県四日市市塩浜本町');
ok($zip->set_number('5100855')->is_valid_number, '三重県四日市市馳出町');
ok($zip->set_number('5100856')->is_valid_number, '三重県四日市市七つ屋町');
ok($zip->set_number('5100857')->is_valid_number, '三重県四日市市高旭町');
ok($zip->set_number('5100861')->is_valid_number, '三重県四日市市柳町');
ok($zip->set_number('5100862')->is_valid_number, '三重県四日市市御薗町');
ok($zip->set_number('5100863')->is_valid_number, '三重県四日市市磯津');
ok($zip->set_number('5100863')->is_valid_number, '三重県四日市市大里町');
ok($zip->set_number('5100863')->is_valid_number, '三重県四日市市塩浜');
ok($zip->set_number('5100863')->is_valid_number, '三重県四日市市塩浜栄町');
ok($zip->set_number('5100864')->is_valid_number, '三重県四日市市中里町');
ok($zip->set_number('5100865')->is_valid_number, '三重県四日市市小浜町');
ok($zip->set_number('5100866')->is_valid_number, '三重県四日市市大池町');
ok($zip->set_number('5100867')->is_valid_number, '三重県四日市市松泉町');
ok($zip->set_number('5100868')->is_valid_number, '三重県四日市市馳出');
ok($zip->set_number('5100871')->is_valid_number, '三重県四日市市川尻町');
ok($zip->set_number('5100872')->is_valid_number, '三重県四日市市内堀町');
ok($zip->set_number('5100873')->is_valid_number, '三重県四日市市貝塚町');
ok($zip->set_number('5100874')->is_valid_number, '三重県四日市市河原田町');
ok($zip->set_number('5100875')->is_valid_number, '三重県四日市市大治田');
ok($zip->set_number('5100881')->is_valid_number, '三重県四日市市六呂見');
ok($zip->set_number('5100882')->is_valid_number, '三重県四日市市追分');
ok($zip->set_number('5100883')->is_valid_number, '三重県四日市市泊小柳町');
ok($zip->set_number('5100884')->is_valid_number, '三重県四日市市泊町');
ok($zip->set_number('5100885')->is_valid_number, '三重県四日市市日永');
ok($zip->set_number('5100886')->is_valid_number, '三重県四日市市日永東');
ok($zip->set_number('5100891')->is_valid_number, '三重県四日市市日永西');
ok($zip->set_number('5100892')->is_valid_number, '三重県四日市市泊山崎町');
ok($zip->set_number('5100893')->is_valid_number, '三重県四日市市前田町');
ok($zip->set_number('5100894')->is_valid_number, '三重県四日市市泊村');
ok($zip->set_number('5100941')->is_valid_number, '三重県四日市市東日野');
ok($zip->set_number('5100942')->is_valid_number, '三重県四日市市東日野町');
ok($zip->set_number('5100943')->is_valid_number, '三重県四日市市西日野町');
ok($zip->set_number('5100944')->is_valid_number, '三重県四日市市笹川');
ok($zip->set_number('5100945')->is_valid_number, '三重県四日市市高花平');
ok($zip->set_number('5100946')->is_valid_number, '三重県四日市市小林町');
ok($zip->set_number('5100947')->is_valid_number, '三重県四日市市八王子町');
ok($zip->set_number('5100948')->is_valid_number, '三重県四日市市室山町');
ok($zip->set_number('5100951')->is_valid_number, '三重県四日市市小古曽東');
ok($zip->set_number('5100952')->is_valid_number, '三重県四日市市小古曽町');
ok($zip->set_number('5100953')->is_valid_number, '三重県四日市市釆女が丘');
ok($zip->set_number('5100954')->is_valid_number, '三重県四日市市釆女町');
ok($zip->set_number('5100955')->is_valid_number, '三重県四日市市北小松町');
ok($zip->set_number('5100956')->is_valid_number, '三重県四日市市貝家町');
ok($zip->set_number('5100957')->is_valid_number, '三重県四日市市森カ山町');
ok($zip->set_number('5100958')->is_valid_number, '三重県四日市市小古曽');
ok($zip->set_number('5100961')->is_valid_number, '三重県四日市市波木町');
ok($zip->set_number('5100962')->is_valid_number, '三重県四日市市波木が丘町');
ok($zip->set_number('5100963')->is_valid_number, '三重県四日市市波木南台');
ok($zip->set_number('5100971')->is_valid_number, '三重県四日市市南小松町');
ok($zip->set_number('5101200')->is_valid_number, '三重県三重郡菰野町以下に掲載がない場合');
ok($zip->set_number('5101221')->is_valid_number, '三重県三重郡菰野町池底');
ok($zip->set_number('5101222')->is_valid_number, '三重県三重郡菰野町大強原');
ok($zip->set_number('5101223')->is_valid_number, '三重県三重郡菰野町諏訪');
ok($zip->set_number('5101224')->is_valid_number, '三重県三重郡菰野町川北');
ok($zip->set_number('5101225')->is_valid_number, '三重県三重郡菰野町下村');
ok($zip->set_number('5101226')->is_valid_number, '三重県三重郡菰野町吉沢');
ok($zip->set_number('5101231')->is_valid_number, '三重県三重郡菰野町神森');
ok($zip->set_number('5101232')->is_valid_number, '三重県三重郡菰野町宿野');
ok($zip->set_number('5101233')->is_valid_number, '三重県三重郡菰野町菰野');
ok($zip->set_number('5101234')->is_valid_number, '三重県三重郡菰野町福村');
ok($zip->set_number('5101235')->is_valid_number, '三重県三重郡菰野町宝永台');
ok($zip->set_number('5101236')->is_valid_number, '三重県三重郡菰野町初若の郷');
ok($zip->set_number('5101241')->is_valid_number, '三重県三重郡菰野町大羽根園新林町');
ok($zip->set_number('5101242')->is_valid_number, '三重県三重郡菰野町大羽根園柴垣町');
ok($zip->set_number('5101243')->is_valid_number, '三重県三重郡菰野町大羽根園呉竹町');
ok($zip->set_number('5101244')->is_valid_number, '三重県三重郡菰野町大羽根園並木通');
ok($zip->set_number('5101245')->is_valid_number, '三重県三重郡菰野町大羽根園松ケ枝町');
ok($zip->set_number('5101246')->is_valid_number, '三重県三重郡菰野町大羽根園青葉町');
ok($zip->set_number('5101251')->is_valid_number, '三重県三重郡菰野町千草');
ok($zip->set_number('5101252')->is_valid_number, '三重県三重郡菰野町音羽');
ok($zip->set_number('5101253')->is_valid_number, '三重県三重郡菰野町潤田');
ok($zip->set_number('5101311')->is_valid_number, '三重県三重郡菰野町永井');
ok($zip->set_number('5101312')->is_valid_number, '三重県三重郡菰野町竹成');
ok($zip->set_number('5101321')->is_valid_number, '三重県三重郡菰野町田口');
ok($zip->set_number('5101322')->is_valid_number, '三重県三重郡菰野町田口新田');
ok($zip->set_number('5101323')->is_valid_number, '三重県三重郡菰野町小島');
ok($zip->set_number('5101324')->is_valid_number, '三重県三重郡菰野町田光');
ok($zip->set_number('5101325')->is_valid_number, '三重県三重郡菰野町榊');
ok($zip->set_number('5101326')->is_valid_number, '三重県三重郡菰野町杉谷');
ok($zip->set_number('5101327')->is_valid_number, '三重県三重郡菰野町根の平');
ok($zip->set_number('5101328')->is_valid_number, '三重県三重郡菰野町切畑');
ok($zip->set_number('5108001')->is_valid_number, '三重県四日市市天カ須賀');
ok($zip->set_number('5108002')->is_valid_number, '三重県四日市市天カ須賀新町');
ok($zip->set_number('5108003')->is_valid_number, '三重県四日市市住吉町');
ok($zip->set_number('5108004')->is_valid_number, '三重県四日市市富田一色町');
ok($zip->set_number('5108005')->is_valid_number, '三重県四日市市富双');
ok($zip->set_number('5108006')->is_valid_number, '三重県四日市市東富田町');
ok($zip->set_number('5108007')->is_valid_number, '三重県四日市市富田浜元町');
ok($zip->set_number('5108008')->is_valid_number, '三重県四日市市富田浜町');
ok($zip->set_number('5108009')->is_valid_number, '三重県四日市市浜園町');
ok($zip->set_number('5108011')->is_valid_number, '三重県四日市市東茂福町');
ok($zip->set_number('5108012')->is_valid_number, '三重県四日市市茂福町');
ok($zip->set_number('5108013')->is_valid_number, '三重県四日市市南富田町');
ok($zip->set_number('5108014')->is_valid_number, '三重県四日市市富田');
ok($zip->set_number('5108015')->is_valid_number, '三重県四日市市松原町');
ok($zip->set_number('5108016')->is_valid_number, '三重県四日市市富州原町');
ok($zip->set_number('5108017')->is_valid_number, '三重県四日市市平町');
ok($zip->set_number('5108021')->is_valid_number, '三重県四日市市松寺');
ok($zip->set_number('5108022')->is_valid_number, '三重県四日市市蒔田');
ok($zip->set_number('5108023')->is_valid_number, '三重県四日市市西富田');
ok($zip->set_number('5108024')->is_valid_number, '三重県四日市市西富田町');
ok($zip->set_number('5108025')->is_valid_number, '三重県四日市市富田栄町');
ok($zip->set_number('5108026')->is_valid_number, '三重県四日市市十志町');
ok($zip->set_number('5108027')->is_valid_number, '三重県四日市市茂福');
ok($zip->set_number('5108028')->is_valid_number, '三重県四日市市下之宮町');
ok($zip->set_number('5108031')->is_valid_number, '三重県四日市市川北');
ok($zip->set_number('5108032')->is_valid_number, '三重県四日市市川北町');
ok($zip->set_number('5108033')->is_valid_number, '三重県四日市市下さざらい町');
ok($zip->set_number('5108034')->is_valid_number, '三重県四日市市大矢知町');
ok($zip->set_number('5108035')->is_valid_number, '三重県四日市市東垂坂町');
ok($zip->set_number('5108036')->is_valid_number, '三重県四日市市南垂坂町');
ok($zip->set_number('5108037')->is_valid_number, '三重県四日市市垂坂町');
ok($zip->set_number('5108038')->is_valid_number, '三重県四日市市垂坂新町');
ok($zip->set_number('5108039')->is_valid_number, '三重県四日市市大矢知新町');
ok($zip->set_number('5108101')->is_valid_number, '三重県三重郡朝日町縄生');
ok($zip->set_number('5108102')->is_valid_number, '三重県三重郡朝日町小向');
ok($zip->set_number('5108103')->is_valid_number, '三重県三重郡朝日町柿');
ok($zip->set_number('5108104')->is_valid_number, '三重県三重郡朝日町埋縄');
ok($zip->set_number('5108105')->is_valid_number, '三重県三重郡朝日町向陽台');
ok($zip->set_number('5108106')->is_valid_number, '三重県三重郡朝日町白梅の丘東');
ok($zip->set_number('5108107')->is_valid_number, '三重県三重郡朝日町白梅の丘西');
ok($zip->set_number('5108111')->is_valid_number, '三重県三重郡川越町当新田');
ok($zip->set_number('5108112')->is_valid_number, '三重県三重郡川越町亀須新田');
ok($zip->set_number('5108113')->is_valid_number, '三重県三重郡川越町亀尾新田');
ok($zip->set_number('5108114')->is_valid_number, '三重県三重郡川越町亀崎新田');
ok($zip->set_number('5108121')->is_valid_number, '三重県三重郡川越町高松');
ok($zip->set_number('5108122')->is_valid_number, '三重県三重郡川越町豊田');
ok($zip->set_number('5108123')->is_valid_number, '三重県三重郡川越町豊田一色');
ok($zip->set_number('5108124')->is_valid_number, '三重県三重郡川越町南福崎');
ok($zip->set_number('5108125')->is_valid_number, '三重県三重郡川越町北福崎');
ok($zip->set_number('5110000')->is_valid_number, '三重県桑名市以下に掲載がない場合');
ok($zip->set_number('5110001')->is_valid_number, '三重県桑名市上之輪新田');
ok($zip->set_number('5110002')->is_valid_number, '三重県桑名市福島');
ok($zip->set_number('5110003')->is_valid_number, '三重県桑名市東太一丸');
ok($zip->set_number('5110004')->is_valid_number, '三重県桑名市住吉町');
ok($zip->set_number('5110005')->is_valid_number, '三重県桑名市太一丸');
ok($zip->set_number('5110006')->is_valid_number, '三重県桑名市今北町');
ok($zip->set_number('5110007')->is_valid_number, '三重県桑名市参宮通');
ok($zip->set_number('5110008')->is_valid_number, '三重県桑名市蓮見町');
ok($zip->set_number('5110009')->is_valid_number, '三重県桑名市桑名');
ok($zip->set_number('5110011')->is_valid_number, '三重県桑名市船馬町');
ok($zip->set_number('5110012')->is_valid_number, '三重県桑名市春日町');
ok($zip->set_number('5110013')->is_valid_number, '三重県桑名市宝殿町');
ok($zip->set_number('5110014')->is_valid_number, '三重県桑名市三崎通');
ok($zip->set_number('5110015')->is_valid_number, '三重県桑名市殿町');
ok($zip->set_number('5110016')->is_valid_number, '三重県桑名市相生町');
ok($zip->set_number('5110017')->is_valid_number, '三重県桑名市今片町');
ok($zip->set_number('5110018')->is_valid_number, '三重県桑名市今中町');
ok($zip->set_number('5110019')->is_valid_number, '三重県桑名市清水町');
ok($zip->set_number('5110021')->is_valid_number, '三重県桑名市川口町');
ok($zip->set_number('5110022')->is_valid_number, '三重県桑名市江戸町');
ok($zip->set_number('5110023')->is_valid_number, '三重県桑名市本町');
ok($zip->set_number('5110024')->is_valid_number, '三重県桑名市北魚町');
ok($zip->set_number('5110025')->is_valid_number, '三重県桑名市風呂町');
ok($zip->set_number('5110026')->is_valid_number, '三重県桑名市宮町');
ok($zip->set_number('5110027')->is_valid_number, '三重県桑名市福島新町');
ok($zip->set_number('5110031')->is_valid_number, '三重県桑名市三之丸');
ok($zip->set_number('5110032')->is_valid_number, '三重県桑名市吉之丸');
ok($zip->set_number('5110033')->is_valid_number, '三重県桑名市赤須賀');
ok($zip->set_number('5110034')->is_valid_number, '三重県桑名市地蔵');
ok($zip->set_number('5110035')->is_valid_number, '三重県桑名市東野');
ok($zip->set_number('5110036')->is_valid_number, '三重県桑名市伊賀町');
ok($zip->set_number('5110037')->is_valid_number, '三重県桑名市元赤須賀');
ok($zip->set_number('5110038')->is_valid_number, '三重県桑名市内堀');
ok($zip->set_number('5110039')->is_valid_number, '三重県桑名市京町');
ok($zip->set_number('5110041')->is_valid_number, '三重県桑名市外堀');
ok($zip->set_number('5110042')->is_valid_number, '三重県桑名市柳原');
ok($zip->set_number('5110043')->is_valid_number, '三重県桑名市新屋敷');
ok($zip->set_number('5110044')->is_valid_number, '三重県桑名市萱町');
ok($zip->set_number('5110045')->is_valid_number, '三重県桑名市伝馬町');
ok($zip->set_number('5110046')->is_valid_number, '三重県桑名市一色町');
ok($zip->set_number('5110047')->is_valid_number, '三重県桑名市鍜冶町');
ok($zip->set_number('5110048')->is_valid_number, '三重県桑名市新町');
ok($zip->set_number('5110049')->is_valid_number, '三重県桑名市八幡町');
ok($zip->set_number('5110051')->is_valid_number, '三重県桑名市矢田磧');
ok($zip->set_number('5110052')->is_valid_number, '三重県桑名市相川町');
ok($zip->set_number('5110053')->is_valid_number, '三重県桑名市東鍋屋町');
ok($zip->set_number('5110054')->is_valid_number, '三重県桑名市西鍋屋町');
ok($zip->set_number('5110055')->is_valid_number, '三重県桑名市東矢田町');
ok($zip->set_number('5110056')->is_valid_number, '三重県桑名市西矢田町');
ok($zip->set_number('5110057')->is_valid_number, '三重県桑名市三ツ矢橋');
ok($zip->set_number('5110058')->is_valid_number, '三重県桑名市千代田町');
ok($zip->set_number('5110061')->is_valid_number, '三重県桑名市寿町');
ok($zip->set_number('5110062')->is_valid_number, '三重県桑名市常盤町');
ok($zip->set_number('5110063')->is_valid_number, '三重県桑名市京橋町');
ok($zip->set_number('5110064')->is_valid_number, '三重県桑名市新築町');
ok($zip->set_number('5110065')->is_valid_number, '三重県桑名市大央町');
ok($zip->set_number('5110066')->is_valid_number, '三重県桑名市北鍋屋町');
ok($zip->set_number('5110067')->is_valid_number, '三重県桑名市掛樋');
ok($zip->set_number('5110068')->is_valid_number, '三重県桑名市中央町');
ok($zip->set_number('5110069')->is_valid_number, '三重県桑名市新矢田');
ok($zip->set_number('5110071')->is_valid_number, '三重県桑名市駅元町');
ok($zip->set_number('5110072')->is_valid_number, '三重県桑名市堤原');
ok($zip->set_number('5110073')->is_valid_number, '三重県桑名市北寺町');
ok($zip->set_number('5110074')->is_valid_number, '三重県桑名市南寺町');
ok($zip->set_number('5110075')->is_valid_number, '三重県桑名市三栄町');
ok($zip->set_number('5110076')->is_valid_number, '三重県桑名市八間通');
ok($zip->set_number('5110077')->is_valid_number, '三重県桑名市末広町');
ok($zip->set_number('5110078')->is_valid_number, '三重県桑名市桑栄町');
ok($zip->set_number('5110079')->is_valid_number, '三重県桑名市有楽町');
ok($zip->set_number('5110081')->is_valid_number, '三重県桑名市片町');
ok($zip->set_number('5110082')->is_valid_number, '三重県桑名市宮通');
ok($zip->set_number('5110083')->is_valid_number, '三重県桑名市職人町');
ok($zip->set_number('5110084')->is_valid_number, '三重県桑名市油町');
ok($zip->set_number('5110085')->is_valid_number, '三重県桑名市紺屋町');
ok($zip->set_number('5110086')->is_valid_number, '三重県桑名市入江葭町');
ok($zip->set_number('5110087')->is_valid_number, '三重県桑名市吉津屋町');
ok($zip->set_number('5110088')->is_valid_number, '三重県桑名市南魚町');
ok($zip->set_number('5110089')->is_valid_number, '三重県桑名市田町');
ok($zip->set_number('5110101')->is_valid_number, '三重県桑名市多度町柚井');
ok($zip->set_number('5110102')->is_valid_number, '三重県桑名市多度町香取');
ok($zip->set_number('5110103')->is_valid_number, '三重県桑名市多度町戸津');
ok($zip->set_number('5110104')->is_valid_number, '三重県桑名市多度町肱江');
ok($zip->set_number('5110105')->is_valid_number, '三重県桑名市多度町小山');
ok($zip->set_number('5110106')->is_valid_number, '三重県桑名市多度町多度');
ok($zip->set_number('5110111')->is_valid_number, '三重県桑名市多度町平古');
ok($zip->set_number('5110112')->is_valid_number, '三重県桑名市多度町福永');
ok($zip->set_number('5110113')->is_valid_number, '三重県桑名市多度町上之郷');
ok($zip->set_number('5110114')->is_valid_number, '三重県桑名市多度町中須');
ok($zip->set_number('5110115')->is_valid_number, '三重県桑名市多度町南之郷');
ok($zip->set_number('5110116')->is_valid_number, '三重県桑名市多度町大鳥居');
ok($zip->set_number('5110117')->is_valid_number, '三重県桑名市多度町下野代');
ok($zip->set_number('5110118')->is_valid_number, '三重県桑名市多度町御衣野');
ok($zip->set_number('5110121')->is_valid_number, '三重県桑名市多度町美鹿');
ok($zip->set_number('5110122')->is_valid_number, '三重県桑名市多度町古野');
ok($zip->set_number('5110123')->is_valid_number, '三重県桑名市多度町北猪飼');
ok($zip->set_number('5110124')->is_valid_number, '三重県桑名市多度町猪飼');
ok($zip->set_number('5110125')->is_valid_number, '三重県桑名市多度町力尾');
ok($zip->set_number('5110200')->is_valid_number, '三重県いなべ市以下に掲載がない場合');
ok($zip->set_number('5110200')->is_valid_number, '三重県員弁郡東員町以下に掲載がない場合');
ok($zip->set_number('5110201')->is_valid_number, '三重県いなべ市員弁町市之原');
ok($zip->set_number('5110202')->is_valid_number, '三重県いなべ市員弁町楚原');
ok($zip->set_number('5110203')->is_valid_number, '三重県いなべ市員弁町畑新田');
ok($zip->set_number('5110204')->is_valid_number, '三重県いなべ市員弁町石仏');
ok($zip->set_number('5110205')->is_valid_number, '三重県いなべ市員弁町笠田新田');
ok($zip->set_number('5110206')->is_valid_number, '三重県いなべ市員弁町宇野');
ok($zip->set_number('5110207')->is_valid_number, '三重県いなべ市員弁町上笠田');
ok($zip->set_number('5110208')->is_valid_number, '三重県いなべ市員弁町坂東新田');
ok($zip->set_number('5110211')->is_valid_number, '三重県いなべ市員弁町松名新田');
ok($zip->set_number('5110212')->is_valid_number, '三重県いなべ市員弁町平古');
ok($zip->set_number('5110213')->is_valid_number, '三重県いなべ市員弁町暮明');
ok($zip->set_number('5110214')->is_valid_number, '三重県いなべ市員弁町岡丁田');
ok($zip->set_number('5110215')->is_valid_number, '三重県いなべ市員弁町東一色');
ok($zip->set_number('5110216')->is_valid_number, '三重県いなべ市員弁町松之木');
ok($zip->set_number('5110217')->is_valid_number, '三重県いなべ市員弁町大泉新田');
ok($zip->set_number('5110221')->is_valid_number, '三重県いなべ市員弁町下笠田');
ok($zip->set_number('5110222')->is_valid_number, '三重県いなべ市員弁町御薗');
ok($zip->set_number('5110223')->is_valid_number, '三重県いなべ市員弁町北金井');
ok($zip->set_number('5110224')->is_valid_number, '三重県いなべ市員弁町大泉');
ok($zip->set_number('5110225')->is_valid_number, '三重県いなべ市員弁町西方');
ok($zip->set_number('5110231')->is_valid_number, '三重県員弁郡東員町笹尾西');
ok($zip->set_number('5110232')->is_valid_number, '三重県員弁郡東員町笹尾東');
ok($zip->set_number('5110233')->is_valid_number, '三重県員弁郡東員町城山');
ok($zip->set_number('5110241')->is_valid_number, '三重県員弁郡東員町鳥取');
ok($zip->set_number('5110242')->is_valid_number, '三重県員弁郡東員町六把野新田');
ok($zip->set_number('5110243')->is_valid_number, '三重県員弁郡東員町穴太');
ok($zip->set_number('5110244')->is_valid_number, '三重県員弁郡東員町大木');
ok($zip->set_number('5110245')->is_valid_number, '三重県員弁郡東員町八幡新田');
ok($zip->set_number('5110251')->is_valid_number, '三重県員弁郡東員町北山田');
ok($zip->set_number('5110251')->is_valid_number, '三重県員弁郡東員町山田');
ok($zip->set_number('5110252')->is_valid_number, '三重県員弁郡東員町瀬古泉');
ok($zip->set_number('5110253')->is_valid_number, '三重県員弁郡東員町筑紫');
ok($zip->set_number('5110254')->is_valid_number, '三重県員弁郡東員町中上');
ok($zip->set_number('5110255')->is_valid_number, '三重県員弁郡東員町長深');
ok($zip->set_number('5110256')->is_valid_number, '三重県員弁郡東員町南大社');
ok($zip->set_number('5110257')->is_valid_number, '三重県員弁郡東員町北大社');
ok($zip->set_number('5110261')->is_valid_number, '三重県いなべ市大安町丹生川上');
ok($zip->set_number('5110262')->is_valid_number, '三重県いなべ市大安町丹生川中');
ok($zip->set_number('5110263')->is_valid_number, '三重県いなべ市大安町丹生川久下');
ok($zip->set_number('5110264')->is_valid_number, '三重県いなべ市大安町石榑東');
ok($zip->set_number('5110265')->is_valid_number, '三重県いなべ市大安町石榑北');
ok($zip->set_number('5110266')->is_valid_number, '三重県いなべ市大安町石榑南');
ok($zip->set_number('5110267')->is_valid_number, '三重県いなべ市大安町石榑北山');
ok($zip->set_number('5110271')->is_valid_number, '三重県いなべ市大安町片樋');
ok($zip->set_number('5110272')->is_valid_number, '三重県いなべ市大安町高柳');
ok($zip->set_number('5110273')->is_valid_number, '三重県いなべ市大安町平塚');
ok($zip->set_number('5110274')->is_valid_number, '三重県いなべ市大安町大井田');
ok($zip->set_number('5110275')->is_valid_number, '三重県いなべ市大安町鍋坂');
ok($zip->set_number('5110276')->is_valid_number, '三重県いなべ市大安町石榑下');
ok($zip->set_number('5110281')->is_valid_number, '三重県いなべ市大安町門前');
ok($zip->set_number('5110282')->is_valid_number, '三重県いなべ市大安町大泉');
ok($zip->set_number('5110283')->is_valid_number, '三重県いなべ市大安町南金井');
ok($zip->set_number('5110284')->is_valid_number, '三重県いなべ市大安町梅戸');
ok($zip->set_number('5110285')->is_valid_number, '三重県いなべ市大安町宇賀新田');
ok($zip->set_number('5110286')->is_valid_number, '三重県いなべ市大安町宇賀');
ok($zip->set_number('5110287')->is_valid_number, '三重県いなべ市大安町中央ケ丘');
ok($zip->set_number('5110401')->is_valid_number, '三重県いなべ市北勢町川原');
ok($zip->set_number('5110402')->is_valid_number, '三重県いなべ市北勢町千司久連新田');
ok($zip->set_number('5110403')->is_valid_number, '三重県いなべ市北勢町二之瀬');
ok($zip->set_number('5110404')->is_valid_number, '三重県いなべ市北勢町小原一色');
ok($zip->set_number('5110405')->is_valid_number, '三重県いなべ市北勢町田辺');
ok($zip->set_number('5110406')->is_valid_number, '三重県いなべ市北勢町塩崎');
ok($zip->set_number('5110411')->is_valid_number, '三重県いなべ市北勢町京ケ野新田');
ok($zip->set_number('5110412')->is_valid_number, '三重県いなべ市北勢町向平');
ok($zip->set_number('5110413')->is_valid_number, '三重県いなべ市北勢町畑毛');
ok($zip->set_number('5110414')->is_valid_number, '三重県いなべ市北勢町西貝野');
ok($zip->set_number('5110415')->is_valid_number, '三重県いなべ市北勢町東貝野');
ok($zip->set_number('5110416')->is_valid_number, '三重県いなべ市北勢町飯倉');
ok($zip->set_number('5110417')->is_valid_number, '三重県いなべ市北勢町瀬木');
ok($zip->set_number('5110418')->is_valid_number, '三重県いなべ市北勢町下平');
ok($zip->set_number('5110421')->is_valid_number, '三重県いなべ市北勢町皷');
ok($zip->set_number('5110422')->is_valid_number, '三重県いなべ市北勢町北中津原');
ok($zip->set_number('5110423')->is_valid_number, '三重県いなべ市北勢町平野新田');
ok($zip->set_number('5110424')->is_valid_number, '三重県いなべ市北勢町南中津原');
ok($zip->set_number('5110425')->is_valid_number, '三重県いなべ市北勢町大辻新田');
ok($zip->set_number('5110426')->is_valid_number, '三重県いなべ市北勢町其原');
ok($zip->set_number('5110427')->is_valid_number, '三重県いなべ市北勢町麻生田');
ok($zip->set_number('5110428')->is_valid_number, '三重県いなべ市北勢町阿下喜');
ok($zip->set_number('5110431')->is_valid_number, '三重県いなべ市北勢町別名');
ok($zip->set_number('5110432')->is_valid_number, '三重県いなべ市北勢町東村');
ok($zip->set_number('5110433')->is_valid_number, '三重県いなべ市北勢町中山');
ok($zip->set_number('5110434')->is_valid_number, '三重県いなべ市北勢町麓村');
ok($zip->set_number('5110435')->is_valid_number, '三重県いなべ市北勢町奥村');
ok($zip->set_number('5110436')->is_valid_number, '三重県いなべ市北勢町新町');
ok($zip->set_number('5110437')->is_valid_number, '三重県いなべ市北勢町垣内');
ok($zip->set_number('5110438')->is_valid_number, '三重県いなべ市北勢町治田外面');
ok($zip->set_number('5110501')->is_valid_number, '三重県いなべ市藤原町鼎');
ok($zip->set_number('5110502')->is_valid_number, '三重県いなべ市藤原町上相場');
ok($zip->set_number('5110503')->is_valid_number, '三重県いなべ市藤原町下相場');
ok($zip->set_number('5110504')->is_valid_number, '三重県いなべ市藤原町川合');
ok($zip->set_number('5110505')->is_valid_number, '三重県いなべ市藤原町日内');
ok($zip->set_number('5110506')->is_valid_number, '三重県いなべ市藤原町長尾');
ok($zip->set_number('5110507')->is_valid_number, '三重県いなべ市藤原町上之山田');
ok($zip->set_number('5110508')->is_valid_number, '三重県いなべ市藤原町藤ケ丘');
ok($zip->set_number('5110511')->is_valid_number, '三重県いなべ市藤原町市場');
ok($zip->set_number('5110512')->is_valid_number, '三重県いなべ市藤原町志礼石新田');
ok($zip->set_number('5110513')->is_valid_number, '三重県いなべ市藤原町下野尻');
ok($zip->set_number('5110514')->is_valid_number, '三重県いなべ市藤原町石川');
ok($zip->set_number('5110515')->is_valid_number, '三重県いなべ市藤原町東禅寺');
ok($zip->set_number('5110516')->is_valid_number, '三重県いなべ市藤原町西野尻');
ok($zip->set_number('5110517')->is_valid_number, '三重県いなべ市藤原町大貝戸');
ok($zip->set_number('5110518')->is_valid_number, '三重県いなべ市藤原町坂本');
ok($zip->set_number('5110519')->is_valid_number, '三重県いなべ市藤原町別名');
ok($zip->set_number('5110521')->is_valid_number, '三重県いなべ市藤原町古田');
ok($zip->set_number('5110522')->is_valid_number, '三重県いなべ市藤原町篠立');
ok($zip->set_number('5110523')->is_valid_number, '三重県いなべ市藤原町本郷');
ok($zip->set_number('5110524')->is_valid_number, '三重県いなべ市藤原町山口');
ok($zip->set_number('5110801')->is_valid_number, '三重県桑名市今島');
ok($zip->set_number('5110802')->is_valid_number, '三重県桑名市川崎町');
ok($zip->set_number('5110803')->is_valid_number, '三重県桑名市枇杷島台');
ok($zip->set_number('5110804')->is_valid_number, '三重県桑名市北川原台');
ok($zip->set_number('5110805')->is_valid_number, '三重県桑名市深谷町');
ok($zip->set_number('5110806')->is_valid_number, '三重県桑名市東汰上');
ok($zip->set_number('5110807')->is_valid_number, '三重県桑名市西汰上');
ok($zip->set_number('5110808')->is_valid_number, '三重県桑名市下深谷部');
ok($zip->set_number('5110809')->is_valid_number, '三重県桑名市上深谷部');
ok($zip->set_number('5110810')->is_valid_number, '三重県桑名市清竹の丘');
ok($zip->set_number('5110811')->is_valid_number, '三重県桑名市東方');
ok($zip->set_number('5110812')->is_valid_number, '三重県桑名市尾野山');
ok($zip->set_number('5110813')->is_valid_number, '三重県桑名市桜通');
ok($zip->set_number('5110814')->is_valid_number, '三重県桑名市松並町');
ok($zip->set_number('5110815')->is_valid_number, '三重県桑名市梅園通');
ok($zip->set_number('5110816')->is_valid_number, '三重県桑名市汐見町');
ok($zip->set_number('5110817')->is_valid_number, '三重県桑名市青葉町');
ok($zip->set_number('5110818')->is_valid_number, '三重県桑名市高塚町');
ok($zip->set_number('5110819')->is_valid_number, '三重県桑名市北別所');
ok($zip->set_number('5110821')->is_valid_number, '三重県桑名市矢田');
ok($zip->set_number('5110822')->is_valid_number, '三重県桑名市馬道');
ok($zip->set_number('5110823')->is_valid_number, '三重県桑名市明正町');
ok($zip->set_number('5110824')->is_valid_number, '三重県桑名市繁松新田');
ok($zip->set_number('5110825')->is_valid_number, '三重県桑名市上野');
ok($zip->set_number('5110826')->is_valid_number, '三重県桑名市太夫');
ok($zip->set_number('5110827')->is_valid_number, '三重県桑名市霞町');
ok($zip->set_number('5110828')->is_valid_number, '三重県桑名市立花町');
ok($zip->set_number('5110829')->is_valid_number, '三重県桑名市神楽町');
ok($zip->set_number('5110831')->is_valid_number, '三重県桑名市益生町');
ok($zip->set_number('5110832')->is_valid_number, '三重県桑名市新地');
ok($zip->set_number('5110833')->is_valid_number, '三重県桑名市福江町');
ok($zip->set_number('5110834')->is_valid_number, '三重県桑名市大福');
ok($zip->set_number('5110835')->is_valid_number, '三重県桑名市本願寺');
ok($zip->set_number('5110836')->is_valid_number, '三重県桑名市江場');
ok($zip->set_number('5110837')->is_valid_number, '三重県桑名市小泉');
ok($zip->set_number('5110838')->is_valid_number, '三重県桑名市和泉');
ok($zip->set_number('5110839')->is_valid_number, '三重県桑名市安永');
ok($zip->set_number('5110841')->is_valid_number, '三重県桑名市小貝須');
ok($zip->set_number('5110842')->is_valid_number, '三重県桑名市立田町');
ok($zip->set_number('5110843')->is_valid_number, '三重県桑名市太平町');
ok($zip->set_number('5110844')->is_valid_number, '三重県桑名市福岡町');
ok($zip->set_number('5110845')->is_valid_number, '三重県桑名市福地');
ok($zip->set_number('5110846')->is_valid_number, '三重県桑名市城南萱町');
ok($zip->set_number('5110847')->is_valid_number, '三重県桑名市福江');
ok($zip->set_number('5110848')->is_valid_number, '三重県桑名市大貝須');
ok($zip->set_number('5110851')->is_valid_number, '三重県桑名市希望ケ丘');
ok($zip->set_number('5110851')->is_valid_number, '三重県桑名市西別所');
ok($zip->set_number('5110852')->is_valid_number, '三重県桑名市稗田');
ok($zip->set_number('5110853')->is_valid_number, '三重県桑名市増田');
ok($zip->set_number('5110854')->is_valid_number, '三重県桑名市蓮花寺');
ok($zip->set_number('5110855')->is_valid_number, '三重県桑名市新倉持');
ok($zip->set_number('5110861')->is_valid_number, '三重県桑名市蠣塚新田');
ok($zip->set_number('5110862')->is_valid_number, '三重県桑名市播磨');
ok($zip->set_number('5110863')->is_valid_number, '三重県桑名市新西方');
ok($zip->set_number('5110864')->is_valid_number, '三重県桑名市西方');
ok($zip->set_number('5110865')->is_valid_number, '三重県桑名市藤が丘');
ok($zip->set_number('5110866')->is_valid_number, '三重県桑名市神成町');
ok($zip->set_number('5110867')->is_valid_number, '三重県桑名市陽だまりの丘');
ok($zip->set_number('5110868')->is_valid_number, '三重県桑名市さくらの丘');
ok($zip->set_number('5110901')->is_valid_number, '三重県桑名市筒尾');
ok($zip->set_number('5110902')->is_valid_number, '三重県桑名市松ノ木');
ok($zip->set_number('5110903')->is_valid_number, '三重県桑名市大山田');
ok($zip->set_number('5110904')->is_valid_number, '三重県桑名市野田');
ok($zip->set_number('5110911')->is_valid_number, '三重県桑名市額田');
ok($zip->set_number('5110912')->is_valid_number, '三重県桑名市星川');
ok($zip->set_number('5110912')->is_valid_number, '三重県桑名市星見ケ丘');
ok($zip->set_number('5110913')->is_valid_number, '三重県桑名市里町');
ok($zip->set_number('5110914')->is_valid_number, '三重県桑名市中山町');
ok($zip->set_number('5110921')->is_valid_number, '三重県桑名市東金井');
ok($zip->set_number('5110922')->is_valid_number, '三重県桑名市西金井');
ok($zip->set_number('5110923')->is_valid_number, '三重県桑名市桑部');
ok($zip->set_number('5110924')->is_valid_number, '三重県桑名市城山台');
ok($zip->set_number('5110931')->is_valid_number, '三重県桑名市能部');
ok($zip->set_number('5110932')->is_valid_number, '三重県桑名市東正和台');
ok($zip->set_number('5110933')->is_valid_number, '三重県桑名市西正和台');
ok($zip->set_number('5110934')->is_valid_number, '三重県桑名市赤尾');
ok($zip->set_number('5110935')->is_valid_number, '三重県桑名市赤尾台');
ok($zip->set_number('5110936')->is_valid_number, '三重県桑名市島田');
ok($zip->set_number('5110937')->is_valid_number, '三重県桑名市志知');
ok($zip->set_number('5110938')->is_valid_number, '三重県桑名市友村');
ok($zip->set_number('5110939')->is_valid_number, '三重県桑名市坂井');
ok($zip->set_number('5110941')->is_valid_number, '三重県桑名市嘉例川');
ok($zip->set_number('5110942')->is_valid_number, '三重県桑名市広見ケ丘');
ok($zip->set_number('5110943')->is_valid_number, '三重県桑名市森忠');
ok($zip->set_number('5110944')->is_valid_number, '三重県桑名市芳ケ崎');
ok($zip->set_number('5110945')->is_valid_number, '三重県桑名市筑紫');
ok($zip->set_number('5110946')->is_valid_number, '三重県桑名市五反田');
ok($zip->set_number('5110947')->is_valid_number, '三重県桑名市大仲新田');
ok($zip->set_number('5111101')->is_valid_number, '三重県桑名市長島町新所');
ok($zip->set_number('5111102')->is_valid_number, '三重県桑名市長島町西川');
ok($zip->set_number('5111103')->is_valid_number, '三重県桑名市長島町中川');
ok($zip->set_number('5111104')->is_valid_number, '三重県桑名市長島町高座');
ok($zip->set_number('5111105')->is_valid_number, '三重県桑名市長島町千倉');
ok($zip->set_number('5111106')->is_valid_number, '三重県桑名市長島町下坂手');
ok($zip->set_number('5111107')->is_valid_number, '三重県桑名市長島町上坂手');
ok($zip->set_number('5111108')->is_valid_number, '三重県桑名市長島町杉江');
ok($zip->set_number('5111109')->is_valid_number, '三重県桑名市長島町松之木');
ok($zip->set_number('5111111')->is_valid_number, '三重県桑名市長島町小島');
ok($zip->set_number('5111112')->is_valid_number, '三重県桑名市長島町大倉');
ok($zip->set_number('5111113')->is_valid_number, '三重県桑名市長島町押付');
ok($zip->set_number('5111114')->is_valid_number, '三重県桑名市長島町長島下町');
ok($zip->set_number('5111115')->is_valid_number, '三重県桑名市長島町長島中町');
ok($zip->set_number('5111116')->is_valid_number, '三重県桑名市長島町長島萱町');
ok($zip->set_number('5111121')->is_valid_number, '三重県桑名市長島町東殿名');
ok($zip->set_number('5111122')->is_valid_number, '三重県桑名市長島町松ケ島');
ok($zip->set_number('5111123')->is_valid_number, '三重県桑名市長島町鎌ケ地');
ok($zip->set_number('5111124')->is_valid_number, '三重県桑名市長島町葭ケ須');
ok($zip->set_number('5111125')->is_valid_number, '三重県桑名市長島町源部外面');
ok($zip->set_number('5111126')->is_valid_number, '三重県桑名市長島町又木');
ok($zip->set_number('5111127')->is_valid_number, '三重県桑名市長島町殿名');
ok($zip->set_number('5111128')->is_valid_number, '三重県桑名市長島町又木市街');
ok($zip->set_number('5111131')->is_valid_number, '三重県桑名市長島町赤地');
ok($zip->set_number('5111132')->is_valid_number, '三重県桑名市長島町福豊');
ok($zip->set_number('5111133')->is_valid_number, '三重県桑名市長島町横満蔵');
ok($zip->set_number('5111134')->is_valid_number, '三重県桑名市長島町松蔭');
ok($zip->set_number('5111135')->is_valid_number, '三重県桑名市長島町浦安');
ok($zip->set_number('5111136')->is_valid_number, '三重県桑名市長島町白鶏');
ok($zip->set_number('5111137')->is_valid_number, '三重県桑名市長島町福吉');
ok($zip->set_number('5111141')->is_valid_number, '三重県桑名市長島町間々');
ok($zip->set_number('5111142')->is_valid_number, '三重県桑名市長島町出口');
ok($zip->set_number('5111143')->is_valid_number, '三重県桑名市長島町西外面');
ok($zip->set_number('5111144')->is_valid_number, '三重県桑名市長島町駒江');
ok($zip->set_number('5111145')->is_valid_number, '三重県桑名市長島町大島');
ok($zip->set_number('5111146')->is_valid_number, '三重県桑名市長島町十日外面');
ok($zip->set_number('5111147')->is_valid_number, '三重県桑名市長島町平方');
ok($zip->set_number('5111148')->is_valid_number, '三重県桑名市長島町北殿名');
ok($zip->set_number('5111149')->is_valid_number, '三重県桑名市長島町西外面市街');
ok($zip->set_number('5120301')->is_valid_number, '三重県四日市市水沢野田町');
ok($zip->set_number('5120901')->is_valid_number, '三重県四日市市大谷台');
ok($zip->set_number('5120902')->is_valid_number, '三重県四日市市小杉町');
ok($zip->set_number('5120903')->is_valid_number, '三重県四日市市小杉新町');
ok($zip->set_number('5120904')->is_valid_number, '三重県四日市市東坂部町');
ok($zip->set_number('5120905')->is_valid_number, '三重県四日市市坂部が丘');
ok($zip->set_number('5120906')->is_valid_number, '三重県四日市市山之一色町');
ok($zip->set_number('5120907')->is_valid_number, '三重県四日市市東ケ谷');
ok($zip->set_number('5120908')->is_valid_number, '三重県四日市市坂部台');
ok($zip->set_number('5120911')->is_valid_number, '三重県四日市市生桑町');
ok($zip->set_number('5120912')->is_valid_number, '三重県四日市市三重');
ok($zip->set_number('5120913')->is_valid_number, '三重県四日市市西坂部町');
ok($zip->set_number('5120914')->is_valid_number, '三重県四日市市南坂部町');
ok($zip->set_number('5120921')->is_valid_number, '三重県四日市市尾平町');
ok($zip->set_number('5120922')->is_valid_number, '三重県四日市市曽井町');
ok($zip->set_number('5120923')->is_valid_number, '三重県四日市市高角町');
ok($zip->set_number('5120924')->is_valid_number, '三重県四日市市寺方町');
ok($zip->set_number('5120925')->is_valid_number, '三重県四日市市菅原町');
ok($zip->set_number('5120931')->is_valid_number, '三重県四日市市浮橋');
ok($zip->set_number('5120932')->is_valid_number, '三重県四日市市小生町');
ok($zip->set_number('5120933')->is_valid_number, '三重県四日市市三滝台');
ok($zip->set_number('5120934')->is_valid_number, '三重県四日市市川島町');
ok($zip->set_number('5120935')->is_valid_number, '三重県四日市市川島新町');
ok($zip->set_number('5120936')->is_valid_number, '三重県四日市市別山');
ok($zip->set_number('5121101')->is_valid_number, '三重県四日市市内山町');
ok($zip->set_number('5121102')->is_valid_number, '三重県四日市市小山町');
ok($zip->set_number('5121103')->is_valid_number, '三重県四日市市西山町');
ok($zip->set_number('5121104')->is_valid_number, '三重県四日市市美里町');
ok($zip->set_number('5121105')->is_valid_number, '三重県四日市市水沢町');
ok($zip->set_number('5121111')->is_valid_number, '三重県四日市市山田町');
ok($zip->set_number('5121113')->is_valid_number, '三重県四日市市鹿間町');
ok($zip->set_number('5121114')->is_valid_number, '三重県四日市市和無田町');
ok($zip->set_number('5121115')->is_valid_number, '三重県四日市市堂ケ山町');
ok($zip->set_number('5121116')->is_valid_number, '三重県四日市市六名町');
ok($zip->set_number('5121201')->is_valid_number, '三重県四日市市上海老町');
ok($zip->set_number('5121202')->is_valid_number, '三重県四日市市あがたが丘');
ok($zip->set_number('5121203')->is_valid_number, '三重県四日市市下海老町');
ok($zip->set_number('5121204')->is_valid_number, '三重県四日市市赤水町');
ok($zip->set_number('5121205')->is_valid_number, '三重県四日市市平尾町');
ok($zip->set_number('5121206')->is_valid_number, '三重県四日市市江村町');
ok($zip->set_number('5121207')->is_valid_number, '三重県四日市市黒田町');
ok($zip->set_number('5121208')->is_valid_number, '三重県四日市市北野町');
ok($zip->set_number('5121211')->is_valid_number, '三重県四日市市桜町');
ok($zip->set_number('5121212')->is_valid_number, '三重県四日市市智積町');
ok($zip->set_number('5121213')->is_valid_number, '三重県四日市市桜台本町');
ok($zip->set_number('5121214')->is_valid_number, '三重県四日市市桜台');
ok($zip->set_number('5121215')->is_valid_number, '三重県四日市市桜新町');
ok($zip->set_number('5121216')->is_valid_number, '三重県四日市市桜花台');
ok($zip->set_number('5121301')->is_valid_number, '三重県四日市市高見台');
ok($zip->set_number('5121302')->is_valid_number, '三重県四日市市市場町');
ok($zip->set_number('5121303')->is_valid_number, '三重県四日市市小牧町');
ok($zip->set_number('5121304')->is_valid_number, '三重県四日市市中野町');
ok($zip->set_number('5121305')->is_valid_number, '三重県四日市市西村町');
ok($zip->set_number('5121306')->is_valid_number, '三重県四日市市まきの木台');
ok($zip->set_number('5128041')->is_valid_number, '三重県四日市市山分町');
ok($zip->set_number('5128042')->is_valid_number, '三重県四日市市平津町');
ok($zip->set_number('5128043')->is_valid_number, '三重県四日市市平津新町');
ok($zip->set_number('5128044')->is_valid_number, '三重県四日市市中村町');
ok($zip->set_number('5128045')->is_valid_number, '三重県四日市市萱生町');
ok($zip->set_number('5128046')->is_valid_number, '三重県四日市市あかつき台');
ok($zip->set_number('5128047')->is_valid_number, '三重県四日市市八千代台');
ok($zip->set_number('5128048')->is_valid_number, '三重県四日市市山城町');
ok($zip->set_number('5128051')->is_valid_number, '三重県四日市市北山町');
ok($zip->set_number('5128052')->is_valid_number, '三重県四日市市西大鐘町');
ok($zip->set_number('5128053')->is_valid_number, '三重県四日市市大鐘町');
ok($zip->set_number('5128054')->is_valid_number, '三重県四日市市朝明町');
ok($zip->set_number('5128055')->is_valid_number, '三重県四日市市あさけが丘');
ok($zip->set_number('5128056')->is_valid_number, '三重県四日市市札場町');
ok($zip->set_number('5128061')->is_valid_number, '三重県四日市市広永町');
ok($zip->set_number('5128062')->is_valid_number, '三重県四日市市黄金町');
ok($zip->set_number('5128063')->is_valid_number, '三重県四日市市山村町');
ok($zip->set_number('5128064')->is_valid_number, '三重県四日市市伊坂町');
ok($zip->set_number('5128065')->is_valid_number, '三重県四日市市千代田町');
ok($zip->set_number('5128066')->is_valid_number, '三重県四日市市伊坂台');
ok($zip->set_number('5130000')->is_valid_number, '三重県鈴鹿市以下に掲載がない場合');
ok($zip->set_number('5130001')->is_valid_number, '三重県鈴鹿市広瀬町');
ok($zip->set_number('5130002')->is_valid_number, '三重県鈴鹿市津賀町');
ok($zip->set_number('5130003')->is_valid_number, '三重県鈴鹿市加佐登町');
ok($zip->set_number('5130004')->is_valid_number, '三重県鈴鹿市加佐登');
ok($zip->set_number('5130005')->is_valid_number, '三重県鈴鹿市汲川原町');
ok($zip->set_number('5130006')->is_valid_number, '三重県鈴鹿市和泉町');
ok($zip->set_number('5130007')->is_valid_number, '三重県鈴鹿市小田町');
ok($zip->set_number('5130008')->is_valid_number, '三重県鈴鹿市西冨田町');
ok($zip->set_number('5130009')->is_valid_number, '三重県鈴鹿市中冨田町');
ok($zip->set_number('5130010')->is_valid_number, '三重県鈴鹿市釆女が丘町');
ok($zip->set_number('5130011')->is_valid_number, '三重県鈴鹿市高塚町');
ok($zip->set_number('5130012')->is_valid_number, '三重県鈴鹿市石薬師町');
ok($zip->set_number('5130013')->is_valid_number, '三重県鈴鹿市国分町');
ok($zip->set_number('5130014')->is_valid_number, '三重県鈴鹿市高岡町');
ok($zip->set_number('5130015')->is_valid_number, '三重県鈴鹿市木田町');
ok($zip->set_number('5130016')->is_valid_number, '三重県鈴鹿市山辺町');
ok($zip->set_number('5130017')->is_valid_number, '三重県鈴鹿市上野町');
ok($zip->set_number('5130018')->is_valid_number, '三重県鈴鹿市上田町');
ok($zip->set_number('5130019')->is_valid_number, '三重県鈴鹿市高岡台');
ok($zip->set_number('5130021')->is_valid_number, '三重県鈴鹿市甲斐町');
ok($zip->set_number('5130022')->is_valid_number, '三重県鈴鹿市野辺町');
ok($zip->set_number('5130023')->is_valid_number, '三重県鈴鹿市河田町');
ok($zip->set_number('5130024')->is_valid_number, '三重県鈴鹿市野辺');
ok($zip->set_number('5130025')->is_valid_number, '三重県鈴鹿市竹野');
ok($zip->set_number('5130026')->is_valid_number, '三重県鈴鹿市竹野町');
ok($zip->set_number('5130027')->is_valid_number, '三重県鈴鹿市岡田');
ok($zip->set_number('5130028')->is_valid_number, '三重県鈴鹿市岡田町');
ok($zip->set_number('5130031')->is_valid_number, '三重県鈴鹿市一ノ宮町');
ok($zip->set_number('5130032')->is_valid_number, '三重県鈴鹿市池田町');
ok($zip->set_number('5130033')->is_valid_number, '三重県鈴鹿市須賀町');
ok($zip->set_number('5130034')->is_valid_number, '三重県鈴鹿市須賀');
ok($zip->set_number('5130035')->is_valid_number, '三重県鈴鹿市矢橋町');
ok($zip->set_number('5130036')->is_valid_number, '三重県鈴鹿市矢橋');
ok($zip->set_number('5130037')->is_valid_number, '三重県鈴鹿市十宮');
ok($zip->set_number('5130038')->is_valid_number, '三重県鈴鹿市十宮町');
ok($zip->set_number('5130041')->is_valid_number, '三重県鈴鹿市長太新町');
ok($zip->set_number('5130042')->is_valid_number, '三重県鈴鹿市長太旭町');
ok($zip->set_number('5130043')->is_valid_number, '三重県鈴鹿市長太栄町');
ok($zip->set_number('5130044')->is_valid_number, '三重県鈴鹿市北堀江町');
ok($zip->set_number('5130045')->is_valid_number, '三重県鈴鹿市北堀江');
ok($zip->set_number('5130046')->is_valid_number, '三重県鈴鹿市南堀江');
ok($zip->set_number('5130047')->is_valid_number, '三重県鈴鹿市南堀江町');
ok($zip->set_number('5130048')->is_valid_number, '三重県鈴鹿市南長太町');
ok($zip->set_number('5130049')->is_valid_number, '三重県鈴鹿市北長太町');
ok($zip->set_number('5130051')->is_valid_number, '三重県鈴鹿市下箕田町');
ok($zip->set_number('5130052')->is_valid_number, '三重県鈴鹿市下箕田');
ok($zip->set_number('5130053')->is_valid_number, '三重県鈴鹿市中箕田町');
ok($zip->set_number('5130054')->is_valid_number, '三重県鈴鹿市中箕田');
ok($zip->set_number('5130055')->is_valid_number, '三重県鈴鹿市上箕田町');
ok($zip->set_number('5130056')->is_valid_number, '三重県鈴鹿市上箕田');
ok($zip->set_number('5130057')->is_valid_number, '三重県鈴鹿市南林崎町');
ok($zip->set_number('5130058')->is_valid_number, '三重県鈴鹿市林崎');
ok($zip->set_number('5130059')->is_valid_number, '三重県鈴鹿市林崎町');
ok($zip->set_number('5130801')->is_valid_number, '三重県鈴鹿市神戸');
ok($zip->set_number('5130801')->is_valid_number, '三重県鈴鹿市神戸本多町');
ok($zip->set_number('5130802')->is_valid_number, '三重県鈴鹿市飯野寺家町');
ok($zip->set_number('5130803')->is_valid_number, '三重県鈴鹿市三日市町');
ok($zip->set_number('5130804')->is_valid_number, '三重県鈴鹿市三日市南');
ok($zip->set_number('5130805')->is_valid_number, '三重県鈴鹿市算所町');
ok($zip->set_number('5130806')->is_valid_number, '三重県鈴鹿市算所');
ok($zip->set_number('5130807')->is_valid_number, '三重県鈴鹿市三日市');
ok($zip->set_number('5130808')->is_valid_number, '三重県鈴鹿市西條町');
ok($zip->set_number('5130809')->is_valid_number, '三重県鈴鹿市西条');
ok($zip->set_number('5130811')->is_valid_number, '三重県鈴鹿市柳町');
ok($zip->set_number('5130812')->is_valid_number, '三重県鈴鹿市土師町');
ok($zip->set_number('5130813')->is_valid_number, '三重県鈴鹿市北玉垣町');
ok($zip->set_number('5130814')->is_valid_number, '三重県鈴鹿市東玉垣町');
ok($zip->set_number('5130815')->is_valid_number, '三重県鈴鹿市西玉垣町');
ok($zip->set_number('5130816')->is_valid_number, '三重県鈴鹿市南玉垣町');
ok($zip->set_number('5130817')->is_valid_number, '三重県鈴鹿市桜島町');
ok($zip->set_number('5130818')->is_valid_number, '三重県鈴鹿市安塚町');
ok($zip->set_number('5130819')->is_valid_number, '三重県鈴鹿市肥田町');
ok($zip->set_number('5130821')->is_valid_number, '三重県鈴鹿市地子町');
ok($zip->set_number('5130822')->is_valid_number, '三重県鈴鹿市末広町');
ok($zip->set_number('5130823')->is_valid_number, '三重県鈴鹿市道伯');
ok($zip->set_number('5130824')->is_valid_number, '三重県鈴鹿市道伯町');
ok($zip->set_number('5130825')->is_valid_number, '三重県鈴鹿市住吉町');
ok($zip->set_number('5130826')->is_valid_number, '三重県鈴鹿市住吉');
ok($zip->set_number('5130827')->is_valid_number, '三重県鈴鹿市大池');
ok($zip->set_number('5130828')->is_valid_number, '三重県鈴鹿市阿古曽町');
ok($zip->set_number('5130831')->is_valid_number, '三重県鈴鹿市庄野町');
ok($zip->set_number('5130832')->is_valid_number, '三重県鈴鹿市庄野東');
ok($zip->set_number('5130833')->is_valid_number, '三重県鈴鹿市庄野共進');
ok($zip->set_number('5130834')->is_valid_number, '三重県鈴鹿市庄野羽山');
ok($zip->set_number('5130835')->is_valid_number, '三重県鈴鹿市平野町');
ok($zip->set_number('5130836')->is_valid_number, '三重県鈴鹿市国府町');
ok($zip->set_number('5130837')->is_valid_number, '三重県鈴鹿市八野町');
ok($zip->set_number('5130841')->is_valid_number, '三重県鈴鹿市弓削町');
ok($zip->set_number('5130842')->is_valid_number, '三重県鈴鹿市弓削');
ok($zip->set_number('5130843')->is_valid_number, '三重県鈴鹿市平田東町');
ok($zip->set_number('5130844')->is_valid_number, '三重県鈴鹿市平田');
ok($zip->set_number('5130845')->is_valid_number, '三重県鈴鹿市平田新町');
ok($zip->set_number('5130846')->is_valid_number, '三重県鈴鹿市平田中町');
ok($zip->set_number('5130847')->is_valid_number, '三重県鈴鹿市平田町');
ok($zip->set_number('5130848')->is_valid_number, '三重県鈴鹿市平田本町');
ok($zip->set_number('5130851')->is_valid_number, '三重県鈴鹿市末広東');
ok($zip->set_number('5130852')->is_valid_number, '三重県鈴鹿市末広西');
ok($zip->set_number('5130853')->is_valid_number, '三重県鈴鹿市末広南');
ok($zip->set_number('5130854')->is_valid_number, '三重県鈴鹿市末広北');
ok($zip->set_number('5130855')->is_valid_number, '三重県鈴鹿市石垣');
ok($zip->set_number('5131121')->is_valid_number, '三重県鈴鹿市岸田町');
ok($zip->set_number('5131122')->is_valid_number, '三重県鈴鹿市花川町');
ok($zip->set_number('5131123')->is_valid_number, '三重県鈴鹿市下大久保町');
ok($zip->set_number('5131124')->is_valid_number, '三重県鈴鹿市自由ヶ丘');
ok($zip->set_number('5140000')->is_valid_number, '三重県津市以下に掲載がない場合');
ok($zip->set_number('5140001')->is_valid_number, '三重県津市江戸橋');
ok($zip->set_number('5140002')->is_valid_number, '三重県津市島崎町');
ok($zip->set_number('5140003')->is_valid_number, '三重県津市桜橋');
ok($zip->set_number('5140004')->is_valid_number, '三重県津市栄町');
ok($zip->set_number('5140005')->is_valid_number, '三重県津市鳥居町');
ok($zip->set_number('5140006')->is_valid_number, '三重県津市広明町');
ok($zip->set_number('5140007')->is_valid_number, '三重県津市大谷町');
ok($zip->set_number('5140008')->is_valid_number, '三重県津市上浜町');
ok($zip->set_number('5140009')->is_valid_number, '三重県津市羽所町');
ok($zip->set_number('5140010')->is_valid_number, '三重県津市なぎさまち');
ok($zip->set_number('5140011')->is_valid_number, '三重県津市高洲町');
ok($zip->set_number('5140012')->is_valid_number, '三重県津市末広町');
ok($zip->set_number('5140013')->is_valid_number, '三重県津市海岸町');
ok($zip->set_number('5140014')->is_valid_number, '三重県津市港町');
ok($zip->set_number('5140015')->is_valid_number, '三重県津市寿町');
ok($zip->set_number('5140016')->is_valid_number, '三重県津市乙部');
ok($zip->set_number('5140017')->is_valid_number, '三重県津市相生町');
ok($zip->set_number('5140018')->is_valid_number, '三重県津市中河原');
ok($zip->set_number('5140019')->is_valid_number, '三重県津市住吉町');
ok($zip->set_number('5140021')->is_valid_number, '三重県津市万町津');
ok($zip->set_number('5140022')->is_valid_number, '三重県津市愛宕町');
ok($zip->set_number('5140023')->is_valid_number, '三重県津市北町津');
ok($zip->set_number('5140024')->is_valid_number, '三重県津市新立町津');
ok($zip->set_number('5140025')->is_valid_number, '三重県津市東町津');
ok($zip->set_number('5140026')->is_valid_number, '三重県津市新東町塔世');
ok($zip->set_number('5140027')->is_valid_number, '三重県津市大門');
ok($zip->set_number('5140028')->is_valid_number, '三重県津市東丸之内');
ok($zip->set_number('5140031')->is_valid_number, '三重県津市北丸之内');
ok($zip->set_number('5140032')->is_valid_number, '三重県津市中央');
ok($zip->set_number('5140033')->is_valid_number, '三重県津市丸之内');
ok($zip->set_number('5140034')->is_valid_number, '三重県津市南丸之内');
ok($zip->set_number('5140035')->is_valid_number, '三重県津市西丸之内');
ok($zip->set_number('5140036')->is_valid_number, '三重県津市丸之内養正町');
ok($zip->set_number('5140037')->is_valid_number, '三重県津市東古河町');
ok($zip->set_number('5140038')->is_valid_number, '三重県津市西古河町');
ok($zip->set_number('5140039')->is_valid_number, '三重県津市押加部町');
ok($zip->set_number('5140041')->is_valid_number, '三重県津市八町');
ok($zip->set_number('5140042')->is_valid_number, '三重県津市新町');
ok($zip->set_number('5140043')->is_valid_number, '三重県津市南新町');
ok($zip->set_number('5140044')->is_valid_number, '三重県津市川添町');
ok($zip->set_number('5140045')->is_valid_number, '三重県津市美川町');
ok($zip->set_number('5140046')->is_valid_number, '三重県津市大園町');
ok($zip->set_number('5140047')->is_valid_number, '三重県津市桜田町');
ok($zip->set_number('5140051')->is_valid_number, '三重県津市納所町');
ok($zip->set_number('5140052')->is_valid_number, '三重県津市神納町');
ok($zip->set_number('5140053')->is_valid_number, '三重県津市博多町');
ok($zip->set_number('5140054')->is_valid_number, '三重県津市神納');
ok($zip->set_number('5140055')->is_valid_number, '三重県津市南河路');
ok($zip->set_number('5140056')->is_valid_number, '三重県津市北河路町');
ok($zip->set_number('5140057')->is_valid_number, '三重県津市一色町');
ok($zip->set_number('5140058')->is_valid_number, '三重県津市安東町');
ok($zip->set_number('5140061')->is_valid_number, '三重県津市一身田上津部田');
ok($zip->set_number('5140062')->is_valid_number, '三重県津市観音寺町');
ok($zip->set_number('5140063')->is_valid_number, '三重県津市渋見町');
ok($zip->set_number('5140064')->is_valid_number, '三重県津市長岡町');
ok($zip->set_number('5140065')->is_valid_number, '三重県津市河辺町');
ok($zip->set_number('5140071')->is_valid_number, '三重県津市分部');
ok($zip->set_number('5140072')->is_valid_number, '三重県津市小舟');
ok($zip->set_number('5140073')->is_valid_number, '三重県津市殿村');
ok($zip->set_number('5140074')->is_valid_number, '三重県津市片田長谷場町');
ok($zip->set_number('5140075')->is_valid_number, '三重県津市片田志袋町');
ok($zip->set_number('5140076')->is_valid_number, '三重県津市産品');
ok($zip->set_number('5140077')->is_valid_number, '三重県津市片田長谷町');
ok($zip->set_number('5140081')->is_valid_number, '三重県津市片田田中町');
ok($zip->set_number('5140082')->is_valid_number, '三重県津市片田井戸町');
ok($zip->set_number('5140083')->is_valid_number, '三重県津市片田新町');
ok($zip->set_number('5140084')->is_valid_number, '三重県津市片田町');
ok($zip->set_number('5140085')->is_valid_number, '三重県津市片田久保町');
ok($zip->set_number('5140086')->is_valid_number, '三重県津市片田薬王寺町');
ok($zip->set_number('5140101')->is_valid_number, '三重県津市白塚町');
ok($zip->set_number('5140102')->is_valid_number, '三重県津市栗真町屋町');
ok($zip->set_number('5140103')->is_valid_number, '三重県津市栗真中山町');
ok($zip->set_number('5140104')->is_valid_number, '三重県津市栗真小川町');
ok($zip->set_number('5140111')->is_valid_number, '三重県津市一身田平野');
ok($zip->set_number('5140112')->is_valid_number, '三重県津市一身田中野');
ok($zip->set_number('5140113')->is_valid_number, '三重県津市一身田大古曽');
ok($zip->set_number('5140114')->is_valid_number, '三重県津市一身田町');
ok($zip->set_number('5140115')->is_valid_number, '三重県津市一身田豊野');
ok($zip->set_number('5140116')->is_valid_number, '三重県津市夢が丘');
ok($zip->set_number('5140121')->is_valid_number, '三重県津市大里山室町');
ok($zip->set_number('5140122')->is_valid_number, '三重県津市大里野田町');
ok($zip->set_number('5140123')->is_valid_number, '三重県津市大里小野田町');
ok($zip->set_number('5140124')->is_valid_number, '三重県津市大里川北町');
ok($zip->set_number('5140125')->is_valid_number, '三重県津市大里窪田町');
ok($zip->set_number('5140126')->is_valid_number, '三重県津市大里睦合町');
ok($zip->set_number('5140131')->is_valid_number, '三重県津市あのつ台');
ok($zip->set_number('5140301')->is_valid_number, '三重県津市雲出鋼管町');
ok($zip->set_number('5140302')->is_valid_number, '三重県津市雲出伊倉津町');
ok($zip->set_number('5140303')->is_valid_number, '三重県津市雲出長常町');
ok($zip->set_number('5140304')->is_valid_number, '三重県津市雲出本郷町');
ok($zip->set_number('5140305')->is_valid_number, '三重県津市雲出島貫町');
ok($zip->set_number('5140311')->is_valid_number, '三重県津市香良洲町(稲葉)');
ok($zip->set_number('5140312')->is_valid_number, '三重県津市香良洲町(小松)');
ok($zip->set_number('5140313')->is_valid_number, '三重県津市香良洲町(浜浦)');
ok($zip->set_number('5140314')->is_valid_number, '三重県津市香良洲町(高砂)');
ok($zip->set_number('5140315')->is_valid_number, '三重県津市香良洲町(その他)');
ok($zip->set_number('5140321')->is_valid_number, '三重県津市香良洲町(砂原)');
ok($zip->set_number('5140323')->is_valid_number, '三重県津市香良洲町(馬場)');
ok($zip->set_number('5140324')->is_valid_number, '三重県津市香良洲町(地家)');
ok($zip->set_number('5140325')->is_valid_number, '三重県津市香良洲町(桜町)');
ok($zip->set_number('5140326')->is_valid_number, '三重県津市香良洲町(川原)');
ok($zip->set_number('5140801')->is_valid_number, '三重県津市船頭町津興');
ok($zip->set_number('5140802')->is_valid_number, '三重県津市三重町津興');
ok($zip->set_number('5140803')->is_valid_number, '三重県津市柳山津興');
ok($zip->set_number('5140804')->is_valid_number, '三重県津市上弁財町津興');
ok($zip->set_number('5140805')->is_valid_number, '三重県津市下弁財町津興');
ok($zip->set_number('5140806')->is_valid_number, '三重県津市上弁財町');
ok($zip->set_number('5140811')->is_valid_number, '三重県津市阿漕町');
ok($zip->set_number('5140812')->is_valid_number, '三重県津市津興');
ok($zip->set_number('5140813')->is_valid_number, '三重県津市八幡町');
ok($zip->set_number('5140814')->is_valid_number, '三重県津市藤枝町');
ok($zip->set_number('5140815')->is_valid_number, '三重県津市藤方');
ok($zip->set_number('5140816')->is_valid_number, '三重県津市高茶屋小森上野町');
ok($zip->set_number('5140817')->is_valid_number, '三重県津市高茶屋小森町');
ok($zip->set_number('5140818')->is_valid_number, '三重県津市城山');
ok($zip->set_number('5140819')->is_valid_number, '三重県津市高茶屋');
ok($zip->set_number('5140821')->is_valid_number, '三重県津市垂水');
ok($zip->set_number('5140822')->is_valid_number, '三重県津市南が丘');
ok($zip->set_number('5140823')->is_valid_number, '三重県津市半田');
ok($zip->set_number('5140824')->is_valid_number, '三重県津市神戸');
ok($zip->set_number('5140825')->is_valid_number, '三重県津市緑が丘');
ok($zip->set_number('5140826')->is_valid_number, '三重県津市野田');
ok($zip->set_number('5140831')->is_valid_number, '三重県津市本町');
ok($zip->set_number('5140832')->is_valid_number, '三重県津市南中央');
ok($zip->set_number('5140833')->is_valid_number, '三重県津市西阿漕町岩田');
ok($zip->set_number('5140834')->is_valid_number, '三重県津市大倉');
ok($zip->set_number('5140835')->is_valid_number, '三重県津市幸町');
ok($zip->set_number('5140836')->is_valid_number, '三重県津市野崎垣内岩田');
ok($zip->set_number('5140837')->is_valid_number, '三重県津市修成町');
ok($zip->set_number('5140838')->is_valid_number, '三重県津市岩田');
ok($zip->set_number('5141101')->is_valid_number, '三重県津市久居明神町');
ok($zip->set_number('5141102')->is_valid_number, '三重県津市久居藤ケ丘町');
ok($zip->set_number('5141103')->is_valid_number, '三重県津市久居相川町');
ok($zip->set_number('5141104')->is_valid_number, '三重県津市久居持川町');
ok($zip->set_number('5141105')->is_valid_number, '三重県津市久居北口町');
ok($zip->set_number('5141106')->is_valid_number, '三重県津市久居寺町');
ok($zip->set_number('5141107')->is_valid_number, '三重県津市久居中町');
ok($zip->set_number('5141108')->is_valid_number, '三重県津市久居射場町');
ok($zip->set_number('5141109')->is_valid_number, '三重県津市久居烏木町');
ok($zip->set_number('5141111')->is_valid_number, '三重県津市久居桜が丘町');
ok($zip->set_number('5141112')->is_valid_number, '三重県津市久居小野辺町');
ok($zip->set_number('5141113')->is_valid_number, '三重県津市久居野村町');
ok($zip->set_number('5141114')->is_valid_number, '三重県津市久居井戸山町');
ok($zip->set_number('5141115')->is_valid_number, '三重県津市木造町');
ok($zip->set_number('5141116')->is_valid_number, '三重県津市新家町');
ok($zip->set_number('5141117')->is_valid_number, '三重県津市久居野口町');
ok($zip->set_number('5141118')->is_valid_number, '三重県津市久居新町');
ok($zip->set_number('5141121')->is_valid_number, '三重県津市久居二ノ町');
ok($zip->set_number('5141122')->is_valid_number, '三重県津市川方町');
ok($zip->set_number('5141123')->is_valid_number, '三重県津市牧町');
ok($zip->set_number('5141124')->is_valid_number, '三重県津市須ケ瀬町');
ok($zip->set_number('5141125')->is_valid_number, '三重県津市久居元町');
ok($zip->set_number('5141131')->is_valid_number, '三重県津市久居西鷹跡町');
ok($zip->set_number('5141132')->is_valid_number, '三重県津市久居幸町');
ok($zip->set_number('5141133')->is_valid_number, '三重県津市久居万町');
ok($zip->set_number('5141134')->is_valid_number, '三重県津市久居旅籠町');
ok($zip->set_number('5141135')->is_valid_number, '三重県津市久居本町');
ok($zip->set_number('5141136')->is_valid_number, '三重県津市久居東鷹跡町');
ok($zip->set_number('5141137')->is_valid_number, '三重県津市久居小戸木町');
ok($zip->set_number('5141138')->is_valid_number, '三重県津市戸木町');
ok($zip->set_number('5141139')->is_valid_number, '三重県津市青葉台');
ok($zip->set_number('5141251')->is_valid_number, '三重県津市榊原町');
ok($zip->set_number('5141252')->is_valid_number, '三重県津市稲葉町');
ok($zip->set_number('5141253')->is_valid_number, '三重県津市久居一色町');
ok($zip->set_number('5141254')->is_valid_number, '三重県津市森町');
ok($zip->set_number('5141255')->is_valid_number, '三重県津市庄田町');
ok($zip->set_number('5141256')->is_valid_number, '三重県津市中村町');
ok($zip->set_number('5141257')->is_valid_number, '三重県津市大鳥町');
ok($zip->set_number('5141258')->is_valid_number, '三重県津市久居緑が丘町');
ok($zip->set_number('5142101')->is_valid_number, '三重県津市美里町高座原');
ok($zip->set_number('5142102')->is_valid_number, '三重県津市美里町船山');
ok($zip->set_number('5142103')->is_valid_number, '三重県津市美里町日南田');
ok($zip->set_number('5142104')->is_valid_number, '三重県津市美里町家所');
ok($zip->set_number('5142105')->is_valid_number, '三重県津市美里町五百野');
ok($zip->set_number('5142106')->is_valid_number, '三重県津市美里町足坂');
ok($zip->set_number('5142107')->is_valid_number, '三重県津市美里町穴倉');
ok($zip->set_number('5142111')->is_valid_number, '三重県津市美里町平木');
ok($zip->set_number('5142112')->is_valid_number, '三重県津市美里町北長野');
ok($zip->set_number('5142113')->is_valid_number, '三重県津市美里町三郷');
ok($zip->set_number('5142114')->is_valid_number, '三重県津市美里町南長野');
ok($zip->set_number('5142115')->is_valid_number, '三重県津市美里町桂畑');
ok($zip->set_number('5142201')->is_valid_number, '三重県津市芸濃町楠原');
ok($zip->set_number('5142202')->is_valid_number, '三重県津市芸濃町林');
ok($zip->set_number('5142203')->is_valid_number, '三重県津市芸濃町中縄');
ok($zip->set_number('5142204')->is_valid_number, '三重県津市芸濃町雲林院');
ok($zip->set_number('5142205')->is_valid_number, '三重県津市芸濃町多門');
ok($zip->set_number('5142206')->is_valid_number, '三重県津市芸濃町小野平');
ok($zip->set_number('5142207')->is_valid_number, '三重県津市芸濃町河内');
ok($zip->set_number('5142208')->is_valid_number, '三重県津市芸濃町忍田');
ok($zip->set_number('5142211')->is_valid_number, '三重県津市芸濃町椋本');
ok($zip->set_number('5142212')->is_valid_number, '三重県津市芸濃町岡本');
ok($zip->set_number('5142213')->is_valid_number, '三重県津市芸濃町北神山');
ok($zip->set_number('5142214')->is_valid_number, '三重県津市芸濃町萩野');
ok($zip->set_number('5142221')->is_valid_number, '三重県津市高野尾町');
ok($zip->set_number('5142222')->is_valid_number, '三重県津市豊が丘');
ok($zip->set_number('5142301')->is_valid_number, '三重県津市安濃町荒木');
ok($zip->set_number('5142302')->is_valid_number, '三重県津市安濃町安濃');
ok($zip->set_number('5142303')->is_valid_number, '三重県津市安濃町内多');
ok($zip->set_number('5142304')->is_valid_number, '三重県津市安濃町太田');
ok($zip->set_number('5142305')->is_valid_number, '三重県津市安濃町清水');
ok($zip->set_number('5142306')->is_valid_number, '三重県津市安濃町曽根');
ok($zip->set_number('5142307')->is_valid_number, '三重県津市安濃町浄土寺');
ok($zip->set_number('5142308')->is_valid_number, '三重県津市安濃町川西');
ok($zip->set_number('5142311')->is_valid_number, '三重県津市安濃町神田');
ok($zip->set_number('5142312')->is_valid_number, '三重県津市安濃町連部');
ok($zip->set_number('5142313')->is_valid_number, '三重県津市安濃町今徳');
ok($zip->set_number('5142314')->is_valid_number, '三重県津市安濃町妙法寺');
ok($zip->set_number('5142315')->is_valid_number, '三重県津市安濃町光明寺');
ok($zip->set_number('5142316')->is_valid_number, '三重県津市安濃町南神山');
ok($zip->set_number('5142317')->is_valid_number, '三重県津市安濃町前野');
ok($zip->set_number('5142318')->is_valid_number, '三重県津市安濃町中川');
ok($zip->set_number('5142321')->is_valid_number, '三重県津市安濃町野口');
ok($zip->set_number('5142322')->is_valid_number, '三重県津市安濃町戸島');
ok($zip->set_number('5142323')->is_valid_number, '三重県津市安濃町大塚');
ok($zip->set_number('5142324')->is_valid_number, '三重県津市安濃町粟加');
ok($zip->set_number('5142325')->is_valid_number, '三重県津市安濃町田端上野');
ok($zip->set_number('5142326')->is_valid_number, '三重県津市安濃町東観音寺');
ok($zip->set_number('5142327')->is_valid_number, '三重県津市安濃町安部');
ok($zip->set_number('5142328')->is_valid_number, '三重県津市安濃町草生');
ok($zip->set_number('5150000')->is_valid_number, '三重県松阪市以下に掲載がない場合');
ok($zip->set_number('5150001')->is_valid_number, '三重県松阪市大口町');
ok($zip->set_number('5150002')->is_valid_number, '三重県松阪市郷津町');
ok($zip->set_number('5150003')->is_valid_number, '三重県松阪市朝日町一区');
ok($zip->set_number('5150004')->is_valid_number, '三重県松阪市朝日町');
ok($zip->set_number('5150005')->is_valid_number, '三重県松阪市鎌田町');
ok($zip->set_number('5150006')->is_valid_number, '三重県松阪市石津町');
ok($zip->set_number('5150007')->is_valid_number, '三重県松阪市荒木町');
ok($zip->set_number('5150011')->is_valid_number, '三重県松阪市高町');
ok($zip->set_number('5150012')->is_valid_number, '三重県松阪市東町');
ok($zip->set_number('5150013')->is_valid_number, '三重県松阪市幸生町');
ok($zip->set_number('5150014')->is_valid_number, '三重県松阪市若葉町');
ok($zip->set_number('5150015')->is_valid_number, '三重県松阪市宮町');
ok($zip->set_number('5150016')->is_valid_number, '三重県松阪市末広町');
ok($zip->set_number('5150017')->is_valid_number, '三重県松阪市京町');
ok($zip->set_number('5150018')->is_valid_number, '三重県松阪市京町一区');
ok($zip->set_number('5150019')->is_valid_number, '三重県松阪市中央町');
ok($zip->set_number('5150021')->is_valid_number, '三重県松阪市古井町');
ok($zip->set_number('5150022')->is_valid_number, '三重県松阪市新屋敷町');
ok($zip->set_number('5150023')->is_valid_number, '三重県松阪市下七見町');
ok($zip->set_number('5150024')->is_valid_number, '三重県松阪市大宮田町');
ok($zip->set_number('5150025')->is_valid_number, '三重県松阪市和屋町');
ok($zip->set_number('5150026')->is_valid_number, '三重県松阪市立田町');
ok($zip->set_number('5150027')->is_valid_number, '三重県松阪市朝田町');
ok($zip->set_number('5150028')->is_valid_number, '三重県松阪市佐久米町');
ok($zip->set_number('5150029')->is_valid_number, '三重県松阪市西野々町');
ok($zip->set_number('5150031')->is_valid_number, '三重県松阪市大津町');
ok($zip->set_number('5150032')->is_valid_number, '三重県松阪市田原町');
ok($zip->set_number('5150033')->is_valid_number, '三重県松阪市垣鼻町');
ok($zip->set_number('5150034')->is_valid_number, '三重県松阪市南町');
ok($zip->set_number('5150035')->is_valid_number, '三重県松阪市長月町');
ok($zip->set_number('5150036')->is_valid_number, '三重県松阪市平生町');
ok($zip->set_number('5150037')->is_valid_number, '三重県松阪市愛宕町');
ok($zip->set_number('5150038')->is_valid_number, '三重県松阪市挽木町');
ok($zip->set_number('5150039')->is_valid_number, '三重県松阪市清生町');
ok($zip->set_number('5150041')->is_valid_number, '三重県松阪市上川町');
ok($zip->set_number('5150042')->is_valid_number, '三重県松阪市虹が丘町');
ok($zip->set_number('5150043')->is_valid_number, '三重県松阪市下村町');
ok($zip->set_number('5150044')->is_valid_number, '三重県松阪市久保町');
ok($zip->set_number('5150045')->is_valid_number, '三重県松阪市駅部田町');
ok($zip->set_number('5150046')->is_valid_number, '三重県松阪市南虹が丘町');
ok($zip->set_number('5150051')->is_valid_number, '三重県松阪市光町');
ok($zip->set_number('5150052')->is_valid_number, '三重県松阪市山室町');
ok($zip->set_number('5150053')->is_valid_number, '三重県松阪市広陽町');
ok($zip->set_number('5150054')->is_valid_number, '三重県松阪市立野町');
ok($zip->set_number('5150055')->is_valid_number, '三重県松阪市田村町');
ok($zip->set_number('5150056')->is_valid_number, '三重県松阪市宝塚町');
ok($zip->set_number('5150057')->is_valid_number, '三重県松阪市御殿山町');
ok($zip->set_number('5150061')->is_valid_number, '三重県松阪市黒田町');
ok($zip->set_number('5150062')->is_valid_number, '三重県松阪市小黒田町');
ok($zip->set_number('5150063')->is_valid_number, '三重県松阪市大黒田町');
ok($zip->set_number('5150064')->is_valid_number, '三重県松阪市五反田町');
ok($zip->set_number('5150065')->is_valid_number, '三重県松阪市五月町');
ok($zip->set_number('5150066')->is_valid_number, '三重県松阪市泉町');
ok($zip->set_number('5150071')->is_valid_number, '三重県松阪市桜町');
ok($zip->set_number('5150072')->is_valid_number, '三重県松阪市内五曲町');
ok($zip->set_number('5150073')->is_valid_number, '三重県松阪市殿町');
ok($zip->set_number('5150074')->is_valid_number, '三重県松阪市新座町');
ok($zip->set_number('5150075')->is_valid_number, '三重県松阪市新町');
ok($zip->set_number('5150076')->is_valid_number, '三重県松阪市白粉町');
ok($zip->set_number('5150077')->is_valid_number, '三重県松阪市茶与町');
ok($zip->set_number('5150078')->is_valid_number, '三重県松阪市春日町');
ok($zip->set_number('5150081')->is_valid_number, '三重県松阪市本町');
ok($zip->set_number('5150082')->is_valid_number, '三重県松阪市魚町');
ok($zip->set_number('5150083')->is_valid_number, '三重県松阪市中町');
ok($zip->set_number('5150084')->is_valid_number, '三重県松阪市日野町');
ok($zip->set_number('5150085')->is_valid_number, '三重県松阪市湊町');
ok($zip->set_number('5150086')->is_valid_number, '三重県松阪市五十鈴町');
ok($zip->set_number('5150087')->is_valid_number, '三重県松阪市萌木町');
ok($zip->set_number('5150088')->is_valid_number, '三重県松阪市木の郷町');
ok($zip->set_number('5150101')->is_valid_number, '三重県松阪市東黒部町');
ok($zip->set_number('5150102')->is_valid_number, '三重県松阪市松名瀬町');
ok($zip->set_number('5150103')->is_valid_number, '三重県松阪市西黒部町');
ok($zip->set_number('5150104')->is_valid_number, '三重県松阪市高須町');
ok($zip->set_number('5150111')->is_valid_number, '三重県松阪市柿木原町');
ok($zip->set_number('5150112')->is_valid_number, '三重県松阪市土古路町');
ok($zip->set_number('5150113')->is_valid_number, '三重県松阪市出間町');
ok($zip->set_number('5150114')->is_valid_number, '三重県松阪市大垣内町');
ok($zip->set_number('5150115')->is_valid_number, '三重県松阪市蓮花寺町');
ok($zip->set_number('5150116')->is_valid_number, '三重県松阪市牛草町');
ok($zip->set_number('5150117')->is_valid_number, '三重県松阪市乙部町');
ok($zip->set_number('5150118')->is_valid_number, '三重県松阪市垣内田町');
ok($zip->set_number('5150119')->is_valid_number, '三重県松阪市神守町');
ok($zip->set_number('5150121')->is_valid_number, '三重県松阪市東久保町');
ok($zip->set_number('5150122')->is_valid_number, '三重県松阪市川島町');
ok($zip->set_number('5150123')->is_valid_number, '三重県松阪市新開町');
ok($zip->set_number('5150124')->is_valid_number, '三重県松阪市保津町');
ok($zip->set_number('5150125')->is_valid_number, '三重県松阪市腹太町');
ok($zip->set_number('5150126')->is_valid_number, '三重県松阪市井口中町');
ok($zip->set_number('5150127')->is_valid_number, '三重県松阪市六根町');
ok($zip->set_number('5150128')->is_valid_number, '三重県松阪市魚見町');
ok($zip->set_number('5150201')->is_valid_number, '三重県松阪市上七見町');
ok($zip->set_number('5150202')->is_valid_number, '三重県松阪市菅生町');
ok($zip->set_number('5150203')->is_valid_number, '三重県松阪市清水町');
ok($zip->set_number('5150204')->is_valid_number, '三重県松阪市櫛田町');
ok($zip->set_number('5150205')->is_valid_number, '三重県松阪市豊原町');
ok($zip->set_number('5150206')->is_valid_number, '三重県松阪市山下町');
ok($zip->set_number('5150207')->is_valid_number, '三重県松阪市安楽町');
ok($zip->set_number('5150208')->is_valid_number, '三重県松阪市山添町');
ok($zip->set_number('5150211')->is_valid_number, '三重県松阪市高木町');
ok($zip->set_number('5150212')->is_valid_number, '三重県松阪市稲木町');
ok($zip->set_number('5150213')->is_valid_number, '三重県松阪市伊勢場町');
ok($zip->set_number('5150214')->is_valid_number, '三重県松阪市法田町');
ok($zip->set_number('5150215')->is_valid_number, '三重県松阪市横地町');
ok($zip->set_number('5150216')->is_valid_number, '三重県松阪市目田町');
ok($zip->set_number('5150217')->is_valid_number, '三重県松阪市早馬瀬町');
ok($zip->set_number('5150300')->is_valid_number, '三重県多気郡明和町以下に掲載がない場合');
ok($zip->set_number('5150301')->is_valid_number, '三重県多気郡明和町大堀川新田');
ok($zip->set_number('5150302')->is_valid_number, '三重県多気郡明和町大淀');
ok($zip->set_number('5150303')->is_valid_number, '三重県多気郡明和町山大淀');
ok($zip->set_number('5150311')->is_valid_number, '三重県多気郡明和町平尾');
ok($zip->set_number('5150312')->is_valid_number, '三重県多気郡明和町上野');
ok($zip->set_number('5150313')->is_valid_number, '三重県多気郡明和町明星');
ok($zip->set_number('5150314')->is_valid_number, '三重県多気郡明和町新茶屋');
ok($zip->set_number('5150315')->is_valid_number, '三重県多気郡明和町蓑村');
ok($zip->set_number('5150316')->is_valid_number, '三重県多気郡明和町有爾中');
ok($zip->set_number('5150317')->is_valid_number, '三重県多気郡明和町池村');
ok($zip->set_number('5150321')->is_valid_number, '三重県多気郡明和町斎宮');
ok($zip->set_number('5150322')->is_valid_number, '三重県多気郡明和町上村');
ok($zip->set_number('5150323')->is_valid_number, '三重県多気郡明和町岩内');
ok($zip->set_number('5150324')->is_valid_number, '三重県多気郡明和町金剛坂');
ok($zip->set_number('5150325')->is_valid_number, '三重県多気郡明和町竹川');
ok($zip->set_number('5150331')->is_valid_number, '三重県多気郡明和町佐田');
ok($zip->set_number('5150332')->is_valid_number, '三重県多気郡明和町馬之上');
ok($zip->set_number('5150333')->is_valid_number, '三重県多気郡明和町坂本');
ok($zip->set_number('5150334')->is_valid_number, '三重県多気郡明和町中海');
ok($zip->set_number('5150341')->is_valid_number, '三重県多気郡明和町北藤原');
ok($zip->set_number('5150342')->is_valid_number, '三重県多気郡明和町南藤原');
ok($zip->set_number('5150343')->is_valid_number, '三重県多気郡明和町内座');
ok($zip->set_number('5150344')->is_valid_number, '三重県多気郡明和町養川');
ok($zip->set_number('5150345')->is_valid_number, '三重県多気郡明和町田屋');
ok($zip->set_number('5150346')->is_valid_number, '三重県多気郡明和町前野');
ok($zip->set_number('5150347')->is_valid_number, '三重県多気郡明和町志貴');
ok($zip->set_number('5150348')->is_valid_number, '三重県多気郡明和町中村');
ok($zip->set_number('5150349')->is_valid_number, '三重県多気郡明和町川尻');
ok($zip->set_number('5150351')->is_valid_number, '三重県多気郡明和町浜田');
ok($zip->set_number('5150352')->is_valid_number, '三重県多気郡明和町八木戸');
ok($zip->set_number('5150353')->is_valid_number, '三重県多気郡明和町根倉');
ok($zip->set_number('5150354')->is_valid_number, '三重県多気郡明和町行部');
ok($zip->set_number('5150501')->is_valid_number, '三重県伊勢市有滝町');
ok($zip->set_number('5150502')->is_valid_number, '三重県伊勢市東豊浜町');
ok($zip->set_number('5150503')->is_valid_number, '三重県伊勢市樫原町');
ok($zip->set_number('5150504')->is_valid_number, '三重県伊勢市磯町');
ok($zip->set_number('5150505')->is_valid_number, '三重県伊勢市西豊浜町');
ok($zip->set_number('5150506')->is_valid_number, '三重県伊勢市植山町');
ok($zip->set_number('5150507')->is_valid_number, '三重県伊勢市村松町');
ok($zip->set_number('5150508')->is_valid_number, '三重県伊勢市柏町');
ok($zip->set_number('5150509')->is_valid_number, '三重県伊勢市東大淀町');
ok($zip->set_number('5150511')->is_valid_number, '三重県伊勢市野村町');
ok($zip->set_number('5150521')->is_valid_number, '三重県伊勢市御薗町上條(三軒屋)');
ok($zip->set_number('5150801')->is_valid_number, '三重県松阪市新松ケ島町');
ok($zip->set_number('5150802')->is_valid_number, '三重県松阪市猟師町');
ok($zip->set_number('5150803')->is_valid_number, '三重県松阪市町平尾町');
ok($zip->set_number('5150804')->is_valid_number, '三重県松阪市大平尾町');
ok($zip->set_number('5150811')->is_valid_number, '三重県松阪市塚本町');
ok($zip->set_number('5150812')->is_valid_number, '三重県松阪市船江町');
ok($zip->set_number('5150813')->is_valid_number, '三重県松阪市大塚町');
ok($zip->set_number('5150814')->is_valid_number, '三重県松阪市久保田町');
ok($zip->set_number('5150815')->is_valid_number, '三重県松阪市西町');
ok($zip->set_number('5150816')->is_valid_number, '三重県松阪市西之庄町');
ok($zip->set_number('5150817')->is_valid_number, '三重県松阪市井村町');
ok($zip->set_number('5150818')->is_valid_number, '三重県松阪市川井町');
ok($zip->set_number('5150821')->is_valid_number, '三重県松阪市外五曲町');
ok($zip->set_number('5150822')->is_valid_number, '三重県松阪市大足町');
ok($zip->set_number('5150823')->is_valid_number, '三重県松阪市阿形町');
ok($zip->set_number('5150824')->is_valid_number, '三重県松阪市平成町');
ok($zip->set_number('5150825')->is_valid_number, '三重県松阪市藤之木町');
ok($zip->set_number('5150831')->is_valid_number, '三重県松阪市岡本町');
ok($zip->set_number('5150832')->is_valid_number, '三重県松阪市丹生寺町');
ok($zip->set_number('5150833')->is_valid_number, '三重県松阪市西野町');
ok($zip->set_number('5150834')->is_valid_number, '三重県松阪市岡山町');
ok($zip->set_number('5150835')->is_valid_number, '三重県松阪市日丘町');
ok($zip->set_number('5150841')->is_valid_number, '三重県松阪市曲町');
ok($zip->set_number('5150842')->is_valid_number, '三重県松阪市田牧町');
ok($zip->set_number('5150843')->is_valid_number, '三重県松阪市殿村町');
ok($zip->set_number('5150844')->is_valid_number, '三重県松阪市八重田町');
ok($zip->set_number('5150845')->is_valid_number, '三重県松阪市伊勢寺町');
ok($zip->set_number('5150846')->is_valid_number, '三重県松阪市深長町');
ok($zip->set_number('5150847')->is_valid_number, '三重県松阪市岩内町');
ok($zip->set_number('5150848')->is_valid_number, '三重県松阪市野村町');
ok($zip->set_number('5151101')->is_valid_number, '三重県松阪市勢津町');
ok($zip->set_number('5151102')->is_valid_number, '三重県松阪市矢津町');
ok($zip->set_number('5151103')->is_valid_number, '三重県松阪市笹川町');
ok($zip->set_number('5151104')->is_valid_number, '三重県松阪市桂瀬町');
ok($zip->set_number('5151105')->is_valid_number, '三重県松阪市大河内町');
ok($zip->set_number('5151106')->is_valid_number, '三重県松阪市辻原町');
ok($zip->set_number('5151107')->is_valid_number, '三重県松阪市阪内町');
ok($zip->set_number('5151201')->is_valid_number, '三重県松阪市広瀬町');
ok($zip->set_number('5151202')->is_valid_number, '三重県松阪市茅原町');
ok($zip->set_number('5151203')->is_valid_number, '三重県松阪市六呂木町');
ok($zip->set_number('5151204')->is_valid_number, '三重県松阪市小片野町');
ok($zip->set_number('5151205')->is_valid_number, '三重県松阪市大石町');
ok($zip->set_number('5151301')->is_valid_number, '三重県松阪市飯南町深野');
ok($zip->set_number('5151302')->is_valid_number, '三重県松阪市飯南町横野');
ok($zip->set_number('5151303')->is_valid_number, '三重県松阪市飯南町下仁柿');
ok($zip->set_number('5151304')->is_valid_number, '三重県松阪市飯南町上仁柿');
ok($zip->set_number('5151411')->is_valid_number, '三重県松阪市飯南町粥見');
ok($zip->set_number('5151412')->is_valid_number, '三重県松阪市飯南町向粥見');
ok($zip->set_number('5151413')->is_valid_number, '三重県松阪市飯南町有間野');
ok($zip->set_number('5151501')->is_valid_number, '三重県松阪市飯高町下滝野');
ok($zip->set_number('5151502')->is_valid_number, '三重県松阪市飯高町宮前');
ok($zip->set_number('5151503')->is_valid_number, '三重県松阪市飯高町野々口');
ok($zip->set_number('5151504')->is_valid_number, '三重県松阪市飯高町作滝');
ok($zip->set_number('5151505')->is_valid_number, '三重県松阪市飯高町赤桶');
ok($zip->set_number('5151506')->is_valid_number, '三重県松阪市飯高町田引');
ok($zip->set_number('5151611')->is_valid_number, '三重県松阪市飯高町七日市');
ok($zip->set_number('5151612')->is_valid_number, '三重県松阪市飯高町富永');
ok($zip->set_number('5151613')->is_valid_number, '三重県松阪市飯高町粟野');
ok($zip->set_number('5151614')->is_valid_number, '三重県松阪市飯高町宮本');
ok($zip->set_number('5151615')->is_valid_number, '三重県松阪市飯高町森');
ok($zip->set_number('5151616')->is_valid_number, '三重県松阪市飯高町青田');
ok($zip->set_number('5151617')->is_valid_number, '三重県松阪市飯高町猿山');
ok($zip->set_number('5151618')->is_valid_number, '三重県松阪市飯高町蓮');
ok($zip->set_number('5151721')->is_valid_number, '三重県松阪市飯高町月出');
ok($zip->set_number('5151722')->is_valid_number, '三重県松阪市飯高町加波');
ok($zip->set_number('5151723')->is_valid_number, '三重県松阪市飯高町乙栗子');
ok($zip->set_number('5151724')->is_valid_number, '三重県松阪市飯高町桑原');
ok($zip->set_number('5151725')->is_valid_number, '三重県松阪市飯高町波瀬');
ok($zip->set_number('5151726')->is_valid_number, '三重県松阪市飯高町太良木');
ok($zip->set_number('5151727')->is_valid_number, '三重県松阪市飯高町草鹿野');
ok($zip->set_number('5151731')->is_valid_number, '三重県松阪市飯高町舟戸');
ok($zip->set_number('5151732')->is_valid_number, '三重県松阪市飯高町落方');
ok($zip->set_number('5151733')->is_valid_number, '三重県松阪市飯高町栃谷');
ok($zip->set_number('5151734')->is_valid_number, '三重県松阪市飯高町木梶');
ok($zip->set_number('5152101')->is_valid_number, '三重県松阪市星合町');
ok($zip->set_number('5152102')->is_valid_number, '三重県松阪市五主町');
ok($zip->set_number('5152103')->is_valid_number, '三重県松阪市笠松町');
ok($zip->set_number('5152104')->is_valid_number, '三重県松阪市小舟江町');
ok($zip->set_number('5152105')->is_valid_number, '三重県松阪市肥留町');
ok($zip->set_number('5152106')->is_valid_number, '三重県松阪市西肥留町');
ok($zip->set_number('5152107')->is_valid_number, '三重県松阪市舞出町');
ok($zip->set_number('5152108')->is_valid_number, '三重県松阪市甚目町');
ok($zip->set_number('5152109')->is_valid_number, '三重県松阪市小野江町');
ok($zip->set_number('5152111')->is_valid_number, '三重県松阪市中林町');
ok($zip->set_number('5152112')->is_valid_number, '三重県松阪市曽原町');
ok($zip->set_number('5152113')->is_valid_number, '三重県松阪市喜多村新田町');
ok($zip->set_number('5152114')->is_valid_number, '三重県松阪市小津町');
ok($zip->set_number('5152115')->is_valid_number, '三重県松阪市中道町');
ok($zip->set_number('5152121')->is_valid_number, '三重県松阪市市場庄町');
ok($zip->set_number('5152122')->is_valid_number, '三重県松阪市久米町');
ok($zip->set_number('5152123')->is_valid_number, '三重県松阪市上ノ庄町');
ok($zip->set_number('5152124')->is_valid_number, '三重県松阪市中ノ庄町');
ok($zip->set_number('5152131')->is_valid_number, '三重県松阪市六軒町');
ok($zip->set_number('5152132')->is_valid_number, '三重県松阪市松崎浦町');
ok($zip->set_number('5152133')->is_valid_number, '三重県松阪市松ケ島町');
ok($zip->set_number('5152301')->is_valid_number, '三重県松阪市嬉野島田町');
ok($zip->set_number('5152302')->is_valid_number, '三重県松阪市嬉野天花寺町');
ok($zip->set_number('5152303')->is_valid_number, '三重県松阪市嬉野宮古町');
ok($zip->set_number('5152304')->is_valid_number, '三重県松阪市嬉野平生町');
ok($zip->set_number('5152305')->is_valid_number, '三重県松阪市嬉野一志町');
ok($zip->set_number('5152311')->is_valid_number, '三重県松阪市嬉野黒田町');
ok($zip->set_number('5152312')->is_valid_number, '三重県松阪市嬉野見永町');
ok($zip->set_number('5152313')->is_valid_number, '三重県松阪市嬉野川原木造町');
ok($zip->set_number('5152314')->is_valid_number, '三重県松阪市嬉野新屋庄町');
ok($zip->set_number('5152315')->is_valid_number, '三重県松阪市嬉野小村町');
ok($zip->set_number('5152316')->is_valid_number, '三重県松阪市嬉野川北町');
ok($zip->set_number('5152317')->is_valid_number, '三重県松阪市嬉野野田町');
ok($zip->set_number('5152321')->is_valid_number, '三重県松阪市嬉野中川町');
ok($zip->set_number('5152322')->is_valid_number, '三重県松阪市嬉野須賀町');
ok($zip->set_number('5152323')->is_valid_number, '三重県松阪市嬉野権現前町');
ok($zip->set_number('5152324')->is_valid_number, '三重県松阪市嬉野町');
ok($zip->set_number('5152325')->is_valid_number, '三重県松阪市嬉野中川新町');
ok($zip->set_number('5152331')->is_valid_number, '三重県松阪市嬉野須賀領町');
ok($zip->set_number('5152332')->is_valid_number, '三重県松阪市嬉野津屋城町');
ok($zip->set_number('5152333')->is_valid_number, '三重県松阪市嬉野田村町');
ok($zip->set_number('5152334')->is_valid_number, '三重県松阪市嬉野黒野町');
ok($zip->set_number('5152335')->is_valid_number, '三重県松阪市嬉野算所町');
ok($zip->set_number('5152341')->is_valid_number, '三重県松阪市小野町');
ok($zip->set_number('5152342')->is_valid_number, '三重県松阪市大阿坂町');
ok($zip->set_number('5152343')->is_valid_number, '三重県松阪市小阿坂町');
ok($zip->set_number('5152344')->is_valid_number, '三重県松阪市美濃田町');
ok($zip->set_number('5152351')->is_valid_number, '三重県松阪市嬉野井之上町');
ok($zip->set_number('5152352')->is_valid_number, '三重県松阪市嬉野八田町');
ok($zip->set_number('5152353')->is_valid_number, '三重県松阪市嬉野堀之内町');
ok($zip->set_number('5152354')->is_valid_number, '三重県松阪市嬉野下之庄町');
ok($zip->set_number('5152355')->is_valid_number, '三重県松阪市嬉野薬王寺町');
ok($zip->set_number('5152356')->is_valid_number, '三重県松阪市嬉野上野町');
ok($zip->set_number('5152357')->is_valid_number, '三重県松阪市嬉野神ノ木町');
ok($zip->set_number('5152401')->is_valid_number, '三重県松阪市嬉野釜生田町');
ok($zip->set_number('5152402')->is_valid_number, '三重県松阪市嬉野森本町');
ok($zip->set_number('5152403')->is_valid_number, '三重県松阪市嬉野岩倉町');
ok($zip->set_number('5152404')->is_valid_number, '三重県松阪市嬉野上小川町');
ok($zip->set_number('5152405')->is_valid_number, '三重県松阪市嬉野小原町');
ok($zip->set_number('5152406')->is_valid_number, '三重県松阪市嬉野合ケ野町');
ok($zip->set_number('5152407')->is_valid_number, '三重県松阪市嬉野矢下町');
ok($zip->set_number('5152408')->is_valid_number, '三重県松阪市嬉野宮野町');
ok($zip->set_number('5152409')->is_valid_number, '三重県松阪市嬉野滝之川町');
ok($zip->set_number('5152411')->is_valid_number, '三重県松阪市与原町');
ok($zip->set_number('5152412')->is_valid_number, '三重県松阪市飯福田町');
ok($zip->set_number('5152413')->is_valid_number, '三重県松阪市後山町');
ok($zip->set_number('5152414')->is_valid_number, '三重県松阪市柚原町');
ok($zip->set_number('5152501')->is_valid_number, '三重県津市一志町庄村');
ok($zip->set_number('5152502')->is_valid_number, '三重県津市一志町其村');
ok($zip->set_number('5152503')->is_valid_number, '三重県津市一志町日置');
ok($zip->set_number('5152504')->is_valid_number, '三重県津市一志町高野(高野団地)');
ok($zip->set_number('5152504')->is_valid_number, '三重県津市一志町高野(野田)');
ok($zip->set_number('5152504')->is_valid_number, '三重県津市一志町高野(その他)');
ok($zip->set_number('5152505')->is_valid_number, '三重県津市一志町小戸木');
ok($zip->set_number('5152511')->is_valid_number, '三重県津市一志町片野');
ok($zip->set_number('5152512')->is_valid_number, '三重県津市一志町新沢田');
ok($zip->set_number('5152513')->is_valid_number, '三重県津市一志町虹が丘');
ok($zip->set_number('5152514')->is_valid_number, '三重県津市一志町小山(小山台地)');
ok($zip->set_number('5152514')->is_valid_number, '三重県津市一志町小山(その他)');
ok($zip->set_number('5152515')->is_valid_number, '三重県津市一志町八太(一志団地)');
ok($zip->set_number('5152515')->is_valid_number, '三重県津市一志町八太(その他)');
ok($zip->set_number('5152516')->is_valid_number, '三重県津市一志町田尻');
ok($zip->set_number('5152517')->is_valid_number, '三重県津市一志町みのりケ丘');
ok($zip->set_number('5152521')->is_valid_number, '三重県津市一志町井関');
ok($zip->set_number('5152522')->is_valid_number, '三重県津市一志町波瀬');
ok($zip->set_number('5152523')->is_valid_number, '三重県津市一志町井生');
ok($zip->set_number('5152524')->is_valid_number, '三重県津市一志町大仰');
ok($zip->set_number('5152525')->is_valid_number, '三重県津市一志町石橋');
ok($zip->set_number('5152526')->is_valid_number, '三重県津市一志町其倉');
ok($zip->set_number('5152601')->is_valid_number, '三重県津市白山町三ケ野');
ok($zip->set_number('5152602')->is_valid_number, '三重県津市白山町二本木');
ok($zip->set_number('5152603')->is_valid_number, '三重県津市白山町川口');
ok($zip->set_number('5152604')->is_valid_number, '三重県津市白山町岡');
ok($zip->set_number('5152605')->is_valid_number, '三重県津市白山台');
ok($zip->set_number('5152611')->is_valid_number, '三重県津市白山町南出');
ok($zip->set_number('5152612')->is_valid_number, '三重県津市白山町古市');
ok($zip->set_number('5152613')->is_valid_number, '三重県津市白山町山田野');
ok($zip->set_number('5152614')->is_valid_number, '三重県津市白山町伊勢見');
ok($zip->set_number('5152615')->is_valid_number, '三重県津市白山町八対野');
ok($zip->set_number('5152616')->is_valid_number, '三重県津市白山町稲垣');
ok($zip->set_number('5152617')->is_valid_number, '三重県津市グリンタウン榊原');
ok($zip->set_number('5152621')->is_valid_number, '三重県津市白山町佐田');
ok($zip->set_number('5152622')->is_valid_number, '三重県津市白山町中ノ村');
ok($zip->set_number('5152623')->is_valid_number, '三重県津市白山町上ノ村');
ok($zip->set_number('5152624')->is_valid_number, '三重県津市白山町垣内');
ok($zip->set_number('5153131')->is_valid_number, '三重県津市白山町藤');
ok($zip->set_number('5153132')->is_valid_number, '三重県津市白山町北家城');
ok($zip->set_number('5153133')->is_valid_number, '三重県津市白山町南家城');
ok($zip->set_number('5153134')->is_valid_number, '三重県津市白山町真見');
ok($zip->set_number('5153135')->is_valid_number, '三重県津市白山町二俣');
ok($zip->set_number('5153136')->is_valid_number, '三重県津市白山町福田山');
ok($zip->set_number('5153137')->is_valid_number, '三重県津市白山町大原');
ok($zip->set_number('5153138')->is_valid_number, '三重県津市白山町小杉');
ok($zip->set_number('5153139')->is_valid_number, '三重県津市白山町城立');
ok($zip->set_number('5153201')->is_valid_number, '三重県津市美杉町竹原');
ok($zip->set_number('5153202')->is_valid_number, '三重県津市美杉町八手俣');
ok($zip->set_number('5153203')->is_valid_number, '三重県津市美杉町下之川');
ok($zip->set_number('5153311')->is_valid_number, '三重県津市美杉町下多気');
ok($zip->set_number('5153312')->is_valid_number, '三重県津市美杉町上多気');
ok($zip->set_number('5153313')->is_valid_number, '三重県津市美杉町丹生俣');
ok($zip->set_number('5153421')->is_valid_number, '三重県津市美杉町八知');
ok($zip->set_number('5153531')->is_valid_number, '三重県津市美杉町奥津');
ok($zip->set_number('5153532')->is_valid_number, '三重県津市美杉町川上');
ok($zip->set_number('5153533')->is_valid_number, '三重県津市美杉町石名原');
ok($zip->set_number('5153534')->is_valid_number, '三重県津市美杉町杉平');
ok($zip->set_number('5153535')->is_valid_number, '三重県津市美杉町三多気');
ok($zip->set_number('5153536')->is_valid_number, '三重県津市美杉町太郎生');
ok($zip->set_number('5160000')->is_valid_number, '三重県伊勢市以下に掲載がない場合');
ok($zip->set_number('5160001')->is_valid_number, '三重県伊勢市大湊町');
ok($zip->set_number('5160002')->is_valid_number, '三重県伊勢市馬瀬町');
ok($zip->set_number('5160003')->is_valid_number, '三重県伊勢市下野町');
ok($zip->set_number('5160004')->is_valid_number, '三重県伊勢市神社港');
ok($zip->set_number('5160005')->is_valid_number, '三重県伊勢市竹ケ鼻町');
ok($zip->set_number('5160006')->is_valid_number, '三重県伊勢市田尻町');
ok($zip->set_number('5160007')->is_valid_number, '三重県伊勢市小木町');
ok($zip->set_number('5160008')->is_valid_number, '三重県伊勢市船江');
ok($zip->set_number('5160009')->is_valid_number, '三重県伊勢市河崎');
ok($zip->set_number('5160011')->is_valid_number, '三重県伊勢市一色町');
ok($zip->set_number('5160012')->is_valid_number, '三重県伊勢市通町');
ok($zip->set_number('5160013')->is_valid_number, '三重県伊勢市鹿海町');
ok($zip->set_number('5160014')->is_valid_number, '三重県伊勢市楠部町');
ok($zip->set_number('5160015')->is_valid_number, '三重県伊勢市久世戸町');
ok($zip->set_number('5160016')->is_valid_number, '三重県伊勢市神田久志本町');
ok($zip->set_number('5160017')->is_valid_number, '三重県伊勢市神久');
ok($zip->set_number('5160018')->is_valid_number, '三重県伊勢市黒瀬町');
ok($zip->set_number('5160021')->is_valid_number, '三重県伊勢市朝熊町(その他)');
ok($zip->set_number('5160022')->is_valid_number, '三重県伊勢市一宇田町');
ok($zip->set_number('5160023')->is_valid_number, '三重県伊勢市宇治館町');
ok($zip->set_number('5160024')->is_valid_number, '三重県伊勢市宇治今在家町');
ok($zip->set_number('5160025')->is_valid_number, '三重県伊勢市宇治中之切町');
ok($zip->set_number('5160026')->is_valid_number, '三重県伊勢市宇治浦田');
ok($zip->set_number('5160027')->is_valid_number, '三重県伊勢市桜木町');
ok($zip->set_number('5160028')->is_valid_number, '三重県伊勢市中村町');
ok($zip->set_number('5160031')->is_valid_number, '三重県伊勢市尾上町');
ok($zip->set_number('5160032')->is_valid_number, '三重県伊勢市倭町');
ok($zip->set_number('5160033')->is_valid_number, '三重県伊勢市古市町');
ok($zip->set_number('5160034')->is_valid_number, '三重県伊勢市中之町');
ok($zip->set_number('5160035')->is_valid_number, '三重県伊勢市勢田町');
ok($zip->set_number('5160036')->is_valid_number, '三重県伊勢市岡本');
ok($zip->set_number('5160037')->is_valid_number, '三重県伊勢市岩渕');
ok($zip->set_number('5160038')->is_valid_number, '三重県伊勢市岩渕町');
ok($zip->set_number('5160041')->is_valid_number, '三重県伊勢市常磐');
ok($zip->set_number('5160042')->is_valid_number, '三重県伊勢市豊川町');
ok($zip->set_number('5160043')->is_valid_number, '三重県伊勢市藤里町');
ok($zip->set_number('5160044')->is_valid_number, '三重県伊勢市前山町');
ok($zip->set_number('5160045')->is_valid_number, '三重県伊勢市旭町');
ok($zip->set_number('5160046')->is_valid_number, '三重県伊勢市辻久留町');
ok($zip->set_number('5160047')->is_valid_number, '三重県伊勢市常磐町');
ok($zip->set_number('5160051')->is_valid_number, '三重県伊勢市上地町');
ok($zip->set_number('5160052')->is_valid_number, '三重県伊勢市川端町');
ok($zip->set_number('5160053')->is_valid_number, '三重県伊勢市中須町');
ok($zip->set_number('5160054')->is_valid_number, '三重県伊勢市粟野町');
ok($zip->set_number('5160061')->is_valid_number, '三重県伊勢市宮川');
ok($zip->set_number('5160062')->is_valid_number, '三重県伊勢市浦口');
ok($zip->set_number('5160063')->is_valid_number, '三重県伊勢市浦口町');
ok($zip->set_number('5160064')->is_valid_number, '三重県伊勢市二俣');
ok($zip->set_number('5160065')->is_valid_number, '三重県伊勢市二俣町');
ok($zip->set_number('5160066')->is_valid_number, '三重県伊勢市辻久留');
ok($zip->set_number('5160067')->is_valid_number, '三重県伊勢市中島');
ok($zip->set_number('5160071')->is_valid_number, '三重県伊勢市一之木');
ok($zip->set_number('5160072')->is_valid_number, '三重県伊勢市宮後');
ok($zip->set_number('5160073')->is_valid_number, '三重県伊勢市吹上');
ok($zip->set_number('5160074')->is_valid_number, '三重県伊勢市本町');
ok($zip->set_number('5160075')->is_valid_number, '三重県伊勢市一志町');
ok($zip->set_number('5160076')->is_valid_number, '三重県伊勢市八日市場町');
ok($zip->set_number('5160077')->is_valid_number, '三重県伊勢市宮町');
ok($zip->set_number('5160078')->is_valid_number, '三重県伊勢市曽祢');
ok($zip->set_number('5160079')->is_valid_number, '三重県伊勢市大世古');
ok($zip->set_number('5160100')->is_valid_number, '三重県度会郡南伊勢町以下に掲載がない場合');
ok($zip->set_number('5160101')->is_valid_number, '三重県度会郡南伊勢町五ケ所浦');
ok($zip->set_number('5160102')->is_valid_number, '三重県度会郡南伊勢町切原');
ok($zip->set_number('5160103')->is_valid_number, '三重県度会郡南伊勢町泉');
ok($zip->set_number('5160104')->is_valid_number, '三重県度会郡南伊勢町神津佐');
ok($zip->set_number('5160105')->is_valid_number, '三重県度会郡南伊勢町下津浦');
ok($zip->set_number('5160106')->is_valid_number, '三重県度会郡南伊勢町木谷');
ok($zip->set_number('5160107')->is_valid_number, '三重県度会郡南伊勢町飯満');
ok($zip->set_number('5160108')->is_valid_number, '三重県度会郡南伊勢町中津浜浦');
ok($zip->set_number('5160109')->is_valid_number, '三重県度会郡南伊勢町船越');
ok($zip->set_number('5160111')->is_valid_number, '三重県度会郡南伊勢町内瀬');
ok($zip->set_number('5160112')->is_valid_number, '三重県度会郡南伊勢町伊勢路');
ok($zip->set_number('5160113')->is_valid_number, '三重県度会郡南伊勢町斎田');
ok($zip->set_number('5160114')->is_valid_number, '三重県度会郡南伊勢町始神');
ok($zip->set_number('5160115')->is_valid_number, '三重県度会郡南伊勢町押渕');
ok($zip->set_number('5160116')->is_valid_number, '三重県度会郡南伊勢町迫間浦');
ok($zip->set_number('5160117')->is_valid_number, '三重県度会郡南伊勢町礫浦');
ok($zip->set_number('5160118')->is_valid_number, '三重県度会郡南伊勢町相賀浦');
ok($zip->set_number('5160221')->is_valid_number, '三重県度会郡南伊勢町宿浦');
ok($zip->set_number('5160222')->is_valid_number, '三重県度会郡南伊勢町田曽浦');
ok($zip->set_number('5160801')->is_valid_number, '三重県伊勢市御薗町小林');
ok($zip->set_number('5160802')->is_valid_number, '三重県伊勢市御薗町新開');
ok($zip->set_number('5160803')->is_valid_number, '三重県伊勢市御薗町王中島');
ok($zip->set_number('5160804')->is_valid_number, '三重県伊勢市御薗町長屋');
ok($zip->set_number('5160805')->is_valid_number, '三重県伊勢市御薗町高向');
ok($zip->set_number('5160806')->is_valid_number, '三重県伊勢市御薗町上條(その他)');
ok($zip->set_number('5161101')->is_valid_number, '三重県伊勢市大倉町');
ok($zip->set_number('5161102')->is_valid_number, '三重県伊勢市佐八町');
ok($zip->set_number('5161103')->is_valid_number, '三重県伊勢市津村町');
ok($zip->set_number('5161104')->is_valid_number, '三重県伊勢市上野町');
ok($zip->set_number('5161105')->is_valid_number, '三重県伊勢市矢持町');
ok($zip->set_number('5161106')->is_valid_number, '三重県伊勢市横輪町');
ok($zip->set_number('5161107')->is_valid_number, '三重県伊勢市神薗町');
ok($zip->set_number('5161108')->is_valid_number, '三重県伊勢市円座町');
ok($zip->set_number('5161231')->is_valid_number, '三重県度会郡度会町川口');
ok($zip->set_number('5161232')->is_valid_number, '三重県度会郡度会町栗原');
ok($zip->set_number('5161233')->is_valid_number, '三重県度会郡度会町日向');
ok($zip->set_number('5161234')->is_valid_number, '三重県度会郡度会町火打石');
ok($zip->set_number('5161235')->is_valid_number, '三重県度会郡度会町駒ケ野');
ok($zip->set_number('5161236')->is_valid_number, '三重県度会郡度会町小川');
ok($zip->set_number('5161237')->is_valid_number, '三重県度会郡度会町五ケ町');
ok($zip->set_number('5161238')->is_valid_number, '三重県度会郡度会町中之郷');
ok($zip->set_number('5161241')->is_valid_number, '三重県度会郡度会町柳');
ok($zip->set_number('5161242')->is_valid_number, '三重県度会郡度会町市場');
ok($zip->set_number('5161243')->is_valid_number, '三重県度会郡度会町和井野');
ok($zip->set_number('5161244')->is_valid_number, '三重県度会郡度会町南中村');
ok($zip->set_number('5161245')->is_valid_number, '三重県度会郡度会町川上');
ok($zip->set_number('5161246')->is_valid_number, '三重県度会郡度会町脇出');
ok($zip->set_number('5161247')->is_valid_number, '三重県度会郡度会町小萩');
ok($zip->set_number('5161301')->is_valid_number, '三重県度会郡南伊勢町道方');
ok($zip->set_number('5161302')->is_valid_number, '三重県度会郡南伊勢町大江');
ok($zip->set_number('5161303')->is_valid_number, '三重県度会郡南伊勢町道行竈');
ok($zip->set_number('5161304')->is_valid_number, '三重県度会郡南伊勢町大方竈');
ok($zip->set_number('5161305')->is_valid_number, '三重県度会郡南伊勢町阿曽浦');
ok($zip->set_number('5161306')->is_valid_number, '三重県度会郡南伊勢町慥柄浦');
ok($zip->set_number('5161307')->is_valid_number, '三重県度会郡南伊勢町贄浦');
ok($zip->set_number('5161308')->is_valid_number, '三重県度会郡南伊勢町奈屋浦');
ok($zip->set_number('5161309')->is_valid_number, '三重県度会郡南伊勢町東宮');
ok($zip->set_number('5161421')->is_valid_number, '三重県度会郡南伊勢町河内');
ok($zip->set_number('5161422')->is_valid_number, '三重県度会郡南伊勢町神前浦');
ok($zip->set_number('5161423')->is_valid_number, '三重県度会郡南伊勢町村山');
ok($zip->set_number('5161531')->is_valid_number, '三重県度会郡南伊勢町方座浦');
ok($zip->set_number('5161532')->is_valid_number, '三重県度会郡南伊勢町小方竈');
ok($zip->set_number('5161533')->is_valid_number, '三重県度会郡南伊勢町栃木竈');
ok($zip->set_number('5161534')->is_valid_number, '三重県度会郡南伊勢町古和浦');
ok($zip->set_number('5161535')->is_valid_number, '三重県度会郡南伊勢町棚橋竈');
ok($zip->set_number('5161536')->is_valid_number, '三重県度会郡南伊勢町新桑竈');
ok($zip->set_number('5162100')->is_valid_number, '三重県度会郡度会町以下に掲載がない場合');
ok($zip->set_number('5162101')->is_valid_number, '三重県度会郡度会町葛原');
ok($zip->set_number('5162102')->is_valid_number, '三重県度会郡度会町大野木');
ok($zip->set_number('5162103')->is_valid_number, '三重県度会郡度会町棚橋');
ok($zip->set_number('5162104')->is_valid_number, '三重県度会郡度会町牧戸');
ok($zip->set_number('5162105')->is_valid_number, '三重県度会郡度会町平生');
ok($zip->set_number('5162106')->is_valid_number, '三重県度会郡度会町大久保');
ok($zip->set_number('5162107')->is_valid_number, '三重県度会郡度会町立岡');
ok($zip->set_number('5162108')->is_valid_number, '三重県度会郡度会町鮠川');
ok($zip->set_number('5162111')->is_valid_number, '三重県度会郡度会町下久具');
ok($zip->set_number('5162112')->is_valid_number, '三重県度会郡度会町上久具');
ok($zip->set_number('5162113')->is_valid_number, '三重県度会郡度会町田間');
ok($zip->set_number('5162114')->is_valid_number, '三重県度会郡度会町当津');
ok($zip->set_number('5162115')->is_valid_number, '三重県度会郡度会町長原');
ok($zip->set_number('5162116')->is_valid_number, '三重県度会郡度会町坂井');
ok($zip->set_number('5162117')->is_valid_number, '三重県度会郡度会町麻加江');
ok($zip->set_number('5162118')->is_valid_number, '三重県度会郡度会町田口');
ok($zip->set_number('5162119')->is_valid_number, '三重県度会郡度会町注連指');
ok($zip->set_number('5170000')->is_valid_number, '三重県鳥羽市以下に掲載がない場合');
ok($zip->set_number('5170001')->is_valid_number, '三重県鳥羽市神島町');
ok($zip->set_number('5170002')->is_valid_number, '三重県鳥羽市答志町');
ok($zip->set_number('5170003')->is_valid_number, '三重県鳥羽市桃取町');
ok($zip->set_number('5170004')->is_valid_number, '三重県鳥羽市菅島町');
ok($zip->set_number('5170005')->is_valid_number, '三重県鳥羽市坂手町');
ok($zip->set_number('5170011')->is_valid_number, '三重県鳥羽市鳥羽');
ok($zip->set_number('5170012')->is_valid_number, '三重県鳥羽市池上町');
ok($zip->set_number('5170013')->is_valid_number, '三重県鳥羽市屋内町');
ok($zip->set_number('5170014')->is_valid_number, '三重県鳥羽市堅神町');
ok($zip->set_number('5170015')->is_valid_number, '三重県鳥羽市小浜町');
ok($zip->set_number('5170021')->is_valid_number, '三重県鳥羽市安楽島町');
ok($zip->set_number('5170022')->is_valid_number, '三重県鳥羽市大明東町');
ok($zip->set_number('5170023')->is_valid_number, '三重県鳥羽市大明西町');
ok($zip->set_number('5170024')->is_valid_number, '三重県鳥羽市高丘町');
ok($zip->set_number('5170025')->is_valid_number, '三重県鳥羽市浦村町');
ok($zip->set_number('5170026')->is_valid_number, '三重県鳥羽市石鏡町');
ok($zip->set_number('5170031')->is_valid_number, '三重県鳥羽市国崎町');
ok($zip->set_number('5170032')->is_valid_number, '三重県鳥羽市相差町');
ok($zip->set_number('5170033')->is_valid_number, '三重県鳥羽市畔蛸町');
ok($zip->set_number('5170034')->is_valid_number, '三重県鳥羽市千賀町');
ok($zip->set_number('5170035')->is_valid_number, '三重県鳥羽市堅子町');
ok($zip->set_number('5170041')->is_valid_number, '三重県鳥羽市岩倉町');
ok($zip->set_number('5170042')->is_valid_number, '三重県鳥羽市松尾町');
ok($zip->set_number('5170043')->is_valid_number, '三重県鳥羽市白木町');
ok($zip->set_number('5170044')->is_valid_number, '三重県鳥羽市河内町');
ok($zip->set_number('5170045')->is_valid_number, '三重県鳥羽市船津町');
ok($zip->set_number('5170046')->is_valid_number, '三重県鳥羽市幸丘');
ok($zip->set_number('5170047')->is_valid_number, '三重県鳥羽市若杉町');
ok($zip->set_number('5170081')->is_valid_number, '三重県伊勢市朝熊町(池の浦、箕曲瀬)');
ok($zip->set_number('5170201')->is_valid_number, '三重県志摩市磯部町五知');
ok($zip->set_number('5170202')->is_valid_number, '三重県志摩市磯部町沓掛');
ok($zip->set_number('5170203')->is_valid_number, '三重県志摩市磯部町山田');
ok($zip->set_number('5170204')->is_valid_number, '三重県志摩市磯部町的矢');
ok($zip->set_number('5170205')->is_valid_number, '三重県志摩市磯部町渡鹿野');
ok($zip->set_number('5170206')->is_valid_number, '三重県志摩市磯部町飯浜');
ok($zip->set_number('5170207')->is_valid_number, '三重県志摩市磯部町下之郷');
ok($zip->set_number('5170208')->is_valid_number, '三重県志摩市磯部町上之郷');
ok($zip->set_number('5170209')->is_valid_number, '三重県志摩市磯部町恵利原');
ok($zip->set_number('5170211')->is_valid_number, '三重県志摩市磯部町三ケ所');
ok($zip->set_number('5170212')->is_valid_number, '三重県志摩市磯部町坂崎');
ok($zip->set_number('5170213')->is_valid_number, '三重県志摩市磯部町穴川');
ok($zip->set_number('5170214')->is_valid_number, '三重県志摩市磯部町迫間');
ok($zip->set_number('5170215')->is_valid_number, '三重県志摩市磯部町檜山');
ok($zip->set_number('5170216')->is_valid_number, '三重県志摩市磯部町栗木広');
ok($zip->set_number('5170217')->is_valid_number, '三重県志摩市磯部町山原');
ok($zip->set_number('5170218')->is_valid_number, '三重県志摩市磯部町築地');
ok($zip->set_number('5170401')->is_valid_number, '三重県志摩市浜島町桧山路');
ok($zip->set_number('5170402')->is_valid_number, '三重県志摩市浜島町塩屋');
ok($zip->set_number('5170403')->is_valid_number, '三重県志摩市浜島町迫子');
ok($zip->set_number('5170404')->is_valid_number, '三重県志摩市浜島町浜島');
ok($zip->set_number('5170405')->is_valid_number, '三重県志摩市浜島町南張');
ok($zip->set_number('5170500')->is_valid_number, '三重県志摩市以下に掲載がない場合');
ok($zip->set_number('5170501')->is_valid_number, '三重県志摩市阿児町鵜方');
ok($zip->set_number('5170502')->is_valid_number, '三重県志摩市阿児町神明');
ok($zip->set_number('5170503')->is_valid_number, '三重県志摩市阿児町立神');
ok($zip->set_number('5170504')->is_valid_number, '三重県志摩市阿児町志島');
ok($zip->set_number('5170505')->is_valid_number, '三重県志摩市阿児町甲賀');
ok($zip->set_number('5170506')->is_valid_number, '三重県志摩市阿児町国府');
ok($zip->set_number('5170507')->is_valid_number, '三重県志摩市阿児町安乗');
ok($zip->set_number('5170601')->is_valid_number, '三重県志摩市大王町畔名');
ok($zip->set_number('5170602')->is_valid_number, '三重県志摩市大王町名田');
ok($zip->set_number('5170603')->is_valid_number, '三重県志摩市大王町波切');
ok($zip->set_number('5170604')->is_valid_number, '三重県志摩市大王町船越');
ok($zip->set_number('5170701')->is_valid_number, '三重県志摩市志摩町片田');
ok($zip->set_number('5170702')->is_valid_number, '三重県志摩市志摩町布施田');
ok($zip->set_number('5170703')->is_valid_number, '三重県志摩市志摩町和具');
ok($zip->set_number('5170704')->is_valid_number, '三重県志摩市志摩町越賀');
ok($zip->set_number('5170705')->is_valid_number, '三重県志摩市志摩町御座');
ok($zip->set_number('5180000')->is_valid_number, '三重県伊賀市以下に掲載がない場合');
ok($zip->set_number('5180001')->is_valid_number, '三重県伊賀市佐那具町');
ok($zip->set_number('5180002')->is_valid_number, '三重県伊賀市千歳');
ok($zip->set_number('5180003')->is_valid_number, '三重県伊賀市一之宮');
ok($zip->set_number('5180004')->is_valid_number, '三重県伊賀市寺田');
ok($zip->set_number('5180005')->is_valid_number, '三重県伊賀市高畑');
ok($zip->set_number('5180006')->is_valid_number, '三重県伊賀市羽根');
ok($zip->set_number('5180007')->is_valid_number, '三重県伊賀市服部町');
ok($zip->set_number('5180008')->is_valid_number, '三重県伊賀市印代');
ok($zip->set_number('5180011')->is_valid_number, '三重県伊賀市外山');
ok($zip->set_number('5180012')->is_valid_number, '三重県伊賀市坂之下');
ok($zip->set_number('5180013')->is_valid_number, '三重県伊賀市東条');
ok($zip->set_number('5180014')->is_valid_number, '三重県伊賀市西条');
ok($zip->set_number('5180015')->is_valid_number, '三重県伊賀市土橋');
ok($zip->set_number('5180016')->is_valid_number, '三重県伊賀市山神');
ok($zip->set_number('5180017')->is_valid_number, '三重県伊賀市大谷');
ok($zip->set_number('5180021')->is_valid_number, '三重県伊賀市諏訪');
ok($zip->set_number('5180022')->is_valid_number, '三重県伊賀市三田');
ok($zip->set_number('5180023')->is_valid_number, '三重県伊賀市野間');
ok($zip->set_number('5180024')->is_valid_number, '三重県伊賀市東高倉');
ok($zip->set_number('5180025')->is_valid_number, '三重県伊賀市西高倉');
ok($zip->set_number('5180026')->is_valid_number, '三重県伊賀市岩倉');
ok($zip->set_number('5180027')->is_valid_number, '三重県伊賀市西山');
ok($zip->set_number('5180031')->is_valid_number, '三重県伊賀市長田');
ok($zip->set_number('5180032')->is_valid_number, '三重県伊賀市朝屋');
ok($zip->set_number('5180033')->is_valid_number, '三重県伊賀市大野木');
ok($zip->set_number('5180034')->is_valid_number, '三重県伊賀市大内');
ok($zip->set_number('5180035')->is_valid_number, '三重県伊賀市七本木');
ok($zip->set_number('5180036')->is_valid_number, '三重県伊賀市法花');
ok($zip->set_number('5180101')->is_valid_number, '三重県伊賀市依那具');
ok($zip->set_number('5180102')->is_valid_number, '三重県伊賀市市部');
ok($zip->set_number('5180103')->is_valid_number, '三重県伊賀市沖');
ok($zip->set_number('5180104')->is_valid_number, '三重県伊賀市摺見');
ok($zip->set_number('5180105')->is_valid_number, '三重県伊賀市比自岐');
ok($zip->set_number('5180106')->is_valid_number, '三重県伊賀市岡波');
ok($zip->set_number('5180107')->is_valid_number, '三重県伊賀市枅川');
ok($zip->set_number('5180108')->is_valid_number, '三重県伊賀市才良');
ok($zip->set_number('5180111')->is_valid_number, '三重県伊賀市下神戸');
ok($zip->set_number('5180112')->is_valid_number, '三重県伊賀市上林');
ok($zip->set_number('5180113')->is_valid_number, '三重県伊賀市古郡');
ok($zip->set_number('5180114')->is_valid_number, '三重県伊賀市朝日ケ丘町');
ok($zip->set_number('5180115')->is_valid_number, '三重県伊賀市比土');
ok($zip->set_number('5180116')->is_valid_number, '三重県伊賀市上神戸');
ok($zip->set_number('5180121')->is_valid_number, '三重県伊賀市上之庄');
ok($zip->set_number('5180122')->is_valid_number, '三重県伊賀市笠部');
ok($zip->set_number('5180123')->is_valid_number, '三重県伊賀市猪田');
ok($zip->set_number('5180124')->is_valid_number, '三重県伊賀市下郡');
ok($zip->set_number('5180125')->is_valid_number, '三重県伊賀市上郡');
ok($zip->set_number('5180126')->is_valid_number, '三重県伊賀市森寺');
ok($zip->set_number('5180127')->is_valid_number, '三重県伊賀市山出');
ok($zip->set_number('5180131')->is_valid_number, '三重県伊賀市ゆめが丘');
ok($zip->set_number('5180201')->is_valid_number, '三重県伊賀市瀧');
ok($zip->set_number('5180202')->is_valid_number, '三重県伊賀市妙楽地');
ok($zip->set_number('5180203')->is_valid_number, '三重県伊賀市勝地');
ok($zip->set_number('5180204')->is_valid_number, '三重県伊賀市北山');
ok($zip->set_number('5180205')->is_valid_number, '三重県伊賀市伊勢路');
ok($zip->set_number('5180206')->is_valid_number, '三重県伊賀市下川原');
ok($zip->set_number('5180211')->is_valid_number, '三重県伊賀市奥鹿野');
ok($zip->set_number('5180212')->is_valid_number, '三重県伊賀市福川');
ok($zip->set_number('5180213')->is_valid_number, '三重県伊賀市諸木');
ok($zip->set_number('5180214')->is_valid_number, '三重県伊賀市腰山');
ok($zip->set_number('5180215')->is_valid_number, '三重県伊賀市霧生');
ok($zip->set_number('5180216')->is_valid_number, '三重県伊賀市高尾');
ok($zip->set_number('5180217')->is_valid_number, '三重県伊賀市種生');
ok($zip->set_number('5180218')->is_valid_number, '三重県伊賀市川上');
ok($zip->set_number('5180219')->is_valid_number, '三重県伊賀市老川');
ok($zip->set_number('5180221')->is_valid_number, '三重県伊賀市別府');
ok($zip->set_number('5180222')->is_valid_number, '三重県伊賀市寺脇');
ok($zip->set_number('5180223')->is_valid_number, '三重県伊賀市岡田');
ok($zip->set_number('5180224')->is_valid_number, '三重県伊賀市柏尾');
ok($zip->set_number('5180225')->is_valid_number, '三重県伊賀市桐ケ丘');
ok($zip->set_number('5180226')->is_valid_number, '三重県伊賀市阿保');
ok($zip->set_number('5180227')->is_valid_number, '三重県伊賀市青山羽根');
ok($zip->set_number('5180400')->is_valid_number, '三重県名張市以下に掲載がない場合');
ok($zip->set_number('5180401')->is_valid_number, '三重県名張市すずらん台東1番町');
ok($zip->set_number('5180402')->is_valid_number, '三重県名張市すずらん台東2番町');
ok($zip->set_number('5180403')->is_valid_number, '三重県名張市すずらん台東3番町');
ok($zip->set_number('5180404')->is_valid_number, '三重県名張市すずらん台東4番町');
ok($zip->set_number('5180405')->is_valid_number, '三重県名張市すずらん台東5番町');
ok($zip->set_number('5180406')->is_valid_number, '三重県名張市すずらん台西1番町');
ok($zip->set_number('5180407')->is_valid_number, '三重県名張市すずらん台西2番町');
ok($zip->set_number('5180408')->is_valid_number, '三重県名張市すずらん台西3番町');
ok($zip->set_number('5180409')->is_valid_number, '三重県名張市すずらん台西4番町');
ok($zip->set_number('5180411')->is_valid_number, '三重県名張市滝之原');
ok($zip->set_number('5180412')->is_valid_number, '三重県名張市上比奈知');
ok($zip->set_number('5180413')->is_valid_number, '三重県名張市下比奈知');
ok($zip->set_number('5180414')->is_valid_number, '三重県名張市富貴ケ丘1番町');
ok($zip->set_number('5180415')->is_valid_number, '三重県名張市富貴ケ丘2番町');
ok($zip->set_number('5180416')->is_valid_number, '三重県名張市富貴ケ丘3番町');
ok($zip->set_number('5180417')->is_valid_number, '三重県名張市富貴ケ丘4番町');
ok($zip->set_number('5180418')->is_valid_number, '三重県名張市富貴ケ丘5番町');
ok($zip->set_number('5180419')->is_valid_number, '三重県名張市富貴ケ丘6番町');
ok($zip->set_number('5180421')->is_valid_number, '三重県名張市つつじが丘南1番町');
ok($zip->set_number('5180422')->is_valid_number, '三重県名張市つつじが丘南2番町');
ok($zip->set_number('5180423')->is_valid_number, '三重県名張市つつじが丘南3番町');
ok($zip->set_number('5180424')->is_valid_number, '三重県名張市つつじが丘南4番町');
ok($zip->set_number('5180425')->is_valid_number, '三重県名張市つつじが丘南5番町');
ok($zip->set_number('5180426')->is_valid_number, '三重県名張市つつじが丘南6番町');
ok($zip->set_number('5180427')->is_valid_number, '三重県名張市つつじが丘南7番町');
ok($zip->set_number('5180428')->is_valid_number, '三重県名張市つつじが丘南8番町');
ok($zip->set_number('5180430')->is_valid_number, '三重県名張市つつじが丘北10番町');
ok($zip->set_number('5180431')->is_valid_number, '三重県名張市つつじが丘北1番町');
ok($zip->set_number('5180432')->is_valid_number, '三重県名張市つつじが丘北2番町');
ok($zip->set_number('5180433')->is_valid_number, '三重県名張市つつじが丘北3番町');
ok($zip->set_number('5180434')->is_valid_number, '三重県名張市つつじが丘北4番町');
ok($zip->set_number('5180435')->is_valid_number, '三重県名張市つつじが丘北5番町');
ok($zip->set_number('5180436')->is_valid_number, '三重県名張市つつじが丘北6番町');
ok($zip->set_number('5180437')->is_valid_number, '三重県名張市つつじが丘北7番町');
ok($zip->set_number('5180438')->is_valid_number, '三重県名張市つつじが丘北8番町');
ok($zip->set_number('5180439')->is_valid_number, '三重県名張市つつじが丘北9番町');
ok($zip->set_number('5180441')->is_valid_number, '三重県名張市夏見');
ok($zip->set_number('5180442')->is_valid_number, '三重県名張市中知山');
ok($zip->set_number('5180443')->is_valid_number, '三重県名張市青蓮寺');
ok($zip->set_number('5180444')->is_valid_number, '三重県名張市箕曲中村');
ok($zip->set_number('5180445')->is_valid_number, '三重県名張市瀬古口');
ok($zip->set_number('5180446')->is_valid_number, '三重県名張市南百合が丘');
ok($zip->set_number('5180453')->is_valid_number, '三重県名張市春日丘1番町');
ok($zip->set_number('5180454')->is_valid_number, '三重県名張市春日丘2番町');
ok($zip->set_number('5180455')->is_valid_number, '三重県名張市春日丘3番町');
ok($zip->set_number('5180456')->is_valid_number, '三重県名張市春日丘4番町');
ok($zip->set_number('5180457')->is_valid_number, '三重県名張市春日丘5番町');
ok($zip->set_number('5180458')->is_valid_number, '三重県名張市春日丘6番町');
ok($zip->set_number('5180459')->is_valid_number, '三重県名張市春日丘7番町');
ok($zip->set_number('5180461')->is_valid_number, '三重県名張市赤目町すみれが丘');
ok($zip->set_number('5180462')->is_valid_number, '三重県名張市赤目町星川');
ok($zip->set_number('5180463')->is_valid_number, '三重県名張市赤目町檀');
ok($zip->set_number('5180464')->is_valid_number, '三重県名張市赤目町柏原');
ok($zip->set_number('5180465')->is_valid_number, '三重県名張市赤目町丈六');
ok($zip->set_number('5180466')->is_valid_number, '三重県名張市赤目町新川');
ok($zip->set_number('5180467')->is_valid_number, '三重県名張市赤目町相楽');
ok($zip->set_number('5180468')->is_valid_number, '三重県名張市赤目町一ノ井');
ok($zip->set_number('5180469')->is_valid_number, '三重県名張市赤目町長坂');
ok($zip->set_number('5180471')->is_valid_number, '三重県名張市百合が丘東1番町');
ok($zip->set_number('5180472')->is_valid_number, '三重県名張市百合が丘東2番町');
ok($zip->set_number('5180473')->is_valid_number, '三重県名張市百合が丘東3番町');
ok($zip->set_number('5180474')->is_valid_number, '三重県名張市百合が丘東4番町');
ok($zip->set_number('5180475')->is_valid_number, '三重県名張市百合が丘東5番町');
ok($zip->set_number('5180476')->is_valid_number, '三重県名張市百合が丘東6番町');
ok($zip->set_number('5180477')->is_valid_number, '三重県名張市百合が丘東7番町');
ok($zip->set_number('5180478')->is_valid_number, '三重県名張市百合が丘東8番町');
ok($zip->set_number('5180479')->is_valid_number, '三重県名張市百合が丘東9番町');
ok($zip->set_number('5180481')->is_valid_number, '三重県名張市百合が丘西1番町');
ok($zip->set_number('5180482')->is_valid_number, '三重県名張市百合が丘西2番町');
ok($zip->set_number('5180483')->is_valid_number, '三重県名張市百合が丘西3番町');
ok($zip->set_number('5180484')->is_valid_number, '三重県名張市百合が丘西4番町');
ok($zip->set_number('5180485')->is_valid_number, '三重県名張市百合が丘西5番町');
ok($zip->set_number('5180486')->is_valid_number, '三重県名張市百合が丘西6番町');
ok($zip->set_number('5180501')->is_valid_number, '三重県名張市長瀬');
ok($zip->set_number('5180502')->is_valid_number, '三重県名張市上長瀬');
ok($zip->set_number('5180503')->is_valid_number, '三重県名張市布生');
ok($zip->set_number('5180504')->is_valid_number, '三重県名張市神屋');
ok($zip->set_number('5180505')->is_valid_number, '三重県名張市奈垣');
ok($zip->set_number('5180601')->is_valid_number, '三重県名張市南古山');
ok($zip->set_number('5180602')->is_valid_number, '三重県名張市東田原');
ok($zip->set_number('5180603')->is_valid_number, '三重県名張市西原町');
ok($zip->set_number('5180604')->is_valid_number, '三重県名張市さつき台');
ok($zip->set_number('5180605')->is_valid_number, '三重県名張市八幡');
ok($zip->set_number('5180606')->is_valid_number, '三重県名張市薦生');
ok($zip->set_number('5180607')->is_valid_number, '三重県名張市家野');
ok($zip->set_number('5180607')->is_valid_number, '三重県名張市葛尾');
ok($zip->set_number('5180608')->is_valid_number, '三重県名張市鵜山');
ok($zip->set_number('5180609')->is_valid_number, '三重県名張市西田原');
ok($zip->set_number('5180610')->is_valid_number, '三重県名張市美旗町藤が丘');
ok($zip->set_number('5180611')->is_valid_number, '三重県名張市新田');
ok($zip->set_number('5180612')->is_valid_number, '三重県名張市下小波田');
ok($zip->set_number('5180613')->is_valid_number, '三重県名張市上小波田');
ok($zip->set_number('5180614')->is_valid_number, '三重県名張市美旗町池の台東');
ok($zip->set_number('5180614')->is_valid_number, '三重県名張市美旗町池の台西');
ok($zip->set_number('5180615')->is_valid_number, '三重県名張市美旗中村');
ok($zip->set_number('5180616')->is_valid_number, '三重県名張市美旗町南西原');
ok($zip->set_number('5180617')->is_valid_number, '三重県名張市美旗町中1番');
ok($zip->set_number('5180618')->is_valid_number, '三重県名張市美旗町中2番');
ok($zip->set_number('5180619')->is_valid_number, '三重県名張市美旗町中3番');
ok($zip->set_number('5180621')->is_valid_number, '三重県名張市桔梗が丘1番町');
ok($zip->set_number('5180622')->is_valid_number, '三重県名張市桔梗が丘2番町');
ok($zip->set_number('5180623')->is_valid_number, '三重県名張市桔梗が丘3番町');
ok($zip->set_number('5180624')->is_valid_number, '三重県名張市桔梗が丘4番町');
ok($zip->set_number('5180625')->is_valid_number, '三重県名張市桔梗が丘5番町');
ok($zip->set_number('5180626')->is_valid_number, '三重県名張市桔梗が丘6番町');
ok($zip->set_number('5180627')->is_valid_number, '三重県名張市桔梗が丘7番町');
ok($zip->set_number('5180628')->is_valid_number, '三重県名張市桔梗が丘8番町');
ok($zip->set_number('5180631')->is_valid_number, '三重県名張市桔梗が丘南1番町');
ok($zip->set_number('5180632')->is_valid_number, '三重県名張市桔梗が丘南2番町');
ok($zip->set_number('5180633')->is_valid_number, '三重県名張市桔梗が丘南3番町');
ok($zip->set_number('5180634')->is_valid_number, '三重県名張市桔梗が丘南4番町');
ok($zip->set_number('5180641')->is_valid_number, '三重県名張市桔梗が丘西1番町');
ok($zip->set_number('5180642')->is_valid_number, '三重県名張市桔梗が丘西2番町');
ok($zip->set_number('5180643')->is_valid_number, '三重県名張市桔梗が丘西3番町');
ok($zip->set_number('5180644')->is_valid_number, '三重県名張市桔梗が丘西4番町');
ok($zip->set_number('5180645')->is_valid_number, '三重県名張市桔梗が丘西5番町');
ok($zip->set_number('5180646')->is_valid_number, '三重県名張市桔梗が丘西6番町');
ok($zip->set_number('5180647')->is_valid_number, '三重県名張市桔梗が丘西7番町');
ok($zip->set_number('5180701')->is_valid_number, '三重県名張市鴻之台1番町');
ok($zip->set_number('5180702')->is_valid_number, '三重県名張市鴻之台2番町');
ok($zip->set_number('5180703')->is_valid_number, '三重県名張市鴻之台3番町');
ok($zip->set_number('5180704')->is_valid_number, '三重県名張市鴻之台4番町');
ok($zip->set_number('5180705')->is_valid_number, '三重県名張市鴻之台5番町');
ok($zip->set_number('5180710')->is_valid_number, '三重県名張市上八町');
ok($zip->set_number('5180711')->is_valid_number, '三重県名張市東町');
ok($zip->set_number('5180712')->is_valid_number, '三重県名張市桜ケ丘');
ok($zip->set_number('5180713')->is_valid_number, '三重県名張市平尾');
ok($zip->set_number('5180714')->is_valid_number, '三重県名張市鍛冶町');
ok($zip->set_number('5180715')->is_valid_number, '三重県名張市柳原町');
ok($zip->set_number('5180716')->is_valid_number, '三重県名張市上本町');
ok($zip->set_number('5180717')->is_valid_number, '三重県名張市中町');
ok($zip->set_number('5180718')->is_valid_number, '三重県名張市丸之内');
ok($zip->set_number('5180719')->is_valid_number, '三重県名張市栄町');
ok($zip->set_number('5180721')->is_valid_number, '三重県名張市朝日町');
ok($zip->set_number('5180722')->is_valid_number, '三重県名張市松崎町');
ok($zip->set_number('5180723')->is_valid_number, '三重県名張市木屋町');
ok($zip->set_number('5180724')->is_valid_number, '三重県名張市榊町');
ok($zip->set_number('5180725')->is_valid_number, '三重県名張市元町');
ok($zip->set_number('5180726')->is_valid_number, '三重県名張市本町');
ok($zip->set_number('5180727')->is_valid_number, '三重県名張市新町');
ok($zip->set_number('5180728')->is_valid_number, '三重県名張市豊後町');
ok($zip->set_number('5180729')->is_valid_number, '三重県名張市南町');
ok($zip->set_number('5180731')->is_valid_number, '三重県名張市夏秋');
ok($zip->set_number('5180732')->is_valid_number, '三重県名張市松原町');
ok($zip->set_number('5180733')->is_valid_number, '三重県名張市大屋戸');
ok($zip->set_number('5180734')->is_valid_number, '三重県名張市黒田');
ok($zip->set_number('5180735')->is_valid_number, '三重県名張市結馬');
ok($zip->set_number('5180736')->is_valid_number, '三重県名張市井手');
ok($zip->set_number('5180737')->is_valid_number, '三重県名張市安部田');
ok($zip->set_number('5180738')->is_valid_number, '三重県名張市短野');
ok($zip->set_number('5180739')->is_valid_number, '三重県名張市下三谷');
ok($zip->set_number('5180740')->is_valid_number, '三重県名張市梅が丘北5番町');
ok($zip->set_number('5180741')->is_valid_number, '三重県名張市梅が丘南1番町');
ok($zip->set_number('5180742')->is_valid_number, '三重県名張市梅が丘南2番町');
ok($zip->set_number('5180743')->is_valid_number, '三重県名張市梅が丘南3番町');
ok($zip->set_number('5180744')->is_valid_number, '三重県名張市梅が丘南4番町');
ok($zip->set_number('5180745')->is_valid_number, '三重県名張市梅が丘南5番町');
ok($zip->set_number('5180746')->is_valid_number, '三重県名張市梅が丘北1番町');
ok($zip->set_number('5180747')->is_valid_number, '三重県名張市梅が丘北2番町');
ok($zip->set_number('5180748')->is_valid_number, '三重県名張市梅が丘北3番町');
ok($zip->set_number('5180749')->is_valid_number, '三重県名張市梅が丘北4番町');
ok($zip->set_number('5180751')->is_valid_number, '三重県名張市蔵持町芝出');
ok($zip->set_number('5180752')->is_valid_number, '三重県名張市蔵持町原出');
ok($zip->set_number('5180753')->is_valid_number, '三重県名張市蔵持町里');
ok($zip->set_number('5180754')->is_valid_number, '三重県名張市緑が丘西');
ok($zip->set_number('5180755')->is_valid_number, '三重県名張市緑が丘中');
ok($zip->set_number('5180756')->is_valid_number, '三重県名張市緑が丘東');
ok($zip->set_number('5180761')->is_valid_number, '三重県名張市竜口');
ok($zip->set_number('5180762')->is_valid_number, '三重県名張市上三谷');
ok($zip->set_number('5180763')->is_valid_number, '三重県名張市矢川');
ok($zip->set_number('5180771')->is_valid_number, '三重県名張市希央台1番町');
ok($zip->set_number('5180772')->is_valid_number, '三重県名張市希央台2番町');
ok($zip->set_number('5180773')->is_valid_number, '三重県名張市希央台3番町');
ok($zip->set_number('5180774')->is_valid_number, '三重県名張市希央台4番町');
ok($zip->set_number('5180775')->is_valid_number, '三重県名張市希央台5番町');
ok($zip->set_number('5180801')->is_valid_number, '三重県伊賀市平野見能');
ok($zip->set_number('5180802')->is_valid_number, '三重県伊賀市平野樋之口');
ok($zip->set_number('5180804')->is_valid_number, '三重県伊賀市平野六反田');
ok($zip->set_number('5180807')->is_valid_number, '三重県伊賀市平野上川原');
ok($zip->set_number('5180808')->is_valid_number, '三重県伊賀市平野蔵垣内');
ok($zip->set_number('5180809')->is_valid_number, '三重県伊賀市西明寺');
ok($zip->set_number('5180810')->is_valid_number, '三重県伊賀市平野東町');
ok($zip->set_number('5180811')->is_valid_number, '三重県伊賀市喰代');
ok($zip->set_number('5180812')->is_valid_number, '三重県伊賀市高山');
ok($zip->set_number('5180813')->is_valid_number, '三重県伊賀市蓮池');
ok($zip->set_number('5180814')->is_valid_number, '三重県伊賀市上友生');
ok($zip->set_number('5180815')->is_valid_number, '三重県伊賀市界外');
ok($zip->set_number('5180816')->is_valid_number, '三重県伊賀市中友生');
ok($zip->set_number('5180817')->is_valid_number, '三重県伊賀市下友生');
ok($zip->set_number('5180818')->is_valid_number, '三重県伊賀市荒木');
ok($zip->set_number('5180820')->is_valid_number, '三重県伊賀市平野西町');
ok($zip->set_number('5180821')->is_valid_number, '三重県伊賀市生琉里');
ok($zip->set_number('5180822')->is_valid_number, '三重県伊賀市問屋町');
ok($zip->set_number('5180823')->is_valid_number, '三重県伊賀市四十九町');
ok($zip->set_number('5180824')->is_valid_number, '三重県伊賀市守田町');
ok($zip->set_number('5180825')->is_valid_number, '三重県伊賀市小田町');
ok($zip->set_number('5180826')->is_valid_number, '三重県伊賀市平野北谷');
ok($zip->set_number('5180827')->is_valid_number, '三重県伊賀市平野清水');
ok($zip->set_number('5180828')->is_valid_number, '三重県伊賀市平野中川原');
ok($zip->set_number('5180829')->is_valid_number, '三重県伊賀市平野山之下');
ok($zip->set_number('5180830')->is_valid_number, '三重県伊賀市平野城北町');
ok($zip->set_number('5180831')->is_valid_number, '三重県伊賀市上野農人町');
ok($zip->set_number('5180832')->is_valid_number, '三重県伊賀市上野車坂町');
ok($zip->set_number('5180833')->is_valid_number, '三重県伊賀市緑ケ丘東町');
ok($zip->set_number('5180834')->is_valid_number, '三重県伊賀市緑ケ丘中町');
ok($zip->set_number('5180835')->is_valid_number, '三重県伊賀市緑ケ丘南町');
ok($zip->set_number('5180836')->is_valid_number, '三重県伊賀市緑ケ丘本町');
ok($zip->set_number('5180837')->is_valid_number, '三重県伊賀市緑ケ丘西町');
ok($zip->set_number('5180838')->is_valid_number, '三重県伊賀市上野茅町');
ok($zip->set_number('5180839')->is_valid_number, '三重県伊賀市上野田端町');
ok($zip->set_number('5180840')->is_valid_number, '三重県伊賀市陽光台');
ok($zip->set_number('5180841')->is_valid_number, '三重県伊賀市上野恵美須町');
ok($zip->set_number('5180842')->is_valid_number, '三重県伊賀市上野桑町');
ok($zip->set_number('5180843')->is_valid_number, '三重県伊賀市久米町');
ok($zip->set_number('5180844')->is_valid_number, '三重県伊賀市八幡町');
ok($zip->set_number('5180845')->is_valid_number, '三重県伊賀市木興町');
ok($zip->set_number('5180846')->is_valid_number, '三重県伊賀市上野愛宕町');
ok($zip->set_number('5180847')->is_valid_number, '三重県伊賀市上野鉄砲町');
ok($zip->set_number('5180848')->is_valid_number, '三重県伊賀市上野西日南町');
ok($zip->set_number('5180849')->is_valid_number, '三重県伊賀市上野東日南町');
ok($zip->set_number('5180851')->is_valid_number, '三重県伊賀市上野寺町');
ok($zip->set_number('5180852')->is_valid_number, '三重県伊賀市上野伊予町');
ok($zip->set_number('5180853')->is_valid_number, '三重県伊賀市上野池町');
ok($zip->set_number('5180854')->is_valid_number, '三重県伊賀市上野忍町');
ok($zip->set_number('5180855')->is_valid_number, '三重県伊賀市上野万町');
ok($zip->set_number('5180856')->is_valid_number, '三重県伊賀市上野徳居町');
ok($zip->set_number('5180857')->is_valid_number, '三重県伊賀市上野三之西町');
ok($zip->set_number('5180858')->is_valid_number, '三重県伊賀市上野紺屋町');
ok($zip->set_number('5180859')->is_valid_number, '三重県伊賀市上野相生町');
ok($zip->set_number('5180861')->is_valid_number, '三重県伊賀市上野東町');
ok($zip->set_number('5180862')->is_valid_number, '三重県伊賀市上野片原町');
ok($zip->set_number('5180863')->is_valid_number, '三重県伊賀市上野新町');
ok($zip->set_number('5180864')->is_valid_number, '三重県伊賀市上野鍛冶町');
ok($zip->set_number('5180865')->is_valid_number, '三重県伊賀市上野魚町');
ok($zip->set_number('5180866')->is_valid_number, '三重県伊賀市上野小玉町');
ok($zip->set_number('5180867')->is_valid_number, '三重県伊賀市上野福居町');
ok($zip->set_number('5180868')->is_valid_number, '三重県伊賀市上野西町');
ok($zip->set_number('5180869')->is_valid_number, '三重県伊賀市上野中町');
ok($zip->set_number('5180871')->is_valid_number, '三重県伊賀市上野赤坂町');
ok($zip->set_number('5180872')->is_valid_number, '三重県伊賀市上野玄蕃町');
ok($zip->set_number('5180873')->is_valid_number, '三重県伊賀市上野丸之内');
ok($zip->set_number('5180874')->is_valid_number, '三重県伊賀市上野幸坂町');
ok($zip->set_number('5180875')->is_valid_number, '三重県伊賀市上野向島町');
ok($zip->set_number('5180877')->is_valid_number, '三重県伊賀市上野下幸坂町');
ok($zip->set_number('5180878')->is_valid_number, '三重県伊賀市上野西大手町');
ok($zip->set_number('5181141')->is_valid_number, '三重県伊賀市菖蒲池');
ok($zip->set_number('5181142')->is_valid_number, '三重県伊賀市古山界外');
ok($zip->set_number('5181143')->is_valid_number, '三重県伊賀市鍛冶屋');
ok($zip->set_number('5181144')->is_valid_number, '三重県伊賀市東谷');
ok($zip->set_number('5181145')->is_valid_number, '三重県伊賀市安場');
ok($zip->set_number('5181146')->is_valid_number, '三重県伊賀市湯屋谷');
ok($zip->set_number('5181147')->is_valid_number, '三重県伊賀市蔵縄手');
ok($zip->set_number('5181151')->is_valid_number, '三重県伊賀市白樫');
ok($zip->set_number('5181152')->is_valid_number, '三重県伊賀市予野');
ok($zip->set_number('5181153')->is_valid_number, '三重県伊賀市桂');
ok($zip->set_number('5181154')->is_valid_number, '三重県伊賀市大滝');
ok($zip->set_number('5181155')->is_valid_number, '三重県伊賀市治田');
ok($zip->set_number('5181301')->is_valid_number, '三重県伊賀市西湯舟');
ok($zip->set_number('5181302')->is_valid_number, '三重県伊賀市東湯舟');
ok($zip->set_number('5181303')->is_valid_number, '三重県伊賀市上友田');
ok($zip->set_number('5181304')->is_valid_number, '三重県伊賀市中友田');
ok($zip->set_number('5181305')->is_valid_number, '三重県伊賀市下友田');
ok($zip->set_number('5181306')->is_valid_number, '三重県伊賀市湯舟');
ok($zip->set_number('5181307')->is_valid_number, '三重県伊賀市川合(東山タウン)');
ok($zip->set_number('5181311')->is_valid_number, '三重県伊賀市馬田');
ok($zip->set_number('5181312')->is_valid_number, '三重県伊賀市田中');
ok($zip->set_number('5181313')->is_valid_number, '三重県伊賀市馬場');
ok($zip->set_number('5181314')->is_valid_number, '三重県伊賀市円徳院');
ok($zip->set_number('5181315')->is_valid_number, '三重県伊賀市川合');
ok($zip->set_number('5181316')->is_valid_number, '三重県伊賀市阿山ハイツ');
ok($zip->set_number('5181317')->is_valid_number, '三重県伊賀市大江');
ok($zip->set_number('5181318')->is_valid_number, '三重県伊賀市波敷野');
ok($zip->set_number('5181319')->is_valid_number, '三重県伊賀市千貝');
ok($zip->set_number('5181321')->is_valid_number, '三重県伊賀市内保');
ok($zip->set_number('5181322')->is_valid_number, '三重県伊賀市玉滝');
ok($zip->set_number('5181323')->is_valid_number, '三重県伊賀市石川');
ok($zip->set_number('5181324')->is_valid_number, '三重県伊賀市音羽');
ok($zip->set_number('5181325')->is_valid_number, '三重県伊賀市丸柱');
ok($zip->set_number('5181326')->is_valid_number, '三重県伊賀市槙山');
ok($zip->set_number('5181401')->is_valid_number, '三重県伊賀市千戸');
ok($zip->set_number('5181403')->is_valid_number, '三重県伊賀市炊村');
ok($zip->set_number('5181404')->is_valid_number, '三重県伊賀市甲野');
ok($zip->set_number('5181405')->is_valid_number, '三重県伊賀市鳳凰寺');
ok($zip->set_number('5181406')->is_valid_number, '三重県伊賀市中村');
ok($zip->set_number('5181407')->is_valid_number, '三重県伊賀市出後');
ok($zip->set_number('5181408')->is_valid_number, '三重県伊賀市畑村');
ok($zip->set_number('5181412')->is_valid_number, '三重県伊賀市上阿波');
ok($zip->set_number('5181414')->is_valid_number, '三重県伊賀市猿野');
ok($zip->set_number('5181416')->is_valid_number, '三重県伊賀市下阿波');
ok($zip->set_number('5181417')->is_valid_number, '三重県伊賀市富永');
ok($zip->set_number('5181421')->is_valid_number, '三重県伊賀市真泥');
ok($zip->set_number('5181422')->is_valid_number, '三重県伊賀市平田');
ok($zip->set_number('5181424')->is_valid_number, '三重県伊賀市富岡');
ok($zip->set_number('5181425')->is_valid_number, '三重県伊賀市川北');
ok($zip->set_number('5181426')->is_valid_number, '三重県伊賀市広瀬');
ok($zip->set_number('5181427')->is_valid_number, '三重県伊賀市奥馬野');
ok($zip->set_number('5181428')->is_valid_number, '三重県伊賀市中馬野');
ok($zip->set_number('5181429')->is_valid_number, '三重県伊賀市坂下');
ok($zip->set_number('5190100')->is_valid_number, '三重県亀山市以下に掲載がない場合');
ok($zip->set_number('5190101')->is_valid_number, '三重県亀山市井田川町');
ok($zip->set_number('5190102')->is_valid_number, '三重県亀山市和田町');
ok($zip->set_number('5190103')->is_valid_number, '三重県亀山市川合町');
ok($zip->set_number('5190104')->is_valid_number, '三重県亀山市椿世町');
ok($zip->set_number('5190105')->is_valid_number, '三重県亀山市みずほ台');
ok($zip->set_number('5190106')->is_valid_number, '三重県亀山市みどり町');
ok($zip->set_number('5190111')->is_valid_number, '三重県亀山市栄町');
ok($zip->set_number('5190112')->is_valid_number, '三重県亀山市上野町');
ok($zip->set_number('5190113')->is_valid_number, '三重県亀山市小下町');
ok($zip->set_number('5190114')->is_valid_number, '三重県亀山市南鹿島町');
ok($zip->set_number('5190115')->is_valid_number, '三重県亀山市北鹿島町');
ok($zip->set_number('5190116')->is_valid_number, '三重県亀山市本町');
ok($zip->set_number('5190117')->is_valid_number, '三重県亀山市北山町');
ok($zip->set_number('5190118')->is_valid_number, '三重県亀山市北町');
ok($zip->set_number('5190119')->is_valid_number, '三重県亀山市高塚町');
ok($zip->set_number('5190121')->is_valid_number, '三重県亀山市江ケ室');
ok($zip->set_number('5190122')->is_valid_number, '三重県亀山市東台町');
ok($zip->set_number('5190123')->is_valid_number, '三重県亀山市渋倉町');
ok($zip->set_number('5190124')->is_valid_number, '三重県亀山市東御幸町');
ok($zip->set_number('5190125')->is_valid_number, '三重県亀山市東町');
ok($zip->set_number('5190126')->is_valid_number, '三重県亀山市東丸町');
ok($zip->set_number('5190127')->is_valid_number, '三重県亀山市中屋敷町');
ok($zip->set_number('5190131')->is_valid_number, '三重県亀山市井尻町');
ok($zip->set_number('5190132')->is_valid_number, '三重県亀山市菅内町');
ok($zip->set_number('5190133')->is_valid_number, '三重県亀山市下庄町');
ok($zip->set_number('5190134')->is_valid_number, '三重県亀山市中庄町');
ok($zip->set_number('5190135')->is_valid_number, '三重県亀山市三寺町');
ok($zip->set_number('5190136')->is_valid_number, '三重県亀山市田茂町');
ok($zip->set_number('5190137')->is_valid_number, '三重県亀山市阿野田町');
ok($zip->set_number('5190141')->is_valid_number, '三重県亀山市海本町');
ok($zip->set_number('5190142')->is_valid_number, '三重県亀山市天神');
ok($zip->set_number('5190143')->is_valid_number, '三重県亀山市安知本町');
ok($zip->set_number('5190144')->is_valid_number, '三重県亀山市楠平尾町');
ok($zip->set_number('5190145')->is_valid_number, '三重県亀山市和賀町');
ok($zip->set_number('5190146')->is_valid_number, '三重県亀山市野村町');
ok($zip->set_number('5190147')->is_valid_number, '三重県亀山市山下町');
ok($zip->set_number('5190148')->is_valid_number, '三重県亀山市木下町');
ok($zip->set_number('5190151')->is_valid_number, '三重県亀山市若山町');
ok($zip->set_number('5190152')->is_valid_number, '三重県亀山市本丸町');
ok($zip->set_number('5190153')->is_valid_number, '三重県亀山市西町');
ok($zip->set_number('5190154')->is_valid_number, '三重県亀山市南崎町');
ok($zip->set_number('5190155')->is_valid_number, '三重県亀山市御幸町');
ok($zip->set_number('5190156')->is_valid_number, '三重県亀山市南野町');
ok($zip->set_number('5190157')->is_valid_number, '三重県亀山市北野町');
ok($zip->set_number('5190158')->is_valid_number, '三重県亀山市市ケ坂町');
ok($zip->set_number('5190159')->is_valid_number, '三重県亀山市西丸町');
ok($zip->set_number('5190161')->is_valid_number, '三重県亀山市小川町');
ok($zip->set_number('5190162')->is_valid_number, '三重県亀山市住山町');
ok($zip->set_number('5190163')->is_valid_number, '三重県亀山市亀田町');
ok($zip->set_number('5190164')->is_valid_number, '三重県亀山市羽若町');
ok($zip->set_number('5190165')->is_valid_number, '三重県亀山市野村');
ok($zip->set_number('5190166')->is_valid_number, '三重県亀山市布気町');
ok($zip->set_number('5190167')->is_valid_number, '三重県亀山市小野町');
ok($zip->set_number('5190168')->is_valid_number, '三重県亀山市太岡寺町');
ok($zip->set_number('5190169')->is_valid_number, '三重県亀山市白木町');
ok($zip->set_number('5190171')->is_valid_number, '三重県亀山市アイリス町');
ok($zip->set_number('5190181')->is_valid_number, '三重県亀山市みずきが丘');
ok($zip->set_number('5190211')->is_valid_number, '三重県亀山市川崎町');
ok($zip->set_number('5190212')->is_valid_number, '三重県亀山市能褒野町');
ok($zip->set_number('5190213')->is_valid_number, '三重県亀山市田村町');
ok($zip->set_number('5190214')->is_valid_number, '三重県亀山市長明寺町');
ok($zip->set_number('5190215')->is_valid_number, '三重県亀山市太森町');
ok($zip->set_number('5190221')->is_valid_number, '三重県亀山市辺法寺町');
ok($zip->set_number('5190222')->is_valid_number, '三重県亀山市両尾町');
ok($zip->set_number('5190223')->is_valid_number, '三重県亀山市安坂山町');
ok($zip->set_number('5190271')->is_valid_number, '三重県鈴鹿市西庄内町');
ok($zip->set_number('5190272')->is_valid_number, '三重県鈴鹿市東庄内町');
ok($zip->set_number('5190311')->is_valid_number, '三重県鈴鹿市大久保町');
ok($zip->set_number('5190312')->is_valid_number, '三重県鈴鹿市椿一宮町');
ok($zip->set_number('5190313')->is_valid_number, '三重県鈴鹿市追分町');
ok($zip->set_number('5190314')->is_valid_number, '三重県鈴鹿市長澤町');
ok($zip->set_number('5190315')->is_valid_number, '三重県鈴鹿市山本町');
ok($zip->set_number('5190316')->is_valid_number, '三重県鈴鹿市小岐須町');
ok($zip->set_number('5190321')->is_valid_number, '三重県鈴鹿市深溝町');
ok($zip->set_number('5190322')->is_valid_number, '三重県鈴鹿市三畑町');
ok($zip->set_number('5190323')->is_valid_number, '三重県鈴鹿市伊船町');
ok($zip->set_number('5190324')->is_valid_number, '三重県鈴鹿市小社町');
ok($zip->set_number('5190400')->is_valid_number, '三重県度会郡玉城町以下に掲載がない場合');
ok($zip->set_number('5190401')->is_valid_number, '三重県度会郡玉城町世古');
ok($zip->set_number('5190402')->is_valid_number, '三重県度会郡玉城町門前');
ok($zip->set_number('5190403')->is_valid_number, '三重県度会郡玉城町井倉');
ok($zip->set_number('5190404')->is_valid_number, '三重県度会郡玉城町長更');
ok($zip->set_number('5190405')->is_valid_number, '三重県度会郡玉城町日向');
ok($zip->set_number('5190406')->is_valid_number, '三重県度会郡玉城町岡村');
ok($zip->set_number('5190407')->is_valid_number, '三重県度会郡玉城町玉川');
ok($zip->set_number('5190408')->is_valid_number, '三重県度会郡玉城町坂本');
ok($zip->set_number('5190411')->is_valid_number, '三重県度会郡玉城町久保');
ok($zip->set_number('5190412')->is_valid_number, '三重県度会郡玉城町中楽');
ok($zip->set_number('5190413')->is_valid_number, '三重県度会郡玉城町妙法寺');
ok($zip->set_number('5190414')->is_valid_number, '三重県度会郡玉城町佐田');
ok($zip->set_number('5190415')->is_valid_number, '三重県度会郡玉城町田丸');
ok($zip->set_number('5190416')->is_valid_number, '三重県度会郡玉城町下田辺');
ok($zip->set_number('5190417')->is_valid_number, '三重県度会郡玉城町上田辺');
ok($zip->set_number('5190421')->is_valid_number, '三重県度会郡玉城町冨岡');
ok($zip->set_number('5190422')->is_valid_number, '三重県度会郡玉城町小社曽根');
ok($zip->set_number('5190423')->is_valid_number, '三重県度会郡玉城町昼田');
ok($zip->set_number('5190424')->is_valid_number, '三重県度会郡玉城町山岡');
ok($zip->set_number('5190425')->is_valid_number, '三重県度会郡玉城町岩出');
ok($zip->set_number('5190426')->is_valid_number, '三重県度会郡玉城町中角');
ok($zip->set_number('5190427')->is_valid_number, '三重県度会郡玉城町宮古');
ok($zip->set_number('5190428')->is_valid_number, '三重県度会郡玉城町岡出');
ok($zip->set_number('5190431')->is_valid_number, '三重県度会郡玉城町蚊野');
ok($zip->set_number('5190432')->is_valid_number, '三重県度会郡玉城町野篠');
ok($zip->set_number('5190433')->is_valid_number, '三重県度会郡玉城町勝田');
ok($zip->set_number('5190434')->is_valid_number, '三重県度会郡玉城町田宮寺');
ok($zip->set_number('5190435')->is_valid_number, '三重県度会郡玉城町矢野');
ok($zip->set_number('5190436')->is_valid_number, '三重県度会郡玉城町山神');
ok($zip->set_number('5190437')->is_valid_number, '三重県度会郡玉城町積良');
ok($zip->set_number('5190438')->is_valid_number, '三重県度会郡玉城町原');
ok($zip->set_number('5190501')->is_valid_number, '三重県伊勢市小俣町明野');
ok($zip->set_number('5190502')->is_valid_number, '三重県伊勢市小俣町相合');
ok($zip->set_number('5190503')->is_valid_number, '三重県伊勢市小俣町元町');
ok($zip->set_number('5190504')->is_valid_number, '三重県伊勢市小俣町宮前');
ok($zip->set_number('5190505')->is_valid_number, '三重県伊勢市小俣町本町');
ok($zip->set_number('5190506')->is_valid_number, '三重県伊勢市小俣町湯田');
ok($zip->set_number('5190507')->is_valid_number, '三重県伊勢市小俣町新村');
ok($zip->set_number('5190601')->is_valid_number, '三重県伊勢市二見町松下');
ok($zip->set_number('5190602')->is_valid_number, '三重県伊勢市二見町江');
ok($zip->set_number('5190603')->is_valid_number, '三重県伊勢市二見町三津');
ok($zip->set_number('5190604')->is_valid_number, '三重県伊勢市二見町山田原');
ok($zip->set_number('5190605')->is_valid_number, '三重県伊勢市二見町溝口');
ok($zip->set_number('5190606')->is_valid_number, '三重県伊勢市二見町荘');
ok($zip->set_number('5190607')->is_valid_number, '三重県伊勢市二見町西');
ok($zip->set_number('5190608')->is_valid_number, '三重県伊勢市二見町今一色');
ok($zip->set_number('5190609')->is_valid_number, '三重県伊勢市二見町茶屋');
ok($zip->set_number('5190611')->is_valid_number, '三重県伊勢市二見町光の街');
ok($zip->set_number('5191101')->is_valid_number, '三重県亀山市関町坂下');
ok($zip->set_number('5191102')->is_valid_number, '三重県亀山市関町沓掛');
ok($zip->set_number('5191103')->is_valid_number, '三重県亀山市関町市瀬');
ok($zip->set_number('5191104')->is_valid_number, '三重県亀山市関町白木一色');
ok($zip->set_number('5191105')->is_valid_number, '三重県亀山市関町鷲山');
ok($zip->set_number('5191106')->is_valid_number, '三重県亀山市関町会下');
ok($zip->set_number('5191107')->is_valid_number, '三重県亀山市関町木崎');
ok($zip->set_number('5191108')->is_valid_number, '三重県亀山市関町小野');
ok($zip->set_number('5191111')->is_valid_number, '三重県亀山市関町新所');
ok($zip->set_number('5191112')->is_valid_number, '三重県亀山市関町中町');
ok($zip->set_number('5191113')->is_valid_number, '三重県亀山市関町古厩');
ok($zip->set_number('5191114')->is_valid_number, '三重県亀山市関町萩原');
ok($zip->set_number('5191115')->is_valid_number, '三重県亀山市関町福徳');
ok($zip->set_number('5191116')->is_valid_number, '三重県亀山市関町久我');
ok($zip->set_number('5191117')->is_valid_number, '三重県亀山市関町泉ケ丘');
ok($zip->set_number('5191118')->is_valid_number, '三重県亀山市関町富士ハイツ');
ok($zip->set_number('5191119')->is_valid_number, '三重県亀山市関ケ丘');
ok($zip->set_number('5191121')->is_valid_number, '三重県亀山市加太梶ケ坂');
ok($zip->set_number('5191122')->is_valid_number, '三重県亀山市加太市場');
ok($zip->set_number('5191123')->is_valid_number, '三重県亀山市関町金場');
ok($zip->set_number('5191124')->is_valid_number, '三重県亀山市関町越川');
ok($zip->set_number('5191125')->is_valid_number, '三重県亀山市加太向井');
ok($zip->set_number('5191126')->is_valid_number, '三重県亀山市加太神武');
ok($zip->set_number('5191127')->is_valid_number, '三重県亀山市加太中在家');
ok($zip->set_number('5191128')->is_valid_number, '三重県亀山市加太北在家');
ok($zip->set_number('5191129')->is_valid_number, '三重県亀山市加太板屋');
ok($zip->set_number('5191401')->is_valid_number, '三重県伊賀市一ツ家');
ok($zip->set_number('5191402')->is_valid_number, '三重県伊賀市柘植町');
ok($zip->set_number('5191403')->is_valid_number, '三重県伊賀市上村');
ok($zip->set_number('5191404')->is_valid_number, '三重県伊賀市中柘植');
ok($zip->set_number('5191405')->is_valid_number, '三重県伊賀市野村');
ok($zip->set_number('5191406')->is_valid_number, '三重県伊賀市小杉');
ok($zip->set_number('5191411')->is_valid_number, '三重県伊賀市楯岡');
ok($zip->set_number('5191412')->is_valid_number, '三重県伊賀市下柘植');
ok($zip->set_number('5191413')->is_valid_number, '三重県伊賀市愛田');
ok($zip->set_number('5191414')->is_valid_number, '三重県伊賀市御代');
ok($zip->set_number('5191415')->is_valid_number, '三重県伊賀市柏野');
ok($zip->set_number('5191416')->is_valid_number, '三重県伊賀市新堂');
ok($zip->set_number('5191421')->is_valid_number, '三重県伊賀市山畑');
ok($zip->set_number('5191422')->is_valid_number, '三重県伊賀市希望ケ丘東');
ok($zip->set_number('5191423')->is_valid_number, '三重県伊賀市希望ケ丘西');
ok($zip->set_number('5191424')->is_valid_number, '三重県伊賀市川東');
ok($zip->set_number('5191425')->is_valid_number, '三重県伊賀市川西');
ok($zip->set_number('5191426')->is_valid_number, '三重県伊賀市西之澤');
ok($zip->set_number('5191701')->is_valid_number, '三重県伊賀市島ケ原(川南)');
ok($zip->set_number('5191702')->is_valid_number, '三重県伊賀市島ケ原(不見上)');
ok($zip->set_number('5191703')->is_valid_number, '三重県伊賀市島ケ原(山菅)');
ok($zip->set_number('5191704')->is_valid_number, '三重県伊賀市島ケ原(町)');
ok($zip->set_number('5191705')->is_valid_number, '三重県伊賀市島ケ原(中村)');
ok($zip->set_number('5191706')->is_valid_number, '三重県伊賀市島ケ原(奥村)');
ok($zip->set_number('5191707')->is_valid_number, '三重県伊賀市島ケ原(大道)');
ok($zip->set_number('5191708')->is_valid_number, '三重県伊賀市島ケ原(中矢)');
ok($zip->set_number('5191711')->is_valid_number, '三重県伊賀市島ケ原');
ok($zip->set_number('5192100')->is_valid_number, '三重県多気郡多気町以下に掲載がない場合');
ok($zip->set_number('5192141')->is_valid_number, '三重県松阪市上蛸路町');
ok($zip->set_number('5192142')->is_valid_number, '三重県松阪市下蛸路町');
ok($zip->set_number('5192143')->is_valid_number, '三重県松阪市中万町');
ok($zip->set_number('5192144')->is_valid_number, '三重県松阪市八太町');
ok($zip->set_number('5192145')->is_valid_number, '三重県松阪市射和町');
ok($zip->set_number('5192146')->is_valid_number, '三重県松阪市阿波曽町');
ok($zip->set_number('5192147')->is_valid_number, '三重県松阪市庄町');
ok($zip->set_number('5192148')->is_valid_number, '三重県松阪市御麻生薗町');
ok($zip->set_number('5192151')->is_valid_number, '三重県多気郡多気町朝長');
ok($zip->set_number('5192152')->is_valid_number, '三重県多気郡多気町弟国');
ok($zip->set_number('5192153')->is_valid_number, '三重県多気郡多気町河田');
ok($zip->set_number('5192154')->is_valid_number, '三重県多気郡多気町多気');
ok($zip->set_number('5192155')->is_valid_number, '三重県多気郡多気町東池上');
ok($zip->set_number('5192156')->is_valid_number, '三重県多気郡多気町西池上');
ok($zip->set_number('5192157')->is_valid_number, '三重県多気郡多気町五佐奈');
ok($zip->set_number('5192158')->is_valid_number, '三重県多気郡多気町荒蒔');
ok($zip->set_number('5192159')->is_valid_number, '三重県多気郡多気町兄国');
ok($zip->set_number('5192161')->is_valid_number, '三重県多気郡多気町土羽');
ok($zip->set_number('5192162')->is_valid_number, '三重県多気郡多気町笠木');
ok($zip->set_number('5192163')->is_valid_number, '三重県多気郡多気町矢田');
ok($zip->set_number('5192164')->is_valid_number, '三重県多気郡多気町森荘');
ok($zip->set_number('5192165')->is_valid_number, '三重県多気郡多気町田中');
ok($zip->set_number('5192166')->is_valid_number, '三重県多気郡多気町野中');
ok($zip->set_number('5192167')->is_valid_number, '三重県多気郡多気町相鹿瀬');
ok($zip->set_number('5192170')->is_valid_number, '三重県多気郡多気町ヴィソン');
ok($zip->set_number('5192171')->is_valid_number, '三重県多気郡多気町西山');
ok($zip->set_number('5192172')->is_valid_number, '三重県多気郡多気町四神田');
ok($zip->set_number('5192173')->is_valid_number, '三重県多気郡多気町油夫');
ok($zip->set_number('5192174')->is_valid_number, '三重県多気郡多気町五桂');
ok($zip->set_number('5192175')->is_valid_number, '三重県多気郡多気町前村');
ok($zip->set_number('5192176')->is_valid_number, '三重県多気郡多気町長谷');
ok($zip->set_number('5192177')->is_valid_number, '三重県多気郡多気町神坂');
ok($zip->set_number('5192178')->is_valid_number, '三重県多気郡多気町平谷');
ok($zip->set_number('5192179')->is_valid_number, '三重県多気郡多気町仁田');
ok($zip->set_number('5192181')->is_valid_number, '三重県多気郡多気町相可');
ok($zip->set_number('5192182')->is_valid_number, '三重県多気郡多気町相可台');
ok($zip->set_number('5192183')->is_valid_number, '三重県多気郡多気町四疋田');
ok($zip->set_number('5192184')->is_valid_number, '三重県多気郡多気町三疋田');
ok($zip->set_number('5192185')->is_valid_number, '三重県多気郡多気町佐伯中');
ok($zip->set_number('5192186')->is_valid_number, '三重県多気郡多気町井内林');
ok($zip->set_number('5192187')->is_valid_number, '三重県多気郡多気町鍬形');
ok($zip->set_number('5192188')->is_valid_number, '三重県多気郡多気町牧');
ok($zip->set_number('5192189')->is_valid_number, '三重県多気郡多気町津留');
ok($zip->set_number('5192201')->is_valid_number, '三重県多気郡多気町上出江');
ok($zip->set_number('5192202')->is_valid_number, '三重県多気郡多気町下出江');
ok($zip->set_number('5192203')->is_valid_number, '三重県多気郡多気町片野');
ok($zip->set_number('5192204')->is_valid_number, '三重県多気郡多気町波多瀬');
ok($zip->set_number('5192211')->is_valid_number, '三重県多気郡多気町丹生');
ok($zip->set_number('5192212')->is_valid_number, '三重県多気郡多気町色太');
ok($zip->set_number('5192213')->is_valid_number, '三重県多気郡多気町土屋');
ok($zip->set_number('5192214')->is_valid_number, '三重県多気郡多気町車川');
ok($zip->set_number('5192215')->is_valid_number, '三重県多気郡多気町朝柄');
ok($zip->set_number('5192216')->is_valid_number, '三重県多気郡多気町古江');
ok($zip->set_number('5192400')->is_valid_number, '三重県多気郡大台町以下に掲載がない場合');
ok($zip->set_number('5192401')->is_valid_number, '三重県多気郡大台町長ケ');
ok($zip->set_number('5192402')->is_valid_number, '三重県多気郡大台町下三瀬');
ok($zip->set_number('5192403')->is_valid_number, '三重県多気郡大台町上三瀬');
ok($zip->set_number('5192404')->is_valid_number, '三重県多気郡大台町佐原');
ok($zip->set_number('5192405')->is_valid_number, '三重県多気郡大台町弥起井');
ok($zip->set_number('5192411')->is_valid_number, '三重県多気郡大台町上菅');
ok($zip->set_number('5192412')->is_valid_number, '三重県多気郡大台町川合');
ok($zip->set_number('5192412')->is_valid_number, '三重県多気郡大台町下菅');
ok($zip->set_number('5192412')->is_valid_number, '三重県多気郡大台町菅合');
ok($zip->set_number('5192412')->is_valid_number, '三重県多気郡大台町滝広');
ok($zip->set_number('5192413')->is_valid_number, '三重県多気郡大台町大ケ所');
ok($zip->set_number('5192421')->is_valid_number, '三重県多気郡大台町千代');
ok($zip->set_number('5192422')->is_valid_number, '三重県多気郡大台町柳原');
ok($zip->set_number('5192423')->is_valid_number, '三重県多気郡大台町新田');
ok($zip->set_number('5192424')->is_valid_number, '三重県多気郡大台町栃原');
ok($zip->set_number('5192425')->is_valid_number, '三重県多気郡大台町神瀬');
ok($zip->set_number('5192426')->is_valid_number, '三重県多気郡大台町下楠');
ok($zip->set_number('5192427')->is_valid_number, '三重県多気郡大台町上楠');
ok($zip->set_number('5192428')->is_valid_number, '三重県多気郡大台町粟生');
ok($zip->set_number('5192429')->is_valid_number, '三重県多気郡大台町高奈');
ok($zip->set_number('5192501')->is_valid_number, '三重県多気郡大台町下真手');
ok($zip->set_number('5192502')->is_valid_number, '三重県多気郡大台町上真手');
ok($zip->set_number('5192503')->is_valid_number, '三重県多気郡大台町本田木屋');
ok($zip->set_number('5192504')->is_valid_number, '三重県多気郡大台町小切畑');
ok($zip->set_number('5192505')->is_valid_number, '三重県多気郡大台町江馬');
ok($zip->set_number('5192506')->is_valid_number, '三重県多気郡大台町天ケ瀬');
ok($zip->set_number('5192507')->is_valid_number, '三重県多気郡大台町栗谷');
ok($zip->set_number('5192511')->is_valid_number, '三重県多気郡大台町菅木屋');
ok($zip->set_number('5192512')->is_valid_number, '三重県多気郡大台町清滝');
ok($zip->set_number('5192513')->is_valid_number, '三重県多気郡大台町薗');
ok($zip->set_number('5192514')->is_valid_number, '三重県多気郡大台町茂原');
ok($zip->set_number('5192515')->is_valid_number, '三重県多気郡大台町熊内');
ok($zip->set_number('5192516')->is_valid_number, '三重県多気郡大台町唐櫃');
ok($zip->set_number('5192517')->is_valid_number, '三重県多気郡大台町南');
ok($zip->set_number('5192518')->is_valid_number, '三重県多気郡大台町大井');
ok($zip->set_number('5192521')->is_valid_number, '三重県多気郡大台町明豆');
ok($zip->set_number('5192522')->is_valid_number, '三重県多気郡大台町御棟');
ok($zip->set_number('5192523')->is_valid_number, '三重県多気郡大台町小滝');
ok($zip->set_number('5192524')->is_valid_number, '三重県多気郡大台町神滝');
ok($zip->set_number('5192525')->is_valid_number, '三重県多気郡大台町滝谷');
ok($zip->set_number('5192631')->is_valid_number, '三重県多気郡大台町岩井');
ok($zip->set_number('5192632')->is_valid_number, '三重県多気郡大台町桧原');
ok($zip->set_number('5192633')->is_valid_number, '三重県多気郡大台町久豆');
ok($zip->set_number('5192634')->is_valid_number, '三重県多気郡大台町大杉');
ok($zip->set_number('5192700')->is_valid_number, '三重県度会郡大紀町以下に掲載がない場合');
ok($zip->set_number('5192701')->is_valid_number, '三重県度会郡大紀町船木');
ok($zip->set_number('5192702')->is_valid_number, '三重県度会郡大紀町三瀬川');
ok($zip->set_number('5192703')->is_valid_number, '三重県度会郡大紀町滝原');
ok($zip->set_number('5192704')->is_valid_number, '三重県度会郡大紀町阿曽');
ok($zip->set_number('5192731')->is_valid_number, '三重県度会郡大紀町野原');
ok($zip->set_number('5192732')->is_valid_number, '三重県度会郡大紀町野添');
ok($zip->set_number('5192733')->is_valid_number, '三重県度会郡大紀町金輪');
ok($zip->set_number('5192734')->is_valid_number, '三重県度会郡大紀町永会');
ok($zip->set_number('5192735')->is_valid_number, '三重県度会郡大紀町神原');
ok($zip->set_number('5192736')->is_valid_number, '三重県度会郡大紀町打見');
ok($zip->set_number('5192801')->is_valid_number, '三重県度会郡大紀町柏野');
ok($zip->set_number('5192802')->is_valid_number, '三重県度会郡大紀町崎');
ok($zip->set_number('5192911')->is_valid_number, '三重県度会郡大紀町錦');
ok($zip->set_number('5193111')->is_valid_number, '三重県度会郡大紀町大内山');
ok($zip->set_number('5193201')->is_valid_number, '三重県北牟婁郡紀北町十須');
ok($zip->set_number('5193202')->is_valid_number, '三重県北牟婁郡紀北町大原');
ok($zip->set_number('5193203')->is_valid_number, '三重県北牟婁郡紀北町島原');
ok($zip->set_number('5193204')->is_valid_number, '三重県北牟婁郡紀北町東長島');
ok($zip->set_number('5193205')->is_valid_number, '三重県北牟婁郡紀北町長島');
ok($zip->set_number('5193206')->is_valid_number, '三重県北牟婁郡紀北町海野');
ok($zip->set_number('5193207')->is_valid_number, '三重県北牟婁郡紀北町道瀬');
ok($zip->set_number('5193208')->is_valid_number, '三重県北牟婁郡紀北町三浦');
ok($zip->set_number('5193209')->is_valid_number, '三重県北牟婁郡紀北町古里');
ok($zip->set_number('5193400')->is_valid_number, '三重県北牟婁郡紀北町以下に掲載がない場合');
ok($zip->set_number('5193401')->is_valid_number, '三重県北牟婁郡紀北町馬瀬');
ok($zip->set_number('5193402')->is_valid_number, '三重県北牟婁郡紀北町河内');
ok($zip->set_number('5193403')->is_valid_number, '三重県北牟婁郡紀北町上里');
ok($zip->set_number('5193404')->is_valid_number, '三重県北牟婁郡紀北町中里');
ok($zip->set_number('5193405')->is_valid_number, '三重県北牟婁郡紀北町船津');
ok($zip->set_number('5193406')->is_valid_number, '三重県北牟婁郡紀北町相賀');
ok($zip->set_number('5193407')->is_valid_number, '三重県北牟婁郡紀北町小山浦');
ok($zip->set_number('5193408')->is_valid_number, '三重県北牟婁郡紀北町便ノ山');
ok($zip->set_number('5193411')->is_valid_number, '三重県北牟婁郡紀北町白浦');
ok($zip->set_number('5193412')->is_valid_number, '三重県北牟婁郡紀北町島勝浦');
ok($zip->set_number('5193413')->is_valid_number, '三重県北牟婁郡紀北町引本浦');
ok($zip->set_number('5193414')->is_valid_number, '三重県北牟婁郡紀北町小浦');
ok($zip->set_number('5193415')->is_valid_number, '三重県北牟婁郡紀北町矢口浦');
ok($zip->set_number('5193421')->is_valid_number, '三重県尾鷲市須賀利町');
ok($zip->set_number('5193600')->is_valid_number, '三重県尾鷲市以下に掲載がない場合');
ok($zip->set_number('5193601')->is_valid_number, '三重県尾鷲市南浦(天満)');
ok($zip->set_number('5193602')->is_valid_number, '三重県尾鷲市天満浦');
ok($zip->set_number('5193604')->is_valid_number, '三重県尾鷲市港町');
ok($zip->set_number('5193605')->is_valid_number, '三重県尾鷲市中井町');
ok($zip->set_number('5193606')->is_valid_number, '三重県尾鷲市北浦町');
ok($zip->set_number('5193609')->is_valid_number, '三重県尾鷲市北浦東町');
ok($zip->set_number('5193610')->is_valid_number, '三重県尾鷲市北浦西町');
ok($zip->set_number('5193611')->is_valid_number, '三重県尾鷲市朝日町');
ok($zip->set_number('5193612')->is_valid_number, '三重県尾鷲市林町');
ok($zip->set_number('5193613')->is_valid_number, '三重県尾鷲市瀬木山町');
ok($zip->set_number('5193613')->is_valid_number, '三重県尾鷲市南浦(林)');
ok($zip->set_number('5193614')->is_valid_number, '三重県尾鷲市南陽町');
ok($zip->set_number('5193615')->is_valid_number, '三重県尾鷲市中央町');
ok($zip->set_number('5193616')->is_valid_number, '三重県尾鷲市中村町');
ok($zip->set_number('5193617')->is_valid_number, '三重県尾鷲市野地町');
ok($zip->set_number('5193618')->is_valid_number, '三重県尾鷲市栄町');
ok($zip->set_number('5193619')->is_valid_number, '三重県尾鷲市馬越町');
ok($zip->set_number('5193620')->is_valid_number, '三重県尾鷲市座ノ下町');
ok($zip->set_number('5193621')->is_valid_number, '三重県尾鷲市行野浦');
ok($zip->set_number('5193623')->is_valid_number, '三重県尾鷲市大曽根浦');
ok($zip->set_number('5193625')->is_valid_number, '三重県尾鷲市向井');
ok($zip->set_number('5193626')->is_valid_number, '三重県尾鷲市国市松泉町');
ok($zip->set_number('5193634')->is_valid_number, '三重県尾鷲市南浦(矢浜)');
ok($zip->set_number('5193637')->is_valid_number, '三重県尾鷲市光ケ丘');
ok($zip->set_number('5193638')->is_valid_number, '三重県尾鷲市新田町');
ok($zip->set_number('5193639')->is_valid_number, '三重県尾鷲市中川');
ok($zip->set_number('5193640')->is_valid_number, '三重県尾鷲市桂ケ丘');
ok($zip->set_number('5193642')->is_valid_number, '三重県尾鷲市大滝町');
ok($zip->set_number('5193643')->is_valid_number, '三重県尾鷲市南浦(小原野)');
ok($zip->set_number('5193646')->is_valid_number, '三重県尾鷲市泉町');
ok($zip->set_number('5193647')->is_valid_number, '三重県尾鷲市小川西町');
ok($zip->set_number('5193648')->is_valid_number, '三重県尾鷲市小川東町');
ok($zip->set_number('5193651')->is_valid_number, '三重県尾鷲市末広町');
ok($zip->set_number('5193652')->is_valid_number, '三重県尾鷲市古戸町');
ok($zip->set_number('5193653')->is_valid_number, '三重県尾鷲市上野町');
ok($zip->set_number('5193656')->is_valid_number, '三重県尾鷲市南浦(倉ノ谷)');
ok($zip->set_number('5193658')->is_valid_number, '三重県尾鷲市倉ノ谷町');
ok($zip->set_number('5193659')->is_valid_number, '三重県尾鷲市古戸野町');
ok($zip->set_number('5193663')->is_valid_number, '三重県尾鷲市宮ノ上町');
ok($zip->set_number('5193664')->is_valid_number, '三重県尾鷲市坂場町');
ok($zip->set_number('5193666')->is_valid_number, '三重県尾鷲市坂場西町');
ok($zip->set_number('5193666')->is_valid_number, '三重県尾鷲市中井浦(坂場)');
ok($zip->set_number('5193667')->is_valid_number, '三重県尾鷲市南浦(クチスボ)');
ok($zip->set_number('5193671')->is_valid_number, '三重県尾鷲市矢浜(丁目)');
ok($zip->set_number('5193672')->is_valid_number, '三重県尾鷲市矢浜岡崎町');
ok($zip->set_number('5193673')->is_valid_number, '三重県尾鷲市矢浜大道');
ok($zip->set_number('5193674')->is_valid_number, '三重県尾鷲市矢浜真砂');
ok($zip->set_number('5193701')->is_valid_number, '三重県尾鷲市九鬼町');
ok($zip->set_number('5193702')->is_valid_number, '三重県尾鷲市早田町');
ok($zip->set_number('5193811')->is_valid_number, '三重県尾鷲市三木里町');
ok($zip->set_number('5193812')->is_valid_number, '三重県尾鷲市名柄町');
ok($zip->set_number('5193813')->is_valid_number, '三重県尾鷲市小脇町');
ok($zip->set_number('5193814')->is_valid_number, '三重県尾鷲市三木浦町');
ok($zip->set_number('5193921')->is_valid_number, '三重県尾鷲市賀田町');
ok($zip->set_number('5193922')->is_valid_number, '三重県尾鷲市古江町');
ok($zip->set_number('5193923')->is_valid_number, '三重県尾鷲市梶賀町');
ok($zip->set_number('5193924')->is_valid_number, '三重県尾鷲市曽根町');
ok($zip->set_number('5194201')->is_valid_number, '三重県熊野市須野町');
ok($zip->set_number('5194202')->is_valid_number, '三重県熊野市甫母町');
ok($zip->set_number('5194203')->is_valid_number, '三重県熊野市二木島里町');
ok($zip->set_number('5194204')->is_valid_number, '三重県熊野市二木島町');
ok($zip->set_number('5194205')->is_valid_number, '三重県熊野市遊木町');
ok($zip->set_number('5194206')->is_valid_number, '三重県熊野市新鹿町');
ok($zip->set_number('5194207')->is_valid_number, '三重県熊野市波田須町');
ok($zip->set_number('5194300')->is_valid_number, '三重県熊野市以下に掲載がない場合');
ok($zip->set_number('5194321')->is_valid_number, '三重県熊野市磯崎町');
ok($zip->set_number('5194322')->is_valid_number, '三重県熊野市大泊町');
ok($zip->set_number('5194323')->is_valid_number, '三重県熊野市木本町');
ok($zip->set_number('5194324')->is_valid_number, '三重県熊野市井戸町');
ok($zip->set_number('5194325')->is_valid_number, '三重県熊野市有馬町');
ok($zip->set_number('5194326')->is_valid_number, '三重県熊野市久生屋町');
ok($zip->set_number('5194327')->is_valid_number, '三重県熊野市金山町');
ok($zip->set_number('5194441')->is_valid_number, '三重県熊野市神川町花知');
ok($zip->set_number('5194442')->is_valid_number, '三重県熊野市神川町神上');
ok($zip->set_number('5194443')->is_valid_number, '三重県熊野市神川町柳谷');
ok($zip->set_number('5194444')->is_valid_number, '三重県熊野市神川町長原');
ok($zip->set_number('5194445')->is_valid_number, '三重県熊野市育生町粉所');
ok($zip->set_number('5194446')->is_valid_number, '三重県熊野市育生町赤倉');
ok($zip->set_number('5194447')->is_valid_number, '三重県熊野市育生町尾川');
ok($zip->set_number('5194448')->is_valid_number, '三重県熊野市育生町大井');
ok($zip->set_number('5194449')->is_valid_number, '三重県熊野市育生町長井');
ok($zip->set_number('5194561')->is_valid_number, '三重県熊野市飛鳥町大又');
ok($zip->set_number('5194562')->is_valid_number, '三重県熊野市飛鳥町小又');
ok($zip->set_number('5194563')->is_valid_number, '三重県熊野市飛鳥町小阪');
ok($zip->set_number('5194564')->is_valid_number, '三重県熊野市飛鳥町佐渡');
ok($zip->set_number('5194565')->is_valid_number, '三重県熊野市飛鳥町野口');
ok($zip->set_number('5194566')->is_valid_number, '三重県熊野市飛鳥町神山');
ok($zip->set_number('5194671')->is_valid_number, '三重県熊野市五郷町桃崎');
ok($zip->set_number('5194672')->is_valid_number, '三重県熊野市五郷町湯谷');
ok($zip->set_number('5194673')->is_valid_number, '三重県熊野市五郷町寺谷');
ok($zip->set_number('5194674')->is_valid_number, '三重県熊野市五郷町和田');
ok($zip->set_number('5194675')->is_valid_number, '三重県熊野市五郷町大井谷');
ok($zip->set_number('5195200')->is_valid_number, '三重県南牟婁郡御浜町以下に掲載がない場合');
ok($zip->set_number('5195201')->is_valid_number, '三重県南牟婁郡御浜町神木');
ok($zip->set_number('5195202')->is_valid_number, '三重県南牟婁郡御浜町志原');
ok($zip->set_number('5195203')->is_valid_number, '三重県南牟婁郡御浜町下市木');
ok($zip->set_number('5195203')->is_valid_number, '三重県南牟婁郡御浜町萩内');
ok($zip->set_number('5195204')->is_valid_number, '三重県南牟婁郡御浜町阿田和');
ok($zip->set_number('5195204')->is_valid_number, '三重県南牟婁郡御浜町阿田和(平見)');
ok($zip->set_number('5195204')->is_valid_number, '三重県南牟婁郡御浜町山地');
ok($zip->set_number('5195205')->is_valid_number, '三重県南牟婁郡御浜町引作');
ok($zip->set_number('5195206')->is_valid_number, '三重県南牟婁郡御浜町柿原');
ok($zip->set_number('5195211')->is_valid_number, '三重県南牟婁郡御浜町上市木');
ok($zip->set_number('5195321')->is_valid_number, '三重県南牟婁郡御浜町阪本');
ok($zip->set_number('5195322')->is_valid_number, '三重県南牟婁郡御浜町上野');
ok($zip->set_number('5195323')->is_valid_number, '三重県南牟婁郡御浜町西原');
ok($zip->set_number('5195324')->is_valid_number, '三重県南牟婁郡御浜町中立');
ok($zip->set_number('5195325')->is_valid_number, '三重県南牟婁郡御浜町片川');
ok($zip->set_number('5195326')->is_valid_number, '三重県南牟婁郡御浜町栗須');
ok($zip->set_number('5195327')->is_valid_number, '三重県南牟婁郡御浜町川瀬');
ok($zip->set_number('5195401')->is_valid_number, '三重県熊野市紀和町小森');
ok($zip->set_number('5195402')->is_valid_number, '三重県熊野市紀和町平谷');
ok($zip->set_number('5195403')->is_valid_number, '三重県熊野市紀和町長尾');
ok($zip->set_number('5195404')->is_valid_number, '三重県熊野市紀和町赤木');
ok($zip->set_number('5195405')->is_valid_number, '三重県熊野市紀和町丸山');
ok($zip->set_number('5195406')->is_valid_number, '三重県熊野市紀和町矢ノ川');
ok($zip->set_number('5195411')->is_valid_number, '三重県熊野市紀和町木津呂');
ok($zip->set_number('5195412')->is_valid_number, '三重県熊野市紀和町大栗須');
ok($zip->set_number('5195413')->is_valid_number, '三重県熊野市紀和町板屋');
ok($zip->set_number('5195414')->is_valid_number, '三重県熊野市紀和町小栗須');
ok($zip->set_number('5195415')->is_valid_number, '三重県熊野市紀和町大河内');
ok($zip->set_number('5195416')->is_valid_number, '三重県熊野市紀和町湯ノ口');
ok($zip->set_number('5195417')->is_valid_number, '三重県熊野市紀和町小川口');
ok($zip->set_number('5195700')->is_valid_number, '三重県南牟婁郡紀宝町以下に掲載がない場合');
ok($zip->set_number('5195701')->is_valid_number, '三重県南牟婁郡紀宝町鵜殿');
ok($zip->set_number('5195711')->is_valid_number, '三重県南牟婁郡紀宝町井田');
ok($zip->set_number('5195712')->is_valid_number, '三重県南牟婁郡紀宝町神内');
ok($zip->set_number('5195713')->is_valid_number, '三重県南牟婁郡紀宝町成川');
ok($zip->set_number('5195714')->is_valid_number, '三重県南牟婁郡紀宝町鮒田');
ok($zip->set_number('5195715')->is_valid_number, '三重県南牟婁郡紀宝町高岡');
ok($zip->set_number('5195716')->is_valid_number, '三重県南牟婁郡紀宝町北桧杖');
ok($zip->set_number('5195717')->is_valid_number, '三重県南牟婁郡紀宝町瀬原');
ok($zip->set_number('5195718')->is_valid_number, '三重県南牟婁郡紀宝町浅里');
ok($zip->set_number('5195831')->is_valid_number, '三重県南牟婁郡紀宝町桐原');
ok($zip->set_number('5195832')->is_valid_number, '三重県南牟婁郡紀宝町阪松原');
ok($zip->set_number('5195833')->is_valid_number, '三重県南牟婁郡紀宝町平尾井');
ok($zip->set_number('5195834')->is_valid_number, '三重県南牟婁郡紀宝町井内');
ok($zip->set_number('5195835')->is_valid_number, '三重県南牟婁郡紀宝町大里');
ok($zip->set_number('5200000')->is_valid_number, '滋賀県大津市以下に掲載がない場合');
ok($zip->set_number('5200001')->is_valid_number, '滋賀県大津市蓮池町');
ok($zip->set_number('5200002')->is_valid_number, '滋賀県大津市際川');
ok($zip->set_number('5200003')->is_valid_number, '滋賀県大津市あかね町');
ok($zip->set_number('5200004')->is_valid_number, '滋賀県大津市見世');
ok($zip->set_number('5200005')->is_valid_number, '滋賀県大津市高砂町');
ok($zip->set_number('5200006')->is_valid_number, '滋賀県大津市滋賀里');
ok($zip->set_number('5200011')->is_valid_number, '滋賀県大津市南志賀');
ok($zip->set_number('5200012')->is_valid_number, '滋賀県大津市鏡が浜');
ok($zip->set_number('5200013')->is_valid_number, '滋賀県大津市勧学');
ok($zip->set_number('5200014')->is_valid_number, '滋賀県大津市柳川');
ok($zip->set_number('5200015')->is_valid_number, '滋賀県大津市神宮町');
ok($zip->set_number('5200016')->is_valid_number, '滋賀県大津市比叡平');
ok($zip->set_number('5200017')->is_valid_number, '滋賀県大津市山中町');
ok($zip->set_number('5200018')->is_valid_number, '滋賀県大津市南滋賀町');
ok($zip->set_number('5200021')->is_valid_number, '滋賀県大津市二本松');
ok($zip->set_number('5200022')->is_valid_number, '滋賀県大津市柳が崎');
ok($zip->set_number('5200023')->is_valid_number, '滋賀県大津市茶が崎');
ok($zip->set_number('5200024')->is_valid_number, '滋賀県大津市松山町');
ok($zip->set_number('5200025')->is_valid_number, '滋賀県大津市皇子が丘');
ok($zip->set_number('5200026')->is_valid_number, '滋賀県大津市桜野町');
ok($zip->set_number('5200027')->is_valid_number, '滋賀県大津市錦織');
ok($zip->set_number('5200028')->is_valid_number, '滋賀県大津市千石台');
ok($zip->set_number('5200031')->is_valid_number, '滋賀県大津市尾花川');
ok($zip->set_number('5200032')->is_valid_number, '滋賀県大津市観音寺');
ok($zip->set_number('5200033')->is_valid_number, '滋賀県大津市大門通');
ok($zip->set_number('5200034')->is_valid_number, '滋賀県大津市三井寺町');
ok($zip->set_number('5200035')->is_valid_number, '滋賀県大津市小関町');
ok($zip->set_number('5200036')->is_valid_number, '滋賀県大津市園城寺町');
ok($zip->set_number('5200037')->is_valid_number, '滋賀県大津市御陵町');
ok($zip->set_number('5200038')->is_valid_number, '滋賀県大津市山上町');
ok($zip->set_number('5200041')->is_valid_number, '滋賀県大津市浜町');
ok($zip->set_number('5200042')->is_valid_number, '滋賀県大津市島の関');
ok($zip->set_number('5200043')->is_valid_number, '滋賀県大津市中央');
ok($zip->set_number('5200044')->is_valid_number, '滋賀県大津市京町');
ok($zip->set_number('5200045')->is_valid_number, '滋賀県大津市札の辻');
ok($zip->set_number('5200046')->is_valid_number, '滋賀県大津市長等');
ok($zip->set_number('5200047')->is_valid_number, '滋賀県大津市浜大津');
ok($zip->set_number('5200051')->is_valid_number, '滋賀県大津市梅林');
ok($zip->set_number('5200052')->is_valid_number, '滋賀県大津市朝日が丘');
ok($zip->set_number('5200053')->is_valid_number, '滋賀県大津市音羽台');
ok($zip->set_number('5200054')->is_valid_number, '滋賀県大津市逢坂');
ok($zip->set_number('5200055')->is_valid_number, '滋賀県大津市春日町');
ok($zip->set_number('5200056')->is_valid_number, '滋賀県大津市末広町');
ok($zip->set_number('5200057')->is_valid_number, '滋賀県大津市御幸町');
ok($zip->set_number('5200061')->is_valid_number, '滋賀県大津市神出開町');
ok($zip->set_number('5200062')->is_valid_number, '滋賀県大津市大谷町');
ok($zip->set_number('5200063')->is_valid_number, '滋賀県大津市横木');
ok($zip->set_number('5200064')->is_valid_number, '滋賀県大津市追分町');
ok($zip->set_number('5200065')->is_valid_number, '滋賀県大津市稲葉台');
ok($zip->set_number('5200066')->is_valid_number, '滋賀県大津市茶戸町');
ok($zip->set_number('5200067')->is_valid_number, '滋賀県大津市藤尾奥町');
ok($zip->set_number('5200101')->is_valid_number, '滋賀県大津市雄琴');
ok($zip->set_number('5200102')->is_valid_number, '滋賀県大津市苗鹿');
ok($zip->set_number('5200103')->is_valid_number, '滋賀県大津市木の岡町');
ok($zip->set_number('5200104')->is_valid_number, '滋賀県大津市比叡辻');
ok($zip->set_number('5200105')->is_valid_number, '滋賀県大津市下阪本');
ok($zip->set_number('5200106')->is_valid_number, '滋賀県大津市唐崎');
ok($zip->set_number('5200107')->is_valid_number, '滋賀県大津市雄琴北');
ok($zip->set_number('5200111')->is_valid_number, '滋賀県大津市千野');
ok($zip->set_number('5200112')->is_valid_number, '滋賀県大津市日吉台');
ok($zip->set_number('5200113')->is_valid_number, '滋賀県大津市坂本');
ok($zip->set_number('5200114')->is_valid_number, '滋賀県大津市穴太');
ok($zip->set_number('5200115')->is_valid_number, '滋賀県大津市弥生町');
ok($zip->set_number('5200116')->is_valid_number, '滋賀県大津市坂本本町');
ok($zip->set_number('5200221')->is_valid_number, '滋賀県大津市緑町');
ok($zip->set_number('5200222')->is_valid_number, '滋賀県大津市花園町');
ok($zip->set_number('5200223')->is_valid_number, '滋賀県大津市美空町');
ok($zip->set_number('5200224')->is_valid_number, '滋賀県大津市向陽町');
ok($zip->set_number('5200225')->is_valid_number, '滋賀県大津市清風町');
ok($zip->set_number('5200226')->is_valid_number, '滋賀県大津市陽明町');
ok($zip->set_number('5200227')->is_valid_number, '滋賀県大津市清和町');
ok($zip->set_number('5200231')->is_valid_number, '滋賀県大津市真野普門');
ok($zip->set_number('5200232')->is_valid_number, '滋賀県大津市真野');
ok($zip->set_number('5200233')->is_valid_number, '滋賀県大津市真野谷口町');
ok($zip->set_number('5200234')->is_valid_number, '滋賀県大津市真野家田町');
ok($zip->set_number('5200235')->is_valid_number, '滋賀県大津市真野大野');
ok($zip->set_number('5200236')->is_valid_number, '滋賀県大津市真野佐川町');
ok($zip->set_number('5200241')->is_valid_number, '滋賀県大津市今堅田');
ok($zip->set_number('5200242')->is_valid_number, '滋賀県大津市本堅田');
ok($zip->set_number('5200243')->is_valid_number, '滋賀県大津市堅田');
ok($zip->set_number('5200244')->is_valid_number, '滋賀県大津市衣川');
ok($zip->set_number('5200245')->is_valid_number, '滋賀県大津市仰木町');
ok($zip->set_number('5200246')->is_valid_number, '滋賀県大津市仰木の里');
ok($zip->set_number('5200247')->is_valid_number, '滋賀県大津市仰木');
ok($zip->set_number('5200248')->is_valid_number, '滋賀県大津市仰木の里東');
ok($zip->set_number('5200351')->is_valid_number, '滋賀県大津市伊香立北在地町');
ok($zip->set_number('5200352')->is_valid_number, '滋賀県大津市伊香立下在地町');
ok($zip->set_number('5200353')->is_valid_number, '滋賀県大津市伊香立向在地町');
ok($zip->set_number('5200354')->is_valid_number, '滋賀県大津市伊香立南庄町');
ok($zip->set_number('5200355')->is_valid_number, '滋賀県大津市伊香立生津町');
ok($zip->set_number('5200356')->is_valid_number, '滋賀県大津市伊香立上在地町');
ok($zip->set_number('5200357')->is_valid_number, '滋賀県大津市山百合の丘');
ok($zip->set_number('5200361')->is_valid_number, '滋賀県大津市伊香立途中町');
ok($zip->set_number('5200362')->is_valid_number, '滋賀県大津市伊香立上龍華町');
ok($zip->set_number('5200363')->is_valid_number, '滋賀県大津市伊香立下龍華町');
ok($zip->set_number('5200461')->is_valid_number, '京都府京都市左京区久多川合町');
ok($zip->set_number('5200462')->is_valid_number, '京都府京都市左京区久多下の町');
ok($zip->set_number('5200463')->is_valid_number, '京都府京都市左京区久多宮の町');
ok($zip->set_number('5200464')->is_valid_number, '京都府京都市左京区久多中の町');
ok($zip->set_number('5200465')->is_valid_number, '京都府京都市左京区久多上の町');
ok($zip->set_number('5200471')->is_valid_number, '滋賀県大津市葛川細川町');
ok($zip->set_number('5200472')->is_valid_number, '滋賀県大津市葛川貫井町');
ok($zip->set_number('5200473')->is_valid_number, '滋賀県大津市葛川梅ノ木町');
ok($zip->set_number('5200474')->is_valid_number, '滋賀県大津市葛川町居町');
ok($zip->set_number('5200475')->is_valid_number, '滋賀県大津市葛川坊村町');
ok($zip->set_number('5200476')->is_valid_number, '滋賀県大津市葛川中村町');
ok($zip->set_number('5200477')->is_valid_number, '滋賀県大津市葛川木戸口町');
ok($zip->set_number('5200478')->is_valid_number, '滋賀県大津市葛川坂下町');
ok($zip->set_number('5200501')->is_valid_number, '滋賀県大津市北小松');
ok($zip->set_number('5200502')->is_valid_number, '滋賀県大津市南小松');
ok($zip->set_number('5200503')->is_valid_number, '滋賀県大津市北比良');
ok($zip->set_number('5200511')->is_valid_number, '滋賀県大津市南比良');
ok($zip->set_number('5200512')->is_valid_number, '滋賀県大津市大物');
ok($zip->set_number('5200513')->is_valid_number, '滋賀県大津市荒川');
ok($zip->set_number('5200514')->is_valid_number, '滋賀県大津市木戸');
ok($zip->set_number('5200515')->is_valid_number, '滋賀県大津市八屋戸');
ok($zip->set_number('5200516')->is_valid_number, '滋賀県大津市南船路');
ok($zip->set_number('5200521')->is_valid_number, '滋賀県大津市和邇北浜');
ok($zip->set_number('5200522')->is_valid_number, '滋賀県大津市和邇中浜');
ok($zip->set_number('5200523')->is_valid_number, '滋賀県大津市和邇南浜');
ok($zip->set_number('5200524')->is_valid_number, '滋賀県大津市和邇今宿');
ok($zip->set_number('5200525')->is_valid_number, '滋賀県大津市小野');
ok($zip->set_number('5200526')->is_valid_number, '滋賀県大津市和邇中');
ok($zip->set_number('5200527')->is_valid_number, '滋賀県大津市栗原');
ok($zip->set_number('5200528')->is_valid_number, '滋賀県大津市和邇高城');
ok($zip->set_number('5200529')->is_valid_number, '滋賀県大津市和邇春日');
ok($zip->set_number('5200531')->is_valid_number, '滋賀県大津市水明');
ok($zip->set_number('5200532')->is_valid_number, '滋賀県大津市湖青');
ok($zip->set_number('5200533')->is_valid_number, '滋賀県大津市朝日');
ok($zip->set_number('5200801')->is_valid_number, '滋賀県大津市におの浜');
ok($zip->set_number('5200802')->is_valid_number, '滋賀県大津市馬場');
ok($zip->set_number('5200803')->is_valid_number, '滋賀県大津市竜が丘');
ok($zip->set_number('5200804')->is_valid_number, '滋賀県大津市本宮');
ok($zip->set_number('5200805')->is_valid_number, '滋賀県大津市石場');
ok($zip->set_number('5200806')->is_valid_number, '滋賀県大津市打出浜');
ok($zip->set_number('5200807')->is_valid_number, '滋賀県大津市松本');
ok($zip->set_number('5200811')->is_valid_number, '滋賀県大津市由美浜');
ok($zip->set_number('5200812')->is_valid_number, '滋賀県大津市木下町');
ok($zip->set_number('5200813')->is_valid_number, '滋賀県大津市丸の内町');
ok($zip->set_number('5200814')->is_valid_number, '滋賀県大津市本丸町');
ok($zip->set_number('5200815')->is_valid_number, '滋賀県大津市膳所');
ok($zip->set_number('5200816')->is_valid_number, '滋賀県大津市相模町');
ok($zip->set_number('5200817')->is_valid_number, '滋賀県大津市昭和町');
ok($zip->set_number('5200818')->is_valid_number, '滋賀県大津市西の庄');
ok($zip->set_number('5200821')->is_valid_number, '滋賀県大津市湖城が丘');
ok($zip->set_number('5200822')->is_valid_number, '滋賀県大津市秋葉台');
ok($zip->set_number('5200823')->is_valid_number, '滋賀県大津市膳所上別保町');
ok($zip->set_number('5200824')->is_valid_number, '滋賀県大津市膳所平尾町');
ok($zip->set_number('5200825')->is_valid_number, '滋賀県大津市膳所池ノ内町');
ok($zip->set_number('5200826')->is_valid_number, '滋賀県大津市鶴の里');
ok($zip->set_number('5200827')->is_valid_number, '滋賀県大津市池の里');
ok($zip->set_number('5200831')->is_valid_number, '滋賀県大津市松原町');
ok($zip->set_number('5200832')->is_valid_number, '滋賀県大津市粟津町');
ok($zip->set_number('5200833')->is_valid_number, '滋賀県大津市晴嵐');
ok($zip->set_number('5200834')->is_valid_number, '滋賀県大津市御殿浜');
ok($zip->set_number('5200835')->is_valid_number, '滋賀県大津市別保');
ok($zip->set_number('5200836')->is_valid_number, '滋賀県大津市杉浦町');
ok($zip->set_number('5200837')->is_valid_number, '滋賀県大津市中庄');
ok($zip->set_number('5200841')->is_valid_number, '滋賀県大津市美崎町');
ok($zip->set_number('5200842')->is_valid_number, '滋賀県大津市園山');
ok($zip->set_number('5200843')->is_valid_number, '滋賀県大津市北大路');
ok($zip->set_number('5200844')->is_valid_number, '滋賀県大津市国分');
ok($zip->set_number('5200845')->is_valid_number, '滋賀県大津市若葉台');
ok($zip->set_number('5200846')->is_valid_number, '滋賀県大津市富士見台');
ok($zip->set_number('5200851')->is_valid_number, '滋賀県大津市唐橋町');
ok($zip->set_number('5200852')->is_valid_number, '滋賀県大津市田辺町');
ok($zip->set_number('5200853')->is_valid_number, '滋賀県大津市螢谷');
ok($zip->set_number('5200854')->is_valid_number, '滋賀県大津市鳥居川町');
ok($zip->set_number('5200855')->is_valid_number, '滋賀県大津市栄町');
ok($zip->set_number('5200856')->is_valid_number, '滋賀県大津市光が丘町');
ok($zip->set_number('5200860')->is_valid_number, '滋賀県大津市石山千町');
ok($zip->set_number('5200861')->is_valid_number, '滋賀県大津市石山寺');
ok($zip->set_number('5200862')->is_valid_number, '滋賀県大津市平津');
ok($zip->set_number('5200863')->is_valid_number, '滋賀県大津市千町');
ok($zip->set_number('5200864')->is_valid_number, '滋賀県大津市赤尾町');
ok($zip->set_number('5200865')->is_valid_number, '滋賀県大津市南郷');
ok($zip->set_number('5200866')->is_valid_number, '滋賀県大津市石山寺辺町');
ok($zip->set_number('5200867')->is_valid_number, '滋賀県大津市大平');
ok($zip->set_number('5200868')->is_valid_number, '滋賀県大津市石山外畑町');
ok($zip->set_number('5200869')->is_valid_number, '滋賀県大津市石山内畑町');
ok($zip->set_number('5200871')->is_valid_number, '滋賀県大津市南郷上山町');
ok($zip->set_number('5201100')->is_valid_number, '滋賀県高島市以下に掲載がない場合');
ok($zip->set_number('5201101')->is_valid_number, '滋賀県高島市武曽横山');
ok($zip->set_number('5201102')->is_valid_number, '滋賀県高島市野田');
ok($zip->set_number('5201103')->is_valid_number, '滋賀県高島市宮野');
ok($zip->set_number('5201111')->is_valid_number, '滋賀県高島市鴨');
ok($zip->set_number('5201112')->is_valid_number, '滋賀県高島市永田');
ok($zip->set_number('5201121')->is_valid_number, '滋賀県高島市勝野');
ok($zip->set_number('5201122')->is_valid_number, '滋賀県高島市鵜川');
ok($zip->set_number('5201123')->is_valid_number, '滋賀県高島市城山台');
ok($zip->set_number('5201131')->is_valid_number, '滋賀県高島市音羽');
ok($zip->set_number('5201132')->is_valid_number, '滋賀県高島市拝戸');
ok($zip->set_number('5201133')->is_valid_number, '滋賀県高島市鴨川平');
ok($zip->set_number('5201141')->is_valid_number, '滋賀県高島市高島');
ok($zip->set_number('5201142')->is_valid_number, '滋賀県高島市鹿ケ瀬');
ok($zip->set_number('5201143')->is_valid_number, '滋賀県高島市黒谷');
ok($zip->set_number('5201144')->is_valid_number, '滋賀県高島市畑');
ok($zip->set_number('5201201')->is_valid_number, '滋賀県高島市安曇川町上古賀');
ok($zip->set_number('5201202')->is_valid_number, '滋賀県高島市安曇川町下古賀');
ok($zip->set_number('5201203')->is_valid_number, '滋賀県高島市安曇川町南古賀');
ok($zip->set_number('5201204')->is_valid_number, '滋賀県高島市安曇川町中野');
ok($zip->set_number('5201205')->is_valid_number, '滋賀県高島市安曇川町長尾');
ok($zip->set_number('5201211')->is_valid_number, '滋賀県高島市安曇川町常磐木');
ok($zip->set_number('5201212')->is_valid_number, '滋賀県高島市安曇川町西万木');
ok($zip->set_number('5201213')->is_valid_number, '滋賀県高島市安曇川町五番領');
ok($zip->set_number('5201214')->is_valid_number, '滋賀県高島市安曇川町末広');
ok($zip->set_number('5201215')->is_valid_number, '滋賀県高島市安曇川町三尾里');
ok($zip->set_number('5201216')->is_valid_number, '滋賀県高島市安曇川町中央');
ok($zip->set_number('5201217')->is_valid_number, '滋賀県高島市安曇川町田中');
ok($zip->set_number('5201221')->is_valid_number, '滋賀県高島市安曇川町青柳');
ok($zip->set_number('5201222')->is_valid_number, '滋賀県高島市安曇川町横江');
ok($zip->set_number('5201223')->is_valid_number, '滋賀県高島市安曇川町下小川');
ok($zip->set_number('5201224')->is_valid_number, '滋賀県高島市安曇川町上小川');
ok($zip->set_number('5201231')->is_valid_number, '滋賀県高島市安曇川町川島');
ok($zip->set_number('5201232')->is_valid_number, '滋賀県高島市安曇川町北船木');
ok($zip->set_number('5201233')->is_valid_number, '滋賀県高島市安曇川町南船木');
ok($zip->set_number('5201234')->is_valid_number, '滋賀県高島市安曇川町四津川');
ok($zip->set_number('5201235')->is_valid_number, '滋賀県高島市安曇川町横江浜');
ok($zip->set_number('5201401')->is_valid_number, '滋賀県高島市朽木市場');
ok($zip->set_number('5201411')->is_valid_number, '滋賀県高島市朽木荒川');
ok($zip->set_number('5201412')->is_valid_number, '滋賀県高島市朽木野尻');
ok($zip->set_number('5201413')->is_valid_number, '滋賀県高島市朽木上野');
ok($zip->set_number('5201414')->is_valid_number, '滋賀県高島市朽木宮前坊');
ok($zip->set_number('5201415')->is_valid_number, '滋賀県高島市朽木柏');
ok($zip->set_number('5201421')->is_valid_number, '滋賀県高島市朽木岩瀬');
ok($zip->set_number('5201422')->is_valid_number, '滋賀県高島市朽木古川');
ok($zip->set_number('5201423')->is_valid_number, '滋賀県高島市朽木大野');
ok($zip->set_number('5201424')->is_valid_number, '滋賀県高島市朽木村井');
ok($zip->set_number('5201425')->is_valid_number, '滋賀県高島市朽木栃生');
ok($zip->set_number('5201431')->is_valid_number, '滋賀県高島市朽木小川');
ok($zip->set_number('5201432')->is_valid_number, '滋賀県高島市朽木平良');
ok($zip->set_number('5201433')->is_valid_number, '滋賀県高島市朽木桑原');
ok($zip->set_number('5201441')->is_valid_number, '滋賀県高島市朽木古屋');
ok($zip->set_number('5201442')->is_valid_number, '滋賀県高島市朽木生杉');
ok($zip->set_number('5201443')->is_valid_number, '滋賀県高島市朽木小入谷');
ok($zip->set_number('5201444')->is_valid_number, '滋賀県高島市朽木中牧');
ok($zip->set_number('5201451')->is_valid_number, '滋賀県高島市朽木麻生');
ok($zip->set_number('5201452')->is_valid_number, '滋賀県高島市朽木地子原');
ok($zip->set_number('5201453')->is_valid_number, '滋賀県高島市朽木雲洞谷');
ok($zip->set_number('5201454')->is_valid_number, '滋賀県高島市朽木能家');
ok($zip->set_number('5201455')->is_valid_number, '滋賀県高島市朽木木地山');
ok($zip->set_number('5201501')->is_valid_number, '滋賀県高島市新旭町旭');
ok($zip->set_number('5201502')->is_valid_number, '滋賀県高島市新旭町針江');
ok($zip->set_number('5201503')->is_valid_number, '滋賀県高島市新旭町深溝');
ok($zip->set_number('5201511')->is_valid_number, '滋賀県高島市新旭町藁園');
ok($zip->set_number('5201512')->is_valid_number, '滋賀県高島市新旭町太田');
ok($zip->set_number('5201521')->is_valid_number, '滋賀県高島市新旭町北畑');
ok($zip->set_number('5201522')->is_valid_number, '滋賀県高島市新旭町新庄');
ok($zip->set_number('5201531')->is_valid_number, '滋賀県高島市新旭町饗庭');
ok($zip->set_number('5201532')->is_valid_number, '滋賀県高島市新旭町熊野本');
ok($zip->set_number('5201533')->is_valid_number, '滋賀県高島市新旭町安井川');
ok($zip->set_number('5201601')->is_valid_number, '滋賀県高島市今津町深清水');
ok($zip->set_number('5201602')->is_valid_number, '滋賀県高島市今津町桂');
ok($zip->set_number('5201603')->is_valid_number, '滋賀県高島市今津町北仰');
ok($zip->set_number('5201604')->is_valid_number, '滋賀県高島市今津町浜分');
ok($zip->set_number('5201605')->is_valid_number, '滋賀県高島市今津町南新保');
ok($zip->set_number('5201611')->is_valid_number, '滋賀県高島市今津町弘川');
ok($zip->set_number('5201612')->is_valid_number, '滋賀県高島市今津町下弘部');
ok($zip->set_number('5201613')->is_valid_number, '滋賀県高島市今津町上弘部');
ok($zip->set_number('5201614')->is_valid_number, '滋賀県高島市今津町藺生');
ok($zip->set_number('5201621')->is_valid_number, '滋賀県高島市今津町今津');
ok($zip->set_number('5201622')->is_valid_number, '滋賀県高島市今津町中沼');
ok($zip->set_number('5201623')->is_valid_number, '滋賀県高島市今津町住吉');
ok($zip->set_number('5201631')->is_valid_number, '滋賀県高島市今津町名小路');
ok($zip->set_number('5201632')->is_valid_number, '滋賀県高島市今津町桜町');
ok($zip->set_number('5201633')->is_valid_number, '滋賀県高島市今津町松陽台');
ok($zip->set_number('5201634')->is_valid_number, '滋賀県高島市今津町大供大門');
ok($zip->set_number('5201635')->is_valid_number, '滋賀県高島市今津町大供');
ok($zip->set_number('5201636')->is_valid_number, '滋賀県高島市今津町舟橋');
ok($zip->set_number('5201641')->is_valid_number, '滋賀県高島市今津町南生見');
ok($zip->set_number('5201642')->is_valid_number, '滋賀県高島市今津町北生見');
ok($zip->set_number('5201643')->is_valid_number, '滋賀県高島市今津町保坂');
ok($zip->set_number('5201644')->is_valid_number, '滋賀県高島市今津町途中谷');
ok($zip->set_number('5201645')->is_valid_number, '滋賀県高島市今津町椋川');
ok($zip->set_number('5201646')->is_valid_number, '滋賀県高島市今津町杉山');
ok($zip->set_number('5201647')->is_valid_number, '滋賀県高島市今津町天増川');
ok($zip->set_number('5201648')->is_valid_number, '滋賀県高島市今津町角川');
ok($zip->set_number('5201651')->is_valid_number, '滋賀県高島市今津町酒波');
ok($zip->set_number('5201652')->is_valid_number, '滋賀県高島市今津町福岡');
ok($zip->set_number('5201653')->is_valid_number, '滋賀県高島市今津町岸脇');
ok($zip->set_number('5201654')->is_valid_number, '滋賀県高島市今津町梅原');
ok($zip->set_number('5201655')->is_valid_number, '滋賀県高島市今津町日置前');
ok($zip->set_number('5201801')->is_valid_number, '滋賀県高島市マキノ町在原');
ok($zip->set_number('5201802')->is_valid_number, '滋賀県高島市マキノ町野口');
ok($zip->set_number('5201803')->is_valid_number, '滋賀県高島市マキノ町小荒路');
ok($zip->set_number('5201804')->is_valid_number, '滋賀県高島市マキノ町浦');
ok($zip->set_number('5201805')->is_valid_number, '滋賀県高島市マキノ町下');
ok($zip->set_number('5201806')->is_valid_number, '滋賀県高島市マキノ町山中');
ok($zip->set_number('5201811')->is_valid_number, '滋賀県高島市マキノ町海津');
ok($zip->set_number('5201812')->is_valid_number, '滋賀県高島市マキノ町西浜');
ok($zip->set_number('5201813')->is_valid_number, '滋賀県高島市マキノ町高木浜');
ok($zip->set_number('5201814')->is_valid_number, '滋賀県高島市マキノ町知内');
ok($zip->set_number('5201821')->is_valid_number, '滋賀県高島市マキノ町沢');
ok($zip->set_number('5201822')->is_valid_number, '滋賀県高島市マキノ町新保');
ok($zip->set_number('5201823')->is_valid_number, '滋賀県高島市マキノ町中庄');
ok($zip->set_number('5201824')->is_valid_number, '滋賀県高島市マキノ町大沼');
ok($zip->set_number('5201825')->is_valid_number, '滋賀県高島市マキノ町森西');
ok($zip->set_number('5201826')->is_valid_number, '滋賀県高島市マキノ町辻');
ok($zip->set_number('5201831')->is_valid_number, '滋賀県高島市マキノ町上開田');
ok($zip->set_number('5201832')->is_valid_number, '滋賀県高島市マキノ町下開田');
ok($zip->set_number('5201833')->is_valid_number, '滋賀県高島市マキノ町蛭口');
ok($zip->set_number('5201834')->is_valid_number, '滋賀県高島市マキノ町寺久保');
ok($zip->set_number('5201835')->is_valid_number, '滋賀県高島市マキノ町石庭');
ok($zip->set_number('5201836')->is_valid_number, '滋賀県高島市マキノ町牧野');
ok($zip->set_number('5201837')->is_valid_number, '滋賀県高島市マキノ町白谷');
ok($zip->set_number('5202101')->is_valid_number, '滋賀県大津市青山');
ok($zip->set_number('5202102')->is_valid_number, '滋賀県大津市松が丘');
ok($zip->set_number('5202111')->is_valid_number, '滋賀県大津市桐生');
ok($zip->set_number('5202112')->is_valid_number, '滋賀県大津市牧');
ok($zip->set_number('5202113')->is_valid_number, '滋賀県大津市平野');
ok($zip->set_number('5202114')->is_valid_number, '滋賀県大津市中野');
ok($zip->set_number('5202115')->is_valid_number, '滋賀県大津市新免');
ok($zip->set_number('5202116')->is_valid_number, '滋賀県大津市堂');
ok($zip->set_number('5202117')->is_valid_number, '滋賀県大津市芝原');
ok($zip->set_number('5202118')->is_valid_number, '滋賀県大津市大鳥居');
ok($zip->set_number('5202121')->is_valid_number, '滋賀県大津市瀬田月輪町');
ok($zip->set_number('5202122')->is_valid_number, '滋賀県大津市瀬田南大萱町');
ok($zip->set_number('5202123')->is_valid_number, '滋賀県大津市瀬田大江町');
ok($zip->set_number('5202124')->is_valid_number, '滋賀県大津市瀬田神領町');
ok($zip->set_number('5202125')->is_valid_number, '滋賀県大津市瀬田橋本町');
ok($zip->set_number('5202131')->is_valid_number, '滋賀県大津市三大寺');
ok($zip->set_number('5202132')->is_valid_number, '滋賀県大津市神領');
ok($zip->set_number('5202133')->is_valid_number, '滋賀県大津市野郷原');
ok($zip->set_number('5202134')->is_valid_number, '滋賀県大津市瀬田');
ok($zip->set_number('5202135')->is_valid_number, '滋賀県大津市松陽');
ok($zip->set_number('5202141')->is_valid_number, '滋賀県大津市大江');
ok($zip->set_number('5202142')->is_valid_number, '滋賀県大津市玉野浦');
ok($zip->set_number('5202143')->is_valid_number, '滋賀県大津市萱野浦');
ok($zip->set_number('5202144')->is_valid_number, '滋賀県大津市大萱');
ok($zip->set_number('5202145')->is_valid_number, '滋賀県大津市大将軍');
ok($zip->set_number('5202151')->is_valid_number, '滋賀県大津市栗林町');
ok($zip->set_number('5202152')->is_valid_number, '滋賀県大津市月輪');
ok($zip->set_number('5202153')->is_valid_number, '滋賀県大津市一里山');
ok($zip->set_number('5202161')->is_valid_number, '滋賀県大津市上田上桐生町');
ok($zip->set_number('5202162')->is_valid_number, '滋賀県大津市上田上牧町');
ok($zip->set_number('5202163')->is_valid_number, '滋賀県大津市上田上平野町');
ok($zip->set_number('5202164')->is_valid_number, '滋賀県大津市上田上中野町');
ok($zip->set_number('5202165')->is_valid_number, '滋賀県大津市上田上新免町');
ok($zip->set_number('5202166')->is_valid_number, '滋賀県大津市上田上堂町');
ok($zip->set_number('5202167')->is_valid_number, '滋賀県大津市上田上芝原町');
ok($zip->set_number('5202261')->is_valid_number, '滋賀県大津市大石曽束');
ok($zip->set_number('5202261')->is_valid_number, '滋賀県大津市大石曽束町');
ok($zip->set_number('5202262')->is_valid_number, '滋賀県大津市大石淀');
ok($zip->set_number('5202262')->is_valid_number, '滋賀県大津市大石淀町');
ok($zip->set_number('5202263')->is_valid_number, '滋賀県大津市大石中');
ok($zip->set_number('5202264')->is_valid_number, '滋賀県大津市大石東');
ok($zip->set_number('5202265')->is_valid_number, '滋賀県大津市大石富川');
ok($zip->set_number('5202265')->is_valid_number, '滋賀県大津市大石富川町');
ok($zip->set_number('5202266')->is_valid_number, '滋賀県大津市大石龍門');
ok($zip->set_number('5202267')->is_valid_number, '滋賀県大津市大石小田原');
ok($zip->set_number('5202267')->is_valid_number, '滋賀県大津市大石小田原町');
ok($zip->set_number('5202271')->is_valid_number, '滋賀県大津市稲津');
ok($zip->set_number('5202272')->is_valid_number, '滋賀県大津市石居');
ok($zip->set_number('5202273')->is_valid_number, '滋賀県大津市羽栗');
ok($zip->set_number('5202274')->is_valid_number, '滋賀県大津市森');
ok($zip->set_number('5202275')->is_valid_number, '滋賀県大津市枝');
ok($zip->set_number('5202276')->is_valid_number, '滋賀県大津市里');
ok($zip->set_number('5202277')->is_valid_number, '滋賀県大津市関津');
ok($zip->set_number('5202278')->is_valid_number, '滋賀県大津市太子');
ok($zip->set_number('5202279')->is_valid_number, '滋賀県大津市黒津');
ok($zip->set_number('5202300')->is_valid_number, '滋賀県野洲市以下に掲載がない場合');
ok($zip->set_number('5202301')->is_valid_number, '滋賀県野洲市小南');
ok($zip->set_number('5202302')->is_valid_number, '滋賀県野洲市高木');
ok($zip->set_number('5202303')->is_valid_number, '滋賀県野洲市中北');
ok($zip->set_number('5202304')->is_valid_number, '滋賀県野洲市永原');
ok($zip->set_number('5202305')->is_valid_number, '滋賀県野洲市北');
ok($zip->set_number('5202311')->is_valid_number, '滋賀県野洲市長島');
ok($zip->set_number('5202312')->is_valid_number, '滋賀県野洲市入町');
ok($zip->set_number('5202313')->is_valid_number, '滋賀県野洲市大篠原');
ok($zip->set_number('5202314')->is_valid_number, '滋賀県野洲市小堤');
ok($zip->set_number('5202315')->is_valid_number, '滋賀県野洲市辻町');
ok($zip->set_number('5202316')->is_valid_number, '滋賀県野洲市上屋');
ok($zip->set_number('5202321')->is_valid_number, '滋賀県野洲市北桜');
ok($zip->set_number('5202322')->is_valid_number, '滋賀県野洲市南桜');
ok($zip->set_number('5202323')->is_valid_number, '滋賀県野洲市三上');
ok($zip->set_number('5202324')->is_valid_number, '滋賀県野洲市近江富士');
ok($zip->set_number('5202331')->is_valid_number, '滋賀県野洲市小篠原');
ok($zip->set_number('5202332')->is_valid_number, '滋賀県野洲市妙光寺');
ok($zip->set_number('5202333')->is_valid_number, '滋賀県野洲市栄');
ok($zip->set_number('5202341')->is_valid_number, '滋賀県野洲市行畑');
ok($zip->set_number('5202342')->is_valid_number, '滋賀県野洲市野洲');
ok($zip->set_number('5202343')->is_valid_number, '滋賀県野洲市大畑');
ok($zip->set_number('5202351')->is_valid_number, '滋賀県野洲市冨波甲');
ok($zip->set_number('5202352')->is_valid_number, '滋賀県野洲市冨波乙');
ok($zip->set_number('5202353')->is_valid_number, '滋賀県野洲市久野部');
ok($zip->set_number('5202361')->is_valid_number, '滋賀県野洲市北野');
ok($zip->set_number('5202362')->is_valid_number, '滋賀県野洲市市三宅');
ok($zip->set_number('5202363')->is_valid_number, '滋賀県野洲市竹生');
ok($zip->set_number('5202364')->is_valid_number, '滋賀県野洲市五之里');
ok($zip->set_number('5202365')->is_valid_number, '滋賀県野洲市竹ヶ丘');
ok($zip->set_number('5202401')->is_valid_number, '滋賀県野洲市吉川');
ok($zip->set_number('5202402')->is_valid_number, '滋賀県野洲市菖蒲');
ok($zip->set_number('5202403')->is_valid_number, '滋賀県野洲市喜合');
ok($zip->set_number('5202411')->is_valid_number, '滋賀県野洲市安治');
ok($zip->set_number('5202412')->is_valid_number, '滋賀県野洲市六条');
ok($zip->set_number('5202413')->is_valid_number, '滋賀県野洲市吉地');
ok($zip->set_number('5202414')->is_valid_number, '滋賀県野洲市井口');
ok($zip->set_number('5202415')->is_valid_number, '滋賀県野洲市須原');
ok($zip->set_number('5202416')->is_valid_number, '滋賀県野洲市堤');
ok($zip->set_number('5202417')->is_valid_number, '滋賀県野洲市下堤');
ok($zip->set_number('5202421')->is_valid_number, '滋賀県野洲市野田');
ok($zip->set_number('5202422')->is_valid_number, '滋賀県野洲市比留田');
ok($zip->set_number('5202423')->is_valid_number, '滋賀県野洲市西河原');
ok($zip->set_number('5202424')->is_valid_number, '滋賀県野洲市五条');
ok($zip->set_number('5202431')->is_valid_number, '滋賀県野洲市木部');
ok($zip->set_number('5202432')->is_valid_number, '滋賀県野洲市虫生');
ok($zip->set_number('5202433')->is_valid_number, '滋賀県野洲市八夫');
ok($zip->set_number('5202434')->is_valid_number, '滋賀県野洲市比江');
ok($zip->set_number('5202435')->is_valid_number, '滋賀県野洲市乙窪');
ok($zip->set_number('5202436')->is_valid_number, '滋賀県野洲市北比江');
ok($zip->set_number('5202437')->is_valid_number, '滋賀県野洲市小比江');
ok($zip->set_number('5202500')->is_valid_number, '滋賀県蒲生郡竜王町以下に掲載がない場合');
ok($zip->set_number('5202501')->is_valid_number, '滋賀県蒲生郡竜王町弓削');
ok($zip->set_number('5202502')->is_valid_number, '滋賀県蒲生郡竜王町庄');
ok($zip->set_number('5202503')->is_valid_number, '滋賀県蒲生郡竜王町信濃');
ok($zip->set_number('5202504')->is_valid_number, '滋賀県蒲生郡竜王町川上');
ok($zip->set_number('5202511')->is_valid_number, '滋賀県蒲生郡竜王町林');
ok($zip->set_number('5202512')->is_valid_number, '滋賀県蒲生郡竜王町駕輿丁');
ok($zip->set_number('5202513')->is_valid_number, '滋賀県蒲生郡竜王町島');
ok($zip->set_number('5202514')->is_valid_number, '滋賀県蒲生郡竜王町橋本');
ok($zip->set_number('5202521')->is_valid_number, '滋賀県蒲生郡竜王町川守');
ok($zip->set_number('5202522')->is_valid_number, '滋賀県蒲生郡竜王町岩井');
ok($zip->set_number('5202523')->is_valid_number, '滋賀県蒲生郡竜王町田中');
ok($zip->set_number('5202524')->is_valid_number, '滋賀県蒲生郡竜王町綾戸');
ok($zip->set_number('5202531')->is_valid_number, '滋賀県蒲生郡竜王町山之上');
ok($zip->set_number('5202541')->is_valid_number, '滋賀県蒲生郡竜王町岡屋');
ok($zip->set_number('5202542')->is_valid_number, '滋賀県蒲生郡竜王町山中');
ok($zip->set_number('5202551')->is_valid_number, '滋賀県蒲生郡竜王町薬師');
ok($zip->set_number('5202552')->is_valid_number, '滋賀県蒲生郡竜王町小口');
ok($zip->set_number('5202561')->is_valid_number, '滋賀県蒲生郡竜王町須恵');
ok($zip->set_number('5202562')->is_valid_number, '滋賀県蒲生郡竜王町鵜川');
ok($zip->set_number('5202563')->is_valid_number, '滋賀県蒲生郡竜王町七里');
ok($zip->set_number('5202564')->is_valid_number, '滋賀県蒲生郡竜王町山面');
ok($zip->set_number('5202571')->is_valid_number, '滋賀県蒲生郡竜王町西横関');
ok($zip->set_number('5202572')->is_valid_number, '滋賀県蒲生郡竜王町西川');
ok($zip->set_number('5202573')->is_valid_number, '滋賀県蒲生郡竜王町鏡');
ok($zip->set_number('5203000')->is_valid_number, '滋賀県栗東市以下に掲載がない場合');
ok($zip->set_number('5203001')->is_valid_number, '滋賀県栗東市東坂');
ok($zip->set_number('5203002')->is_valid_number, '滋賀県栗東市観音寺');
ok($zip->set_number('5203003')->is_valid_number, '滋賀県栗東市荒張');
ok($zip->set_number('5203004')->is_valid_number, '滋賀県栗東市上砥山');
ok($zip->set_number('5203005')->is_valid_number, '滋賀県栗東市御園');
ok($zip->set_number('5203006')->is_valid_number, '滋賀県栗東市井上');
ok($zip->set_number('5203011')->is_valid_number, '滋賀県栗東市下戸山');
ok($zip->set_number('5203012')->is_valid_number, '滋賀県栗東市岡');
ok($zip->set_number('5203013')->is_valid_number, '滋賀県栗東市目川');
ok($zip->set_number('5203014')->is_valid_number, '滋賀県栗東市川辺');
ok($zip->set_number('5203015')->is_valid_number, '滋賀県栗東市安養寺');
ok($zip->set_number('5203016')->is_valid_number, '滋賀県栗東市小野');
ok($zip->set_number('5203017')->is_valid_number, '滋賀県栗東市六地蔵');
ok($zip->set_number('5203021')->is_valid_number, '滋賀県栗東市蜂屋');
ok($zip->set_number('5203022')->is_valid_number, '滋賀県栗東市上鈎');
ok($zip->set_number('5203023')->is_valid_number, '滋賀県栗東市坊袋');
ok($zip->set_number('5203024')->is_valid_number, '滋賀県栗東市小柿');
ok($zip->set_number('5203025')->is_valid_number, '滋賀県栗東市中沢');
ok($zip->set_number('5203026')->is_valid_number, '滋賀県栗東市下鈎');
ok($zip->set_number('5203027')->is_valid_number, '滋賀県栗東市野尻');
ok($zip->set_number('5203031')->is_valid_number, '滋賀県栗東市綣');
ok($zip->set_number('5203032')->is_valid_number, '滋賀県栗東市苅原');
ok($zip->set_number('5203033')->is_valid_number, '滋賀県栗東市笠川');
ok($zip->set_number('5203034')->is_valid_number, '滋賀県栗東市小平井');
ok($zip->set_number('5203035')->is_valid_number, '滋賀県栗東市霊仙寺');
ok($zip->set_number('5203036')->is_valid_number, '滋賀県栗東市十里');
ok($zip->set_number('5203037')->is_valid_number, '滋賀県栗東市北中小路');
ok($zip->set_number('5203041')->is_valid_number, '滋賀県栗東市出庭');
ok($zip->set_number('5203042')->is_valid_number, '滋賀県栗東市辻');
ok($zip->set_number('5203043')->is_valid_number, '滋賀県栗東市林');
ok($zip->set_number('5203044')->is_valid_number, '滋賀県栗東市伊勢落');
ok($zip->set_number('5203045')->is_valid_number, '滋賀県栗東市高野');
ok($zip->set_number('5203046')->is_valid_number, '滋賀県栗東市大橋');
ok($zip->set_number('5203047')->is_valid_number, '滋賀県栗東市手原');
ok($zip->set_number('5203101')->is_valid_number, '滋賀県湖南市石部');
ok($zip->set_number('5203102')->is_valid_number, '滋賀県湖南市宮の森');
ok($zip->set_number('5203103')->is_valid_number, '滋賀県湖南市宝来坂');
ok($zip->set_number('5203104')->is_valid_number, '滋賀県湖南市岡出');
ok($zip->set_number('5203105')->is_valid_number, '滋賀県湖南市石部西');
ok($zip->set_number('5203106')->is_valid_number, '滋賀県湖南市石部中央');
ok($zip->set_number('5203107')->is_valid_number, '滋賀県湖南市石部東');
ok($zip->set_number('5203108')->is_valid_number, '滋賀県湖南市石部南');
ok($zip->set_number('5203109')->is_valid_number, '滋賀県湖南市石部が丘');
ok($zip->set_number('5203111')->is_valid_number, '滋賀県湖南市東寺');
ok($zip->set_number('5203112')->is_valid_number, '滋賀県湖南市丸山');
ok($zip->set_number('5203113')->is_valid_number, '滋賀県湖南市石部北');
ok($zip->set_number('5203114')->is_valid_number, '滋賀県湖南市石部口');
ok($zip->set_number('5203115')->is_valid_number, '滋賀県湖南市石部緑台');
ok($zip->set_number('5203116')->is_valid_number, '滋賀県湖南市雨山');
ok($zip->set_number('5203121')->is_valid_number, '滋賀県湖南市西寺');
ok($zip->set_number('5203200')->is_valid_number, '滋賀県湖南市以下に掲載がない場合');
ok($zip->set_number('5203201')->is_valid_number, '滋賀県湖南市下田');
ok($zip->set_number('5203202')->is_valid_number, '滋賀県湖南市西峰町');
ok($zip->set_number('5203203')->is_valid_number, '滋賀県湖南市日枝町');
ok($zip->set_number('5203211')->is_valid_number, '滋賀県湖南市高松町');
ok($zip->set_number('5203212')->is_valid_number, '滋賀県湖南市小砂町');
ok($zip->set_number('5203213')->is_valid_number, '滋賀県湖南市大池町');
ok($zip->set_number('5203214')->is_valid_number, '滋賀県湖南市梅影町');
ok($zip->set_number('5203215')->is_valid_number, '滋賀県湖南市水戸町');
ok($zip->set_number('5203216')->is_valid_number, '滋賀県湖南市若竹町');
ok($zip->set_number('5203221')->is_valid_number, '滋賀県湖南市三雲');
ok($zip->set_number('5203222')->is_valid_number, '滋賀県湖南市吉永');
ok($zip->set_number('5203223')->is_valid_number, '滋賀県湖南市夏見');
ok($zip->set_number('5203231')->is_valid_number, '滋賀県湖南市針');
ok($zip->set_number('5203232')->is_valid_number, '滋賀県湖南市平松');
ok($zip->set_number('5203233')->is_valid_number, '滋賀県湖南市柑子袋');
ok($zip->set_number('5203234')->is_valid_number, '滋賀県湖南市中央');
ok($zip->set_number('5203235')->is_valid_number, '滋賀県湖南市平松北');
ok($zip->set_number('5203236')->is_valid_number, '滋賀県湖南市柑子袋東');
ok($zip->set_number('5203237')->is_valid_number, '滋賀県湖南市柑子袋西');
ok($zip->set_number('5203241')->is_valid_number, '滋賀県湖南市北山台');
ok($zip->set_number('5203242')->is_valid_number, '滋賀県湖南市菩提寺');
ok($zip->set_number('5203244')->is_valid_number, '滋賀県湖南市サイドタウン');
ok($zip->set_number('5203245')->is_valid_number, '滋賀県湖南市近江台');
ok($zip->set_number('5203246')->is_valid_number, '滋賀県湖南市菩提寺北');
ok($zip->set_number('5203247')->is_valid_number, '滋賀県湖南市菩提寺東');
ok($zip->set_number('5203248')->is_valid_number, '滋賀県湖南市菩提寺西');
ok($zip->set_number('5203251')->is_valid_number, '滋賀県湖南市朝国');
ok($zip->set_number('5203252')->is_valid_number, '滋賀県湖南市岩根');
ok($zip->set_number('5203253')->is_valid_number, '滋賀県湖南市正福寺');
ok($zip->set_number('5203254')->is_valid_number, '滋賀県湖南市岩根中央');
ok($zip->set_number('5203255')->is_valid_number, '滋賀県湖南市日枝山手台');
ok($zip->set_number('5203256')->is_valid_number, '滋賀県湖南市日枝あおい');
ok($zip->set_number('5203301')->is_valid_number, '滋賀県甲賀市甲南町寺庄');
ok($zip->set_number('5203302')->is_valid_number, '滋賀県甲賀市甲南町池田');
ok($zip->set_number('5203303')->is_valid_number, '滋賀県甲賀市甲南町上馬杉');
ok($zip->set_number('5203304')->is_valid_number, '滋賀県甲賀市甲南町下馬杉');
ok($zip->set_number('5203305')->is_valid_number, '滋賀県甲賀市甲南町野川');
ok($zip->set_number('5203306')->is_valid_number, '滋賀県甲賀市甲南町柑子');
ok($zip->set_number('5203307')->is_valid_number, '滋賀県甲賀市甲南町野尻');
ok($zip->set_number('5203308')->is_valid_number, '滋賀県甲賀市甲南町野田');
ok($zip->set_number('5203311')->is_valid_number, '滋賀県甲賀市甲南町竜法師');
ok($zip->set_number('5203312')->is_valid_number, '滋賀県甲賀市甲南町磯尾');
ok($zip->set_number('5203313')->is_valid_number, '滋賀県甲賀市甲南町新治');
ok($zip->set_number('5203314')->is_valid_number, '滋賀県甲賀市甲南町杉谷');
ok($zip->set_number('5203315')->is_valid_number, '滋賀県甲賀市甲南町塩野');
ok($zip->set_number('5203316')->is_valid_number, '滋賀県甲賀市甲南町市原');
ok($zip->set_number('5203321')->is_valid_number, '滋賀県甲賀市甲南町葛木');
ok($zip->set_number('5203322')->is_valid_number, '滋賀県甲賀市甲南町深川');
ok($zip->set_number('5203323')->is_valid_number, '滋賀県甲賀市甲南町深川市場');
ok($zip->set_number('5203324')->is_valid_number, '滋賀県甲賀市甲南町森尻');
ok($zip->set_number('5203325')->is_valid_number, '滋賀県甲賀市甲南町宝木');
ok($zip->set_number('5203326')->is_valid_number, '滋賀県甲賀市甲南町耕心');
ok($zip->set_number('5203331')->is_valid_number, '滋賀県甲賀市甲南町稗谷');
ok($zip->set_number('5203332')->is_valid_number, '滋賀県甲賀市甲南町希望ケ丘本町');
ok($zip->set_number('5203333')->is_valid_number, '滋賀県甲賀市甲南町希望ケ丘');
ok($zip->set_number('5203401')->is_valid_number, '滋賀県甲賀市甲賀町岩室');
ok($zip->set_number('5203402')->is_valid_number, '滋賀県甲賀市甲賀町小佐治');
ok($zip->set_number('5203403')->is_valid_number, '滋賀県甲賀市甲賀町鳥居野');
ok($zip->set_number('5203404')->is_valid_number, '滋賀県甲賀市甲賀町神保');
ok($zip->set_number('5203405')->is_valid_number, '滋賀県甲賀市甲賀町隠岐');
ok($zip->set_number('5203411')->is_valid_number, '滋賀県甲賀市甲賀町神');
ok($zip->set_number('5203412')->is_valid_number, '滋賀県甲賀市甲賀町櫟野');
ok($zip->set_number('5203413')->is_valid_number, '滋賀県甲賀市甲賀町油日');
ok($zip->set_number('5203414')->is_valid_number, '滋賀県甲賀市甲賀町大久保');
ok($zip->set_number('5203415')->is_valid_number, '滋賀県甲賀市甲賀町大原上田');
ok($zip->set_number('5203421')->is_valid_number, '滋賀県甲賀市甲賀町上野');
ok($zip->set_number('5203422')->is_valid_number, '滋賀県甲賀市甲賀町和田');
ok($zip->set_number('5203423')->is_valid_number, '滋賀県甲賀市甲賀町五反田');
ok($zip->set_number('5203424')->is_valid_number, '滋賀県甲賀市甲賀町高嶺');
ok($zip->set_number('5203425')->is_valid_number, '滋賀県甲賀市甲賀町毛枚');
ok($zip->set_number('5203426')->is_valid_number, '滋賀県甲賀市甲賀町田堵野');
ok($zip->set_number('5203427')->is_valid_number, '滋賀県甲賀市甲賀町鹿深台');
ok($zip->set_number('5203431')->is_valid_number, '滋賀県甲賀市甲賀町大原中');
ok($zip->set_number('5203432')->is_valid_number, '滋賀県甲賀市甲賀町滝');
ok($zip->set_number('5203433')->is_valid_number, '滋賀県甲賀市甲賀町大原市場');
ok($zip->set_number('5203434')->is_valid_number, '滋賀県甲賀市甲賀町高野');
ok($zip->set_number('5203435')->is_valid_number, '滋賀県甲賀市甲賀町相模');
ok($zip->set_number('5203436')->is_valid_number, '滋賀県甲賀市甲賀町拝坂');
ok($zip->set_number('5210000')->is_valid_number, '滋賀県米原市以下に掲載がない場合');
ok($zip->set_number('5210001')->is_valid_number, '滋賀県米原市朝妻筑摩');
ok($zip->set_number('5210002')->is_valid_number, '滋賀県米原市上多良');
ok($zip->set_number('5210003')->is_valid_number, '滋賀県米原市入江');
ok($zip->set_number('5210004')->is_valid_number, '滋賀県米原市磯');
ok($zip->set_number('5210011')->is_valid_number, '滋賀県米原市中多良');
ok($zip->set_number('5210012')->is_valid_number, '滋賀県米原市米原');
ok($zip->set_number('5210013')->is_valid_number, '滋賀県米原市梅ケ原');
ok($zip->set_number('5210014')->is_valid_number, '滋賀県米原市梅ケ原栄');
ok($zip->set_number('5210015')->is_valid_number, '滋賀県米原市米原西');
ok($zip->set_number('5210016')->is_valid_number, '滋賀県米原市下多良');
ok($zip->set_number('5210021')->is_valid_number, '滋賀県米原市河南');
ok($zip->set_number('5210022')->is_valid_number, '滋賀県米原市樋口');
ok($zip->set_number('5210023')->is_valid_number, '滋賀県米原市三吉');
ok($zip->set_number('5210024')->is_valid_number, '滋賀県米原市西坂');
ok($zip->set_number('5210025')->is_valid_number, '滋賀県米原市番場');
ok($zip->set_number('5210031')->is_valid_number, '滋賀県米原市一色');
ok($zip->set_number('5210032')->is_valid_number, '滋賀県米原市枝折');
ok($zip->set_number('5210033')->is_valid_number, '滋賀県米原市上丹生');
ok($zip->set_number('5210034')->is_valid_number, '滋賀県米原市下丹生');
ok($zip->set_number('5210035')->is_valid_number, '滋賀県米原市醒井');
ok($zip->set_number('5210061')->is_valid_number, '滋賀県米原市長沢');
ok($zip->set_number('5210062')->is_valid_number, '滋賀県米原市宇賀野');
ok($zip->set_number('5210063')->is_valid_number, '滋賀県米原市飯');
ok($zip->set_number('5210064')->is_valid_number, '滋賀県米原市世継');
ok($zip->set_number('5210071')->is_valid_number, '滋賀県米原市舟崎');
ok($zip->set_number('5210072')->is_valid_number, '滋賀県米原市顔戸');
ok($zip->set_number('5210073')->is_valid_number, '滋賀県米原市箕浦');
ok($zip->set_number('5210074')->is_valid_number, '滋賀県米原市高溝');
ok($zip->set_number('5210081')->is_valid_number, '滋賀県米原市多和田');
ok($zip->set_number('5210082')->is_valid_number, '滋賀県米原市能登瀬');
ok($zip->set_number('5210083')->is_valid_number, '滋賀県米原市新庄');
ok($zip->set_number('5210084')->is_valid_number, '滋賀県米原市日光寺');
ok($zip->set_number('5210091')->is_valid_number, '滋賀県米原市岩脇');
ok($zip->set_number('5210092')->is_valid_number, '滋賀県米原市西円寺');
ok($zip->set_number('5210093')->is_valid_number, '滋賀県米原市寺倉');
ok($zip->set_number('5210201')->is_valid_number, '滋賀県米原市長久寺');
ok($zip->set_number('5210202')->is_valid_number, '滋賀県米原市柏原');
ok($zip->set_number('5210203')->is_valid_number, '滋賀県米原市清滝');
ok($zip->set_number('5210211')->is_valid_number, '滋賀県米原市梓河内');
ok($zip->set_number('5210212')->is_valid_number, '滋賀県米原市本郷');
ok($zip->set_number('5210213')->is_valid_number, '滋賀県米原市堂谷');
ok($zip->set_number('5210214')->is_valid_number, '滋賀県米原市大鹿');
ok($zip->set_number('5210215')->is_valid_number, '滋賀県米原市山室');
ok($zip->set_number('5210216')->is_valid_number, '滋賀県米原市菅江');
ok($zip->set_number('5210217')->is_valid_number, '滋賀県米原市北方');
ok($zip->set_number('5210218')->is_valid_number, '滋賀県米原市志賀谷');
ok($zip->set_number('5210219')->is_valid_number, '滋賀県米原市加勢野');
ok($zip->set_number('5210221')->is_valid_number, '滋賀県米原市池下');
ok($zip->set_number('5210222')->is_valid_number, '滋賀県米原市天満');
ok($zip->set_number('5210223')->is_valid_number, '滋賀県米原市本市場');
ok($zip->set_number('5210224')->is_valid_number, '滋賀県米原市夫馬');
ok($zip->set_number('5210225')->is_valid_number, '滋賀県米原市市場');
ok($zip->set_number('5210226')->is_valid_number, '滋賀県米原市朝日');
ok($zip->set_number('5210227')->is_valid_number, '滋賀県米原市烏脇');
ok($zip->set_number('5210231')->is_valid_number, '滋賀県米原市村居田');
ok($zip->set_number('5210232')->is_valid_number, '滋賀県米原市坂口');
ok($zip->set_number('5210233')->is_valid_number, '滋賀県米原市野一色');
ok($zip->set_number('5210234')->is_valid_number, '滋賀県米原市井之口');
ok($zip->set_number('5210235')->is_valid_number, '滋賀県米原市小田');
ok($zip->set_number('5210236')->is_valid_number, '滋賀県米原市間田');
ok($zip->set_number('5210241')->is_valid_number, '滋賀県米原市西山');
ok($zip->set_number('5210242')->is_valid_number, '滋賀県米原市長岡');
ok($zip->set_number('5210243')->is_valid_number, '滋賀県米原市万願寺');
ok($zip->set_number('5210244')->is_valid_number, '滋賀県米原市大野木');
ok($zip->set_number('5210245')->is_valid_number, '滋賀県米原市須川');
ok($zip->set_number('5210301')->is_valid_number, '滋賀県米原市甲津原');
ok($zip->set_number('5210302')->is_valid_number, '滋賀県米原市曲谷');
ok($zip->set_number('5210303')->is_valid_number, '滋賀県米原市甲賀');
ok($zip->set_number('5210304')->is_valid_number, '滋賀県米原市吉槻');
ok($zip->set_number('5210305')->is_valid_number, '滋賀県米原市上板並');
ok($zip->set_number('5210306')->is_valid_number, '滋賀県米原市下板並');
ok($zip->set_number('5210307')->is_valid_number, '滋賀県米原市大久保');
ok($zip->set_number('5210308')->is_valid_number, '滋賀県米原市小泉');
ok($zip->set_number('5210311')->is_valid_number, '滋賀県米原市伊吹');
ok($zip->set_number('5210312')->is_valid_number, '滋賀県米原市上野');
ok($zip->set_number('5210313')->is_valid_number, '滋賀県米原市弥高');
ok($zip->set_number('5210314')->is_valid_number, '滋賀県米原市春照');
ok($zip->set_number('5210321')->is_valid_number, '滋賀県米原市高番');
ok($zip->set_number('5210322')->is_valid_number, '滋賀県米原市杉沢');
ok($zip->set_number('5210323')->is_valid_number, '滋賀県米原市村木');
ok($zip->set_number('5210324')->is_valid_number, '滋賀県米原市大清水');
ok($zip->set_number('5210325')->is_valid_number, '滋賀県米原市藤川');
ok($zip->set_number('5210326')->is_valid_number, '滋賀県米原市寺林');
ok($zip->set_number('5210327')->is_valid_number, '滋賀県米原市上平寺');
ok($zip->set_number('5211101')->is_valid_number, '滋賀県彦根市石寺町');
ok($zip->set_number('5211102')->is_valid_number, '滋賀県彦根市下岡部町');
ok($zip->set_number('5211103')->is_valid_number, '滋賀県彦根市上岡部町');
ok($zip->set_number('5211104')->is_valid_number, '滋賀県彦根市出路町');
ok($zip->set_number('5211105')->is_valid_number, '滋賀県彦根市田原町');
ok($zip->set_number('5211111')->is_valid_number, '滋賀県彦根市稲里町');
ok($zip->set_number('5211112')->is_valid_number, '滋賀県彦根市金沢町');
ok($zip->set_number('5211113')->is_valid_number, '滋賀県彦根市稲部町');
ok($zip->set_number('5211114')->is_valid_number, '滋賀県彦根市彦富町');
ok($zip->set_number('5211115')->is_valid_number, '滋賀県彦根市金田町');
ok($zip->set_number('5211121')->is_valid_number, '滋賀県彦根市海瀬町');
ok($zip->set_number('5211122')->is_valid_number, '滋賀県彦根市三津町');
ok($zip->set_number('5211123')->is_valid_number, '滋賀県彦根市肥田町');
ok($zip->set_number('5211124')->is_valid_number, '滋賀県彦根市野良田町');
ok($zip->set_number('5211125')->is_valid_number, '滋賀県彦根市稲枝町');
ok($zip->set_number('5211126')->is_valid_number, '滋賀県彦根市服部町');
ok($zip->set_number('5211131')->is_valid_number, '滋賀県彦根市上稲葉町');
ok($zip->set_number('5211132')->is_valid_number, '滋賀県彦根市下稲葉町');
ok($zip->set_number('5211133')->is_valid_number, '滋賀県彦根市本庄町');
ok($zip->set_number('5211134')->is_valid_number, '滋賀県彦根市田附町');
ok($zip->set_number('5211135')->is_valid_number, '滋賀県彦根市新海町');
ok($zip->set_number('5211136')->is_valid_number, '滋賀県彦根市新海浜');
ok($zip->set_number('5211141')->is_valid_number, '滋賀県彦根市甲崎町');
ok($zip->set_number('5211142')->is_valid_number, '滋賀県彦根市下西川町');
ok($zip->set_number('5211143')->is_valid_number, '滋賀県彦根市上西川町');
ok($zip->set_number('5211144')->is_valid_number, '滋賀県彦根市普光寺町');
ok($zip->set_number('5211145')->is_valid_number, '滋賀県彦根市南三ツ谷町');
ok($zip->set_number('5211146')->is_valid_number, '滋賀県彦根市柳川町');
ok($zip->set_number('5211147')->is_valid_number, '滋賀県彦根市薩摩町');
ok($zip->set_number('5211201')->is_valid_number, '滋賀県東近江市新宮町');
ok($zip->set_number('5211202')->is_valid_number, '滋賀県東近江市阿弥陀堂町');
ok($zip->set_number('5211203')->is_valid_number, '滋賀県東近江市川南町');
ok($zip->set_number('5211204')->is_valid_number, '滋賀県東近江市小川町');
ok($zip->set_number('5211205')->is_valid_number, '滋賀県東近江市躰光寺町');
ok($zip->set_number('5211211')->is_valid_number, '滋賀県東近江市今町');
ok($zip->set_number('5211212')->is_valid_number, '滋賀県東近江市種町');
ok($zip->set_number('5211213')->is_valid_number, '滋賀県東近江市神郷町');
ok($zip->set_number('5211214')->is_valid_number, '滋賀県東近江市長勝寺町');
ok($zip->set_number('5211215')->is_valid_number, '滋賀県東近江市佐生町');
ok($zip->set_number('5211221')->is_valid_number, '滋賀県東近江市垣見町');
ok($zip->set_number('5211222')->is_valid_number, '滋賀県東近江市佐野町');
ok($zip->set_number('5211223')->is_valid_number, '滋賀県東近江市猪子町');
ok($zip->set_number('5211224')->is_valid_number, '滋賀県東近江市林町');
ok($zip->set_number('5211225')->is_valid_number, '滋賀県東近江市山路町');
ok($zip->set_number('5211231')->is_valid_number, '滋賀県東近江市能登川町');
ok($zip->set_number('5211232')->is_valid_number, '滋賀県東近江市北須田町');
ok($zip->set_number('5211233')->is_valid_number, '滋賀県東近江市南須田町');
ok($zip->set_number('5211234')->is_valid_number, '滋賀県東近江市きぬがさ町');
ok($zip->set_number('5211235')->is_valid_number, '滋賀県東近江市伊庭町');
ok($zip->set_number('5211241')->is_valid_number, '滋賀県東近江市乙女浜町');
ok($zip->set_number('5211242')->is_valid_number, '滋賀県東近江市福堂町');
ok($zip->set_number('5211243')->is_valid_number, '滋賀県東近江市栗見新田町');
ok($zip->set_number('5211244')->is_valid_number, '滋賀県東近江市大中町');
ok($zip->set_number('5211245')->is_valid_number, '滋賀県東近江市栗見出在家町');
ok($zip->set_number('5211301')->is_valid_number, '滋賀県近江八幡市安土町大中');
ok($zip->set_number('5211311')->is_valid_number, '滋賀県近江八幡市安土町下豊浦');
ok($zip->set_number('5211321')->is_valid_number, '滋賀県近江八幡市安土町桑実寺');
ok($zip->set_number('5211322')->is_valid_number, '滋賀県近江八幡市安土町宮津');
ok($zip->set_number('5211331')->is_valid_number, '滋賀県近江八幡市安土町石寺');
ok($zip->set_number('5211332')->is_valid_number, '滋賀県近江八幡市安土町東老蘇');
ok($zip->set_number('5211333')->is_valid_number, '滋賀県近江八幡市安土町内野');
ok($zip->set_number('5211334')->is_valid_number, '滋賀県近江八幡市安土町西老蘇');
ok($zip->set_number('5211341')->is_valid_number, '滋賀県近江八幡市安土町上豊浦');
ok($zip->set_number('5211342')->is_valid_number, '滋賀県近江八幡市安土町上出');
ok($zip->set_number('5211343')->is_valid_number, '滋賀県近江八幡市安土町小中');
ok($zip->set_number('5211344')->is_valid_number, '滋賀県近江八幡市安土町中屋');
ok($zip->set_number('5211345')->is_valid_number, '滋賀県近江八幡市安土町慈恩寺');
ok($zip->set_number('5211346')->is_valid_number, '滋賀県近江八幡市安土町香庄');
ok($zip->set_number('5211351')->is_valid_number, '滋賀県近江八幡市安土町常楽寺');
ok($zip->set_number('5220000')->is_valid_number, '滋賀県彦根市以下に掲載がない場合');
ok($zip->set_number('5220001')->is_valid_number, '滋賀県彦根市尾末町');
ok($zip->set_number('5220002')->is_valid_number, '滋賀県彦根市松原');
ok($zip->set_number('5220002')->is_valid_number, '滋賀県彦根市松原町');
ok($zip->set_number('5220003')->is_valid_number, '滋賀県彦根市宮田町');
ok($zip->set_number('5220004')->is_valid_number, '滋賀県彦根市鳥居本町');
ok($zip->set_number('5220005')->is_valid_number, '滋賀県彦根市小野町');
ok($zip->set_number('5220006')->is_valid_number, '滋賀県彦根市佐和山町');
ok($zip->set_number('5220007')->is_valid_number, '滋賀県彦根市古沢町');
ok($zip->set_number('5220008')->is_valid_number, '滋賀県彦根市安清東町');
ok($zip->set_number('5220009')->is_valid_number, '滋賀県彦根市外町');
ok($zip->set_number('5220010')->is_valid_number, '滋賀県彦根市駅東町');
ok($zip->set_number('5220011')->is_valid_number, '滋賀県彦根市下矢倉町');
ok($zip->set_number('5220012')->is_valid_number, '滋賀県彦根市甲田町');
ok($zip->set_number('5220013')->is_valid_number, '滋賀県彦根市中山町');
ok($zip->set_number('5220014')->is_valid_number, '滋賀県彦根市善谷町');
ok($zip->set_number('5220015')->is_valid_number, '滋賀県彦根市荘厳寺町');
ok($zip->set_number('5220016')->is_valid_number, '滋賀県彦根市武奈町');
ok($zip->set_number('5220017')->is_valid_number, '滋賀県彦根市男鬼町');
ok($zip->set_number('5220018')->is_valid_number, '滋賀県彦根市仏生寺町');
ok($zip->set_number('5220019')->is_valid_number, '滋賀県彦根市笹尾町');
ok($zip->set_number('5220021')->is_valid_number, '滋賀県彦根市幸町');
ok($zip->set_number('5220022')->is_valid_number, '滋賀県彦根市里根町');
ok($zip->set_number('5220023')->is_valid_number, '滋賀県彦根市原町');
ok($zip->set_number('5220024')->is_valid_number, '滋賀県彦根市正法寺町');
ok($zip->set_number('5220025')->is_valid_number, '滋賀県彦根市野田山町');
ok($zip->set_number('5220026')->is_valid_number, '滋賀県彦根市大堀町');
ok($zip->set_number('5220027')->is_valid_number, '滋賀県彦根市東沼波町');
ok($zip->set_number('5220029')->is_valid_number, '滋賀県彦根市地蔵町');
ok($zip->set_number('5220031')->is_valid_number, '滋賀県彦根市芹中町');
ok($zip->set_number('5220032')->is_valid_number, '滋賀県彦根市芹町');
ok($zip->set_number('5220033')->is_valid_number, '滋賀県彦根市芹川町');
ok($zip->set_number('5220034')->is_valid_number, '滋賀県彦根市大橋町');
ok($zip->set_number('5220035')->is_valid_number, '滋賀県彦根市元岡町');
ok($zip->set_number('5220036')->is_valid_number, '滋賀県彦根市沼波町');
ok($zip->set_number('5220037')->is_valid_number, '滋賀県彦根市岡町');
ok($zip->set_number('5220038')->is_valid_number, '滋賀県彦根市西沼波町');
ok($zip->set_number('5220038')->is_valid_number, '滋賀県彦根市山之脇町');
ok($zip->set_number('5220039')->is_valid_number, '滋賀県彦根市和田町');
ok($zip->set_number('5220041')->is_valid_number, '滋賀県彦根市平田町');
ok($zip->set_number('5220042')->is_valid_number, '滋賀県彦根市戸賀町');
ok($zip->set_number('5220043')->is_valid_number, '滋賀県彦根市小泉町');
ok($zip->set_number('5220044')->is_valid_number, '滋賀県彦根市竹ケ鼻町');
ok($zip->set_number('5220045')->is_valid_number, '滋賀県彦根市宇尾町(その他)');
ok($zip->set_number('5220046')->is_valid_number, '滋賀県彦根市甘呂町');
ok($zip->set_number('5220047')->is_valid_number, '滋賀県彦根市日夏町');
ok($zip->set_number('5220051')->is_valid_number, '滋賀県彦根市中藪');
ok($zip->set_number('5220051')->is_valid_number, '滋賀県彦根市中藪町');
ok($zip->set_number('5220052')->is_valid_number, '滋賀県彦根市長曽根南町');
ok($zip->set_number('5220053')->is_valid_number, '滋賀県彦根市大藪町');
ok($zip->set_number('5220054')->is_valid_number, '滋賀県彦根市西今町');
ok($zip->set_number('5220055')->is_valid_number, '滋賀県彦根市野瀬町');
ok($zip->set_number('5220056')->is_valid_number, '滋賀県彦根市開出今町');
ok($zip->set_number('5220057')->is_valid_number, '滋賀県彦根市八坂町');
ok($zip->set_number('5220058')->is_valid_number, '滋賀県彦根市須越町');
ok($zip->set_number('5220059')->is_valid_number, '滋賀県彦根市三津屋町');
ok($zip->set_number('5220061')->is_valid_number, '滋賀県彦根市金亀町');
ok($zip->set_number('5220062')->is_valid_number, '滋賀県彦根市立花町');
ok($zip->set_number('5220063')->is_valid_number, '滋賀県彦根市中央町');
ok($zip->set_number('5220064')->is_valid_number, '滋賀県彦根市本町');
ok($zip->set_number('5220065')->is_valid_number, '滋賀県彦根市池州町');
ok($zip->set_number('5220066')->is_valid_number, '滋賀県彦根市栄町');
ok($zip->set_number('5220067')->is_valid_number, '滋賀県彦根市長曽根町');
ok($zip->set_number('5220068')->is_valid_number, '滋賀県彦根市城町');
ok($zip->set_number('5220069')->is_valid_number, '滋賀県彦根市馬場');
ok($zip->set_number('5220071')->is_valid_number, '滋賀県彦根市元町');
ok($zip->set_number('5220072')->is_valid_number, '滋賀県彦根市船町');
ok($zip->set_number('5220073')->is_valid_number, '滋賀県彦根市旭町');
ok($zip->set_number('5220074')->is_valid_number, '滋賀県彦根市大東町');
ok($zip->set_number('5220075')->is_valid_number, '滋賀県彦根市佐和町');
ok($zip->set_number('5220081')->is_valid_number, '滋賀県彦根市京町');
ok($zip->set_number('5220082')->is_valid_number, '滋賀県彦根市安清町');
ok($zip->set_number('5220083')->is_valid_number, '滋賀県彦根市河原');
ok($zip->set_number('5220084')->is_valid_number, '滋賀県彦根市橋向町');
ok($zip->set_number('5220085')->is_valid_number, '滋賀県彦根市新町');
ok($zip->set_number('5220086')->is_valid_number, '滋賀県彦根市後三条町');
ok($zip->set_number('5220087')->is_valid_number, '滋賀県彦根市芹橋');
ok($zip->set_number('5220088')->is_valid_number, '滋賀県彦根市銀座町');
ok($zip->set_number('5220089')->is_valid_number, '滋賀県彦根市錦町');
ok($zip->set_number('5220200')->is_valid_number, '滋賀県犬上郡甲良町以下に掲載がない場合');
ok($zip->set_number('5220201')->is_valid_number, '滋賀県彦根市高宮町');
ok($zip->set_number('5220211')->is_valid_number, '滋賀県彦根市法士町');
ok($zip->set_number('5220212')->is_valid_number, '滋賀県彦根市葛籠町');
ok($zip->set_number('5220213')->is_valid_number, '滋賀県彦根市西葛籠町');
ok($zip->set_number('5220214')->is_valid_number, '滋賀県彦根市出町');
ok($zip->set_number('5220221')->is_valid_number, '滋賀県彦根市野口町');
ok($zip->set_number('5220222')->is_valid_number, '滋賀県彦根市南川瀬町');
ok($zip->set_number('5220223')->is_valid_number, '滋賀県彦根市川瀬馬場町');
ok($zip->set_number('5220231')->is_valid_number, '滋賀県彦根市極楽寺町');
ok($zip->set_number('5220232')->is_valid_number, '滋賀県彦根市蓮台寺町');
ok($zip->set_number('5220233')->is_valid_number, '滋賀県彦根市辻堂町');
ok($zip->set_number('5220234')->is_valid_number, '滋賀県彦根市森堂町');
ok($zip->set_number('5220235')->is_valid_number, '滋賀県彦根市金剛寺町');
ok($zip->set_number('5220236')->is_valid_number, '滋賀県彦根市犬方町');
ok($zip->set_number('5220237')->is_valid_number, '滋賀県彦根市堀町');
ok($zip->set_number('5220238')->is_valid_number, '滋賀県彦根市広野町');
ok($zip->set_number('5220239')->is_valid_number, '滋賀県彦根市宇尾町(897番地及び中島505~518番地)');
ok($zip->set_number('5220241')->is_valid_number, '滋賀県犬上郡甲良町呉竹');
ok($zip->set_number('5220242')->is_valid_number, '滋賀県犬上郡甲良町尼子');
ok($zip->set_number('5220243')->is_valid_number, '滋賀県犬上郡甲良町小川原');
ok($zip->set_number('5220244')->is_valid_number, '滋賀県犬上郡甲良町在士');
ok($zip->set_number('5220251')->is_valid_number, '滋賀県犬上郡甲良町北落');
ok($zip->set_number('5220252')->is_valid_number, '滋賀県犬上郡甲良町金屋');
ok($zip->set_number('5220253')->is_valid_number, '滋賀県犬上郡甲良町正楽寺');
ok($zip->set_number('5220254')->is_valid_number, '滋賀県犬上郡甲良町池寺');
ok($zip->set_number('5220261')->is_valid_number, '滋賀県犬上郡甲良町長寺');
ok($zip->set_number('5220262')->is_valid_number, '滋賀県犬上郡甲良町横関');
ok($zip->set_number('5220263')->is_valid_number, '滋賀県犬上郡甲良町法養寺');
ok($zip->set_number('5220271')->is_valid_number, '滋賀県犬上郡甲良町下之郷');
ok($zip->set_number('5220300')->is_valid_number, '滋賀県犬上郡多賀町以下に掲載がない場合');
ok($zip->set_number('5220301')->is_valid_number, '滋賀県犬上郡多賀町河内');
ok($zip->set_number('5220302')->is_valid_number, '滋賀県犬上郡多賀町向之倉');
ok($zip->set_number('5220303')->is_valid_number, '滋賀県犬上郡多賀町屏風');
ok($zip->set_number('5220304')->is_valid_number, '滋賀県犬上郡多賀町後谷');
ok($zip->set_number('5220305')->is_valid_number, '滋賀県犬上郡多賀町甲頭倉');
ok($zip->set_number('5220306')->is_valid_number, '滋賀県犬上郡多賀町霊仙');
ok($zip->set_number('5220311')->is_valid_number, '滋賀県犬上郡多賀町五僧');
ok($zip->set_number('5220312')->is_valid_number, '滋賀県犬上郡多賀町保月');
ok($zip->set_number('5220313')->is_valid_number, '滋賀県犬上郡多賀町杉');
ok($zip->set_number('5220314')->is_valid_number, '滋賀県犬上郡多賀町四手');
ok($zip->set_number('5220315')->is_valid_number, '滋賀県犬上郡多賀町大岡');
ok($zip->set_number('5220316')->is_valid_number, '滋賀県犬上郡多賀町栗栖');
ok($zip->set_number('5220317')->is_valid_number, '滋賀県犬上郡多賀町一円');
ok($zip->set_number('5220318')->is_valid_number, '滋賀県犬上郡多賀町水谷');
ok($zip->set_number('5220319')->is_valid_number, '滋賀県犬上郡多賀町桃原');
ok($zip->set_number('5220321')->is_valid_number, '滋賀県犬上郡多賀町大君ケ畑');
ok($zip->set_number('5220322')->is_valid_number, '滋賀県犬上郡多賀町佐目');
ok($zip->set_number('5220323')->is_valid_number, '滋賀県犬上郡多賀町一ノ瀬');
ok($zip->set_number('5220324')->is_valid_number, '滋賀県犬上郡多賀町川相');
ok($zip->set_number('5220325')->is_valid_number, '滋賀県犬上郡多賀町小原');
ok($zip->set_number('5220326')->is_valid_number, '滋賀県犬上郡多賀町霜ケ原');
ok($zip->set_number('5220327')->is_valid_number, '滋賀県犬上郡多賀町南後谷');
ok($zip->set_number('5220331')->is_valid_number, '滋賀県犬上郡多賀町大杉');
ok($zip->set_number('5220332')->is_valid_number, '滋賀県犬上郡多賀町樋田');
ok($zip->set_number('5220333')->is_valid_number, '滋賀県犬上郡多賀町萱原');
ok($zip->set_number('5220334')->is_valid_number, '滋賀県犬上郡多賀町仏ケ後');
ok($zip->set_number('5220335')->is_valid_number, '滋賀県犬上郡多賀町藤瀬');
ok($zip->set_number('5220336')->is_valid_number, '滋賀県犬上郡多賀町楢崎');
ok($zip->set_number('5220337')->is_valid_number, '滋賀県犬上郡多賀町富之尾');
ok($zip->set_number('5220338')->is_valid_number, '滋賀県犬上郡多賀町壺');
ok($zip->set_number('5220341')->is_valid_number, '滋賀県犬上郡多賀町多賀');
ok($zip->set_number('5220342')->is_valid_number, '滋賀県犬上郡多賀町敏満寺');
ok($zip->set_number('5220343')->is_valid_number, '滋賀県犬上郡多賀町猿木');
ok($zip->set_number('5220351')->is_valid_number, '滋賀県犬上郡多賀町八重練');
ok($zip->set_number('5220352')->is_valid_number, '滋賀県犬上郡多賀町久徳');
ok($zip->set_number('5220353')->is_valid_number, '滋賀県犬上郡多賀町月之木');
ok($zip->set_number('5220354')->is_valid_number, '滋賀県犬上郡多賀町土田');
ok($zip->set_number('5220355')->is_valid_number, '滋賀県犬上郡多賀町中川原');
ok($zip->set_number('5220356')->is_valid_number, '滋賀県犬上郡多賀町木曽');
ok($zip->set_number('5230000')->is_valid_number, '滋賀県近江八幡市以下に掲載がない場合');
ok($zip->set_number('5230001')->is_valid_number, '滋賀県近江八幡市金剛寺町');
ok($zip->set_number('5230002')->is_valid_number, '滋賀県近江八幡市野田町');
ok($zip->set_number('5230003')->is_valid_number, '滋賀県近江八幡市御所内町');
ok($zip->set_number('5230004')->is_valid_number, '滋賀県近江八幡市西生来町');
ok($zip->set_number('5230005')->is_valid_number, '滋賀県近江八幡市末広町');
ok($zip->set_number('5230011')->is_valid_number, '滋賀県近江八幡市友定町');
ok($zip->set_number('5230012')->is_valid_number, '滋賀県近江八幡市武佐町');
ok($zip->set_number('5230013')->is_valid_number, '滋賀県近江八幡市長光寺町');
ok($zip->set_number('5230014')->is_valid_number, '滋賀県近江八幡市西宿町');
ok($zip->set_number('5230015')->is_valid_number, '滋賀県近江八幡市上田町');
ok($zip->set_number('5230016')->is_valid_number, '滋賀県近江八幡市千僧供町');
ok($zip->set_number('5230021')->is_valid_number, '滋賀県近江八幡市長福寺町');
ok($zip->set_number('5230022')->is_valid_number, '滋賀県近江八幡市馬淵町');
ok($zip->set_number('5230023')->is_valid_number, '滋賀県近江八幡市倉橋部町');
ok($zip->set_number('5230024')->is_valid_number, '滋賀県近江八幡市浄土寺町');
ok($zip->set_number('5230025')->is_valid_number, '滋賀県近江八幡市新巻町');
ok($zip->set_number('5230026')->is_valid_number, '滋賀県近江八幡市上畑町');
ok($zip->set_number('5230027')->is_valid_number, '滋賀県近江八幡市東川町');
ok($zip->set_number('5230031')->is_valid_number, '滋賀県近江八幡市堀上町');
ok($zip->set_number('5230032')->is_valid_number, '滋賀県近江八幡市白鳥町');
ok($zip->set_number('5230033')->is_valid_number, '滋賀県近江八幡市日吉野町');
ok($zip->set_number('5230034')->is_valid_number, '滋賀県近江八幡市若宮町');
ok($zip->set_number('5230035')->is_valid_number, '滋賀県近江八幡市東横関町');
ok($zip->set_number('5230036')->is_valid_number, '滋賀県近江八幡市竹町');
ok($zip->set_number('5230037')->is_valid_number, '滋賀県近江八幡市東町');
ok($zip->set_number('5230041')->is_valid_number, '滋賀県近江八幡市中小森町');
ok($zip->set_number('5230042')->is_valid_number, '滋賀県近江八幡市大森町');
ok($zip->set_number('5230043')->is_valid_number, '滋賀県近江八幡市池田本町');
ok($zip->set_number('5230044')->is_valid_number, '滋賀県近江八幡市篠原町');
ok($zip->set_number('5230045')->is_valid_number, '滋賀県近江八幡市安養寺町');
ok($zip->set_number('5230046')->is_valid_number, '滋賀県近江八幡市上野町');
ok($zip->set_number('5230047')->is_valid_number, '滋賀県近江八幡市川原町');
ok($zip->set_number('5230048')->is_valid_number, '滋賀県近江八幡市緑町');
ok($zip->set_number('5230051')->is_valid_number, '滋賀県近江八幡市八木町');
ok($zip->set_number('5230052')->is_valid_number, '滋賀県近江八幡市赤尾町');
ok($zip->set_number('5230053')->is_valid_number, '滋賀県近江八幡市益田町');
ok($zip->set_number('5230054')->is_valid_number, '滋賀県近江八幡市森尻町');
ok($zip->set_number('5230055')->is_valid_number, '滋賀県近江八幡市柳町');
ok($zip->set_number('5230056')->is_valid_number, '滋賀県近江八幡市古川町');
ok($zip->set_number('5230057')->is_valid_number, '滋賀県近江八幡市田中江町');
ok($zip->set_number('5230058')->is_valid_number, '滋賀県近江八幡市加茂町');
ok($zip->set_number('5230061')->is_valid_number, '滋賀県近江八幡市江頭町');
ok($zip->set_number('5230062')->is_valid_number, '滋賀県近江八幡市丸の内町');
ok($zip->set_number('5230063')->is_valid_number, '滋賀県近江八幡市十王町');
ok($zip->set_number('5230064')->is_valid_number, '滋賀県近江八幡市小田町');
ok($zip->set_number('5230071')->is_valid_number, '滋賀県近江八幡市大房町');
ok($zip->set_number('5230072')->is_valid_number, '滋賀県近江八幡市牧町');
ok($zip->set_number('5230073')->is_valid_number, '滋賀県近江八幡市元水茎町');
ok($zip->set_number('5230074')->is_valid_number, '滋賀県近江八幡市水茎町');
ok($zip->set_number('5230075')->is_valid_number, '滋賀県近江八幡市野村町');
ok($zip->set_number('5230076')->is_valid_number, '滋賀県近江八幡市佐波江町');
ok($zip->set_number('5230081')->is_valid_number, '滋賀県近江八幡市新栄町');
ok($zip->set_number('5230082')->is_valid_number, '滋賀県近江八幡市土田町');
ok($zip->set_number('5230083')->is_valid_number, '滋賀県近江八幡市小船木町');
ok($zip->set_number('5230084')->is_valid_number, '滋賀県近江八幡市船木町');
ok($zip->set_number('5230085')->is_valid_number, '滋賀県近江八幡市南津田町');
ok($zip->set_number('5230086')->is_valid_number, '滋賀県近江八幡市津田町');
ok($zip->set_number('5230087')->is_valid_number, '滋賀県近江八幡市北津田町');
ok($zip->set_number('5230801')->is_valid_number, '滋賀県近江八幡市沖島町');
ok($zip->set_number('5230802')->is_valid_number, '滋賀県近江八幡市大中町');
ok($zip->set_number('5230803')->is_valid_number, '滋賀県近江八幡市白王町');
ok($zip->set_number('5230804')->is_valid_number, '滋賀県近江八幡市島町');
ok($zip->set_number('5230805')->is_valid_number, '滋賀県近江八幡市円山町');
ok($zip->set_number('5230806')->is_valid_number, '滋賀県近江八幡市北之庄町');
ok($zip->set_number('5230807')->is_valid_number, '滋賀県近江八幡市中之庄町');
ok($zip->set_number('5230808')->is_valid_number, '滋賀県近江八幡市長命寺町');
ok($zip->set_number('5230811')->is_valid_number, '滋賀県近江八幡市長田町');
ok($zip->set_number('5230812')->is_valid_number, '滋賀県近江八幡市杉森町');
ok($zip->set_number('5230813')->is_valid_number, '滋賀県近江八幡市西本郷町');
ok($zip->set_number('5230814')->is_valid_number, '滋賀県近江八幡市南本郷町');
ok($zip->set_number('5230815')->is_valid_number, '滋賀県近江八幡市若葉町');
ok($zip->set_number('5230816')->is_valid_number, '滋賀県近江八幡市西庄町');
ok($zip->set_number('5230817')->is_valid_number, '滋賀県近江八幡市浅小井町');
ok($zip->set_number('5230818')->is_valid_number, '滋賀県近江八幡市西本郷町東');
ok($zip->set_number('5230819')->is_valid_number, '滋賀県近江八幡市西本郷町西');
ok($zip->set_number('5230821')->is_valid_number, '滋賀県近江八幡市多賀町');
ok($zip->set_number('5230822')->is_valid_number, '滋賀県近江八幡市船町');
ok($zip->set_number('5230823')->is_valid_number, '滋賀県近江八幡市生須町');
ok($zip->set_number('5230824')->is_valid_number, '滋賀県近江八幡市大工町');
ok($zip->set_number('5230825')->is_valid_number, '滋賀県近江八幡市新左衛門町');
ok($zip->set_number('5230826')->is_valid_number, '滋賀県近江八幡市薬師町');
ok($zip->set_number('5230827')->is_valid_number, '滋賀県近江八幡市鉄炮町');
ok($zip->set_number('5230828')->is_valid_number, '滋賀県近江八幡市宮内町');
ok($zip->set_number('5230831')->is_valid_number, '滋賀県近江八幡市玉屋町');
ok($zip->set_number('5230832')->is_valid_number, '滋賀県近江八幡市江南町');
ok($zip->set_number('5230833')->is_valid_number, '滋賀県近江八幡市鍛治屋町');
ok($zip->set_number('5230834')->is_valid_number, '滋賀県近江八幡市東畳屋町');
ok($zip->set_number('5230835')->is_valid_number, '滋賀県近江八幡市西畳屋町');
ok($zip->set_number('5230836')->is_valid_number, '滋賀県近江八幡市間之町');
ok($zip->set_number('5230837')->is_valid_number, '滋賀県近江八幡市大杉町');
ok($zip->set_number('5230841')->is_valid_number, '滋賀県近江八幡市慈恩寺町元');
ok($zip->set_number('5230842')->is_valid_number, '滋賀県近江八幡市慈恩寺町中');
ok($zip->set_number('5230843')->is_valid_number, '滋賀県近江八幡市慈恩寺町上');
ok($zip->set_number('5230844')->is_valid_number, '滋賀県近江八幡市博労町元');
ok($zip->set_number('5230845')->is_valid_number, '滋賀県近江八幡市博労町中');
ok($zip->set_number('5230846')->is_valid_number, '滋賀県近江八幡市博労町上');
ok($zip->set_number('5230847')->is_valid_number, '滋賀県近江八幡市永原町元');
ok($zip->set_number('5230848')->is_valid_number, '滋賀県近江八幡市永原町中');
ok($zip->set_number('5230849')->is_valid_number, '滋賀県近江八幡市永原町上');
ok($zip->set_number('5230851')->is_valid_number, '滋賀県近江八幡市市井町');
ok($zip->set_number('5230852')->is_valid_number, '滋賀県近江八幡市鍵之手町');
ok($zip->set_number('5230853')->is_valid_number, '滋賀県近江八幡市縄手町元');
ok($zip->set_number('5230854')->is_valid_number, '滋賀県近江八幡市縄手町中');
ok($zip->set_number('5230855')->is_valid_number, '滋賀県近江八幡市縄手町末');
ok($zip->set_number('5230856')->is_valid_number, '滋賀県近江八幡市音羽町');
ok($zip->set_number('5230857')->is_valid_number, '滋賀県近江八幡市八幡町');
ok($zip->set_number('5230861')->is_valid_number, '滋賀県近江八幡市仲屋町元');
ok($zip->set_number('5230862')->is_valid_number, '滋賀県近江八幡市仲屋町中');
ok($zip->set_number('5230863')->is_valid_number, '滋賀県近江八幡市仲屋町上');
ok($zip->set_number('5230864')->is_valid_number, '滋賀県近江八幡市為心町元');
ok($zip->set_number('5230865')->is_valid_number, '滋賀県近江八幡市為心町中');
ok($zip->set_number('5230866')->is_valid_number, '滋賀県近江八幡市為心町上');
ok($zip->set_number('5230867')->is_valid_number, '滋賀県近江八幡市魚屋町元');
ok($zip->set_number('5230868')->is_valid_number, '滋賀県近江八幡市魚屋町中');
ok($zip->set_number('5230869')->is_valid_number, '滋賀県近江八幡市魚屋町上');
ok($zip->set_number('5230871')->is_valid_number, '滋賀県近江八幡市新町');
ok($zip->set_number('5230872')->is_valid_number, '滋賀県近江八幡市玉木町');
ok($zip->set_number('5230873')->is_valid_number, '滋賀県近江八幡市正神町');
ok($zip->set_number('5230874')->is_valid_number, '滋賀県近江八幡市小幡町中');
ok($zip->set_number('5230875')->is_valid_number, '滋賀県近江八幡市小幡町上');
ok($zip->set_number('5230876')->is_valid_number, '滋賀県近江八幡市本町');
ok($zip->set_number('5230877')->is_valid_number, '滋賀県近江八幡市池田町');
ok($zip->set_number('5230881')->is_valid_number, '滋賀県近江八幡市佐久間町');
ok($zip->set_number('5230882')->is_valid_number, '滋賀県近江八幡市元玉屋町');
ok($zip->set_number('5230883')->is_valid_number, '滋賀県近江八幡市北元町');
ok($zip->set_number('5230884')->is_valid_number, '滋賀県近江八幡市北末町');
ok($zip->set_number('5230885')->is_valid_number, '滋賀県近江八幡市板屋町');
ok($zip->set_number('5230886')->is_valid_number, '滋賀県近江八幡市西末町');
ok($zip->set_number('5230887')->is_valid_number, '滋賀県近江八幡市西元町');
ok($zip->set_number('5230888')->is_valid_number, '滋賀県近江八幡市孫平治町');
ok($zip->set_number('5230889')->is_valid_number, '滋賀県近江八幡市日杉町');
ok($zip->set_number('5230891')->is_valid_number, '滋賀県近江八幡市鷹飼町');
ok($zip->set_number('5230892')->is_valid_number, '滋賀県近江八幡市出町');
ok($zip->set_number('5230893')->is_valid_number, '滋賀県近江八幡市桜宮町');
ok($zip->set_number('5230894')->is_valid_number, '滋賀県近江八幡市中村町');
ok($zip->set_number('5230895')->is_valid_number, '滋賀県近江八幡市宇津呂町');
ok($zip->set_number('5230896')->is_valid_number, '滋賀県近江八幡市鷹飼町北');
ok($zip->set_number('5230897')->is_valid_number, '滋賀県近江八幡市鷹飼町東');
ok($zip->set_number('5230898')->is_valid_number, '滋賀県近江八幡市鷹飼町南');
ok($zip->set_number('5240000')->is_valid_number, '滋賀県守山市以下に掲載がない場合');
ok($zip->set_number('5240001')->is_valid_number, '滋賀県守山市川田町');
ok($zip->set_number('5240002')->is_valid_number, '滋賀県守山市小島町');
ok($zip->set_number('5240003')->is_valid_number, '滋賀県守山市中町');
ok($zip->set_number('5240004')->is_valid_number, '滋賀県守山市笠原町');
ok($zip->set_number('5240011')->is_valid_number, '滋賀県守山市今市町');
ok($zip->set_number('5240012')->is_valid_number, '滋賀県守山市播磨田町');
ok($zip->set_number('5240013')->is_valid_number, '滋賀県守山市下之郷');
ok($zip->set_number('5240013')->is_valid_number, '滋賀県守山市下之郷町');
ok($zip->set_number('5240014')->is_valid_number, '滋賀県守山市石田町');
ok($zip->set_number('5240015')->is_valid_number, '滋賀県守山市矢島町');
ok($zip->set_number('5240016')->is_valid_number, '滋賀県守山市荒見町');
ok($zip->set_number('5240021')->is_valid_number, '滋賀県守山市吉身');
ok($zip->set_number('5240021')->is_valid_number, '滋賀県守山市吉身町');
ok($zip->set_number('5240022')->is_valid_number, '滋賀県守山市守山');
ok($zip->set_number('5240022')->is_valid_number, '滋賀県守山市守山町');
ok($zip->set_number('5240031')->is_valid_number, '滋賀県守山市立入町');
ok($zip->set_number('5240032')->is_valid_number, '滋賀県守山市岡町');
ok($zip->set_number('5240033')->is_valid_number, '滋賀県守山市浮気町');
ok($zip->set_number('5240034')->is_valid_number, '滋賀県守山市千代町');
ok($zip->set_number('5240035')->is_valid_number, '滋賀県守山市阿村町');
ok($zip->set_number('5240036')->is_valid_number, '滋賀県守山市伊勢町');
ok($zip->set_number('5240037')->is_valid_number, '滋賀県守山市梅田町');
ok($zip->set_number('5240041')->is_valid_number, '滋賀県守山市勝部');
ok($zip->set_number('5240041')->is_valid_number, '滋賀県守山市勝部町');
ok($zip->set_number('5240042')->is_valid_number, '滋賀県守山市焔魔堂町');
ok($zip->set_number('5240043')->is_valid_number, '滋賀県守山市二町町');
ok($zip->set_number('5240044')->is_valid_number, '滋賀県守山市古高町');
ok($zip->set_number('5240045')->is_valid_number, '滋賀県守山市金森町');
ok($zip->set_number('5240046')->is_valid_number, '滋賀県守山市今宿');
ok($zip->set_number('5240046')->is_valid_number, '滋賀県守山市今宿町');
ok($zip->set_number('5240051')->is_valid_number, '滋賀県守山市三宅町');
ok($zip->set_number('5240052')->is_valid_number, '滋賀県守山市大門町');
ok($zip->set_number('5240053')->is_valid_number, '滋賀県守山市横江町');
ok($zip->set_number('5240054')->is_valid_number, '滋賀県守山市大林町');
ok($zip->set_number('5240055')->is_valid_number, '滋賀県守山市十二里町');
ok($zip->set_number('5240061')->is_valid_number, '滋賀県守山市赤野井町');
ok($zip->set_number('5240062')->is_valid_number, '滋賀県守山市杉江町');
ok($zip->set_number('5240063')->is_valid_number, '滋賀県守山市欲賀町');
ok($zip->set_number('5240064')->is_valid_number, '滋賀県守山市森川原町');
ok($zip->set_number('5240065')->is_valid_number, '滋賀県守山市山賀町');
ok($zip->set_number('5240101')->is_valid_number, '滋賀県守山市今浜町');
ok($zip->set_number('5240102')->is_valid_number, '滋賀県守山市水保町');
ok($zip->set_number('5240103')->is_valid_number, '滋賀県守山市洲本町');
ok($zip->set_number('5240104')->is_valid_number, '滋賀県守山市木浜町');
ok($zip->set_number('5240211')->is_valid_number, '滋賀県守山市小浜町');
ok($zip->set_number('5240212')->is_valid_number, '滋賀県守山市服部町');
ok($zip->set_number('5240213')->is_valid_number, '滋賀県守山市新庄町');
ok($zip->set_number('5240214')->is_valid_number, '滋賀県守山市立田町');
ok($zip->set_number('5240215')->is_valid_number, '滋賀県守山市幸津川町');
ok($zip->set_number('5240216')->is_valid_number, '滋賀県守山市環境学習都市宣言記念公園');
ok($zip->set_number('5250000')->is_valid_number, '滋賀県草津市以下に掲載がない場合');
ok($zip->set_number('5250001')->is_valid_number, '滋賀県草津市下物町');
ok($zip->set_number('5250002')->is_valid_number, '滋賀県草津市芦浦町');
ok($zip->set_number('5250003')->is_valid_number, '滋賀県草津市長束町');
ok($zip->set_number('5250004')->is_valid_number, '滋賀県草津市上寺町');
ok($zip->set_number('5250005')->is_valid_number, '滋賀県草津市志那町');
ok($zip->set_number('5250006')->is_valid_number, '滋賀県草津市志那中町');
ok($zip->set_number('5250007')->is_valid_number, '滋賀県草津市下寺町');
ok($zip->set_number('5250011')->is_valid_number, '滋賀県草津市片岡町');
ok($zip->set_number('5250012')->is_valid_number, '滋賀県草津市穴村町');
ok($zip->set_number('5250013')->is_valid_number, '滋賀県草津市新堂町');
ok($zip->set_number('5250014')->is_valid_number, '滋賀県草津市駒井沢町');
ok($zip->set_number('5250015')->is_valid_number, '滋賀県草津市集町');
ok($zip->set_number('5250016')->is_valid_number, '滋賀県草津市北大萱町');
ok($zip->set_number('5250021')->is_valid_number, '滋賀県草津市川原');
ok($zip->set_number('5250022')->is_valid_number, '滋賀県草津市川原町');
ok($zip->set_number('5250023')->is_valid_number, '滋賀県草津市平井');
ok($zip->set_number('5250024')->is_valid_number, '滋賀県草津市平井町');
ok($zip->set_number('5250025')->is_valid_number, '滋賀県草津市西渋川');
ok($zip->set_number('5250026')->is_valid_number, '滋賀県草津市渋川');
ok($zip->set_number('5250027')->is_valid_number, '滋賀県草津市野村');
ok($zip->set_number('5250028')->is_valid_number, '滋賀県草津市上笠');
ok($zip->set_number('5250029')->is_valid_number, '滋賀県草津市下笠町');
ok($zip->set_number('5250031')->is_valid_number, '滋賀県草津市若竹町');
ok($zip->set_number('5250032')->is_valid_number, '滋賀県草津市大路');
ok($zip->set_number('5250033')->is_valid_number, '滋賀県草津市東草津');
ok($zip->set_number('5250034')->is_valid_number, '滋賀県草津市草津');
ok($zip->set_number('5250035')->is_valid_number, '滋賀県草津市西草津');
ok($zip->set_number('5250036')->is_valid_number, '滋賀県草津市草津町');
ok($zip->set_number('5250037')->is_valid_number, '滋賀県草津市西大路町');
ok($zip->set_number('5250041')->is_valid_number, '滋賀県草津市青地町');
ok($zip->set_number('5250042')->is_valid_number, '滋賀県草津市山寺町');
ok($zip->set_number('5250043')->is_valid_number, '滋賀県草津市馬場町');
ok($zip->set_number('5250044')->is_valid_number, '滋賀県草津市岡本町');
ok($zip->set_number('5250045')->is_valid_number, '滋賀県草津市若草');
ok($zip->set_number('5250047')->is_valid_number, '滋賀県草津市追分');
ok($zip->set_number('5250048')->is_valid_number, '滋賀県草津市追分南');
ok($zip->set_number('5250050')->is_valid_number, '滋賀県草津市南草津');
ok($zip->set_number('5250051')->is_valid_number, '滋賀県草津市木川町');
ok($zip->set_number('5250052')->is_valid_number, '滋賀県草津市西矢倉');
ok($zip->set_number('5250053')->is_valid_number, '滋賀県草津市矢倉');
ok($zip->set_number('5250054')->is_valid_number, '滋賀県草津市東矢倉');
ok($zip->set_number('5250055')->is_valid_number, '滋賀県草津市野路町');
ok($zip->set_number('5250056')->is_valid_number, '滋賀県草津市南笠町');
ok($zip->set_number('5250057')->is_valid_number, '滋賀県草津市桜ケ丘');
ok($zip->set_number('5250058')->is_valid_number, '滋賀県草津市野路東');
ok($zip->set_number('5250059')->is_valid_number, '滋賀県草津市野路');
ok($zip->set_number('5250061')->is_valid_number, '滋賀県草津市北山田町');
ok($zip->set_number('5250062')->is_valid_number, '滋賀県草津市山田町');
ok($zip->set_number('5250063')->is_valid_number, '滋賀県草津市南山田町');
ok($zip->set_number('5250064')->is_valid_number, '滋賀県草津市御倉町');
ok($zip->set_number('5250065')->is_valid_number, '滋賀県草津市橋岡町');
ok($zip->set_number('5250066')->is_valid_number, '滋賀県草津市矢橋町');
ok($zip->set_number('5250067')->is_valid_number, '滋賀県草津市新浜町');
ok($zip->set_number('5250068')->is_valid_number, '滋賀県草津市南草津プリムタウン');
ok($zip->set_number('5250071')->is_valid_number, '滋賀県草津市南笠東');
ok($zip->set_number('5250072')->is_valid_number, '滋賀県草津市笠山');
ok($zip->set_number('5260000')->is_valid_number, '滋賀県長浜市以下に掲載がない場合');
ok($zip->set_number('5260001')->is_valid_number, '滋賀県長浜市国友町');
ok($zip->set_number('5260002')->is_valid_number, '滋賀県長浜市保田町');
ok($zip->set_number('5260003')->is_valid_number, '滋賀県長浜市泉町');
ok($zip->set_number('5260004')->is_valid_number, '滋賀県長浜市小沢町');
ok($zip->set_number('5260005')->is_valid_number, '滋賀県長浜市下之郷町');
ok($zip->set_number('5260011')->is_valid_number, '滋賀県長浜市新庄馬場町');
ok($zip->set_number('5260012')->is_valid_number, '滋賀県長浜市新庄中町');
ok($zip->set_number('5260013')->is_valid_number, '滋賀県長浜市新庄寺町');
ok($zip->set_number('5260014')->is_valid_number, '滋賀県長浜市口分田町');
ok($zip->set_number('5260015')->is_valid_number, '滋賀県長浜市神照町');
ok($zip->set_number('5260016')->is_valid_number, '滋賀県長浜市十里町');
ok($zip->set_number('5260017')->is_valid_number, '滋賀県長浜市相撲町');
ok($zip->set_number('5260018')->is_valid_number, '滋賀県長浜市森町');
ok($zip->set_number('5260021')->is_valid_number, '滋賀県長浜市八幡中山町');
ok($zip->set_number('5260022')->is_valid_number, '滋賀県長浜市中山町');
ok($zip->set_number('5260023')->is_valid_number, '滋賀県長浜市三ツ矢町');
ok($zip->set_number('5260024')->is_valid_number, '滋賀県長浜市三ツ矢元町');
ok($zip->set_number('5260025')->is_valid_number, '滋賀県長浜市分木町');
ok($zip->set_number('5260031')->is_valid_number, '滋賀県長浜市八幡東町');
ok($zip->set_number('5260032')->is_valid_number, '滋賀県長浜市南高田町');
ok($zip->set_number('5260033')->is_valid_number, '滋賀県長浜市平方町');
ok($zip->set_number('5260034')->is_valid_number, '滋賀県長浜市弥高町');
ok($zip->set_number('5260035')->is_valid_number, '滋賀県長浜市平方南町');
ok($zip->set_number('5260036')->is_valid_number, '滋賀県長浜市地福寺町');
ok($zip->set_number('5260037')->is_valid_number, '滋賀県長浜市高田町');
ok($zip->set_number('5260041')->is_valid_number, '滋賀県長浜市四ツ塚町');
ok($zip->set_number('5260042')->is_valid_number, '滋賀県長浜市勝町');
ok($zip->set_number('5260043')->is_valid_number, '滋賀県長浜市大戌亥町');
ok($zip->set_number('5260044')->is_valid_number, '滋賀県長浜市下坂中町');
ok($zip->set_number('5260045')->is_valid_number, '滋賀県長浜市寺田町');
ok($zip->set_number('5260046')->is_valid_number, '滋賀県長浜市高橋町');
ok($zip->set_number('5260047')->is_valid_number, '滋賀県長浜市下坂浜町');
ok($zip->set_number('5260051')->is_valid_number, '滋賀県長浜市一の宮町');
ok($zip->set_number('5260052')->is_valid_number, '滋賀県長浜市神前町');
ok($zip->set_number('5260053')->is_valid_number, '滋賀県長浜市宮前町');
ok($zip->set_number('5260054')->is_valid_number, '滋賀県長浜市大宮町');
ok($zip->set_number('5260055')->is_valid_number, '滋賀県長浜市三和町');
ok($zip->set_number('5260056')->is_valid_number, '滋賀県長浜市朝日町');
ok($zip->set_number('5260057')->is_valid_number, '滋賀県長浜市北船町');
ok($zip->set_number('5260058')->is_valid_number, '滋賀県長浜市南呉服町');
ok($zip->set_number('5260059')->is_valid_number, '滋賀県長浜市元浜町');
ok($zip->set_number('5260061')->is_valid_number, '滋賀県長浜市祇園町');
ok($zip->set_number('5260062')->is_valid_number, '滋賀県長浜市列見町');
ok($zip->set_number('5260063')->is_valid_number, '滋賀県長浜市末広町');
ok($zip->set_number('5260064')->is_valid_number, '滋賀県長浜市殿町');
ok($zip->set_number('5260065')->is_valid_number, '滋賀県長浜市公園町');
ok($zip->set_number('5260066')->is_valid_number, '滋賀県長浜市大島町');
ok($zip->set_number('5260067')->is_valid_number, '滋賀県長浜市港町');
ok($zip->set_number('5260068')->is_valid_number, '滋賀県長浜市鐘紡町');
ok($zip->set_number('5260101')->is_valid_number, '滋賀県長浜市錦織町');
ok($zip->set_number('5260102')->is_valid_number, '滋賀県長浜市落合町');
ok($zip->set_number('5260103')->is_valid_number, '滋賀県長浜市曽根町');
ok($zip->set_number('5260104')->is_valid_number, '滋賀県長浜市御館');
ok($zip->set_number('5260105')->is_valid_number, '滋賀県長浜市細江町');
ok($zip->set_number('5260106')->is_valid_number, '滋賀県長浜市野寺町');
ok($zip->set_number('5260107')->is_valid_number, '滋賀県長浜市新居町');
ok($zip->set_number('5260108')->is_valid_number, '滋賀県長浜市難波町');
ok($zip->set_number('5260111')->is_valid_number, '滋賀県長浜市川道町');
ok($zip->set_number('5260112')->is_valid_number, '滋賀県長浜市鶴が島');
ok($zip->set_number('5260113')->is_valid_number, '滋賀県長浜市南浜町');
ok($zip->set_number('5260114')->is_valid_number, '滋賀県長浜市中浜');
ok($zip->set_number('5260115')->is_valid_number, '滋賀県長浜市大浜町');
ok($zip->set_number('5260116')->is_valid_number, '滋賀県長浜市八木浜町');
ok($zip->set_number('5260121')->is_valid_number, '滋賀県長浜市十九町');
ok($zip->set_number('5260122')->is_valid_number, '滋賀県長浜市上八木町');
ok($zip->set_number('5260123')->is_valid_number, '滋賀県長浜市下八木町');
ok($zip->set_number('5260124')->is_valid_number, '滋賀県長浜市早崎町');
ok($zip->set_number('5260125')->is_valid_number, '滋賀県長浜市益田町');
ok($zip->set_number('5260126')->is_valid_number, '滋賀県長浜市安養寺町');
ok($zip->set_number('5260131')->is_valid_number, '滋賀県長浜市富田町');
ok($zip->set_number('5260132')->is_valid_number, '滋賀県長浜市香花寺町');
ok($zip->set_number('5260133')->is_valid_number, '滋賀県長浜市稲葉町');
ok($zip->set_number('5260134')->is_valid_number, '滋賀県長浜市小観音寺町');
ok($zip->set_number('5260135')->is_valid_number, '滋賀県長浜市弓削町');
ok($zip->set_number('5260201')->is_valid_number, '滋賀県長浜市高山町');
ok($zip->set_number('5260202')->is_valid_number, '滋賀県長浜市草野町');
ok($zip->set_number('5260203')->is_valid_number, '滋賀県長浜市野瀬町');
ok($zip->set_number('5260204')->is_valid_number, '滋賀県長浜市鍛冶屋町');
ok($zip->set_number('5260205')->is_valid_number, '滋賀県長浜市岡谷町');
ok($zip->set_number('5260206')->is_valid_number, '滋賀県長浜市郷野町');
ok($zip->set_number('5260207')->is_valid_number, '滋賀県長浜市太田町');
ok($zip->set_number('5260208')->is_valid_number, '滋賀県長浜市西村町');
ok($zip->set_number('5260209')->is_valid_number, '滋賀県長浜市寺師町');
ok($zip->set_number('5260211')->is_valid_number, '滋賀県長浜市飯山町');
ok($zip->set_number('5260212')->is_valid_number, '滋賀県長浜市徳山町');
ok($zip->set_number('5260213')->is_valid_number, '滋賀県長浜市醍醐町');
ok($zip->set_number('5260214')->is_valid_number, '滋賀県長浜市北ノ郷町');
ok($zip->set_number('5260215')->is_valid_number, '滋賀県長浜市当目町');
ok($zip->set_number('5260216')->is_valid_number, '滋賀県長浜市大門町');
ok($zip->set_number('5260217')->is_valid_number, '滋賀県長浜市乗倉町');
ok($zip->set_number('5260221')->is_valid_number, '滋賀県長浜市小野寺町');
ok($zip->set_number('5260222')->is_valid_number, '滋賀県長浜市浅井高原');
ok($zip->set_number('5260223')->is_valid_number, '滋賀県長浜市法楽寺町');
ok($zip->set_number('5260224')->is_valid_number, '滋賀県長浜市東野町');
ok($zip->set_number('5260225')->is_valid_number, '滋賀県長浜市南郷町');
ok($zip->set_number('5260226')->is_valid_number, '滋賀県長浜市東主計町');
ok($zip->set_number('5260227')->is_valid_number, '滋賀県長浜市西主計町');
ok($zip->set_number('5260231')->is_valid_number, '滋賀県長浜市北池町');
ok($zip->set_number('5260232')->is_valid_number, '滋賀県長浜市南池町');
ok($zip->set_number('5260233')->is_valid_number, '滋賀県長浜市今荘町');
ok($zip->set_number('5260234')->is_valid_number, '滋賀県長浜市相撲庭町');
ok($zip->set_number('5260235')->is_valid_number, '滋賀県長浜市佐野町');
ok($zip->set_number('5260236')->is_valid_number, '滋賀県長浜市野村町');
ok($zip->set_number('5260241')->is_valid_number, '滋賀県長浜市新三田');
ok($zip->set_number('5260242')->is_valid_number, '滋賀県長浜市三田町');
ok($zip->set_number('5260243')->is_valid_number, '滋賀県長浜市大路町');
ok($zip->set_number('5260244')->is_valid_number, '滋賀県長浜市内保町');
ok($zip->set_number('5260245')->is_valid_number, '滋賀県長浜市湯次町');
ok($zip->set_number('5260246')->is_valid_number, '滋賀県長浜市西新三田');
ok($zip->set_number('5260251')->is_valid_number, '滋賀県長浜市大依町');
ok($zip->set_number('5260252')->is_valid_number, '滋賀県長浜市八島町');
ok($zip->set_number('5260253')->is_valid_number, '滋賀県長浜市平塚町');
ok($zip->set_number('5260254')->is_valid_number, '滋賀県長浜市尊野町');
ok($zip->set_number('5260255')->is_valid_number, '滋賀県長浜市西野町');
ok($zip->set_number('5260256')->is_valid_number, '滋賀県長浜市尊勝寺町');
ok($zip->set_number('5260257')->is_valid_number, '滋賀県長浜市山ノ前町');
ok($zip->set_number('5260261')->is_valid_number, '滋賀県長浜市竜安寺町');
ok($zip->set_number('5260262')->is_valid_number, '滋賀県長浜市黒部町');
ok($zip->set_number('5260263')->is_valid_number, '滋賀県長浜市小室町');
ok($zip->set_number('5260264')->is_valid_number, '滋賀県長浜市上野町');
ok($zip->set_number('5260265')->is_valid_number, '滋賀県長浜市木尾町');
ok($zip->set_number('5260266')->is_valid_number, '滋賀県長浜市野田町');
ok($zip->set_number('5260267')->is_valid_number, '滋賀県長浜市力丸町');
ok($zip->set_number('5260271')->is_valid_number, '滋賀県長浜市谷口町');
ok($zip->set_number('5260272')->is_valid_number, '滋賀県長浜市北野町');
ok($zip->set_number('5260273')->is_valid_number, '滋賀県長浜市高畑町');
ok($zip->set_number('5260274')->is_valid_number, '滋賀県長浜市池奥町');
ok($zip->set_number('5260275')->is_valid_number, '滋賀県長浜市瓜生町');
ok($zip->set_number('5260276')->is_valid_number, '滋賀県長浜市田川町');
ok($zip->set_number('5260277')->is_valid_number, '滋賀県長浜市須賀谷町');
ok($zip->set_number('5260801')->is_valid_number, '滋賀県長浜市千草町');
ok($zip->set_number('5260802')->is_valid_number, '滋賀県長浜市東上坂町');
ok($zip->set_number('5260803')->is_valid_number, '滋賀県長浜市西上坂町');
ok($zip->set_number('5260804')->is_valid_number, '滋賀県長浜市加納町');
ok($zip->set_number('5260805')->is_valid_number, '滋賀県長浜市榎木町');
ok($zip->set_number('5260806')->is_valid_number, '滋賀県長浜市今町');
ok($zip->set_number('5260811')->is_valid_number, '滋賀県長浜市垣籠町');
ok($zip->set_number('5260812')->is_valid_number, '滋賀県長浜市保多町');
ok($zip->set_number('5260813')->is_valid_number, '滋賀県長浜市堀部町');
ok($zip->set_number('5260814')->is_valid_number, '滋賀県長浜市石田町');
ok($zip->set_number('5260815')->is_valid_number, '滋賀県長浜市八条町');
ok($zip->set_number('5260816')->is_valid_number, '滋賀県長浜市今川町');
ok($zip->set_number('5260817')->is_valid_number, '滋賀県長浜市七条町');
ok($zip->set_number('5260821')->is_valid_number, '滋賀県長浜市本庄町');
ok($zip->set_number('5260822')->is_valid_number, '滋賀県長浜市鳥羽上町');
ok($zip->set_number('5260823')->is_valid_number, '滋賀県長浜市常喜町');
ok($zip->set_number('5260824')->is_valid_number, '滋賀県長浜市名越町');
ok($zip->set_number('5260825')->is_valid_number, '滋賀県長浜市布勢町');
ok($zip->set_number('5260826')->is_valid_number, '滋賀県長浜市小一条町');
ok($zip->set_number('5260827')->is_valid_number, '滋賀県長浜市加田今町');
ok($zip->set_number('5260828')->is_valid_number, '滋賀県長浜市加田町');
ok($zip->set_number('5260829')->is_valid_number, '滋賀県長浜市田村町');
ok($zip->set_number('5260831')->is_valid_number, '滋賀県長浜市宮司町');
ok($zip->set_number('5260832')->is_valid_number, '滋賀県長浜市大東町');
ok($zip->set_number('5260833')->is_valid_number, '滋賀県長浜市永久寺町');
ok($zip->set_number('5260834')->is_valid_number, '滋賀県長浜市大辰巳町');
ok($zip->set_number('5260835')->is_valid_number, '滋賀県長浜市室町');
ok($zip->set_number('5260841')->is_valid_number, '滋賀県長浜市新栄町');
ok($zip->set_number('5260842')->is_valid_number, '滋賀県長浜市春近町');
ok($zip->set_number('5260843')->is_valid_number, '滋賀県長浜市南小足町');
ok($zip->set_number('5260844')->is_valid_number, '滋賀県長浜市南田附町');
ok($zip->set_number('5260845')->is_valid_number, '滋賀県長浜市小堀町');
ok($zip->set_number('5260846')->is_valid_number, '滋賀県長浜市川崎町');
ok($zip->set_number('5260847')->is_valid_number, '滋賀県長浜市山階町');
ok($zip->set_number('5270000')->is_valid_number, '滋賀県東近江市以下に掲載がない場合');
ok($zip->set_number('5270001')->is_valid_number, '滋賀県東近江市建部下野町');
ok($zip->set_number('5270002')->is_valid_number, '滋賀県東近江市建部上中町');
ok($zip->set_number('5270003')->is_valid_number, '滋賀県東近江市建部北町');
ok($zip->set_number('5270004')->is_valid_number, '滋賀県東近江市建部堺町');
ok($zip->set_number('5270005')->is_valid_number, '滋賀県東近江市建部南町');
ok($zip->set_number('5270006')->is_valid_number, '滋賀県東近江市建部日吉町');
ok($zip->set_number('5270007')->is_valid_number, '滋賀県東近江市建部瓦屋寺町');
ok($zip->set_number('5270011')->is_valid_number, '滋賀県東近江市八日市浜野町');
ok($zip->set_number('5270012')->is_valid_number, '滋賀県東近江市八日市本町');
ok($zip->set_number('5270013')->is_valid_number, '滋賀県東近江市東中野町');
ok($zip->set_number('5270014')->is_valid_number, '滋賀県東近江市西中野町');
ok($zip->set_number('5270015')->is_valid_number, '滋賀県東近江市中野町');
ok($zip->set_number('5270016')->is_valid_number, '滋賀県東近江市今崎町');
ok($zip->set_number('5270017')->is_valid_number, '滋賀県東近江市昭和町');
ok($zip->set_number('5270018')->is_valid_number, '滋賀県東近江市八日市清水');
ok($zip->set_number('5270019')->is_valid_number, '滋賀県東近江市八日市松尾町');
ok($zip->set_number('5270021')->is_valid_number, '滋賀県東近江市八日市東浜町');
ok($zip->set_number('5270022')->is_valid_number, '滋賀県東近江市八日市上之町');
ok($zip->set_number('5270023')->is_valid_number, '滋賀県東近江市八日市緑町');
ok($zip->set_number('5270024')->is_valid_number, '滋賀県東近江市札の辻');
ok($zip->set_number('5270025')->is_valid_number, '滋賀県東近江市八日市東本町');
ok($zip->set_number('5270026')->is_valid_number, '滋賀県東近江市八日市野々宮町');
ok($zip->set_number('5270027')->is_valid_number, '滋賀県東近江市栄町');
ok($zip->set_number('5270028')->is_valid_number, '滋賀県東近江市八日市金屋');
ok($zip->set_number('5270029')->is_valid_number, '滋賀県東近江市八日市町');
ok($zip->set_number('5270031')->is_valid_number, '滋賀県東近江市幸町');
ok($zip->set_number('5270032')->is_valid_number, '滋賀県東近江市春日町');
ok($zip->set_number('5270033')->is_valid_number, '滋賀県東近江市東沖野');
ok($zip->set_number('5270034')->is_valid_number, '滋賀県東近江市沖野');
ok($zip->set_number('5270035')->is_valid_number, '滋賀県東近江市ひばり丘町');
ok($zip->set_number('5270036')->is_valid_number, '滋賀県東近江市聖和町');
ok($zip->set_number('5270037')->is_valid_number, '滋賀県東近江市東今崎町');
ok($zip->set_number('5270038')->is_valid_number, '滋賀県東近江市聖徳町');
ok($zip->set_number('5270039')->is_valid_number, '滋賀県東近江市青葉町');
ok($zip->set_number('5270041')->is_valid_number, '滋賀県東近江市川合寺町');
ok($zip->set_number('5270042')->is_valid_number, '滋賀県東近江市外町');
ok($zip->set_number('5270043')->is_valid_number, '滋賀県東近江市神田町');
ok($zip->set_number('5270044')->is_valid_number, '滋賀県東近江市五智町');
ok($zip->set_number('5270045')->is_valid_number, '滋賀県東近江市中小路町');
ok($zip->set_number('5270046')->is_valid_number, '滋賀県東近江市妙法寺町');
ok($zip->set_number('5270047')->is_valid_number, '滋賀県東近江市野村町');
ok($zip->set_number('5270051')->is_valid_number, '滋賀県東近江市林田町');
ok($zip->set_number('5270052')->is_valid_number, '滋賀県東近江市寺町');
ok($zip->set_number('5270053')->is_valid_number, '滋賀県東近江市今代町');
ok($zip->set_number('5270054')->is_valid_number, '滋賀県東近江市池田町');
ok($zip->set_number('5270055')->is_valid_number, '滋賀県東近江市瓜生津町');
ok($zip->set_number('5270056')->is_valid_number, '滋賀県東近江市御園町');
ok($zip->set_number('5270057')->is_valid_number, '滋賀県東近江市岡田町');
ok($zip->set_number('5270061')->is_valid_number, '滋賀県東近江市土器町');
ok($zip->set_number('5270062')->is_valid_number, '滋賀県東近江市上大森町');
ok($zip->set_number('5270063')->is_valid_number, '滋賀県東近江市大森町');
ok($zip->set_number('5270064')->is_valid_number, '滋賀県東近江市尻無町');
ok($zip->set_number('5270065')->is_valid_number, '滋賀県東近江市下二俣町');
ok($zip->set_number('5270066')->is_valid_number, '滋賀県東近江市柴原南町');
ok($zip->set_number('5270067')->is_valid_number, '滋賀県東近江市芝原町');
ok($zip->set_number('5270071')->is_valid_number, '滋賀県東近江市今堀町');
ok($zip->set_number('5270072')->is_valid_number, '滋賀県東近江市布引台');
ok($zip->set_number('5270073')->is_valid_number, '滋賀県東近江市蛇溝町');
ok($zip->set_number('5270074')->is_valid_number, '滋賀県東近江市市辺町');
ok($zip->set_number('5270075')->is_valid_number, '滋賀県東近江市三津屋町');
ok($zip->set_number('5270076')->is_valid_number, '滋賀県東近江市野口町');
ok($zip->set_number('5270081')->is_valid_number, '滋賀県東近江市布施町');
ok($zip->set_number('5270082')->is_valid_number, '滋賀県東近江市上羽田町');
ok($zip->set_number('5270083')->is_valid_number, '滋賀県東近江市柏木町');
ok($zip->set_number('5270084')->is_valid_number, '滋賀県東近江市中羽田町');
ok($zip->set_number('5270085')->is_valid_number, '滋賀県東近江市下羽田町');
ok($zip->set_number('5270086')->is_valid_number, '滋賀県東近江市上平木町');
ok($zip->set_number('5270087')->is_valid_number, '滋賀県東近江市平田町');
ok($zip->set_number('5270091')->is_valid_number, '滋賀県東近江市小脇町');
ok($zip->set_number('5270092')->is_valid_number, '滋賀県東近江市小今町');
ok($zip->set_number('5270093')->is_valid_number, '滋賀県東近江市糠塚町');
ok($zip->set_number('5270101')->is_valid_number, '滋賀県東近江市祇園町');
ok($zip->set_number('5270102')->is_valid_number, '滋賀県東近江市平柳町');
ok($zip->set_number('5270103')->is_valid_number, '滋賀県東近江市湯屋町');
ok($zip->set_number('5270104')->is_valid_number, '滋賀県東近江市読合堂町');
ok($zip->set_number('5270105')->is_valid_number, '滋賀県東近江市中里町');
ok($zip->set_number('5270106')->is_valid_number, '滋賀県東近江市僧坊町');
ok($zip->set_number('5270107')->is_valid_number, '滋賀県東近江市今在家町');
ok($zip->set_number('5270108')->is_valid_number, '滋賀県東近江市小八木町');
ok($zip->set_number('5270111')->is_valid_number, '滋賀県東近江市北花沢町');
ok($zip->set_number('5270112')->is_valid_number, '滋賀県東近江市南花沢町');
ok($zip->set_number('5270113')->is_valid_number, '滋賀県東近江市池庄町');
ok($zip->set_number('5270114')->is_valid_number, '滋賀県東近江市大沢町');
ok($zip->set_number('5270115')->is_valid_number, '滋賀県東近江市下里町');
ok($zip->set_number('5270121')->is_valid_number, '滋賀県東近江市小池町');
ok($zip->set_number('5270122')->is_valid_number, '滋賀県東近江市長町');
ok($zip->set_number('5270123')->is_valid_number, '滋賀県東近江市中岸本町');
ok($zip->set_number('5270124')->is_valid_number, '滋賀県東近江市下岸本町');
ok($zip->set_number('5270125')->is_valid_number, '滋賀県東近江市小田苅町');
ok($zip->set_number('5270126')->is_valid_number, '滋賀県東近江市大清水町');
ok($zip->set_number('5270127')->is_valid_number, '滋賀県東近江市南清水町');
ok($zip->set_number('5270128')->is_valid_number, '滋賀県東近江市清水中町');
ok($zip->set_number('5270129')->is_valid_number, '滋賀県東近江市北清水町');
ok($zip->set_number('5270131')->is_valid_number, '滋賀県東近江市勝堂町');
ok($zip->set_number('5270132')->is_valid_number, '滋賀県東近江市下一色町');
ok($zip->set_number('5270133')->is_valid_number, '滋賀県東近江市中一色町');
ok($zip->set_number('5270134')->is_valid_number, '滋賀県東近江市平松町');
ok($zip->set_number('5270135')->is_valid_number, '滋賀県東近江市横溝町');
ok($zip->set_number('5270136')->is_valid_number, '滋賀県東近江市南菩提寺町');
ok($zip->set_number('5270137')->is_valid_number, '滋賀県東近江市西菩提寺町');
ok($zip->set_number('5270138')->is_valid_number, '滋賀県東近江市北菩提寺町');
ok($zip->set_number('5270141')->is_valid_number, '滋賀県東近江市百済寺甲町');
ok($zip->set_number('5270142')->is_valid_number, '滋賀県東近江市上山町');
ok($zip->set_number('5270143')->is_valid_number, '滋賀県東近江市百済寺本町');
ok($zip->set_number('5270144')->is_valid_number, '滋賀県東近江市百済寺町');
ok($zip->set_number('5270145')->is_valid_number, '滋賀県東近江市北坂町');
ok($zip->set_number('5270151')->is_valid_number, '滋賀県東近江市市ケ原町');
ok($zip->set_number('5270152')->is_valid_number, '滋賀県東近江市大覚寺町');
ok($zip->set_number('5270153')->is_valid_number, '滋賀県東近江市平尾町');
ok($zip->set_number('5270154')->is_valid_number, '滋賀県東近江市園町');
ok($zip->set_number('5270155')->is_valid_number, '滋賀県東近江市大林町');
ok($zip->set_number('5270156')->is_valid_number, '滋賀県東近江市上中野町');
ok($zip->set_number('5270157')->is_valid_number, '滋賀県東近江市下中野町');
ok($zip->set_number('5270161')->is_valid_number, '滋賀県東近江市中戸町');
ok($zip->set_number('5270162')->is_valid_number, '滋賀県東近江市妹町');
ok($zip->set_number('5270163')->is_valid_number, '滋賀県東近江市曽根町');
ok($zip->set_number('5270164')->is_valid_number, '滋賀県東近江市青山町');
ok($zip->set_number('5270165')->is_valid_number, '滋賀県東近江市小倉町');
ok($zip->set_number('5270166')->is_valid_number, '滋賀県東近江市愛東外町');
ok($zip->set_number('5270171')->is_valid_number, '滋賀県東近江市池之尻町');
ok($zip->set_number('5270172')->is_valid_number, '滋賀県東近江市鯰江町');
ok($zip->set_number('5270173')->is_valid_number, '滋賀県東近江市上岸本町');
ok($zip->set_number('5270174')->is_valid_number, '滋賀県東近江市大萩町');
ok($zip->set_number('5270175')->is_valid_number, '滋賀県東近江市梅林町');
ok($zip->set_number('5270201')->is_valid_number, '滋賀県東近江市蛭谷町');
ok($zip->set_number('5270202')->is_valid_number, '滋賀県東近江市君ケ畑町');
ok($zip->set_number('5270203')->is_valid_number, '滋賀県東近江市箕川町');
ok($zip->set_number('5270204')->is_valid_number, '滋賀県東近江市政所町');
ok($zip->set_number('5270205')->is_valid_number, '滋賀県東近江市黄和田町');
ok($zip->set_number('5270206')->is_valid_number, '滋賀県東近江市杠葉尾町');
ok($zip->set_number('5270207')->is_valid_number, '滋賀県東近江市蓼畑町');
ok($zip->set_number('5270208')->is_valid_number, '滋賀県東近江市萱尾町');
ok($zip->set_number('5270209')->is_valid_number, '滋賀県東近江市佐目町');
ok($zip->set_number('5270211')->is_valid_number, '滋賀県東近江市永源寺相谷町');
ok($zip->set_number('5270212')->is_valid_number, '滋賀県東近江市永源寺高野町');
ok($zip->set_number('5270213')->is_valid_number, '滋賀県東近江市和南町');
ok($zip->set_number('5270214')->is_valid_number, '滋賀県東近江市甲津畑町');
ok($zip->set_number('5270215')->is_valid_number, '滋賀県東近江市九居瀬町');
ok($zip->set_number('5270216')->is_valid_number, '滋賀県東近江市茨川町');
ok($zip->set_number('5270221')->is_valid_number, '滋賀県東近江市上二俣町');
ok($zip->set_number('5270222')->is_valid_number, '滋賀県東近江市池之脇町');
ok($zip->set_number('5270223')->is_valid_number, '滋賀県東近江市高木町');
ok($zip->set_number('5270224')->is_valid_number, '滋賀県東近江市市原野町');
ok($zip->set_number('5270225')->is_valid_number, '滋賀県東近江市新出町');
ok($zip->set_number('5270226')->is_valid_number, '滋賀県東近江市一式町');
ok($zip->set_number('5270227')->is_valid_number, '滋賀県東近江市石谷町');
ok($zip->set_number('5270228')->is_valid_number, '滋賀県東近江市如来町');
ok($zip->set_number('5270231')->is_valid_number, '滋賀県東近江市山上町');
ok($zip->set_number('5270232')->is_valid_number, '滋賀県東近江市青野町');
ok($zip->set_number('5280000')->is_valid_number, '滋賀県甲賀市以下に掲載がない場合');
ok($zip->set_number('5280001')->is_valid_number, '滋賀県甲賀市水口町中畑');
ok($zip->set_number('5280002')->is_valid_number, '滋賀県甲賀市水口町今郷');
ok($zip->set_number('5280003')->is_valid_number, '滋賀県甲賀市水口町和野');
ok($zip->set_number('5280004')->is_valid_number, '滋賀県甲賀市水口町嶬峨');
ok($zip->set_number('5280005')->is_valid_number, '滋賀県甲賀市水口町水口');
ok($zip->set_number('5280006')->is_valid_number, '滋賀県甲賀市水口町元町');
ok($zip->set_number('5280007')->is_valid_number, '滋賀県甲賀市水口町新城');
ok($zip->set_number('5280011')->is_valid_number, '滋賀県甲賀市水口町高塚');
ok($zip->set_number('5280012')->is_valid_number, '滋賀県甲賀市水口町暁');
ok($zip->set_number('5280013')->is_valid_number, '滋賀県甲賀市水口町宮の前');
ok($zip->set_number('5280014')->is_valid_number, '滋賀県甲賀市水口町鹿深');
ok($zip->set_number('5280015')->is_valid_number, '滋賀県甲賀市水口町松栄');
ok($zip->set_number('5280016')->is_valid_number, '滋賀県甲賀市水口町神明');
ok($zip->set_number('5280017')->is_valid_number, '滋賀県甲賀市水口町京町');
ok($zip->set_number('5280020')->is_valid_number, '滋賀県甲賀市水口町的場');
ok($zip->set_number('5280021')->is_valid_number, '滋賀県甲賀市水口町八光');
ok($zip->set_number('5280022')->is_valid_number, '滋賀県甲賀市水口町梅が丘');
ok($zip->set_number('5280023')->is_valid_number, '滋賀県甲賀市水口町本丸');
ok($zip->set_number('5280024')->is_valid_number, '滋賀県甲賀市水口町中邸');
ok($zip->set_number('5280025')->is_valid_number, '滋賀県甲賀市水口町西林口');
ok($zip->set_number('5280026')->is_valid_number, '滋賀県甲賀市水口町東林口');
ok($zip->set_number('5280027')->is_valid_number, '滋賀県甲賀市水口町城内');
ok($zip->set_number('5280028')->is_valid_number, '滋賀県甲賀市水口町城東');
ok($zip->set_number('5280029')->is_valid_number, '滋賀県甲賀市水口町南林口');
ok($zip->set_number('5280031')->is_valid_number, '滋賀県甲賀市水口町本町');
ok($zip->set_number('5280032')->is_valid_number, '滋賀県甲賀市水口町八坂');
ok($zip->set_number('5280033')->is_valid_number, '滋賀県甲賀市水口町綾野');
ok($zip->set_number('5280034')->is_valid_number, '滋賀県甲賀市水口町日電');
ok($zip->set_number('5280035')->is_valid_number, '滋賀県甲賀市水口町名坂');
ok($zip->set_number('5280036')->is_valid_number, '滋賀県甲賀市水口町東名坂');
ok($zip->set_number('5280037')->is_valid_number, '滋賀県甲賀市水口町本綾野');
ok($zip->set_number('5280038')->is_valid_number, '滋賀県甲賀市水口町新町');
ok($zip->set_number('5280040')->is_valid_number, '滋賀県甲賀市水口町三本柳');
ok($zip->set_number('5280041')->is_valid_number, '滋賀県甲賀市水口町虫生野');
ok($zip->set_number('5280042')->is_valid_number, '滋賀県甲賀市水口町虫生野中央');
ok($zip->set_number('5280043')->is_valid_number, '滋賀県甲賀市水口町杣中');
ok($zip->set_number('5280044')->is_valid_number, '滋賀県甲賀市水口町山上');
ok($zip->set_number('5280045')->is_valid_number, '滋賀県甲賀市水口町牛飼');
ok($zip->set_number('5280046')->is_valid_number, '滋賀県甲賀市水口町三大寺');
ok($zip->set_number('5280047')->is_valid_number, '滋賀県甲賀市水口町岩坂');
ok($zip->set_number('5280048')->is_valid_number, '滋賀県甲賀市水口町高山');
ok($zip->set_number('5280049')->is_valid_number, '滋賀県甲賀市水口町貴生川');
ok($zip->set_number('5280051')->is_valid_number, '滋賀県甲賀市水口町北内貴');
ok($zip->set_number('5280052')->is_valid_number, '滋賀県甲賀市水口町宇川');
ok($zip->set_number('5280053')->is_valid_number, '滋賀県甲賀市水口町宇田');
ok($zip->set_number('5280054')->is_valid_number, '滋賀県甲賀市水口町酒人');
ok($zip->set_number('5280055')->is_valid_number, '滋賀県甲賀市水口町植');
ok($zip->set_number('5280056')->is_valid_number, '滋賀県甲賀市水口町泉');
ok($zip->set_number('5280057')->is_valid_number, '滋賀県甲賀市水口町北脇');
ok($zip->set_number('5280058')->is_valid_number, '滋賀県甲賀市水口町北泉');
ok($zip->set_number('5280061')->is_valid_number, '滋賀県甲賀市水口町笹が丘');
ok($zip->set_number('5280062')->is_valid_number, '滋賀県甲賀市水口町さつきが丘');
ok($zip->set_number('5280063')->is_valid_number, '滋賀県甲賀市水口町下山');
ok($zip->set_number('5280064')->is_valid_number, '滋賀県甲賀市水口町伴中山');
ok($zip->set_number('5280065')->is_valid_number, '滋賀県甲賀市水口町春日');
ok($zip->set_number('5280066')->is_valid_number, '滋賀県甲賀市水口町八田');
ok($zip->set_number('5280067')->is_valid_number, '滋賀県甲賀市水口町山');
ok($zip->set_number('5280068')->is_valid_number, '滋賀県甲賀市水口町ひのきが丘');
ok($zip->set_number('5280069')->is_valid_number, '滋賀県甲賀市水口町虫生野虹の町');
ok($zip->set_number('5280071')->is_valid_number, '滋賀県甲賀市水口町秋葉');
ok($zip->set_number('5280072')->is_valid_number, '滋賀県甲賀市水口町朝日が丘');
ok($zip->set_number('5280073')->is_valid_number, '滋賀県甲賀市水口町古城が丘');
ok($zip->set_number('5280074')->is_valid_number, '滋賀県甲賀市水口町松尾');
ok($zip->set_number('5280201')->is_valid_number, '滋賀県甲賀市土山町大河原');
ok($zip->set_number('5280202')->is_valid_number, '滋賀県甲賀市土山町鮎河');
ok($zip->set_number('5280203')->is_valid_number, '滋賀県甲賀市土山町黒滝');
ok($zip->set_number('5280204')->is_valid_number, '滋賀県甲賀市土山町山女原');
ok($zip->set_number('5280205')->is_valid_number, '滋賀県甲賀市土山町笹路');
ok($zip->set_number('5280206')->is_valid_number, '滋賀県甲賀市土山町山中');
ok($zip->set_number('5280207')->is_valid_number, '滋賀県甲賀市土山町猪鼻');
ok($zip->set_number('5280208')->is_valid_number, '滋賀県甲賀市土山町黒川');
ok($zip->set_number('5280211')->is_valid_number, '滋賀県甲賀市土山町北土山');
ok($zip->set_number('5280212')->is_valid_number, '滋賀県甲賀市土山町南土山');
ok($zip->set_number('5280213')->is_valid_number, '滋賀県甲賀市土山町大澤');
ok($zip->set_number('5280221')->is_valid_number, '滋賀県甲賀市土山町青土');
ok($zip->set_number('5280222')->is_valid_number, '滋賀県甲賀市土山町平子');
ok($zip->set_number('5280223')->is_valid_number, '滋賀県甲賀市土山町瀬ノ音');
ok($zip->set_number('5280224')->is_valid_number, '滋賀県甲賀市土山町野上野');
ok($zip->set_number('5280231')->is_valid_number, '滋賀県甲賀市土山町頓宮');
ok($zip->set_number('5280232')->is_valid_number, '滋賀県甲賀市土山町前野');
ok($zip->set_number('5280233')->is_valid_number, '滋賀県甲賀市土山町市場');
ok($zip->set_number('5280234')->is_valid_number, '滋賀県甲賀市土山町徳原');
ok($zip->set_number('5280235')->is_valid_number, '滋賀県甲賀市土山町大野');
ok($zip->set_number('5290101')->is_valid_number, '滋賀県長浜市唐国町');
ok($zip->set_number('5290102')->is_valid_number, '滋賀県長浜市月ヶ瀬町');
ok($zip->set_number('5290103')->is_valid_number, '滋賀県長浜市中野町');
ok($zip->set_number('5290111')->is_valid_number, '滋賀県長浜市三川町');
ok($zip->set_number('5290112')->is_valid_number, '滋賀県長浜市宮部町');
ok($zip->set_number('5290113')->is_valid_number, '滋賀県長浜市大井町');
ok($zip->set_number('5290121')->is_valid_number, '滋賀県長浜市桜町');
ok($zip->set_number('5290122')->is_valid_number, '滋賀県長浜市酢');
ok($zip->set_number('5290123')->is_valid_number, '滋賀県長浜市西大井町');
ok($zip->set_number('5290131')->is_valid_number, '滋賀県長浜市柿ノ木');
ok($zip->set_number('5290132')->is_valid_number, '滋賀県長浜市長田町');
ok($zip->set_number('5290133')->is_valid_number, '滋賀県長浜市新旭町');
ok($zip->set_number('5290141')->is_valid_number, '滋賀県長浜市五村');
ok($zip->set_number('5290142')->is_valid_number, '滋賀県長浜市田町');
ok($zip->set_number('5290143')->is_valid_number, '滋賀県長浜市本町');
ok($zip->set_number('5290144')->is_valid_number, '滋賀県長浜市大寺町');
ok($zip->set_number('5290201')->is_valid_number, '滋賀県長浜市高月町横山');
ok($zip->set_number('5290202')->is_valid_number, '滋賀県長浜市高月町東高田');
ok($zip->set_number('5290203')->is_valid_number, '滋賀県長浜市高月町磯野');
ok($zip->set_number('5290204')->is_valid_number, '滋賀県長浜市高月町布施');
ok($zip->set_number('5290205')->is_valid_number, '滋賀県長浜市高月町唐川');
ok($zip->set_number('5290211')->is_valid_number, '滋賀県長浜市高月町保延寺');
ok($zip->set_number('5290212')->is_valid_number, '滋賀県長浜市高月町井口');
ok($zip->set_number('5290213')->is_valid_number, '滋賀県長浜市高月町持寺');
ok($zip->set_number('5290214')->is_valid_number, '滋賀県長浜市高月町洞戸');
ok($zip->set_number('5290215')->is_valid_number, '滋賀県長浜市高月町尾山');
ok($zip->set_number('5290221')->is_valid_number, '滋賀県長浜市高月町高野');
ok($zip->set_number('5290222')->is_valid_number, '滋賀県長浜市高月町雨森');
ok($zip->set_number('5290223')->is_valid_number, '滋賀県長浜市高月町馬上');
ok($zip->set_number('5290231')->is_valid_number, '滋賀県長浜市高月町森本');
ok($zip->set_number('5290232')->is_valid_number, '滋賀県長浜市高月町落川');
ok($zip->set_number('5290233')->is_valid_number, '滋賀県長浜市高月町渡岸寺');
ok($zip->set_number('5290234')->is_valid_number, '滋賀県長浜市高月町柏原');
ok($zip->set_number('5290241')->is_valid_number, '滋賀県長浜市高月町高月');
ok($zip->set_number('5290251')->is_valid_number, '滋賀県長浜市高月町宇根');
ok($zip->set_number('5290252')->is_valid_number, '滋賀県長浜市高月町東阿閉');
ok($zip->set_number('5290253')->is_valid_number, '滋賀県長浜市高月町西阿閉');
ok($zip->set_number('5290261')->is_valid_number, '滋賀県長浜市高月町東物部');
ok($zip->set_number('5290262')->is_valid_number, '滋賀県長浜市高月町西物部');
ok($zip->set_number('5290263')->is_valid_number, '滋賀県長浜市高月町東柳野');
ok($zip->set_number('5290264')->is_valid_number, '滋賀県長浜市高月町柳野中');
ok($zip->set_number('5290265')->is_valid_number, '滋賀県長浜市高月町西柳野');
ok($zip->set_number('5290271')->is_valid_number, '滋賀県長浜市高月町熊野');
ok($zip->set_number('5290272')->is_valid_number, '滋賀県長浜市高月町片山');
ok($zip->set_number('5290273')->is_valid_number, '滋賀県長浜市高月町西野');
ok($zip->set_number('5290274')->is_valid_number, '滋賀県長浜市高月町松尾');
ok($zip->set_number('5290275')->is_valid_number, '滋賀県長浜市高月町重則');
ok($zip->set_number('5290301')->is_valid_number, '滋賀県長浜市小谷上山田町');
ok($zip->set_number('5290302')->is_valid_number, '滋賀県長浜市下山田');
ok($zip->set_number('5290303')->is_valid_number, '滋賀県長浜市湖北町二俣');
ok($zip->set_number('5290304')->is_valid_number, '滋賀県長浜市小谷丁野町');
ok($zip->set_number('5290311')->is_valid_number, '滋賀県長浜市小谷美濃山町');
ok($zip->set_number('5290312')->is_valid_number, '滋賀県長浜市小谷郡上町');
ok($zip->set_number('5290313')->is_valid_number, '滋賀県長浜市湖北町伊部');
ok($zip->set_number('5290314')->is_valid_number, '滋賀県長浜市湖北町留目');
ok($zip->set_number('5290315')->is_valid_number, '滋賀県長浜市湖北町別所');
ok($zip->set_number('5290316')->is_valid_number, '滋賀県長浜市湖北町河毛');
ok($zip->set_number('5290317')->is_valid_number, '滋賀県長浜市湖北町山脇');
ok($zip->set_number('5290321')->is_valid_number, '滋賀県長浜市湖北町賀');
ok($zip->set_number('5290322')->is_valid_number, '滋賀県長浜市湖北町小今');
ok($zip->set_number('5290331')->is_valid_number, '滋賀県長浜市湖北町八日市');
ok($zip->set_number('5290332')->is_valid_number, '滋賀県長浜市湖北町青名');
ok($zip->set_number('5290333')->is_valid_number, '滋賀県長浜市湖北今町');
ok($zip->set_number('5290334')->is_valid_number, '滋賀県長浜市湖北町沢');
ok($zip->set_number('5290335')->is_valid_number, '滋賀県長浜市湖北町猫口');
ok($zip->set_number('5290341')->is_valid_number, '滋賀県長浜市湖北町速水');
ok($zip->set_number('5290342')->is_valid_number, '滋賀県長浜市湖北高田町');
ok($zip->set_number('5290343')->is_valid_number, '滋賀県長浜市湖北町小倉');
ok($zip->set_number('5290344')->is_valid_number, '滋賀県長浜市湖北町馬渡');
ok($zip->set_number('5290345')->is_valid_number, '滋賀県長浜市湖北町大安寺');
ok($zip->set_number('5290346')->is_valid_number, '滋賀県長浜市湖北町南速水');
ok($zip->set_number('5290351')->is_valid_number, '滋賀県長浜市大光寺町');
ok($zip->set_number('5290352')->is_valid_number, '滋賀県長浜市湖北町五坪');
ok($zip->set_number('5290353')->is_valid_number, '滋賀県長浜市湖北町田中');
ok($zip->set_number('5290354')->is_valid_number, '滋賀県長浜市湖北町山本');
ok($zip->set_number('5290361')->is_valid_number, '滋賀県長浜市湖北町石川');
ok($zip->set_number('5290362')->is_valid_number, '滋賀県長浜市湖北町津里');
ok($zip->set_number('5290363')->is_valid_number, '滋賀県長浜市湖北東尾上町');
ok($zip->set_number('5290364')->is_valid_number, '滋賀県長浜市湖北町尾上');
ok($zip->set_number('5290365')->is_valid_number, '滋賀県長浜市湖北町今西');
ok($zip->set_number('5290366')->is_valid_number, '滋賀県長浜市湖北町延勝寺');
ok($zip->set_number('5290367')->is_valid_number, '滋賀県長浜市湖北町海老江');
ok($zip->set_number('5290401')->is_valid_number, '滋賀県長浜市木之本町金居原');
ok($zip->set_number('5290402')->is_valid_number, '滋賀県長浜市木之本町杉野');
ok($zip->set_number('5290403')->is_valid_number, '滋賀県長浜市木之本町音羽');
ok($zip->set_number('5290404')->is_valid_number, '滋賀県長浜市木之本町杉本');
ok($zip->set_number('5290411')->is_valid_number, '滋賀県長浜市木之本町古橋');
ok($zip->set_number('5290412')->is_valid_number, '滋賀県長浜市木之本町石道');
ok($zip->set_number('5290413')->is_valid_number, '滋賀県長浜市木之本町小山');
ok($zip->set_number('5290414')->is_valid_number, '滋賀県長浜市木之本町川合');
ok($zip->set_number('5290415')->is_valid_number, '滋賀県長浜市木之本町大見');
ok($zip->set_number('5290421')->is_valid_number, '滋賀県長浜市木之本町アットリ');
ok($zip->set_number('5290422')->is_valid_number, '滋賀県長浜市木之本町田部');
ok($zip->set_number('5290423')->is_valid_number, '滋賀県長浜市木之本町千田');
ok($zip->set_number('5290424')->is_valid_number, '滋賀県長浜市木之本町廣瀬');
ok($zip->set_number('5290425')->is_valid_number, '滋賀県長浜市木之本町木之本');
ok($zip->set_number('5290426')->is_valid_number, '滋賀県長浜市木之本町黒田');
ok($zip->set_number('5290431')->is_valid_number, '滋賀県長浜市木之本町大音');
ok($zip->set_number('5290432')->is_valid_number, '滋賀県長浜市木之本町田居');
ok($zip->set_number('5290433')->is_valid_number, '滋賀県長浜市木之本町西山');
ok($zip->set_number('5290434')->is_valid_number, '滋賀県長浜市木之本町北布施');
ok($zip->set_number('5290435')->is_valid_number, '滋賀県長浜市木之本町赤尾');
ok($zip->set_number('5290436')->is_valid_number, '滋賀県長浜市木之本町山梨子');
ok($zip->set_number('5290437')->is_valid_number, '滋賀県長浜市木之本町飯浦(その他)');
ok($zip->set_number('5290501')->is_valid_number, '滋賀県長浜市余呉町針川');
ok($zip->set_number('5290502')->is_valid_number, '滋賀県長浜市余呉町尾羽梨');
ok($zip->set_number('5290503')->is_valid_number, '滋賀県長浜市余呉町奥川並');
ok($zip->set_number('5290504')->is_valid_number, '滋賀県長浜市余呉町田戸');
ok($zip->set_number('5290505')->is_valid_number, '滋賀県長浜市余呉町小原');
ok($zip->set_number('5290506')->is_valid_number, '滋賀県長浜市余呉町鷲見');
ok($zip->set_number('5290511')->is_valid_number, '滋賀県長浜市余呉町菅並');
ok($zip->set_number('5290512')->is_valid_number, '滋賀県長浜市余呉町上丹生');
ok($zip->set_number('5290513')->is_valid_number, '滋賀県長浜市余呉町摺墨');
ok($zip->set_number('5290514')->is_valid_number, '滋賀県長浜市余呉町下丹生');
ok($zip->set_number('5290515')->is_valid_number, '滋賀県長浜市余呉町中之郷');
ok($zip->set_number('5290521')->is_valid_number, '滋賀県長浜市余呉町下余呉');
ok($zip->set_number('5290522')->is_valid_number, '滋賀県長浜市余呉町坂口');
ok($zip->set_number('5290523')->is_valid_number, '滋賀県長浜市余呉町川並');
ok($zip->set_number('5290524')->is_valid_number, '滋賀県長浜市余呉町八戸');
ok($zip->set_number('5290525')->is_valid_number, '滋賀県長浜市余呉町文室');
ok($zip->set_number('5290526')->is_valid_number, '滋賀県長浜市余呉町国安');
ok($zip->set_number('5290527')->is_valid_number, '滋賀県長浜市余呉町東野');
ok($zip->set_number('5290531')->is_valid_number, '滋賀県長浜市余呉町中河内');
ok($zip->set_number('5290532')->is_valid_number, '滋賀県長浜市余呉町椿坂');
ok($zip->set_number('5290533')->is_valid_number, '滋賀県長浜市余呉町柳ケ瀬');
ok($zip->set_number('5290534')->is_valid_number, '滋賀県長浜市余呉町小谷');
ok($zip->set_number('5290535')->is_valid_number, '滋賀県長浜市余呉町今市');
ok($zip->set_number('5290536')->is_valid_number, '滋賀県長浜市余呉町池原');
ok($zip->set_number('5290537')->is_valid_number, '滋賀県長浜市余呉町新堂');
ok($zip->set_number('5290541')->is_valid_number, '滋賀県長浜市木之本町飯浦(坂尻)');
ok($zip->set_number('5290701')->is_valid_number, '滋賀県長浜市西浅井町塩津浜');
ok($zip->set_number('5290702')->is_valid_number, '滋賀県長浜市西浅井町祝山');
ok($zip->set_number('5290703')->is_valid_number, '滋賀県長浜市西浅井町野坂');
ok($zip->set_number('5290704')->is_valid_number, '滋賀県長浜市西浅井町塩津中');
ok($zip->set_number('5290705')->is_valid_number, '滋賀県長浜市西浅井町横波');
ok($zip->set_number('5290706')->is_valid_number, '滋賀県長浜市西浅井町余');
ok($zip->set_number('5290707')->is_valid_number, '滋賀県長浜市西浅井町集福寺');
ok($zip->set_number('5290708')->is_valid_number, '滋賀県長浜市西浅井町沓掛');
ok($zip->set_number('5290711')->is_valid_number, '滋賀県長浜市西浅井町岩熊');
ok($zip->set_number('5290712')->is_valid_number, '滋賀県長浜市西浅井町月出');
ok($zip->set_number('5290713')->is_valid_number, '滋賀県長浜市西浅井町八田部');
ok($zip->set_number('5290714')->is_valid_number, '滋賀県長浜市西浅井町小山');
ok($zip->set_number('5290715')->is_valid_number, '滋賀県長浜市西浅井町山田');
ok($zip->set_number('5290721')->is_valid_number, '滋賀県長浜市西浅井町大浦');
ok($zip->set_number('5290722')->is_valid_number, '滋賀県長浜市西浅井町庄');
ok($zip->set_number('5290723')->is_valid_number, '滋賀県長浜市西浅井町中');
ok($zip->set_number('5290724')->is_valid_number, '滋賀県長浜市西浅井町山門');
ok($zip->set_number('5290725')->is_valid_number, '滋賀県長浜市西浅井町黒山');
ok($zip->set_number('5290726')->is_valid_number, '滋賀県長浜市西浅井町菅浦');
ok($zip->set_number('5291100')->is_valid_number, '滋賀県犬上郡豊郷町以下に掲載がない場合');
ok($zip->set_number('5291151')->is_valid_number, '滋賀県彦根市楡町');
ok($zip->set_number('5291152')->is_valid_number, '滋賀県彦根市安食中町');
ok($zip->set_number('5291153')->is_valid_number, '滋賀県彦根市太堂町');
ok($zip->set_number('5291154')->is_valid_number, '滋賀県彦根市千尋町');
ok($zip->set_number('5291155')->is_valid_number, '滋賀県彦根市賀田山町');
ok($zip->set_number('5291156')->is_valid_number, '滋賀県彦根市清崎町');
ok($zip->set_number('5291161')->is_valid_number, '滋賀県犬上郡豊郷町四十九院');
ok($zip->set_number('5291162')->is_valid_number, '滋賀県犬上郡豊郷町八町');
ok($zip->set_number('5291163')->is_valid_number, '滋賀県犬上郡豊郷町雨降野');
ok($zip->set_number('5291164')->is_valid_number, '滋賀県犬上郡豊郷町日栄');
ok($zip->set_number('5291165')->is_valid_number, '滋賀県犬上郡豊郷町吉田');
ok($zip->set_number('5291166')->is_valid_number, '滋賀県犬上郡豊郷町上枝');
ok($zip->set_number('5291167')->is_valid_number, '滋賀県犬上郡豊郷町杉');
ok($zip->set_number('5291168')->is_valid_number, '滋賀県犬上郡豊郷町八目');
ok($zip->set_number('5291169')->is_valid_number, '滋賀県犬上郡豊郷町石畑');
ok($zip->set_number('5291171')->is_valid_number, '滋賀県犬上郡豊郷町安食西');
ok($zip->set_number('5291172')->is_valid_number, '滋賀県犬上郡豊郷町安食南');
ok($zip->set_number('5291173')->is_valid_number, '滋賀県犬上郡豊郷町高野瀬');
ok($zip->set_number('5291174')->is_valid_number, '滋賀県犬上郡豊郷町下枝');
ok($zip->set_number('5291175')->is_valid_number, '滋賀県犬上郡豊郷町沢');
ok($zip->set_number('5291176')->is_valid_number, '滋賀県犬上郡豊郷町大町');
ok($zip->set_number('5291177')->is_valid_number, '滋賀県犬上郡豊郷町三ツ池');
ok($zip->set_number('5291201')->is_valid_number, '滋賀県愛知郡愛荘町斧磨');
ok($zip->set_number('5291202')->is_valid_number, '滋賀県愛知郡愛荘町松尾寺');
ok($zip->set_number('5291203')->is_valid_number, '滋賀県愛知郡愛荘町上蚊野');
ok($zip->set_number('5291204')->is_valid_number, '滋賀県愛知郡愛荘町蚊野外');
ok($zip->set_number('5291205')->is_valid_number, '滋賀県愛知郡愛荘町軽野');
ok($zip->set_number('5291206')->is_valid_number, '滋賀県愛知郡愛荘町蚊野');
ok($zip->set_number('5291207')->is_valid_number, '滋賀県愛知郡愛荘町岩倉');
ok($zip->set_number('5291208')->is_valid_number, '滋賀県愛知郡愛荘町竹原');
ok($zip->set_number('5291211')->is_valid_number, '滋賀県愛知郡愛荘町香之庄');
ok($zip->set_number('5291212')->is_valid_number, '滋賀県愛知郡愛荘町元持');
ok($zip->set_number('5291213')->is_valid_number, '滋賀県愛知郡愛荘町沖');
ok($zip->set_number('5291214')->is_valid_number, '滋賀県愛知郡愛荘町宮後');
ok($zip->set_number('5291221')->is_valid_number, '滋賀県愛知郡愛荘町下八木');
ok($zip->set_number('5291222')->is_valid_number, '滋賀県愛知郡愛荘町北八木');
ok($zip->set_number('5291223')->is_valid_number, '滋賀県愛知郡愛荘町島川');
ok($zip->set_number('5291224')->is_valid_number, '滋賀県愛知郡愛荘町長塚');
ok($zip->set_number('5291225')->is_valid_number, '滋賀県愛知郡愛荘町栗田');
ok($zip->set_number('5291226')->is_valid_number, '滋賀県愛知郡愛荘町南野々目');
ok($zip->set_number('5291227')->is_valid_number, '滋賀県愛知郡愛荘町野々目');
ok($zip->set_number('5291228')->is_valid_number, '滋賀県愛知郡愛荘町矢守');
ok($zip->set_number('5291231')->is_valid_number, '滋賀県愛知郡愛荘町円城寺');
ok($zip->set_number('5291232')->is_valid_number, '滋賀県愛知郡愛荘町常安寺');
ok($zip->set_number('5291233')->is_valid_number, '滋賀県愛知郡愛荘町東出');
ok($zip->set_number('5291234')->is_valid_number, '滋賀県愛知郡愛荘町安孫子');
ok($zip->set_number('5291235')->is_valid_number, '滋賀県愛知郡愛荘町目加田');
ok($zip->set_number('5291236')->is_valid_number, '滋賀県愛知郡愛荘町深草');
ok($zip->set_number('5291237')->is_valid_number, '滋賀県愛知郡愛荘町西出');
ok($zip->set_number('5291300')->is_valid_number, '滋賀県愛知郡愛荘町以下に掲載がない場合');
ok($zip->set_number('5291301')->is_valid_number, '滋賀県愛知郡愛荘町山川原');
ok($zip->set_number('5291302')->is_valid_number, '滋賀県愛知郡愛荘町川原');
ok($zip->set_number('5291303')->is_valid_number, '滋賀県愛知郡愛荘町長野');
ok($zip->set_number('5291311')->is_valid_number, '滋賀県愛知郡愛荘町石橋');
ok($zip->set_number('5291312')->is_valid_number, '滋賀県愛知郡愛荘町川久保');
ok($zip->set_number('5291313')->is_valid_number, '滋賀県愛知郡愛荘町市');
ok($zip->set_number('5291314')->is_valid_number, '滋賀県愛知郡愛荘町中宿');
ok($zip->set_number('5291315')->is_valid_number, '滋賀県愛知郡愛荘町沓掛');
ok($zip->set_number('5291321')->is_valid_number, '滋賀県愛知郡愛荘町豊満');
ok($zip->set_number('5291322')->is_valid_number, '滋賀県愛知郡愛荘町平居');
ok($zip->set_number('5291323')->is_valid_number, '滋賀県愛知郡愛荘町畑田');
ok($zip->set_number('5291324')->is_valid_number, '滋賀県愛知郡愛荘町苅間');
ok($zip->set_number('5291325')->is_valid_number, '滋賀県愛知郡愛荘町東円堂');
ok($zip->set_number('5291331')->is_valid_number, '滋賀県愛知郡愛荘町愛知川');
ok($zip->set_number('5291401')->is_valid_number, '滋賀県東近江市五個荘石馬寺町');
ok($zip->set_number('5291402')->is_valid_number, '滋賀県東近江市五個荘七里町');
ok($zip->set_number('5291403')->is_valid_number, '滋賀県東近江市五個荘日吉町');
ok($zip->set_number('5291404')->is_valid_number, '滋賀県東近江市宮荘町');
ok($zip->set_number('5291405')->is_valid_number, '滋賀県東近江市五個荘金堂町');
ok($zip->set_number('5291411')->is_valid_number, '滋賀県東近江市五個荘河曲町');
ok($zip->set_number('5291412')->is_valid_number, '滋賀県東近江市五個荘和田町');
ok($zip->set_number('5291413')->is_valid_number, '滋賀県東近江市五個荘簗瀬町');
ok($zip->set_number('5291414')->is_valid_number, '滋賀県東近江市五個荘中町');
ok($zip->set_number('5291415')->is_valid_number, '滋賀県東近江市五個荘五位田町');
ok($zip->set_number('5291421')->is_valid_number, '滋賀県東近江市五個荘竜田町');
ok($zip->set_number('5291422')->is_valid_number, '滋賀県東近江市五個荘小幡町');
ok($zip->set_number('5291423')->is_valid_number, '滋賀県東近江市五個荘奥町');
ok($zip->set_number('5291424')->is_valid_number, '滋賀県東近江市五個荘三俣町');
ok($zip->set_number('5291425')->is_valid_number, '滋賀県東近江市五個荘石川町');
ok($zip->set_number('5291431')->is_valid_number, '滋賀県東近江市五個荘山本町');
ok($zip->set_number('5291432')->is_valid_number, '滋賀県東近江市五個荘新堂町');
ok($zip->set_number('5291433')->is_valid_number, '滋賀県東近江市五個荘木流町');
ok($zip->set_number('5291434')->is_valid_number, '滋賀県東近江市五個荘平阪町');
ok($zip->set_number('5291435')->is_valid_number, '滋賀県東近江市五個荘伊野部町');
ok($zip->set_number('5291441')->is_valid_number, '滋賀県東近江市五個荘川並町');
ok($zip->set_number('5291442')->is_valid_number, '滋賀県東近江市五個荘塚本町');
ok($zip->set_number('5291443')->is_valid_number, '滋賀県東近江市五個荘北町屋町');
ok($zip->set_number('5291444')->is_valid_number, '滋賀県東近江市五個荘石塚町');
ok($zip->set_number('5291445')->is_valid_number, '滋賀県東近江市五個荘清水鼻町');
ok($zip->set_number('5291501')->is_valid_number, '滋賀県東近江市石塔町');
ok($zip->set_number('5291502')->is_valid_number, '滋賀県東近江市平林町');
ok($zip->set_number('5291503')->is_valid_number, '滋賀県東近江市綺田町');
ok($zip->set_number('5291504')->is_valid_number, '滋賀県東近江市蒲生寺町');
ok($zip->set_number('5291511')->is_valid_number, '滋賀県東近江市桜川東町');
ok($zip->set_number('5291512')->is_valid_number, '滋賀県東近江市大塚町');
ok($zip->set_number('5291513')->is_valid_number, '滋賀県東近江市田井町');
ok($zip->set_number('5291514')->is_valid_number, '滋賀県東近江市蒲生大森町');
ok($zip->set_number('5291521')->is_valid_number, '滋賀県東近江市蒲生岡本町');
ok($zip->set_number('5291522')->is_valid_number, '滋賀県東近江市鋳物師町');
ok($zip->set_number('5291523')->is_valid_number, '滋賀県東近江市上麻生町');
ok($zip->set_number('5291524')->is_valid_number, '滋賀県東近江市下麻生町');
ok($zip->set_number('5291531')->is_valid_number, '滋賀県東近江市市子川原町');
ok($zip->set_number('5291532')->is_valid_number, '滋賀県東近江市市子松井町');
ok($zip->set_number('5291533')->is_valid_number, '滋賀県東近江市市子沖町');
ok($zip->set_number('5291534')->is_valid_number, '滋賀県東近江市鈴町');
ok($zip->set_number('5291535')->is_valid_number, '滋賀県東近江市上南町');
ok($zip->set_number('5291536')->is_valid_number, '滋賀県東近江市合戸町');
ok($zip->set_number('5291537')->is_valid_number, '滋賀県東近江市市子殿町');
ok($zip->set_number('5291541')->is_valid_number, '滋賀県東近江市蒲生堂町');
ok($zip->set_number('5291551')->is_valid_number, '滋賀県東近江市宮川町');
ok($zip->set_number('5291561')->is_valid_number, '滋賀県東近江市稲垂町');
ok($zip->set_number('5291562')->is_valid_number, '滋賀県東近江市木村町');
ok($zip->set_number('5291563')->is_valid_number, '滋賀県東近江市横山町');
ok($zip->set_number('5291564')->is_valid_number, '滋賀県東近江市宮井町');
ok($zip->set_number('5291565')->is_valid_number, '滋賀県東近江市外原町');
ok($zip->set_number('5291566')->is_valid_number, '滋賀県東近江市葛巻町');
ok($zip->set_number('5291571')->is_valid_number, '滋賀県東近江市川合町');
ok($zip->set_number('5291572')->is_valid_number, '滋賀県東近江市桜川西町');
ok($zip->set_number('5291600')->is_valid_number, '滋賀県蒲生郡日野町以下に掲載がない場合');
ok($zip->set_number('5291601')->is_valid_number, '滋賀県蒲生郡日野町松尾');
ok($zip->set_number('5291602')->is_valid_number, '滋賀県蒲生郡日野町河原');
ok($zip->set_number('5291603')->is_valid_number, '滋賀県蒲生郡日野町大窪');
ok($zip->set_number('5291604')->is_valid_number, '滋賀県蒲生郡日野町村井');
ok($zip->set_number('5291605')->is_valid_number, '滋賀県蒲生郡日野町小井口');
ok($zip->set_number('5291606')->is_valid_number, '滋賀県蒲生郡日野町寺尻');
ok($zip->set_number('5291607')->is_valid_number, '滋賀県蒲生郡日野町木津');
ok($zip->set_number('5291608')->is_valid_number, '滋賀県蒲生郡日野町大谷');
ok($zip->set_number('5291609')->is_valid_number, '滋賀県蒲生郡日野町中道');
ok($zip->set_number('5291610')->is_valid_number, '滋賀県蒲生郡日野町奥之池');
ok($zip->set_number('5291611')->is_valid_number, '滋賀県蒲生郡日野町杣');
ok($zip->set_number('5291612')->is_valid_number, '滋賀県蒲生郡日野町杉');
ok($zip->set_number('5291613')->is_valid_number, '滋賀県蒲生郡日野町川原');
ok($zip->set_number('5291614')->is_valid_number, '滋賀県蒲生郡日野町原');
ok($zip->set_number('5291615')->is_valid_number, '滋賀県蒲生郡日野町小野');
ok($zip->set_number('5291616')->is_valid_number, '滋賀県蒲生郡日野町奥師');
ok($zip->set_number('5291617')->is_valid_number, '滋賀県蒲生郡日野町中之郷');
ok($zip->set_number('5291618')->is_valid_number, '滋賀県蒲生郡日野町鳥居平');
ok($zip->set_number('5291619')->is_valid_number, '滋賀県蒲生郡日野町佐久良');
ok($zip->set_number('5291621')->is_valid_number, '滋賀県蒲生郡日野町西明寺');
ok($zip->set_number('5291622')->is_valid_number, '滋賀県蒲生郡日野町北畑');
ok($zip->set_number('5291623')->is_valid_number, '滋賀県蒲生郡日野町熊野');
ok($zip->set_number('5291624')->is_valid_number, '滋賀県蒲生郡日野町平子');
ok($zip->set_number('5291625')->is_valid_number, '滋賀県蒲生郡日野町蔵王');
ok($zip->set_number('5291626')->is_valid_number, '滋賀県蒲生郡日野町音羽');
ok($zip->set_number('5291627')->is_valid_number, '滋賀県蒲生郡日野町仁本木');
ok($zip->set_number('5291628')->is_valid_number, '滋賀県蒲生郡日野町西大路');
ok($zip->set_number('5291631')->is_valid_number, '滋賀県蒲生郡日野町鎌掛');
ok($zip->set_number('5291632')->is_valid_number, '滋賀県蒲生郡日野町上駒月');
ok($zip->set_number('5291633')->is_valid_number, '滋賀県蒲生郡日野町下駒月');
ok($zip->set_number('5291634')->is_valid_number, '滋賀県蒲生郡日野町深山口');
ok($zip->set_number('5291635')->is_valid_number, '滋賀県蒲生郡日野町迫');
ok($zip->set_number('5291636')->is_valid_number, '滋賀県蒲生郡日野町清田');
ok($zip->set_number('5291641')->is_valid_number, '滋賀県蒲生郡日野町日田');
ok($zip->set_number('5291642')->is_valid_number, '滋賀県蒲生郡日野町上野田');
ok($zip->set_number('5291643')->is_valid_number, '滋賀県蒲生郡日野町里口');
ok($zip->set_number('5291644')->is_valid_number, '滋賀県蒲生郡日野町内池');
ok($zip->set_number('5291645')->is_valid_number, '滋賀県蒲生郡日野町十禅師');
ok($zip->set_number('5291646')->is_valid_number, '滋賀県蒲生郡日野町猫田');
ok($zip->set_number('5291647')->is_valid_number, '滋賀県蒲生郡日野町別所');
ok($zip->set_number('5291648')->is_valid_number, '滋賀県蒲生郡日野町いせの');
ok($zip->set_number('5291651')->is_valid_number, '滋賀県蒲生郡日野町山本');
ok($zip->set_number('5291652')->is_valid_number, '滋賀県蒲生郡日野町小御門');
ok($zip->set_number('5291653')->is_valid_number, '滋賀県蒲生郡日野町三十坪');
ok($zip->set_number('5291654')->is_valid_number, '滋賀県蒲生郡日野町小谷');
ok($zip->set_number('5291655')->is_valid_number, '滋賀県蒲生郡日野町石原');
ok($zip->set_number('5291656')->is_valid_number, '滋賀県蒲生郡日野町増田');
ok($zip->set_number('5291657')->is_valid_number, '滋賀県蒲生郡日野町豊田');
ok($zip->set_number('5291658')->is_valid_number, '滋賀県蒲生郡日野町中山');
ok($zip->set_number('5291661')->is_valid_number, '滋賀県蒲生郡日野町安部居');
ok($zip->set_number('5291662')->is_valid_number, '滋賀県蒲生郡日野町中在寺');
ok($zip->set_number('5291663')->is_valid_number, '滋賀県蒲生郡日野町北脇');
ok($zip->set_number('5291664')->is_valid_number, '滋賀県蒲生郡日野町蓮花寺');
ok($zip->set_number('5291665')->is_valid_number, '滋賀県蒲生郡日野町野出');
ok($zip->set_number('5291801')->is_valid_number, '滋賀県甲賀市信楽町宮町');
ok($zip->set_number('5291802')->is_valid_number, '滋賀県甲賀市信楽町黄瀬');
ok($zip->set_number('5291803')->is_valid_number, '滋賀県甲賀市信楽町牧');
ok($zip->set_number('5291804')->is_valid_number, '滋賀県甲賀市信楽町勅旨');
ok($zip->set_number('5291811')->is_valid_number, '滋賀県甲賀市信楽町江田');
ok($zip->set_number('5291812')->is_valid_number, '滋賀県甲賀市信楽町神山');
ok($zip->set_number('5291813')->is_valid_number, '滋賀県甲賀市信楽町畑');
ok($zip->set_number('5291814')->is_valid_number, '滋賀県甲賀市信楽町田代');
ok($zip->set_number('5291821')->is_valid_number, '滋賀県甲賀市信楽町多羅尾');
ok($zip->set_number('5291831')->is_valid_number, '滋賀県甲賀市信楽町西');
ok($zip->set_number('5291832')->is_valid_number, '滋賀県甲賀市信楽町小川出');
ok($zip->set_number('5291833')->is_valid_number, '滋賀県甲賀市信楽町小川');
ok($zip->set_number('5291834')->is_valid_number, '滋賀県甲賀市信楽町杉山');
ok($zip->set_number('5291835')->is_valid_number, '滋賀県甲賀市信楽町中野');
ok($zip->set_number('5291836')->is_valid_number, '滋賀県甲賀市信楽町柞原');
ok($zip->set_number('5291841')->is_valid_number, '滋賀県甲賀市信楽町上朝宮');
ok($zip->set_number('5291842')->is_valid_number, '滋賀県甲賀市信楽町下朝宮');
ok($zip->set_number('5291843')->is_valid_number, '滋賀県甲賀市信楽町宮尻');
ok($zip->set_number('5291851')->is_valid_number, '滋賀県甲賀市信楽町長野');
ok($zip->set_number('5300000')->is_valid_number, '大阪府大阪市北区以下に掲載がない場合');
ok($zip->set_number('5300001')->is_valid_number, '大阪府大阪市北区梅田');
ok($zip->set_number('5300002')->is_valid_number, '大阪府大阪市北区曽根崎新地');
ok($zip->set_number('5300003')->is_valid_number, '大阪府大阪市北区堂島');
ok($zip->set_number('5300004')->is_valid_number, '大阪府大阪市北区堂島浜');
ok($zip->set_number('5300005')->is_valid_number, '大阪府大阪市北区中之島(次のビルを除く)');
ok($zip->set_number('5300011')->is_valid_number, '大阪府大阪市北区大深町');
ok($zip->set_number('5300012')->is_valid_number, '大阪府大阪市北区芝田');
ok($zip->set_number('5300013')->is_valid_number, '大阪府大阪市北区茶屋町');
ok($zip->set_number('5300014')->is_valid_number, '大阪府大阪市北区鶴野町');
ok($zip->set_number('5300015')->is_valid_number, '大阪府大阪市北区中崎西');
ok($zip->set_number('5300016')->is_valid_number, '大阪府大阪市北区中崎');
ok($zip->set_number('5300017')->is_valid_number, '大阪府大阪市北区角田町');
ok($zip->set_number('5300018')->is_valid_number, '大阪府大阪市北区小松原町');
ok($zip->set_number('5300021')->is_valid_number, '大阪府大阪市北区浮田');
ok($zip->set_number('5300022')->is_valid_number, '大阪府大阪市北区浪花町');
ok($zip->set_number('5300023')->is_valid_number, '大阪府大阪市北区黒崎町');
ok($zip->set_number('5300024')->is_valid_number, '大阪府大阪市北区山崎町');
ok($zip->set_number('5300025')->is_valid_number, '大阪府大阪市北区扇町');
ok($zip->set_number('5300026')->is_valid_number, '大阪府大阪市北区神山町');
ok($zip->set_number('5300027')->is_valid_number, '大阪府大阪市北区堂山町');
ok($zip->set_number('5300028')->is_valid_number, '大阪府大阪市北区万歳町');
ok($zip->set_number('5300031')->is_valid_number, '大阪府大阪市北区菅栄町');
ok($zip->set_number('5300032')->is_valid_number, '大阪府大阪市北区樋之口町');
ok($zip->set_number('5300033')->is_valid_number, '大阪府大阪市北区池田町');
ok($zip->set_number('5300034')->is_valid_number, '大阪府大阪市北区錦町');
ok($zip->set_number('5300035')->is_valid_number, '大阪府大阪市北区同心');
ok($zip->set_number('5300036')->is_valid_number, '大阪府大阪市北区与力町');
ok($zip->set_number('5300037')->is_valid_number, '大阪府大阪市北区松ケ枝町');
ok($zip->set_number('5300038')->is_valid_number, '大阪府大阪市北区紅梅町');
ok($zip->set_number('5300041')->is_valid_number, '大阪府大阪市北区天神橋(1~6丁目)');
ok($zip->set_number('5300042')->is_valid_number, '大阪府大阪市北区天満橋(次のビルを除く)');
ok($zip->set_number('5300043')->is_valid_number, '大阪府大阪市北区天満');
ok($zip->set_number('5300044')->is_valid_number, '大阪府大阪市北区東天満');
ok($zip->set_number('5300045')->is_valid_number, '大阪府大阪市北区天神西町');
ok($zip->set_number('5300046')->is_valid_number, '大阪府大阪市北区菅原町');
ok($zip->set_number('5300047')->is_valid_number, '大阪府大阪市北区西天満');
ok($zip->set_number('5300051')->is_valid_number, '大阪府大阪市北区太融寺町');
ok($zip->set_number('5300052')->is_valid_number, '大阪府大阪市北区南扇町');
ok($zip->set_number('5300053')->is_valid_number, '大阪府大阪市北区末広町');
ok($zip->set_number('5300054')->is_valid_number, '大阪府大阪市北区南森町');
ok($zip->set_number('5300055')->is_valid_number, '大阪府大阪市北区野崎町');
ok($zip->set_number('5300056')->is_valid_number, '大阪府大阪市北区兎我野町');
ok($zip->set_number('5300057')->is_valid_number, '大阪府大阪市北区曽根崎');
ok($zip->set_number('5306001')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(1階)');
ok($zip->set_number('5306002')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(2階)');
ok($zip->set_number('5306003')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(3階)');
ok($zip->set_number('5306004')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(4階)');
ok($zip->set_number('5306005')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(5階)');
ok($zip->set_number('5306006')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(6階)');
ok($zip->set_number('5306007')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(7階)');
ok($zip->set_number('5306008')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(8階)');
ok($zip->set_number('5306009')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(9階)');
ok($zip->set_number('5306010')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(10階)');
ok($zip->set_number('5306011')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(11階)');
ok($zip->set_number('5306012')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(12階)');
ok($zip->set_number('5306013')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(13階)');
ok($zip->set_number('5306014')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(14階)');
ok($zip->set_number('5306015')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(15階)');
ok($zip->set_number('5306016')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(16階)');
ok($zip->set_number('5306017')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(17階)');
ok($zip->set_number('5306018')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(18階)');
ok($zip->set_number('5306019')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(19階)');
ok($zip->set_number('5306020')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(20階)');
ok($zip->set_number('5306021')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(21階)');
ok($zip->set_number('5306022')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(22階)');
ok($zip->set_number('5306023')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(23階)');
ok($zip->set_number('5306024')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(24階)');
ok($zip->set_number('5306025')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(25階)');
ok($zip->set_number('5306026')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(26階)');
ok($zip->set_number('5306027')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(27階)');
ok($zip->set_number('5306028')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(28階)');
ok($zip->set_number('5306029')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(29階)');
ok($zip->set_number('5306030')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(30階)');
ok($zip->set_number('5306031')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(31階)');
ok($zip->set_number('5306032')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(32階)');
ok($zip->set_number('5306033')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(33階)');
ok($zip->set_number('5306034')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(34階)');
ok($zip->set_number('5306035')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(35階)');
ok($zip->set_number('5306036')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(36階)');
ok($zip->set_number('5306037')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(37階)');
ok($zip->set_number('5306038')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(38階)');
ok($zip->set_number('5306039')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(39階)');
ok($zip->set_number('5306090')->is_valid_number, '大阪府大阪市北区天満橋OAPタワー(地階・階層不明)');
ok($zip->set_number('5306101')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(1階)');
ok($zip->set_number('5306102')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(2階)');
ok($zip->set_number('5306103')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(3階)');
ok($zip->set_number('5306104')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(4階)');
ok($zip->set_number('5306105')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(5階)');
ok($zip->set_number('5306106')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(6階)');
ok($zip->set_number('5306107')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(7階)');
ok($zip->set_number('5306108')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(8階)');
ok($zip->set_number('5306109')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(9階)');
ok($zip->set_number('5306110')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(10階)');
ok($zip->set_number('5306111')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(11階)');
ok($zip->set_number('5306112')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(12階)');
ok($zip->set_number('5306113')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(13階)');
ok($zip->set_number('5306114')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(14階)');
ok($zip->set_number('5306115')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(15階)');
ok($zip->set_number('5306116')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(16階)');
ok($zip->set_number('5306117')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(17階)');
ok($zip->set_number('5306118')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(18階)');
ok($zip->set_number('5306119')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(19階)');
ok($zip->set_number('5306120')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(20階)');
ok($zip->set_number('5306121')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(21階)');
ok($zip->set_number('5306122')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(22階)');
ok($zip->set_number('5306123')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(23階)');
ok($zip->set_number('5306124')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(24階)');
ok($zip->set_number('5306125')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(25階)');
ok($zip->set_number('5306126')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(26階)');
ok($zip->set_number('5306127')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(27階)');
ok($zip->set_number('5306128')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(28階)');
ok($zip->set_number('5306129')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(29階)');
ok($zip->set_number('5306130')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(30階)');
ok($zip->set_number('5306131')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(31階)');
ok($zip->set_number('5306132')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(32階)');
ok($zip->set_number('5306133')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(33階)');
ok($zip->set_number('5306134')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(34階)');
ok($zip->set_number('5306135')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(35階)');
ok($zip->set_number('5306190')->is_valid_number, '大阪府大阪市北区中之島中之島ダイビル(地階・階層不明)');
ok($zip->set_number('5310041')->is_valid_number, '大阪府大阪市北区天神橋(7、8丁目)');
ok($zip->set_number('5310061')->is_valid_number, '大阪府大阪市北区長柄西');
ok($zip->set_number('5310062')->is_valid_number, '大阪府大阪市北区長柄中');
ok($zip->set_number('5310063')->is_valid_number, '大阪府大阪市北区長柄東');
ok($zip->set_number('5310064')->is_valid_number, '大阪府大阪市北区国分寺');
ok($zip->set_number('5310071')->is_valid_number, '大阪府大阪市北区中津');
ok($zip->set_number('5310072')->is_valid_number, '大阪府大阪市北区豊崎');
ok($zip->set_number('5310073')->is_valid_number, '大阪府大阪市北区本庄西');
ok($zip->set_number('5310074')->is_valid_number, '大阪府大阪市北区本庄東');
ok($zip->set_number('5310075')->is_valid_number, '大阪府大阪市北区大淀南');
ok($zip->set_number('5310076')->is_valid_number, '大阪府大阪市北区大淀中(次のビルを除く)');
ok($zip->set_number('5310077')->is_valid_number, '大阪府大阪市北区大淀北');
ok($zip->set_number('5316001')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(1階)');
ok($zip->set_number('5316002')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(2階)');
ok($zip->set_number('5316003')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(3階)');
ok($zip->set_number('5316004')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(4階)');
ok($zip->set_number('5316005')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(5階)');
ok($zip->set_number('5316006')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(6階)');
ok($zip->set_number('5316007')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(7階)');
ok($zip->set_number('5316008')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(8階)');
ok($zip->set_number('5316009')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(9階)');
ok($zip->set_number('5316010')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(10階)');
ok($zip->set_number('5316011')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(11階)');
ok($zip->set_number('5316012')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(12階)');
ok($zip->set_number('5316013')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(13階)');
ok($zip->set_number('5316014')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(14階)');
ok($zip->set_number('5316015')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(15階)');
ok($zip->set_number('5316016')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(16階)');
ok($zip->set_number('5316017')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(17階)');
ok($zip->set_number('5316018')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(18階)');
ok($zip->set_number('5316019')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(19階)');
ok($zip->set_number('5316020')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(20階)');
ok($zip->set_number('5316021')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(21階)');
ok($zip->set_number('5316022')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(22階)');
ok($zip->set_number('5316023')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(23階)');
ok($zip->set_number('5316024')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(24階)');
ok($zip->set_number('5316025')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(25階)');
ok($zip->set_number('5316026')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(26階)');
ok($zip->set_number('5316027')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(27階)');
ok($zip->set_number('5316028')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(28階)');
ok($zip->set_number('5316029')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(29階)');
ok($zip->set_number('5316030')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(30階)');
ok($zip->set_number('5316031')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(31階)');
ok($zip->set_number('5316032')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(32階)');
ok($zip->set_number('5316033')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(33階)');
ok($zip->set_number('5316034')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(34階)');
ok($zip->set_number('5316035')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(35階)');
ok($zip->set_number('5316036')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(36階)');
ok($zip->set_number('5316037')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(37階)');
ok($zip->set_number('5316038')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(38階)');
ok($zip->set_number('5316039')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(39階)');
ok($zip->set_number('5316090')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーイースト(地階・階層不明)');
ok($zip->set_number('5316101')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(1階)');
ok($zip->set_number('5316102')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(2階)');
ok($zip->set_number('5316103')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(3階)');
ok($zip->set_number('5316104')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(4階)');
ok($zip->set_number('5316105')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(5階)');
ok($zip->set_number('5316106')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(6階)');
ok($zip->set_number('5316107')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(7階)');
ok($zip->set_number('5316108')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(8階)');
ok($zip->set_number('5316109')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(9階)');
ok($zip->set_number('5316110')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(10階)');
ok($zip->set_number('5316111')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(11階)');
ok($zip->set_number('5316112')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(12階)');
ok($zip->set_number('5316113')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(13階)');
ok($zip->set_number('5316114')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(14階)');
ok($zip->set_number('5316115')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(15階)');
ok($zip->set_number('5316116')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(16階)');
ok($zip->set_number('5316117')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(17階)');
ok($zip->set_number('5316118')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(18階)');
ok($zip->set_number('5316119')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(19階)');
ok($zip->set_number('5316120')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(20階)');
ok($zip->set_number('5316121')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(21階)');
ok($zip->set_number('5316122')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(22階)');
ok($zip->set_number('5316123')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(23階)');
ok($zip->set_number('5316124')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(24階)');
ok($zip->set_number('5316125')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(25階)');
ok($zip->set_number('5316126')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(26階)');
ok($zip->set_number('5316127')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(27階)');
ok($zip->set_number('5316128')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(28階)');
ok($zip->set_number('5316129')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(29階)');
ok($zip->set_number('5316130')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(30階)');
ok($zip->set_number('5316131')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(31階)');
ok($zip->set_number('5316132')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(32階)');
ok($zip->set_number('5316133')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(33階)');
ok($zip->set_number('5316134')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(34階)');
ok($zip->set_number('5316135')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(35階)');
ok($zip->set_number('5316136')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(36階)');
ok($zip->set_number('5316137')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(37階)');
ok($zip->set_number('5316138')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(38階)');
ok($zip->set_number('5316139')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(39階)');
ok($zip->set_number('5316190')->is_valid_number, '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト(地階・階層不明)');
ok($zip->set_number('5320000')->is_valid_number, '大阪府大阪市淀川区以下に掲載がない場合');
ok($zip->set_number('5320001')->is_valid_number, '大阪府大阪市淀川区十八条');
ok($zip->set_number('5320002')->is_valid_number, '大阪府大阪市淀川区東三国');
ok($zip->set_number('5320003')->is_valid_number, '大阪府大阪市淀川区宮原');
ok($zip->set_number('5320004')->is_valid_number, '大阪府大阪市淀川区西宮原');
ok($zip->set_number('5320005')->is_valid_number, '大阪府大阪市淀川区三国本町');
ok($zip->set_number('5320006')->is_valid_number, '大阪府大阪市淀川区西三国');
ok($zip->set_number('5320011')->is_valid_number, '大阪府大阪市淀川区西中島');
ok($zip->set_number('5320012')->is_valid_number, '大阪府大阪市淀川区木川東');
ok($zip->set_number('5320013')->is_valid_number, '大阪府大阪市淀川区木川西');
ok($zip->set_number('5320021')->is_valid_number, '大阪府大阪市淀川区田川北');
ok($zip->set_number('5320022')->is_valid_number, '大阪府大阪市淀川区野中南');
ok($zip->set_number('5320023')->is_valid_number, '大阪府大阪市淀川区十三東');
ok($zip->set_number('5320024')->is_valid_number, '大阪府大阪市淀川区十三本町');
ok($zip->set_number('5320025')->is_valid_number, '大阪府大阪市淀川区新北野');
ok($zip->set_number('5320026')->is_valid_number, '大阪府大阪市淀川区塚本');
ok($zip->set_number('5320027')->is_valid_number, '大阪府大阪市淀川区田川');
ok($zip->set_number('5320028')->is_valid_number, '大阪府大阪市淀川区十三元今里');
ok($zip->set_number('5320031')->is_valid_number, '大阪府大阪市淀川区加島');
ok($zip->set_number('5320032')->is_valid_number, '大阪府大阪市淀川区三津屋北');
ok($zip->set_number('5320033')->is_valid_number, '大阪府大阪市淀川区新高');
ok($zip->set_number('5320034')->is_valid_number, '大阪府大阪市淀川区野中北');
ok($zip->set_number('5320035')->is_valid_number, '大阪府大阪市淀川区三津屋南');
ok($zip->set_number('5320036')->is_valid_number, '大阪府大阪市淀川区三津屋中');
ok($zip->set_number('5330000')->is_valid_number, '大阪府大阪市東淀川区以下に掲載がない場合');
ok($zip->set_number('5330001')->is_valid_number, '大阪府大阪市東淀川区井高野');
ok($zip->set_number('5330002')->is_valid_number, '大阪府大阪市東淀川区北江口');
ok($zip->set_number('5330003')->is_valid_number, '大阪府大阪市東淀川区南江口');
ok($zip->set_number('5330004')->is_valid_number, '大阪府大阪市東淀川区小松');
ok($zip->set_number('5330005')->is_valid_number, '大阪府大阪市東淀川区瑞光');
ok($zip->set_number('5330006')->is_valid_number, '大阪府大阪市東淀川区上新庄');
ok($zip->set_number('5330007')->is_valid_number, '大阪府大阪市東淀川区相川');
ok($zip->set_number('5330011')->is_valid_number, '大阪府大阪市東淀川区大桐');
ok($zip->set_number('5330012')->is_valid_number, '大阪府大阪市東淀川区大道南');
ok($zip->set_number('5330013')->is_valid_number, '大阪府大阪市東淀川区豊里');
ok($zip->set_number('5330014')->is_valid_number, '大阪府大阪市東淀川区豊新');
ok($zip->set_number('5330015')->is_valid_number, '大阪府大阪市東淀川区大隅');
ok($zip->set_number('5330021')->is_valid_number, '大阪府大阪市東淀川区下新庄');
ok($zip->set_number('5330022')->is_valid_number, '大阪府大阪市東淀川区菅原');
ok($zip->set_number('5330023')->is_valid_number, '大阪府大阪市東淀川区東淡路');
ok($zip->set_number('5330024')->is_valid_number, '大阪府大阪市東淀川区柴島');
ok($zip->set_number('5330031')->is_valid_number, '大阪府大阪市東淀川区西淡路');
ok($zip->set_number('5330032')->is_valid_number, '大阪府大阪市東淀川区淡路');
ok($zip->set_number('5330033')->is_valid_number, '大阪府大阪市東淀川区東中島');
ok($zip->set_number('5340000')->is_valid_number, '大阪府大阪市都島区以下に掲載がない場合');
ok($zip->set_number('5340001')->is_valid_number, '大阪府大阪市都島区毛馬町');
ok($zip->set_number('5340002')->is_valid_number, '大阪府大阪市都島区大東町');
ok($zip->set_number('5340011')->is_valid_number, '大阪府大阪市都島区高倉町');
ok($zip->set_number('5340012')->is_valid_number, '大阪府大阪市都島区御幸町');
ok($zip->set_number('5340013')->is_valid_number, '大阪府大阪市都島区内代町');
ok($zip->set_number('5340014')->is_valid_number, '大阪府大阪市都島区都島北通');
ok($zip->set_number('5340015')->is_valid_number, '大阪府大阪市都島区善源寺町');
ok($zip->set_number('5340016')->is_valid_number, '大阪府大阪市都島区友渕町');
ok($zip->set_number('5340021')->is_valid_number, '大阪府大阪市都島区都島本通');
ok($zip->set_number('5340022')->is_valid_number, '大阪府大阪市都島区都島中通');
ok($zip->set_number('5340023')->is_valid_number, '大阪府大阪市都島区都島南通');
ok($zip->set_number('5340024')->is_valid_number, '大阪府大阪市都島区東野田町');
ok($zip->set_number('5340025')->is_valid_number, '大阪府大阪市都島区片町');
ok($zip->set_number('5340026')->is_valid_number, '大阪府大阪市都島区網島町');
ok($zip->set_number('5340027')->is_valid_number, '大阪府大阪市都島区中野町');
ok($zip->set_number('5350000')->is_valid_number, '大阪府大阪市旭区以下に掲載がない場合');
ok($zip->set_number('5350001')->is_valid_number, '大阪府大阪市旭区太子橋');
ok($zip->set_number('5350002')->is_valid_number, '大阪府大阪市旭区大宮');
ok($zip->set_number('5350003')->is_valid_number, '大阪府大阪市旭区中宮');
ok($zip->set_number('5350004')->is_valid_number, '大阪府大阪市旭区生江');
ok($zip->set_number('5350005')->is_valid_number, '大阪府大阪市旭区赤川');
ok($zip->set_number('5350011')->is_valid_number, '大阪府大阪市旭区今市');
ok($zip->set_number('5350012')->is_valid_number, '大阪府大阪市旭区千林');
ok($zip->set_number('5350013')->is_valid_number, '大阪府大阪市旭区森小路');
ok($zip->set_number('5350021')->is_valid_number, '大阪府大阪市旭区清水');
ok($zip->set_number('5350022')->is_valid_number, '大阪府大阪市旭区新森');
ok($zip->set_number('5350031')->is_valid_number, '大阪府大阪市旭区高殿');
ok($zip->set_number('5360000')->is_valid_number, '大阪府大阪市城東区以下に掲載がない場合');
ok($zip->set_number('5360001')->is_valid_number, '大阪府大阪市城東区古市');
ok($zip->set_number('5360002')->is_valid_number, '大阪府大阪市城東区今福東');
ok($zip->set_number('5360003')->is_valid_number, '大阪府大阪市城東区今福南');
ok($zip->set_number('5360004')->is_valid_number, '大阪府大阪市城東区今福西');
ok($zip->set_number('5360005')->is_valid_number, '大阪府大阪市城東区中央');
ok($zip->set_number('5360006')->is_valid_number, '大阪府大阪市城東区野江');
ok($zip->set_number('5360007')->is_valid_number, '大阪府大阪市城東区成育');
ok($zip->set_number('5360008')->is_valid_number, '大阪府大阪市城東区関目');
ok($zip->set_number('5360011')->is_valid_number, '大阪府大阪市城東区放出西');
ok($zip->set_number('5360012')->is_valid_number, '大阪府大阪市城東区天王田');
ok($zip->set_number('5360013')->is_valid_number, '大阪府大阪市城東区鴫野東');
ok($zip->set_number('5360014')->is_valid_number, '大阪府大阪市城東区鴫野西');
ok($zip->set_number('5360015')->is_valid_number, '大阪府大阪市城東区新喜多');
ok($zip->set_number('5360016')->is_valid_number, '大阪府大阪市城東区蒲生');
ok($zip->set_number('5360017')->is_valid_number, '大阪府大阪市城東区新喜多東');
ok($zip->set_number('5360021')->is_valid_number, '大阪府大阪市城東区諏訪');
ok($zip->set_number('5360022')->is_valid_number, '大阪府大阪市城東区永田');
ok($zip->set_number('5360023')->is_valid_number, '大阪府大阪市城東区東中浜');
ok($zip->set_number('5360024')->is_valid_number, '大阪府大阪市城東区中浜');
ok($zip->set_number('5360025')->is_valid_number, '大阪府大阪市城東区森之宮');
ok($zip->set_number('5370000')->is_valid_number, '大阪府大阪市東成区以下に掲載がない場合');
ok($zip->set_number('5370001')->is_valid_number, '大阪府大阪市東成区深江北');
ok($zip->set_number('5370002')->is_valid_number, '大阪府大阪市東成区深江南');
ok($zip->set_number('5370003')->is_valid_number, '大阪府大阪市東成区神路');
ok($zip->set_number('5370011')->is_valid_number, '大阪府大阪市東成区東今里');
ok($zip->set_number('5370012')->is_valid_number, '大阪府大阪市東成区大今里');
ok($zip->set_number('5370013')->is_valid_number, '大阪府大阪市東成区大今里南');
ok($zip->set_number('5370014')->is_valid_number, '大阪府大阪市東成区大今里西');
ok($zip->set_number('5370021')->is_valid_number, '大阪府大阪市東成区東中本');
ok($zip->set_number('5370022')->is_valid_number, '大阪府大阪市東成区中本');
ok($zip->set_number('5370023')->is_valid_number, '大阪府大阪市東成区玉津');
ok($zip->set_number('5370024')->is_valid_number, '大阪府大阪市東成区東小橋');
ok($zip->set_number('5370025')->is_valid_number, '大阪府大阪市東成区中道');
ok($zip->set_number('5380000')->is_valid_number, '大阪府大阪市鶴見区以下に掲載がない場合');
ok($zip->set_number('5380031')->is_valid_number, '大阪府大阪市鶴見区茨田大宮');
ok($zip->set_number('5380032')->is_valid_number, '大阪府大阪市鶴見区安田');
ok($zip->set_number('5380033')->is_valid_number, '大阪府大阪市鶴見区中茶屋');
ok($zip->set_number('5380034')->is_valid_number, '大阪府大阪市鶴見区徳庵');
ok($zip->set_number('5380035')->is_valid_number, '大阪府大阪市鶴見区浜');
ok($zip->set_number('5380036')->is_valid_number, '大阪府大阪市鶴見区緑地公園');
ok($zip->set_number('5380037')->is_valid_number, '大阪府大阪市鶴見区焼野');
ok($zip->set_number('5380041')->is_valid_number, '大阪府大阪市鶴見区今津北');
ok($zip->set_number('5380042')->is_valid_number, '大阪府大阪市鶴見区今津中');
ok($zip->set_number('5380043')->is_valid_number, '大阪府大阪市鶴見区今津南');
ok($zip->set_number('5380044')->is_valid_number, '大阪府大阪市鶴見区放出東');
ok($zip->set_number('5380051')->is_valid_number, '大阪府大阪市鶴見区諸口');
ok($zip->set_number('5380052')->is_valid_number, '大阪府大阪市鶴見区横堤');
ok($zip->set_number('5380053')->is_valid_number, '大阪府大阪市鶴見区鶴見');
ok($zip->set_number('5380054')->is_valid_number, '大阪府大阪市鶴見区緑');
ok($zip->set_number('5390000')->is_valid_number, '大阪府大阪市中央区以下に掲載がない場合');
ok($zip->set_number('5400001')->is_valid_number, '大阪府大阪市中央区城見(次のビルを除く)');
ok($zip->set_number('5400002')->is_valid_number, '大阪府大阪市中央区大阪城');
ok($zip->set_number('5400003')->is_valid_number, '大阪府大阪市中央区森ノ宮中央');
ok($zip->set_number('5400004')->is_valid_number, '大阪府大阪市中央区玉造');
ok($zip->set_number('5400005')->is_valid_number, '大阪府大阪市中央区上町');
ok($zip->set_number('5400006')->is_valid_number, '大阪府大阪市中央区法円坂');
ok($zip->set_number('5400007')->is_valid_number, '大阪府大阪市中央区馬場町');
ok($zip->set_number('5400008')->is_valid_number, '大阪府大阪市中央区大手前');
ok($zip->set_number('5400010')->is_valid_number, '大阪府大阪市中央区材木町');
ok($zip->set_number('5400011')->is_valid_number, '大阪府大阪市中央区農人橋');
ok($zip->set_number('5400012')->is_valid_number, '大阪府大阪市中央区谷町(1~5丁目)');
ok($zip->set_number('5400013')->is_valid_number, '大阪府大阪市中央区内久宝寺町');
ok($zip->set_number('5400014')->is_valid_number, '大阪府大阪市中央区龍造寺町');
ok($zip->set_number('5400015')->is_valid_number, '大阪府大阪市中央区十二軒町');
ok($zip->set_number('5400016')->is_valid_number, '大阪府大阪市中央区神崎町');
ok($zip->set_number('5400017')->is_valid_number, '大阪府大阪市中央区松屋町住吉');
ok($zip->set_number('5400018')->is_valid_number, '大阪府大阪市中央区粉川町');
ok($zip->set_number('5400019')->is_valid_number, '大阪府大阪市中央区和泉町');
ok($zip->set_number('5400021')->is_valid_number, '大阪府大阪市中央区大手通');
ok($zip->set_number('5400022')->is_valid_number, '大阪府大阪市中央区糸屋町');
ok($zip->set_number('5400023')->is_valid_number, '大阪府大阪市中央区北新町');
ok($zip->set_number('5400024')->is_valid_number, '大阪府大阪市中央区南新町');
ok($zip->set_number('5400025')->is_valid_number, '大阪府大阪市中央区徳井町');
ok($zip->set_number('5400026')->is_valid_number, '大阪府大阪市中央区内本町');
ok($zip->set_number('5400027')->is_valid_number, '大阪府大阪市中央区鎗屋町');
ok($zip->set_number('5400028')->is_valid_number, '大阪府大阪市中央区常盤町');
ok($zip->set_number('5400029')->is_valid_number, '大阪府大阪市中央区本町橋');
ok($zip->set_number('5400031')->is_valid_number, '大阪府大阪市中央区北浜東');
ok($zip->set_number('5400032')->is_valid_number, '大阪府大阪市中央区天満橋京町');
ok($zip->set_number('5400033')->is_valid_number, '大阪府大阪市中央区石町');
ok($zip->set_number('5400034')->is_valid_number, '大阪府大阪市中央区島町');
ok($zip->set_number('5400035')->is_valid_number, '大阪府大阪市中央区釣鐘町');
ok($zip->set_number('5400036')->is_valid_number, '大阪府大阪市中央区船越町');
ok($zip->set_number('5400037')->is_valid_number, '大阪府大阪市中央区内平野町');
ok($zip->set_number('5400038')->is_valid_number, '大阪府大阪市中央区内淡路町');
ok($zip->set_number('5400039')->is_valid_number, '大阪府大阪市中央区東高麗橋');
ok($zip->set_number('5406001')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(1階)');
ok($zip->set_number('5406002')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(2階)');
ok($zip->set_number('5406003')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(3階)');
ok($zip->set_number('5406004')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(4階)');
ok($zip->set_number('5406005')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(5階)');
ok($zip->set_number('5406006')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(6階)');
ok($zip->set_number('5406007')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(7階)');
ok($zip->set_number('5406008')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(8階)');
ok($zip->set_number('5406009')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(9階)');
ok($zip->set_number('5406010')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(10階)');
ok($zip->set_number('5406011')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(11階)');
ok($zip->set_number('5406012')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(12階)');
ok($zip->set_number('5406013')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(13階)');
ok($zip->set_number('5406014')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(14階)');
ok($zip->set_number('5406015')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(15階)');
ok($zip->set_number('5406016')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(16階)');
ok($zip->set_number('5406017')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(17階)');
ok($zip->set_number('5406018')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(18階)');
ok($zip->set_number('5406019')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(19階)');
ok($zip->set_number('5406020')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(20階)');
ok($zip->set_number('5406021')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(21階)');
ok($zip->set_number('5406022')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(22階)');
ok($zip->set_number('5406023')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(23階)');
ok($zip->set_number('5406024')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(24階)');
ok($zip->set_number('5406025')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(25階)');
ok($zip->set_number('5406026')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(26階)');
ok($zip->set_number('5406027')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(27階)');
ok($zip->set_number('5406028')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(28階)');
ok($zip->set_number('5406029')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(29階)');
ok($zip->set_number('5406030')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(30階)');
ok($zip->set_number('5406031')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(31階)');
ok($zip->set_number('5406032')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(32階)');
ok($zip->set_number('5406033')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(33階)');
ok($zip->set_number('5406034')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(34階)');
ok($zip->set_number('5406035')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(35階)');
ok($zip->set_number('5406036')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(36階)');
ok($zip->set_number('5406037')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(37階)');
ok($zip->set_number('5406090')->is_valid_number, '大阪府大阪市中央区城見クリスタルタワー(地階・階層不明)');
ok($zip->set_number('5406101')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(1階)');
ok($zip->set_number('5406102')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(2階)');
ok($zip->set_number('5406103')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(3階)');
ok($zip->set_number('5406104')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(4階)');
ok($zip->set_number('5406105')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(5階)');
ok($zip->set_number('5406106')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(6階)');
ok($zip->set_number('5406107')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(7階)');
ok($zip->set_number('5406108')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(8階)');
ok($zip->set_number('5406109')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(9階)');
ok($zip->set_number('5406110')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(10階)');
ok($zip->set_number('5406111')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(11階)');
ok($zip->set_number('5406112')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(12階)');
ok($zip->set_number('5406113')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(13階)');
ok($zip->set_number('5406114')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(14階)');
ok($zip->set_number('5406115')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(15階)');
ok($zip->set_number('5406116')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(16階)');
ok($zip->set_number('5406117')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(17階)');
ok($zip->set_number('5406118')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(18階)');
ok($zip->set_number('5406119')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(19階)');
ok($zip->set_number('5406120')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(20階)');
ok($zip->set_number('5406121')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(21階)');
ok($zip->set_number('5406122')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(22階)');
ok($zip->set_number('5406123')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(23階)');
ok($zip->set_number('5406124')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(24階)');
ok($zip->set_number('5406125')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(25階)');
ok($zip->set_number('5406126')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(26階)');
ok($zip->set_number('5406127')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(27階)');
ok($zip->set_number('5406128')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(28階)');
ok($zip->set_number('5406129')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(29階)');
ok($zip->set_number('5406130')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(30階)');
ok($zip->set_number('5406131')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(31階)');
ok($zip->set_number('5406132')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(32階)');
ok($zip->set_number('5406133')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(33階)');
ok($zip->set_number('5406134')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(34階)');
ok($zip->set_number('5406135')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(35階)');
ok($zip->set_number('5406136')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(36階)');
ok($zip->set_number('5406137')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(37階)');
ok($zip->set_number('5406138')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(38階)');
ok($zip->set_number('5406190')->is_valid_number, '大阪府大阪市中央区城見MIDタワー(地階・階層不明)');
ok($zip->set_number('5406201')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(1階)');
ok($zip->set_number('5406202')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(2階)');
ok($zip->set_number('5406203')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(3階)');
ok($zip->set_number('5406204')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(4階)');
ok($zip->set_number('5406205')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(5階)');
ok($zip->set_number('5406206')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(6階)');
ok($zip->set_number('5406207')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(7階)');
ok($zip->set_number('5406208')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(8階)');
ok($zip->set_number('5406209')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(9階)');
ok($zip->set_number('5406210')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(10階)');
ok($zip->set_number('5406211')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(11階)');
ok($zip->set_number('5406212')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(12階)');
ok($zip->set_number('5406213')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(13階)');
ok($zip->set_number('5406214')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(14階)');
ok($zip->set_number('5406215')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(15階)');
ok($zip->set_number('5406216')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(16階)');
ok($zip->set_number('5406217')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(17階)');
ok($zip->set_number('5406218')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(18階)');
ok($zip->set_number('5406219')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(19階)');
ok($zip->set_number('5406220')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(20階)');
ok($zip->set_number('5406221')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(21階)');
ok($zip->set_number('5406222')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(22階)');
ok($zip->set_number('5406223')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(23階)');
ok($zip->set_number('5406224')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(24階)');
ok($zip->set_number('5406225')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(25階)');
ok($zip->set_number('5406226')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(26階)');
ok($zip->set_number('5406227')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(27階)');
ok($zip->set_number('5406228')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(28階)');
ok($zip->set_number('5406229')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(29階)');
ok($zip->set_number('5406230')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(30階)');
ok($zip->set_number('5406231')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(31階)');
ok($zip->set_number('5406232')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(32階)');
ok($zip->set_number('5406233')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(33階)');
ok($zip->set_number('5406234')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(34階)');
ok($zip->set_number('5406235')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(35階)');
ok($zip->set_number('5406236')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(36階)');
ok($zip->set_number('5406237')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(37階)');
ok($zip->set_number('5406238')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(38階)');
ok($zip->set_number('5406290')->is_valid_number, '大阪府大阪市中央区城見パナソニックタワー(地階・階層不明)');
ok($zip->set_number('5406301')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(1階)');
ok($zip->set_number('5406302')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(2階)');
ok($zip->set_number('5406303')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(3階)');
ok($zip->set_number('5406304')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(4階)');
ok($zip->set_number('5406305')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(5階)');
ok($zip->set_number('5406306')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(6階)');
ok($zip->set_number('5406307')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(7階)');
ok($zip->set_number('5406308')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(8階)');
ok($zip->set_number('5406309')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(9階)');
ok($zip->set_number('5406310')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(10階)');
ok($zip->set_number('5406311')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(11階)');
ok($zip->set_number('5406312')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(12階)');
ok($zip->set_number('5406313')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(13階)');
ok($zip->set_number('5406314')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(14階)');
ok($zip->set_number('5406315')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(15階)');
ok($zip->set_number('5406316')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(16階)');
ok($zip->set_number('5406317')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(17階)');
ok($zip->set_number('5406318')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(18階)');
ok($zip->set_number('5406319')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(19階)');
ok($zip->set_number('5406320')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(20階)');
ok($zip->set_number('5406321')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(21階)');
ok($zip->set_number('5406322')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(22階)');
ok($zip->set_number('5406323')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(23階)');
ok($zip->set_number('5406324')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(24階)');
ok($zip->set_number('5406325')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(25階)');
ok($zip->set_number('5406326')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(26階)');
ok($zip->set_number('5406390')->is_valid_number, '大阪府大阪市中央区城見松下IMPビル(地階・階層不明)');
ok($zip->set_number('5410041')->is_valid_number, '大阪府大阪市中央区北浜');
ok($zip->set_number('5410042')->is_valid_number, '大阪府大阪市中央区今橋');
ok($zip->set_number('5410043')->is_valid_number, '大阪府大阪市中央区高麗橋');
ok($zip->set_number('5410044')->is_valid_number, '大阪府大阪市中央区伏見町');
ok($zip->set_number('5410045')->is_valid_number, '大阪府大阪市中央区道修町');
ok($zip->set_number('5410046')->is_valid_number, '大阪府大阪市中央区平野町');
ok($zip->set_number('5410047')->is_valid_number, '大阪府大阪市中央区淡路町');
ok($zip->set_number('5410048')->is_valid_number, '大阪府大阪市中央区瓦町');
ok($zip->set_number('5410051')->is_valid_number, '大阪府大阪市中央区備後町');
ok($zip->set_number('5410052')->is_valid_number, '大阪府大阪市中央区安土町');
ok($zip->set_number('5410053')->is_valid_number, '大阪府大阪市中央区本町');
ok($zip->set_number('5410054')->is_valid_number, '大阪府大阪市中央区南本町');
ok($zip->set_number('5410055')->is_valid_number, '大阪府大阪市中央区船場中央');
ok($zip->set_number('5410056')->is_valid_number, '大阪府大阪市中央区久太郎町');
ok($zip->set_number('5410057')->is_valid_number, '大阪府大阪市中央区北久宝寺町');
ok($zip->set_number('5410058')->is_valid_number, '大阪府大阪市中央区南久宝寺町');
ok($zip->set_number('5410059')->is_valid_number, '大阪府大阪市中央区博労町');
ok($zip->set_number('5420012')->is_valid_number, '大阪府大阪市中央区谷町(6~9丁目)');
ok($zip->set_number('5420061')->is_valid_number, '大阪府大阪市中央区安堂寺町');
ok($zip->set_number('5420062')->is_valid_number, '大阪府大阪市中央区上本町西');
ok($zip->set_number('5420063')->is_valid_number, '大阪府大阪市中央区東平');
ok($zip->set_number('5420064')->is_valid_number, '大阪府大阪市中央区上汐');
ok($zip->set_number('5420065')->is_valid_number, '大阪府大阪市中央区中寺');
ok($zip->set_number('5420066')->is_valid_number, '大阪府大阪市中央区瓦屋町');
ok($zip->set_number('5420067')->is_valid_number, '大阪府大阪市中央区松屋町');
ok($zip->set_number('5420071')->is_valid_number, '大阪府大阪市中央区道頓堀(その他)');
ok($zip->set_number('5420072')->is_valid_number, '大阪府大阪市中央区高津');
ok($zip->set_number('5420073')->is_valid_number, '大阪府大阪市中央区日本橋');
ok($zip->set_number('5420074')->is_valid_number, '大阪府大阪市中央区千日前');
ok($zip->set_number('5420075')->is_valid_number, '大阪府大阪市中央区難波千日前');
ok($zip->set_number('5420076')->is_valid_number, '大阪府大阪市中央区難波');
ok($zip->set_number('5420077')->is_valid_number, '大阪府大阪市中央区道頓堀(1丁目東)');
ok($zip->set_number('5420081')->is_valid_number, '大阪府大阪市中央区南船場');
ok($zip->set_number('5420082')->is_valid_number, '大阪府大阪市中央区島之内');
ok($zip->set_number('5420083')->is_valid_number, '大阪府大阪市中央区東心斎橋');
ok($zip->set_number('5420084')->is_valid_number, '大阪府大阪市中央区宗右衛門町');
ok($zip->set_number('5420085')->is_valid_number, '大阪府大阪市中央区心斎橋筋');
ok($zip->set_number('5420086')->is_valid_number, '大阪府大阪市中央区西心斎橋');
ok($zip->set_number('5430000')->is_valid_number, '大阪府大阪市天王寺区以下に掲載がない場合');
ok($zip->set_number('5430001')->is_valid_number, '大阪府大阪市天王寺区上本町');
ok($zip->set_number('5430002')->is_valid_number, '大阪府大阪市天王寺区上汐');
ok($zip->set_number('5430011')->is_valid_number, '大阪府大阪市天王寺区清水谷町');
ok($zip->set_number('5430012')->is_valid_number, '大阪府大阪市天王寺区空堀町');
ok($zip->set_number('5430013')->is_valid_number, '大阪府大阪市天王寺区玉造本町');
ok($zip->set_number('5430014')->is_valid_number, '大阪府大阪市天王寺区玉造元町');
ok($zip->set_number('5430015')->is_valid_number, '大阪府大阪市天王寺区真田山町');
ok($zip->set_number('5430016')->is_valid_number, '大阪府大阪市天王寺区餌差町');
ok($zip->set_number('5430017')->is_valid_number, '大阪府大阪市天王寺区城南寺町');
ok($zip->set_number('5430018')->is_valid_number, '大阪府大阪市天王寺区空清町');
ok($zip->set_number('5430021')->is_valid_number, '大阪府大阪市天王寺区東高津町');
ok($zip->set_number('5430022')->is_valid_number, '大阪府大阪市天王寺区味原本町');
ok($zip->set_number('5430023')->is_valid_number, '大阪府大阪市天王寺区味原町');
ok($zip->set_number('5430024')->is_valid_number, '大阪府大阪市天王寺区舟橋町');
ok($zip->set_number('5430025')->is_valid_number, '大阪府大阪市天王寺区下味原町');
ok($zip->set_number('5430026')->is_valid_number, '大阪府大阪市天王寺区東上町');
ok($zip->set_number('5430027')->is_valid_number, '大阪府大阪市天王寺区筆ケ崎町');
ok($zip->set_number('5430028')->is_valid_number, '大阪府大阪市天王寺区小橋町');
ok($zip->set_number('5430031')->is_valid_number, '大阪府大阪市天王寺区石ケ辻町');
ok($zip->set_number('5430032')->is_valid_number, '大阪府大阪市天王寺区細工谷');
ok($zip->set_number('5430033')->is_valid_number, '大阪府大阪市天王寺区堂ケ芝');
ok($zip->set_number('5430034')->is_valid_number, '大阪府大阪市天王寺区松ケ鼻町');
ok($zip->set_number('5430035')->is_valid_number, '大阪府大阪市天王寺区北山町');
ok($zip->set_number('5430036')->is_valid_number, '大阪府大阪市天王寺区小宮町');
ok($zip->set_number('5430037')->is_valid_number, '大阪府大阪市天王寺区上之宮町');
ok($zip->set_number('5430041')->is_valid_number, '大阪府大阪市天王寺区真法院町');
ok($zip->set_number('5430042')->is_valid_number, '大阪府大阪市天王寺区烏ケ辻');
ok($zip->set_number('5430043')->is_valid_number, '大阪府大阪市天王寺区勝山');
ok($zip->set_number('5430044')->is_valid_number, '大阪府大阪市天王寺区国分町');
ok($zip->set_number('5430045')->is_valid_number, '大阪府大阪市天王寺区寺田町');
ok($zip->set_number('5430051')->is_valid_number, '大阪府大阪市天王寺区四天王寺');
ok($zip->set_number('5430052')->is_valid_number, '大阪府大阪市天王寺区大道');
ok($zip->set_number('5430053')->is_valid_number, '大阪府大阪市天王寺区北河堀町');
ok($zip->set_number('5430054')->is_valid_number, '大阪府大阪市天王寺区南河堀町');
ok($zip->set_number('5430055')->is_valid_number, '大阪府大阪市天王寺区悲田院町');
ok($zip->set_number('5430056')->is_valid_number, '大阪府大阪市天王寺区堀越町');
ok($zip->set_number('5430061')->is_valid_number, '大阪府大阪市天王寺区伶人町');
ok($zip->set_number('5430062')->is_valid_number, '大阪府大阪市天王寺区逢阪');
ok($zip->set_number('5430063')->is_valid_number, '大阪府大阪市天王寺区茶臼山町');
ok($zip->set_number('5430071')->is_valid_number, '大阪府大阪市天王寺区生玉町');
ok($zip->set_number('5430072')->is_valid_number, '大阪府大阪市天王寺区生玉前町');
ok($zip->set_number('5430073')->is_valid_number, '大阪府大阪市天王寺区生玉寺町');
ok($zip->set_number('5430074')->is_valid_number, '大阪府大阪市天王寺区六万体町');
ok($zip->set_number('5430075')->is_valid_number, '大阪府大阪市天王寺区夕陽丘町');
ok($zip->set_number('5430076')->is_valid_number, '大阪府大阪市天王寺区下寺町');
ok($zip->set_number('5440000')->is_valid_number, '大阪府大阪市生野区以下に掲載がない場合');
ok($zip->set_number('5440001')->is_valid_number, '大阪府大阪市生野区新今里');
ok($zip->set_number('5440002')->is_valid_number, '大阪府大阪市生野区小路');
ok($zip->set_number('5440003')->is_valid_number, '大阪府大阪市生野区小路東');
ok($zip->set_number('5440004')->is_valid_number, '大阪府大阪市生野区巽北');
ok($zip->set_number('5440005')->is_valid_number, '大阪府大阪市生野区中川');
ok($zip->set_number('5440006')->is_valid_number, '大阪府大阪市生野区中川東');
ok($zip->set_number('5440011')->is_valid_number, '大阪府大阪市生野区田島');
ok($zip->set_number('5440012')->is_valid_number, '大阪府大阪市生野区巽西');
ok($zip->set_number('5440013')->is_valid_number, '大阪府大阪市生野区巽中');
ok($zip->set_number('5440014')->is_valid_number, '大阪府大阪市生野区巽東');
ok($zip->set_number('5440015')->is_valid_number, '大阪府大阪市生野区巽南');
ok($zip->set_number('5440021')->is_valid_number, '大阪府大阪市生野区勝山南');
ok($zip->set_number('5440022')->is_valid_number, '大阪府大阪市生野区舎利寺');
ok($zip->set_number('5440023')->is_valid_number, '大阪府大阪市生野区林寺');
ok($zip->set_number('5440024')->is_valid_number, '大阪府大阪市生野区生野西');
ok($zip->set_number('5440025')->is_valid_number, '大阪府大阪市生野区生野東');
ok($zip->set_number('5440031')->is_valid_number, '大阪府大阪市生野区鶴橋');
ok($zip->set_number('5440032')->is_valid_number, '大阪府大阪市生野区中川西');
ok($zip->set_number('5440033')->is_valid_number, '大阪府大阪市生野区勝山北');
ok($zip->set_number('5440034')->is_valid_number, '大阪府大阪市生野区桃谷');
ok($zip->set_number('5450000')->is_valid_number, '大阪府大阪市阿倍野区以下に掲載がない場合');
ok($zip->set_number('5450001')->is_valid_number, '大阪府大阪市阿倍野区天王寺町北');
ok($zip->set_number('5450002')->is_valid_number, '大阪府大阪市阿倍野区天王寺町南');
ok($zip->set_number('5450003')->is_valid_number, '大阪府大阪市阿倍野区美章園');
ok($zip->set_number('5450004')->is_valid_number, '大阪府大阪市阿倍野区文の里');
ok($zip->set_number('5450005')->is_valid_number, '大阪府大阪市阿倍野区三明町');
ok($zip->set_number('5450011')->is_valid_number, '大阪府大阪市阿倍野区昭和町');
ok($zip->set_number('5450012')->is_valid_number, '大阪府大阪市阿倍野区桃ケ池町');
ok($zip->set_number('5450013')->is_valid_number, '大阪府大阪市阿倍野区長池町');
ok($zip->set_number('5450014')->is_valid_number, '大阪府大阪市阿倍野区西田辺町');
ok($zip->set_number('5450021')->is_valid_number, '大阪府大阪市阿倍野区阪南町');
ok($zip->set_number('5450022')->is_valid_number, '大阪府大阪市阿倍野区播磨町');
ok($zip->set_number('5450023')->is_valid_number, '大阪府大阪市阿倍野区王子町');
ok($zip->set_number('5450031')->is_valid_number, '大阪府大阪市阿倍野区橋本町');
ok($zip->set_number('5450032')->is_valid_number, '大阪府大阪市阿倍野区晴明通');
ok($zip->set_number('5450033')->is_valid_number, '大阪府大阪市阿倍野区相生通');
ok($zip->set_number('5450034')->is_valid_number, '大阪府大阪市阿倍野区阿倍野元町');
ok($zip->set_number('5450035')->is_valid_number, '大阪府大阪市阿倍野区北畠');
ok($zip->set_number('5450036')->is_valid_number, '大阪府大阪市阿倍野区万代');
ok($zip->set_number('5450037')->is_valid_number, '大阪府大阪市阿倍野区帝塚山');
ok($zip->set_number('5450041')->is_valid_number, '大阪府大阪市阿倍野区共立通');
ok($zip->set_number('5450042')->is_valid_number, '大阪府大阪市阿倍野区丸山通');
ok($zip->set_number('5450043')->is_valid_number, '大阪府大阪市阿倍野区松虫通');
ok($zip->set_number('5450051')->is_valid_number, '大阪府大阪市阿倍野区旭町');
ok($zip->set_number('5450052')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋(次のビルを除く)');
ok($zip->set_number('5450053')->is_valid_number, '大阪府大阪市阿倍野区松崎町');
ok($zip->set_number('5456001')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(1階)');
ok($zip->set_number('5456002')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(2階)');
ok($zip->set_number('5456003')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(3階)');
ok($zip->set_number('5456004')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(4階)');
ok($zip->set_number('5456005')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(5階)');
ok($zip->set_number('5456006')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(6階)');
ok($zip->set_number('5456007')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(7階)');
ok($zip->set_number('5456008')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(8階)');
ok($zip->set_number('5456009')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(9階)');
ok($zip->set_number('5456010')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(10階)');
ok($zip->set_number('5456011')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(11階)');
ok($zip->set_number('5456012')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(12階)');
ok($zip->set_number('5456013')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(13階)');
ok($zip->set_number('5456014')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(14階)');
ok($zip->set_number('5456015')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(15階)');
ok($zip->set_number('5456016')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(16階)');
ok($zip->set_number('5456017')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(17階)');
ok($zip->set_number('5456018')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(18階)');
ok($zip->set_number('5456019')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(19階)');
ok($zip->set_number('5456020')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(20階)');
ok($zip->set_number('5456021')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(21階)');
ok($zip->set_number('5456022')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(22階)');
ok($zip->set_number('5456023')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(23階)');
ok($zip->set_number('5456024')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(24階)');
ok($zip->set_number('5456025')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(25階)');
ok($zip->set_number('5456026')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(26階)');
ok($zip->set_number('5456027')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(27階)');
ok($zip->set_number('5456028')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(28階)');
ok($zip->set_number('5456029')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(29階)');
ok($zip->set_number('5456030')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(30階)');
ok($zip->set_number('5456031')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(31階)');
ok($zip->set_number('5456032')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(32階)');
ok($zip->set_number('5456033')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(33階)');
ok($zip->set_number('5456034')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(34階)');
ok($zip->set_number('5456035')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(35階)');
ok($zip->set_number('5456036')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(36階)');
ok($zip->set_number('5456037')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(37階)');
ok($zip->set_number('5456038')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(38階)');
ok($zip->set_number('5456039')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(39階)');
ok($zip->set_number('5456040')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(40階)');
ok($zip->set_number('5456041')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(41階)');
ok($zip->set_number('5456042')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(42階)');
ok($zip->set_number('5456043')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(43階)');
ok($zip->set_number('5456044')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(44階)');
ok($zip->set_number('5456045')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(45階)');
ok($zip->set_number('5456046')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(46階)');
ok($zip->set_number('5456047')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(47階)');
ok($zip->set_number('5456048')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(48階)');
ok($zip->set_number('5456049')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(49階)');
ok($zip->set_number('5456050')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(50階)');
ok($zip->set_number('5456051')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(51階)');
ok($zip->set_number('5456052')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(52階)');
ok($zip->set_number('5456053')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(53階)');
ok($zip->set_number('5456054')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(54階)');
ok($zip->set_number('5456055')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(55階)');
ok($zip->set_number('5456056')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(56階)');
ok($zip->set_number('5456057')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(57階)');
ok($zip->set_number('5456058')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(58階)');
ok($zip->set_number('5456059')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(59階)');
ok($zip->set_number('5456060')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(60階)');
ok($zip->set_number('5456090')->is_valid_number, '大阪府大阪市阿倍野区阿倍野筋あべのハルカス(地階・階層不明)');
ok($zip->set_number('5460000')->is_valid_number, '大阪府大阪市東住吉区以下に掲載がない場合');
ok($zip->set_number('5460001')->is_valid_number, '大阪府大阪市東住吉区今林');
ok($zip->set_number('5460002')->is_valid_number, '大阪府大阪市東住吉区杭全');
ok($zip->set_number('5460003')->is_valid_number, '大阪府大阪市東住吉区今川');
ok($zip->set_number('5460011')->is_valid_number, '大阪府大阪市東住吉区針中野');
ok($zip->set_number('5460012')->is_valid_number, '大阪府大阪市東住吉区中野');
ok($zip->set_number('5460013')->is_valid_number, '大阪府大阪市東住吉区湯里');
ok($zip->set_number('5460014')->is_valid_number, '大阪府大阪市東住吉区鷹合');
ok($zip->set_number('5460021')->is_valid_number, '大阪府大阪市東住吉区照ケ丘矢田');
ok($zip->set_number('5460022')->is_valid_number, '大阪府大阪市東住吉区住道矢田');
ok($zip->set_number('5460023')->is_valid_number, '大阪府大阪市東住吉区矢田');
ok($zip->set_number('5460024')->is_valid_number, '大阪府大阪市東住吉区公園南矢田');
ok($zip->set_number('5460031')->is_valid_number, '大阪府大阪市東住吉区田辺');
ok($zip->set_number('5460032')->is_valid_number, '大阪府大阪市東住吉区東田辺');
ok($zip->set_number('5460033')->is_valid_number, '大阪府大阪市東住吉区南田辺');
ok($zip->set_number('5460034')->is_valid_number, '大阪府大阪市東住吉区長居公園');
ok($zip->set_number('5460035')->is_valid_number, '大阪府大阪市東住吉区山坂');
ok($zip->set_number('5460041')->is_valid_number, '大阪府大阪市東住吉区桑津');
ok($zip->set_number('5460042')->is_valid_number, '大阪府大阪市東住吉区西今川');
ok($zip->set_number('5460043')->is_valid_number, '大阪府大阪市東住吉区駒川');
ok($zip->set_number('5460044')->is_valid_number, '大阪府大阪市東住吉区北田辺');
ok($zip->set_number('5470000')->is_valid_number, '大阪府大阪市平野区以下に掲載がない場合');
ok($zip->set_number('5470001')->is_valid_number, '大阪府大阪市平野区加美北');
ok($zip->set_number('5470002')->is_valid_number, '大阪府大阪市平野区加美東');
ok($zip->set_number('5470003')->is_valid_number, '大阪府大阪市平野区加美南');
ok($zip->set_number('5470004')->is_valid_number, '大阪府大阪市平野区加美鞍作');
ok($zip->set_number('5470005')->is_valid_number, '大阪府大阪市平野区加美西');
ok($zip->set_number('5470006')->is_valid_number, '大阪府大阪市平野区加美正覚寺');
ok($zip->set_number('5470011')->is_valid_number, '大阪府大阪市平野区長吉出戸');
ok($zip->set_number('5470012')->is_valid_number, '大阪府大阪市平野区長吉六反');
ok($zip->set_number('5470013')->is_valid_number, '大阪府大阪市平野区長吉長原東');
ok($zip->set_number('5470014')->is_valid_number, '大阪府大阪市平野区長吉川辺');
ok($zip->set_number('5470015')->is_valid_number, '大阪府大阪市平野区長吉長原西');
ok($zip->set_number('5470016')->is_valid_number, '大阪府大阪市平野区長吉長原');
ok($zip->set_number('5470021')->is_valid_number, '大阪府大阪市平野区喜連東');
ok($zip->set_number('5470022')->is_valid_number, '大阪府大阪市平野区瓜破東');
ok($zip->set_number('5470023')->is_valid_number, '大阪府大阪市平野区瓜破南');
ok($zip->set_number('5470024')->is_valid_number, '大阪府大阪市平野区瓜破');
ok($zip->set_number('5470025')->is_valid_number, '大阪府大阪市平野区瓜破西');
ok($zip->set_number('5470026')->is_valid_number, '大阪府大阪市平野区喜連西');
ok($zip->set_number('5470027')->is_valid_number, '大阪府大阪市平野区喜連');
ok($zip->set_number('5470031')->is_valid_number, '大阪府大阪市平野区平野南');
ok($zip->set_number('5470032')->is_valid_number, '大阪府大阪市平野区流町');
ok($zip->set_number('5470033')->is_valid_number, '大阪府大阪市平野区平野西');
ok($zip->set_number('5470034')->is_valid_number, '大阪府大阪市平野区背戸口');
ok($zip->set_number('5470035')->is_valid_number, '大阪府大阪市平野区西脇');
ok($zip->set_number('5470041')->is_valid_number, '大阪府大阪市平野区平野北');
ok($zip->set_number('5470042')->is_valid_number, '大阪府大阪市平野区平野市町');
ok($zip->set_number('5470043')->is_valid_number, '大阪府大阪市平野区平野東');
ok($zip->set_number('5470044')->is_valid_number, '大阪府大阪市平野区平野本町');
ok($zip->set_number('5470045')->is_valid_number, '大阪府大阪市平野区平野上町');
ok($zip->set_number('5470046')->is_valid_number, '大阪府大阪市平野区平野宮町');
ok($zip->set_number('5470047')->is_valid_number, '大阪府大阪市平野区平野元町');
ok($zip->set_number('5470048')->is_valid_number, '大阪府大阪市平野区平野馬場');
ok($zip->set_number('5490001')->is_valid_number, '大阪府泉佐野市泉州空港北');
ok($zip->set_number('5490011')->is_valid_number, '大阪府泉南郡田尻町泉州空港中');
ok($zip->set_number('5490021')->is_valid_number, '大阪府泉南市泉州空港南');
ok($zip->set_number('5500000')->is_valid_number, '大阪府大阪市西区以下に掲載がない場合');
ok($zip->set_number('5500001')->is_valid_number, '大阪府大阪市西区土佐堀');
ok($zip->set_number('5500002')->is_valid_number, '大阪府大阪市西区江戸堀');
ok($zip->set_number('5500003')->is_valid_number, '大阪府大阪市西区京町堀');
ok($zip->set_number('5500004')->is_valid_number, '大阪府大阪市西区靱本町');
ok($zip->set_number('5500005')->is_valid_number, '大阪府大阪市西区西本町');
ok($zip->set_number('5500006')->is_valid_number, '大阪府大阪市西区江之子島');
ok($zip->set_number('5500011')->is_valid_number, '大阪府大阪市西区阿波座');
ok($zip->set_number('5500012')->is_valid_number, '大阪府大阪市西区立売堀');
ok($zip->set_number('5500013')->is_valid_number, '大阪府大阪市西区新町');
ok($zip->set_number('5500014')->is_valid_number, '大阪府大阪市西区北堀江');
ok($zip->set_number('5500015')->is_valid_number, '大阪府大阪市西区南堀江');
ok($zip->set_number('5500021')->is_valid_number, '大阪府大阪市西区川口');
ok($zip->set_number('5500022')->is_valid_number, '大阪府大阪市西区本田');
ok($zip->set_number('5500023')->is_valid_number, '大阪府大阪市西区千代崎');
ok($zip->set_number('5500024')->is_valid_number, '大阪府大阪市西区境川');
ok($zip->set_number('5500025')->is_valid_number, '大阪府大阪市西区九条南');
ok($zip->set_number('5500026')->is_valid_number, '大阪府大阪市西区安治川');
ok($zip->set_number('5500027')->is_valid_number, '大阪府大阪市西区九条');
ok($zip->set_number('5510000')->is_valid_number, '大阪府大阪市大正区以下に掲載がない場合');
ok($zip->set_number('5510001')->is_valid_number, '大阪府大阪市大正区三軒家西');
ok($zip->set_number('5510002')->is_valid_number, '大阪府大阪市大正区三軒家東');
ok($zip->set_number('5510003')->is_valid_number, '大阪府大阪市大正区千島');
ok($zip->set_number('5510011')->is_valid_number, '大阪府大阪市大正区小林東');
ok($zip->set_number('5510012')->is_valid_number, '大阪府大阪市大正区平尾');
ok($zip->set_number('5510013')->is_valid_number, '大阪府大阪市大正区小林西');
ok($zip->set_number('5510021')->is_valid_number, '大阪府大阪市大正区南恩加島');
ok($zip->set_number('5510022')->is_valid_number, '大阪府大阪市大正区船町');
ok($zip->set_number('5510023')->is_valid_number, '大阪府大阪市大正区鶴町');
ok($zip->set_number('5510031')->is_valid_number, '大阪府大阪市大正区泉尾');
ok($zip->set_number('5510032')->is_valid_number, '大阪府大阪市大正区北村');
ok($zip->set_number('5510033')->is_valid_number, '大阪府大阪市大正区北恩加島');
ok($zip->set_number('5520000')->is_valid_number, '大阪府大阪市港区以下に掲載がない場合');
ok($zip->set_number('5520001')->is_valid_number, '大阪府大阪市港区波除');
ok($zip->set_number('5520002')->is_valid_number, '大阪府大阪市港区市岡元町');
ok($zip->set_number('5520003')->is_valid_number, '大阪府大阪市港区磯路');
ok($zip->set_number('5520004')->is_valid_number, '大阪府大阪市港区夕凪');
ok($zip->set_number('5520005')->is_valid_number, '大阪府大阪市港区田中');
ok($zip->set_number('5520006')->is_valid_number, '大阪府大阪市港区石田');
ok($zip->set_number('5520007')->is_valid_number, '大阪府大阪市港区弁天');
ok($zip->set_number('5520011')->is_valid_number, '大阪府大阪市港区南市岡');
ok($zip->set_number('5520012')->is_valid_number, '大阪府大阪市港区市岡');
ok($zip->set_number('5520013')->is_valid_number, '大阪府大阪市港区福崎');
ok($zip->set_number('5520014')->is_valid_number, '大阪府大阪市港区八幡屋');
ok($zip->set_number('5520015')->is_valid_number, '大阪府大阪市港区池島');
ok($zip->set_number('5520016')->is_valid_number, '大阪府大阪市港区三先');
ok($zip->set_number('5520021')->is_valid_number, '大阪府大阪市港区築港');
ok($zip->set_number('5520022')->is_valid_number, '大阪府大阪市港区海岸通');
ok($zip->set_number('5520023')->is_valid_number, '大阪府大阪市港区港晴');
ok($zip->set_number('5530000')->is_valid_number, '大阪府大阪市福島区以下に掲載がない場合');
ok($zip->set_number('5530001')->is_valid_number, '大阪府大阪市福島区海老江');
ok($zip->set_number('5530002')->is_valid_number, '大阪府大阪市福島区鷺洲');
ok($zip->set_number('5530003')->is_valid_number, '大阪府大阪市福島区福島');
ok($zip->set_number('5530004')->is_valid_number, '大阪府大阪市福島区玉川');
ok($zip->set_number('5530005')->is_valid_number, '大阪府大阪市福島区野田');
ok($zip->set_number('5530006')->is_valid_number, '大阪府大阪市福島区吉野');
ok($zip->set_number('5530007')->is_valid_number, '大阪府大阪市福島区大開');
ok($zip->set_number('5540000')->is_valid_number, '大阪府大阪市此花区以下に掲載がない場合');
ok($zip->set_number('5540001')->is_valid_number, '大阪府大阪市此花区高見');
ok($zip->set_number('5540002')->is_valid_number, '大阪府大阪市此花区伝法');
ok($zip->set_number('5540011')->is_valid_number, '大阪府大阪市此花区朝日');
ok($zip->set_number('5540012')->is_valid_number, '大阪府大阪市此花区西九条');
ok($zip->set_number('5540013')->is_valid_number, '大阪府大阪市此花区梅香');
ok($zip->set_number('5540014')->is_valid_number, '大阪府大阪市此花区四貫島');
ok($zip->set_number('5540021')->is_valid_number, '大阪府大阪市此花区春日出北');
ok($zip->set_number('5540022')->is_valid_number, '大阪府大阪市此花区春日出中');
ok($zip->set_number('5540023')->is_valid_number, '大阪府大阪市此花区春日出南');
ok($zip->set_number('5540024')->is_valid_number, '大阪府大阪市此花区島屋');
ok($zip->set_number('5540031')->is_valid_number, '大阪府大阪市此花区桜島');
ok($zip->set_number('5540032')->is_valid_number, '大阪府大阪市此花区梅町');
ok($zip->set_number('5540033')->is_valid_number, '大阪府大阪市此花区北港');
ok($zip->set_number('5540041')->is_valid_number, '大阪府大阪市此花区北港白津');
ok($zip->set_number('5540042')->is_valid_number, '大阪府大阪市此花区北港緑地');
ok($zip->set_number('5540043')->is_valid_number, '大阪府大阪市此花区夢洲東');
ok($zip->set_number('5540051')->is_valid_number, '大阪府大阪市此花区酉島');
ok($zip->set_number('5540052')->is_valid_number, '大阪府大阪市此花区常吉');
ok($zip->set_number('5550000')->is_valid_number, '大阪府大阪市西淀川区以下に掲載がない場合');
ok($zip->set_number('5550001')->is_valid_number, '大阪府大阪市西淀川区佃');
ok($zip->set_number('5550011')->is_valid_number, '大阪府大阪市西淀川区竹島');
ok($zip->set_number('5550012')->is_valid_number, '大阪府大阪市西淀川区御幣島');
ok($zip->set_number('5550013')->is_valid_number, '大阪府大阪市西淀川区千舟');
ok($zip->set_number('5550021')->is_valid_number, '大阪府大阪市西淀川区歌島');
ok($zip->set_number('5550022')->is_valid_number, '大阪府大阪市西淀川区柏里');
ok($zip->set_number('5550023')->is_valid_number, '大阪府大阪市西淀川区花川');
ok($zip->set_number('5550024')->is_valid_number, '大阪府大阪市西淀川区野里');
ok($zip->set_number('5550025')->is_valid_number, '大阪府大阪市西淀川区姫里');
ok($zip->set_number('5550031')->is_valid_number, '大阪府大阪市西淀川区出来島');
ok($zip->set_number('5550032')->is_valid_number, '大阪府大阪市西淀川区大和田');
ok($zip->set_number('5550033')->is_valid_number, '大阪府大阪市西淀川区姫島');
ok($zip->set_number('5550034')->is_valid_number, '大阪府大阪市西淀川区福町');
ok($zip->set_number('5550041')->is_valid_number, '大阪府大阪市西淀川区中島');
ok($zip->set_number('5550042')->is_valid_number, '大阪府大阪市西淀川区西島');
ok($zip->set_number('5550043')->is_valid_number, '大阪府大阪市西淀川区大野');
ok($zip->set_number('5550044')->is_valid_number, '大阪府大阪市西淀川区百島');
ok($zip->set_number('5560000')->is_valid_number, '大阪府大阪市浪速区以下に掲載がない場合');
ok($zip->set_number('5560001')->is_valid_number, '大阪府大阪市浪速区下寺');
ok($zip->set_number('5560002')->is_valid_number, '大阪府大阪市浪速区恵美須東');
ok($zip->set_number('5560003')->is_valid_number, '大阪府大阪市浪速区恵美須西');
ok($zip->set_number('5560004')->is_valid_number, '大阪府大阪市浪速区日本橋西');
ok($zip->set_number('5560005')->is_valid_number, '大阪府大阪市浪速区日本橋');
ok($zip->set_number('5560006')->is_valid_number, '大阪府大阪市浪速区日本橋東');
ok($zip->set_number('5560011')->is_valid_number, '大阪府大阪市浪速区難波中');
ok($zip->set_number('5560012')->is_valid_number, '大阪府大阪市浪速区敷津東');
ok($zip->set_number('5560013')->is_valid_number, '大阪府大阪市浪速区戎本町');
ok($zip->set_number('5560014')->is_valid_number, '大阪府大阪市浪速区大国');
ok($zip->set_number('5560015')->is_valid_number, '大阪府大阪市浪速区敷津西');
ok($zip->set_number('5560016')->is_valid_number, '大阪府大阪市浪速区元町');
ok($zip->set_number('5560017')->is_valid_number, '大阪府大阪市浪速区湊町');
ok($zip->set_number('5560020')->is_valid_number, '大阪府大阪市浪速区立葉');
ok($zip->set_number('5560021')->is_valid_number, '大阪府大阪市浪速区幸町');
ok($zip->set_number('5560022')->is_valid_number, '大阪府大阪市浪速区桜川');
ok($zip->set_number('5560023')->is_valid_number, '大阪府大阪市浪速区稲荷');
ok($zip->set_number('5560024')->is_valid_number, '大阪府大阪市浪速区塩草');
ok($zip->set_number('5560025')->is_valid_number, '大阪府大阪市浪速区浪速東');
ok($zip->set_number('5560026')->is_valid_number, '大阪府大阪市浪速区浪速西');
ok($zip->set_number('5560027')->is_valid_number, '大阪府大阪市浪速区木津川');
ok($zip->set_number('5560028')->is_valid_number, '大阪府大阪市浪速区久保吉');
ok($zip->set_number('5560029')->is_valid_number, '大阪府大阪市浪速区芦原');
ok($zip->set_number('5570000')->is_valid_number, '大阪府大阪市西成区以下に掲載がない場合');
ok($zip->set_number('5570001')->is_valid_number, '大阪府大阪市西成区山王');
ok($zip->set_number('5570002')->is_valid_number, '大阪府大阪市西成区太子');
ok($zip->set_number('5570003')->is_valid_number, '大阪府大阪市西成区天下茶屋北');
ok($zip->set_number('5570004')->is_valid_number, '大阪府大阪市西成区萩之茶屋');
ok($zip->set_number('5570011')->is_valid_number, '大阪府大阪市西成区天下茶屋東');
ok($zip->set_number('5570012')->is_valid_number, '大阪府大阪市西成区聖天下');
ok($zip->set_number('5570013')->is_valid_number, '大阪府大阪市西成区天神ノ森');
ok($zip->set_number('5570014')->is_valid_number, '大阪府大阪市西成区天下茶屋');
ok($zip->set_number('5570015')->is_valid_number, '大阪府大阪市西成区花園南');
ok($zip->set_number('5570016')->is_valid_number, '大阪府大阪市西成区花園北');
ok($zip->set_number('5570021')->is_valid_number, '大阪府大阪市西成区北開');
ok($zip->set_number('5570022')->is_valid_number, '大阪府大阪市西成区中開');
ok($zip->set_number('5570023')->is_valid_number, '大阪府大阪市西成区南開');
ok($zip->set_number('5570024')->is_valid_number, '大阪府大阪市西成区出城');
ok($zip->set_number('5570025')->is_valid_number, '大阪府大阪市西成区長橋');
ok($zip->set_number('5570031')->is_valid_number, '大阪府大阪市西成区鶴見橋');
ok($zip->set_number('5570032')->is_valid_number, '大阪府大阪市西成区旭');
ok($zip->set_number('5570033')->is_valid_number, '大阪府大阪市西成区梅南');
ok($zip->set_number('5570034')->is_valid_number, '大阪府大阪市西成区松');
ok($zip->set_number('5570041')->is_valid_number, '大阪府大阪市西成区岸里');
ok($zip->set_number('5570042')->is_valid_number, '大阪府大阪市西成区岸里東');
ok($zip->set_number('5570043')->is_valid_number, '大阪府大阪市西成区玉出東');
ok($zip->set_number('5570044')->is_valid_number, '大阪府大阪市西成区玉出中');
ok($zip->set_number('5570045')->is_valid_number, '大阪府大阪市西成区玉出西');
ok($zip->set_number('5570051')->is_valid_number, '大阪府大阪市西成区橘');
ok($zip->set_number('5570052')->is_valid_number, '大阪府大阪市西成区潮路');
ok($zip->set_number('5570053')->is_valid_number, '大阪府大阪市西成区千本北');
ok($zip->set_number('5570054')->is_valid_number, '大阪府大阪市西成区千本中');
ok($zip->set_number('5570055')->is_valid_number, '大阪府大阪市西成区千本南');
ok($zip->set_number('5570061')->is_valid_number, '大阪府大阪市西成区北津守');
ok($zip->set_number('5570062')->is_valid_number, '大阪府大阪市西成区津守');
ok($zip->set_number('5570063')->is_valid_number, '大阪府大阪市西成区南津守');
ok($zip->set_number('5580000')->is_valid_number, '大阪府大阪市住吉区以下に掲載がない場合');
ok($zip->set_number('5580001')->is_valid_number, '大阪府大阪市住吉区大領');
ok($zip->set_number('5580002')->is_valid_number, '大阪府大阪市住吉区長居西');
ok($zip->set_number('5580003')->is_valid_number, '大阪府大阪市住吉区長居');
ok($zip->set_number('5580004')->is_valid_number, '大阪府大阪市住吉区長居東');
ok($zip->set_number('5580011')->is_valid_number, '大阪府大阪市住吉区苅田');
ok($zip->set_number('5580012')->is_valid_number, '大阪府大阪市住吉区庭井');
ok($zip->set_number('5580013')->is_valid_number, '大阪府大阪市住吉区我孫子東');
ok($zip->set_number('5580014')->is_valid_number, '大阪府大阪市住吉区我孫子');
ok($zip->set_number('5580015')->is_valid_number, '大阪府大阪市住吉区我孫子西');
ok($zip->set_number('5580021')->is_valid_number, '大阪府大阪市住吉区浅香');
ok($zip->set_number('5580022')->is_valid_number, '大阪府大阪市住吉区杉本');
ok($zip->set_number('5580023')->is_valid_number, '大阪府大阪市住吉区山之内');
ok($zip->set_number('5580024')->is_valid_number, '大阪府大阪市住吉区山之内元町');
ok($zip->set_number('5580031')->is_valid_number, '大阪府大阪市住吉区沢之町');
ok($zip->set_number('5580032')->is_valid_number, '大阪府大阪市住吉区遠里小野');
ok($zip->set_number('5580033')->is_valid_number, '大阪府大阪市住吉区清水丘');
ok($zip->set_number('5580041')->is_valid_number, '大阪府大阪市住吉区南住吉');
ok($zip->set_number('5580042')->is_valid_number, '大阪府大阪市住吉区殿辻');
ok($zip->set_number('5580043')->is_valid_number, '大阪府大阪市住吉区墨江');
ok($zip->set_number('5580044')->is_valid_number, '大阪府大阪市住吉区長峡町');
ok($zip->set_number('5580045')->is_valid_number, '大阪府大阪市住吉区住吉');
ok($zip->set_number('5580046')->is_valid_number, '大阪府大阪市住吉区上住吉');
ok($zip->set_number('5580047')->is_valid_number, '大阪府大阪市住吉区千躰');
ok($zip->set_number('5580051')->is_valid_number, '大阪府大阪市住吉区東粉浜');
ok($zip->set_number('5580052')->is_valid_number, '大阪府大阪市住吉区帝塚山西');
ok($zip->set_number('5580053')->is_valid_number, '大阪府大阪市住吉区帝塚山中');
ok($zip->set_number('5580054')->is_valid_number, '大阪府大阪市住吉区帝塚山東');
ok($zip->set_number('5580055')->is_valid_number, '大阪府大阪市住吉区万代');
ok($zip->set_number('5580056')->is_valid_number, '大阪府大阪市住吉区万代東');
ok($zip->set_number('5590000')->is_valid_number, '大阪府大阪市住之江区以下に掲載がない場合');
ok($zip->set_number('5590001')->is_valid_number, '大阪府大阪市住之江区粉浜');
ok($zip->set_number('5590002')->is_valid_number, '大阪府大阪市住之江区浜口東');
ok($zip->set_number('5590003')->is_valid_number, '大阪府大阪市住之江区安立');
ok($zip->set_number('5590004')->is_valid_number, '大阪府大阪市住之江区住之江');
ok($zip->set_number('5590005')->is_valid_number, '大阪府大阪市住之江区西住之江');
ok($zip->set_number('5590006')->is_valid_number, '大阪府大阪市住之江区浜口西');
ok($zip->set_number('5590007')->is_valid_number, '大阪府大阪市住之江区粉浜西');
ok($zip->set_number('5590011')->is_valid_number, '大阪府大阪市住之江区北加賀屋');
ok($zip->set_number('5590012')->is_valid_number, '大阪府大阪市住之江区東加賀屋');
ok($zip->set_number('5590013')->is_valid_number, '大阪府大阪市住之江区御崎');
ok($zip->set_number('5590014')->is_valid_number, '大阪府大阪市住之江区北島');
ok($zip->set_number('5590015')->is_valid_number, '大阪府大阪市住之江区南加賀屋');
ok($zip->set_number('5590016')->is_valid_number, '大阪府大阪市住之江区西加賀屋');
ok($zip->set_number('5590017')->is_valid_number, '大阪府大阪市住之江区中加賀屋');
ok($zip->set_number('5590021')->is_valid_number, '大阪府大阪市住之江区柴谷');
ok($zip->set_number('5590022')->is_valid_number, '大阪府大阪市住之江区緑木');
ok($zip->set_number('5590023')->is_valid_number, '大阪府大阪市住之江区泉');
ok($zip->set_number('5590024')->is_valid_number, '大阪府大阪市住之江区新北島');
ok($zip->set_number('5590025')->is_valid_number, '大阪府大阪市住之江区平林南');
ok($zip->set_number('5590026')->is_valid_number, '大阪府大阪市住之江区平林北');
ok($zip->set_number('5590031')->is_valid_number, '大阪府大阪市住之江区南港東');
ok($zip->set_number('5590032')->is_valid_number, '大阪府大阪市住之江区南港南');
ok($zip->set_number('5590033')->is_valid_number, '大阪府大阪市住之江区南港中');
ok($zip->set_number('5590034')->is_valid_number, '大阪府大阪市住之江区南港北');
ok($zip->set_number('5600000')->is_valid_number, '大阪府豊中市以下に掲載がない場合');
ok($zip->set_number('5600001')->is_valid_number, '大阪府豊中市北緑丘');
ok($zip->set_number('5600002')->is_valid_number, '大阪府豊中市緑丘');
ok($zip->set_number('5600003')->is_valid_number, '大阪府豊中市東豊中町');
ok($zip->set_number('5600004')->is_valid_number, '大阪府豊中市少路');
ok($zip->set_number('5600005')->is_valid_number, '大阪府豊中市西緑丘');
ok($zip->set_number('5600011')->is_valid_number, '大阪府豊中市上野西');
ok($zip->set_number('5600012')->is_valid_number, '大阪府豊中市上野坂');
ok($zip->set_number('5600013')->is_valid_number, '大阪府豊中市上野東');
ok($zip->set_number('5600014')->is_valid_number, '大阪府豊中市熊野町');
ok($zip->set_number('5600015')->is_valid_number, '大阪府豊中市赤阪');
ok($zip->set_number('5600016')->is_valid_number, '大阪府豊中市栗ケ丘町');
ok($zip->set_number('5600021')->is_valid_number, '大阪府豊中市本町');
ok($zip->set_number('5600022')->is_valid_number, '大阪府豊中市北桜塚');
ok($zip->set_number('5600023')->is_valid_number, '大阪府豊中市岡上の町');
ok($zip->set_number('5600024')->is_valid_number, '大阪府豊中市末広町');
ok($zip->set_number('5600025')->is_valid_number, '大阪府豊中市立花町');
ok($zip->set_number('5600026')->is_valid_number, '大阪府豊中市玉井町');
ok($zip->set_number('5600031')->is_valid_number, '大阪府豊中市蛍池北町');
ok($zip->set_number('5600032')->is_valid_number, '大阪府豊中市蛍池東町');
ok($zip->set_number('5600033')->is_valid_number, '大阪府豊中市蛍池中町');
ok($zip->set_number('5600034')->is_valid_number, '大阪府豊中市蛍池南町');
ok($zip->set_number('5600035')->is_valid_number, '大阪府豊中市箕輪');
ok($zip->set_number('5600036')->is_valid_number, '大阪府豊中市蛍池西町');
ok($zip->set_number('5600041')->is_valid_number, '大阪府豊中市清風荘');
ok($zip->set_number('5600042')->is_valid_number, '大阪府豊中市石橋麻田町');
ok($zip->set_number('5600043')->is_valid_number, '大阪府豊中市待兼山町');
ok($zip->set_number('5600044')->is_valid_number, '大阪府豊中市刀根山元町');
ok($zip->set_number('5600045')->is_valid_number, '大阪府豊中市刀根山');
ok($zip->set_number('5600046')->is_valid_number, '大阪府豊中市千里園');
ok($zip->set_number('5600051')->is_valid_number, '大阪府豊中市永楽荘');
ok($zip->set_number('5600052')->is_valid_number, '大阪府豊中市春日町');
ok($zip->set_number('5600053')->is_valid_number, '大阪府豊中市向丘');
ok($zip->set_number('5600054')->is_valid_number, '大阪府豊中市桜の町');
ok($zip->set_number('5600055')->is_valid_number, '大阪府豊中市柴原町');
ok($zip->set_number('5600056')->is_valid_number, '大阪府豊中市宮山町');
ok($zip->set_number('5600081')->is_valid_number, '大阪府豊中市新千里北町');
ok($zip->set_number('5600082')->is_valid_number, '大阪府豊中市新千里東町');
ok($zip->set_number('5600083')->is_valid_number, '大阪府豊中市新千里西町');
ok($zip->set_number('5600084')->is_valid_number, '大阪府豊中市新千里南町');
ok($zip->set_number('5600085')->is_valid_number, '大阪府豊中市上新田');
ok($zip->set_number('5610801')->is_valid_number, '大阪府豊中市曽根西町');
ok($zip->set_number('5610802')->is_valid_number, '大阪府豊中市曽根東町');
ok($zip->set_number('5610803')->is_valid_number, '大阪府豊中市城山町');
ok($zip->set_number('5610804')->is_valid_number, '大阪府豊中市曽根南町');
ok($zip->set_number('5610805')->is_valid_number, '大阪府豊中市原田南');
ok($zip->set_number('5610806')->is_valid_number, '大阪府豊中市原田西町');
ok($zip->set_number('5610807')->is_valid_number, '大阪府豊中市原田中');
ok($zip->set_number('5610808')->is_valid_number, '大阪府豊中市原田元町');
ok($zip->set_number('5610811')->is_valid_number, '大阪府豊中市若竹町');
ok($zip->set_number('5610812')->is_valid_number, '大阪府豊中市北条町');
ok($zip->set_number('5610813')->is_valid_number, '大阪府豊中市小曽根');
ok($zip->set_number('5610814')->is_valid_number, '大阪府豊中市豊南町東');
ok($zip->set_number('5610815')->is_valid_number, '大阪府豊中市豊南町南');
ok($zip->set_number('5610816')->is_valid_number, '大阪府豊中市豊南町西');
ok($zip->set_number('5610817')->is_valid_number, '大阪府豊中市浜');
ok($zip->set_number('5610821')->is_valid_number, '大阪府豊中市日出町');
ok($zip->set_number('5610822')->is_valid_number, '大阪府豊中市三国');
ok($zip->set_number('5610823')->is_valid_number, '大阪府豊中市神州町');
ok($zip->set_number('5610824')->is_valid_number, '大阪府豊中市大島町');
ok($zip->set_number('5610825')->is_valid_number, '大阪府豊中市二葉町');
ok($zip->set_number('5610826')->is_valid_number, '大阪府豊中市島江町');
ok($zip->set_number('5610827')->is_valid_number, '大阪府豊中市大黒町');
ok($zip->set_number('5610828')->is_valid_number, '大阪府豊中市三和町');
ok($zip->set_number('5610829')->is_valid_number, '大阪府豊中市千成町');
ok($zip->set_number('5610831')->is_valid_number, '大阪府豊中市庄内東町');
ok($zip->set_number('5610832')->is_valid_number, '大阪府豊中市庄内西町');
ok($zip->set_number('5610833')->is_valid_number, '大阪府豊中市庄内幸町');
ok($zip->set_number('5610834')->is_valid_number, '大阪府豊中市庄内栄町');
ok($zip->set_number('5610835')->is_valid_number, '大阪府豊中市庄本町');
ok($zip->set_number('5610836')->is_valid_number, '大阪府豊中市庄内宝町');
ok($zip->set_number('5610841')->is_valid_number, '大阪府豊中市名神口');
ok($zip->set_number('5610842')->is_valid_number, '大阪府豊中市今在家町');
ok($zip->set_number('5610843')->is_valid_number, '大阪府豊中市上津島');
ok($zip->set_number('5610844')->is_valid_number, '大阪府豊中市利倉西');
ok($zip->set_number('5610845')->is_valid_number, '大阪府豊中市利倉');
ok($zip->set_number('5610846')->is_valid_number, '大阪府豊中市利倉東');
ok($zip->set_number('5610851')->is_valid_number, '大阪府豊中市服部元町');
ok($zip->set_number('5610852')->is_valid_number, '大阪府豊中市服部本町');
ok($zip->set_number('5610853')->is_valid_number, '大阪府豊中市服部南町');
ok($zip->set_number('5610854')->is_valid_number, '大阪府豊中市稲津町');
ok($zip->set_number('5610855')->is_valid_number, '大阪府豊中市野田町');
ok($zip->set_number('5610856')->is_valid_number, '大阪府豊中市穂積');
ok($zip->set_number('5610857')->is_valid_number, '大阪府豊中市服部寿町');
ok($zip->set_number('5610858')->is_valid_number, '大阪府豊中市服部西町');
ok($zip->set_number('5610859')->is_valid_number, '大阪府豊中市服部豊町');
ok($zip->set_number('5610861')->is_valid_number, '大阪府豊中市東泉丘');
ok($zip->set_number('5610862')->is_valid_number, '大阪府豊中市西泉丘');
ok($zip->set_number('5610863')->is_valid_number, '大阪府豊中市広田町');
ok($zip->set_number('5610864')->is_valid_number, '大阪府豊中市夕日丘');
ok($zip->set_number('5610865')->is_valid_number, '大阪府豊中市旭丘');
ok($zip->set_number('5610871')->is_valid_number, '大阪府豊中市東寺内町');
ok($zip->set_number('5610872')->is_valid_number, '大阪府豊中市寺内');
ok($zip->set_number('5610873')->is_valid_number, '大阪府豊中市服部緑地');
ok($zip->set_number('5610874')->is_valid_number, '大阪府豊中市長興寺南');
ok($zip->set_number('5610875')->is_valid_number, '大阪府豊中市長興寺北');
ok($zip->set_number('5610881')->is_valid_number, '大阪府豊中市中桜塚');
ok($zip->set_number('5610882')->is_valid_number, '大阪府豊中市南桜塚');
ok($zip->set_number('5610883')->is_valid_number, '大阪府豊中市岡町南');
ok($zip->set_number('5610884')->is_valid_number, '大阪府豊中市岡町北');
ok($zip->set_number('5610885')->is_valid_number, '大阪府豊中市岡町');
ok($zip->set_number('5610891')->is_valid_number, '大阪府豊中市走井');
ok($zip->set_number('5610892')->is_valid_number, '大阪府豊中市山ノ上町');
ok($zip->set_number('5610893')->is_valid_number, '大阪府豊中市宝山町');
ok($zip->set_number('5610894')->is_valid_number, '大阪府豊中市勝部');
ok($zip->set_number('5620000')->is_valid_number, '大阪府箕面市以下に掲載がない場合');
ok($zip->set_number('5620001')->is_valid_number, '大阪府箕面市箕面');
ok($zip->set_number('5620002')->is_valid_number, '大阪府箕面市箕面公園');
ok($zip->set_number('5620003')->is_valid_number, '大阪府箕面市西小路');
ok($zip->set_number('5620004')->is_valid_number, '大阪府箕面市牧落');
ok($zip->set_number('5620005')->is_valid_number, '大阪府箕面市新稲');
ok($zip->set_number('5620006')->is_valid_number, '大阪府箕面市温泉町');
ok($zip->set_number('5620011')->is_valid_number, '大阪府箕面市如意谷');
ok($zip->set_number('5620012')->is_valid_number, '大阪府箕面市白島');
ok($zip->set_number('5620013')->is_valid_number, '大阪府箕面市坊島');
ok($zip->set_number('5620014')->is_valid_number, '大阪府箕面市萱野');
ok($zip->set_number('5620015')->is_valid_number, '大阪府箕面市稲');
ok($zip->set_number('5620021')->is_valid_number, '大阪府箕面市粟生間谷');
ok($zip->set_number('5620022')->is_valid_number, '大阪府箕面市粟生間谷東');
ok($zip->set_number('5620023')->is_valid_number, '大阪府箕面市粟生間谷西');
ok($zip->set_number('5620024')->is_valid_number, '大阪府箕面市粟生新家');
ok($zip->set_number('5620025')->is_valid_number, '大阪府箕面市粟生外院');
ok($zip->set_number('5620026')->is_valid_number, '大阪府箕面市外院');
ok($zip->set_number('5620027')->is_valid_number, '大阪府箕面市石丸');
ok($zip->set_number('5620028')->is_valid_number, '大阪府箕面市彩都粟生南');
ok($zip->set_number('5620029')->is_valid_number, '大阪府箕面市彩都粟生北');
ok($zip->set_number('5620031')->is_valid_number, '大阪府箕面市小野原東');
ok($zip->set_number('5620032')->is_valid_number, '大阪府箕面市小野原西');
ok($zip->set_number('5620033')->is_valid_number, '大阪府箕面市今宮');
ok($zip->set_number('5620034')->is_valid_number, '大阪府箕面市西宿');
ok($zip->set_number('5620035')->is_valid_number, '大阪府箕面市船場東');
ok($zip->set_number('5620036')->is_valid_number, '大阪府箕面市船場西');
ok($zip->set_number('5620041')->is_valid_number, '大阪府箕面市桜');
ok($zip->set_number('5620042')->is_valid_number, '大阪府箕面市百楽荘');
ok($zip->set_number('5620043')->is_valid_number, '大阪府箕面市桜井');
ok($zip->set_number('5620044')->is_valid_number, '大阪府箕面市半町');
ok($zip->set_number('5620045')->is_valid_number, '大阪府箕面市瀬川');
ok($zip->set_number('5620046')->is_valid_number, '大阪府箕面市桜ケ丘');
ok($zip->set_number('5630000')->is_valid_number, '大阪府池田市以下に掲載がない場合');
ok($zip->set_number('5630011')->is_valid_number, '大阪府池田市伏尾町');
ok($zip->set_number('5630012')->is_valid_number, '大阪府池田市東山町');
ok($zip->set_number('5630013')->is_valid_number, '大阪府池田市中川原町');
ok($zip->set_number('5630014')->is_valid_number, '大阪府池田市木部町');
ok($zip->set_number('5630015')->is_valid_number, '大阪府池田市古江町');
ok($zip->set_number('5630016')->is_valid_number, '大阪府池田市吉田町');
ok($zip->set_number('5630017')->is_valid_number, '大阪府池田市伏尾台');
ok($zip->set_number('5630021')->is_valid_number, '大阪府池田市畑');
ok($zip->set_number('5630022')->is_valid_number, '大阪府池田市旭丘');
ok($zip->set_number('5630023')->is_valid_number, '大阪府池田市井口堂');
ok($zip->set_number('5630024')->is_valid_number, '大阪府池田市鉢塚');
ok($zip->set_number('5630025')->is_valid_number, '大阪府池田市城南');
ok($zip->set_number('5630026')->is_valid_number, '大阪府池田市緑丘');
ok($zip->set_number('5630027')->is_valid_number, '大阪府池田市上池田');
ok($zip->set_number('5630028')->is_valid_number, '大阪府池田市渋谷');
ok($zip->set_number('5630029')->is_valid_number, '大阪府池田市五月丘');
ok($zip->set_number('5630031')->is_valid_number, '大阪府池田市天神');
ok($zip->set_number('5630032')->is_valid_number, '大阪府池田市石橋');
ok($zip->set_number('5630033')->is_valid_number, '大阪府池田市住吉');
ok($zip->set_number('5630034')->is_valid_number, '大阪府池田市空港');
ok($zip->set_number('5630035')->is_valid_number, '大阪府池田市豊島南');
ok($zip->set_number('5630036')->is_valid_number, '大阪府池田市豊島北');
ok($zip->set_number('5630037')->is_valid_number, '大阪府池田市八王寺');
ok($zip->set_number('5630038')->is_valid_number, '大阪府池田市荘園');
ok($zip->set_number('5630041')->is_valid_number, '大阪府池田市満寿美町');
ok($zip->set_number('5630042')->is_valid_number, '大阪府池田市宇保町');
ok($zip->set_number('5630043')->is_valid_number, '大阪府池田市神田');
ok($zip->set_number('5630044')->is_valid_number, '大阪府池田市ダイハツ町');
ok($zip->set_number('5630045')->is_valid_number, '大阪府池田市桃園');
ok($zip->set_number('5630046')->is_valid_number, '大阪府池田市姫室町');
ok($zip->set_number('5630047')->is_valid_number, '大阪府池田市室町');
ok($zip->set_number('5630048')->is_valid_number, '大阪府池田市呉服町');
ok($zip->set_number('5630050')->is_valid_number, '大阪府池田市新町');
ok($zip->set_number('5630051')->is_valid_number, '大阪府池田市綾羽');
ok($zip->set_number('5630052')->is_valid_number, '大阪府池田市城山町');
ok($zip->set_number('5630053')->is_valid_number, '大阪府池田市建石町');
ok($zip->set_number('5630054')->is_valid_number, '大阪府池田市大和町');
ok($zip->set_number('5630055')->is_valid_number, '大阪府池田市菅原町');
ok($zip->set_number('5630056')->is_valid_number, '大阪府池田市栄町');
ok($zip->set_number('5630057')->is_valid_number, '大阪府池田市槻木町');
ok($zip->set_number('5630058')->is_valid_number, '大阪府池田市栄本町');
ok($zip->set_number('5630059')->is_valid_number, '大阪府池田市西本町');
ok($zip->set_number('5630100')->is_valid_number, '大阪府豊能郡豊能町以下に掲載がない場合');
ok($zip->set_number('5630101')->is_valid_number, '大阪府豊能郡豊能町吉川');
ok($zip->set_number('5630102')->is_valid_number, '大阪府豊能郡豊能町ときわ台');
ok($zip->set_number('5630103')->is_valid_number, '大阪府豊能郡豊能町東ときわ台');
ok($zip->set_number('5630104')->is_valid_number, '大阪府豊能郡豊能町光風台');
ok($zip->set_number('5630105')->is_valid_number, '大阪府豊能郡豊能町新光風台');
ok($zip->set_number('5630111')->is_valid_number, '大阪府豊能郡能勢町吉野');
ok($zip->set_number('5630112')->is_valid_number, '大阪府豊能郡能勢町杉原');
ok($zip->set_number('5630113')->is_valid_number, '大阪府豊能郡能勢町倉垣');
ok($zip->set_number('5630114')->is_valid_number, '大阪府豊能郡能勢町山内');
ok($zip->set_number('5630121')->is_valid_number, '大阪府豊能郡能勢町地黄');
ok($zip->set_number('5630122')->is_valid_number, '大阪府豊能郡能勢町上田尻');
ok($zip->set_number('5630123')->is_valid_number, '大阪府豊能郡能勢町下田尻');
ok($zip->set_number('5630131')->is_valid_number, '大阪府豊能郡能勢町野間大原');
ok($zip->set_number('5630132')->is_valid_number, '大阪府豊能郡能勢町野間中');
ok($zip->set_number('5630133')->is_valid_number, '大阪府豊能郡能勢町野間稲地');
ok($zip->set_number('5630134')->is_valid_number, '大阪府豊能郡能勢町野間出野');
ok($zip->set_number('5630135')->is_valid_number, '大阪府豊能郡能勢町野間西山');
ok($zip->set_number('5630211')->is_valid_number, '大阪府豊能郡豊能町牧');
ok($zip->set_number('5630212')->is_valid_number, '大阪府豊能郡豊能町寺田');
ok($zip->set_number('5630213')->is_valid_number, '大阪府豊能郡豊能町切畑');
ok($zip->set_number('5630214')->is_valid_number, '大阪府豊能郡豊能町希望ケ丘');
ok($zip->set_number('5630215')->is_valid_number, '大阪府豊能郡豊能町木代');
ok($zip->set_number('5630216')->is_valid_number, '大阪府豊能郡豊能町高山');
ok($zip->set_number('5630217')->is_valid_number, '大阪府豊能郡豊能町川尻');
ok($zip->set_number('5630218')->is_valid_number, '大阪府豊能郡豊能町野間口');
ok($zip->set_number('5630219')->is_valid_number, '大阪府豊能郡豊能町余野');
ok($zip->set_number('5630251')->is_valid_number, '大阪府箕面市上止々呂美');
ok($zip->set_number('5630252')->is_valid_number, '大阪府箕面市下止々呂美');
ok($zip->set_number('5630255')->is_valid_number, '大阪府箕面市森町西');
ok($zip->set_number('5630256')->is_valid_number, '大阪府箕面市森町北');
ok($zip->set_number('5630257')->is_valid_number, '大阪府箕面市森町中');
ok($zip->set_number('5630258')->is_valid_number, '大阪府箕面市森町南');
ok($zip->set_number('5630300')->is_valid_number, '大阪府豊能郡能勢町以下に掲載がない場合');
ok($zip->set_number('5630341')->is_valid_number, '大阪府豊能郡能勢町宿野');
ok($zip->set_number('5630351')->is_valid_number, '大阪府豊能郡能勢町栗栖');
ok($zip->set_number('5630352')->is_valid_number, '大阪府豊能郡能勢町大里');
ok($zip->set_number('5630353')->is_valid_number, '大阪府豊能郡能勢町柏原');
ok($zip->set_number('5630354')->is_valid_number, '大阪府豊能郡能勢町片山');
ok($zip->set_number('5630355')->is_valid_number, '大阪府豊能郡能勢町下田');
ok($zip->set_number('5630356')->is_valid_number, '大阪府豊能郡能勢町平通');
ok($zip->set_number('5630361')->is_valid_number, '大阪府豊能郡能勢町今西');
ok($zip->set_number('5630362')->is_valid_number, '大阪府豊能郡能勢町森上');
ok($zip->set_number('5630363')->is_valid_number, '大阪府豊能郡能勢町稲地');
ok($zip->set_number('5630364')->is_valid_number, '大阪府豊能郡能勢町平野');
ok($zip->set_number('5630365')->is_valid_number, '大阪府豊能郡能勢町上杉');
ok($zip->set_number('5630366')->is_valid_number, '大阪府豊能郡能勢町垂水');
ok($zip->set_number('5630367')->is_valid_number, '大阪府豊能郡能勢町神山');
ok($zip->set_number('5630368')->is_valid_number, '大阪府豊能郡能勢町長谷');
ok($zip->set_number('5630371')->is_valid_number, '大阪府豊能郡能勢町天王');
ok($zip->set_number('5630372')->is_valid_number, '大阪府豊能郡能勢町山辺');
ok($zip->set_number('5630373')->is_valid_number, '大阪府豊能郡能勢町山田');
ok($zip->set_number('5630801')->is_valid_number, '兵庫県伊丹市小阪田(食田)');
ok($zip->set_number('5640000')->is_valid_number, '大阪府吹田市以下に掲載がない場合');
ok($zip->set_number('5640001')->is_valid_number, '大阪府吹田市岸部北');
ok($zip->set_number('5640002')->is_valid_number, '大阪府吹田市岸部中');
ok($zip->set_number('5640003')->is_valid_number, '大阪府吹田市天道町');
ok($zip->set_number('5640004')->is_valid_number, '大阪府吹田市原町');
ok($zip->set_number('5640011')->is_valid_number, '大阪府吹田市岸部南');
ok($zip->set_number('5640012')->is_valid_number, '大阪府吹田市南正雀');
ok($zip->set_number('5640013')->is_valid_number, '大阪府吹田市川園町');
ok($zip->set_number('5640014')->is_valid_number, '大阪府吹田市吹東町');
ok($zip->set_number('5640015')->is_valid_number, '大阪府吹田市幸町');
ok($zip->set_number('5640016')->is_valid_number, '大阪府吹田市平松町');
ok($zip->set_number('5640017')->is_valid_number, '大阪府吹田市芝田町');
ok($zip->set_number('5640018')->is_valid_number, '大阪府吹田市岸部新町');
ok($zip->set_number('5640021')->is_valid_number, '大阪府吹田市目俵町');
ok($zip->set_number('5640022')->is_valid_number, '大阪府吹田市末広町');
ok($zip->set_number('5640023')->is_valid_number, '大阪府吹田市日の出町');
ok($zip->set_number('5640024')->is_valid_number, '大阪府吹田市高城町');
ok($zip->set_number('5640025')->is_valid_number, '大阪府吹田市南高浜町');
ok($zip->set_number('5640026')->is_valid_number, '大阪府吹田市高浜町');
ok($zip->set_number('5640027')->is_valid_number, '大阪府吹田市朝日町');
ok($zip->set_number('5640028')->is_valid_number, '大阪府吹田市昭和町');
ok($zip->set_number('5640031')->is_valid_number, '大阪府吹田市元町');
ok($zip->set_number('5640032')->is_valid_number, '大阪府吹田市内本町');
ok($zip->set_number('5640033')->is_valid_number, '大阪府吹田市東御旅町');
ok($zip->set_number('5640034')->is_valid_number, '大阪府吹田市西御旅町');
ok($zip->set_number('5640035')->is_valid_number, '大阪府吹田市中の島町');
ok($zip->set_number('5640036')->is_valid_number, '大阪府吹田市寿町');
ok($zip->set_number('5640037')->is_valid_number, '大阪府吹田市川岸町');
ok($zip->set_number('5640038')->is_valid_number, '大阪府吹田市南清和園町');
ok($zip->set_number('5640039')->is_valid_number, '大阪府吹田市清和園町');
ok($zip->set_number('5640041')->is_valid_number, '大阪府吹田市泉町');
ok($zip->set_number('5640042')->is_valid_number, '大阪府吹田市穂波町');
ok($zip->set_number('5640043')->is_valid_number, '大阪府吹田市南吹田');
ok($zip->set_number('5640044')->is_valid_number, '大阪府吹田市南金田');
ok($zip->set_number('5640045')->is_valid_number, '大阪府吹田市金田町');
ok($zip->set_number('5640051')->is_valid_number, '大阪府吹田市豊津町');
ok($zip->set_number('5640052')->is_valid_number, '大阪府吹田市広芝町');
ok($zip->set_number('5640053')->is_valid_number, '大阪府吹田市江の木町');
ok($zip->set_number('5640054')->is_valid_number, '大阪府吹田市芳野町');
ok($zip->set_number('5640061')->is_valid_number, '大阪府吹田市円山町');
ok($zip->set_number('5640062')->is_valid_number, '大阪府吹田市垂水町');
ok($zip->set_number('5640063')->is_valid_number, '大阪府吹田市江坂町');
ok($zip->set_number('5640071')->is_valid_number, '大阪府吹田市西の庄町');
ok($zip->set_number('5640072')->is_valid_number, '大阪府吹田市出口町');
ok($zip->set_number('5640073')->is_valid_number, '大阪府吹田市山手町');
ok($zip->set_number('5640081')->is_valid_number, '大阪府吹田市藤が丘町');
ok($zip->set_number('5640082')->is_valid_number, '大阪府吹田市片山町');
ok($zip->set_number('5640083')->is_valid_number, '大阪府吹田市朝日が丘町');
ok($zip->set_number('5650801')->is_valid_number, '大阪府吹田市青葉丘北');
ok($zip->set_number('5650802')->is_valid_number, '大阪府吹田市青葉丘南');
ok($zip->set_number('5650803')->is_valid_number, '大阪府吹田市新芦屋下');
ok($zip->set_number('5650804')->is_valid_number, '大阪府吹田市新芦屋上');
ok($zip->set_number('5650805')->is_valid_number, '大阪府吹田市清水');
ok($zip->set_number('5650806')->is_valid_number, '大阪府吹田市樫切山');
ok($zip->set_number('5650811')->is_valid_number, '大阪府吹田市千里丘上');
ok($zip->set_number('5650812')->is_valid_number, '大阪府吹田市千里丘中');
ok($zip->set_number('5650813')->is_valid_number, '大阪府吹田市千里丘下');
ok($zip->set_number('5650814')->is_valid_number, '大阪府吹田市千里丘西');
ok($zip->set_number('5650815')->is_valid_number, '大阪府吹田市千里丘北');
ok($zip->set_number('5650816')->is_valid_number, '大阪府吹田市長野東');
ok($zip->set_number('5650817')->is_valid_number, '大阪府吹田市長野西');
ok($zip->set_number('5650818')->is_valid_number, '大阪府吹田市尺谷');
ok($zip->set_number('5650821')->is_valid_number, '大阪府吹田市山田東');
ok($zip->set_number('5650822')->is_valid_number, '大阪府吹田市山田市場');
ok($zip->set_number('5650823')->is_valid_number, '大阪府吹田市山田南');
ok($zip->set_number('5650824')->is_valid_number, '大阪府吹田市山田西');
ok($zip->set_number('5650825')->is_valid_number, '大阪府吹田市山田北');
ok($zip->set_number('5650826')->is_valid_number, '大阪府吹田市千里万博公園');
ok($zip->set_number('5650831')->is_valid_number, '大阪府吹田市五月が丘東');
ok($zip->set_number('5650832')->is_valid_number, '大阪府吹田市五月が丘南');
ok($zip->set_number('5650833')->is_valid_number, '大阪府吹田市五月が丘西');
ok($zip->set_number('5650834')->is_valid_number, '大阪府吹田市五月が丘北');
ok($zip->set_number('5650835')->is_valid_number, '大阪府吹田市竹谷町');
ok($zip->set_number('5650836')->is_valid_number, '大阪府吹田市佐井寺');
ok($zip->set_number('5650837')->is_valid_number, '大阪府吹田市佐井寺南が丘');
ok($zip->set_number('5650841')->is_valid_number, '大阪府吹田市上山手町');
ok($zip->set_number('5650842')->is_valid_number, '大阪府吹田市千里山東');
ok($zip->set_number('5650843')->is_valid_number, '大阪府吹田市千里山松が丘');
ok($zip->set_number('5650844')->is_valid_number, '大阪府吹田市千里山霧が丘');
ok($zip->set_number('5650845')->is_valid_number, '大阪府吹田市千里山星が丘');
ok($zip->set_number('5650846')->is_valid_number, '大阪府吹田市千里山虹が丘');
ok($zip->set_number('5650847')->is_valid_number, '大阪府吹田市千里山月が丘');
ok($zip->set_number('5650848')->is_valid_number, '大阪府吹田市千里山高塚');
ok($zip->set_number('5650851')->is_valid_number, '大阪府吹田市千里山西');
ok($zip->set_number('5650852')->is_valid_number, '大阪府吹田市千里山竹園');
ok($zip->set_number('5650853')->is_valid_number, '大阪府吹田市春日');
ok($zip->set_number('5650854')->is_valid_number, '大阪府吹田市桃山台');
ok($zip->set_number('5650855')->is_valid_number, '大阪府吹田市佐竹台');
ok($zip->set_number('5650861')->is_valid_number, '大阪府吹田市高野台');
ok($zip->set_number('5650862')->is_valid_number, '大阪府吹田市津雲台');
ok($zip->set_number('5650863')->is_valid_number, '大阪府吹田市竹見台');
ok($zip->set_number('5650871')->is_valid_number, '大阪府吹田市山田丘');
ok($zip->set_number('5650872')->is_valid_number, '大阪府吹田市上山田');
ok($zip->set_number('5650873')->is_valid_number, '大阪府吹田市藤白台');
ok($zip->set_number('5650874')->is_valid_number, '大阪府吹田市古江台');
ok($zip->set_number('5650875')->is_valid_number, '大阪府吹田市青山台');
ok($zip->set_number('5660000')->is_valid_number, '大阪府摂津市以下に掲載がない場合');
ok($zip->set_number('5660001')->is_valid_number, '大阪府摂津市千里丘');
ok($zip->set_number('5660002')->is_valid_number, '大阪府摂津市千里丘新町');
ok($zip->set_number('5660011')->is_valid_number, '大阪府摂津市千里丘東');
ok($zip->set_number('5660012')->is_valid_number, '大阪府摂津市庄屋');
ok($zip->set_number('5660013')->is_valid_number, '大阪府摂津市阪急正雀');
ok($zip->set_number('5660021')->is_valid_number, '大阪府摂津市南千里丘');
ok($zip->set_number('5660022')->is_valid_number, '大阪府摂津市三島');
ok($zip->set_number('5660023')->is_valid_number, '大阪府摂津市正雀');
ok($zip->set_number('5660024')->is_valid_number, '大阪府摂津市正雀本町');
ok($zip->set_number('5660025')->is_valid_number, '大阪府摂津市東正雀');
ok($zip->set_number('5660031')->is_valid_number, '大阪府摂津市昭和園');
ok($zip->set_number('5660032')->is_valid_number, '大阪府摂津市桜町');
ok($zip->set_number('5660033')->is_valid_number, '大阪府摂津市学園町');
ok($zip->set_number('5660034')->is_valid_number, '大阪府摂津市香露園');
ok($zip->set_number('5660035')->is_valid_number, '大阪府摂津市鶴野');
ok($zip->set_number('5660041')->is_valid_number, '大阪府摂津市北別府町');
ok($zip->set_number('5660042')->is_valid_number, '大阪府摂津市東別府');
ok($zip->set_number('5660043')->is_valid_number, '大阪府摂津市一津屋');
ok($zip->set_number('5660044')->is_valid_number, '大阪府摂津市西一津屋');
ok($zip->set_number('5660045')->is_valid_number, '大阪府摂津市南別府町');
ok($zip->set_number('5660046')->is_valid_number, '大阪府摂津市別府');
ok($zip->set_number('5660047')->is_valid_number, '大阪府摂津市浜町');
ok($zip->set_number('5660051')->is_valid_number, '大阪府摂津市安威川南町');
ok($zip->set_number('5660052')->is_valid_number, '大阪府摂津市鳥飼本町');
ok($zip->set_number('5660053')->is_valid_number, '大阪府摂津市鳥飼野々');
ok($zip->set_number('5660054')->is_valid_number, '大阪府摂津市鳥飼八防');
ok($zip->set_number('5660055')->is_valid_number, '大阪府摂津市新在家');
ok($zip->set_number('5660061')->is_valid_number, '大阪府摂津市鳥飼八町');
ok($zip->set_number('5660062')->is_valid_number, '大阪府摂津市鳥飼上');
ok($zip->set_number('5660063')->is_valid_number, '大阪府摂津市鳥飼銘木町');
ok($zip->set_number('5660064')->is_valid_number, '大阪府摂津市鳥飼中');
ok($zip->set_number('5660065')->is_valid_number, '大阪府摂津市鳥飼新町');
ok($zip->set_number('5660071')->is_valid_number, '大阪府摂津市鳥飼下');
ok($zip->set_number('5660072')->is_valid_number, '大阪府摂津市鳥飼西');
ok($zip->set_number('5660073')->is_valid_number, '大阪府摂津市鳥飼和道');
ok($zip->set_number('5660074')->is_valid_number, '大阪府摂津市東一津屋');
ok($zip->set_number('5670000')->is_valid_number, '大阪府茨木市以下に掲載がない場合');
ok($zip->set_number('5670001')->is_valid_number, '大阪府茨木市安威');
ok($zip->set_number('5670002')->is_valid_number, '大阪府茨木市東安威');
ok($zip->set_number('5670003')->is_valid_number, '大阪府茨木市西河原北町');
ok($zip->set_number('5670004')->is_valid_number, '大阪府茨木市南耳原');
ok($zip->set_number('5670005')->is_valid_number, '大阪府茨木市五日市');
ok($zip->set_number('5670006')->is_valid_number, '大阪府茨木市耳原');
ok($zip->set_number('5670007')->is_valid_number, '大阪府茨木市南安威');
ok($zip->set_number('5670008')->is_valid_number, '大阪府茨木市西安威');
ok($zip->set_number('5670009')->is_valid_number, '大阪府茨木市山手台');
ok($zip->set_number('5670010')->is_valid_number, '大阪府茨木市山手台新町');
ok($zip->set_number('5670011')->is_valid_number, '大阪府茨木市高田町');
ok($zip->set_number('5670012')->is_valid_number, '大阪府茨木市東太田');
ok($zip->set_number('5670013')->is_valid_number, '大阪府茨木市太田東芝町');
ok($zip->set_number('5670014')->is_valid_number, '大阪府茨木市城の前町');
ok($zip->set_number('5670015')->is_valid_number, '大阪府茨木市西太田町');
ok($zip->set_number('5670016')->is_valid_number, '大阪府茨木市十日市町');
ok($zip->set_number('5670017')->is_valid_number, '大阪府茨木市花園');
ok($zip->set_number('5670018')->is_valid_number, '大阪府茨木市太田');
ok($zip->set_number('5670021')->is_valid_number, '大阪府茨木市三島丘');
ok($zip->set_number('5670022')->is_valid_number, '大阪府茨木市三島町');
ok($zip->set_number('5670023')->is_valid_number, '大阪府茨木市西河原');
ok($zip->set_number('5670024')->is_valid_number, '大阪府茨木市三咲町');
ok($zip->set_number('5670025')->is_valid_number, '大阪府茨木市田中町');
ok($zip->set_number('5670026')->is_valid_number, '大阪府茨木市松下町');
ok($zip->set_number('5670027')->is_valid_number, '大阪府茨木市西田中町');
ok($zip->set_number('5670028')->is_valid_number, '大阪府茨木市畑田町');
ok($zip->set_number('5670029')->is_valid_number, '大阪府茨木市五日市緑町');
ok($zip->set_number('5670031')->is_valid_number, '大阪府茨木市春日');
ok($zip->set_number('5670032')->is_valid_number, '大阪府茨木市西駅前町');
ok($zip->set_number('5670033')->is_valid_number, '大阪府茨木市松ケ本町');
ok($zip->set_number('5670034')->is_valid_number, '大阪府茨木市中穂積');
ok($zip->set_number('5670035')->is_valid_number, '大阪府茨木市見付山');
ok($zip->set_number('5670036')->is_valid_number, '大阪府茨木市上穂積');
ok($zip->set_number('5670037')->is_valid_number, '大阪府茨木市上穂東町');
ok($zip->set_number('5670041')->is_valid_number, '大阪府茨木市下穂積');
ok($zip->set_number('5670042')->is_valid_number, '大阪府茨木市宇野辺');
ok($zip->set_number('5670043')->is_valid_number, '大阪府茨木市小坪井');
ok($zip->set_number('5670044')->is_valid_number, '大阪府茨木市穂積台');
ok($zip->set_number('5670045')->is_valid_number, '大阪府茨木市紫明園');
ok($zip->set_number('5670046')->is_valid_number, '大阪府茨木市南春日丘');
ok($zip->set_number('5670047')->is_valid_number, '大阪府茨木市美穂ケ丘');
ok($zip->set_number('5670048')->is_valid_number, '大阪府茨木市北春日丘');
ok($zip->set_number('5670051')->is_valid_number, '大阪府茨木市宿久庄');
ok($zip->set_number('5670052')->is_valid_number, '大阪府茨木市室山');
ok($zip->set_number('5670053')->is_valid_number, '大阪府茨木市豊原町');
ok($zip->set_number('5670054')->is_valid_number, '大阪府茨木市藤の里');
ok($zip->set_number('5670055')->is_valid_number, '大阪府茨木市宿川原町');
ok($zip->set_number('5670056')->is_valid_number, '大阪府茨木市南清水町');
ok($zip->set_number('5670057')->is_valid_number, '大阪府茨木市豊川');
ok($zip->set_number('5670058')->is_valid_number, '大阪府茨木市西豊川町');
ok($zip->set_number('5670059')->is_valid_number, '大阪府茨木市清水');
ok($zip->set_number('5670061')->is_valid_number, '大阪府茨木市福井');
ok($zip->set_number('5670062')->is_valid_number, '大阪府茨木市東福井');
ok($zip->set_number('5670063')->is_valid_number, '大阪府茨木市中河原町');
ok($zip->set_number('5670064')->is_valid_number, '大阪府茨木市上野町');
ok($zip->set_number('5670065')->is_valid_number, '大阪府茨木市上郡');
ok($zip->set_number('5670066')->is_valid_number, '大阪府茨木市下井町');
ok($zip->set_number('5670067')->is_valid_number, '大阪府茨木市西福井');
ok($zip->set_number('5670071')->is_valid_number, '大阪府茨木市郡山');
ok($zip->set_number('5670072')->is_valid_number, '大阪府茨木市郡');
ok($zip->set_number('5670073')->is_valid_number, '大阪府茨木市西穂積町');
ok($zip->set_number('5670074')->is_valid_number, '大阪府茨木市新郡山');
ok($zip->set_number('5670075')->is_valid_number, '大阪府茨木市道祖本');
ok($zip->set_number('5670076')->is_valid_number, '大阪府茨木市井口台');
ok($zip->set_number('5670082')->is_valid_number, '大阪府茨木市彩都はなだ');
ok($zip->set_number('5670083')->is_valid_number, '大阪府茨木市彩都もえぎ');
ok($zip->set_number('5670084')->is_valid_number, '大阪府茨木市彩都あかね');
ok($zip->set_number('5670085')->is_valid_number, '大阪府茨木市彩都あさぎ');
ok($zip->set_number('5670086')->is_valid_number, '大阪府茨木市彩都やまぶき');
ok($zip->set_number('5670801')->is_valid_number, '大阪府茨木市総持寺');
ok($zip->set_number('5670802')->is_valid_number, '大阪府茨木市総持寺駅前町');
ok($zip->set_number('5670803')->is_valid_number, '大阪府茨木市中総持寺町');
ok($zip->set_number('5670804')->is_valid_number, '大阪府茨木市総持寺台');
ok($zip->set_number('5670805')->is_valid_number, '大阪府茨木市橋の内');
ok($zip->set_number('5670806')->is_valid_number, '大阪府茨木市庄');
ok($zip->set_number('5670810')->is_valid_number, '大阪府茨木市宮元町');
ok($zip->set_number('5670811')->is_valid_number, '大阪府茨木市上泉町');
ok($zip->set_number('5670812')->is_valid_number, '大阪府茨木市東宮町');
ok($zip->set_number('5670813')->is_valid_number, '大阪府茨木市大住町');
ok($zip->set_number('5670814')->is_valid_number, '大阪府茨木市戸伏町');
ok($zip->set_number('5670815')->is_valid_number, '大阪府茨木市竹橋町');
ok($zip->set_number('5670816')->is_valid_number, '大阪府茨木市永代町');
ok($zip->set_number('5670817')->is_valid_number, '大阪府茨木市別院町');
ok($zip->set_number('5670818')->is_valid_number, '大阪府茨木市本町');
ok($zip->set_number('5670819')->is_valid_number, '大阪府茨木市片桐町');
ok($zip->set_number('5670821')->is_valid_number, '大阪府茨木市末広町');
ok($zip->set_number('5670822')->is_valid_number, '大阪府茨木市中村町');
ok($zip->set_number('5670823')->is_valid_number, '大阪府茨木市寺田町');
ok($zip->set_number('5670824')->is_valid_number, '大阪府茨木市中津町');
ok($zip->set_number('5670825')->is_valid_number, '大阪府茨木市園田町');
ok($zip->set_number('5670826')->is_valid_number, '大阪府茨木市大池');
ok($zip->set_number('5670827')->is_valid_number, '大阪府茨木市稲葉町');
ok($zip->set_number('5670828')->is_valid_number, '大阪府茨木市舟木町');
ok($zip->set_number('5670829')->is_valid_number, '大阪府茨木市双葉町');
ok($zip->set_number('5670831')->is_valid_number, '大阪府茨木市鮎川');
ok($zip->set_number('5670832')->is_valid_number, '大阪府茨木市白川');
ok($zip->set_number('5670833')->is_valid_number, '大阪府茨木市学園町');
ok($zip->set_number('5670834')->is_valid_number, '大阪府茨木市学園南町');
ok($zip->set_number('5670835')->is_valid_number, '大阪府茨木市新堂');
ok($zip->set_number('5670836')->is_valid_number, '大阪府茨木市目垣');
ok($zip->set_number('5670837')->is_valid_number, '大阪府茨木市南目垣');
ok($zip->set_number('5670838')->is_valid_number, '大阪府茨木市東野々宮町');
ok($zip->set_number('5670841')->is_valid_number, '大阪府茨木市桑田町');
ok($zip->set_number('5670842')->is_valid_number, '大阪府茨木市五十鈴町');
ok($zip->set_number('5670843')->is_valid_number, '大阪府茨木市星見町');
ok($zip->set_number('5670844')->is_valid_number, '大阪府茨木市大同町');
ok($zip->set_number('5670845')->is_valid_number, '大阪府茨木市平田');
ok($zip->set_number('5670846')->is_valid_number, '大阪府茨木市玉島');
ok($zip->set_number('5670847')->is_valid_number, '大阪府茨木市野々宮');
ok($zip->set_number('5670848')->is_valid_number, '大阪府茨木市玉島台');
ok($zip->set_number('5670849')->is_valid_number, '大阪府茨木市平田台');
ok($zip->set_number('5670850')->is_valid_number, '大阪府茨木市真砂玉島台');
ok($zip->set_number('5670851')->is_valid_number, '大阪府茨木市真砂');
ok($zip->set_number('5670852')->is_valid_number, '大阪府茨木市小柳町');
ok($zip->set_number('5670853')->is_valid_number, '大阪府茨木市宮島');
ok($zip->set_number('5670854')->is_valid_number, '大阪府茨木市島');
ok($zip->set_number('5670855')->is_valid_number, '大阪府茨木市新和町');
ok($zip->set_number('5670861')->is_valid_number, '大阪府茨木市東奈良');
ok($zip->set_number('5670862')->is_valid_number, '大阪府茨木市美沢町');
ok($zip->set_number('5670863')->is_valid_number, '大阪府茨木市沢良宜東町');
ok($zip->set_number('5670864')->is_valid_number, '大阪府茨木市沢良宜浜');
ok($zip->set_number('5670865')->is_valid_number, '大阪府茨木市横江');
ok($zip->set_number('5670866')->is_valid_number, '大阪府茨木市高浜町');
ok($zip->set_number('5670867')->is_valid_number, '大阪府茨木市大正町');
ok($zip->set_number('5670868')->is_valid_number, '大阪府茨木市沢良宜西');
ok($zip->set_number('5670871')->is_valid_number, '大阪府茨木市岩倉町');
ok($zip->set_number('5670872')->is_valid_number, '大阪府茨木市新中条町');
ok($zip->set_number('5670873')->is_valid_number, '大阪府茨木市小川町');
ok($zip->set_number('5670874')->is_valid_number, '大阪府茨木市奈良町');
ok($zip->set_number('5670875')->is_valid_number, '大阪府茨木市若草町');
ok($zip->set_number('5670876')->is_valid_number, '大阪府茨木市天王');
ok($zip->set_number('5670877')->is_valid_number, '大阪府茨木市丑寅');
ok($zip->set_number('5670878')->is_valid_number, '大阪府茨木市蔵垣内');
ok($zip->set_number('5670879')->is_valid_number, '大阪府茨木市東宇野辺町');
ok($zip->set_number('5670881')->is_valid_number, '大阪府茨木市上中条');
ok($zip->set_number('5670882')->is_valid_number, '大阪府茨木市元町');
ok($zip->set_number('5670883')->is_valid_number, '大阪府茨木市大手町');
ok($zip->set_number('5670884')->is_valid_number, '大阪府茨木市新庄町');
ok($zip->set_number('5670885')->is_valid_number, '大阪府茨木市東中条町');
ok($zip->set_number('5670886')->is_valid_number, '大阪府茨木市下中条町');
ok($zip->set_number('5670887')->is_valid_number, '大阪府茨木市西中条町');
ok($zip->set_number('5670888')->is_valid_number, '大阪府茨木市駅前');
ok($zip->set_number('5670891')->is_valid_number, '大阪府茨木市水尾');
ok($zip->set_number('5670892')->is_valid_number, '大阪府茨木市並木町');
ok($zip->set_number('5670893')->is_valid_number, '大阪府茨木市玉瀬町');
ok($zip->set_number('5670894')->is_valid_number, '大阪府茨木市若園町');
ok($zip->set_number('5670895')->is_valid_number, '大阪府茨木市玉櫛');
ok($zip->set_number('5670896')->is_valid_number, '大阪府茨木市玉水町');
ok($zip->set_number('5670897')->is_valid_number, '大阪府茨木市主原町');
ok($zip->set_number('5680081')->is_valid_number, '大阪府茨木市清阪');
ok($zip->set_number('5680082')->is_valid_number, '大阪府茨木市下音羽');
ok($zip->set_number('5680083')->is_valid_number, '大阪府茨木市車作');
ok($zip->set_number('5680084')->is_valid_number, '大阪府茨木市安元');
ok($zip->set_number('5680085')->is_valid_number, '大阪府茨木市忍頂寺');
ok($zip->set_number('5680086')->is_valid_number, '大阪府茨木市上音羽');
ok($zip->set_number('5680087')->is_valid_number, '大阪府茨木市銭原');
ok($zip->set_number('5680088')->is_valid_number, '大阪府茨木市長谷');
ok($zip->set_number('5680089')->is_valid_number, '大阪府茨木市山手台東町');
ok($zip->set_number('5680091')->is_valid_number, '大阪府茨木市大岩');
ok($zip->set_number('5680092')->is_valid_number, '大阪府茨木市生保');
ok($zip->set_number('5680093')->is_valid_number, '大阪府茨木市大門寺');
ok($zip->set_number('5680094')->is_valid_number, '大阪府茨木市桑原');
ok($zip->set_number('5680095')->is_valid_number, '大阪府茨木市佐保');
ok($zip->set_number('5680096')->is_valid_number, '大阪府茨木市粟生岩阪');
ok($zip->set_number('5680097')->is_valid_number, '大阪府茨木市泉原');
ok($zip->set_number('5680098')->is_valid_number, '大阪府茨木市千提寺');
ok($zip->set_number('5690000')->is_valid_number, '大阪府高槻市以下に掲載がない場合');
ok($zip->set_number('5690001')->is_valid_number, '大阪府高槻市淀の原町');
ok($zip->set_number('5690002')->is_valid_number, '大阪府高槻市東上牧');
ok($zip->set_number('5690003')->is_valid_number, '大阪府高槻市上牧町');
ok($zip->set_number('5690004')->is_valid_number, '大阪府高槻市上牧南駅前町');
ok($zip->set_number('5690005')->is_valid_number, '大阪府高槻市上牧北駅前町');
ok($zip->set_number('5690006')->is_valid_number, '大阪府高槻市上牧山手町');
ok($zip->set_number('5690007')->is_valid_number, '大阪府高槻市神内');
ok($zip->set_number('5690011')->is_valid_number, '大阪府高槻市道鵜町');
ok($zip->set_number('5690012')->is_valid_number, '大阪府高槻市東天川');
ok($zip->set_number('5690013')->is_valid_number, '大阪府高槻市野田');
ok($zip->set_number('5690014')->is_valid_number, '大阪府高槻市野田東');
ok($zip->set_number('5690015')->is_valid_number, '大阪府高槻市井尻');
ok($zip->set_number('5690016')->is_valid_number, '大阪府高槻市五領町');
ok($zip->set_number('5690021')->is_valid_number, '大阪府高槻市前島');
ok($zip->set_number('5690022')->is_valid_number, '大阪府高槻市須賀町');
ok($zip->set_number('5690023')->is_valid_number, '大阪府高槻市松川町');
ok($zip->set_number('5690024')->is_valid_number, '大阪府高槻市日向町');
ok($zip->set_number('5690025')->is_valid_number, '大阪府高槻市藤の里町');
ok($zip->set_number('5690026')->is_valid_number, '大阪府高槻市天川町');
ok($zip->set_number('5690027')->is_valid_number, '大阪府高槻市天川新町');
ok($zip->set_number('5690031')->is_valid_number, '大阪府高槻市大冠町');
ok($zip->set_number('5690032')->is_valid_number, '大阪府高槻市東和町');
ok($zip->set_number('5690033')->is_valid_number, '大阪府高槻市深沢本町');
ok($zip->set_number('5690034')->is_valid_number, '大阪府高槻市大塚町');
ok($zip->set_number('5690035')->is_valid_number, '大阪府高槻市深沢町');
ok($zip->set_number('5690036')->is_valid_number, '大阪府高槻市辻子');
ok($zip->set_number('5690041')->is_valid_number, '大阪府高槻市北大樋町');
ok($zip->set_number('5690042')->is_valid_number, '大阪府高槻市南大樋町');
ok($zip->set_number('5690043')->is_valid_number, '大阪府高槻市竹の内町');
ok($zip->set_number('5690044')->is_valid_number, '大阪府高槻市番田');
ok($zip->set_number('5690045')->is_valid_number, '大阪府高槻市西大樋町');
ok($zip->set_number('5690046')->is_valid_number, '大阪府高槻市登町');
ok($zip->set_number('5690047')->is_valid_number, '大阪府高槻市堤町');
ok($zip->set_number('5690051')->is_valid_number, '大阪府高槻市八幡町');
ok($zip->set_number('5690052')->is_valid_number, '大阪府高槻市城東町');
ok($zip->set_number('5690053')->is_valid_number, '大阪府高槻市春日町');
ok($zip->set_number('5690054')->is_valid_number, '大阪府高槻市若松町');
ok($zip->set_number('5690055')->is_valid_number, '大阪府高槻市西冠');
ok($zip->set_number('5690056')->is_valid_number, '大阪府高槻市城南町');
ok($zip->set_number('5690057')->is_valid_number, '大阪府高槻市土橋町');
ok($zip->set_number('5690061')->is_valid_number, '大阪府高槻市高西町');
ok($zip->set_number('5690062')->is_valid_number, '大阪府高槻市下田部町');
ok($zip->set_number('5690063')->is_valid_number, '大阪府高槻市南庄所町');
ok($zip->set_number('5690064')->is_valid_number, '大阪府高槻市庄所町');
ok($zip->set_number('5690065')->is_valid_number, '大阪府高槻市城西町');
ok($zip->set_number('5690066')->is_valid_number, '大阪府高槻市中川町');
ok($zip->set_number('5690067')->is_valid_number, '大阪府高槻市桃園町');
ok($zip->set_number('5690071')->is_valid_number, '大阪府高槻市城北町');
ok($zip->set_number('5690072')->is_valid_number, '大阪府高槻市京口町');
ok($zip->set_number('5690073')->is_valid_number, '大阪府高槻市上本町');
ok($zip->set_number('5690074')->is_valid_number, '大阪府高槻市本町');
ok($zip->set_number('5690075')->is_valid_number, '大阪府高槻市城内町');
ok($zip->set_number('5690076')->is_valid_number, '大阪府高槻市出丸町');
ok($zip->set_number('5690077')->is_valid_number, '大阪府高槻市野見町');
ok($zip->set_number('5690078')->is_valid_number, '大阪府高槻市大手町');
ok($zip->set_number('5690081')->is_valid_number, '大阪府高槻市宮野町');
ok($zip->set_number('5690082')->is_valid_number, '大阪府高槻市明野町');
ok($zip->set_number('5690083')->is_valid_number, '大阪府高槻市永楽町');
ok($zip->set_number('5690084')->is_valid_number, '大阪府高槻市沢良木町');
ok($zip->set_number('5690085')->is_valid_number, '大阪府高槻市南松原町');
ok($zip->set_number('5690086')->is_valid_number, '大阪府高槻市松原町');
ok($zip->set_number('5690087')->is_valid_number, '大阪府高槻市千代田町');
ok($zip->set_number('5690088')->is_valid_number, '大阪府高槻市天王町');
ok($zip->set_number('5690091')->is_valid_number, '大阪府高槻市梶原');
ok($zip->set_number('5690092')->is_valid_number, '大阪府高槻市梶原中村町');
ok($zip->set_number('5690093')->is_valid_number, '大阪府高槻市萩之庄');
ok($zip->set_number('5690094')->is_valid_number, '大阪府高槻市緑町');
ok($zip->set_number('5690095')->is_valid_number, '大阪府高槻市八丁西町');
ok($zip->set_number('5690096')->is_valid_number, '大阪府高槻市八丁畷町');
ok($zip->set_number('5690097')->is_valid_number, '大阪府高槻市高垣町');
ok($zip->set_number('5690801')->is_valid_number, '大阪府高槻市大学町');
ok($zip->set_number('5690802')->is_valid_number, '大阪府高槻市北園町');
ok($zip->set_number('5690803')->is_valid_number, '大阪府高槻市高槻町');
ok($zip->set_number('5690804')->is_valid_number, '大阪府高槻市紺屋町');
ok($zip->set_number('5690805')->is_valid_number, '大阪府高槻市上田辺町');
ok($zip->set_number('5690806')->is_valid_number, '大阪府高槻市明田町');
ok($zip->set_number('5690807')->is_valid_number, '大阪府高槻市桜町');
ok($zip->set_number('5690811')->is_valid_number, '大阪府高槻市東五百住町');
ok($zip->set_number('5690812')->is_valid_number, '大阪府高槻市登美の里町');
ok($zip->set_number('5690813')->is_valid_number, '大阪府高槻市西五百住町');
ok($zip->set_number('5690814')->is_valid_number, '大阪府高槻市富田町');
ok($zip->set_number('5690815')->is_valid_number, '大阪府高槻市昭和台町');
ok($zip->set_number('5690816')->is_valid_number, '大阪府高槻市北昭和台町');
ok($zip->set_number('5690817')->is_valid_number, '大阪府高槻市桜ケ丘北町');
ok($zip->set_number('5690818')->is_valid_number, '大阪府高槻市桜ケ丘南町');
ok($zip->set_number('5690821')->is_valid_number, '大阪府高槻市津之江北町');
ok($zip->set_number('5690822')->is_valid_number, '大阪府高槻市津之江町');
ok($zip->set_number('5690823')->is_valid_number, '大阪府高槻市芝生町');
ok($zip->set_number('5690824')->is_valid_number, '大阪府高槻市川添');
ok($zip->set_number('5690825')->is_valid_number, '大阪府高槻市栄町');
ok($zip->set_number('5690826')->is_valid_number, '大阪府高槻市寿町');
ok($zip->set_number('5690827')->is_valid_number, '大阪府高槻市如是町');
ok($zip->set_number('5690831')->is_valid_number, '大阪府高槻市唐崎北');
ok($zip->set_number('5690832')->is_valid_number, '大阪府高槻市唐崎中');
ok($zip->set_number('5690833')->is_valid_number, '大阪府高槻市唐崎南');
ok($zip->set_number('5690834')->is_valid_number, '大阪府高槻市唐崎');
ok($zip->set_number('5690835')->is_valid_number, '大阪府高槻市三島江');
ok($zip->set_number('5690836')->is_valid_number, '大阪府高槻市唐崎西');
ok($zip->set_number('5690841')->is_valid_number, '大阪府高槻市西面北');
ok($zip->set_number('5690842')->is_valid_number, '大阪府高槻市西面中');
ok($zip->set_number('5690843')->is_valid_number, '大阪府高槻市三箇牧');
ok($zip->set_number('5690844')->is_valid_number, '大阪府高槻市柱本');
ok($zip->set_number('5690845')->is_valid_number, '大阪府高槻市柱本南町');
ok($zip->set_number('5690846')->is_valid_number, '大阪府高槻市柱本新町');
ok($zip->set_number('5690847')->is_valid_number, '大阪府高槻市西面南');
ok($zip->set_number('5690851')->is_valid_number, '大阪府高槻市南総持寺町');
ok($zip->set_number('5690852')->is_valid_number, '大阪府高槻市北柳川町');
ok($zip->set_number('5690853')->is_valid_number, '大阪府高槻市柳川町');
ok($zip->set_number('5690854')->is_valid_number, '大阪府高槻市西町');
ok($zip->set_number('5690855')->is_valid_number, '大阪府高槻市牧田町');
ok($zip->set_number('5690856')->is_valid_number, '大阪府高槻市玉川新町');
ok($zip->set_number('5690857')->is_valid_number, '大阪府高槻市玉川');
ok($zip->set_number('5691001')->is_valid_number, '大阪府高槻市中畑');
ok($zip->set_number('5691002')->is_valid_number, '大阪府高槻市田能');
ok($zip->set_number('5691003')->is_valid_number, '大阪府高槻市出灰');
ok($zip->set_number('5691004')->is_valid_number, '大阪府高槻市二料');
ok($zip->set_number('5691005')->is_valid_number, '大阪府高槻市杉生');
ok($zip->set_number('5691011')->is_valid_number, '大阪府高槻市川久保');
ok($zip->set_number('5691012')->is_valid_number, '大阪府高槻市成合');
ok($zip->set_number('5691013')->is_valid_number, '大阪府高槻市成合南の町');
ok($zip->set_number('5691014')->is_valid_number, '大阪府高槻市成合東の町');
ok($zip->set_number('5691015')->is_valid_number, '大阪府高槻市成合中の町');
ok($zip->set_number('5691016')->is_valid_number, '大阪府高槻市成合西の町');
ok($zip->set_number('5691017')->is_valid_number, '大阪府高槻市成合北の町');
ok($zip->set_number('5691018')->is_valid_number, '大阪府高槻市花林苑');
ok($zip->set_number('5691020')->is_valid_number, '大阪府高槻市高見台');
ok($zip->set_number('5691021')->is_valid_number, '大阪府高槻市弥生が丘町');
ok($zip->set_number('5691022')->is_valid_number, '大阪府高槻市日吉台');
ok($zip->set_number('5691023')->is_valid_number, '大阪府高槻市宮が谷町');
ok($zip->set_number('5691024')->is_valid_number, '大阪府高槻市寺谷町');
ok($zip->set_number('5691025')->is_valid_number, '大阪府高槻市芝谷町');
ok($zip->set_number('5691026')->is_valid_number, '大阪府高槻市緑が丘');
ok($zip->set_number('5691027')->is_valid_number, '大阪府高槻市浦堂');
ok($zip->set_number('5691028')->is_valid_number, '大阪府高槻市浦堂本町');
ok($zip->set_number('5691029')->is_valid_number, '大阪府高槻市安岡寺町');
ok($zip->set_number('5691031')->is_valid_number, '大阪府高槻市松が丘');
ok($zip->set_number('5691032')->is_valid_number, '大阪府高槻市宮之川原');
ok($zip->set_number('5691033')->is_valid_number, '大阪府高槻市宮之川原元町');
ok($zip->set_number('5691034')->is_valid_number, '大阪府高槻市大蔵司');
ok($zip->set_number('5691035')->is_valid_number, '大阪府高槻市西之川原');
ok($zip->set_number('5691036')->is_valid_number, '大阪府高槻市塚脇');
ok($zip->set_number('5691037')->is_valid_number, '大阪府高槻市東城山町');
ok($zip->set_number('5691038')->is_valid_number, '大阪府高槻市黄金の里');
ok($zip->set_number('5691039')->is_valid_number, '大阪府高槻市清水台');
ok($zip->set_number('5691041')->is_valid_number, '大阪府高槻市奈佐原');
ok($zip->set_number('5691042')->is_valid_number, '大阪府高槻市南平台');
ok($zip->set_number('5691043')->is_valid_number, '大阪府高槻市奈佐原元町');
ok($zip->set_number('5691044')->is_valid_number, '大阪府高槻市上土室');
ok($zip->set_number('5691045')->is_valid_number, '大阪府高槻市阿武野');
ok($zip->set_number('5691046')->is_valid_number, '大阪府高槻市塚原');
ok($zip->set_number('5691047')->is_valid_number, '大阪府高槻市大和');
ok($zip->set_number('5691051')->is_valid_number, '大阪府高槻市原');
ok($zip->set_number('5691052')->is_valid_number, '大阪府高槻市霊仙寺町');
ok($zip->set_number('5691053')->is_valid_number, '大阪府高槻市萩谷月見台');
ok($zip->set_number('5691054')->is_valid_number, '大阪府高槻市萩谷');
ok($zip->set_number('5691101')->is_valid_number, '大阪府高槻市安満御所の町');
ok($zip->set_number('5691102')->is_valid_number, '大阪府高槻市安満磐手町');
ok($zip->set_number('5691103')->is_valid_number, '大阪府高槻市山手町');
ok($zip->set_number('5691104')->is_valid_number, '大阪府高槻市安満東の町');
ok($zip->set_number('5691105')->is_valid_number, '大阪府高槻市安満中の町');
ok($zip->set_number('5691106')->is_valid_number, '大阪府高槻市安満新町');
ok($zip->set_number('5691107')->is_valid_number, '大阪府高槻市安満西の町');
ok($zip->set_number('5691108')->is_valid_number, '大阪府高槻市安満北の町');
ok($zip->set_number('5691109')->is_valid_number, '大阪府高槻市紅茸町');
ok($zip->set_number('5691111')->is_valid_number, '大阪府高槻市美しが丘');
ok($zip->set_number('5691112')->is_valid_number, '大阪府高槻市別所本町');
ok($zip->set_number('5691113')->is_valid_number, '大阪府高槻市別所中の町');
ok($zip->set_number('5691114')->is_valid_number, '大阪府高槻市別所新町');
ok($zip->set_number('5691115')->is_valid_number, '大阪府高槻市古曽部町');
ok($zip->set_number('5691116')->is_valid_number, '大阪府高槻市白梅町');
ok($zip->set_number('5691117')->is_valid_number, '大阪府高槻市天神町');
ok($zip->set_number('5691118')->is_valid_number, '大阪府高槻市奥天神町');
ok($zip->set_number('5691121')->is_valid_number, '大阪府高槻市真上町');
ok($zip->set_number('5691122')->is_valid_number, '大阪府高槻市月見町');
ok($zip->set_number('5691123')->is_valid_number, '大阪府高槻市芥川町');
ok($zip->set_number('5691124')->is_valid_number, '大阪府高槻市南芥川町');
ok($zip->set_number('5691125')->is_valid_number, '大阪府高槻市紫町');
ok($zip->set_number('5691126')->is_valid_number, '大阪府高槻市殿町');
ok($zip->set_number('5691127')->is_valid_number, '大阪府高槻市西真上');
ok($zip->set_number('5691128')->is_valid_number, '大阪府高槻市名神町');
ok($zip->set_number('5691131')->is_valid_number, '大阪府高槻市郡家本町');
ok($zip->set_number('5691132')->is_valid_number, '大阪府高槻市清福寺町');
ok($zip->set_number('5691133')->is_valid_number, '大阪府高槻市川西町');
ok($zip->set_number('5691134')->is_valid_number, '大阪府高槻市朝日町');
ok($zip->set_number('5691135')->is_valid_number, '大阪府高槻市今城町');
ok($zip->set_number('5691136')->is_valid_number, '大阪府高槻市郡家新町');
ok($zip->set_number('5691137')->is_valid_number, '大阪府高槻市岡本町');
ok($zip->set_number('5691141')->is_valid_number, '大阪府高槻市氷室町');
ok($zip->set_number('5691142')->is_valid_number, '大阪府高槻市宮田町');
ok($zip->set_number('5691143')->is_valid_number, '大阪府高槻市幸町');
ok($zip->set_number('5691144')->is_valid_number, '大阪府高槻市大畑町');
ok($zip->set_number('5691145')->is_valid_number, '大阪府高槻市富田丘町');
ok($zip->set_number('5691146')->is_valid_number, '大阪府高槻市赤大路町');
ok($zip->set_number('5691147')->is_valid_number, '大阪府高槻市土室町');
ok($zip->set_number('5700000')->is_valid_number, '大阪府守口市以下に掲載がない場合');
ok($zip->set_number('5700001')->is_valid_number, '大阪府守口市佐太西町');
ok($zip->set_number('5700002')->is_valid_number, '大阪府守口市佐太中町');
ok($zip->set_number('5700003')->is_valid_number, '大阪府守口市大日町');
ok($zip->set_number('5700004')->is_valid_number, '大阪府守口市淀江町');
ok($zip->set_number('5700005')->is_valid_number, '大阪府守口市八雲中町');
ok($zip->set_number('5700006')->is_valid_number, '大阪府守口市八雲西町');
ok($zip->set_number('5700007')->is_valid_number, '大阪府守口市下島町');
ok($zip->set_number('5700008')->is_valid_number, '大阪府守口市八雲北町');
ok($zip->set_number('5700009')->is_valid_number, '大阪府守口市大庭町');
ok($zip->set_number('5700011')->is_valid_number, '大阪府守口市金田町');
ok($zip->set_number('5700012')->is_valid_number, '大阪府守口市大久保町');
ok($zip->set_number('5700013')->is_valid_number, '大阪府守口市東町');
ok($zip->set_number('5700014')->is_valid_number, '大阪府守口市藤田町');
ok($zip->set_number('5700015')->is_valid_number, '大阪府守口市梶町');
ok($zip->set_number('5700016')->is_valid_number, '大阪府守口市大日東町');
ok($zip->set_number('5700017')->is_valid_number, '大阪府守口市佐太東町');
ok($zip->set_number('5700021')->is_valid_number, '大阪府守口市八雲東町');
ok($zip->set_number('5700022')->is_valid_number, '大阪府守口市暁町');
ok($zip->set_number('5700023')->is_valid_number, '大阪府守口市日向町');
ok($zip->set_number('5700024')->is_valid_number, '大阪府守口市神木町');
ok($zip->set_number('5700025')->is_valid_number, '大阪府守口市竜田通');
ok($zip->set_number('5700026')->is_valid_number, '大阪府守口市松月町');
ok($zip->set_number('5700027')->is_valid_number, '大阪府守口市桜町');
ok($zip->set_number('5700028')->is_valid_number, '大阪府守口市本町');
ok($zip->set_number('5700029')->is_valid_number, '大阪府守口市来迎町');
ok($zip->set_number('5700031')->is_valid_number, '大阪府守口市橋波東之町');
ok($zip->set_number('5700032')->is_valid_number, '大阪府守口市菊水通');
ok($zip->set_number('5700033')->is_valid_number, '大阪府守口市大宮通');
ok($zip->set_number('5700034')->is_valid_number, '大阪府守口市西郷通');
ok($zip->set_number('5700035')->is_valid_number, '大阪府守口市東光町');
ok($zip->set_number('5700036')->is_valid_number, '大阪府守口市大枝東町');
ok($zip->set_number('5700037')->is_valid_number, '大阪府守口市大枝北町');
ok($zip->set_number('5700038')->is_valid_number, '大阪府守口市河原町');
ok($zip->set_number('5700039')->is_valid_number, '大阪府守口市橋波西之町');
ok($zip->set_number('5700041')->is_valid_number, '大阪府守口市東郷通');
ok($zip->set_number('5700042')->is_valid_number, '大阪府守口市寺方錦通');
ok($zip->set_number('5700043')->is_valid_number, '大阪府守口市高瀬旧大枝');
ok($zip->set_number('5700043')->is_valid_number, '大阪府守口市高瀬旧世木');
ok($zip->set_number('5700043')->is_valid_number, '大阪府守口市高瀬旧馬場');
ok($zip->set_number('5700043')->is_valid_number, '大阪府守口市南寺方東通');
ok($zip->set_number('5700044')->is_valid_number, '大阪府守口市南寺方南通');
ok($zip->set_number('5700045')->is_valid_number, '大阪府守口市南寺方中通');
ok($zip->set_number('5700046')->is_valid_number, '大阪府守口市南寺方北通');
ok($zip->set_number('5700047')->is_valid_number, '大阪府守口市寺方元町');
ok($zip->set_number('5700048')->is_valid_number, '大阪府守口市寺方本通');
ok($zip->set_number('5700051')->is_valid_number, '大阪府守口市大枝南町');
ok($zip->set_number('5700052')->is_valid_number, '大阪府守口市松下町');
ok($zip->set_number('5700053')->is_valid_number, '大阪府守口市高瀬町');
ok($zip->set_number('5700054')->is_valid_number, '大阪府守口市大枝西町');
ok($zip->set_number('5700055')->is_valid_number, '大阪府守口市春日町');
ok($zip->set_number('5700056')->is_valid_number, '大阪府守口市寺内町');
ok($zip->set_number('5700061')->is_valid_number, '大阪府守口市小春町');
ok($zip->set_number('5700062')->is_valid_number, '大阪府守口市馬場町');
ok($zip->set_number('5700063')->is_valid_number, '大阪府守口市大門町');
ok($zip->set_number('5700064')->is_valid_number, '大阪府守口市長池町');
ok($zip->set_number('5700065')->is_valid_number, '大阪府守口市滝井元町');
ok($zip->set_number('5700066')->is_valid_number, '大阪府守口市梅園町');
ok($zip->set_number('5700071')->is_valid_number, '大阪府守口市祝町');
ok($zip->set_number('5700072')->is_valid_number, '大阪府守口市早苗町');
ok($zip->set_number('5700073')->is_valid_number, '大阪府守口市土居町');
ok($zip->set_number('5700074')->is_valid_number, '大阪府守口市文園町');
ok($zip->set_number('5700075')->is_valid_number, '大阪府守口市紅屋町');
ok($zip->set_number('5700076')->is_valid_number, '大阪府守口市滝井西町');
ok($zip->set_number('5700077')->is_valid_number, '大阪府守口市寿町');
ok($zip->set_number('5700078')->is_valid_number, '大阪府守口市平代町');
ok($zip->set_number('5700079')->is_valid_number, '大阪府守口市金下町');
ok($zip->set_number('5700081')->is_valid_number, '大阪府守口市日吉町');
ok($zip->set_number('5700082')->is_valid_number, '大阪府守口市豊秀町');
ok($zip->set_number('5700083')->is_valid_number, '大阪府守口市京阪本通');
ok($zip->set_number('5700084')->is_valid_number, '大阪府守口市緑町');
ok($zip->set_number('5700085')->is_valid_number, '大阪府守口市松町');
ok($zip->set_number('5700086')->is_valid_number, '大阪府守口市竹町');
ok($zip->set_number('5700087')->is_valid_number, '大阪府守口市梅町');
ok($zip->set_number('5700091')->is_valid_number, '大阪府守口市北斗町');
ok($zip->set_number('5700092')->is_valid_number, '大阪府守口市日光町');
ok($zip->set_number('5700093')->is_valid_number, '大阪府守口市浜町');
ok($zip->set_number('5700094')->is_valid_number, '大阪府守口市京阪北本通');
ok($zip->set_number('5700095')->is_valid_number, '大阪府守口市八島町');
ok($zip->set_number('5700096')->is_valid_number, '大阪府守口市外島町');
ok($zip->set_number('5700097')->is_valid_number, '大阪府守口市桃町');
ok($zip->set_number('5700098')->is_valid_number, '大阪府守口市新橋寺町');
ok($zip->set_number('5710000')->is_valid_number, '大阪府門真市以下に掲載がない場合');
ok($zip->set_number('5710001')->is_valid_number, '大阪府門真市巣本町');
ok($zip->set_number('5710002')->is_valid_number, '大阪府門真市岸和田');
ok($zip->set_number('5710005')->is_valid_number, '大阪府門真市南野口町');
ok($zip->set_number('5710007')->is_valid_number, '大阪府門真市北岸和田');
ok($zip->set_number('5710008')->is_valid_number, '大阪府門真市東江端町');
ok($zip->set_number('5710009')->is_valid_number, '大阪府門真市下馬伏町');
ok($zip->set_number('5710011')->is_valid_number, '大阪府門真市脇田町');
ok($zip->set_number('5710012')->is_valid_number, '大阪府門真市江端町');
ok($zip->set_number('5710013')->is_valid_number, '大阪府門真市千石東町');
ok($zip->set_number('5710014')->is_valid_number, '大阪府門真市千石西町');
ok($zip->set_number('5710015')->is_valid_number, '大阪府門真市三ツ島');
ok($zip->set_number('5710016')->is_valid_number, '大阪府門真市島頭');
ok($zip->set_number('5710017')->is_valid_number, '大阪府門真市四宮');
ok($zip->set_number('5710018')->is_valid_number, '大阪府門真市北島東町');
ok($zip->set_number('5710021')->is_valid_number, '大阪府門真市舟田町');
ok($zip->set_number('5710022')->is_valid_number, '大阪府門真市沖町');
ok($zip->set_number('5710023')->is_valid_number, '大阪府門真市横地');
ok($zip->set_number('5710024')->is_valid_number, '大阪府門真市野口');
ok($zip->set_number('5710025')->is_valid_number, '大阪府門真市北島');
ok($zip->set_number('5710026')->is_valid_number, '大阪府門真市北島町');
ok($zip->set_number('5710027')->is_valid_number, '大阪府門真市五月田町');
ok($zip->set_number('5710028')->is_valid_number, '大阪府門真市打越');
ok($zip->set_number('5710029')->is_valid_number, '大阪府門真市打越町');
ok($zip->set_number('5710030')->is_valid_number, '大阪府門真市末広町');
ok($zip->set_number('5710031')->is_valid_number, '大阪府門真市古川町');
ok($zip->set_number('5710032')->is_valid_number, '大阪府門真市寿町');
ok($zip->set_number('5710033')->is_valid_number, '大阪府門真市一番町');
ok($zip->set_number('5710034')->is_valid_number, '大阪府門真市東田町');
ok($zip->set_number('5710035')->is_valid_number, '大阪府門真市桑才町');
ok($zip->set_number('5710037')->is_valid_number, '大阪府門真市ひえ島町');
ok($zip->set_number('5710038')->is_valid_number, '大阪府門真市柳田町');
ok($zip->set_number('5710039')->is_valid_number, '大阪府門真市速見町');
ok($zip->set_number('5710041')->is_valid_number, '大阪府門真市柳町');
ok($zip->set_number('5710042')->is_valid_number, '大阪府門真市深田町');
ok($zip->set_number('5710043')->is_valid_number, '大阪府門真市桑才新町');
ok($zip->set_number('5710044')->is_valid_number, '大阪府門真市松生町');
ok($zip->set_number('5710045')->is_valid_number, '大阪府門真市殿島町');
ok($zip->set_number('5710046')->is_valid_number, '大阪府門真市本町');
ok($zip->set_number('5710047')->is_valid_number, '大阪府門真市栄町');
ok($zip->set_number('5710048')->is_valid_number, '大阪府門真市新橋町');
ok($zip->set_number('5710050')->is_valid_number, '大阪府門真市門真');
ok($zip->set_number('5710051')->is_valid_number, '大阪府門真市向島町');
ok($zip->set_number('5710052')->is_valid_number, '大阪府門真市月出町');
ok($zip->set_number('5710053')->is_valid_number, '大阪府門真市泉町');
ok($zip->set_number('5710054')->is_valid_number, '大阪府門真市浜町');
ok($zip->set_number('5710055')->is_valid_number, '大阪府門真市中町');
ok($zip->set_number('5710056')->is_valid_number, '大阪府門真市松葉町');
ok($zip->set_number('5710057')->is_valid_number, '大阪府門真市元町');
ok($zip->set_number('5710058')->is_valid_number, '大阪府門真市小路町');
ok($zip->set_number('5710059')->is_valid_number, '大阪府門真市堂山町');
ok($zip->set_number('5710061')->is_valid_number, '大阪府門真市朝日町');
ok($zip->set_number('5710062')->is_valid_number, '大阪府門真市宮野町');
ok($zip->set_number('5710063')->is_valid_number, '大阪府門真市常称寺町');
ok($zip->set_number('5710064')->is_valid_number, '大阪府門真市御堂町');
ok($zip->set_number('5710065')->is_valid_number, '大阪府門真市垣内町');
ok($zip->set_number('5710066')->is_valid_number, '大阪府門真市幸福町');
ok($zip->set_number('5710067')->is_valid_number, '大阪府門真市石原町');
ok($zip->set_number('5710068')->is_valid_number, '大阪府門真市大倉町');
ok($zip->set_number('5710070')->is_valid_number, '大阪府門真市上野口町');
ok($zip->set_number('5710071')->is_valid_number, '大阪府門真市上島町');
ok($zip->set_number('5710072')->is_valid_number, '大阪府門真市城垣町');
ok($zip->set_number('5710073')->is_valid_number, '大阪府門真市北巣本町');
ok($zip->set_number('5710074')->is_valid_number, '大阪府門真市宮前町');
ok($zip->set_number('5710075')->is_valid_number, '大阪府門真市下島町');
ok($zip->set_number('5710076')->is_valid_number, '大阪府門真市大池町');
ok($zip->set_number('5710077')->is_valid_number, '大阪府門真市大橋町');
ok($zip->set_number('5710078')->is_valid_number, '大阪府門真市常盤町');
ok($zip->set_number('5710079')->is_valid_number, '大阪府門真市野里町');
ok($zip->set_number('5720000')->is_valid_number, '大阪府寝屋川市以下に掲載がない場合');
ok($zip->set_number('5720001')->is_valid_number, '大阪府寝屋川市成田東町');
ok($zip->set_number('5720002')->is_valid_number, '大阪府寝屋川市成田東が丘');
ok($zip->set_number('5720003')->is_valid_number, '大阪府寝屋川市成田南町');
ok($zip->set_number('5720004')->is_valid_number, '大阪府寝屋川市成田町');
ok($zip->set_number('5720005')->is_valid_number, '大阪府寝屋川市成田西町');
ok($zip->set_number('5720006')->is_valid_number, '大阪府寝屋川市美井元町');
ok($zip->set_number('5720007')->is_valid_number, '大阪府寝屋川市美井町');
ok($zip->set_number('5720008')->is_valid_number, '大阪府寝屋川市菅相塚町');
ok($zip->set_number('5720009')->is_valid_number, '大阪府寝屋川市末広町');
ok($zip->set_number('5720011')->is_valid_number, '大阪府寝屋川市明徳');
ok($zip->set_number('5720012')->is_valid_number, '大阪府寝屋川市池の瀬町');
ok($zip->set_number('5720013')->is_valid_number, '大阪府寝屋川市三井が丘');
ok($zip->set_number('5720014')->is_valid_number, '大阪府寝屋川市八幡台');
ok($zip->set_number('5720015')->is_valid_number, '大阪府寝屋川市川勝町');
ok($zip->set_number('5720016')->is_valid_number, '大阪府寝屋川市国松町');
ok($zip->set_number('5720017')->is_valid_number, '大阪府寝屋川市幸町');
ok($zip->set_number('5720018')->is_valid_number, '大阪府寝屋川市境橋町');
ok($zip->set_number('5720019')->is_valid_number, '大阪府寝屋川市三井南町');
ok($zip->set_number('5720020')->is_valid_number, '大阪府寝屋川市田井西町');
ok($zip->set_number('5720021')->is_valid_number, '大阪府寝屋川市田井町');
ok($zip->set_number('5720022')->is_valid_number, '大阪府寝屋川市緑町');
ok($zip->set_number('5720023')->is_valid_number, '大阪府寝屋川市音羽町');
ok($zip->set_number('5720024')->is_valid_number, '大阪府寝屋川市石津南町');
ok($zip->set_number('5720025')->is_valid_number, '大阪府寝屋川市石津元町');
ok($zip->set_number('5720026')->is_valid_number, '大阪府寝屋川市石津中町');
ok($zip->set_number('5720027')->is_valid_number, '大阪府寝屋川市石津東町');
ok($zip->set_number('5720028')->is_valid_number, '大阪府寝屋川市日新町');
ok($zip->set_number('5720029')->is_valid_number, '大阪府寝屋川市寿町');
ok($zip->set_number('5720030')->is_valid_number, '大阪府寝屋川市池田本町');
ok($zip->set_number('5720031')->is_valid_number, '大阪府寝屋川市若葉町');
ok($zip->set_number('5720032')->is_valid_number, '大阪府寝屋川市北大利町');
ok($zip->set_number('5720033')->is_valid_number, '大阪府寝屋川市池田東町');
ok($zip->set_number('5720034')->is_valid_number, '大阪府寝屋川市池田南町');
ok($zip->set_number('5720035')->is_valid_number, '大阪府寝屋川市池田旭町');
ok($zip->set_number('5720036')->is_valid_number, '大阪府寝屋川市池田西町');
ok($zip->set_number('5720037')->is_valid_number, '大阪府寝屋川市葛原新町');
ok($zip->set_number('5720038')->is_valid_number, '大阪府寝屋川市池田新町');
ok($zip->set_number('5720039')->is_valid_number, '大阪府寝屋川市池田');
ok($zip->set_number('5720041')->is_valid_number, '大阪府寝屋川市桜木町');
ok($zip->set_number('5720042')->is_valid_number, '大阪府寝屋川市東大利町');
ok($zip->set_number('5720043')->is_valid_number, '大阪府寝屋川市錦町');
ok($zip->set_number('5720044')->is_valid_number, '大阪府寝屋川市清水町');
ok($zip->set_number('5720045')->is_valid_number, '大阪府寝屋川市東神田町');
ok($zip->set_number('5720046')->is_valid_number, '大阪府寝屋川市成美町');
ok($zip->set_number('5720047')->is_valid_number, '大阪府寝屋川市大利元町');
ok($zip->set_number('5720048')->is_valid_number, '大阪府寝屋川市大利町');
ok($zip->set_number('5720050')->is_valid_number, '大阪府寝屋川市黒原城内町');
ok($zip->set_number('5720051')->is_valid_number, '大阪府寝屋川市高柳');
ok($zip->set_number('5720052')->is_valid_number, '大阪府寝屋川市上神田');
ok($zip->set_number('5720053')->is_valid_number, '大阪府寝屋川市中神田町');
ok($zip->set_number('5720054')->is_valid_number, '大阪府寝屋川市下神田町');
ok($zip->set_number('5720055')->is_valid_number, '大阪府寝屋川市御幸東町');
ok($zip->set_number('5720056')->is_valid_number, '大阪府寝屋川市御幸西町');
ok($zip->set_number('5720057')->is_valid_number, '大阪府寝屋川市黒原旭町');
ok($zip->set_number('5720058')->is_valid_number, '大阪府寝屋川市黒原橘町');
ok($zip->set_number('5720059')->is_valid_number, '大阪府寝屋川市黒原新町');
ok($zip->set_number('5720061')->is_valid_number, '大阪府寝屋川市長栄寺町');
ok($zip->set_number('5720062')->is_valid_number, '大阪府寝屋川市高柳栄町');
ok($zip->set_number('5720063')->is_valid_number, '大阪府寝屋川市春日町');
ok($zip->set_number('5720064')->is_valid_number, '大阪府寝屋川市対馬江東町');
ok($zip->set_number('5720065')->is_valid_number, '大阪府寝屋川市対馬江西町');
ok($zip->set_number('5720066')->is_valid_number, '大阪府寝屋川市仁和寺町');
ok($zip->set_number('5720067')->is_valid_number, '大阪府寝屋川市宝町');
ok($zip->set_number('5720071')->is_valid_number, '大阪府寝屋川市豊里町');
ok($zip->set_number('5720072')->is_valid_number, '大阪府寝屋川市太間東町');
ok($zip->set_number('5720073')->is_valid_number, '大阪府寝屋川市池田北町');
ok($zip->set_number('5720074')->is_valid_number, '大阪府寝屋川市池田中町');
ok($zip->set_number('5720075')->is_valid_number, '大阪府寝屋川市葛原');
ok($zip->set_number('5720076')->is_valid_number, '大阪府寝屋川市仁和寺本町');
ok($zip->set_number('5720077')->is_valid_number, '大阪府寝屋川市点野');
ok($zip->set_number('5720078')->is_valid_number, '大阪府寝屋川市太間町');
ok($zip->set_number('5720080')->is_valid_number, '大阪府寝屋川市香里北之町');
ok($zip->set_number('5720081')->is_valid_number, '大阪府寝屋川市東香里園町');
ok($zip->set_number('5720082')->is_valid_number, '大阪府寝屋川市香里本通町');
ok($zip->set_number('5720083')->is_valid_number, '大阪府寝屋川市郡元町');
ok($zip->set_number('5720084')->is_valid_number, '大阪府寝屋川市香里南之町');
ok($zip->set_number('5720085')->is_valid_number, '大阪府寝屋川市香里新町');
ok($zip->set_number('5720086')->is_valid_number, '大阪府寝屋川市松屋町');
ok($zip->set_number('5720087')->is_valid_number, '大阪府寝屋川市木屋町');
ok($zip->set_number('5720088')->is_valid_number, '大阪府寝屋川市木屋元町');
ok($zip->set_number('5720089')->is_valid_number, '大阪府寝屋川市香里西之町');
ok($zip->set_number('5720801')->is_valid_number, '大阪府寝屋川市寝屋');
ok($zip->set_number('5720803')->is_valid_number, '大阪府寝屋川市梅が丘');
ok($zip->set_number('5720806')->is_valid_number, '大阪府寝屋川市高宮');
ok($zip->set_number('5720810')->is_valid_number, '大阪府寝屋川市堀溝北町');
ok($zip->set_number('5720811')->is_valid_number, '大阪府寝屋川市楠根南町');
ok($zip->set_number('5720812')->is_valid_number, '大阪府寝屋川市新家');
ok($zip->set_number('5720813')->is_valid_number, '大阪府寝屋川市讃良東町');
ok($zip->set_number('5720814')->is_valid_number, '大阪府寝屋川市堀溝');
ok($zip->set_number('5720815')->is_valid_number, '大阪府寝屋川市河北東町');
ok($zip->set_number('5720816')->is_valid_number, '大阪府寝屋川市河北中町');
ok($zip->set_number('5720817')->is_valid_number, '大阪府寝屋川市河北西町');
ok($zip->set_number('5720818')->is_valid_number, '大阪府寝屋川市讃良西町');
ok($zip->set_number('5720819')->is_valid_number, '大阪府寝屋川市大成町');
ok($zip->set_number('5720820')->is_valid_number, '大阪府寝屋川市中木田町');
ok($zip->set_number('5720821')->is_valid_number, '大阪府寝屋川市出雲町');
ok($zip->set_number('5720822')->is_valid_number, '大阪府寝屋川市木田元宮');
ok($zip->set_number('5720823')->is_valid_number, '大阪府寝屋川市下木田町');
ok($zip->set_number('5720824')->is_valid_number, '大阪府寝屋川市萱島東');
ok($zip->set_number('5720825')->is_valid_number, '大阪府寝屋川市萱島南町');
ok($zip->set_number('5720826')->is_valid_number, '大阪府寝屋川市南水苑町');
ok($zip->set_number('5720827')->is_valid_number, '大阪府寝屋川市萱島本町');
ok($zip->set_number('5720828')->is_valid_number, '大阪府寝屋川市萱島桜園町');
ok($zip->set_number('5720829')->is_valid_number, '大阪府寝屋川市萱島信和町');
ok($zip->set_number('5720831')->is_valid_number, '大阪府寝屋川市豊野町');
ok($zip->set_number('5720832')->is_valid_number, '大阪府寝屋川市本町');
ok($zip->set_number('5720833')->is_valid_number, '大阪府寝屋川市初町');
ok($zip->set_number('5720834')->is_valid_number, '大阪府寝屋川市昭栄町');
ok($zip->set_number('5720835')->is_valid_number, '大阪府寝屋川市日之出町');
ok($zip->set_number('5720836')->is_valid_number, '大阪府寝屋川市木田町');
ok($zip->set_number('5720837')->is_valid_number, '大阪府寝屋川市早子町');
ok($zip->set_number('5720838')->is_valid_number, '大阪府寝屋川市八坂町');
ok($zip->set_number('5720839')->is_valid_number, '大阪府寝屋川市平池町');
ok($zip->set_number('5720840')->is_valid_number, '大阪府寝屋川市太秦桜が丘');
ok($zip->set_number('5720841')->is_valid_number, '大阪府寝屋川市太秦東が丘');
ok($zip->set_number('5720842')->is_valid_number, '大阪府寝屋川市太秦高塚町');
ok($zip->set_number('5720843')->is_valid_number, '大阪府寝屋川市太秦中町');
ok($zip->set_number('5720844')->is_valid_number, '大阪府寝屋川市太秦緑が丘');
ok($zip->set_number('5720845')->is_valid_number, '大阪府寝屋川市楠根北町');
ok($zip->set_number('5720846')->is_valid_number, '大阪府寝屋川市高宮栄町');
ok($zip->set_number('5720847')->is_valid_number, '大阪府寝屋川市高宮新町');
ok($zip->set_number('5720848')->is_valid_number, '大阪府寝屋川市秦町');
ok($zip->set_number('5720849')->is_valid_number, '大阪府寝屋川市太秦元町');
ok($zip->set_number('5720850')->is_valid_number, '大阪府寝屋川市打上高塚町');
ok($zip->set_number('5720851')->is_valid_number, '大阪府寝屋川市寝屋北町');
ok($zip->set_number('5720852')->is_valid_number, '大阪府寝屋川市寝屋新町');
ok($zip->set_number('5720853')->is_valid_number, '大阪府寝屋川市大谷町');
ok($zip->set_number('5720854')->is_valid_number, '大阪府寝屋川市寝屋川公園');
ok($zip->set_number('5720855')->is_valid_number, '大阪府寝屋川市寝屋南');
ok($zip->set_number('5720856')->is_valid_number, '大阪府寝屋川市宇谷町');
ok($zip->set_number('5720857')->is_valid_number, '大阪府寝屋川市打上中町');
ok($zip->set_number('5720858')->is_valid_number, '大阪府寝屋川市打上元町');
ok($zip->set_number('5720859')->is_valid_number, '大阪府寝屋川市打上新町');
ok($zip->set_number('5720861')->is_valid_number, '大阪府寝屋川市打上南町');
ok($zip->set_number('5720862')->is_valid_number, '大阪府寝屋川市打上宮前町');
ok($zip->set_number('5720863')->is_valid_number, '大阪府寝屋川市明和');
ok($zip->set_number('5720864')->is_valid_number, '大阪府寝屋川市高倉');
ok($zip->set_number('5720865')->is_valid_number, '大阪府寝屋川市小路北町');
ok($zip->set_number('5720866')->is_valid_number, '大阪府寝屋川市小路南町');
ok($zip->set_number('5720867')->is_valid_number, '大阪府寝屋川市高宮あさひ丘');
ok($zip->set_number('5730000')->is_valid_number, '大阪府枚方市以下に掲載がない場合');
ok($zip->set_number('5730001')->is_valid_number, '大阪府枚方市田口山');
ok($zip->set_number('5730002')->is_valid_number, '大阪府枚方市出屋敷元町');
ok($zip->set_number('5730003')->is_valid_number, '大阪府枚方市出屋敷西町');
ok($zip->set_number('5730004')->is_valid_number, '大阪府枚方市中宮大池');
ok($zip->set_number('5730005')->is_valid_number, '大阪府枚方市池之宮');
ok($zip->set_number('5730006')->is_valid_number, '大阪府枚方市堂山東町');
ok($zip->set_number('5730007')->is_valid_number, '大阪府枚方市堂山');
ok($zip->set_number('5730011')->is_valid_number, '大阪府枚方市中宮山戸町');
ok($zip->set_number('5730012')->is_valid_number, '大阪府枚方市松丘町');
ok($zip->set_number('5730013')->is_valid_number, '大阪府枚方市星丘');
ok($zip->set_number('5730014')->is_valid_number, '大阪府枚方市村野高見台');
ok($zip->set_number('5730015')->is_valid_number, '大阪府枚方市村野東町');
ok($zip->set_number('5730016')->is_valid_number, '大阪府枚方市村野本町');
ok($zip->set_number('5730017')->is_valid_number, '大阪府枚方市印田町');
ok($zip->set_number('5730018')->is_valid_number, '大阪府枚方市桜丘町');
ok($zip->set_number('5730021')->is_valid_number, '大阪府枚方市中宮西之町');
ok($zip->set_number('5730022')->is_valid_number, '大阪府枚方市宮之阪');
ok($zip->set_number('5730023')->is_valid_number, '大阪府枚方市東田宮');
ok($zip->set_number('5730024')->is_valid_number, '大阪府枚方市田宮本町');
ok($zip->set_number('5730025')->is_valid_number, '大阪府枚方市西田宮町');
ok($zip->set_number('5730026')->is_valid_number, '大阪府枚方市朝日丘町');
ok($zip->set_number('5730027')->is_valid_number, '大阪府枚方市大垣内町');
ok($zip->set_number('5730028')->is_valid_number, '大阪府枚方市川原町');
ok($zip->set_number('5730031')->is_valid_number, '大阪府枚方市岡本町');
ok($zip->set_number('5730032')->is_valid_number, '大阪府枚方市岡東町');
ok($zip->set_number('5730033')->is_valid_number, '大阪府枚方市岡南町');
ok($zip->set_number('5730034')->is_valid_number, '大阪府枚方市岡山手町');
ok($zip->set_number('5730035')->is_valid_number, '大阪府枚方市高塚町');
ok($zip->set_number('5730036')->is_valid_number, '大阪府枚方市伊加賀北町');
ok($zip->set_number('5730037')->is_valid_number, '大阪府枚方市枚方上之町');
ok($zip->set_number('5730041')->is_valid_number, '大阪府枚方市山之上東町');
ok($zip->set_number('5730042')->is_valid_number, '大阪府枚方市村野西町');
ok($zip->set_number('5730043')->is_valid_number, '大阪府枚方市村野南町');
ok($zip->set_number('5730044')->is_valid_number, '大阪府枚方市東藤田町');
ok($zip->set_number('5730045')->is_valid_number, '大阪府枚方市藤田町');
ok($zip->set_number('5730046')->is_valid_number, '大阪府枚方市宮之下町');
ok($zip->set_number('5730047')->is_valid_number, '大阪府枚方市山之上');
ok($zip->set_number('5730048')->is_valid_number, '大阪府枚方市山之上西町');
ok($zip->set_number('5730049')->is_valid_number, '大阪府枚方市山之上北町');
ok($zip->set_number('5730051')->is_valid_number, '大阪府枚方市三矢町');
ok($zip->set_number('5730052')->is_valid_number, '大阪府枚方市枚方元町');
ok($zip->set_number('5730053')->is_valid_number, '大阪府枚方市伊加賀南町');
ok($zip->set_number('5730054')->is_valid_number, '大阪府枚方市枚方公園町');
ok($zip->set_number('5730055')->is_valid_number, '大阪府枚方市伊加賀本町');
ok($zip->set_number('5730056')->is_valid_number, '大阪府枚方市桜町');
ok($zip->set_number('5730057')->is_valid_number, '大阪府枚方市堤町');
ok($zip->set_number('5730058')->is_valid_number, '大阪府枚方市伊加賀東町');
ok($zip->set_number('5730061')->is_valid_number, '大阪府枚方市伊加賀寿町');
ok($zip->set_number('5730062')->is_valid_number, '大阪府枚方市伊加賀栄町');
ok($zip->set_number('5730063')->is_valid_number, '大阪府枚方市走谷');
ok($zip->set_number('5730064')->is_valid_number, '大阪府枚方市北中振');
ok($zip->set_number('5730065')->is_valid_number, '大阪府枚方市出口');
ok($zip->set_number('5730066')->is_valid_number, '大阪府枚方市伊加賀西町');
ok($zip->set_number('5730067')->is_valid_number, '大阪府枚方市伊加賀緑町');
ok($zip->set_number('5730071')->is_valid_number, '大阪府枚方市茄子作');
ok($zip->set_number('5730072')->is_valid_number, '大阪府枚方市茄子作南町');
ok($zip->set_number('5730073')->is_valid_number, '大阪府枚方市高田');
ok($zip->set_number('5730074')->is_valid_number, '大阪府枚方市東香里南町');
ok($zip->set_number('5730075')->is_valid_number, '大阪府枚方市東香里');
ok($zip->set_number('5730076')->is_valid_number, '大阪府枚方市東香里元町');
ok($zip->set_number('5730077')->is_valid_number, '大阪府枚方市東香里新町');
ok($zip->set_number('5730081')->is_valid_number, '大阪府枚方市釈尊寺町');
ok($zip->set_number('5730082')->is_valid_number, '大阪府枚方市茄子作東町');
ok($zip->set_number('5730083')->is_valid_number, '大阪府枚方市茄子作北町');
ok($zip->set_number('5730084')->is_valid_number, '大阪府枚方市香里ケ丘');
ok($zip->set_number('5730085')->is_valid_number, '大阪府枚方市香里園東之町');
ok($zip->set_number('5730086')->is_valid_number, '大阪府枚方市香里園町');
ok($zip->set_number('5730087')->is_valid_number, '大阪府枚方市香里園山之手町');
ok($zip->set_number('5730088')->is_valid_number, '大阪府枚方市香里園桜木町');
ok($zip->set_number('5730091')->is_valid_number, '大阪府枚方市菊丘町');
ok($zip->set_number('5730092')->is_valid_number, '大阪府枚方市菊丘南町');
ok($zip->set_number('5730093')->is_valid_number, '大阪府枚方市東中振');
ok($zip->set_number('5730094')->is_valid_number, '大阪府枚方市南中振');
ok($zip->set_number('5730095')->is_valid_number, '大阪府枚方市翠香園町');
ok($zip->set_number('5730101')->is_valid_number, '大阪府枚方市長尾峠町');
ok($zip->set_number('5730102')->is_valid_number, '大阪府枚方市長尾家具町');
ok($zip->set_number('5730103')->is_valid_number, '大阪府枚方市長尾荒阪');
ok($zip->set_number('5730104')->is_valid_number, '大阪府枚方市長尾播磨谷');
ok($zip->set_number('5730105')->is_valid_number, '大阪府枚方市長尾東町');
ok($zip->set_number('5730106')->is_valid_number, '大阪府枚方市長尾台');
ok($zip->set_number('5730107')->is_valid_number, '大阪府枚方市長尾宮前');
ok($zip->set_number('5730111')->is_valid_number, '大阪府枚方市杉北町');
ok($zip->set_number('5730112')->is_valid_number, '大阪府枚方市尊延寺');
ok($zip->set_number('5730113')->is_valid_number, '大阪府枚方市宗谷');
ok($zip->set_number('5730114')->is_valid_number, '大阪府枚方市穂谷');
ok($zip->set_number('5730115')->is_valid_number, '大阪府枚方市氷室台');
ok($zip->set_number('5730116')->is_valid_number, '大阪府枚方市杉責谷');
ok($zip->set_number('5730117')->is_valid_number, '大阪府枚方市杉');
ok($zip->set_number('5730118')->is_valid_number, '大阪府枚方市杉山手');
ok($zip->set_number('5730121')->is_valid_number, '大阪府枚方市津田北町');
ok($zip->set_number('5730122')->is_valid_number, '大阪府枚方市津田東町');
ok($zip->set_number('5730123')->is_valid_number, '大阪府枚方市津田');
ok($zip->set_number('5730124')->is_valid_number, '大阪府枚方市津田南町');
ok($zip->set_number('5730125')->is_valid_number, '大阪府枚方市津田駅前');
ok($zip->set_number('5730126')->is_valid_number, '大阪府枚方市津田西町');
ok($zip->set_number('5730127')->is_valid_number, '大阪府枚方市津田元町');
ok($zip->set_number('5730128')->is_valid_number, '大阪府枚方市津田山手');
ok($zip->set_number('5730131')->is_valid_number, '大阪府枚方市春日野');
ok($zip->set_number('5730132')->is_valid_number, '大阪府枚方市野村元町');
ok($zip->set_number('5730133')->is_valid_number, '大阪府枚方市野村南町');
ok($zip->set_number('5730134')->is_valid_number, '大阪府枚方市春日東町');
ok($zip->set_number('5730135')->is_valid_number, '大阪府枚方市春日元町');
ok($zip->set_number('5730136')->is_valid_number, '大阪府枚方市春日西町');
ok($zip->set_number('5730137')->is_valid_number, '大阪府枚方市春日北町');
ok($zip->set_number('5730141')->is_valid_number, '大阪府枚方市大峰北町');
ok($zip->set_number('5730142')->is_valid_number, '大阪府枚方市大峰東町');
ok($zip->set_number('5730143')->is_valid_number, '大阪府枚方市野村北町');
ok($zip->set_number('5730144')->is_valid_number, '大阪府枚方市野村中町');
ok($zip->set_number('5730145')->is_valid_number, '大阪府枚方市大峰南町');
ok($zip->set_number('5730146')->is_valid_number, '大阪府枚方市大峰元町');
ok($zip->set_number('5730151')->is_valid_number, '大阪府枚方市藤阪北町');
ok($zip->set_number('5730152')->is_valid_number, '大阪府枚方市藤阪中町');
ok($zip->set_number('5730153')->is_valid_number, '大阪府枚方市藤阪東町');
ok($zip->set_number('5730154')->is_valid_number, '大阪府枚方市王仁公園');
ok($zip->set_number('5730155')->is_valid_number, '大阪府枚方市藤阪天神町');
ok($zip->set_number('5730156')->is_valid_number, '大阪府枚方市藤阪南町');
ok($zip->set_number('5730157')->is_valid_number, '大阪府枚方市藤阪元町');
ok($zip->set_number('5730158')->is_valid_number, '大阪府枚方市藤阪西町');
ok($zip->set_number('5730161')->is_valid_number, '大阪府枚方市長尾北町');
ok($zip->set_number('5730162')->is_valid_number, '大阪府枚方市長尾西町');
ok($zip->set_number('5730163')->is_valid_number, '大阪府枚方市長尾元町');
ok($zip->set_number('5730164')->is_valid_number, '大阪府枚方市長尾谷町');
ok($zip->set_number('5730165')->is_valid_number, '大阪府枚方市山田池東町');
ok($zip->set_number('5730166')->is_valid_number, '大阪府枚方市山田池北町');
ok($zip->set_number('5730167')->is_valid_number, '大阪府枚方市山田池公園');
ok($zip->set_number('5730168')->is_valid_number, '大阪府枚方市山田池南町');
ok($zip->set_number('5730171')->is_valid_number, '大阪府枚方市北山');
ok($zip->set_number('5731101')->is_valid_number, '大阪府枚方市楠葉中之芝');
ok($zip->set_number('5731102')->is_valid_number, '大阪府枚方市北楠葉町');
ok($zip->set_number('5731103')->is_valid_number, '大阪府枚方市楠葉野田');
ok($zip->set_number('5731104')->is_valid_number, '大阪府枚方市楠葉丘');
ok($zip->set_number('5731105')->is_valid_number, '大阪府枚方市南楠葉');
ok($zip->set_number('5731106')->is_valid_number, '大阪府枚方市町楠葉');
ok($zip->set_number('5731107')->is_valid_number, '大阪府枚方市楠葉中町');
ok($zip->set_number('5731111')->is_valid_number, '大阪府枚方市楠葉朝日');
ok($zip->set_number('5731112')->is_valid_number, '大阪府枚方市楠葉美咲');
ok($zip->set_number('5731113')->is_valid_number, '大阪府枚方市楠葉面取町');
ok($zip->set_number('5731114')->is_valid_number, '大阪府枚方市東山');
ok($zip->set_number('5731115')->is_valid_number, '大阪府枚方市東船橋');
ok($zip->set_number('5731116')->is_valid_number, '大阪府枚方市船橋本町');
ok($zip->set_number('5731117')->is_valid_number, '大阪府枚方市北船橋町');
ok($zip->set_number('5731118')->is_valid_number, '大阪府枚方市楠葉並木');
ok($zip->set_number('5731121')->is_valid_number, '大阪府枚方市楠葉花園町');
ok($zip->set_number('5731122')->is_valid_number, '大阪府枚方市西船橋');
ok($zip->set_number('5731123')->is_valid_number, '大阪府枚方市南船橋');
ok($zip->set_number('5731124')->is_valid_number, '大阪府枚方市養父東町');
ok($zip->set_number('5731125')->is_valid_number, '大阪府枚方市養父元町');
ok($zip->set_number('5731126')->is_valid_number, '大阪府枚方市上島東町');
ok($zip->set_number('5731127')->is_valid_number, '大阪府枚方市上島町');
ok($zip->set_number('5731128')->is_valid_number, '大阪府枚方市樋之上町');
ok($zip->set_number('5731131')->is_valid_number, '大阪府枚方市高野道');
ok($zip->set_number('5731132')->is_valid_number, '大阪府枚方市招提田近');
ok($zip->set_number('5731133')->is_valid_number, '大阪府枚方市招提元町');
ok($zip->set_number('5731134')->is_valid_number, '大阪府枚方市養父丘');
ok($zip->set_number('5731135')->is_valid_number, '大阪府枚方市招提平野町');
ok($zip->set_number('5731136')->is_valid_number, '大阪府枚方市宇山東町');
ok($zip->set_number('5731137')->is_valid_number, '大阪府枚方市西招提町');
ok($zip->set_number('5731138')->is_valid_number, '大阪府枚方市招提北町');
ok($zip->set_number('5731141')->is_valid_number, '大阪府枚方市養父西町');
ok($zip->set_number('5731142')->is_valid_number, '大阪府枚方市牧野下島町');
ok($zip->set_number('5731143')->is_valid_number, '大阪府枚方市宇山町');
ok($zip->set_number('5731144')->is_valid_number, '大阪府枚方市牧野本町');
ok($zip->set_number('5731145')->is_valid_number, '大阪府枚方市黄金野');
ok($zip->set_number('5731146')->is_valid_number, '大阪府枚方市牧野阪');
ok($zip->set_number('5731147')->is_valid_number, '大阪府枚方市渚内野');
ok($zip->set_number('5731148')->is_valid_number, '大阪府枚方市西牧野');
ok($zip->set_number('5731149')->is_valid_number, '大阪府枚方市牧野北町');
ok($zip->set_number('5731151')->is_valid_number, '大阪府枚方市東牧野町');
ok($zip->set_number('5731152')->is_valid_number, '大阪府枚方市招提中町');
ok($zip->set_number('5731153')->is_valid_number, '大阪府枚方市招提大谷');
ok($zip->set_number('5731154')->is_valid_number, '大阪府枚方市招提東町');
ok($zip->set_number('5731155')->is_valid_number, '大阪府枚方市招提南町');
ok($zip->set_number('5731156')->is_valid_number, '大阪府枚方市片鉾東町');
ok($zip->set_number('5731157')->is_valid_number, '大阪府枚方市片鉾本町');
ok($zip->set_number('5731158')->is_valid_number, '大阪府枚方市北片鉾町');
ok($zip->set_number('5731159')->is_valid_number, '大阪府枚方市車塚');
ok($zip->set_number('5731161')->is_valid_number, '大阪府枚方市交北');
ok($zip->set_number('5731162')->is_valid_number, '大阪府枚方市田口');
ok($zip->set_number('5731163')->is_valid_number, '大阪府枚方市甲斐田新町');
ok($zip->set_number('5731164')->is_valid_number, '大阪府枚方市須山町');
ok($zip->set_number('5731165')->is_valid_number, '大阪府枚方市都丘町');
ok($zip->set_number('5731166')->is_valid_number, '大阪府枚方市新之栄町');
ok($zip->set_number('5731167')->is_valid_number, '大阪府枚方市甲斐田町');
ok($zip->set_number('5731168')->is_valid_number, '大阪府枚方市甲斐田東町');
ok($zip->set_number('5731171')->is_valid_number, '大阪府枚方市三栗');
ok($zip->set_number('5731172')->is_valid_number, '大阪府枚方市渚栄町');
ok($zip->set_number('5731173')->is_valid_number, '大阪府枚方市小倉町');
ok($zip->set_number('5731174')->is_valid_number, '大阪府枚方市小倉東町');
ok($zip->set_number('5731175')->is_valid_number, '大阪府枚方市上野');
ok($zip->set_number('5731176')->is_valid_number, '大阪府枚方市渚東町');
ok($zip->set_number('5731177')->is_valid_number, '大阪府枚方市渚元町');
ok($zip->set_number('5731178')->is_valid_number, '大阪府枚方市渚西');
ok($zip->set_number('5731181')->is_valid_number, '大阪府枚方市渚本町');
ok($zip->set_number('5731182')->is_valid_number, '大阪府枚方市御殿山町');
ok($zip->set_number('5731183')->is_valid_number, '大阪府枚方市渚南町');
ok($zip->set_number('5731184')->is_valid_number, '大阪府枚方市磯島茶屋町');
ok($zip->set_number('5731185')->is_valid_number, '大阪府枚方市天之川町');
ok($zip->set_number('5731186')->is_valid_number, '大阪府枚方市磯島南町');
ok($zip->set_number('5731187')->is_valid_number, '大阪府枚方市磯島元町');
ok($zip->set_number('5731188')->is_valid_number, '大阪府枚方市磯島北町');
ok($zip->set_number('5731191')->is_valid_number, '大阪府枚方市新町');
ok($zip->set_number('5731192')->is_valid_number, '大阪府枚方市西禁野');
ok($zip->set_number('5731193')->is_valid_number, '大阪府枚方市御殿山南町');
ok($zip->set_number('5731194')->is_valid_number, '大阪府枚方市中宮北町');
ok($zip->set_number('5731195')->is_valid_number, '大阪府枚方市中宮東之町');
ok($zip->set_number('5731196')->is_valid_number, '大阪府枚方市中宮本町');
ok($zip->set_number('5731197')->is_valid_number, '大阪府枚方市禁野本町');
ok($zip->set_number('5740000')->is_valid_number, '大阪府大東市以下に掲載がない場合');
ok($zip->set_number('5740001')->is_valid_number, '大阪府大東市学園町');
ok($zip->set_number('5740002')->is_valid_number, '大阪府大東市錦町');
ok($zip->set_number('5740003')->is_valid_number, '大阪府大東市明美の里町');
ok($zip->set_number('5740004')->is_valid_number, '大阪府大東市南楠の里町');
ok($zip->set_number('5740005')->is_valid_number, '大阪府大東市西楠の里町');
ok($zip->set_number('5740006')->is_valid_number, '大阪府大東市中楠の里町');
ok($zip->set_number('5740007')->is_valid_number, '大阪府大東市北楠の里町');
ok($zip->set_number('5740008')->is_valid_number, '大阪府大東市北新町');
ok($zip->set_number('5740011')->is_valid_number, '大阪府大東市北条');
ok($zip->set_number('5740012')->is_valid_number, '大阪府大東市龍間');
ok($zip->set_number('5740013')->is_valid_number, '大阪府大東市中垣内');
ok($zip->set_number('5740014')->is_valid_number, '大阪府大東市寺川');
ok($zip->set_number('5740015')->is_valid_number, '大阪府大東市野崎');
ok($zip->set_number('5740016')->is_valid_number, '大阪府大東市南津の辺町');
ok($zip->set_number('5740017')->is_valid_number, '大阪府大東市津の辺町');
ok($zip->set_number('5740021')->is_valid_number, '大阪府大東市平野屋新町');
ok($zip->set_number('5740022')->is_valid_number, '大阪府大東市平野屋');
ok($zip->set_number('5740023')->is_valid_number, '大阪府大東市南新田');
ok($zip->set_number('5740024')->is_valid_number, '大阪府大東市泉町');
ok($zip->set_number('5740025')->is_valid_number, '大阪府大東市御供田');
ok($zip->set_number('5740026')->is_valid_number, '大阪府大東市住道');
ok($zip->set_number('5740027')->is_valid_number, '大阪府大東市三住町');
ok($zip->set_number('5740028')->is_valid_number, '大阪府大東市幸町');
ok($zip->set_number('5740031')->is_valid_number, '大阪府大東市川中新町');
ok($zip->set_number('5740032')->is_valid_number, '大阪府大東市栄和町');
ok($zip->set_number('5740033')->is_valid_number, '大阪府大東市扇町');
ok($zip->set_number('5740034')->is_valid_number, '大阪府大東市朋来');
ok($zip->set_number('5740035')->is_valid_number, '大阪府大東市三洋町');
ok($zip->set_number('5740036')->is_valid_number, '大阪府大東市末広町');
ok($zip->set_number('5740037')->is_valid_number, '大阪府大東市新町');
ok($zip->set_number('5740041')->is_valid_number, '大阪府大東市浜町');
ok($zip->set_number('5740042')->is_valid_number, '大阪府大東市大野');
ok($zip->set_number('5740043')->is_valid_number, '大阪府大東市灰塚');
ok($zip->set_number('5740044')->is_valid_number, '大阪府大東市諸福');
ok($zip->set_number('5740045')->is_valid_number, '大阪府大東市太子田');
ok($zip->set_number('5740046')->is_valid_number, '大阪府大東市赤井');
ok($zip->set_number('5740051')->is_valid_number, '大阪府大東市新田境町');
ok($zip->set_number('5740052')->is_valid_number, '大阪府大東市新田北町');
ok($zip->set_number('5740053')->is_valid_number, '大阪府大東市新田旭町');
ok($zip->set_number('5740054')->is_valid_number, '大阪府大東市新田東本町');
ok($zip->set_number('5740055')->is_valid_number, '大阪府大東市新田本町');
ok($zip->set_number('5740056')->is_valid_number, '大阪府大東市新田中町');
ok($zip->set_number('5740057')->is_valid_number, '大阪府大東市新田西町');
ok($zip->set_number('5740061')->is_valid_number, '大阪府大東市大東町');
ok($zip->set_number('5740062')->is_valid_number, '大阪府大東市氷野');
ok($zip->set_number('5740063')->is_valid_number, '大阪府大東市南郷町');
ok($zip->set_number('5740064')->is_valid_number, '大阪府大東市御領');
ok($zip->set_number('5740071')->is_valid_number, '大阪府大東市深野北');
ok($zip->set_number('5740072')->is_valid_number, '大阪府大東市深野');
ok($zip->set_number('5740073')->is_valid_number, '大阪府大東市緑が丘');
ok($zip->set_number('5740074')->is_valid_number, '大阪府大東市谷川');
ok($zip->set_number('5740075')->is_valid_number, '大阪府大東市深野南町');
ok($zip->set_number('5740076')->is_valid_number, '大阪府大東市曙町');
ok($zip->set_number('5740077')->is_valid_number, '大阪府大東市三箇');
ok($zip->set_number('5750000')->is_valid_number, '大阪府四條畷市以下に掲載がない場合');
ok($zip->set_number('5750001')->is_valid_number, '大阪府四條畷市砂');
ok($zip->set_number('5750002')->is_valid_number, '大阪府四條畷市岡山(丁目)');
ok($zip->set_number('5750003')->is_valid_number, '大阪府四條畷市岡山東');
ok($zip->set_number('5750004')->is_valid_number, '大阪府四條畷市岡山(番地)');
ok($zip->set_number('5750011')->is_valid_number, '大阪府四條畷市逢阪');
ok($zip->set_number('5750012')->is_valid_number, '大阪府四條畷市下田原');
ok($zip->set_number('5750013')->is_valid_number, '大阪府四條畷市田原台');
ok($zip->set_number('5750014')->is_valid_number, '大阪府四條畷市上田原');
ok($zip->set_number('5750015')->is_valid_number, '大阪府四條畷市さつきケ丘');
ok($zip->set_number('5750016')->is_valid_number, '大阪府四條畷市緑風台');
ok($zip->set_number('5750021')->is_valid_number, '大阪府四條畷市南野(丁目)');
ok($zip->set_number('5750022')->is_valid_number, '大阪府四條畷市南野(番地)');
ok($zip->set_number('5750023')->is_valid_number, '大阪府四條畷市楠公');
ok($zip->set_number('5750024')->is_valid_number, '大阪府四條畷市塚脇町');
ok($zip->set_number('5750032')->is_valid_number, '大阪府四條畷市米崎町');
ok($zip->set_number('5750033')->is_valid_number, '大阪府四條畷市美田町');
ok($zip->set_number('5750034')->is_valid_number, '大阪府四條畷市江瀬美町');
ok($zip->set_number('5750035')->is_valid_number, '大阪府四條畷市雁屋北町');
ok($zip->set_number('5750036')->is_valid_number, '大阪府四條畷市雁屋南町');
ok($zip->set_number('5750041')->is_valid_number, '大阪府四條畷市蔀屋新町');
ok($zip->set_number('5750042')->is_valid_number, '大阪府四條畷市蔀屋本町');
ok($zip->set_number('5750043')->is_valid_number, '大阪府四條畷市北出町');
ok($zip->set_number('5750044')->is_valid_number, '大阪府四條畷市二丁通町');
ok($zip->set_number('5750045')->is_valid_number, '大阪府四條畷市雁屋西町');
ok($zip->set_number('5750051')->is_valid_number, '大阪府四條畷市中野本町');
ok($zip->set_number('5750052')->is_valid_number, '大阪府四條畷市中野(丁目)');
ok($zip->set_number('5750053')->is_valid_number, '大阪府四條畷市中野(番地)');
ok($zip->set_number('5750054')->is_valid_number, '大阪府四條畷市中野新町');
ok($zip->set_number('5750055')->is_valid_number, '大阪府四條畷市西中野');
ok($zip->set_number('5750061')->is_valid_number, '大阪府四條畷市清滝中町');
ok($zip->set_number('5750062')->is_valid_number, '大阪府四條畷市清滝新町');
ok($zip->set_number('5750063')->is_valid_number, '大阪府四條畷市清瀧');
ok($zip->set_number('5760000')->is_valid_number, '大阪府交野市以下に掲載がない場合');
ok($zip->set_number('5760001')->is_valid_number, '大阪府交野市倉治(番地)');
ok($zip->set_number('5760002')->is_valid_number, '大阪府交野市私部(番地)');
ok($zip->set_number('5760003')->is_valid_number, '大阪府交野市傍示');
ok($zip->set_number('5760004')->is_valid_number, '大阪府交野市私市(番地)');
ok($zip->set_number('5760005')->is_valid_number, '大阪府交野市森');
ok($zip->set_number('5760006')->is_valid_number, '大阪府交野市寺(番地)');
ok($zip->set_number('5760011')->is_valid_number, '大阪府交野市星田(番地)');
ok($zip->set_number('5760012')->is_valid_number, '大阪府交野市妙見東');
ok($zip->set_number('5760013')->is_valid_number, '大阪府交野市南星台');
ok($zip->set_number('5760014')->is_valid_number, '大阪府交野市星田山手');
ok($zip->set_number('5760015')->is_valid_number, '大阪府交野市星田西');
ok($zip->set_number('5760016')->is_valid_number, '大阪府交野市星田(丁目)');
ok($zip->set_number('5760017')->is_valid_number, '大阪府交野市星田北');
ok($zip->set_number('5760021')->is_valid_number, '大阪府交野市妙見坂');
ok($zip->set_number('5760022')->is_valid_number, '大阪府交野市藤が尾');
ok($zip->set_number('5760031')->is_valid_number, '大阪府交野市森南');
ok($zip->set_number('5760032')->is_valid_number, '大阪府交野市私市山手');
ok($zip->set_number('5760033')->is_valid_number, '大阪府交野市私市(丁目)');
ok($zip->set_number('5760034')->is_valid_number, '大阪府交野市天野が原町');
ok($zip->set_number('5760035')->is_valid_number, '大阪府交野市私部南');
ok($zip->set_number('5760036')->is_valid_number, '大阪府交野市森北');
ok($zip->set_number('5760041')->is_valid_number, '大阪府交野市私部西');
ok($zip->set_number('5760042')->is_valid_number, '大阪府交野市梅が枝');
ok($zip->set_number('5760043')->is_valid_number, '大阪府交野市松塚');
ok($zip->set_number('5760051')->is_valid_number, '大阪府交野市倉治(丁目)');
ok($zip->set_number('5760052')->is_valid_number, '大阪府交野市私部(丁目)');
ok($zip->set_number('5760053')->is_valid_number, '大阪府交野市郡津');
ok($zip->set_number('5760054')->is_valid_number, '大阪府交野市幾野');
ok($zip->set_number('5760061')->is_valid_number, '大阪府交野市東倉治');
ok($zip->set_number('5760062')->is_valid_number, '大阪府交野市神宮寺');
ok($zip->set_number('5760063')->is_valid_number, '大阪府交野市寺(丁目)');
ok($zip->set_number('5760064')->is_valid_number, '大阪府交野市寺南野');
ok($zip->set_number('5760065')->is_valid_number, '大阪府交野市向井田');
ok($zip->set_number('5760066')->is_valid_number, '大阪府交野市青山');
ok($zip->set_number('5770000')->is_valid_number, '大阪府東大阪市以下に掲載がない場合');
ok($zip->set_number('5770001')->is_valid_number, '大阪府東大阪市徳庵本町');
ok($zip->set_number('5770002')->is_valid_number, '大阪府東大阪市稲田上町');
ok($zip->set_number('5770003')->is_valid_number, '大阪府東大阪市稲田三島町');
ok($zip->set_number('5770004')->is_valid_number, '大阪府東大阪市稲田新町');
ok($zip->set_number('5770005')->is_valid_number, '大阪府東大阪市七軒家');
ok($zip->set_number('5770006')->is_valid_number, '大阪府東大阪市楠根');
ok($zip->set_number('5770007')->is_valid_number, '大阪府東大阪市稲田本町');
ok($zip->set_number('5770011')->is_valid_number, '大阪府東大阪市荒本北');
ok($zip->set_number('5770012')->is_valid_number, '大阪府東大阪市長田東');
ok($zip->set_number('5770013')->is_valid_number, '大阪府東大阪市長田中');
ok($zip->set_number('5770014')->is_valid_number, '大阪府東大阪市長田内介');
ok($zip->set_number('5770015')->is_valid_number, '大阪府東大阪市長田');
ok($zip->set_number('5770016')->is_valid_number, '大阪府東大阪市長田西');
ok($zip->set_number('5770017')->is_valid_number, '大阪府東大阪市藤戸新田');
ok($zip->set_number('5770022')->is_valid_number, '大阪府東大阪市荒本新町');
ok($zip->set_number('5770023')->is_valid_number, '大阪府東大阪市荒本');
ok($zip->set_number('5770024')->is_valid_number, '大阪府東大阪市荒本西');
ok($zip->set_number('5770025')->is_valid_number, '大阪府東大阪市新家');
ok($zip->set_number('5770026')->is_valid_number, '大阪府東大阪市新家東町');
ok($zip->set_number('5770027')->is_valid_number, '大阪府東大阪市新家中町');
ok($zip->set_number('5770028')->is_valid_number, '大阪府東大阪市新家西町');
ok($zip->set_number('5770032')->is_valid_number, '大阪府東大阪市御厨');
ok($zip->set_number('5770033')->is_valid_number, '大阪府東大阪市御厨東');
ok($zip->set_number('5770034')->is_valid_number, '大阪府東大阪市御厨南');
ok($zip->set_number('5770035')->is_valid_number, '大阪府東大阪市御厨中');
ok($zip->set_number('5770036')->is_valid_number, '大阪府東大阪市御厨栄町');
ok($zip->set_number('5770037')->is_valid_number, '大阪府東大阪市御厨西ノ町');
ok($zip->set_number('5770042')->is_valid_number, '大阪府東大阪市西堤');
ok($zip->set_number('5770044')->is_valid_number, '大阪府東大阪市西堤学園町');
ok($zip->set_number('5770045')->is_valid_number, '大阪府東大阪市西堤本通東');
ok($zip->set_number('5770046')->is_valid_number, '大阪府東大阪市西堤本通西');
ok($zip->set_number('5770047')->is_valid_number, '大阪府東大阪市西堤楠町');
ok($zip->set_number('5770048')->is_valid_number, '大阪府東大阪市西堤西');
ok($zip->set_number('5770052')->is_valid_number, '大阪府東大阪市新喜多');
ok($zip->set_number('5770053')->is_valid_number, '大阪府東大阪市高井田');
ok($zip->set_number('5770054')->is_valid_number, '大阪府東大阪市高井田元町');
ok($zip->set_number('5770055')->is_valid_number, '大阪府東大阪市長栄寺');
ok($zip->set_number('5770056')->is_valid_number, '大阪府東大阪市長堂');
ok($zip->set_number('5770057')->is_valid_number, '大阪府東大阪市足代新町');
ok($zip->set_number('5770058')->is_valid_number, '大阪府東大阪市足代北');
ok($zip->set_number('5770061')->is_valid_number, '大阪府東大阪市森河内西');
ok($zip->set_number('5770062')->is_valid_number, '大阪府東大阪市森河内東');
ok($zip->set_number('5770063')->is_valid_number, '大阪府東大阪市川俣');
ok($zip->set_number('5770064')->is_valid_number, '大阪府東大阪市川俣本町');
ok($zip->set_number('5770065')->is_valid_number, '大阪府東大阪市高井田中');
ok($zip->set_number('5770066')->is_valid_number, '大阪府東大阪市高井田本通');
ok($zip->set_number('5770067')->is_valid_number, '大阪府東大阪市高井田西');
ok($zip->set_number('5770801')->is_valid_number, '大阪府東大阪市小阪');
ok($zip->set_number('5770802')->is_valid_number, '大阪府東大阪市小阪本町');
ok($zip->set_number('5770803')->is_valid_number, '大阪府東大阪市下小阪');
ok($zip->set_number('5770804')->is_valid_number, '大阪府東大阪市中小阪');
ok($zip->set_number('5770805')->is_valid_number, '大阪府東大阪市宝持');
ok($zip->set_number('5770806')->is_valid_number, '大阪府東大阪市上小阪');
ok($zip->set_number('5770807')->is_valid_number, '大阪府東大阪市菱屋西');
ok($zip->set_number('5770808')->is_valid_number, '大阪府東大阪市横沼町');
ok($zip->set_number('5770809')->is_valid_number, '大阪府東大阪市永和');
ok($zip->set_number('5770811')->is_valid_number, '大阪府東大阪市西上小阪');
ok($zip->set_number('5770812')->is_valid_number, '大阪府東大阪市東上小阪');
ok($zip->set_number('5770813')->is_valid_number, '大阪府東大阪市新上小阪');
ok($zip->set_number('5770814')->is_valid_number, '大阪府東大阪市南上小阪');
ok($zip->set_number('5770815')->is_valid_number, '大阪府東大阪市金物町');
ok($zip->set_number('5770816')->is_valid_number, '大阪府東大阪市友井');
ok($zip->set_number('5770817')->is_valid_number, '大阪府東大阪市近江堂');
ok($zip->set_number('5770818')->is_valid_number, '大阪府東大阪市小若江');
ok($zip->set_number('5770821')->is_valid_number, '大阪府東大阪市吉松');
ok($zip->set_number('5770822')->is_valid_number, '大阪府東大阪市源氏ケ丘');
ok($zip->set_number('5770823')->is_valid_number, '大阪府東大阪市金岡');
ok($zip->set_number('5770824')->is_valid_number, '大阪府東大阪市大蓮東');
ok($zip->set_number('5770825')->is_valid_number, '大阪府東大阪市大蓮南');
ok($zip->set_number('5770826')->is_valid_number, '大阪府東大阪市大蓮北');
ok($zip->set_number('5770827')->is_valid_number, '大阪府東大阪市衣摺');
ok($zip->set_number('5770831')->is_valid_number, '大阪府東大阪市俊徳町');
ok($zip->set_number('5770832')->is_valid_number, '大阪府東大阪市長瀬町');
ok($zip->set_number('5770833')->is_valid_number, '大阪府東大阪市柏田東町');
ok($zip->set_number('5770834')->is_valid_number, '大阪府東大阪市柏田本町');
ok($zip->set_number('5770835')->is_valid_number, '大阪府東大阪市柏田西');
ok($zip->set_number('5770836')->is_valid_number, '大阪府東大阪市渋川町');
ok($zip->set_number('5770837')->is_valid_number, '大阪府東大阪市寿町');
ok($zip->set_number('5770841')->is_valid_number, '大阪府東大阪市足代');
ok($zip->set_number('5770842')->is_valid_number, '大阪府東大阪市足代南');
ok($zip->set_number('5770843')->is_valid_number, '大阪府東大阪市荒川');
ok($zip->set_number('5770844')->is_valid_number, '大阪府東大阪市太平寺');
ok($zip->set_number('5770845')->is_valid_number, '大阪府東大阪市寺前町');
ok($zip->set_number('5770846')->is_valid_number, '大阪府東大阪市岸田堂北町');
ok($zip->set_number('5770847')->is_valid_number, '大阪府東大阪市岸田堂南町');
ok($zip->set_number('5770848')->is_valid_number, '大阪府東大阪市岸田堂西');
ok($zip->set_number('5770849')->is_valid_number, '大阪府東大阪市三ノ瀬');
ok($zip->set_number('5780901')->is_valid_number, '大阪府東大阪市加納');
ok($zip->set_number('5780902')->is_valid_number, '大阪府東大阪市川中');
ok($zip->set_number('5780903')->is_valid_number, '大阪府東大阪市今米');
ok($zip->set_number('5780904')->is_valid_number, '大阪府東大阪市吉原');
ok($zip->set_number('5780905')->is_valid_number, '大阪府東大阪市川田');
ok($zip->set_number('5780911')->is_valid_number, '大阪府東大阪市中新開');
ok($zip->set_number('5780912')->is_valid_number, '大阪府東大阪市角田');
ok($zip->set_number('5780913')->is_valid_number, '大阪府東大阪市中野');
ok($zip->set_number('5780914')->is_valid_number, '大阪府東大阪市箕輪');
ok($zip->set_number('5780915')->is_valid_number, '大阪府東大阪市古箕輪');
ok($zip->set_number('5780921')->is_valid_number, '大阪府東大阪市水走');
ok($zip->set_number('5780922')->is_valid_number, '大阪府東大阪市松原');
ok($zip->set_number('5780923')->is_valid_number, '大阪府東大阪市松原南');
ok($zip->set_number('5780924')->is_valid_number, '大阪府東大阪市吉田');
ok($zip->set_number('5780925')->is_valid_number, '大阪府東大阪市稲葉');
ok($zip->set_number('5780931')->is_valid_number, '大阪府東大阪市花園東町');
ok($zip->set_number('5780932')->is_valid_number, '大阪府東大阪市玉串町東');
ok($zip->set_number('5780933')->is_valid_number, '大阪府東大阪市玉串元町');
ok($zip->set_number('5780934')->is_valid_number, '大阪府東大阪市玉串町西');
ok($zip->set_number('5780935')->is_valid_number, '大阪府東大阪市若江東町');
ok($zip->set_number('5780936')->is_valid_number, '大阪府東大阪市花園西町');
ok($zip->set_number('5780937')->is_valid_number, '大阪府東大阪市花園本町');
ok($zip->set_number('5780941')->is_valid_number, '大阪府東大阪市岩田町');
ok($zip->set_number('5780942')->is_valid_number, '大阪府東大阪市若江本町');
ok($zip->set_number('5780943')->is_valid_number, '大阪府東大阪市若江南町');
ok($zip->set_number('5780944')->is_valid_number, '大阪府東大阪市若江西新町');
ok($zip->set_number('5780945')->is_valid_number, '大阪府東大阪市若江北町');
ok($zip->set_number('5780946')->is_valid_number, '大阪府東大阪市瓜生堂');
ok($zip->set_number('5780947')->is_valid_number, '大阪府東大阪市西岩田');
ok($zip->set_number('5780948')->is_valid_number, '大阪府東大阪市菱屋東');
ok($zip->set_number('5780951')->is_valid_number, '大阪府東大阪市新庄東');
ok($zip->set_number('5780952')->is_valid_number, '大阪府東大阪市本庄東');
ok($zip->set_number('5780953')->is_valid_number, '大阪府東大阪市本庄');
ok($zip->set_number('5780954')->is_valid_number, '大阪府東大阪市横枕');
ok($zip->set_number('5780955')->is_valid_number, '大阪府東大阪市横枕南');
ok($zip->set_number('5780956')->is_valid_number, '大阪府東大阪市横枕西');
ok($zip->set_number('5780957')->is_valid_number, '大阪府東大阪市本庄中');
ok($zip->set_number('5780958')->is_valid_number, '大阪府東大阪市新庄南');
ok($zip->set_number('5780961')->is_valid_number, '大阪府東大阪市南鴻池町');
ok($zip->set_number('5780963')->is_valid_number, '大阪府東大阪市新庄');
ok($zip->set_number('5780964')->is_valid_number, '大阪府東大阪市新庄西');
ok($zip->set_number('5780965')->is_valid_number, '大阪府東大阪市本庄西');
ok($zip->set_number('5780966')->is_valid_number, '大阪府東大阪市三島');
ok($zip->set_number('5780967')->is_valid_number, '大阪府東大阪市新鴻池町');
ok($zip->set_number('5780971')->is_valid_number, '大阪府東大阪市鴻池本町');
ok($zip->set_number('5780972')->is_valid_number, '大阪府東大阪市鴻池町');
ok($zip->set_number('5780973')->is_valid_number, '大阪府東大阪市東鴻池町');
ok($zip->set_number('5780974')->is_valid_number, '大阪府東大阪市鴻池元町');
ok($zip->set_number('5780975')->is_valid_number, '大阪府東大阪市中鴻池町');
ok($zip->set_number('5780976')->is_valid_number, '大阪府東大阪市西鴻池町');
ok($zip->set_number('5780977')->is_valid_number, '大阪府東大阪市鴻池徳庵町');
ok($zip->set_number('5780978')->is_valid_number, '大阪府東大阪市北鴻池町');
ok($zip->set_number('5780981')->is_valid_number, '大阪府東大阪市島之内');
ok($zip->set_number('5780982')->is_valid_number, '大阪府東大阪市吉田本町');
ok($zip->set_number('5780983')->is_valid_number, '大阪府東大阪市吉田下島');
ok($zip->set_number('5780984')->is_valid_number, '大阪府東大阪市菱江');
ok($zip->set_number('5780985')->is_valid_number, '大阪府東大阪市中野南');
ok($zip->set_number('5798001')->is_valid_number, '大阪府東大阪市善根寺町');
ok($zip->set_number('5798002')->is_valid_number, '大阪府東大阪市池之端町');
ok($zip->set_number('5798003')->is_valid_number, '大阪府東大阪市日下町');
ok($zip->set_number('5798004')->is_valid_number, '大阪府東大阪市布市町');
ok($zip->set_number('5798005')->is_valid_number, '大阪府東大阪市元町');
ok($zip->set_number('5798011')->is_valid_number, '大阪府東大阪市東石切町');
ok($zip->set_number('5798012')->is_valid_number, '大阪府東大阪市上石切町(その他)');
ok($zip->set_number('5798013')->is_valid_number, '大阪府東大阪市西石切町');
ok($zip->set_number('5798014')->is_valid_number, '大阪府東大阪市中石切町');
ok($zip->set_number('5798015')->is_valid_number, '大阪府東大阪市北石切町');
ok($zip->set_number('5798021')->is_valid_number, '大阪府東大阪市額田町');
ok($zip->set_number('5798022')->is_valid_number, '大阪府東大阪市山手町');
ok($zip->set_number('5798023')->is_valid_number, '大阪府東大阪市立花町');
ok($zip->set_number('5798024')->is_valid_number, '大阪府東大阪市南荘町');
ok($zip->set_number('5798025')->is_valid_number, '大阪府東大阪市宝町');
ok($zip->set_number('5798026')->is_valid_number, '大阪府東大阪市弥生町');
ok($zip->set_number('5798027')->is_valid_number, '大阪府東大阪市東山町');
ok($zip->set_number('5798031')->is_valid_number, '大阪府東大阪市豊浦町');
ok($zip->set_number('5798032')->is_valid_number, '大阪府東大阪市東豊浦町');
ok($zip->set_number('5798033')->is_valid_number, '大阪府東大阪市出雲井町');
ok($zip->set_number('5798034')->is_valid_number, '大阪府東大阪市出雲井本町');
ok($zip->set_number('5798035')->is_valid_number, '大阪府東大阪市鳥居町');
ok($zip->set_number('5798036')->is_valid_number, '大阪府東大阪市鷹殿町');
ok($zip->set_number('5798037')->is_valid_number, '大阪府東大阪市新町');
ok($zip->set_number('5798038')->is_valid_number, '大阪府東大阪市箱殿町');
ok($zip->set_number('5798041')->is_valid_number, '大阪府東大阪市喜里川町');
ok($zip->set_number('5798042')->is_valid_number, '大阪府東大阪市五条町');
ok($zip->set_number('5798043')->is_valid_number, '大阪府東大阪市客坊町');
ok($zip->set_number('5798044')->is_valid_number, '大阪府東大阪市河内町');
ok($zip->set_number('5798045')->is_valid_number, '大阪府東大阪市本町');
ok($zip->set_number('5798046')->is_valid_number, '大阪府東大阪市昭和町');
ok($zip->set_number('5798047')->is_valid_number, '大阪府東大阪市桜町');
ok($zip->set_number('5798048')->is_valid_number, '大阪府東大阪市旭町');
ok($zip->set_number('5798051')->is_valid_number, '大阪府東大阪市瓢箪山町');
ok($zip->set_number('5798052')->is_valid_number, '大阪府東大阪市上四条町');
ok($zip->set_number('5798053')->is_valid_number, '大阪府東大阪市四条町');
ok($zip->set_number('5798054')->is_valid_number, '大阪府東大阪市南四条町');
ok($zip->set_number('5798055')->is_valid_number, '大阪府東大阪市末広町');
ok($zip->set_number('5798056')->is_valid_number, '大阪府東大阪市若草町');
ok($zip->set_number('5798057')->is_valid_number, '大阪府東大阪市御幸町');
ok($zip->set_number('5798058')->is_valid_number, '大阪府東大阪市神田町');
ok($zip->set_number('5798061')->is_valid_number, '大阪府東大阪市六万寺町');
ok($zip->set_number('5798062')->is_valid_number, '大阪府東大阪市上六万寺町');
ok($zip->set_number('5798063')->is_valid_number, '大阪府東大阪市横小路町');
ok($zip->set_number('5798064')->is_valid_number, '大阪府東大阪市池島町');
ok($zip->set_number('5798065')->is_valid_number, '大阪府東大阪市新池島町');
ok($zip->set_number('5798066')->is_valid_number, '大阪府東大阪市下六万寺町');
ok($zip->set_number('5800000')->is_valid_number, '大阪府松原市以下に掲載がない場合');
ok($zip->set_number('5800001')->is_valid_number, '大阪府松原市若林');
ok($zip->set_number('5800002')->is_valid_number, '大阪府松原市小川');
ok($zip->set_number('5800003')->is_valid_number, '大阪府松原市一津屋');
ok($zip->set_number('5800004')->is_valid_number, '大阪府松原市西野々');
ok($zip->set_number('5800005')->is_valid_number, '大阪府松原市別所');
ok($zip->set_number('5800006')->is_valid_number, '大阪府松原市大堀');
ok($zip->set_number('5800011')->is_valid_number, '大阪府松原市西大塚');
ok($zip->set_number('5800012')->is_valid_number, '大阪府松原市立部');
ok($zip->set_number('5800013')->is_valid_number, '大阪府松原市丹南');
ok($zip->set_number('5800014')->is_valid_number, '大阪府松原市岡');
ok($zip->set_number('5800015')->is_valid_number, '大阪府松原市新堂');
ok($zip->set_number('5800016')->is_valid_number, '大阪府松原市上田');
ok($zip->set_number('5800017')->is_valid_number, '大阪府松原市柴垣');
ok($zip->set_number('5800021')->is_valid_number, '大阪府松原市高見の里');
ok($zip->set_number('5800022')->is_valid_number, '大阪府松原市河合');
ok($zip->set_number('5800023')->is_valid_number, '大阪府松原市南新町');
ok($zip->set_number('5800024')->is_valid_number, '大阪府松原市東新町');
ok($zip->set_number('5800025')->is_valid_number, '大阪府松原市北新町');
ok($zip->set_number('5800026')->is_valid_number, '大阪府松原市天美我堂');
ok($zip->set_number('5800031')->is_valid_number, '大阪府松原市天美北');
ok($zip->set_number('5800032')->is_valid_number, '大阪府松原市天美東');
ok($zip->set_number('5800033')->is_valid_number, '大阪府松原市天美南');
ok($zip->set_number('5800034')->is_valid_number, '大阪府松原市天美西');
ok($zip->set_number('5800041')->is_valid_number, '大阪府松原市三宅東');
ok($zip->set_number('5800042')->is_valid_number, '大阪府松原市松ケ丘');
ok($zip->set_number('5800043')->is_valid_number, '大阪府松原市阿保');
ok($zip->set_number('5800044')->is_valid_number, '大阪府松原市田井城');
ok($zip->set_number('5800045')->is_valid_number, '大阪府松原市三宅西');
ok($zip->set_number('5800046')->is_valid_number, '大阪府松原市三宅中');
ok($zip->set_number('5810000')->is_valid_number, '大阪府八尾市以下に掲載がない場合');
ok($zip->set_number('5810001')->is_valid_number, '大阪府八尾市末広町');
ok($zip->set_number('5810002')->is_valid_number, '大阪府八尾市東久宝寺');
ok($zip->set_number('5810003')->is_valid_number, '大阪府八尾市本町');
ok($zip->set_number('5810004')->is_valid_number, '大阪府八尾市東本町');
ok($zip->set_number('5810005')->is_valid_number, '大阪府八尾市荘内町');
ok($zip->set_number('5810006')->is_valid_number, '大阪府八尾市清水町');
ok($zip->set_number('5810007')->is_valid_number, '大阪府八尾市光南町');
ok($zip->set_number('5810010')->is_valid_number, '大阪府八尾市都塚北');
ok($zip->set_number('5810011')->is_valid_number, '大阪府八尾市若草町');
ok($zip->set_number('5810012')->is_valid_number, '大阪府八尾市小阪合町');
ok($zip->set_number('5810013')->is_valid_number, '大阪府八尾市山本町南');
ok($zip->set_number('5810014')->is_valid_number, '大阪府八尾市中田');
ok($zip->set_number('5810015')->is_valid_number, '大阪府八尾市刑部');
ok($zip->set_number('5810016')->is_valid_number, '大阪府八尾市八尾木北');
ok($zip->set_number('5810017')->is_valid_number, '大阪府八尾市高美町');
ok($zip->set_number('5810018')->is_valid_number, '大阪府八尾市青山町');
ok($zip->set_number('5810019')->is_valid_number, '大阪府八尾市南小阪合町');
ok($zip->set_number('5810020')->is_valid_number, '大阪府八尾市曙川東');
ok($zip->set_number('5810021')->is_valid_number, '大阪府八尾市山本高安町');
ok($zip->set_number('5810022')->is_valid_number, '大阪府八尾市柏村町');
ok($zip->set_number('5810023')->is_valid_number, '大阪府八尾市都塚');
ok($zip->set_number('5810024')->is_valid_number, '大阪府八尾市二俣');
ok($zip->set_number('5810025')->is_valid_number, '大阪府八尾市天王寺屋');
ok($zip->set_number('5810026')->is_valid_number, '大阪府八尾市曙町');
ok($zip->set_number('5810027')->is_valid_number, '大阪府八尾市八尾木(丁目)');
ok($zip->set_number('5810027')->is_valid_number, '大阪府八尾市八尾木(大字)');
ok($zip->set_number('5810028')->is_valid_number, '大阪府八尾市八尾木東');
ok($zip->set_number('5810029')->is_valid_number, '大阪府八尾市東弓削');
ok($zip->set_number('5810030')->is_valid_number, '大阪府八尾市都塚南');
ok($zip->set_number('5810031')->is_valid_number, '大阪府八尾市志紀町');
ok($zip->set_number('5810032')->is_valid_number, '大阪府八尾市弓削町');
ok($zip->set_number('5810033')->is_valid_number, '大阪府八尾市志紀町南');
ok($zip->set_number('5810034')->is_valid_number, '大阪府八尾市弓削町南');
ok($zip->set_number('5810035')->is_valid_number, '大阪府八尾市西弓削');
ok($zip->set_number('5810036')->is_valid_number, '大阪府八尾市沼');
ok($zip->set_number('5810037')->is_valid_number, '大阪府八尾市太田');
ok($zip->set_number('5810038')->is_valid_number, '大阪府八尾市若林町');
ok($zip->set_number('5810039')->is_valid_number, '大阪府八尾市太田新町');
ok($zip->set_number('5810041')->is_valid_number, '大阪府八尾市北木の本');
ok($zip->set_number('5810042')->is_valid_number, '大阪府八尾市南木の本');
ok($zip->set_number('5810043')->is_valid_number, '大阪府八尾市空港');
ok($zip->set_number('5810044')->is_valid_number, '大阪府八尾市木の本');
ok($zip->set_number('5810045')->is_valid_number, '大阪府八尾市西木の本');
ok($zip->set_number('5810051')->is_valid_number, '大阪府八尾市竹渕西');
ok($zip->set_number('5810052')->is_valid_number, '大阪府八尾市竹渕');
ok($zip->set_number('5810053')->is_valid_number, '大阪府八尾市竹渕東');
ok($zip->set_number('5810054')->is_valid_number, '大阪府八尾市南亀井町');
ok($zip->set_number('5810055')->is_valid_number, '大阪府八尾市跡部南の町');
ok($zip->set_number('5810056')->is_valid_number, '大阪府八尾市南太子堂');
ok($zip->set_number('5810061')->is_valid_number, '大阪府八尾市春日町');
ok($zip->set_number('5810062')->is_valid_number, '大阪府八尾市東太子');
ok($zip->set_number('5810063')->is_valid_number, '大阪府八尾市太子堂');
ok($zip->set_number('5810064')->is_valid_number, '大阪府八尾市跡部本町');
ok($zip->set_number('5810065')->is_valid_number, '大阪府八尾市亀井町');
ok($zip->set_number('5810066')->is_valid_number, '大阪府八尾市北亀井町');
ok($zip->set_number('5810067')->is_valid_number, '大阪府八尾市神武町');
ok($zip->set_number('5810068')->is_valid_number, '大阪府八尾市跡部北の町');
ok($zip->set_number('5810069')->is_valid_number, '大阪府八尾市龍華町');
ok($zip->set_number('5810071')->is_valid_number, '大阪府八尾市北久宝寺');
ok($zip->set_number('5810072')->is_valid_number, '大阪府八尾市久宝寺');
ok($zip->set_number('5810073')->is_valid_number, '大阪府八尾市高町');
ok($zip->set_number('5810074')->is_valid_number, '大阪府八尾市栄町');
ok($zip->set_number('5810075')->is_valid_number, '大阪府八尾市渋川町');
ok($zip->set_number('5810076')->is_valid_number, '大阪府八尾市南久宝寺');
ok($zip->set_number('5810077')->is_valid_number, '大阪府八尾市西久宝寺');
ok($zip->set_number('5810081')->is_valid_number, '大阪府八尾市南本町');
ok($zip->set_number('5810082')->is_valid_number, '大阪府八尾市相生町');
ok($zip->set_number('5810083')->is_valid_number, '大阪府八尾市永畑町');
ok($zip->set_number('5810084')->is_valid_number, '大阪府八尾市植松町');
ok($zip->set_number('5810085')->is_valid_number, '大阪府八尾市安中町');
ok($zip->set_number('5810086')->is_valid_number, '大阪府八尾市陽光園');
ok($zip->set_number('5810087')->is_valid_number, '大阪府八尾市明美町');
ok($zip->set_number('5810088')->is_valid_number, '大阪府八尾市松山町');
ok($zip->set_number('5810091')->is_valid_number, '大阪府八尾市南植松町');
ok($zip->set_number('5810092')->is_valid_number, '大阪府八尾市老原');
ok($zip->set_number('5810093')->is_valid_number, '大阪府八尾市東老原');
ok($zip->set_number('5810094')->is_valid_number, '大阪府八尾市志紀町西');
ok($zip->set_number('5810095')->is_valid_number, '大阪府八尾市田井中');
ok($zip->set_number('5810801')->is_valid_number, '大阪府八尾市山城町');
ok($zip->set_number('5810802')->is_valid_number, '大阪府八尾市北本町');
ok($zip->set_number('5810803')->is_valid_number, '大阪府八尾市光町');
ok($zip->set_number('5810811')->is_valid_number, '大阪府八尾市新家町');
ok($zip->set_number('5810812')->is_valid_number, '大阪府八尾市山賀町');
ok($zip->set_number('5810813')->is_valid_number, '大阪府八尾市泉町');
ok($zip->set_number('5810814')->is_valid_number, '大阪府八尾市楠根町');
ok($zip->set_number('5810815')->is_valid_number, '大阪府八尾市宮町');
ok($zip->set_number('5810816')->is_valid_number, '大阪府八尾市佐堂町');
ok($zip->set_number('5810817')->is_valid_number, '大阪府八尾市久宝園');
ok($zip->set_number('5810818')->is_valid_number, '大阪府八尾市美園町');
ok($zip->set_number('5810821')->is_valid_number, '大阪府八尾市幸町');
ok($zip->set_number('5810822')->is_valid_number, '大阪府八尾市高砂町');
ok($zip->set_number('5810823')->is_valid_number, '大阪府八尾市桂町');
ok($zip->set_number('5810831')->is_valid_number, '大阪府八尾市山本町北');
ok($zip->set_number('5810832')->is_valid_number, '大阪府八尾市堤町');
ok($zip->set_number('5810833')->is_valid_number, '大阪府八尾市旭ケ丘');
ok($zip->set_number('5810834')->is_valid_number, '大阪府八尾市萱振町');
ok($zip->set_number('5810835')->is_valid_number, '大阪府八尾市小畑町');
ok($zip->set_number('5810836')->is_valid_number, '大阪府八尾市長池町');
ok($zip->set_number('5810837')->is_valid_number, '大阪府八尾市緑ケ丘');
ok($zip->set_number('5810841')->is_valid_number, '大阪府八尾市福万寺町北');
ok($zip->set_number('5810842')->is_valid_number, '大阪府八尾市福万寺町');
ok($zip->set_number('5810843')->is_valid_number, '大阪府八尾市福万寺町南');
ok($zip->set_number('5810844')->is_valid_number, '大阪府八尾市福栄町');
ok($zip->set_number('5810845')->is_valid_number, '大阪府八尾市上之島町北');
ok($zip->set_number('5810846')->is_valid_number, '大阪府八尾市上之島町南');
ok($zip->set_number('5810847')->is_valid_number, '大阪府八尾市東山本町');
ok($zip->set_number('5810851')->is_valid_number, '大阪府八尾市上尾町');
ok($zip->set_number('5810852')->is_valid_number, '大阪府八尾市西高安町');
ok($zip->set_number('5810853')->is_valid_number, '大阪府八尾市楽音寺');
ok($zip->set_number('5810854')->is_valid_number, '大阪府八尾市大竹');
ok($zip->set_number('5810855')->is_valid_number, '大阪府八尾市神立');
ok($zip->set_number('5810856')->is_valid_number, '大阪府八尾市水越');
ok($zip->set_number('5810861')->is_valid_number, '大阪府八尾市東町');
ok($zip->set_number('5810862')->is_valid_number, '大阪府八尾市千塚');
ok($zip->set_number('5810863')->is_valid_number, '大阪府八尾市大窪');
ok($zip->set_number('5810864')->is_valid_number, '大阪府八尾市山畑');
ok($zip->set_number('5810865')->is_valid_number, '大阪府八尾市服部川');
ok($zip->set_number('5810866')->is_valid_number, '大阪府八尾市東山本新町');
ok($zip->set_number('5810867')->is_valid_number, '大阪府八尾市山本町');
ok($zip->set_number('5810868')->is_valid_number, '大阪府八尾市西山本町');
ok($zip->set_number('5810869')->is_valid_number, '大阪府八尾市桜ケ丘');
ok($zip->set_number('5810871')->is_valid_number, '大阪府八尾市高安町北');
ok($zip->set_number('5810872')->is_valid_number, '大阪府八尾市郡川');
ok($zip->set_number('5810873')->is_valid_number, '大阪府八尾市黒谷');
ok($zip->set_number('5810874')->is_valid_number, '大阪府八尾市教興寺');
ok($zip->set_number('5810875')->is_valid_number, '大阪府八尾市高安町南');
ok($zip->set_number('5810881')->is_valid_number, '大阪府八尾市垣内');
ok($zip->set_number('5810882')->is_valid_number, '大阪府八尾市恩智北町');
ok($zip->set_number('5810883')->is_valid_number, '大阪府八尾市恩智中町');
ok($zip->set_number('5810884')->is_valid_number, '大阪府八尾市恩智南町');
ok($zip->set_number('5810885')->is_valid_number, '大阪府八尾市神宮寺');
ok($zip->set_number('5820000')->is_valid_number, '大阪府柏原市以下に掲載がない場合');
ok($zip->set_number('5820001')->is_valid_number, '大阪府柏原市本郷');
ok($zip->set_number('5820002')->is_valid_number, '大阪府柏原市今町');
ok($zip->set_number('5820003')->is_valid_number, '大阪府柏原市堂島町');
ok($zip->set_number('5820004')->is_valid_number, '大阪府柏原市河原町');
ok($zip->set_number('5820005')->is_valid_number, '大阪府柏原市法善寺');
ok($zip->set_number('5820006')->is_valid_number, '大阪府柏原市清州');
ok($zip->set_number('5820007')->is_valid_number, '大阪府柏原市上市');
ok($zip->set_number('5820008')->is_valid_number, '大阪府柏原市古町');
ok($zip->set_number('5820009')->is_valid_number, '大阪府柏原市大正');
ok($zip->set_number('5820010')->is_valid_number, '大阪府柏原市山ノ井町');
ok($zip->set_number('5820011')->is_valid_number, '大阪府柏原市本堂');
ok($zip->set_number('5820012')->is_valid_number, '大阪府柏原市雁多尾畑');
ok($zip->set_number('5820013')->is_valid_number, '大阪府柏原市峠');
ok($zip->set_number('5820014')->is_valid_number, '大阪府柏原市青谷');
ok($zip->set_number('5820015')->is_valid_number, '大阪府柏原市高井田');
ok($zip->set_number('5820016')->is_valid_number, '大阪府柏原市安堂町');
ok($zip->set_number('5820017')->is_valid_number, '大阪府柏原市太平寺');
ok($zip->set_number('5820018')->is_valid_number, '大阪府柏原市大県');
ok($zip->set_number('5820019')->is_valid_number, '大阪府柏原市平野');
ok($zip->set_number('5820020')->is_valid_number, '大阪府柏原市片山町');
ok($zip->set_number('5820021')->is_valid_number, '大阪府柏原市国分本町');
ok($zip->set_number('5820022')->is_valid_number, '大阪府柏原市国分市場');
ok($zip->set_number('5820023')->is_valid_number, '大阪府柏原市国分東条町');
ok($zip->set_number('5820024')->is_valid_number, '大阪府柏原市田辺');
ok($zip->set_number('5820025')->is_valid_number, '大阪府柏原市国分西');
ok($zip->set_number('5820026')->is_valid_number, '大阪府柏原市旭ケ丘');
ok($zip->set_number('5820027')->is_valid_number, '大阪府柏原市円明町');
ok($zip->set_number('5820028')->is_valid_number, '大阪府柏原市玉手町');
ok($zip->set_number('5820029')->is_valid_number, '大阪府柏原市石川町');
ok($zip->set_number('5830000')->is_valid_number, '大阪府羽曳野市以下に掲載がない場合');
ok($zip->set_number('5830000')->is_valid_number, '大阪府藤井寺市以下に掲載がない場合');
ok($zip->set_number('5830000')->is_valid_number, '大阪府南河内郡太子町以下に掲載がない場合');
ok($zip->set_number('5830001')->is_valid_number, '大阪府藤井寺市川北');
ok($zip->set_number('5830002')->is_valid_number, '大阪府藤井寺市北條町');
ok($zip->set_number('5830003')->is_valid_number, '大阪府藤井寺市船橋町');
ok($zip->set_number('5830004')->is_valid_number, '大阪府藤井寺市梅が園町');
ok($zip->set_number('5830005')->is_valid_number, '大阪府藤井寺市惣社');
ok($zip->set_number('5830006')->is_valid_number, '大阪府藤井寺市国府');
ok($zip->set_number('5830007')->is_valid_number, '大阪府藤井寺市林');
ok($zip->set_number('5830008')->is_valid_number, '大阪府藤井寺市大井');
ok($zip->set_number('5830009')->is_valid_number, '大阪府藤井寺市西大井');
ok($zip->set_number('5830011')->is_valid_number, '大阪府藤井寺市沢田');
ok($zip->set_number('5830012')->is_valid_number, '大阪府藤井寺市道明寺');
ok($zip->set_number('5830013')->is_valid_number, '大阪府藤井寺市古室');
ok($zip->set_number('5830014')->is_valid_number, '大阪府藤井寺市野中');
ok($zip->set_number('5830015')->is_valid_number, '大阪府藤井寺市青山');
ok($zip->set_number('5830016')->is_valid_number, '大阪府藤井寺市陵南町');
ok($zip->set_number('5830017')->is_valid_number, '大阪府藤井寺市藤ケ丘');
ok($zip->set_number('5830018')->is_valid_number, '大阪府藤井寺市西古室');
ok($zip->set_number('5830021')->is_valid_number, '大阪府藤井寺市御舟町');
ok($zip->set_number('5830022')->is_valid_number, '大阪府藤井寺市東藤井寺町');
ok($zip->set_number('5830023')->is_valid_number, '大阪府藤井寺市さくら町');
ok($zip->set_number('5830024')->is_valid_number, '大阪府藤井寺市藤井寺');
ok($zip->set_number('5830025')->is_valid_number, '大阪府藤井寺市春日丘新町');
ok($zip->set_number('5830026')->is_valid_number, '大阪府藤井寺市春日丘');
ok($zip->set_number('5830027')->is_valid_number, '大阪府藤井寺市岡');
ok($zip->set_number('5830031')->is_valid_number, '大阪府藤井寺市小山新町');
ok($zip->set_number('5830032')->is_valid_number, '大阪府藤井寺市小山藤美町');
ok($zip->set_number('5830033')->is_valid_number, '大阪府藤井寺市小山');
ok($zip->set_number('5830034')->is_valid_number, '大阪府藤井寺市小山藤の里町');
ok($zip->set_number('5830035')->is_valid_number, '大阪府藤井寺市北岡');
ok($zip->set_number('5830036')->is_valid_number, '大阪府藤井寺市恵美坂');
ok($zip->set_number('5830037')->is_valid_number, '大阪府藤井寺市津堂');
ok($zip->set_number('5830841')->is_valid_number, '大阪府羽曳野市駒ケ谷');
ok($zip->set_number('5830842')->is_valid_number, '大阪府羽曳野市飛鳥');
ok($zip->set_number('5830843')->is_valid_number, '大阪府羽曳野市通法寺');
ok($zip->set_number('5830844')->is_valid_number, '大阪府羽曳野市壺井');
ok($zip->set_number('5830845')->is_valid_number, '大阪府羽曳野市広瀬');
ok($zip->set_number('5830846')->is_valid_number, '大阪府羽曳野市東阪田');
ok($zip->set_number('5830847')->is_valid_number, '大阪府羽曳野市大黒');
ok($zip->set_number('5830848')->is_valid_number, '大阪府羽曳野市川向');
ok($zip->set_number('5830851')->is_valid_number, '大阪府羽曳野市碓井');
ok($zip->set_number('5830852')->is_valid_number, '大阪府羽曳野市古市');
ok($zip->set_number('5830853')->is_valid_number, '大阪府羽曳野市栄町');
ok($zip->set_number('5830854')->is_valid_number, '大阪府羽曳野市軽里');
ok($zip->set_number('5830855')->is_valid_number, '大阪府羽曳野市翠鳥園');
ok($zip->set_number('5830856')->is_valid_number, '大阪府羽曳野市白鳥');
ok($zip->set_number('5830857')->is_valid_number, '大阪府羽曳野市誉田');
ok($zip->set_number('5830858')->is_valid_number, '大阪府羽曳野市南古市');
ok($zip->set_number('5830861')->is_valid_number, '大阪府羽曳野市西浦');
ok($zip->set_number('5830862')->is_valid_number, '大阪府羽曳野市尺度');
ok($zip->set_number('5830863')->is_valid_number, '大阪府羽曳野市蔵之内');
ok($zip->set_number('5830864')->is_valid_number, '大阪府羽曳野市羽曳が丘');
ok($zip->set_number('5830865')->is_valid_number, '大阪府羽曳野市羽曳が丘西');
ok($zip->set_number('5830866')->is_valid_number, '大阪府羽曳野市埴生野');
ok($zip->set_number('5830867')->is_valid_number, '大阪府羽曳野市河原城');
ok($zip->set_number('5830868')->is_valid_number, '大阪府羽曳野市学園前');
ok($zip->set_number('5830871')->is_valid_number, '大阪府羽曳野市野々上');
ok($zip->set_number('5830872')->is_valid_number, '大阪府羽曳野市はびきの');
ok($zip->set_number('5830873')->is_valid_number, '大阪府羽曳野市桃山台');
ok($zip->set_number('5830874')->is_valid_number, '大阪府羽曳野市郡戸');
ok($zip->set_number('5830875')->is_valid_number, '大阪府羽曳野市樫山');
ok($zip->set_number('5830876')->is_valid_number, '大阪府羽曳野市伊賀');
ok($zip->set_number('5830881')->is_valid_number, '大阪府羽曳野市島泉');
ok($zip->set_number('5830882')->is_valid_number, '大阪府羽曳野市高鷲');
ok($zip->set_number('5830883')->is_valid_number, '大阪府羽曳野市向野');
ok($zip->set_number('5830884')->is_valid_number, '大阪府羽曳野市野');
ok($zip->set_number('5830885')->is_valid_number, '大阪府羽曳野市南恵我之荘');
ok($zip->set_number('5830886')->is_valid_number, '大阪府羽曳野市恵我之荘');
ok($zip->set_number('5830991')->is_valid_number, '大阪府南河内郡太子町春日');
ok($zip->set_number('5830992')->is_valid_number, '大阪府南河内郡太子町山田');
ok($zip->set_number('5830993')->is_valid_number, '大阪府南河内郡太子町畑');
ok($zip->set_number('5830994')->is_valid_number, '大阪府南河内郡太子町葉室');
ok($zip->set_number('5830995')->is_valid_number, '大阪府南河内郡太子町太子');
ok($zip->set_number('5830996')->is_valid_number, '大阪府南河内郡太子町聖和台');
ok($zip->set_number('5840000')->is_valid_number, '大阪府富田林市以下に掲載がない場合');
ok($zip->set_number('5840001')->is_valid_number, '大阪府富田林市梅の里');
ok($zip->set_number('5840002')->is_valid_number, '大阪府富田林市平町');
ok($zip->set_number('5840003')->is_valid_number, '大阪府富田林市喜志新家町');
ok($zip->set_number('5840004')->is_valid_number, '大阪府富田林市木戸山町');
ok($zip->set_number('5840005')->is_valid_number, '大阪府富田林市喜志町');
ok($zip->set_number('5840006')->is_valid_number, '大阪府富田林市旭ケ丘町');
ok($zip->set_number('5840007')->is_valid_number, '大阪府富田林市南旭ケ丘町');
ok($zip->set_number('5840008')->is_valid_number, '大阪府富田林市喜志');
ok($zip->set_number('5840011')->is_valid_number, '大阪府富田林市宮町');
ok($zip->set_number('5840012')->is_valid_number, '大阪府富田林市粟ケ池町');
ok($zip->set_number('5840013')->is_valid_number, '大阪府富田林市桜井町');
ok($zip->set_number('5840014')->is_valid_number, '大阪府富田林市川面町');
ok($zip->set_number('5840015')->is_valid_number, '大阪府富田林市西条町');
ok($zip->set_number('5840016')->is_valid_number, '大阪府富田林市通法寺町');
ok($zip->set_number('5840021')->is_valid_number, '大阪府富田林市中野町');
ok($zip->set_number('5840022')->is_valid_number, '大阪府富田林市中野町東');
ok($zip->set_number('5840023')->is_valid_number, '大阪府富田林市若松町東');
ok($zip->set_number('5840024')->is_valid_number, '大阪府富田林市若松町');
ok($zip->set_number('5840025')->is_valid_number, '大阪府富田林市若松町西');
ok($zip->set_number('5840026')->is_valid_number, '大阪府富田林市緑ケ丘町');
ok($zip->set_number('5840027')->is_valid_number, '大阪府富田林市中野');
ok($zip->set_number('5840028')->is_valid_number, '大阪府富田林市中野町西');
ok($zip->set_number('5840031')->is_valid_number, '大阪府富田林市寿町');
ok($zip->set_number('5840032')->is_valid_number, '大阪府富田林市常盤町');
ok($zip->set_number('5840033')->is_valid_number, '大阪府富田林市富田林町');
ok($zip->set_number('5840034')->is_valid_number, '大阪府富田林市清水町');
ok($zip->set_number('5840035')->is_valid_number, '大阪府富田林市谷川町');
ok($zip->set_number('5840036')->is_valid_number, '大阪府富田林市甲田');
ok($zip->set_number('5840037')->is_valid_number, '大阪府富田林市宮甲田町');
ok($zip->set_number('5840038')->is_valid_number, '大阪府富田林市錦ケ丘町');
ok($zip->set_number('5840039')->is_valid_number, '大阪府富田林市美山台');
ok($zip->set_number('5840040')->is_valid_number, '大阪府富田林市かがり台');
ok($zip->set_number('5840041')->is_valid_number, '大阪府富田林市楠町');
ok($zip->set_number('5840042')->is_valid_number, '大阪府富田林市北大伴町');
ok($zip->set_number('5840043')->is_valid_number, '大阪府富田林市南大伴町');
ok($zip->set_number('5840044')->is_valid_number, '大阪府富田林市別井');
ok($zip->set_number('5840045')->is_valid_number, '大阪府富田林市山中田町');
ok($zip->set_number('5840046')->is_valid_number, '大阪府富田林市東板持町');
ok($zip->set_number('5840047')->is_valid_number, '大阪府富田林市山手町');
ok($zip->set_number('5840048')->is_valid_number, '大阪府富田林市西板持町');
ok($zip->set_number('5840049')->is_valid_number, '大阪府富田林市川向町');
ok($zip->set_number('5840051')->is_valid_number, '大阪府富田林市楠風台');
ok($zip->set_number('5840052')->is_valid_number, '大阪府富田林市佐備');
ok($zip->set_number('5840053')->is_valid_number, '大阪府富田林市龍泉');
ok($zip->set_number('5840054')->is_valid_number, '大阪府富田林市甘南備');
ok($zip->set_number('5840055')->is_valid_number, '大阪府富田林市伏見堂');
ok($zip->set_number('5840056')->is_valid_number, '大阪府富田林市嬉');
ok($zip->set_number('5840057')->is_valid_number, '大阪府富田林市横山');
ok($zip->set_number('5840058')->is_valid_number, '大阪府富田林市彼方');
ok($zip->set_number('5840061')->is_valid_number, '大阪府富田林市伏山');
ok($zip->set_number('5840062')->is_valid_number, '大阪府富田林市須賀');
ok($zip->set_number('5840063')->is_valid_number, '大阪府富田林市錦織');
ok($zip->set_number('5840064')->is_valid_number, '大阪府富田林市不動ケ丘町');
ok($zip->set_number('5840065')->is_valid_number, '大阪府富田林市金剛伏山台');
ok($zip->set_number('5840066')->is_valid_number, '大阪府富田林市錦織北');
ok($zip->set_number('5840067')->is_valid_number, '大阪府富田林市錦織南');
ok($zip->set_number('5840068')->is_valid_number, '大阪府富田林市錦織中');
ok($zip->set_number('5840069')->is_valid_number, '大阪府富田林市錦織東');
ok($zip->set_number('5840070')->is_valid_number, '大阪府富田林市金剛錦織台');
ok($zip->set_number('5840071')->is_valid_number, '大阪府富田林市藤沢台');
ok($zip->set_number('5840072')->is_valid_number, '大阪府富田林市高辺台');
ok($zip->set_number('5840073')->is_valid_number, '大阪府富田林市寺池台');
ok($zip->set_number('5840074')->is_valid_number, '大阪府富田林市久野喜台');
ok($zip->set_number('5840076')->is_valid_number, '大阪府富田林市青葉丘');
ok($zip->set_number('5840077')->is_valid_number, '大阪府富田林市新青葉丘町');
ok($zip->set_number('5840078')->is_valid_number, '大阪府富田林市加太');
ok($zip->set_number('5840079')->is_valid_number, '大阪府富田林市五軒家');
ok($zip->set_number('5840081')->is_valid_number, '大阪府富田林市廿山');
ok($zip->set_number('5840082')->is_valid_number, '大阪府富田林市向陽台');
ok($zip->set_number('5840083')->is_valid_number, '大阪府富田林市小金台');
ok($zip->set_number('5840084')->is_valid_number, '大阪府富田林市桜ケ丘町');
ok($zip->set_number('5840085')->is_valid_number, '大阪府富田林市新家');
ok($zip->set_number('5840086')->is_valid_number, '大阪府富田林市津々山台');
ok($zip->set_number('5840091')->is_valid_number, '大阪府富田林市新堂');
ok($zip->set_number('5840092')->is_valid_number, '大阪府富田林市昭和町');
ok($zip->set_number('5840093')->is_valid_number, '大阪府富田林市本町');
ok($zip->set_number('5840094')->is_valid_number, '大阪府富田林市富美ケ丘町');
ok($zip->set_number('5840095')->is_valid_number, '大阪府富田林市毛人谷');
ok($zip->set_number('5850000')->is_valid_number, '大阪府南河内郡河南町以下に掲載がない場合');
ok($zip->set_number('5850000')->is_valid_number, '大阪府南河内郡千早赤阪村以下に掲載がない場合');
ok($zip->set_number('5850001')->is_valid_number, '大阪府南河内郡河南町東山');
ok($zip->set_number('5850002')->is_valid_number, '大阪府南河内郡河南町一須賀');
ok($zip->set_number('5850003')->is_valid_number, '大阪府南河内郡河南町大ケ塚');
ok($zip->set_number('5850004')->is_valid_number, '大阪府南河内郡河南町山城');
ok($zip->set_number('5850005')->is_valid_number, '大阪府南河内郡河南町大宝');
ok($zip->set_number('5850006')->is_valid_number, '大阪府南河内郡河南町葉室');
ok($zip->set_number('5850011')->is_valid_number, '大阪府南河内郡河南町寺田');
ok($zip->set_number('5850012')->is_valid_number, '大阪府南河内郡河南町加納');
ok($zip->set_number('5850013')->is_valid_number, '大阪府南河内郡河南町平石');
ok($zip->set_number('5850014')->is_valid_number, '大阪府南河内郡河南町白木');
ok($zip->set_number('5850021')->is_valid_number, '大阪府南河内郡河南町持尾');
ok($zip->set_number('5850022')->is_valid_number, '大阪府南河内郡河南町弘川');
ok($zip->set_number('5850023')->is_valid_number, '大阪府南河内郡河南町下河内');
ok($zip->set_number('5850024')->is_valid_number, '大阪府南河内郡河南町上河内');
ok($zip->set_number('5850025')->is_valid_number, '大阪府南河内郡河南町さくら坂');
ok($zip->set_number('5850026')->is_valid_number, '大阪府南河内郡河南町鈴美台');
ok($zip->set_number('5850027')->is_valid_number, '大阪府南河内郡河南町さくら坂南');
ok($zip->set_number('5850031')->is_valid_number, '大阪府南河内郡河南町中');
ok($zip->set_number('5850032')->is_valid_number, '大阪府南河内郡河南町馬谷');
ok($zip->set_number('5850033')->is_valid_number, '大阪府南河内郡河南町芹生谷');
ok($zip->set_number('5850034')->is_valid_number, '大阪府南河内郡河南町神山');
ok($zip->set_number('5850035')->is_valid_number, '大阪府南河内郡河南町寛弘寺');
ok($zip->set_number('5850041')->is_valid_number, '大阪府南河内郡千早赤阪村水分');
ok($zip->set_number('5850042')->is_valid_number, '大阪府南河内郡千早赤阪村二河原辺');
ok($zip->set_number('5850043')->is_valid_number, '大阪府南河内郡千早赤阪村桐山');
ok($zip->set_number('5850044')->is_valid_number, '大阪府南河内郡千早赤阪村森屋');
ok($zip->set_number('5850045')->is_valid_number, '大阪府南河内郡千早赤阪村川野辺');
ok($zip->set_number('5850051')->is_valid_number, '大阪府南河内郡千早赤阪村千早');
ok($zip->set_number('5850052')->is_valid_number, '大阪府南河内郡千早赤阪村中津原');
ok($zip->set_number('5850053')->is_valid_number, '大阪府南河内郡千早赤阪村小吹');
ok($zip->set_number('5850054')->is_valid_number, '大阪府南河内郡千早赤阪村吉年');
ok($zip->set_number('5850055')->is_valid_number, '大阪府南河内郡千早赤阪村東阪');
ok($zip->set_number('5860000')->is_valid_number, '大阪府河内長野市以下に掲載がない場合');
ok($zip->set_number('5860001')->is_valid_number, '大阪府河内長野市木戸');
ok($zip->set_number('5860001')->is_valid_number, '大阪府河内長野市木戸町');
ok($zip->set_number('5860002')->is_valid_number, '大阪府河内長野市市町');
ok($zip->set_number('5860003')->is_valid_number, '大阪府河内長野市楠町東');
ok($zip->set_number('5860004')->is_valid_number, '大阪府河内長野市楠町西');
ok($zip->set_number('5860005')->is_valid_number, '大阪府河内長野市松ケ丘西町');
ok($zip->set_number('5860006')->is_valid_number, '大阪府河内長野市松ケ丘中町');
ok($zip->set_number('5860007')->is_valid_number, '大阪府河内長野市松ケ丘東町');
ok($zip->set_number('5860008')->is_valid_number, '大阪府河内長野市木戸東町');
ok($zip->set_number('5860009')->is_valid_number, '大阪府河内長野市木戸西町');
ok($zip->set_number('5860011')->is_valid_number, '大阪府河内長野市汐の宮町');
ok($zip->set_number('5860012')->is_valid_number, '大阪府河内長野市菊水町');
ok($zip->set_number('5860013')->is_valid_number, '大阪府河内長野市向野町');
ok($zip->set_number('5860014')->is_valid_number, '大阪府河内長野市長野町');
ok($zip->set_number('5860015')->is_valid_number, '大阪府河内長野市本町');
ok($zip->set_number('5860016')->is_valid_number, '大阪府河内長野市西代町');
ok($zip->set_number('5860017')->is_valid_number, '大阪府河内長野市古野町');
ok($zip->set_number('5860018')->is_valid_number, '大阪府河内長野市千代田南町');
ok($zip->set_number('5860021')->is_valid_number, '大阪府河内長野市原町');
ok($zip->set_number('5860022')->is_valid_number, '大阪府河内長野市本多町');
ok($zip->set_number('5860023')->is_valid_number, '大阪府河内長野市野作町');
ok($zip->set_number('5860024')->is_valid_number, '大阪府河内長野市西之山町');
ok($zip->set_number('5860025')->is_valid_number, '大阪府河内長野市昭栄町');
ok($zip->set_number('5860026')->is_valid_number, '大阪府河内長野市寿町');
ok($zip->set_number('5860027')->is_valid_number, '大阪府河内長野市千代田台町');
ok($zip->set_number('5860031')->is_valid_number, '大阪府河内長野市錦町');
ok($zip->set_number('5860032')->is_valid_number, '大阪府河内長野市栄町');
ok($zip->set_number('5860033')->is_valid_number, '大阪府河内長野市喜多町');
ok($zip->set_number('5860034')->is_valid_number, '大阪府河内長野市上田町');
ok($zip->set_number('5860035')->is_valid_number, '大阪府河内長野市小塩町');
ok($zip->set_number('5860036')->is_valid_number, '大阪府河内長野市高向');
ok($zip->set_number('5860037')->is_valid_number, '大阪府河内長野市上原町');
ok($zip->set_number('5860038')->is_valid_number, '大阪府河内長野市上原西町');
ok($zip->set_number('5860039')->is_valid_number, '大阪府河内長野市楠ケ丘');
ok($zip->set_number('5860041')->is_valid_number, '大阪府河内長野市大師町');
ok($zip->set_number('5860042')->is_valid_number, '大阪府河内長野市日東町');
ok($zip->set_number('5860043')->is_valid_number, '大阪府河内長野市清見台');
ok($zip->set_number('5860044')->is_valid_number, '大阪府河内長野市美加の台');
ok($zip->set_number('5860045')->is_valid_number, '大阪府河内長野市東片添町');
ok($zip->set_number('5860046')->is_valid_number, '大阪府河内長野市中片添町');
ok($zip->set_number('5860047')->is_valid_number, '大阪府河内長野市西片添町');
ok($zip->set_number('5860048')->is_valid_number, '大阪府河内長野市三日市町');
ok($zip->set_number('5860051')->is_valid_number, '大阪府河内長野市末広町');
ok($zip->set_number('5860052')->is_valid_number, '大阪府河内長野市河合寺');
ok($zip->set_number('5860053')->is_valid_number, '大阪府河内長野市寺元');
ok($zip->set_number('5860054')->is_valid_number, '大阪府河内長野市神ガ丘');
ok($zip->set_number('5860055')->is_valid_number, '大阪府河内長野市鳩原');
ok($zip->set_number('5860056')->is_valid_number, '大阪府河内長野市太井');
ok($zip->set_number('5860057')->is_valid_number, '大阪府河内長野市小深');
ok($zip->set_number('5860058')->is_valid_number, '大阪府河内長野市石見川');
ok($zip->set_number('5860061')->is_valid_number, '大阪府河内長野市岩瀬');
ok($zip->set_number('5860062')->is_valid_number, '大阪府河内長野市天見');
ok($zip->set_number('5860063')->is_valid_number, '大阪府河内長野市流谷');
ok($zip->set_number('5860064')->is_valid_number, '大阪府河内長野市唐久谷');
ok($zip->set_number('5860065')->is_valid_number, '大阪府河内長野市南ケ丘');
ok($zip->set_number('5860066')->is_valid_number, '大阪府河内長野市清水');
ok($zip->set_number('5860067')->is_valid_number, '大阪府河内長野市南青葉台');
ok($zip->set_number('5860068')->is_valid_number, '大阪府河内長野市北青葉台');
ok($zip->set_number('5860069')->is_valid_number, '大阪府河内長野市石仏');
ok($zip->set_number('5860071')->is_valid_number, '大阪府河内長野市加賀田');
ok($zip->set_number('5860072')->is_valid_number, '大阪府河内長野市滝畑');
ok($zip->set_number('5860073')->is_valid_number, '大阪府河内長野市大矢船西町');
ok($zip->set_number('5860074')->is_valid_number, '大阪府河内長野市大矢船南町');
ok($zip->set_number('5860075')->is_valid_number, '大阪府河内長野市大矢船中町');
ok($zip->set_number('5860076')->is_valid_number, '大阪府河内長野市大矢船北町');
ok($zip->set_number('5860077')->is_valid_number, '大阪府河内長野市南花台');
ok($zip->set_number('5860081')->is_valid_number, '大阪府河内長野市緑ケ丘北町');
ok($zip->set_number('5860082')->is_valid_number, '大阪府河内長野市緑ケ丘中町');
ok($zip->set_number('5860083')->is_valid_number, '大阪府河内長野市緑ケ丘南町');
ok($zip->set_number('5860084')->is_valid_number, '大阪府河内長野市旭ケ丘');
ok($zip->set_number('5860085')->is_valid_number, '大阪府河内長野市日野');
ok($zip->set_number('5860086')->is_valid_number, '大阪府河内長野市天野町');
ok($zip->set_number('5860087')->is_valid_number, '大阪府河内長野市下里町');
ok($zip->set_number('5860091')->is_valid_number, '大阪府河内長野市北貴望ケ丘');
ok($zip->set_number('5860092')->is_valid_number, '大阪府河内長野市南貴望ケ丘');
ok($zip->set_number('5860093')->is_valid_number, '大阪府河内長野市荘園町');
ok($zip->set_number('5860094')->is_valid_number, '大阪府河内長野市小山田町');
ok($zip->set_number('5860095')->is_valid_number, '大阪府河内長野市あかしあ台');
ok($zip->set_number('5860096')->is_valid_number, '大阪府河内長野市自由ケ丘');
ok($zip->set_number('5860097')->is_valid_number, '大阪府河内長野市桐ケ丘');
ok($zip->set_number('5870000')->is_valid_number, '大阪府堺市美原区以下に掲載がない場合');
ok($zip->set_number('5870001')->is_valid_number, '大阪府堺市美原区大保');
ok($zip->set_number('5870002')->is_valid_number, '大阪府堺市美原区黒山');
ok($zip->set_number('5870003')->is_valid_number, '大阪府堺市美原区阿弥');
ok($zip->set_number('5870011')->is_valid_number, '大阪府堺市美原区丹上');
ok($zip->set_number('5870012')->is_valid_number, '大阪府堺市美原区多治井');
ok($zip->set_number('5870013')->is_valid_number, '大阪府堺市美原区真福寺');
ok($zip->set_number('5870014')->is_valid_number, '大阪府堺市美原区丹南');
ok($zip->set_number('5870021')->is_valid_number, '大阪府堺市美原区小平尾');
ok($zip->set_number('5870022')->is_valid_number, '大阪府堺市美原区平尾');
ok($zip->set_number('5870031')->is_valid_number, '大阪府堺市美原区さつき野西');
ok($zip->set_number('5870032')->is_valid_number, '大阪府堺市美原区さつき野東');
ok($zip->set_number('5870041')->is_valid_number, '大阪府堺市美原区菅生');
ok($zip->set_number('5870042')->is_valid_number, '大阪府堺市美原区木材通');
ok($zip->set_number('5870043')->is_valid_number, '大阪府堺市美原区青南台');
ok($zip->set_number('5870051')->is_valid_number, '大阪府堺市美原区北余部');
ok($zip->set_number('5870052')->is_valid_number, '大阪府堺市美原区南余部');
ok($zip->set_number('5870053')->is_valid_number, '大阪府堺市美原区北余部西');
ok($zip->set_number('5870054')->is_valid_number, '大阪府堺市美原区南余部西');
ok($zip->set_number('5870061')->is_valid_number, '大阪府堺市美原区今井');
ok($zip->set_number('5870062')->is_valid_number, '大阪府堺市美原区太井');
ok($zip->set_number('5870063')->is_valid_number, '大阪府堺市美原区大饗');
ok($zip->set_number('5870064')->is_valid_number, '大阪府堺市美原区菩提');
ok($zip->set_number('5870065')->is_valid_number, '大阪府堺市美原区小寺');
ok($zip->set_number('5870066')->is_valid_number, '大阪府堺市美原区石原');
ok($zip->set_number('5890000')->is_valid_number, '大阪府大阪狭山市以下に掲載がない場合');
ok($zip->set_number('5890001')->is_valid_number, '大阪府大阪狭山市東野西');
ok($zip->set_number('5890002')->is_valid_number, '大阪府大阪狭山市東野中');
ok($zip->set_number('5890003')->is_valid_number, '大阪府大阪狭山市東野東');
ok($zip->set_number('5890004')->is_valid_number, '大阪府大阪狭山市東池尻');
ok($zip->set_number('5890005')->is_valid_number, '大阪府大阪狭山市狭山');
ok($zip->set_number('5890006')->is_valid_number, '大阪府大阪狭山市金剛');
ok($zip->set_number('5890007')->is_valid_number, '大阪府大阪狭山市池尻中');
ok($zip->set_number('5890008')->is_valid_number, '大阪府大阪狭山市池尻自由丘');
ok($zip->set_number('5890009')->is_valid_number, '大阪府大阪狭山市池尻北');
ok($zip->set_number('5890011')->is_valid_number, '大阪府大阪狭山市半田');
ok($zip->set_number('5890012')->is_valid_number, '大阪府大阪狭山市東茱萸木');
ok($zip->set_number('5890013')->is_valid_number, '大阪府大阪狭山市茱萸木');
ok($zip->set_number('5890014')->is_valid_number, '大阪府大阪狭山市大野東');
ok($zip->set_number('5890015')->is_valid_number, '大阪府大阪狭山市大野中');
ok($zip->set_number('5890016')->is_valid_number, '大阪府大阪狭山市大野西');
ok($zip->set_number('5890021')->is_valid_number, '大阪府大阪狭山市今熊');
ok($zip->set_number('5890022')->is_valid_number, '大阪府大阪狭山市西山台');
ok($zip->set_number('5890023')->is_valid_number, '大阪府大阪狭山市大野台');
ok($zip->set_number('5890031')->is_valid_number, '大阪府大阪狭山市池之原');
ok($zip->set_number('5890032')->is_valid_number, '大阪府大阪狭山市岩室');
ok($zip->set_number('5890033')->is_valid_number, '大阪府大阪狭山市山本南');
ok($zip->set_number('5890034')->is_valid_number, '大阪府大阪狭山市山本中');
ok($zip->set_number('5890035')->is_valid_number, '大阪府大阪狭山市山本北');
ok($zip->set_number('5890036')->is_valid_number, '大阪府大阪狭山市山本東');
ok($zip->set_number('5900000')->is_valid_number, '大阪府堺市堺区以下に掲載がない場合');
ok($zip->set_number('5900001')->is_valid_number, '大阪府堺市堺区遠里小野町');
ok($zip->set_number('5900002')->is_valid_number, '大阪府堺市堺区砂道町');
ok($zip->set_number('5900003')->is_valid_number, '大阪府堺市堺区高須町');
ok($zip->set_number('5900004')->is_valid_number, '大阪府堺市堺区北清水町');
ok($zip->set_number('5900005')->is_valid_number, '大阪府堺市堺区南清水町');
ok($zip->set_number('5900006')->is_valid_number, '大阪府堺市堺区錦綾町');
ok($zip->set_number('5900007')->is_valid_number, '大阪府堺市堺区北庄町');
ok($zip->set_number('5900008')->is_valid_number, '大阪府堺市堺区南庄町');
ok($zip->set_number('5900011')->is_valid_number, '大阪府堺市堺区香ケ丘町');
ok($zip->set_number('5900012')->is_valid_number, '大阪府堺市堺区浅香山町');
ok($zip->set_number('5900013')->is_valid_number, '大阪府堺市堺区東雲西町');
ok($zip->set_number('5900014')->is_valid_number, '大阪府堺市堺区田出井町');
ok($zip->set_number('5900015')->is_valid_number, '大阪府堺市堺区南田出井町');
ok($zip->set_number('5900016')->is_valid_number, '大阪府堺市堺区中田出井町');
ok($zip->set_number('5900017')->is_valid_number, '大阪府堺市堺区北田出井町');
ok($zip->set_number('5900018')->is_valid_number, '大阪府堺市堺区今池町');
ok($zip->set_number('5900021')->is_valid_number, '大阪府堺市堺区北三国ケ丘町');
ok($zip->set_number('5900022')->is_valid_number, '大阪府堺市堺区中三国ケ丘町');
ok($zip->set_number('5900023')->is_valid_number, '大阪府堺市堺区南三国ケ丘町');
ok($zip->set_number('5900024')->is_valid_number, '大阪府堺市堺区向陵中町');
ok($zip->set_number('5900025')->is_valid_number, '大阪府堺市堺区向陵東町');
ok($zip->set_number('5900026')->is_valid_number, '大阪府堺市堺区向陵西町');
ok($zip->set_number('5900027')->is_valid_number, '大阪府堺市堺区榎元町');
ok($zip->set_number('5900028')->is_valid_number, '大阪府堺市堺区三国ケ丘御幸通');
ok($zip->set_number('5900031')->is_valid_number, '大阪府堺市堺区五月町');
ok($zip->set_number('5900032')->is_valid_number, '大阪府堺市堺区西永山園');
ok($zip->set_number('5900033')->is_valid_number, '大阪府堺市堺区中永山園');
ok($zip->set_number('5900034')->is_valid_number, '大阪府堺市堺区東永山園');
ok($zip->set_number('5900035')->is_valid_number, '大阪府堺市堺区大仙町');
ok($zip->set_number('5900036')->is_valid_number, '大阪府堺市堺区南丸保園');
ok($zip->set_number('5900037')->is_valid_number, '大阪府堺市堺区北丸保園');
ok($zip->set_number('5900041')->is_valid_number, '大阪府堺市堺区陵西通');
ok($zip->set_number('5900042')->is_valid_number, '大阪府堺市堺区七条通');
ok($zip->set_number('5900043')->is_valid_number, '大阪府堺市堺区六条通');
ok($zip->set_number('5900044')->is_valid_number, '大阪府堺市堺区五条通');
ok($zip->set_number('5900045')->is_valid_number, '大阪府堺市堺区四条通');
ok($zip->set_number('5900046')->is_valid_number, '大阪府堺市堺区三条通');
ok($zip->set_number('5900047')->is_valid_number, '大阪府堺市堺区二条通');
ok($zip->set_number('5900048')->is_valid_number, '大阪府堺市堺区一条通');
ok($zip->set_number('5900051')->is_valid_number, '大阪府堺市堺区幸通');
ok($zip->set_number('5900052')->is_valid_number, '大阪府堺市堺区八千代通');
ok($zip->set_number('5900053')->is_valid_number, '大阪府堺市堺区文珠橋通');
ok($zip->set_number('5900054')->is_valid_number, '大阪府堺市堺区京町通');
ok($zip->set_number('5900055')->is_valid_number, '大阪府堺市堺区旭通');
ok($zip->set_number('5900056')->is_valid_number, '大阪府堺市堺区神保通');
ok($zip->set_number('5900057')->is_valid_number, '大阪府堺市堺区御陵通');
ok($zip->set_number('5900061')->is_valid_number, '大阪府堺市堺区翁橋町');
ok($zip->set_number('5900062')->is_valid_number, '大阪府堺市堺区北安井町');
ok($zip->set_number('5900063')->is_valid_number, '大阪府堺市堺区中安井町');
ok($zip->set_number('5900064')->is_valid_number, '大阪府堺市堺区南安井町');
ok($zip->set_number('5900065')->is_valid_number, '大阪府堺市堺区永代町');
ok($zip->set_number('5900066')->is_valid_number, '大阪府堺市堺区賑町');
ok($zip->set_number('5900071')->is_valid_number, '大阪府堺市堺区北向陽町');
ok($zip->set_number('5900072')->is_valid_number, '大阪府堺市堺区中向陽町');
ok($zip->set_number('5900073')->is_valid_number, '大阪府堺市堺区南向陽町');
ok($zip->set_number('5900074')->is_valid_number, '大阪府堺市堺区北花田口町');
ok($zip->set_number('5900075')->is_valid_number, '大阪府堺市堺区南花田口町');
ok($zip->set_number('5900076')->is_valid_number, '大阪府堺市堺区北瓦町');
ok($zip->set_number('5900077')->is_valid_number, '大阪府堺市堺区中瓦町');
ok($zip->set_number('5900078')->is_valid_number, '大阪府堺市堺区南瓦町');
ok($zip->set_number('5900079')->is_valid_number, '大阪府堺市堺区新町');
ok($zip->set_number('5900100')->is_valid_number, '大阪府堺市南区以下に掲載がない場合');
ok($zip->set_number('5900101')->is_valid_number, '大阪府堺市南区宮山台');
ok($zip->set_number('5900102')->is_valid_number, '大阪府堺市南区和田東');
ok($zip->set_number('5900103')->is_valid_number, '大阪府堺市南区深阪南');
ok($zip->set_number('5900104')->is_valid_number, '大阪府堺市南区土佐屋台');
ok($zip->set_number('5900105')->is_valid_number, '大阪府堺市南区竹城台');
ok($zip->set_number('5900106')->is_valid_number, '大阪府堺市南区豊田');
ok($zip->set_number('5900111')->is_valid_number, '大阪府堺市南区三原台');
ok($zip->set_number('5900112')->is_valid_number, '大阪府堺市南区岩室');
ok($zip->set_number('5900113')->is_valid_number, '大阪府堺市南区晴美台');
ok($zip->set_number('5900114')->is_valid_number, '大阪府堺市南区槇塚台');
ok($zip->set_number('5900115')->is_valid_number, '大阪府堺市南区茶山台');
ok($zip->set_number('5900116')->is_valid_number, '大阪府堺市南区若松台');
ok($zip->set_number('5900117')->is_valid_number, '大阪府堺市南区高倉台');
ok($zip->set_number('5900121')->is_valid_number, '大阪府堺市南区片蔵');
ok($zip->set_number('5900122')->is_valid_number, '大阪府堺市南区釜室');
ok($zip->set_number('5900123')->is_valid_number, '大阪府堺市南区逆瀬川');
ok($zip->set_number('5900124')->is_valid_number, '大阪府堺市南区畑');
ok($zip->set_number('5900125')->is_valid_number, '大阪府堺市南区鉢ケ峯寺');
ok($zip->set_number('5900126')->is_valid_number, '大阪府堺市南区泉田中');
ok($zip->set_number('5900127')->is_valid_number, '大阪府堺市南区富蔵');
ok($zip->set_number('5900131')->is_valid_number, '大阪府堺市南区栂');
ok($zip->set_number('5900132')->is_valid_number, '大阪府堺市南区原山台');
ok($zip->set_number('5900133')->is_valid_number, '大阪府堺市南区庭代台');
ok($zip->set_number('5900134')->is_valid_number, '大阪府堺市南区御池台');
ok($zip->set_number('5900135')->is_valid_number, '大阪府堺市南区別所');
ok($zip->set_number('5900136')->is_valid_number, '大阪府堺市南区美木多上');
ok($zip->set_number('5900137')->is_valid_number, '大阪府堺市南区城山台');
ok($zip->set_number('5900138')->is_valid_number, '大阪府堺市南区鴨谷台');
ok($zip->set_number('5900141')->is_valid_number, '大阪府堺市南区桃山台');
ok($zip->set_number('5900142')->is_valid_number, '大阪府堺市南区檜尾');
ok($zip->set_number('5900143')->is_valid_number, '大阪府堺市南区新檜尾台');
ok($zip->set_number('5900144')->is_valid_number, '大阪府堺市南区赤坂台');
ok($zip->set_number('5900145')->is_valid_number, '大阪府堺市南区大森');
ok($zip->set_number('5900151')->is_valid_number, '大阪府堺市南区小代(その他)');
ok($zip->set_number('5900152')->is_valid_number, '大阪府堺市南区和田');
ok($zip->set_number('5900153')->is_valid_number, '大阪府堺市南区大庭寺');
ok($zip->set_number('5900154')->is_valid_number, '大阪府堺市南区三木閉');
ok($zip->set_number('5900155')->is_valid_number, '大阪府堺市南区野々井');
ok($zip->set_number('5900156')->is_valid_number, '大阪府堺市南区稲葉');
ok($zip->set_number('5900157')->is_valid_number, '大阪府堺市南区高尾');
ok($zip->set_number('5900158')->is_valid_number, '大阪府堺市南区太平寺(508-5、696-2~696-3、724-1、725-1、');
ok($zip->set_number('5900158')->is_valid_number, '大阪府堺市南区726-1、727、728、728-1、729、730、731、732、');
ok($zip->set_number('5900158')->is_valid_number, '大阪府堺市南区733-1~733-2、735、786-3番地)');
ok($zip->set_number('5900400')->is_valid_number, '大阪府泉南郡熊取町以下に掲載がない場合');
ok($zip->set_number('5900401')->is_valid_number, '大阪府泉南郡熊取町大久保');
ok($zip->set_number('5900402')->is_valid_number, '大阪府泉南郡熊取町大久保北');
ok($zip->set_number('5900403')->is_valid_number, '大阪府泉南郡熊取町大久保中');
ok($zip->set_number('5900404')->is_valid_number, '大阪府泉南郡熊取町大久保西');
ok($zip->set_number('5900405')->is_valid_number, '大阪府泉南郡熊取町大久保南');
ok($zip->set_number('5900406')->is_valid_number, '大阪府泉南郡熊取町大久保東');
ok($zip->set_number('5900407')->is_valid_number, '大阪府泉南郡熊取町青葉台');
ok($zip->set_number('5900411')->is_valid_number, '大阪府泉南郡熊取町五門');
ok($zip->set_number('5900412')->is_valid_number, '大阪府泉南郡熊取町紺屋');
ok($zip->set_number('5900413')->is_valid_number, '大阪府泉南郡熊取町桜が丘');
ok($zip->set_number('5900414')->is_valid_number, '大阪府泉南郡熊取町五門東');
ok($zip->set_number('5900415')->is_valid_number, '大阪府泉南郡熊取町五門西');
ok($zip->set_number('5900416')->is_valid_number, '大阪府泉南郡熊取町東和苑');
ok($zip->set_number('5900417')->is_valid_number, '大阪府泉南郡熊取町和田');
ok($zip->set_number('5900421')->is_valid_number, '大阪府泉南郡熊取町七山');
ok($zip->set_number('5900422')->is_valid_number, '大阪府泉南郡熊取町希望が丘');
ok($zip->set_number('5900423')->is_valid_number, '大阪府泉南郡熊取町自由が丘');
ok($zip->set_number('5900424')->is_valid_number, '大阪府泉南郡熊取町七山北');
ok($zip->set_number('5900425')->is_valid_number, '大阪府泉南郡熊取町七山東');
ok($zip->set_number('5900426')->is_valid_number, '大阪府泉南郡熊取町七山南');
ok($zip->set_number('5900427')->is_valid_number, '大阪府泉南郡熊取町七山西');
ok($zip->set_number('5900431')->is_valid_number, '大阪府泉南郡熊取町小谷');
ok($zip->set_number('5900432')->is_valid_number, '大阪府泉南郡熊取町小垣内');
ok($zip->set_number('5900433')->is_valid_number, '大阪府泉南郡熊取町若葉');
ok($zip->set_number('5900434')->is_valid_number, '大阪府泉南郡熊取町小谷北');
ok($zip->set_number('5900435')->is_valid_number, '大阪府泉南郡熊取町小谷南');
ok($zip->set_number('5900436')->is_valid_number, '大阪府泉南郡熊取町高田');
ok($zip->set_number('5900441')->is_valid_number, '大阪府泉南郡熊取町久保');
ok($zip->set_number('5900442')->is_valid_number, '大阪府泉南郡熊取町つばさが丘東');
ok($zip->set_number('5900443')->is_valid_number, '大阪府泉南郡熊取町つばさが丘西');
ok($zip->set_number('5900444')->is_valid_number, '大阪府泉南郡熊取町つばさが丘北');
ok($zip->set_number('5900445')->is_valid_number, '大阪府泉南郡熊取町五月ケ丘');
ok($zip->set_number('5900446')->is_valid_number, '大阪府泉南郡熊取町成合北');
ok($zip->set_number('5900447')->is_valid_number, '大阪府泉南郡熊取町成合東');
ok($zip->set_number('5900448')->is_valid_number, '大阪府泉南郡熊取町成合南');
ok($zip->set_number('5900449')->is_valid_number, '大阪府泉南郡熊取町成合西');
ok($zip->set_number('5900450')->is_valid_number, '大阪府泉南郡熊取町大宮');
ok($zip->set_number('5900451')->is_valid_number, '大阪府泉南郡熊取町野田');
ok($zip->set_number('5900452')->is_valid_number, '大阪府泉南郡熊取町山の手台');
ok($zip->set_number('5900453')->is_valid_number, '大阪府泉南郡熊取町南山の手台');
ok($zip->set_number('5900454')->is_valid_number, '大阪府泉南郡熊取町新野田');
ok($zip->set_number('5900455')->is_valid_number, '大阪府泉南郡熊取町長池');
ok($zip->set_number('5900456')->is_valid_number, '大阪府泉南郡熊取町美熊台');
ok($zip->set_number('5900457')->is_valid_number, '大阪府泉南郡熊取町朝代東');
ok($zip->set_number('5900458')->is_valid_number, '大阪府泉南郡熊取町朝代西');
ok($zip->set_number('5900459')->is_valid_number, '大阪府泉南郡熊取町朝代台');
ok($zip->set_number('5900461')->is_valid_number, '大阪府貝塚市三ツ松(2576番地)');
ok($zip->set_number('5900500')->is_valid_number, '大阪府泉南市以下に掲載がない場合');
ok($zip->set_number('5900501')->is_valid_number, '大阪府泉南市兎田');
ok($zip->set_number('5900502')->is_valid_number, '大阪府泉南市別所');
ok($zip->set_number('5900503')->is_valid_number, '大阪府泉南市新家');
ok($zip->set_number('5900504')->is_valid_number, '大阪府泉南市信達市場');
ok($zip->set_number('5900505')->is_valid_number, '大阪府泉南市信達大苗代');
ok($zip->set_number('5900511')->is_valid_number, '大阪府泉南市信達葛畑');
ok($zip->set_number('5900512')->is_valid_number, '大阪府泉南市信達童子畑');
ok($zip->set_number('5900513')->is_valid_number, '大阪府泉南市信達楠畑');
ok($zip->set_number('5900514')->is_valid_number, '大阪府泉南市信達金熊寺');
ok($zip->set_number('5900515')->is_valid_number, '大阪府泉南市信達六尾');
ok($zip->set_number('5900521')->is_valid_number, '大阪府泉南市樽井');
ok($zip->set_number('5900522')->is_valid_number, '大阪府泉南市信達牧野');
ok($zip->set_number('5900523')->is_valid_number, '大阪府泉南市信達岡中');
ok($zip->set_number('5900524')->is_valid_number, '大阪府泉南市幡代');
ok($zip->set_number('5900525')->is_valid_number, '大阪府泉南市馬場');
ok($zip->set_number('5900526')->is_valid_number, '大阪府泉南市男里');
ok($zip->set_number('5900531')->is_valid_number, '大阪府泉南市岡田');
ok($zip->set_number('5900532')->is_valid_number, '大阪府泉南市北野');
ok($zip->set_number('5900533')->is_valid_number, '大阪府泉南市中小路');
ok($zip->set_number('5900534')->is_valid_number, '大阪府泉南市鳴滝');
ok($zip->set_number('5900535')->is_valid_number, '大阪府泉南市りんくう南浜');
ok($zip->set_number('5900801')->is_valid_number, '大阪府堺市堺区大仙中町');
ok($zip->set_number('5900802')->is_valid_number, '大阪府堺市堺区百舌鳥夕雲町');
ok($zip->set_number('5900803')->is_valid_number, '大阪府堺市堺区東上野芝町(1丁)');
ok($zip->set_number('5900804')->is_valid_number, '大阪府堺市堺区緑ヶ丘南町');
ok($zip->set_number('5900805')->is_valid_number, '大阪府堺市堺区緑ヶ丘中町');
ok($zip->set_number('5900806')->is_valid_number, '大阪府堺市堺区緑ヶ丘北町');
ok($zip->set_number('5900807')->is_valid_number, '大阪府堺市堺区旭ケ丘南町');
ok($zip->set_number('5900808')->is_valid_number, '大阪府堺市堺区旭ケ丘中町');
ok($zip->set_number('5900809')->is_valid_number, '大阪府堺市堺区旭ケ丘北町');
ok($zip->set_number('5900811')->is_valid_number, '大阪府堺市堺区南陵町');
ok($zip->set_number('5900812')->is_valid_number, '大阪府堺市堺区霞ケ丘町');
ok($zip->set_number('5900813')->is_valid_number, '大阪府堺市堺区神石市之町');
ok($zip->set_number('5900814')->is_valid_number, '大阪府堺市堺区石津町');
ok($zip->set_number('5900820')->is_valid_number, '大阪府堺市堺区高砂町');
ok($zip->set_number('5900821')->is_valid_number, '大阪府堺市堺区大仙西町');
ok($zip->set_number('5900822')->is_valid_number, '大阪府堺市堺区協和町');
ok($zip->set_number('5900823')->is_valid_number, '大阪府堺市堺区石津北町');
ok($zip->set_number('5900824')->is_valid_number, '大阪府堺市堺区老松町');
ok($zip->set_number('5900825')->is_valid_number, '大阪府堺市堺区昭和通');
ok($zip->set_number('5900826')->is_valid_number, '大阪府堺市堺区菅原通');
ok($zip->set_number('5900827')->is_valid_number, '大阪府堺市堺区春日通');
ok($zip->set_number('5900828')->is_valid_number, '大阪府堺市堺区八幡通');
ok($zip->set_number('5900829')->is_valid_number, '大阪府堺市堺区東湊町');
ok($zip->set_number('5900831')->is_valid_number, '大阪府堺市堺区出島西町');
ok($zip->set_number('5900832')->is_valid_number, '大阪府堺市堺区出島浜通');
ok($zip->set_number('5900833')->is_valid_number, '大阪府堺市堺区出島海岸通');
ok($zip->set_number('5900834')->is_valid_number, '大阪府堺市堺区出島町');
ok($zip->set_number('5900835')->is_valid_number, '大阪府堺市堺区西湊町');
ok($zip->set_number('5900836')->is_valid_number, '大阪府堺市堺区楠町');
ok($zip->set_number('5900837')->is_valid_number, '大阪府堺市堺区柏木町');
ok($zip->set_number('5900901')->is_valid_number, '大阪府堺市堺区築港八幡町');
ok($zip->set_number('5900902')->is_valid_number, '大阪府堺市堺区松屋大和川通');
ok($zip->set_number('5900903')->is_valid_number, '大阪府堺市堺区松屋町');
ok($zip->set_number('5900904')->is_valid_number, '大阪府堺市堺区南島町');
ok($zip->set_number('5900905')->is_valid_number, '大阪府堺市堺区鉄砲町');
ok($zip->set_number('5900906')->is_valid_number, '大阪府堺市堺区三宝町');
ok($zip->set_number('5900907')->is_valid_number, '大阪府堺市堺区緑町');
ok($zip->set_number('5900908')->is_valid_number, '大阪府堺市堺区匠町');
ok($zip->set_number('5900911')->is_valid_number, '大阪府堺市堺区七道西町');
ok($zip->set_number('5900912')->is_valid_number, '大阪府堺市堺区並松町');
ok($zip->set_number('5900913')->is_valid_number, '大阪府堺市堺区七道東町');
ok($zip->set_number('5900921')->is_valid_number, '大阪府堺市堺区北半町西');
ok($zip->set_number('5900922')->is_valid_number, '大阪府堺市堺区北半町東');
ok($zip->set_number('5900923')->is_valid_number, '大阪府堺市堺区北旅籠町東');
ok($zip->set_number('5900924')->is_valid_number, '大阪府堺市堺区桜之町東');
ok($zip->set_number('5900925')->is_valid_number, '大阪府堺市堺区綾之町東');
ok($zip->set_number('5900926')->is_valid_number, '大阪府堺市堺区綾之町西');
ok($zip->set_number('5900927')->is_valid_number, '大阪府堺市堺区桜之町西');
ok($zip->set_number('5900928')->is_valid_number, '大阪府堺市堺区北旅籠町西');
ok($zip->set_number('5900930')->is_valid_number, '大阪府堺市堺区柳之町西');
ok($zip->set_number('5900931')->is_valid_number, '大阪府堺市堺区錦之町西');
ok($zip->set_number('5900932')->is_valid_number, '大阪府堺市堺区錦之町東');
ok($zip->set_number('5900933')->is_valid_number, '大阪府堺市堺区柳之町東');
ok($zip->set_number('5900934')->is_valid_number, '大阪府堺市堺区九間町東');
ok($zip->set_number('5900935')->is_valid_number, '大阪府堺市堺区神明町東');
ok($zip->set_number('5900936')->is_valid_number, '大阪府堺市堺区宿屋町東');
ok($zip->set_number('5900937')->is_valid_number, '大阪府堺市堺区宿屋町西');
ok($zip->set_number('5900938')->is_valid_number, '大阪府堺市堺区神明町西');
ok($zip->set_number('5900939')->is_valid_number, '大阪府堺市堺区九間町西');
ok($zip->set_number('5900940')->is_valid_number, '大阪府堺市堺区車之町西');
ok($zip->set_number('5900941')->is_valid_number, '大阪府堺市堺区材木町西');
ok($zip->set_number('5900942')->is_valid_number, '大阪府堺市堺区材木町東');
ok($zip->set_number('5900943')->is_valid_number, '大阪府堺市堺区車之町東');
ok($zip->set_number('5900944')->is_valid_number, '大阪府堺市堺区櫛屋町東');
ok($zip->set_number('5900945')->is_valid_number, '大阪府堺市堺区戎之町東');
ok($zip->set_number('5900946')->is_valid_number, '大阪府堺市堺区熊野町東');
ok($zip->set_number('5900947')->is_valid_number, '大阪府堺市堺区熊野町西');
ok($zip->set_number('5900948')->is_valid_number, '大阪府堺市堺区戎之町西');
ok($zip->set_number('5900949')->is_valid_number, '大阪府堺市堺区櫛屋町西');
ok($zip->set_number('5900950')->is_valid_number, '大阪府堺市堺区甲斐町西');
ok($zip->set_number('5900951')->is_valid_number, '大阪府堺市堺区市之町西');
ok($zip->set_number('5900952')->is_valid_number, '大阪府堺市堺区市之町東');
ok($zip->set_number('5900953')->is_valid_number, '大阪府堺市堺区甲斐町東');
ok($zip->set_number('5900954')->is_valid_number, '大阪府堺市堺区大町東');
ok($zip->set_number('5900955')->is_valid_number, '大阪府堺市堺区宿院町東');
ok($zip->set_number('5900956')->is_valid_number, '大阪府堺市堺区中之町東');
ok($zip->set_number('5900957')->is_valid_number, '大阪府堺市堺区中之町西');
ok($zip->set_number('5900958')->is_valid_number, '大阪府堺市堺区宿院町西');
ok($zip->set_number('5900959')->is_valid_number, '大阪府堺市堺区大町西');
ok($zip->set_number('5900960')->is_valid_number, '大阪府堺市堺区少林寺町西');
ok($zip->set_number('5900961')->is_valid_number, '大阪府堺市堺区寺地町西');
ok($zip->set_number('5900962')->is_valid_number, '大阪府堺市堺区寺地町東');
ok($zip->set_number('5900963')->is_valid_number, '大阪府堺市堺区少林寺町東');
ok($zip->set_number('5900964')->is_valid_number, '大阪府堺市堺区新在家町東');
ok($zip->set_number('5900965')->is_valid_number, '大阪府堺市堺区南旅篭町東');
ok($zip->set_number('5900966')->is_valid_number, '大阪府堺市堺区南半町東');
ok($zip->set_number('5900967')->is_valid_number, '大阪府堺市堺区南半町西');
ok($zip->set_number('5900968')->is_valid_number, '大阪府堺市堺区南旅篭町西');
ok($zip->set_number('5900969')->is_valid_number, '大阪府堺市堺区新在家町西');
ok($zip->set_number('5900971')->is_valid_number, '大阪府堺市堺区栄橋町');
ok($zip->set_number('5900972')->is_valid_number, '大阪府堺市堺区竜神橋町');
ok($zip->set_number('5900973')->is_valid_number, '大阪府堺市堺区住吉橋町');
ok($zip->set_number('5900974')->is_valid_number, '大阪府堺市堺区大浜北町');
ok($zip->set_number('5900975')->is_valid_number, '大阪府堺市堺区大浜中町');
ok($zip->set_number('5900976')->is_valid_number, '大阪府堺市堺区大浜南町');
ok($zip->set_number('5900977')->is_valid_number, '大阪府堺市堺区大浜西町');
ok($zip->set_number('5900981')->is_valid_number, '大阪府堺市堺区塩浜町');
ok($zip->set_number('5900982')->is_valid_number, '大阪府堺市堺区海山町');
ok($zip->set_number('5900983')->is_valid_number, '大阪府堺市堺区山本町');
ok($zip->set_number('5900984')->is_valid_number, '大阪府堺市堺区神南辺町');
ok($zip->set_number('5900985')->is_valid_number, '大阪府堺市堺区戎島町');
ok($zip->set_number('5900986')->is_valid_number, '大阪府堺市堺区北波止町');
ok($zip->set_number('5900987')->is_valid_number, '大阪府堺市堺区築港南町');
ok($zip->set_number('5910000')->is_valid_number, '大阪府堺市北区以下に掲載がない場合');
ok($zip->set_number('5918001')->is_valid_number, '大阪府堺市北区常磐町');
ok($zip->set_number('5918002')->is_valid_number, '大阪府堺市北区北花田町');
ok($zip->set_number('5918003')->is_valid_number, '大阪府堺市北区船堂町');
ok($zip->set_number('5918004')->is_valid_number, '大阪府堺市北区蔵前町');
ok($zip->set_number('5918005')->is_valid_number, '大阪府堺市北区新堀町');
ok($zip->set_number('5918006')->is_valid_number, '大阪府堺市北区宮本町');
ok($zip->set_number('5918007')->is_valid_number, '大阪府堺市北区奥本町');
ok($zip->set_number('5918008')->is_valid_number, '大阪府堺市北区東浅香山町');
ok($zip->set_number('5918011')->is_valid_number, '大阪府堺市北区南花田町');
ok($zip->set_number('5918012')->is_valid_number, '大阪府堺市北区中村町');
ok($zip->set_number('5918013')->is_valid_number, '大阪府堺市北区野遠町');
ok($zip->set_number('5918014')->is_valid_number, '大阪府堺市北区八下北');
ok($zip->set_number('5918021')->is_valid_number, '大阪府堺市北区新金岡町');
ok($zip->set_number('5918022')->is_valid_number, '大阪府堺市北区金岡町');
ok($zip->set_number('5918023')->is_valid_number, '大阪府堺市北区中百舌鳥町');
ok($zip->set_number('5918024')->is_valid_number, '大阪府堺市北区黒土町');
ok($zip->set_number('5918025')->is_valid_number, '大阪府堺市北区長曽根町');
ok($zip->set_number('5918031')->is_valid_number, '大阪府堺市北区百舌鳥梅北町');
ok($zip->set_number('5918032')->is_valid_number, '大阪府堺市北区百舌鳥梅町');
ok($zip->set_number('5918033')->is_valid_number, '大阪府堺市北区百舌鳥西之町');
ok($zip->set_number('5918034')->is_valid_number, '大阪府堺市北区百舌鳥陵南町');
ok($zip->set_number('5918035')->is_valid_number, '大阪府堺市北区東上野芝町(2丁)');
ok($zip->set_number('5918036')->is_valid_number, '大阪府堺市北区百舌鳥本町');
ok($zip->set_number('5918037')->is_valid_number, '大阪府堺市北区百舌鳥赤畑町');
ok($zip->set_number('5918041')->is_valid_number, '大阪府堺市北区東雲東町');
ok($zip->set_number('5918042')->is_valid_number, '大阪府堺市北区大豆塚町');
ok($zip->set_number('5918043')->is_valid_number, '大阪府堺市北区北長尾町');
ok($zip->set_number('5918044')->is_valid_number, '大阪府堺市北区中長尾町');
ok($zip->set_number('5918045')->is_valid_number, '大阪府堺市北区南長尾町');
ok($zip->set_number('5918046')->is_valid_number, '大阪府堺市北区東三国ケ丘町');
ok($zip->set_number('5920000')->is_valid_number, '大阪府高石市以下に掲載がない場合');
ok($zip->set_number('5920001')->is_valid_number, '大阪府高石市高砂');
ok($zip->set_number('5920002')->is_valid_number, '大阪府高石市羽衣');
ok($zip->set_number('5920002')->is_valid_number, '大阪府高石市羽衣公園丁');
ok($zip->set_number('5920003')->is_valid_number, '大阪府高石市東羽衣');
ok($zip->set_number('5920004')->is_valid_number, '大阪府高石市高師浜');
ok($zip->set_number('5920005')->is_valid_number, '大阪府高石市千代田');
ok($zip->set_number('5920006')->is_valid_number, '大阪府高石市高師浜丁');
ok($zip->set_number('5920011')->is_valid_number, '大阪府高石市加茂');
ok($zip->set_number('5920012')->is_valid_number, '大阪府高石市西取石');
ok($zip->set_number('5920013')->is_valid_number, '大阪府高石市取石');
ok($zip->set_number('5920014')->is_valid_number, '大阪府高石市綾園');
ok($zip->set_number('5928331')->is_valid_number, '大阪府堺市西区築港新町');
ok($zip->set_number('5928332')->is_valid_number, '大阪府堺市西区石津西町');
ok($zip->set_number('5928333')->is_valid_number, '大阪府堺市西区浜寺石津町西');
ok($zip->set_number('5928334')->is_valid_number, '大阪府堺市西区浜寺石津町中');
ok($zip->set_number('5928335')->is_valid_number, '大阪府堺市西区浜寺石津町東');
ok($zip->set_number('5928341')->is_valid_number, '大阪府堺市西区浜寺船尾町東');
ok($zip->set_number('5928342')->is_valid_number, '大阪府堺市西区浜寺船尾町西');
ok($zip->set_number('5928343')->is_valid_number, '大阪府堺市西区浜寺元町');
ok($zip->set_number('5928344')->is_valid_number, '大阪府堺市西区浜寺南町');
ok($zip->set_number('5928345')->is_valid_number, '大阪府堺市西区浜寺昭和町');
ok($zip->set_number('5928346')->is_valid_number, '大阪府堺市西区浜寺公園町');
ok($zip->set_number('5928347')->is_valid_number, '大阪府堺市西区浜寺諏訪森町西');
ok($zip->set_number('5928348')->is_valid_number, '大阪府堺市西区浜寺諏訪森町中');
ok($zip->set_number('5928349')->is_valid_number, '大阪府堺市西区浜寺諏訪森町東');
ok($zip->set_number('5928351')->is_valid_number, '大阪府堺市西区築港浜寺町');
ok($zip->set_number('5928352')->is_valid_number, '大阪府堺市西区築港浜寺西町');
ok($zip->set_number('5930000')->is_valid_number, '大阪府堺市西区以下に掲載がない場合');
ok($zip->set_number('5938301')->is_valid_number, '大阪府堺市西区上野芝町');
ok($zip->set_number('5938302')->is_valid_number, '大阪府堺市西区北条町');
ok($zip->set_number('5938303')->is_valid_number, '大阪府堺市西区上野芝向ケ丘町');
ok($zip->set_number('5938304')->is_valid_number, '大阪府堺市西区家原寺町');
ok($zip->set_number('5938305')->is_valid_number, '大阪府堺市西区堀上緑町');
ok($zip->set_number('5938306')->is_valid_number, '大阪府堺市西区八田寺町(40-1~40-3番地)');
ok($zip->set_number('5938307')->is_valid_number, '大阪府堺市西区平岡町');
ok($zip->set_number('5938308')->is_valid_number, '大阪府堺市西区神野町');
ok($zip->set_number('5938311')->is_valid_number, '大阪府堺市西区上');
ok($zip->set_number('5938312')->is_valid_number, '大阪府堺市西区草部');
ok($zip->set_number('5938313')->is_valid_number, '大阪府堺市西区小代(292-1番地)');
ok($zip->set_number('5938314')->is_valid_number, '大阪府堺市西区太平寺(その他)');
ok($zip->set_number('5938315')->is_valid_number, '大阪府堺市西区菱木');
ok($zip->set_number('5938316')->is_valid_number, '大阪府堺市西区山田');
ok($zip->set_number('5938317')->is_valid_number, '大阪府堺市西区原田');
ok($zip->set_number('5938321')->is_valid_number, '大阪府堺市西区宮下町');
ok($zip->set_number('5938322')->is_valid_number, '大阪府堺市西区津久野町');
ok($zip->set_number('5938323')->is_valid_number, '大阪府堺市西区鶴田町');
ok($zip->set_number('5938324')->is_valid_number, '大阪府堺市西区鳳東町');
ok($zip->set_number('5938325')->is_valid_number, '大阪府堺市西区鳳南町');
ok($zip->set_number('5938326')->is_valid_number, '大阪府堺市西区鳳西町');
ok($zip->set_number('5938327')->is_valid_number, '大阪府堺市西区鳳中町');
ok($zip->set_number('5938328')->is_valid_number, '大阪府堺市西区鳳北町');
ok($zip->set_number('5938329')->is_valid_number, '大阪府堺市西区下田町');
ok($zip->set_number('5940000')->is_valid_number, '大阪府和泉市以下に掲載がない場合');
ok($zip->set_number('5940001')->is_valid_number, '大阪府和泉市舞町');
ok($zip->set_number('5940002')->is_valid_number, '大阪府和泉市上町');
ok($zip->set_number('5940003')->is_valid_number, '大阪府和泉市太町');
ok($zip->set_number('5940004')->is_valid_number, '大阪府和泉市王子町');
ok($zip->set_number('5940005')->is_valid_number, '大阪府和泉市幸');
ok($zip->set_number('5940006')->is_valid_number, '大阪府和泉市尾井町');
ok($zip->set_number('5940011')->is_valid_number, '大阪府和泉市上代町');
ok($zip->set_number('5940012')->is_valid_number, '大阪府和泉市小野町');
ok($zip->set_number('5940013')->is_valid_number, '大阪府和泉市鶴山台');
ok($zip->set_number('5940021')->is_valid_number, '大阪府和泉市山荘町');
ok($zip->set_number('5940022')->is_valid_number, '大阪府和泉市黒鳥町');
ok($zip->set_number('5940023')->is_valid_number, '大阪府和泉市伯太町');
ok($zip->set_number('5940031')->is_valid_number, '大阪府和泉市伏屋町');
ok($zip->set_number('5940032')->is_valid_number, '大阪府和泉市池田下町');
ok($zip->set_number('5940041')->is_valid_number, '大阪府和泉市いぶき野');
ok($zip->set_number('5940042')->is_valid_number, '大阪府和泉市箕形町');
ok($zip->set_number('5940051')->is_valid_number, '大阪府和泉市東阪本町');
ok($zip->set_number('5940052')->is_valid_number, '大阪府和泉市阪本町');
ok($zip->set_number('5940053')->is_valid_number, '大阪府和泉市芦部町');
ok($zip->set_number('5940054')->is_valid_number, '大阪府和泉市一条院町');
ok($zip->set_number('5940061')->is_valid_number, '大阪府和泉市弥生町');
ok($zip->set_number('5940062')->is_valid_number, '大阪府和泉市寺田町');
ok($zip->set_number('5940063')->is_valid_number, '大阪府和泉市今福町');
ok($zip->set_number('5940064')->is_valid_number, '大阪府和泉市寺門町');
ok($zip->set_number('5940065')->is_valid_number, '大阪府和泉市観音寺町');
ok($zip->set_number('5940066')->is_valid_number, '大阪府和泉市桑原町');
ok($zip->set_number('5940071')->is_valid_number, '大阪府和泉市府中町');
ok($zip->set_number('5940072')->is_valid_number, '大阪府和泉市井ノ口町');
ok($zip->set_number('5940073')->is_valid_number, '大阪府和泉市和気町');
ok($zip->set_number('5940074')->is_valid_number, '大阪府和泉市小田町');
ok($zip->set_number('5940075')->is_valid_number, '大阪府和泉市繁和町');
ok($zip->set_number('5940076')->is_valid_number, '大阪府和泉市肥子町');
ok($zip->set_number('5940081')->is_valid_number, '大阪府和泉市葛の葉町');
ok($zip->set_number('5940082')->is_valid_number, '大阪府和泉市富秋町');
ok($zip->set_number('5940083')->is_valid_number, '大阪府和泉市池上町');
ok($zip->set_number('5941101')->is_valid_number, '大阪府和泉市室堂町');
ok($zip->set_number('5941102')->is_valid_number, '大阪府和泉市和田町');
ok($zip->set_number('5941103')->is_valid_number, '大阪府和泉市浦田町');
ok($zip->set_number('5941104')->is_valid_number, '大阪府和泉市万町');
ok($zip->set_number('5941105')->is_valid_number, '大阪府和泉市のぞみ野');
ok($zip->set_number('5941106')->is_valid_number, '大阪府和泉市はつが野');
ok($zip->set_number('5941111')->is_valid_number, '大阪府和泉市光明台');
ok($zip->set_number('5941112')->is_valid_number, '大阪府和泉市三林町');
ok($zip->set_number('5941113')->is_valid_number, '大阪府和泉市黒石町');
ok($zip->set_number('5941114')->is_valid_number, '大阪府和泉市国分町');
ok($zip->set_number('5941115')->is_valid_number, '大阪府和泉市平井町');
ok($zip->set_number('5941116')->is_valid_number, '大阪府和泉市納花町');
ok($zip->set_number('5941117')->is_valid_number, '大阪府和泉市鍛治屋町');
ok($zip->set_number('5941118')->is_valid_number, '大阪府和泉市みずき台');
ok($zip->set_number('5941121')->is_valid_number, '大阪府和泉市下宮町');
ok($zip->set_number('5941122')->is_valid_number, '大阪府和泉市北田中町');
ok($zip->set_number('5941123')->is_valid_number, '大阪府和泉市福瀬町');
ok($zip->set_number('5941124')->is_valid_number, '大阪府和泉市南面利町');
ok($zip->set_number('5941125')->is_valid_number, '大阪府和泉市善正町');
ok($zip->set_number('5941126')->is_valid_number, '大阪府和泉市九鬼町');
ok($zip->set_number('5941127')->is_valid_number, '大阪府和泉市小野田町');
ok($zip->set_number('5941128')->is_valid_number, '大阪府和泉市岡町');
ok($zip->set_number('5941131')->is_valid_number, '大阪府和泉市槇尾山町');
ok($zip->set_number('5941132')->is_valid_number, '大阪府和泉市父鬼町');
ok($zip->set_number('5941133')->is_valid_number, '大阪府和泉市春木川町');
ok($zip->set_number('5941134')->is_valid_number, '大阪府和泉市大野町');
ok($zip->set_number('5941135')->is_valid_number, '大阪府和泉市坪井町');
ok($zip->set_number('5941136')->is_valid_number, '大阪府和泉市仏並町');
ok($zip->set_number('5941141')->is_valid_number, '大阪府和泉市春木町');
ok($zip->set_number('5941142')->is_valid_number, '大阪府和泉市久井町');
ok($zip->set_number('5941143')->is_valid_number, '大阪府和泉市若樫町');
ok($zip->set_number('5941144')->is_valid_number, '大阪府和泉市テクノステージ');
ok($zip->set_number('5941151')->is_valid_number, '大阪府和泉市唐国町');
ok($zip->set_number('5941152')->is_valid_number, '大阪府和泉市まなび野');
ok($zip->set_number('5941153')->is_valid_number, '大阪府和泉市青葉台');
ok($zip->set_number('5941154')->is_valid_number, '大阪府和泉市松尾寺町');
ok($zip->set_number('5941155')->is_valid_number, '大阪府和泉市緑ケ丘');
ok($zip->set_number('5941156')->is_valid_number, '大阪府和泉市内田町');
ok($zip->set_number('5941157')->is_valid_number, '大阪府和泉市あゆみ野');
ok($zip->set_number('5950000')->is_valid_number, '大阪府泉大津市以下に掲載がない場合');
ok($zip->set_number('5950000')->is_valid_number, '大阪府泉北郡忠岡町以下に掲載がない場合');
ok($zip->set_number('5950001')->is_valid_number, '大阪府泉大津市綾井');
ok($zip->set_number('5950002')->is_valid_number, '大阪府泉大津市末広町');
ok($zip->set_number('5950003')->is_valid_number, '大阪府泉大津市尾井千原町');
ok($zip->set_number('5950004')->is_valid_number, '大阪府泉大津市千原町');
ok($zip->set_number('5950005')->is_valid_number, '大阪府泉大津市森町');
ok($zip->set_number('5950006')->is_valid_number, '大阪府泉大津市東助松町');
ok($zip->set_number('5950007')->is_valid_number, '大阪府泉大津市助松団地');
ok($zip->set_number('5950011')->is_valid_number, '大阪府泉大津市曽根町');
ok($zip->set_number('5950011')->is_valid_number, '大阪府泉大津市南曾根');
ok($zip->set_number('5950012')->is_valid_number, '大阪府泉大津市北豊中町');
ok($zip->set_number('5950013')->is_valid_number, '大阪府泉大津市宮町');
ok($zip->set_number('5950014')->is_valid_number, '大阪府泉大津市寿町');
ok($zip->set_number('5950015')->is_valid_number, '大阪府泉大津市二田町');
ok($zip->set_number('5950016')->is_valid_number, '大阪府泉大津市条南町');
ok($zip->set_number('5950017')->is_valid_number, '大阪府泉大津市池園町');
ok($zip->set_number('5950021')->is_valid_number, '大阪府泉大津市東豊中町');
ok($zip->set_number('5950022')->is_valid_number, '大阪府泉大津市池浦');
ok($zip->set_number('5950023')->is_valid_number, '大阪府泉大津市豊中町');
ok($zip->set_number('5950024')->is_valid_number, '大阪府泉大津市池浦町');
ok($zip->set_number('5950025')->is_valid_number, '大阪府泉大津市旭町');
ok($zip->set_number('5950026')->is_valid_number, '大阪府泉大津市東雲町');
ok($zip->set_number('5950027')->is_valid_number, '大阪府泉大津市下条町');
ok($zip->set_number('5950028')->is_valid_number, '大阪府泉大津市要池住宅');
ok($zip->set_number('5950031')->is_valid_number, '大阪府泉大津市我孫子');
ok($zip->set_number('5950032')->is_valid_number, '大阪府泉大津市穴田');
ok($zip->set_number('5950033')->is_valid_number, '大阪府泉大津市板原');
ok($zip->set_number('5950033')->is_valid_number, '大阪府泉大津市板原町');
ok($zip->set_number('5950034')->is_valid_number, '大阪府泉大津市宇多');
ok($zip->set_number('5950035')->is_valid_number, '大阪府泉大津市式内町');
ok($zip->set_number('5950036')->is_valid_number, '大阪府泉大津市昭和町');
ok($zip->set_number('5950037')->is_valid_number, '大阪府泉大津市虫取');
ok($zip->set_number('5950037')->is_valid_number, '大阪府泉大津市虫取町');
ok($zip->set_number('5950038')->is_valid_number, '大阪府泉大津市楠町西');
ok($zip->set_number('5950039')->is_valid_number, '大阪府泉大津市楠町東');
ok($zip->set_number('5950041')->is_valid_number, '大阪府泉大津市戎町');
ok($zip->set_number('5950042')->is_valid_number, '大阪府泉大津市高津町');
ok($zip->set_number('5950043')->is_valid_number, '大阪府泉大津市清水町');
ok($zip->set_number('5950044')->is_valid_number, '大阪府泉大津市河原町');
ok($zip->set_number('5950045')->is_valid_number, '大阪府泉大津市下之町');
ok($zip->set_number('5950046')->is_valid_number, '大阪府泉大津市上之町');
ok($zip->set_number('5950051')->is_valid_number, '大阪府泉大津市東港町');
ok($zip->set_number('5950052')->is_valid_number, '大阪府泉大津市西港町');
ok($zip->set_number('5950053')->is_valid_number, '大阪府泉大津市青葉町');
ok($zip->set_number('5950054')->is_valid_number, '大阪府泉大津市汐見町');
ok($zip->set_number('5950055')->is_valid_number, '大阪府泉大津市なぎさ町');
ok($zip->set_number('5950056')->is_valid_number, '大阪府泉大津市夕凪町');
ok($zip->set_number('5950061')->is_valid_number, '大阪府泉大津市春日町');
ok($zip->set_number('5950062')->is_valid_number, '大阪府泉大津市田中町');
ok($zip->set_number('5950063')->is_valid_number, '大阪府泉大津市本町');
ok($zip->set_number('5950064')->is_valid_number, '大阪府泉大津市神明町');
ok($zip->set_number('5950065')->is_valid_number, '大阪府泉大津市若宮町');
ok($zip->set_number('5950066')->is_valid_number, '大阪府泉大津市菅原町');
ok($zip->set_number('5950067')->is_valid_number, '大阪府泉大津市小松町');
ok($zip->set_number('5950071')->is_valid_number, '大阪府泉大津市助松町');
ok($zip->set_number('5950072')->is_valid_number, '大阪府泉大津市松之浜町');
ok($zip->set_number('5950073')->is_valid_number, '大阪府泉大津市新港町');
ok($zip->set_number('5950074')->is_valid_number, '大阪府泉大津市小津島町');
ok($zip->set_number('5950075')->is_valid_number, '大阪府泉大津市臨海町');
ok($zip->set_number('5950081')->is_valid_number, '大阪府高石市南高砂');
ok($zip->set_number('5950801')->is_valid_number, '大阪府泉北郡忠岡町高月北');
ok($zip->set_number('5950802')->is_valid_number, '大阪府泉北郡忠岡町高月南');
ok($zip->set_number('5950803')->is_valid_number, '大阪府泉北郡忠岡町北出');
ok($zip->set_number('5950804')->is_valid_number, '大阪府泉北郡忠岡町馬瀬');
ok($zip->set_number('5950805')->is_valid_number, '大阪府泉北郡忠岡町忠岡東');
ok($zip->set_number('5950811')->is_valid_number, '大阪府泉北郡忠岡町忠岡北');
ok($zip->set_number('5950812')->is_valid_number, '大阪府泉北郡忠岡町忠岡中');
ok($zip->set_number('5950813')->is_valid_number, '大阪府泉北郡忠岡町忠岡南');
ok($zip->set_number('5950814')->is_valid_number, '大阪府泉北郡忠岡町新浜');
ok($zip->set_number('5960000')->is_valid_number, '大阪府岸和田市以下に掲載がない場合');
ok($zip->set_number('5960001')->is_valid_number, '大阪府岸和田市磯上町');
ok($zip->set_number('5960002')->is_valid_number, '大阪府岸和田市吉井町');
ok($zip->set_number('5960003')->is_valid_number, '大阪府岸和田市中井町');
ok($zip->set_number('5960004')->is_valid_number, '大阪府岸和田市荒木町');
ok($zip->set_number('5960005')->is_valid_number, '大阪府岸和田市春木旭町');
ok($zip->set_number('5960006')->is_valid_number, '大阪府岸和田市春木若松町');
ok($zip->set_number('5960011')->is_valid_number, '大阪府岸和田市木材町');
ok($zip->set_number('5960012')->is_valid_number, '大阪府岸和田市新港町');
ok($zip->set_number('5960013')->is_valid_number, '大阪府岸和田市臨海町');
ok($zip->set_number('5960014')->is_valid_number, '大阪府岸和田市港緑町');
ok($zip->set_number('5960015')->is_valid_number, '大阪府岸和田市地蔵浜町');
ok($zip->set_number('5960016')->is_valid_number, '大阪府岸和田市岸之浦町');
ok($zip->set_number('5960021')->is_valid_number, '大阪府岸和田市松風町');
ok($zip->set_number('5960022')->is_valid_number, '大阪府岸和田市戎町');
ok($zip->set_number('5960023')->is_valid_number, '大阪府岸和田市八幡町');
ok($zip->set_number('5960024')->is_valid_number, '大阪府岸和田市春木宮川町');
ok($zip->set_number('5960025')->is_valid_number, '大阪府岸和田市春木宮本町');
ok($zip->set_number('5960026')->is_valid_number, '大阪府岸和田市春木大国町');
ok($zip->set_number('5960031')->is_valid_number, '大阪府岸和田市春木大小路町');
ok($zip->set_number('5960032')->is_valid_number, '大阪府岸和田市春木元町');
ok($zip->set_number('5960033')->is_valid_number, '大阪府岸和田市春木中町');
ok($zip->set_number('5960034')->is_valid_number, '大阪府岸和田市春木本町');
ok($zip->set_number('5960035')->is_valid_number, '大阪府岸和田市春木泉町');
ok($zip->set_number('5960036')->is_valid_number, '大阪府岸和田市春木南浜町');
ok($zip->set_number('5960037')->is_valid_number, '大阪府岸和田市春木北浜町');
ok($zip->set_number('5960041')->is_valid_number, '大阪府岸和田市下野町');
ok($zip->set_number('5960042')->is_valid_number, '大阪府岸和田市加守町');
ok($zip->set_number('5960043')->is_valid_number, '大阪府岸和田市宮前町');
ok($zip->set_number('5960044')->is_valid_number, '大阪府岸和田市西之内町');
ok($zip->set_number('5960045')->is_valid_number, '大阪府岸和田市別所町');
ok($zip->set_number('5960046')->is_valid_number, '大阪府岸和田市藤井町');
ok($zip->set_number('5960047')->is_valid_number, '大阪府岸和田市上野町東');
ok($zip->set_number('5960048')->is_valid_number, '大阪府岸和田市上野町西');
ok($zip->set_number('5960049')->is_valid_number, '大阪府岸和田市八阪町');
ok($zip->set_number('5960051')->is_valid_number, '大阪府岸和田市岸野町');
ok($zip->set_number('5960052')->is_valid_number, '大阪府岸和田市並松町');
ok($zip->set_number('5960053')->is_valid_number, '大阪府岸和田市沼町');
ok($zip->set_number('5960054')->is_valid_number, '大阪府岸和田市宮本町');
ok($zip->set_number('5960055')->is_valid_number, '大阪府岸和田市五軒屋町');
ok($zip->set_number('5960056')->is_valid_number, '大阪府岸和田市北町');
ok($zip->set_number('5960057')->is_valid_number, '大阪府岸和田市筋海町');
ok($zip->set_number('5960061')->is_valid_number, '大阪府岸和田市大北町');
ok($zip->set_number('5960062')->is_valid_number, '大阪府岸和田市中北町');
ok($zip->set_number('5960063')->is_valid_number, '大阪府岸和田市大手町');
ok($zip->set_number('5960064')->is_valid_number, '大阪府岸和田市紙屋町');
ok($zip->set_number('5960065')->is_valid_number, '大阪府岸和田市中之浜町');
ok($zip->set_number('5960066')->is_valid_number, '大阪府岸和田市大工町');
ok($zip->set_number('5960067')->is_valid_number, '大阪府岸和田市南町');
ok($zip->set_number('5960071')->is_valid_number, '大阪府岸和田市魚屋町');
ok($zip->set_number('5960072')->is_valid_number, '大阪府岸和田市堺町');
ok($zip->set_number('5960073')->is_valid_number, '大阪府岸和田市岸城町');
ok($zip->set_number('5960074')->is_valid_number, '大阪府岸和田市本町');
ok($zip->set_number('5960075')->is_valid_number, '大阪府岸和田市中町');
ok($zip->set_number('5960076')->is_valid_number, '大阪府岸和田市野田町');
ok($zip->set_number('5960077')->is_valid_number, '大阪府岸和田市上町');
ok($zip->set_number('5960078')->is_valid_number, '大阪府岸和田市南上町');
ok($zip->set_number('5960101')->is_valid_number, '大阪府岸和田市包近町');
ok($zip->set_number('5960102')->is_valid_number, '大阪府岸和田市山直中町');
ok($zip->set_number('5960103')->is_valid_number, '大阪府岸和田市稲葉町');
ok($zip->set_number('5960104')->is_valid_number, '大阪府岸和田市積川町');
ok($zip->set_number('5960105')->is_valid_number, '大阪府岸和田市内畑町');
ok($zip->set_number('5960111')->is_valid_number, '大阪府岸和田市上白原町');
ok($zip->set_number('5960112')->is_valid_number, '大阪府岸和田市神於町');
ok($zip->set_number('5960113')->is_valid_number, '大阪府岸和田市河合町');
ok($zip->set_number('5960114')->is_valid_number, '大阪府岸和田市大沢町');
ok($zip->set_number('5960115')->is_valid_number, '大阪府岸和田市相川町');
ok($zip->set_number('5960116')->is_valid_number, '大阪府岸和田市塔原町');
ok($zip->set_number('5960801')->is_valid_number, '大阪府岸和田市箕土路町');
ok($zip->set_number('5960802')->is_valid_number, '大阪府岸和田市西大路町');
ok($zip->set_number('5960803')->is_valid_number, '大阪府岸和田市東大路町');
ok($zip->set_number('5960804')->is_valid_number, '大阪府岸和田市今木町');
ok($zip->set_number('5960805')->is_valid_number, '大阪府岸和田市田治米町');
ok($zip->set_number('5960806')->is_valid_number, '大阪府岸和田市摩湯町');
ok($zip->set_number('5960807')->is_valid_number, '大阪府岸和田市東ケ丘町');
ok($zip->set_number('5960808')->is_valid_number, '大阪府岸和田市三田町');
ok($zip->set_number('5960811')->is_valid_number, '大阪府岸和田市下池田町');
ok($zip->set_number('5960812')->is_valid_number, '大阪府岸和田市大町');
ok($zip->set_number('5960813')->is_valid_number, '大阪府岸和田市池尻町');
ok($zip->set_number('5960814')->is_valid_number, '大阪府岸和田市岡山町');
ok($zip->set_number('5960815')->is_valid_number, '大阪府岸和田市三ケ山町');
ok($zip->set_number('5960816')->is_valid_number, '大阪府岸和田市尾生町');
ok($zip->set_number('5960817')->is_valid_number, '大阪府岸和田市岸の丘町');
ok($zip->set_number('5960821')->is_valid_number, '大阪府岸和田市小松里町');
ok($zip->set_number('5960822')->is_valid_number, '大阪府岸和田市額原町');
ok($zip->set_number('5960823')->is_valid_number, '大阪府岸和田市下松町');
ok($zip->set_number('5960824')->is_valid_number, '大阪府岸和田市葛城町');
ok($zip->set_number('5960825')->is_valid_number, '大阪府岸和田市土生町');
ok($zip->set_number('5960826')->is_valid_number, '大阪府岸和田市作才町');
ok($zip->set_number('5960827')->is_valid_number, '大阪府岸和田市上松町');
ok($zip->set_number('5960828')->is_valid_number, '大阪府岸和田市門前町');
ok($zip->set_number('5960831')->is_valid_number, '大阪府岸和田市畑町');
ok($zip->set_number('5960832')->is_valid_number, '大阪府岸和田市極楽寺町');
ok($zip->set_number('5960833')->is_valid_number, '大阪府岸和田市神須屋町');
ok($zip->set_number('5960834')->is_valid_number, '大阪府岸和田市天神山町');
ok($zip->set_number('5960835')->is_valid_number, '大阪府岸和田市流木町');
ok($zip->set_number('5960836')->is_valid_number, '大阪府岸和田市行遇町');
ok($zip->set_number('5960841')->is_valid_number, '大阪府岸和田市八田町');
ok($zip->set_number('5960842')->is_valid_number, '大阪府岸和田市真上町');
ok($zip->set_number('5960843')->is_valid_number, '大阪府岸和田市北阪町');
ok($zip->set_number('5960844')->is_valid_number, '大阪府岸和田市土生滝町');
ok($zip->set_number('5960845')->is_valid_number, '大阪府岸和田市阿間河滝町');
ok($zip->set_number('5970000')->is_valid_number, '大阪府貝塚市以下に掲載がない場合');
ok($zip->set_number('5970001')->is_valid_number, '大阪府貝塚市近木町');
ok($zip->set_number('5970002')->is_valid_number, '大阪府貝塚市新町');
ok($zip->set_number('5970003')->is_valid_number, '大阪府貝塚市中町');
ok($zip->set_number('5970004')->is_valid_number, '大阪府貝塚市西町');
ok($zip->set_number('5970005')->is_valid_number, '大阪府貝塚市南町');
ok($zip->set_number('5970011')->is_valid_number, '大阪府貝塚市北町');
ok($zip->set_number('5970012')->is_valid_number, '大阪府貝塚市津田');
ok($zip->set_number('5970013')->is_valid_number, '大阪府貝塚市津田北町');
ok($zip->set_number('5970014')->is_valid_number, '大阪府貝塚市津田南町');
ok($zip->set_number('5970015')->is_valid_number, '大阪府貝塚市堀');
ok($zip->set_number('5970021')->is_valid_number, '大阪府貝塚市小瀬');
ok($zip->set_number('5970022')->is_valid_number, '大阪府貝塚市新井');
ok($zip->set_number('5970023')->is_valid_number, '大阪府貝塚市福田');
ok($zip->set_number('5970031')->is_valid_number, '大阪府貝塚市久保');
ok($zip->set_number('5970032')->is_valid_number, '大阪府貝塚市永吉');
ok($zip->set_number('5970033')->is_valid_number, '大阪府貝塚市半田');
ok($zip->set_number('5970041')->is_valid_number, '大阪府貝塚市清児');
ok($zip->set_number('5970042')->is_valid_number, '大阪府貝塚市名越');
ok($zip->set_number('5970043')->is_valid_number, '大阪府貝塚市橋本');
ok($zip->set_number('5970044')->is_valid_number, '大阪府貝塚市森');
ok($zip->set_number('5970045')->is_valid_number, '大阪府貝塚市三ツ松(596、894-1、915-4、925、927-2、932');
ok($zip->set_number('5970045')->is_valid_number, '大阪府貝塚市-4、934~968、1013-1、1464番地)');
ok($zip->set_number('5970046')->is_valid_number, '大阪府貝塚市東山');
ok($zip->set_number('5970051')->is_valid_number, '大阪府貝塚市王子');
ok($zip->set_number('5970052')->is_valid_number, '大阪府貝塚市窪田');
ok($zip->set_number('5970053')->is_valid_number, '大阪府貝塚市地蔵堂(その他)');
ok($zip->set_number('5970054')->is_valid_number, '大阪府貝塚市堤');
ok($zip->set_number('5970061')->is_valid_number, '大阪府貝塚市浦田');
ok($zip->set_number('5970062')->is_valid_number, '大阪府貝塚市澤');
ok($zip->set_number('5970063')->is_valid_number, '大阪府貝塚市二色港町');
ok($zip->set_number('5970071')->is_valid_number, '大阪府貝塚市加神');
ok($zip->set_number('5970072')->is_valid_number, '大阪府貝塚市畠中(その他)');
ok($zip->set_number('5970073')->is_valid_number, '大阪府貝塚市脇浜');
ok($zip->set_number('5970074')->is_valid_number, '大阪府貝塚市加治');
ok($zip->set_number('5970075')->is_valid_number, '大阪府貝塚市神前');
ok($zip->set_number('5970081')->is_valid_number, '大阪府貝塚市麻生中');
ok($zip->set_number('5970082')->is_valid_number, '大阪府貝塚市石才');
ok($zip->set_number('5970083')->is_valid_number, '大阪府貝塚市海塚');
ok($zip->set_number('5970084')->is_valid_number, '大阪府貝塚市鳥羽');
ok($zip->set_number('5970085')->is_valid_number, '大阪府貝塚市東');
ok($zip->set_number('5970091')->is_valid_number, '大阪府貝塚市二色');
ok($zip->set_number('5970092')->is_valid_number, '大阪府貝塚市二色北町');
ok($zip->set_number('5970093')->is_valid_number, '大阪府貝塚市二色中町');
ok($zip->set_number('5970094')->is_valid_number, '大阪府貝塚市二色南町');
ok($zip->set_number('5970095')->is_valid_number, '大阪府貝塚市港');
ok($zip->set_number('5970101')->is_valid_number, '大阪府貝塚市三ケ山');
ok($zip->set_number('5970102')->is_valid_number, '大阪府貝塚市木積');
ok($zip->set_number('5970103')->is_valid_number, '大阪府貝塚市馬場');
ok($zip->set_number('5970104')->is_valid_number, '大阪府貝塚市水間');
ok($zip->set_number('5970105')->is_valid_number, '大阪府貝塚市三ツ松(その他)');
ok($zip->set_number('5970106')->is_valid_number, '大阪府貝塚市畠中(632-1、633、642-3)');
ok($zip->set_number('5970107')->is_valid_number, '大阪府貝塚市地蔵堂(611、695、732、675)');
ok($zip->set_number('5970111')->is_valid_number, '大阪府貝塚市蕎原');
ok($zip->set_number('5970112')->is_valid_number, '大阪府貝塚市大川');
ok($zip->set_number('5970113')->is_valid_number, '大阪府貝塚市秬谷');
ok($zip->set_number('5980000')->is_valid_number, '大阪府泉佐野市以下に掲載がない場合');
ok($zip->set_number('5980000')->is_valid_number, '大阪府泉南郡田尻町以下に掲載がない場合');
ok($zip->set_number('5980001')->is_valid_number, '大阪府泉佐野市上瓦屋');
ok($zip->set_number('5980002')->is_valid_number, '大阪府泉佐野市中庄');
ok($zip->set_number('5980003')->is_valid_number, '大阪府泉佐野市俵屋');
ok($zip->set_number('5980004')->is_valid_number, '大阪府泉佐野市市場南');
ok($zip->set_number('5980005')->is_valid_number, '大阪府泉佐野市市場東');
ok($zip->set_number('5980006')->is_valid_number, '大阪府泉佐野市市場西');
ok($zip->set_number('5980007')->is_valid_number, '大阪府泉佐野市上町');
ok($zip->set_number('5980008')->is_valid_number, '大阪府泉佐野市松風台');
ok($zip->set_number('5980011')->is_valid_number, '大阪府泉佐野市高松北');
ok($zip->set_number('5980012')->is_valid_number, '大阪府泉佐野市高松東');
ok($zip->set_number('5980013')->is_valid_number, '大阪府泉佐野市中町');
ok($zip->set_number('5980014')->is_valid_number, '大阪府泉佐野市葵町');
ok($zip->set_number('5980015')->is_valid_number, '大阪府泉佐野市高松南');
ok($zip->set_number('5980016')->is_valid_number, '大阪府泉佐野市高松西');
ok($zip->set_number('5980021')->is_valid_number, '大阪府泉佐野市日根野');
ok($zip->set_number('5980022')->is_valid_number, '大阪府泉佐野市土丸');
ok($zip->set_number('5980023')->is_valid_number, '大阪府泉佐野市大木');
ok($zip->set_number('5980024')->is_valid_number, '大阪府泉佐野市上之郷');
ok($zip->set_number('5980031')->is_valid_number, '大阪府泉佐野市東羽倉崎町');
ok($zip->set_number('5980032')->is_valid_number, '大阪府泉佐野市新安松');
ok($zip->set_number('5980033')->is_valid_number, '大阪府泉佐野市南中安松');
ok($zip->set_number('5980034')->is_valid_number, '大阪府泉佐野市長滝');
ok($zip->set_number('5980035')->is_valid_number, '大阪府泉佐野市南中樫井');
ok($zip->set_number('5980036')->is_valid_number, '大阪府泉佐野市岡本');
ok($zip->set_number('5980036')->is_valid_number, '大阪府泉佐野市南中岡本');
ok($zip->set_number('5980037')->is_valid_number, '大阪府泉佐野市羽倉崎上町');
ok($zip->set_number('5980041')->is_valid_number, '大阪府泉佐野市野出町');
ok($zip->set_number('5980042')->is_valid_number, '大阪府泉佐野市西本町');
ok($zip->set_number('5980043')->is_valid_number, '大阪府泉佐野市大西');
ok($zip->set_number('5980044')->is_valid_number, '大阪府泉佐野市笠松');
ok($zip->set_number('5980045')->is_valid_number, '大阪府泉佐野市松原');
ok($zip->set_number('5980046')->is_valid_number, '大阪府泉佐野市羽倉崎');
ok($zip->set_number('5980047')->is_valid_number, '大阪府泉佐野市りんくう往来南');
ok($zip->set_number('5980048')->is_valid_number, '大阪府泉佐野市りんくう往来北');
ok($zip->set_number('5980051')->is_valid_number, '大阪府泉佐野市新町');
ok($zip->set_number('5980052')->is_valid_number, '大阪府泉佐野市旭町');
ok($zip->set_number('5980053')->is_valid_number, '大阪府泉佐野市大宮町');
ok($zip->set_number('5980054')->is_valid_number, '大阪府泉佐野市栄町');
ok($zip->set_number('5980055')->is_valid_number, '大阪府泉佐野市若宮町');
ok($zip->set_number('5980056')->is_valid_number, '大阪府泉佐野市元町');
ok($zip->set_number('5980057')->is_valid_number, '大阪府泉佐野市本町');
ok($zip->set_number('5980058')->is_valid_number, '大阪府泉佐野市春日町');
ok($zip->set_number('5980061')->is_valid_number, '大阪府泉佐野市住吉町');
ok($zip->set_number('5980062')->is_valid_number, '大阪府泉佐野市下瓦屋');
ok($zip->set_number('5980063')->is_valid_number, '大阪府泉佐野市湊');
ok($zip->set_number('5980064')->is_valid_number, '大阪府泉佐野市新浜町');
ok($zip->set_number('5980071')->is_valid_number, '大阪府泉佐野市鶴原');
ok($zip->set_number('5980072')->is_valid_number, '大阪府泉佐野市泉ケ丘');
ok($zip->set_number('5980073')->is_valid_number, '大阪府泉佐野市南泉ケ丘');
ok($zip->set_number('5980074')->is_valid_number, '大阪府泉佐野市東佐野台');
ok($zip->set_number('5980075')->is_valid_number, '大阪府泉佐野市佐野台');
ok($zip->set_number('5980091')->is_valid_number, '大阪府泉南郡田尻町嘉祥寺');
ok($zip->set_number('5980092')->is_valid_number, '大阪府泉南郡田尻町吉見');
ok($zip->set_number('5980093')->is_valid_number, '大阪府泉南郡田尻町りんくうポート北');
ok($zip->set_number('5980094')->is_valid_number, '大阪府泉南郡田尻町りんくうポート南');
ok($zip->set_number('5990000')->is_valid_number, '大阪府堺市中区以下に掲載がない場合');
ok($zip->set_number('5990000')->is_valid_number, '大阪府堺市東区以下に掲載がない場合');
ok($zip->set_number('5990200')->is_valid_number, '大阪府阪南市以下に掲載がない場合');
ok($zip->set_number('5990201')->is_valid_number, '大阪府阪南市尾崎町');
ok($zip->set_number('5990202')->is_valid_number, '大阪府阪南市下出');
ok($zip->set_number('5990203')->is_valid_number, '大阪府阪南市黒田');
ok($zip->set_number('5990204')->is_valid_number, '大阪府阪南市鳥取');
ok($zip->set_number('5990205')->is_valid_number, '大阪府阪南市新町');
ok($zip->set_number('5990211')->is_valid_number, '大阪府阪南市鳥取中');
ok($zip->set_number('5990212')->is_valid_number, '大阪府阪南市自然田');
ok($zip->set_number('5990213')->is_valid_number, '大阪府阪南市和泉鳥取');
ok($zip->set_number('5990214')->is_valid_number, '大阪府阪南市山中渓');
ok($zip->set_number('5990215')->is_valid_number, '大阪府阪南市さつき台');
ok($zip->set_number('5990216')->is_valid_number, '大阪府阪南市緑ケ丘');
ok($zip->set_number('5990221')->is_valid_number, '大阪府阪南市石田');
ok($zip->set_number('5990222')->is_valid_number, '大阪府阪南市桑畑');
ok($zip->set_number('5990223')->is_valid_number, '大阪府阪南市光陽台');
ok($zip->set_number('5990224')->is_valid_number, '大阪府阪南市舞');
ok($zip->set_number('5990225')->is_valid_number, '大阪府阪南市鳥取三井');
ok($zip->set_number('5990231')->is_valid_number, '大阪府阪南市貝掛');
ok($zip->set_number('5990232')->is_valid_number, '大阪府阪南市箱作');
ok($zip->set_number('5990233')->is_valid_number, '大阪府阪南市南山中');
ok($zip->set_number('5990234')->is_valid_number, '大阪府阪南市淡輪');
ok($zip->set_number('5990235')->is_valid_number, '大阪府阪南市箱の浦');
ok($zip->set_number('5990236')->is_valid_number, '大阪府阪南市桃の木台');
ok($zip->set_number('5990300')->is_valid_number, '大阪府泉南郡岬町以下に掲載がない場合');
ok($zip->set_number('5990301')->is_valid_number, '大阪府泉南郡岬町淡輪');
ok($zip->set_number('5990302')->is_valid_number, '大阪府泉南郡岬町孝子');
ok($zip->set_number('5990303')->is_valid_number, '大阪府泉南郡岬町深日');
ok($zip->set_number('5990304')->is_valid_number, '大阪府泉南郡岬町望海坂');
ok($zip->set_number('5990311')->is_valid_number, '大阪府泉南郡岬町多奈川谷川');
ok($zip->set_number('5990312')->is_valid_number, '大阪府泉南郡岬町多奈川東畑');
ok($zip->set_number('5990313')->is_valid_number, '大阪府泉南郡岬町多奈川西畑');
ok($zip->set_number('5990314')->is_valid_number, '大阪府泉南郡岬町多奈川小島');
ok($zip->set_number('5998101')->is_valid_number, '大阪府堺市東区八下町');
ok($zip->set_number('5998102')->is_valid_number, '大阪府堺市東区石原町');
ok($zip->set_number('5998103')->is_valid_number, '大阪府堺市東区菩提町');
ok($zip->set_number('5998104')->is_valid_number, '大阪府堺市東区引野町');
ok($zip->set_number('5998107')->is_valid_number, '大阪府堺市東区白鷺町');
ok($zip->set_number('5998111')->is_valid_number, '大阪府堺市東区日置荘北町');
ok($zip->set_number('5998112')->is_valid_number, '大阪府堺市東区日置荘原寺町');
ok($zip->set_number('5998113')->is_valid_number, '大阪府堺市東区日置荘田中町');
ok($zip->set_number('5998114')->is_valid_number, '大阪府堺市東区日置荘西町');
ok($zip->set_number('5998115')->is_valid_number, '大阪府堺市東区関茶屋');
ok($zip->set_number('5998116')->is_valid_number, '大阪府堺市東区野尻町');
ok($zip->set_number('5998121')->is_valid_number, '大阪府堺市東区高松');
ok($zip->set_number('5998122')->is_valid_number, '大阪府堺市東区丈六');
ok($zip->set_number('5998123')->is_valid_number, '大阪府堺市東区北野田');
ok($zip->set_number('5998124')->is_valid_number, '大阪府堺市東区南野田');
ok($zip->set_number('5998125')->is_valid_number, '大阪府堺市東区西野');
ok($zip->set_number('5998126')->is_valid_number, '大阪府堺市東区大美野');
ok($zip->set_number('5998127')->is_valid_number, '大阪府堺市東区草尾');
ok($zip->set_number('5998128')->is_valid_number, '大阪府堺市東区中茶屋');
ok($zip->set_number('5998231')->is_valid_number, '大阪府堺市中区学園町');
ok($zip->set_number('5998232')->is_valid_number, '大阪府堺市中区新家町');
ok($zip->set_number('5998233')->is_valid_number, '大阪府堺市中区大野芝町');
ok($zip->set_number('5998234')->is_valid_number, '大阪府堺市中区土塔町');
ok($zip->set_number('5998235')->is_valid_number, '大阪府堺市中区深井東町');
ok($zip->set_number('5998236')->is_valid_number, '大阪府堺市中区深井沢町');
ok($zip->set_number('5998237')->is_valid_number, '大阪府堺市中区深井水池町');
ok($zip->set_number('5998238')->is_valid_number, '大阪府堺市中区土師町');
ok($zip->set_number('5998241')->is_valid_number, '大阪府堺市中区福田');
ok($zip->set_number('5998242')->is_valid_number, '大阪府堺市中区陶器北');
ok($zip->set_number('5998243')->is_valid_number, '大阪府堺市中区見野山');
ok($zip->set_number('5998244')->is_valid_number, '大阪府堺市中区上之');
ok($zip->set_number('5998245')->is_valid_number, '大阪府堺市中区辻之');
ok($zip->set_number('5998246')->is_valid_number, '大阪府堺市中区田園');
ok($zip->set_number('5998247')->is_valid_number, '大阪府堺市中区東山');
ok($zip->set_number('5998248')->is_valid_number, '大阪府堺市中区深井畑山町');
ok($zip->set_number('5998251')->is_valid_number, '大阪府堺市中区平井');
ok($zip->set_number('5998252')->is_valid_number, '大阪府堺市中区楢葉');
ok($zip->set_number('5998253')->is_valid_number, '大阪府堺市中区深阪');
ok($zip->set_number('5998254')->is_valid_number, '大阪府堺市中区伏尾');
ok($zip->set_number('5998261')->is_valid_number, '大阪府堺市中区堀上町');
ok($zip->set_number('5998262')->is_valid_number, '大阪府堺市中区八田北町');
ok($zip->set_number('5998263')->is_valid_number, '大阪府堺市中区八田南之町');
ok($zip->set_number('5998264')->is_valid_number, '大阪府堺市中区小阪西町');
ok($zip->set_number('5998265')->is_valid_number, '大阪府堺市中区八田西町');
ok($zip->set_number('5998266')->is_valid_number, '大阪府堺市中区毛穴町');
ok($zip->set_number('5998267')->is_valid_number, '大阪府堺市中区八田寺町(その他)');
ok($zip->set_number('5998271')->is_valid_number, '大阪府堺市中区深井北町');
ok($zip->set_number('5998272')->is_valid_number, '大阪府堺市中区深井中町');
ok($zip->set_number('5998273')->is_valid_number, '大阪府堺市中区深井清水町');
ok($zip->set_number('5998274')->is_valid_number, '大阪府堺市中区宮園町');
ok($zip->set_number('5998275')->is_valid_number, '大阪府堺市中区東八田');
ok($zip->set_number('5998276')->is_valid_number, '大阪府堺市中区小阪');
ok($zip->set_number('6000000')->is_valid_number, '京都府京都市下京区以下に掲載がない場合');
ok($zip->set_number('6008001')->is_valid_number, '京都府京都市下京区真町');
ok($zip->set_number('6008002')->is_valid_number, '京都府京都市下京区御旅町');
ok($zip->set_number('6008003')->is_valid_number, '京都府京都市下京区御旅宮本町');
ok($zip->set_number('6008004')->is_valid_number, '京都府京都市下京区奈良物町');
ok($zip->set_number('6008005')->is_valid_number, '京都府京都市下京区立売東町');
ok($zip->set_number('6008006')->is_valid_number, '京都府京都市下京区立売中之町');
ok($zip->set_number('6008007')->is_valid_number, '京都府京都市下京区立売西町');
ok($zip->set_number('6008008')->is_valid_number, '京都府京都市下京区長刀鉾町');
ok($zip->set_number('6008009')->is_valid_number, '京都府京都市下京区函谷鉾町');
ok($zip->set_number('6008011')->is_valid_number, '京都府京都市下京区橋本町');
ok($zip->set_number('6008012')->is_valid_number, '京都府京都市下京区斎藤町');
ok($zip->set_number('6008013')->is_valid_number, '京都府京都市下京区天王町');
ok($zip->set_number('6008014')->is_valid_number, '京都府京都市下京区和泉屋町');
ok($zip->set_number('6008015')->is_valid_number, '京都府京都市下京区美濃屋町');
ok($zip->set_number('6008016')->is_valid_number, '京都府京都市下京区材木町(木屋町通松原下る、松原通木屋町東入、松原通高瀬川筋東入)');
ok($zip->set_number('6008017')->is_valid_number, '京都府京都市下京区下材木町');
ok($zip->set_number('6008018')->is_valid_number, '京都府京都市下京区市之町');
ok($zip->set_number('6008019')->is_valid_number, '京都府京都市下京区船頭町');
ok($zip->set_number('6008020')->is_valid_number, '京都府京都市下京区御影堂前町');
ok($zip->set_number('6008021')->is_valid_number, '京都府京都市下京区順風町');
ok($zip->set_number('6008022')->is_valid_number, '京都府京都市下京区稲荷町(河原町通四条下る、河原町通四条下る2丁目)');
ok($zip->set_number('6008023')->is_valid_number, '京都府京都市下京区富永町(河原町通四条下る2丁目、河原町通高辻上る、河原町通仏');
ok($zip->set_number('6008023')->is_valid_number, '京都府京都市下京区光寺下る、河原町通松原上る、河原町通松原上る2丁目、高辻通河原町西入、');
ok($zip->set_number('6008023')->is_valid_number, '京都府京都市下京区仏光寺通河原町西入)');
ok($zip->set_number('6008024')->is_valid_number, '京都府京都市下京区天満町');
ok($zip->set_number('6008025')->is_valid_number, '京都府京都市下京区清水町(河原町通高辻下る、河原町通松原上る、西木屋町通高辻');
ok($zip->set_number('6008025')->is_valid_number, '京都府京都市下京区下る、西木屋町通松原上る)');
ok($zip->set_number('6008026')->is_valid_number, '京都府京都市下京区松川町');
ok($zip->set_number('6008027')->is_valid_number, '京都府京都市下京区難波町');
ok($zip->set_number('6008028')->is_valid_number, '京都府京都市下京区植松町(河原町通松原下る、河原町通万寿寺上る、寺町通松原');
ok($zip->set_number('6008028')->is_valid_number, '京都府京都市下京区下る、寺町通万寿寺上る、松原通寺町西入、松原通寺町東入、万寿寺通河原町');
ok($zip->set_number('6008028')->is_valid_number, '京都府京都市下京区西入、万寿寺通寺町西入)');
ok($zip->set_number('6008029')->is_valid_number, '京都府京都市下京区西橋詰町');
ok($zip->set_number('6008031')->is_valid_number, '京都府京都市下京区貞安前之町');
ok($zip->set_number('6008032')->is_valid_number, '京都府京都市下京区中之町(寺町通綾小路下る、寺町通仏光寺上る、仏光寺通寺町西');
ok($zip->set_number('6008032')->is_valid_number, '京都府京都市下京区入、仏光寺通寺町東入)');
ok($zip->set_number('6008033')->is_valid_number, '京都府京都市下京区恵美須之町');
ok($zip->set_number('6008034')->is_valid_number, '京都府京都市下京区幸竹町');
ok($zip->set_number('6008035')->is_valid_number, '京都府京都市下京区京極町');
ok($zip->set_number('6008036')->is_valid_number, '京都府京都市下京区茶磨屋町(高辻通御幸町東入、高辻通寺町西入)');
ok($zip->set_number('6008037')->is_valid_number, '京都府京都市下京区丸屋町(御幸町通綾小路下る、御幸町通仏光寺上る)');
ok($zip->set_number('6008038')->is_valid_number, '京都府京都市下京区足袋屋町');
ok($zip->set_number('6008039')->is_valid_number, '京都府京都市下京区大寿町');
ok($zip->set_number('6008040')->is_valid_number, '京都府京都市下京区安土町');
ok($zip->set_number('6008041')->is_valid_number, '京都府京都市下京区八文字町');
ok($zip->set_number('6008042')->is_valid_number, '京都府京都市下京区俵屋町(麩屋町通綾小路下る、麩屋町通仏光寺上る)');
ok($zip->set_number('6008043')->is_valid_number, '京都府京都市下京区大黒町(仏光寺通御幸町西入、仏光寺通御幸町東入、仏光寺通');
ok($zip->set_number('6008043')->is_valid_number, '京都府京都市下京区寺町西入、仏光寺通麩屋町東入)');
ok($zip->set_number('6008044')->is_valid_number, '京都府京都市下京区橘町(御幸町通高辻上る、御幸町通仏光寺下る、高辻通御幸町');
ok($zip->set_number('6008044')->is_valid_number, '京都府京都市下京区西入、高辻通御幸町東入)');
ok($zip->set_number('6008045')->is_valid_number, '京都府京都市下京区茶磨屋町(高辻通御幸町西入、高辻通麩屋町東入)');
ok($zip->set_number('6008046')->is_valid_number, '京都府京都市下京区桝屋町');
ok($zip->set_number('6008047')->is_valid_number, '京都府京都市下京区石不動之町');
ok($zip->set_number('6008048')->is_valid_number, '京都府京都市下京区須浜町');
ok($zip->set_number('6008049')->is_valid_number, '京都府京都市下京区堅田町(万寿寺通御幸町西入)');
ok($zip->set_number('6008050')->is_valid_number, '京都府京都市下京区堅田町(万寿寺通富小路東入、万寿寺通麩屋町西入)');
ok($zip->set_number('6008051')->is_valid_number, '京都府京都市下京区徳正寺町');
ok($zip->set_number('6008052')->is_valid_number, '京都府京都市下京区塩屋町(綾小路通富小路西入、綾小路通富小路東入、綾小路通');
ok($zip->set_number('6008052')->is_valid_number, '京都府京都市下京区麩屋町西入、綾小路通柳馬場東入、富小路通綾小路上る、富小路通綾小路下');
ok($zip->set_number('6008052')->is_valid_number, '京都府京都市下京区る、麩屋町通綾小路下る)');
ok($zip->set_number('6008053')->is_valid_number, '京都府京都市下京区塗師屋町(富小路通綾小路下る、富小路通仏光寺上る)');
ok($zip->set_number('6008054')->is_valid_number, '京都府京都市下京区仏光寺東町');
ok($zip->set_number('6008055')->is_valid_number, '京都府京都市下京区鍋屋町');
ok($zip->set_number('6008056')->is_valid_number, '京都府京都市下京区雁金町(高辻通富小路東入、高辻通麩屋町西入)');
ok($zip->set_number('6008057')->is_valid_number, '京都府京都市下京区鍵屋町(高辻通麩屋町西入、高辻通麩屋町東入、麩屋町通高辻');
ok($zip->set_number('6008057')->is_valid_number, '京都府京都市下京区下る、麩屋町通松原上る)');
ok($zip->set_number('6008058')->is_valid_number, '京都府京都市下京区上鱗形町');
ok($zip->set_number('6008059')->is_valid_number, '京都府京都市下京区下鱗形町');
ok($zip->set_number('6008060')->is_valid_number, '京都府京都市下京区雁金町(高辻通富小路西入、高辻通柳馬場東入)');
ok($zip->set_number('6008061')->is_valid_number, '京都府京都市下京区筋屋町');
ok($zip->set_number('6008062')->is_valid_number, '京都府京都市下京区恵美須屋町');
ok($zip->set_number('6008063')->is_valid_number, '京都府京都市下京区松原中之町');
ok($zip->set_number('6008064')->is_valid_number, '京都府京都市下京区本上神明町');
ok($zip->set_number('6008065')->is_valid_number, '京都府京都市下京区本神明町');
ok($zip->set_number('6008066')->is_valid_number, '京都府京都市下京区柏屋町(万寿寺通柳馬場西入、柳馬場通五条上る、柳馬場通万寿寺下る)');
ok($zip->set_number('6008067')->is_valid_number, '京都府京都市下京区堅田町(万寿寺通堺町東入、万寿寺通富小路西入、万寿寺通柳');
ok($zip->set_number('6008067')->is_valid_number, '京都府京都市下京区馬場西入、万寿寺通柳馬場東入、柳馬場通万寿寺上る)');
ok($zip->set_number('6008068')->is_valid_number, '京都府京都市下京区忠庵町');
ok($zip->set_number('6008069')->is_valid_number, '京都府京都市下京区吉文字町(高辻通柳馬場西入、高辻通柳馬場東入、柳馬場通高辻');
ok($zip->set_number('6008069')->is_valid_number, '京都府京都市下京区下る、柳馬場通松原上る)');
ok($zip->set_number('6008070')->is_valid_number, '京都府京都市下京区俵屋町(堺町通万寿寺下る、万寿寺通堺町西入、万寿寺通堺町東');
ok($zip->set_number('6008070')->is_valid_number, '京都府京都市下京区入、五条通堺町上る)');
ok($zip->set_number('6008071')->is_valid_number, '京都府京都市下京区相之町');
ok($zip->set_number('6008072')->is_valid_number, '京都府京都市下京区綾材木町');
ok($zip->set_number('6008073')->is_valid_number, '京都府京都市下京区永原町');
ok($zip->set_number('6008074')->is_valid_number, '京都府京都市下京区東前町');
ok($zip->set_number('6008075')->is_valid_number, '京都府京都市下京区万里小路町');
ok($zip->set_number('6008076')->is_valid_number, '京都府京都市下京区泉正寺町');
ok($zip->set_number('6008077')->is_valid_number, '京都府京都市下京区夕顔町');
ok($zip->set_number('6008078')->is_valid_number, '京都府京都市下京区杉屋町');
ok($zip->set_number('6008079')->is_valid_number, '京都府京都市下京区鍛冶屋町(堺町通松原下る、堺町通万寿寺上る、万寿寺通堺町東入)');
ok($zip->set_number('6008081')->is_valid_number, '京都府京都市下京区小石町');
ok($zip->set_number('6008082')->is_valid_number, '京都府京都市下京区高材木町');
ok($zip->set_number('6008083')->is_valid_number, '京都府京都市下京区西前町');
ok($zip->set_number('6008084')->is_valid_number, '京都府京都市下京区新開町');
ok($zip->set_number('6008085')->is_valid_number, '京都府京都市下京区葛籠屋町');
ok($zip->set_number('6008086')->is_valid_number, '京都府京都市下京区本燈籠町');
ok($zip->set_number('6008087')->is_valid_number, '京都府京都市下京区樋之下町');
ok($zip->set_number('6008088')->is_valid_number, '京都府京都市下京区官社殿町');
ok($zip->set_number('6008089')->is_valid_number, '京都府京都市下京区堅田町(万寿寺通堺町西入)');
ok($zip->set_number('6008090')->is_valid_number, '京都府京都市下京区竹屋之町');
ok($zip->set_number('6008091')->is_valid_number, '京都府京都市下京区元悪王子町');
ok($zip->set_number('6008092')->is_valid_number, '京都府京都市下京区神明町');
ok($zip->set_number('6008093')->is_valid_number, '京都府京都市下京区竹屋町(高倉通綾小路下る、高倉通仏光寺上る、堺町通綾小路下る西入)');
ok($zip->set_number('6008094')->is_valid_number, '京都府京都市下京区仏光寺西町');
ok($zip->set_number('6008095')->is_valid_number, '京都府京都市下京区扇酒屋町');
ok($zip->set_number('6008096')->is_valid_number, '京都府京都市下京区高橋町');
ok($zip->set_number('6008097')->is_valid_number, '京都府京都市下京区三軒町');
ok($zip->set_number('6008098')->is_valid_number, '京都府京都市下京区稲荷町(間之町通高辻下る、間之町通松原上る、高辻通間之町西');
ok($zip->set_number('6008098')->is_valid_number, '京都府京都市下京区入、高辻通間之町東入、高辻通東洞院東入)');
ok($zip->set_number('6008099')->is_valid_number, '京都府京都市下京区上柳町(仏光寺通烏丸東入、仏光寺通烏丸東入上る、仏光寺通烏丸東入下る、');
ok($zip->set_number('6008099')->is_valid_number, '京都府京都市下京区仏光寺通東洞院西入)');
ok($zip->set_number('6008101')->is_valid_number, '京都府京都市下京区御影堂町');
ok($zip->set_number('6008102')->is_valid_number, '京都府京都市下京区本覚寺前町');
ok($zip->set_number('6008103')->is_valid_number, '京都府京都市下京区塩竈町');
ok($zip->set_number('6008104')->is_valid_number, '京都府京都市下京区万寿寺町');
ok($zip->set_number('6008105')->is_valid_number, '京都府京都市下京区松屋町');
ok($zip->set_number('6008106')->is_valid_number, '京都府京都市下京区醍醐町');
ok($zip->set_number('6008107')->is_valid_number, '京都府京都市下京区東錺屋町');
ok($zip->set_number('6008108')->is_valid_number, '京都府京都市下京区西錺屋町');
ok($zip->set_number('6008109')->is_valid_number, '京都府京都市下京区平屋町');
ok($zip->set_number('6008110')->is_valid_number, '京都府京都市下京区南橋詰町');
ok($zip->set_number('6008111')->is_valid_number, '京都府京都市下京区都市町');
ok($zip->set_number('6008112')->is_valid_number, '京都府京都市下京区八ツ柳町');
ok($zip->set_number('6008113')->is_valid_number, '京都府京都市下京区波止土濃町');
ok($zip->set_number('6008114')->is_valid_number, '京都府京都市下京区早尾町');
ok($zip->set_number('6008115')->is_valid_number, '京都府京都市下京区岩滝町');
ok($zip->set_number('6008116')->is_valid_number, '京都府京都市下京区聖真子町');
ok($zip->set_number('6008117')->is_valid_number, '京都府京都市下京区南京極町');
ok($zip->set_number('6008118')->is_valid_number, '京都府京都市下京区平居町');
ok($zip->set_number('6008119')->is_valid_number, '京都府京都市下京区本塩竈町');
ok($zip->set_number('6008120')->is_valid_number, '京都府京都市下京区若宮町(上ノ口通河原町西入、上ノ口通河原町西入下る、河原');
ok($zip->set_number('6008120')->is_valid_number, '京都府京都市下京区町通上枳殻馬場上る、河原町通上ノ口下る、河原町通正面上る)');
ok($zip->set_number('6008121')->is_valid_number, '京都府京都市下京区菊屋町(上ノ口通加茂川筋西入、上ノ口通加茂川筋西入上る、加');
ok($zip->set_number('6008121')->is_valid_number, '京都府京都市下京区茂川筋上ノ口下る、上ノ口通二ノ宮西入、二ノ宮通上ノ口下る)');
ok($zip->set_number('6008122')->is_valid_number, '京都府京都市下京区平岡町');
ok($zip->set_number('6008123')->is_valid_number, '京都府京都市下京区高宮町');
ok($zip->set_number('6008124')->is_valid_number, '京都府京都市下京区富松町');
ok($zip->set_number('6008125')->is_valid_number, '京都府京都市下京区富浜町');
ok($zip->set_number('6008126')->is_valid_number, '京都府京都市下京区鍵屋町(正面通木屋町東入、加茂川筋正面上る、正面通二ノ宮西');
ok($zip->set_number('6008126')->is_valid_number, '京都府京都市下京区入、木屋町通正面上る、正面通二ノ宮東入、正面通加茂川筋西入、二ノ宮');
ok($zip->set_number('6008126')->is_valid_number, '京都府京都市下京区通正面上る)');
ok($zip->set_number('6008127')->is_valid_number, '京都府京都市下京区梅湊町');
ok($zip->set_number('6008128')->is_valid_number, '京都府京都市下京区大工町(上ノ口通河原町東入、上ノ口通土手町西入、上ノ口通');
ok($zip->set_number('6008128')->is_valid_number, '京都府京都市下京区土手町東入、上ノ口通西木屋町西入、河原町通上ノ口上る、河原町通上ノ口');
ok($zip->set_number('6008128')->is_valid_number, '京都府京都市下京区下る、河原町通六条下る、土手町通上ノ口下る、土手町通正面上る、上枳殻馬場');
ok($zip->set_number('6008128')->is_valid_number, '京都府京都市下京区通河原町東入)');
ok($zip->set_number('6008129')->is_valid_number, '京都府京都市下京区溜池町');
ok($zip->set_number('6008130')->is_valid_number, '京都府京都市下京区紺屋町');
ok($zip->set_number('6008131')->is_valid_number, '京都府京都市下京区上二之宮町');
ok($zip->set_number('6008132')->is_valid_number, '京都府京都市下京区下二之宮町');
ok($zip->set_number('6008133')->is_valid_number, '京都府京都市下京区稲荷町(七条通加茂川筋西入、七条通木屋町東入)');
ok($zip->set_number('6008134')->is_valid_number, '京都府京都市下京区山王町(正面通木屋町西入、正面通木屋町東入、正面通三ノ宮');
ok($zip->set_number('6008134')->is_valid_number, '京都府京都市下京区西入、正面通三ノ宮東入、正面通二ノ宮西入)');
ok($zip->set_number('6008135')->is_valid_number, '京都府京都市下京区上三之宮町');
ok($zip->set_number('6008136')->is_valid_number, '京都府京都市下京区下三之宮町');
ok($zip->set_number('6008137')->is_valid_number, '京都府京都市下京区十禅師町');
ok($zip->set_number('6008138')->is_valid_number, '京都府京都市下京区大宮町');
ok($zip->set_number('6008139')->is_valid_number, '京都府京都市下京区八王子町');
ok($zip->set_number('6008141')->is_valid_number, '京都府京都市下京区新日吉町');
ok($zip->set_number('6008142')->is_valid_number, '京都府京都市下京区納屋町');
ok($zip->set_number('6008143')->is_valid_number, '京都府京都市下京区住吉町(河原町通七条上る、河原町通下枳殻馬場下る、下枳殻馬');
ok($zip->set_number('6008143')->is_valid_number, '京都府京都市下京区場通河原町西入、下珠数屋町通高倉東入)');
ok($zip->set_number('6008144')->is_valid_number, '京都府京都市下京区塩屋町(河原町通七条上る西入、七条通河原町西入上る、下枳');
ok($zip->set_number('6008144')->is_valid_number, '京都府京都市下京区殻馬場通河原町西入下る)');
ok($zip->set_number('6008145')->is_valid_number, '京都府京都市下京区皆山町');
ok($zip->set_number('6008146')->is_valid_number, '京都府京都市下京区材木町(間之町通七条下る、間之町通七条上る、河原町通七条上');
ok($zip->set_number('6008146')->is_valid_number, '京都府京都市下京区る、河原町通七条下る、七条通間之町西入、七条通間之町東入、七条通河原町西');
ok($zip->set_number('6008146')->is_valid_number, '京都府京都市下京区入、七条通河原町東入、七条通高倉西入、七条通高倉東入、七条通土手町');
ok($zip->set_number('6008146')->is_valid_number, '京都府京都市下京区西入、七条通東洞院東入、高倉通七条上る、高倉通七条下る、土手町通七条');
ok($zip->set_number('6008146')->is_valid_number, '京都府京都市下京区上る、東洞院通七条下る、柳馬場通七条上る)');
ok($zip->set_number('6008147')->is_valid_number, '京都府京都市下京区堀詰町');
ok($zip->set_number('6008148')->is_valid_number, '京都府京都市下京区飴屋町');
ok($zip->set_number('6008149')->is_valid_number, '京都府京都市下京区粉川町');
ok($zip->set_number('6008150')->is_valid_number, '京都府京都市下京区上珠数屋町');
ok($zip->set_number('6008151')->is_valid_number, '京都府京都市下京区打越町');
ok($zip->set_number('6008152')->is_valid_number, '京都府京都市下京区筒金町');
ok($zip->set_number('6008153')->is_valid_number, '京都府京都市下京区廿人講町');
ok($zip->set_number('6008154')->is_valid_number, '京都府京都市下京区榎木町');
ok($zip->set_number('6008155')->is_valid_number, '京都府京都市下京区西玉水町');
ok($zip->set_number('6008156')->is_valid_number, '京都府京都市下京区笹屋町');
ok($zip->set_number('6008157')->is_valid_number, '京都府京都市下京区橘町(下珠数屋町通不明門東入、下珠数屋町通烏丸東入、下珠数屋町通東洞院西入)');
ok($zip->set_number('6008158')->is_valid_number, '京都府京都市下京区卓屋町');
ok($zip->set_number('6008159')->is_valid_number, '京都府京都市下京区亀町');
ok($zip->set_number('6008160')->is_valid_number, '京都府京都市下京区西魚屋町');
ok($zip->set_number('6008161')->is_valid_number, '京都府京都市下京区大黒町(鍵屋町通室町西入、鍵屋町通室町東入、五条通室町東');
ok($zip->set_number('6008161')->is_valid_number, '京都府京都市下京区入、室町通鍵屋町上る、室町通楊梅上る、室町通楊梅下る)');
ok($zip->set_number('6008162')->is_valid_number, '京都府京都市下京区堺町(鍵屋町通室町西入、鍵屋町通室町東入、室町通鍵屋町下');
ok($zip->set_number('6008162')->is_valid_number, '京都府京都市下京区る、的場通室町西入、的場通室町東入、室町通五条下る2丁目、室町通六条');
ok($zip->set_number('6008162')->is_valid_number, '京都府京都市下京区上る、室町通的場上る)');
ok($zip->set_number('6008163')->is_valid_number, '京都府京都市下京区下諏訪町');
ok($zip->set_number('6008164')->is_valid_number, '京都府京都市下京区上柳町(諏訪町通花屋町上る、諏訪町通六条上る、諏訪町通六条下');
ok($zip->set_number('6008164')->is_valid_number, '京都府京都市下京区る、六条通烏丸西入、六条通諏訪町西入、六条通諏訪町東入、六条通室町');
ok($zip->set_number('6008164')->is_valid_number, '京都府京都市下京区東入)');
ok($zip->set_number('6008165')->is_valid_number, '京都府京都市下京区下柳町');
ok($zip->set_number('6008166')->is_valid_number, '京都府京都市下京区乾町');
ok($zip->set_number('6008167')->is_valid_number, '京都府京都市下京区常葉町');
ok($zip->set_number('6008168')->is_valid_number, '京都府京都市下京区八百屋町(室町新町ノ間六条下る、室町通花屋町上る、室町通六条下');
ok($zip->set_number('6008168')->is_valid_number, '京都府京都市下京区る、六条通新町東入下る、六条通室町西入、六条通室町西入下る)');
ok($zip->set_number('6008169')->is_valid_number, '京都府京都市下京区東魚屋町');
ok($zip->set_number('6008170')->is_valid_number, '京都府京都市下京区上諏訪町');
ok($zip->set_number('6008171')->is_valid_number, '京都府京都市下京区上平野町');
ok($zip->set_number('6008172')->is_valid_number, '京都府京都市下京区下平野町');
ok($zip->set_number('6008173')->is_valid_number, '京都府京都市下京区仏具屋町(不明門通五条下る2丁目、不明門通花屋町上る、不明門通');
ok($zip->set_number('6008173')->is_valid_number, '京都府京都市下京区六条上る、不明門通六条下る、花屋町通烏丸東入、花屋町通不明門西入、花');
ok($zip->set_number('6008173')->is_valid_number, '京都府京都市下京区屋町通不明門東入、六条通不明門西入、六条通不明門東入、六条通烏丸東');
ok($zip->set_number('6008173')->is_valid_number, '京都府京都市下京区入、六条通東洞院西入)');
ok($zip->set_number('6008174')->is_valid_number, '京都府京都市下京区高槻町');
ok($zip->set_number('6008175')->is_valid_number, '京都府京都市下京区烏丸(2丁目)');
ok($zip->set_number('6008176')->is_valid_number, '京都府京都市下京区北町');
ok($zip->set_number('6008177')->is_valid_number, '京都府京都市下京区大坂町');
ok($zip->set_number('6008178')->is_valid_number, '京都府京都市下京区鍵屋町(鍵屋町通烏丸西入、鍵屋町通諏訪町西入、鍵屋町通室');
ok($zip->set_number('6008178')->is_valid_number, '京都府京都市下京区町東入、諏訪町通鍵屋町上る、諏訪町通鍵屋町下る)');
ok($zip->set_number('6008179')->is_valid_number, '京都府京都市下京区横諏訪町');
ok($zip->set_number('6008180')->is_valid_number, '京都府京都市下京区下万寿寺町');
ok($zip->set_number('6008181')->is_valid_number, '京都府京都市下京区大津町');
ok($zip->set_number('6008182')->is_valid_number, '京都府京都市下京区塗師屋町(間之町通五条下る、間之町通五条下る2丁目、間之町');
ok($zip->set_number('6008182')->is_valid_number, '京都府京都市下京区六条上る、下坂通間之町西入、下坂通間之町東入、六条通間之町西入、六条');
ok($zip->set_number('6008182')->is_valid_number, '京都府京都市下京区通間之町東入、六条通高倉西入、六条通東洞院東入)');
ok($zip->set_number('6008183')->is_valid_number, '京都府京都市下京区夷之町(間之町通五条下る3丁目、間之町通花屋町上る、間之町通');
ok($zip->set_number('6008183')->is_valid_number, '京都府京都市下京区六条下る、花屋町通間之町西入、花屋町通間之町東入、花屋町通東洞院東入、');
ok($zip->set_number('6008183')->is_valid_number, '京都府京都市下京区六条通間之町西入、六条通間之町東入、六条通東洞院東入)');
ok($zip->set_number('6008184')->is_valid_number, '京都府京都市下京区天神町');
ok($zip->set_number('6008185')->is_valid_number, '京都府京都市下京区花屋町(上枳殻馬場通間之町西入、上珠数屋町通間之町西入、');
ok($zip->set_number('6008185')->is_valid_number, '京都府京都市下京区上珠数屋町通東洞院東入、東洞院通上枳殻馬場下る、間之町通上珠数屋町下る)');
ok($zip->set_number('6008186')->is_valid_number, '京都府京都市下京区富田町');
ok($zip->set_number('6008187')->is_valid_number, '京都府京都市下京区橋詰町');
ok($zip->set_number('6008188')->is_valid_number, '京都府京都市下京区和泉町');
ok($zip->set_number('6008189')->is_valid_number, '京都府京都市下京区福島町');
ok($zip->set_number('6008190')->is_valid_number, '京都府京都市下京区東玉水町');
ok($zip->set_number('6008191')->is_valid_number, '京都府京都市下京区堺町(五条通高倉西入、五条通高倉東入、高倉通五条下る)');
ok($zip->set_number('6008192')->is_valid_number, '京都府京都市下京区富屋町');
ok($zip->set_number('6008193')->is_valid_number, '京都府京都市下京区骨屋町(六条通高倉東入、六条通柳馬場西入)');
ok($zip->set_number('6008194')->is_valid_number, '京都府京都市下京区栄町');
ok($zip->set_number('6008195')->is_valid_number, '京都府京都市下京区升屋町');
ok($zip->set_number('6008196')->is_valid_number, '京都府京都市下京区八軒町');
ok($zip->set_number('6008197')->is_valid_number, '京都府京都市下京区唐物町');
ok($zip->set_number('6008198')->is_valid_number, '京都府京都市下京区若松町');
ok($zip->set_number('6008199')->is_valid_number, '京都府京都市下京区万屋町');
ok($zip->set_number('6008201')->is_valid_number, '京都府京都市下京区若宮町(加茂川筋七条下る、木屋町通七条下る、木屋町通七条下');
ok($zip->set_number('6008201')->is_valid_number, '京都府京都市下京区る東入、三ノ宮通七条下る、須原通七条下る、七条大橋西入、七条通加茂川筋');
ok($zip->set_number('6008201')->is_valid_number, '京都府京都市下京区西入、七条通加茂川筋西入下る)');
ok($zip->set_number('6008202')->is_valid_number, '京都府京都市下京区川端町(その他)');
ok($zip->set_number('6008203')->is_valid_number, '京都府京都市下京区屋形町');
ok($zip->set_number('6008204')->is_valid_number, '京都府京都市下京区東之町');
ok($zip->set_number('6008205')->is_valid_number, '京都府京都市下京区西之町');
ok($zip->set_number('6008206')->is_valid_number, '京都府京都市下京区下之町');
ok($zip->set_number('6008207')->is_valid_number, '京都府京都市下京区上之町(その他)');
ok($zip->set_number('6008208')->is_valid_number, '京都府京都市下京区小稲荷町');
ok($zip->set_number('6008209')->is_valid_number, '京都府京都市下京区郷之町');
ok($zip->set_number('6008210')->is_valid_number, '京都府京都市下京区桜木町');
ok($zip->set_number('6008211')->is_valid_number, '京都府京都市下京区真苧屋町');
ok($zip->set_number('6008212')->is_valid_number, '京都府京都市下京区塩小路町');
ok($zip->set_number('6008213')->is_valid_number, '京都府京都市下京区東塩小路向畑町');
ok($zip->set_number('6008214')->is_valid_number, '京都府京都市下京区東塩小路高倉町');
ok($zip->set_number('6008215')->is_valid_number, '京都府京都市下京区東塩小路釜殿町');
ok($zip->set_number('6008216')->is_valid_number, '京都府京都市下京区東塩小路町');
ok($zip->set_number('6008217')->is_valid_number, '京都府京都市下京区東境町');
ok($zip->set_number('6008218')->is_valid_number, '京都府京都市下京区西境町');
ok($zip->set_number('6008219')->is_valid_number, '京都府京都市下京区中居町');
ok($zip->set_number('6008221')->is_valid_number, '京都府京都市下京区高雄町');
ok($zip->set_number('6008222')->is_valid_number, '京都府京都市下京区文覚町');
ok($zip->set_number('6008223')->is_valid_number, '京都府京都市下京区大黒町(油小路通七条下る、七条通油小路東入、七条通西洞院西');
ok($zip->set_number('6008223')->is_valid_number, '京都府京都市下京区入、下魚棚通油小路東入、下魚棚通西洞院西入、西洞院通七条下る、東中');
ok($zip->set_number('6008223')->is_valid_number, '京都府京都市下京区筋通七条下る、東中筋通下魚棚下る)');
ok($zip->set_number('6008224')->is_valid_number, '京都府京都市下京区東町');
ok($zip->set_number('6008225')->is_valid_number, '京都府京都市下京区東大工町');
ok($zip->set_number('6008226')->is_valid_number, '京都府京都市下京区土橋町');
ok($zip->set_number('6008227')->is_valid_number, '京都府京都市下京区菱屋町');
ok($zip->set_number('6008228')->is_valid_number, '京都府京都市下京区北小路町');
ok($zip->set_number('6008229')->is_valid_number, '京都府京都市下京区米屋町');
ok($zip->set_number('6008231')->is_valid_number, '京都府京都市下京区油小路町');
ok($zip->set_number('6008232')->is_valid_number, '京都府京都市下京区南町');
ok($zip->set_number('6008233')->is_valid_number, '京都府京都市下京区北不動堂町');
ok($zip->set_number('6008234')->is_valid_number, '京都府京都市下京区南不動堂町');
ok($zip->set_number('6008235')->is_valid_number, '京都府京都市下京区東油小路町');
ok($zip->set_number('6008236')->is_valid_number, '京都府京都市下京区西油小路町');
ok($zip->set_number('6008237')->is_valid_number, '京都府京都市下京区松明町');
ok($zip->set_number('6008238')->is_valid_number, '京都府京都市下京区御方紺屋町');
ok($zip->set_number('6008239')->is_valid_number, '京都府京都市下京区鎌屋町');
ok($zip->set_number('6008241')->is_valid_number, '京都府京都市下京区志水町');
ok($zip->set_number('6008242')->is_valid_number, '京都府京都市下京区上夷町');
ok($zip->set_number('6008243')->is_valid_number, '京都府京都市下京区南夷町');
ok($zip->set_number('6008244')->is_valid_number, '京都府京都市下京区坊門中之町');
ok($zip->set_number('6008245')->is_valid_number, '京都府京都市下京区古御旅町');
ok($zip->set_number('6008246')->is_valid_number, '京都府京都市下京区垣ケ内町');
ok($zip->set_number('6008247')->is_valid_number, '京都府京都市下京区八条坊門町(塩小路通黒門西入)');
ok($zip->set_number('6008248')->is_valid_number, '京都府京都市下京区上中之町');
ok($zip->set_number('6008249')->is_valid_number, '京都府京都市下京区下糀屋町');
ok($zip->set_number('6008251')->is_valid_number, '京都府京都市下京区南八百屋町');
ok($zip->set_number('6008252')->is_valid_number, '京都府京都市下京区川端町(木津屋橋通堀川西入、堀川通木津屋橋上る)');
ok($zip->set_number('6008253')->is_valid_number, '京都府京都市下京区木津屋町');
ok($zip->set_number('6008254')->is_valid_number, '京都府京都市下京区伊勢松町');
ok($zip->set_number('6008255')->is_valid_number, '京都府京都市下京区清水町(堀川通木津屋橋下る、堀川通塩小路上る、西堀川通木津屋');
ok($zip->set_number('6008255')->is_valid_number, '京都府京都市下京区橋下る、堀川通塩小路西入)');
ok($zip->set_number('6008256')->is_valid_number, '京都府京都市下京区松本町(岩上通木津屋橋下る、岩上通塩小路上る)');
ok($zip->set_number('6008257')->is_valid_number, '京都府京都市下京区三軒替地町');
ok($zip->set_number('6008258')->is_valid_number, '京都府京都市下京区金換町');
ok($zip->set_number('6008259')->is_valid_number, '京都府京都市下京区上糀屋町');
ok($zip->set_number('6008261')->is_valid_number, '京都府京都市下京区花園町');
ok($zip->set_number('6008262')->is_valid_number, '京都府京都市下京区八百屋町(七条通猪熊通東入、七条通東堀川西入、七条通堀川西');
ok($zip->set_number('6008262')->is_valid_number, '京都府京都市下京区入、七条通堀川西入下る、東堀川通七条下る西入、下魚棚通堀川西入)');
ok($zip->set_number('6008263')->is_valid_number, '京都府京都市下京区下魚棚(4丁目)');
ok($zip->set_number('6008264')->is_valid_number, '京都府京都市下京区樽屋町');
ok($zip->set_number('6008265')->is_valid_number, '京都府京都市下京区徹宝町');
ok($zip->set_number('6008266')->is_valid_number, '京都府京都市下京区上之町(大宮通木津屋橋上る、大宮通七条下る、大宮通下魚棚下');
ok($zip->set_number('6008266')->is_valid_number, '京都府京都市下京区る、木津屋橋通大宮東入、下魚棚通大宮東入)');
ok($zip->set_number('6008267')->is_valid_number, '京都府京都市下京区御器屋町');
ok($zip->set_number('6008268')->is_valid_number, '京都府京都市下京区大工町(猪熊通七条上る、猪熊通七条下る、猪熊通下魚棚上る、七');
ok($zip->set_number('6008268')->is_valid_number, '京都府京都市下京区条通猪熊西入、七条通大宮東入、下魚棚通猪熊西入、下魚棚通大宮東入、');
ok($zip->set_number('6008268')->is_valid_number, '京都府京都市下京区下魚棚通大宮東入下る、下魚棚通黒門東入)');
ok($zip->set_number('6008269')->is_valid_number, '京都府京都市下京区西八百屋町');
ok($zip->set_number('6008301')->is_valid_number, '京都府京都市下京区上柳町(楊梅通新町東入、室町新町之間五条下る、楊梅通新町東入');
ok($zip->set_number('6008301')->is_valid_number, '京都府京都市下京区上る、楊梅通室町西入)');
ok($zip->set_number('6008302')->is_valid_number, '京都府京都市下京区蛭子町');
ok($zip->set_number('6008303')->is_valid_number, '京都府京都市下京区銭屋町');
ok($zip->set_number('6008304')->is_valid_number, '京都府京都市下京区艮町');
ok($zip->set_number('6008305')->is_valid_number, '京都府京都市下京区東若松町');
ok($zip->set_number('6008306')->is_valid_number, '京都府京都市下京区平野町');
ok($zip->set_number('6008307')->is_valid_number, '京都府京都市下京区辰巳町');
ok($zip->set_number('6008308')->is_valid_number, '京都府京都市下京区新シ町');
ok($zip->set_number('6008310')->is_valid_number, '京都府京都市下京区夷之町(七条通新町西入、七条通新町東入、七条通新町上る東');
ok($zip->set_number('6008310')->is_valid_number, '京都府京都市下京区入、七条通西洞院東入、新町通七条上る、新町通七条下る、新町通七条下る');
ok($zip->set_number('6008310')->is_valid_number, '京都府京都市下京区東入、西洞院通七条上る)');
ok($zip->set_number('6008311')->is_valid_number, '京都府京都市下京区毘沙門町');
ok($zip->set_number('6008312')->is_valid_number, '京都府京都市下京区上錫屋町');
ok($zip->set_number('6008313')->is_valid_number, '京都府京都市下京区上若宮町');
ok($zip->set_number('6008314')->is_valid_number, '京都府京都市下京区若宮町(新花屋町通若宮西入、新花屋町通若宮東入、六条通新');
ok($zip->set_number('6008314')->is_valid_number, '京都府京都市下京区町西入、六条通西洞院東入、六条通若宮西入、六条通若宮東入、若宮通');
ok($zip->set_number('6008314')->is_valid_number, '京都府京都市下京区新花屋町上る、若宮通新花屋町下る、若宮通花屋町上る、若宮通花屋町下る、若');
ok($zip->set_number('6008314')->is_valid_number, '京都府京都市下京区宮通六条下る)');
ok($zip->set_number('6008315')->is_valid_number, '京都府京都市下京区東松屋町');
ok($zip->set_number('6008316')->is_valid_number, '京都府京都市下京区四本松町');
ok($zip->set_number('6008317')->is_valid_number, '京都府京都市下京区鍵屋町(北小路通西洞院東入、北小路通若宮西入、正面通新町');
ok($zip->set_number('6008317')->is_valid_number, '京都府京都市下京区西入、若宮通正面下る、若宮通北小路上る、正面通若宮東入)');
ok($zip->set_number('6008318')->is_valid_number, '京都府京都市下京区井筒町');
ok($zip->set_number('6008319')->is_valid_number, '京都府京都市下京区竹屋町(若宮通北小路下る、若宮通七条上る)');
ok($zip->set_number('6008320')->is_valid_number, '京都府京都市下京区福本町');
ok($zip->set_number('6008321')->is_valid_number, '京都府京都市下京区八百屋町(西洞院通楊梅上る、西洞院通楊梅下る、楊梅通西洞院東');
ok($zip->set_number('6008321')->is_valid_number, '京都府京都市下京区入、楊梅通若宮西入)');
ok($zip->set_number('6008322')->is_valid_number, '京都府京都市下京区小柳町');
ok($zip->set_number('6008323')->is_valid_number, '京都府京都市下京区金屋町');
ok($zip->set_number('6008324')->is_valid_number, '京都府京都市下京区東側町');
ok($zip->set_number('6008325')->is_valid_number, '京都府京都市下京区西側町');
ok($zip->set_number('6008326')->is_valid_number, '京都府京都市下京区西松屋町');
ok($zip->set_number('6008327')->is_valid_number, '京都府京都市下京区西洞院町');
ok($zip->set_number('6008328')->is_valid_number, '京都府京都市下京区蛭子水町');
ok($zip->set_number('6008329')->is_valid_number, '京都府京都市下京区鍛冶屋町(北小路通西洞院西入、北小路通西洞院東入、西洞院通');
ok($zip->set_number('6008329')->is_valid_number, '京都府京都市下京区北小路上る、西洞院通正面下る)');
ok($zip->set_number('6008331')->is_valid_number, '京都府京都市下京区金東横町');
ok($zip->set_number('6008332')->is_valid_number, '京都府京都市下京区中金仏町');
ok($zip->set_number('6008333')->is_valid_number, '京都府京都市下京区卜味金仏町');
ok($zip->set_number('6008334')->is_valid_number, '京都府京都市下京区西若松町');
ok($zip->set_number('6008335')->is_valid_number, '京都府京都市下京区住吉町(醒ケ井通高辻下る、醒ケ井通松原上る)');
ok($zip->set_number('6008336')->is_valid_number, '京都府京都市下京区元日町');
ok($zip->set_number('6008337')->is_valid_number, '京都府京都市下京区佐女牛井町');
ok($zip->set_number('6008338')->is_valid_number, '京都府京都市下京区泉水町');
ok($zip->set_number('6008340')->is_valid_number, '京都府京都市下京区花屋町(花屋町通油小路西入)');
ok($zip->set_number('6008341')->is_valid_number, '京都府京都市下京区学林町');
ok($zip->set_number('6008342')->is_valid_number, '京都府京都市下京区山川町');
ok($zip->set_number('6008343')->is_valid_number, '京都府京都市下京区植松町(正面通西洞院西入、西洞院通正面下る)');
ok($zip->set_number('6008344')->is_valid_number, '京都府京都市下京区柳町');
ok($zip->set_number('6008345')->is_valid_number, '京都府京都市下京区紅葉町');
ok($zip->set_number('6008346')->is_valid_number, '京都府京都市下京区玉本町');
ok($zip->set_number('6008347')->is_valid_number, '京都府京都市下京区仏具屋町(油小路通正面上る、油小路通花屋町下る、正面通油小路');
ok($zip->set_number('6008347')->is_valid_number, '京都府京都市下京区東入、花屋町通油小路東入)');
ok($zip->set_number('6008348')->is_valid_number, '京都府京都市下京区珠数屋町');
ok($zip->set_number('6008349')->is_valid_number, '京都府京都市下京区堺町(堀川通旧花屋町東入、堀川通旧花屋町東入下る、堀川通正面上る)');
ok($zip->set_number('6008351')->is_valid_number, '京都府京都市下京区富永町(岩上通高辻上る、岩上通高辻下る、高辻通猪熊東入、高');
ok($zip->set_number('6008351')->is_valid_number, '京都府京都市下京区辻通岩上西入、高辻通岩上東入、高辻通西堀川西入、高辻通堀川西入)');
ok($zip->set_number('6008352')->is_valid_number, '京都府京都市下京区吉文字町(岩上通松原上る、岩上通高辻下る)');
ok($zip->set_number('6008353')->is_valid_number, '京都府京都市下京区高辻猪熊町');
ok($zip->set_number('6008354')->is_valid_number, '京都府京都市下京区十文字町');
ok($zip->set_number('6008355')->is_valid_number, '京都府京都市下京区来迎堂町');
ok($zip->set_number('6008356')->is_valid_number, '京都府京都市下京区北門前町');
ok($zip->set_number('6008357')->is_valid_number, '京都府京都市下京区柿本町');
ok($zip->set_number('6008358')->is_valid_number, '京都府京都市下京区門前町');
ok($zip->set_number('6008359')->is_valid_number, '京都府京都市下京区丸屋町(綾小路通猪熊西入、綾小路通大宮東入、綾小路通黒門西');
ok($zip->set_number('6008359')->is_valid_number, '京都府京都市下京区入、綾小路通黒門東入、猪熊通綾小路上る、黒門通綾小路上る、黒門通綾小');
ok($zip->set_number('6008359')->is_valid_number, '京都府京都市下京区路下る)');
ok($zip->set_number('6008361')->is_valid_number, '京都府京都市下京区堀之上町');
ok($zip->set_number('6008362')->is_valid_number, '京都府京都市下京区中堂寺前町');
ok($zip->set_number('6008363')->is_valid_number, '京都府京都市下京区大宮(1~3丁目)');
ok($zip->set_number('6008364')->is_valid_number, '京都府京都市下京区突抜(丁目)');
ok($zip->set_number('6008365')->is_valid_number, '京都府京都市下京区丹波街道町');
ok($zip->set_number('6008371')->is_valid_number, '京都府京都市下京区西門前町');
ok($zip->set_number('6008372')->is_valid_number, '京都府京都市下京区南門前町');
ok($zip->set_number('6008373')->is_valid_number, '京都府京都市下京区下五条町');
ok($zip->set_number('6008374')->is_valid_number, '京都府京都市下京区藪之内町');
ok($zip->set_number('6008375')->is_valid_number, '京都府京都市下京区下長福寺町');
ok($zip->set_number('6008376')->is_valid_number, '京都府京都市下京区上長福寺町');
ok($zip->set_number('6008377')->is_valid_number, '京都府京都市下京区上五条町');
ok($zip->set_number('6008381')->is_valid_number, '京都府京都市下京区下り松町');
ok($zip->set_number('6008382')->is_valid_number, '京都府京都市下京区塩屋町(黒門通綾小路下る、黒門通仏光寺上る)');
ok($zip->set_number('6008383')->is_valid_number, '京都府京都市下京区綾大宮町');
ok($zip->set_number('6008384')->is_valid_number, '京都府京都市下京区今大黒町');
ok($zip->set_number('6008385')->is_valid_number, '京都府京都市下京区五坊大宮町');
ok($zip->set_number('6008386')->is_valid_number, '京都府京都市下京区杉蛭子町');
ok($zip->set_number('6008387')->is_valid_number, '京都府京都市下京区高辻大宮町');
ok($zip->set_number('6008388')->is_valid_number, '京都府京都市下京区坊門町');
ok($zip->set_number('6008389')->is_valid_number, '京都府京都市下京区四条大宮町');
ok($zip->set_number('6008390')->is_valid_number, '京都府京都市下京区松本町(綾小路通猪熊東入、猪熊通綾小路上る、猪熊通四条下る)');
ok($zip->set_number('6008391')->is_valid_number, '京都府京都市下京区佐竹町');
ok($zip->set_number('6008392')->is_valid_number, '京都府京都市下京区妙満寺町');
ok($zip->set_number('6008393')->is_valid_number, '京都府京都市下京区雁金町(岩上通綾小路下る、岩上通仏光寺上る)');
ok($zip->set_number('6008394')->is_valid_number, '京都府京都市下京区晒屋町');
ok($zip->set_number('6008395')->is_valid_number, '京都府京都市下京区徳屋町');
ok($zip->set_number('6008396')->is_valid_number, '京都府京都市下京区槌屋町');
ok($zip->set_number('6008397')->is_valid_number, '京都府京都市下京区西田町');
ok($zip->set_number('6008398')->is_valid_number, '京都府京都市下京区瀬戸屋町');
ok($zip->set_number('6008399')->is_valid_number, '京都府京都市下京区丸屋町(北小路通西中筋東入、西中筋通北小路上る、西中筋通正');
ok($zip->set_number('6008399')->is_valid_number, '京都府京都市下京区面下る、北小路通堀川東入、堀川通北小路上る、堀川通正面下る)');
ok($zip->set_number('6008401')->is_valid_number, '京都府京都市下京区燈籠町');
ok($zip->set_number('6008402')->is_valid_number, '京都府京都市下京区大江町');
ok($zip->set_number('6008403')->is_valid_number, '京都府京都市下京区吉水町(不明門通松原下る、不明門通万寿寺上る)');
ok($zip->set_number('6008404')->is_valid_number, '京都府京都市下京区福田寺町');
ok($zip->set_number('6008405')->is_valid_number, '京都府京都市下京区万寿寺中之町');
ok($zip->set_number('6008406')->is_valid_number, '京都府京都市下京区亀屋町(高倉通五条上る、高倉通万寿寺下る)');
ok($zip->set_number('6008407')->is_valid_number, '京都府京都市下京区朝妻町');
ok($zip->set_number('6008408')->is_valid_number, '京都府京都市下京区深草町');
ok($zip->set_number('6008409')->is_valid_number, '京都府京都市下京区玉屋町');
ok($zip->set_number('6008410')->is_valid_number, '京都府京都市下京区悪王子町');
ok($zip->set_number('6008411')->is_valid_number, '京都府京都市下京区水銀屋町');
ok($zip->set_number('6008412')->is_valid_number, '京都府京都市下京区二帖半敷町');
ok($zip->set_number('6008413')->is_valid_number, '京都府京都市下京区大政所町');
ok($zip->set_number('6008414')->is_valid_number, '京都府京都市下京区匂天神町');
ok($zip->set_number('6008415')->is_valid_number, '京都府京都市下京区因幡堂町');
ok($zip->set_number('6008416')->is_valid_number, '京都府京都市下京区薬師前町');
ok($zip->set_number('6008417')->is_valid_number, '京都府京都市下京区俊成町');
ok($zip->set_number('6008418')->is_valid_number, '京都府京都市下京区五条烏丸町');
ok($zip->set_number('6008419')->is_valid_number, '京都府京都市下京区大堀町');
ok($zip->set_number('6008420')->is_valid_number, '京都府京都市下京区高砂町');
ok($zip->set_number('6008421')->is_valid_number, '京都府京都市下京区童侍者町');
ok($zip->set_number('6008422')->is_valid_number, '京都府京都市下京区白楽天町');
ok($zip->set_number('6008423')->is_valid_number, '京都府京都市下京区釘隠町');
ok($zip->set_number('6008424')->is_valid_number, '京都府京都市下京区山王町(室町通高辻上る、室町通仏光寺下る)');
ok($zip->set_number('6008425')->is_valid_number, '京都府京都市下京区骨屋町(諏訪町通高辻上る、諏訪町通高辻下る、高辻通烏丸西入、高辻通室町東入)');
ok($zip->set_number('6008426')->is_valid_number, '京都府京都市下京区小島町');
ok($zip->set_number('6008427')->is_valid_number, '京都府京都市下京区玉津島町');
ok($zip->set_number('6008428')->is_valid_number, '京都府京都市下京区弁財天町');
ok($zip->set_number('6008429')->is_valid_number, '京都府京都市下京区御供石町');
ok($zip->set_number('6008430')->is_valid_number, '京都府京都市下京区小田原町');
ok($zip->set_number('6008431')->is_valid_number, '京都府京都市下京区善長寺町');
ok($zip->set_number('6008432')->is_valid_number, '京都府京都市下京区糸屋町');
ok($zip->set_number('6008433')->is_valid_number, '京都府京都市下京区繁昌町');
ok($zip->set_number('6008434')->is_valid_number, '京都府京都市下京区高辻町');
ok($zip->set_number('6008435')->is_valid_number, '京都府京都市下京区中野之町');
ok($zip->set_number('6008436')->is_valid_number, '京都府京都市下京区元両替町');
ok($zip->set_number('6008437')->is_valid_number, '京都府京都市下京区徳万町');
ok($zip->set_number('6008438')->is_valid_number, '京都府京都市下京区長刀切町');
ok($zip->set_number('6008439')->is_valid_number, '京都府京都市下京区坂東屋町');
ok($zip->set_number('6008440')->is_valid_number, '京都府京都市下京区材木町(新町通五条上る、新町通万寿寺下る、万寿寺通新町西入、');
ok($zip->set_number('6008440')->is_valid_number, '京都府京都市下京区万寿寺通新町東入)');
ok($zip->set_number('6008441')->is_valid_number, '京都府京都市下京区四条町');
ok($zip->set_number('6008442')->is_valid_number, '京都府京都市下京区矢田町');
ok($zip->set_number('6008443')->is_valid_number, '京都府京都市下京区船鉾町');
ok($zip->set_number('6008444')->is_valid_number, '京都府京都市下京区菅大臣町');
ok($zip->set_number('6008445')->is_valid_number, '京都府京都市下京区岩戸山町');
ok($zip->set_number('6008446')->is_valid_number, '京都府京都市下京区堀之内町');
ok($zip->set_number('6008447')->is_valid_number, '京都府京都市下京区御影町');
ok($zip->set_number('6008448')->is_valid_number, '京都府京都市下京区藪下町');
ok($zip->set_number('6008449')->is_valid_number, '京都府京都市下京区富永町(新町通松原下る、新町通万寿寺上る、万寿寺通新町西入、');
ok($zip->set_number('6008449')->is_valid_number, '京都府京都市下京区万寿寺通新町東入)');
ok($zip->set_number('6008451')->is_valid_number, '京都府京都市下京区亀屋町(若宮通松原下る、若宮通万寿寺上る)');
ok($zip->set_number('6008452')->is_valid_number, '京都府京都市下京区永倉町');
ok($zip->set_number('6008453')->is_valid_number, '京都府京都市下京区月見町');
ok($zip->set_number('6008454')->is_valid_number, '京都府京都市下京区布屋町');
ok($zip->set_number('6008455')->is_valid_number, '京都府京都市下京区八幡町');
ok($zip->set_number('6008456')->is_valid_number, '京都府京都市下京区天使突抜(丁目)');
ok($zip->set_number('6008457')->is_valid_number, '京都府京都市下京区上金仏町');
ok($zip->set_number('6008458')->is_valid_number, '京都府京都市下京区樋口町');
ok($zip->set_number('6008459')->is_valid_number, '京都府京都市下京区天神前町');
ok($zip->set_number('6008460')->is_valid_number, '京都府京都市下京区荒神町');
ok($zip->set_number('6008461')->is_valid_number, '京都府京都市下京区木賊山町');
ok($zip->set_number('6008462')->is_valid_number, '京都府京都市下京区本柳水町');
ok($zip->set_number('6008463')->is_valid_number, '京都府京都市下京区永養寺町');
ok($zip->set_number('6008464')->is_valid_number, '京都府京都市下京区菊屋町(高辻通新町西入下る、高辻通西洞院東入下る、若宮通高辻');
ok($zip->set_number('6008464')->is_valid_number, '京都府京都市下京区下る、若宮通松原上る)');
ok($zip->set_number('6008465')->is_valid_number, '京都府京都市下京区高辻西洞院町');
ok($zip->set_number('6008466')->is_valid_number, '京都府京都市下京区舟屋町');
ok($zip->set_number('6008467')->is_valid_number, '京都府京都市下京区麓町');
ok($zip->set_number('6008468')->is_valid_number, '京都府京都市下京区住吉町(新花屋町通西中筋東入、西中筋通新花屋町上る、西中筋');
ok($zip->set_number('6008468')->is_valid_number, '京都府京都市下京区通新花屋町下る、西中筋通花屋町上る、西中筋通六条下る、新花屋町通堀川東');
ok($zip->set_number('6008468')->is_valid_number, '京都府京都市下京区入、堀川通新花屋町上る、堀川通新花屋町下る、堀川通花屋町上る、堀川通六条');
ok($zip->set_number('6008468')->is_valid_number, '京都府京都市下京区下る)');
ok($zip->set_number('6008469')->is_valid_number, '京都府京都市下京区太子山町');
ok($zip->set_number('6008471')->is_valid_number, '京都府京都市下京区新釜座町');
ok($zip->set_number('6008472')->is_valid_number, '京都府京都市下京区妙伝寺町');
ok($zip->set_number('6008473')->is_valid_number, '京都府京都市下京区芦刈山町');
ok($zip->set_number('6008474')->is_valid_number, '京都府京都市下京区綾西洞院町');
ok($zip->set_number('6008475')->is_valid_number, '京都府京都市下京区風早町');
ok($zip->set_number('6008476')->is_valid_number, '京都府京都市下京区喜吉町');
ok($zip->set_number('6008477')->is_valid_number, '京都府京都市下京区要法寺町');
ok($zip->set_number('6008478')->is_valid_number, '京都府京都市下京区西綾小路西半町');
ok($zip->set_number('6008479')->is_valid_number, '京都府京都市下京区西綾小路東半町');
ok($zip->set_number('6008480')->is_valid_number, '京都府京都市下京区小泉町');
ok($zip->set_number('6008481')->is_valid_number, '京都府京都市下京区四条堀川町');
ok($zip->set_number('6008482')->is_valid_number, '京都府京都市下京区綾堀川町');
ok($zip->set_number('6008483')->is_valid_number, '京都府京都市下京区吉水町(西堀川通高辻上る、西堀川通仏光寺下る、東堀川通高辻');
ok($zip->set_number('6008483')->is_valid_number, '京都府京都市下京区上る、東堀川通仏光寺下る、仏光寺通東堀川東入、堀川通仏光寺下る)');
ok($zip->set_number('6008484')->is_valid_number, '京都府京都市下京区西高辻町');
ok($zip->set_number('6008485')->is_valid_number, '京都府京都市下京区五軒町');
ok($zip->set_number('6008486')->is_valid_number, '京都府京都市下京区高辻堀川町');
ok($zip->set_number('6008487')->is_valid_number, '京都府京都市下京区橘町(醒ケ井通松原上る、醒ケ井通松原下る、松原通油小路西');
ok($zip->set_number('6008487')->is_valid_number, '京都府京都市下京区入、松原通醒ケ井西入、松原通醒ケ井東入、松原通東堀川東入、松原通堀');
ok($zip->set_number('6008487')->is_valid_number, '京都府京都市下京区川東入)');
ok($zip->set_number('6008488')->is_valid_number, '京都府京都市下京区篠屋町');
ok($zip->set_number('6008489')->is_valid_number, '京都府京都市下京区橋橘町');
ok($zip->set_number('6008490')->is_valid_number, '京都府京都市下京区立中町');
ok($zip->set_number('6008491')->is_valid_number, '京都府京都市下京区鶏鉾町');
ok($zip->set_number('6008492')->is_valid_number, '京都府京都市下京区月鉾町');
ok($zip->set_number('6008493')->is_valid_number, '京都府京都市下京区郭巨山町');
ok($zip->set_number('6008494')->is_valid_number, '京都府京都市下京区傘鉾町');
ok($zip->set_number('6008495')->is_valid_number, '京都府京都市下京区藤本寄町');
ok($zip->set_number('6008496')->is_valid_number, '京都府京都市下京区石井筒町');
ok($zip->set_number('6008497')->is_valid_number, '京都府京都市下京区高野堂町');
ok($zip->set_number('6008498')->is_valid_number, '京都府京都市下京区柏屋町(四条通油小路西入、四条通醒ケ井西入、四条通醒ケ井');
ok($zip->set_number('6008498')->is_valid_number, '京都府京都市下京区東入、四条通東堀川東入、四条通堀川東入)');
ok($zip->set_number('6008499')->is_valid_number, '京都府京都市下京区唐津屋町');
ok($zip->set_number('6008801')->is_valid_number, '京都府京都市下京区中堂寺西寺町');
ok($zip->set_number('6008802')->is_valid_number, '京都府京都市下京区中堂寺櫛笥町');
ok($zip->set_number('6008803')->is_valid_number, '京都府京都市下京区中堂寺薮ノ内町');
ok($zip->set_number('6008804')->is_valid_number, '京都府京都市下京区中堂寺前田町');
ok($zip->set_number('6008805')->is_valid_number, '京都府京都市下京区中堂寺鍵田町');
ok($zip->set_number('6008806')->is_valid_number, '京都府京都市下京区中堂寺壬生川町');
ok($zip->set_number('6008807')->is_valid_number, '京都府京都市下京区中堂寺命婦町');
ok($zip->set_number('6008811')->is_valid_number, '京都府京都市下京区中堂寺坊城町');
ok($zip->set_number('6008812')->is_valid_number, '京都府京都市下京区中堂寺北町');
ok($zip->set_number('6008813')->is_valid_number, '京都府京都市下京区中堂寺南町');
ok($zip->set_number('6008814')->is_valid_number, '京都府京都市下京区中堂寺庄ノ内町');
ok($zip->set_number('6008815')->is_valid_number, '京都府京都市下京区中堂寺粟田町');
ok($zip->set_number('6008816')->is_valid_number, '京都府京都市下京区西新屋敷中堂寺町');
ok($zip->set_number('6008821')->is_valid_number, '京都府京都市下京区小坂町');
ok($zip->set_number('6008822')->is_valid_number, '京都府京都市下京区裏片町');
ok($zip->set_number('6008823')->is_valid_number, '京都府京都市下京区薬園町');
ok($zip->set_number('6008824')->is_valid_number, '京都府京都市下京区二人司町');
ok($zip->set_number('6008825')->is_valid_number, '京都府京都市下京区西新屋敷中之町');
ok($zip->set_number('6008826')->is_valid_number, '京都府京都市下京区西新屋敷上之町');
ok($zip->set_number('6008827')->is_valid_number, '京都府京都市下京区西新屋敷太夫町');
ok($zip->set_number('6008828')->is_valid_number, '京都府京都市下京区西新屋敷揚屋町');
ok($zip->set_number('6008829')->is_valid_number, '京都府京都市下京区西新屋敷下之町');
ok($zip->set_number('6008831')->is_valid_number, '京都府京都市下京区花畑町');
ok($zip->set_number('6008832')->is_valid_number, '京都府京都市下京区諏訪開町');
ok($zip->set_number('6008833')->is_valid_number, '京都府京都市下京区西酢屋町');
ok($zip->set_number('6008834')->is_valid_number, '京都府京都市下京区和気町');
ok($zip->set_number('6008835')->is_valid_number, '京都府京都市下京区観喜寺町');
ok($zip->set_number('6008836')->is_valid_number, '京都府京都市下京区八条坊門町(八条通大宮西入)');
ok($zip->set_number('6008837')->is_valid_number, '京都府京都市下京区夷馬場町');
ok($zip->set_number('6008841')->is_valid_number, '京都府京都市下京区朱雀正会町');
ok($zip->set_number('6008842')->is_valid_number, '京都府京都市下京区朱雀堂ノ口町');
ok($zip->set_number('6008843')->is_valid_number, '京都府京都市下京区朱雀内畑町');
ok($zip->set_number('6008844')->is_valid_number, '京都府京都市下京区朱雀裏畑町');
ok($zip->set_number('6008845')->is_valid_number, '京都府京都市下京区朱雀北ノ口町');
ok($zip->set_number('6008846')->is_valid_number, '京都府京都市下京区朱雀宝蔵町');
ok($zip->set_number('6008847')->is_valid_number, '京都府京都市下京区朱雀分木町');
ok($zip->set_number('6008851')->is_valid_number, '京都府京都市下京区梅小路頭町');
ok($zip->set_number('6008852')->is_valid_number, '京都府京都市下京区梅小路東中町');
ok($zip->set_number('6008853')->is_valid_number, '京都府京都市下京区梅小路高畑町');
ok($zip->set_number('6008854')->is_valid_number, '京都府京都市下京区梅小路西中町');
ok($zip->set_number('6008855')->is_valid_number, '京都府京都市下京区梅小路石橋町');
ok($zip->set_number('6008856')->is_valid_number, '京都府京都市下京区梅小路本町');
ok($zip->set_number('6008857')->is_valid_number, '京都府京都市下京区梅小路東町');
ok($zip->set_number('6008861')->is_valid_number, '京都府京都市下京区七条御所ノ内北町');
ok($zip->set_number('6008862')->is_valid_number, '京都府京都市下京区七条御所ノ内中町');
ok($zip->set_number('6008863')->is_valid_number, '京都府京都市下京区七条御所ノ内本町');
ok($zip->set_number('6008864')->is_valid_number, '京都府京都市下京区七条御所ノ内南町');
ok($zip->set_number('6008865')->is_valid_number, '京都府京都市下京区七条御所ノ内西町');
ok($zip->set_number('6008871')->is_valid_number, '京都府京都市下京区西七条北東野町');
ok($zip->set_number('6008872')->is_valid_number, '京都府京都市下京区西七条南東野町');
ok($zip->set_number('6008873')->is_valid_number, '京都府京都市下京区西七条東久保町');
ok($zip->set_number('6008874')->is_valid_number, '京都府京都市下京区西七条西久保町');
ok($zip->set_number('6008875')->is_valid_number, '京都府京都市下京区西七条石井町');
ok($zip->set_number('6008876')->is_valid_number, '京都府京都市下京区西七条南中野町');
ok($zip->set_number('6008877')->is_valid_number, '京都府京都市下京区西七条南西野町');
ok($zip->set_number('6008878')->is_valid_number, '京都府京都市下京区西七条北西野町');
ok($zip->set_number('6008879')->is_valid_number, '京都府京都市下京区西七条中野町');
ok($zip->set_number('6008881')->is_valid_number, '京都府京都市下京区西七条掛越町');
ok($zip->set_number('6008882')->is_valid_number, '京都府京都市下京区西七条比輪田町');
ok($zip->set_number('6008883')->is_valid_number, '京都府京都市下京区西七条北衣田町');
ok($zip->set_number('6008884')->is_valid_number, '京都府京都市下京区西七条南衣田町');
ok($zip->set_number('6008885')->is_valid_number, '京都府京都市下京区西七条南月読町');
ok($zip->set_number('6008886')->is_valid_number, '京都府京都市下京区西七条北月読町');
ok($zip->set_number('6008887')->is_valid_number, '京都府京都市下京区西七条名倉町');
ok($zip->set_number('6008888')->is_valid_number, '京都府京都市下京区西七条八幡町');
ok($zip->set_number('6008891')->is_valid_number, '京都府京都市下京区西七条東八反田町');
ok($zip->set_number('6008892')->is_valid_number, '京都府京都市下京区西七条西八反田町');
ok($zip->set_number('6008893')->is_valid_number, '京都府京都市下京区西七条御領町');
ok($zip->set_number('6008894')->is_valid_number, '京都府京都市下京区西七条市部町');
ok($zip->set_number('6008895')->is_valid_number, '京都府京都市下京区西七条東石ケ坪町');
ok($zip->set_number('6008896')->is_valid_number, '京都府京都市下京区西七条西石ケ坪町');
ok($zip->set_number('6008897')->is_valid_number, '京都府京都市下京区西七条御前田町');
ok($zip->set_number('6008898')->is_valid_number, '京都府京都市下京区西七条東御前田町');
ok($zip->set_number('6008899')->is_valid_number, '京都府京都市下京区西七条赤社町');
ok($zip->set_number('6010000')->is_valid_number, '京都府京都市南区以下に掲載がない場合');
ok($zip->set_number('6010101')->is_valid_number, '京都府京都市北区真弓八幡町');
ok($zip->set_number('6010102')->is_valid_number, '京都府京都市北区真弓善福');
ok($zip->set_number('6010111')->is_valid_number, '京都府京都市北区杉阪北尾');
ok($zip->set_number('6010112')->is_valid_number, '京都府京都市北区杉阪都町');
ok($zip->set_number('6010113')->is_valid_number, '京都府京都市北区杉阪道風町');
ok($zip->set_number('6010121')->is_valid_number, '京都府京都市北区中川東山');
ok($zip->set_number('6010122')->is_valid_number, '京都府京都市北区中川北山町');
ok($zip->set_number('6010123')->is_valid_number, '京都府京都市北区中川西山');
ok($zip->set_number('6010124')->is_valid_number, '京都府京都市北区中川中山');
ok($zip->set_number('6010125')->is_valid_number, '京都府京都市北区中川川登');
ok($zip->set_number('6010131')->is_valid_number, '京都府京都市北区小野下ノ町');
ok($zip->set_number('6010132')->is_valid_number, '京都府京都市北区小野中ノ町');
ok($zip->set_number('6010133')->is_valid_number, '京都府京都市北区小野上ノ町');
ok($zip->set_number('6010134')->is_valid_number, '京都府京都市北区小野岩戸');
ok($zip->set_number('6010135')->is_valid_number, '京都府京都市北区小野宮ノ上町');
ok($zip->set_number('6010141')->is_valid_number, '京都府京都市北区大森稲荷');
ok($zip->set_number('6010142')->is_valid_number, '京都府京都市北区大森芦堂町');
ok($zip->set_number('6010143')->is_valid_number, '京都府京都市北区大森中町');
ok($zip->set_number('6010144')->is_valid_number, '京都府京都市北区大森西町');
ok($zip->set_number('6010145')->is_valid_number, '京都府京都市北区大森東町');
ok($zip->set_number('6010251')->is_valid_number, '京都府京都市右京区京北周山町');
ok($zip->set_number('6010252')->is_valid_number, '京都府京都市右京区京北五本松町');
ok($zip->set_number('6010261')->is_valid_number, '京都府京都市右京区京北柏原町');
ok($zip->set_number('6010262')->is_valid_number, '京都府京都市右京区京北細野町');
ok($zip->set_number('6010263')->is_valid_number, '京都府京都市右京区京北弓槻町');
ok($zip->set_number('6010264')->is_valid_number, '京都府京都市右京区京北栃本町');
ok($zip->set_number('6010265')->is_valid_number, '京都府京都市右京区京北中地町');
ok($zip->set_number('6010266')->is_valid_number, '京都府京都市右京区京北下宇津町');
ok($zip->set_number('6010271')->is_valid_number, '京都府京都市右京区京北熊田町');
ok($zip->set_number('6010272')->is_valid_number, '京都府京都市右京区京北下熊田町');
ok($zip->set_number('6010273')->is_valid_number, '京都府京都市右京区京北明石町');
ok($zip->set_number('6010274')->is_valid_number, '京都府京都市右京区京北浅江町');
ok($zip->set_number('6010275')->is_valid_number, '京都府京都市右京区京北宇野町');
ok($zip->set_number('6010276')->is_valid_number, '京都府京都市右京区京北西町');
ok($zip->set_number('6010277')->is_valid_number, '京都府京都市右京区京北漆谷町');
ok($zip->set_number('6010278')->is_valid_number, '京都府京都市右京区京北矢代中町');
ok($zip->set_number('6010311')->is_valid_number, '京都府京都市右京区京北小塩町');
ok($zip->set_number('6010312')->is_valid_number, '京都府京都市右京区京北初川町');
ok($zip->set_number('6010313')->is_valid_number, '京都府京都市右京区京北井戸町');
ok($zip->set_number('6010314')->is_valid_number, '京都府京都市右京区京北大野町');
ok($zip->set_number('6010315')->is_valid_number, '京都府京都市右京区京北中江町');
ok($zip->set_number('6010316')->is_valid_number, '京都府京都市右京区京北比賀江町');
ok($zip->set_number('6010321')->is_valid_number, '京都府京都市右京区京北塔町');
ok($zip->set_number('6010322')->is_valid_number, '京都府京都市右京区京北辻町');
ok($zip->set_number('6010323')->is_valid_number, '京都府京都市右京区京北鳥居町');
ok($zip->set_number('6010324')->is_valid_number, '京都府京都市右京区京北下町');
ok($zip->set_number('6010401')->is_valid_number, '京都府京都市右京区京北片波町');
ok($zip->set_number('6010402')->is_valid_number, '京都府京都市右京区京北上黒田町');
ok($zip->set_number('6010403')->is_valid_number, '京都府京都市右京区京北灰屋町');
ok($zip->set_number('6010404')->is_valid_number, '京都府京都市右京区京北芹生町');
ok($zip->set_number('6010405')->is_valid_number, '京都府京都市右京区京北下黒田町');
ok($zip->set_number('6010406')->is_valid_number, '京都府京都市右京区京北宮町');
ok($zip->set_number('6010531')->is_valid_number, '京都府京都市右京区京北上弓削町');
ok($zip->set_number('6010532')->is_valid_number, '京都府京都市右京区京北上中町');
ok($zip->set_number('6010533')->is_valid_number, '京都府京都市右京区京北下中町');
ok($zip->set_number('6010534')->is_valid_number, '京都府京都市右京区京北下弓削町');
ok($zip->set_number('6010535')->is_valid_number, '京都府京都市右京区京北井崎町');
ok($zip->set_number('6010536')->is_valid_number, '京都府京都市右京区京北塩田町');
ok($zip->set_number('6010541')->is_valid_number, '京都府京都市右京区京北赤石町');
ok($zip->set_number('6010542')->is_valid_number, '京都府京都市右京区京北田貫町');
ok($zip->set_number('6010543')->is_valid_number, '京都府京都市右京区京北室谷町');
ok($zip->set_number('6010701')->is_valid_number, '京都府南丹市美山町江和');
ok($zip->set_number('6010702')->is_valid_number, '京都府南丹市美山町田歌');
ok($zip->set_number('6010703')->is_valid_number, '京都府南丹市美山町芦生');
ok($zip->set_number('6010704')->is_valid_number, '京都府南丹市美山町白石');
ok($zip->set_number('6010705')->is_valid_number, '京都府南丹市美山町佐々里');
ok($zip->set_number('6010711')->is_valid_number, '京都府南丹市美山町南');
ok($zip->set_number('6010712')->is_valid_number, '京都府南丹市美山町北');
ok($zip->set_number('6010713')->is_valid_number, '京都府南丹市美山町中');
ok($zip->set_number('6010714')->is_valid_number, '京都府南丹市美山町河内谷');
ok($zip->set_number('6010715')->is_valid_number, '京都府南丹市美山町下');
ok($zip->set_number('6010716')->is_valid_number, '京都府南丹市美山町知見');
ok($zip->set_number('6010721')->is_valid_number, '京都府南丹市美山町上平屋');
ok($zip->set_number('6010722')->is_valid_number, '京都府南丹市美山町安掛');
ok($zip->set_number('6010723')->is_valid_number, '京都府南丹市美山町荒倉');
ok($zip->set_number('6010724')->is_valid_number, '京都府南丹市美山町内久保');
ok($zip->set_number('6010731')->is_valid_number, '京都府南丹市美山町又林');
ok($zip->set_number('6010732')->is_valid_number, '京都府南丹市美山町下平屋');
ok($zip->set_number('6010733')->is_valid_number, '京都府南丹市美山町野添');
ok($zip->set_number('6010734')->is_valid_number, '京都府南丹市美山町長尾');
ok($zip->set_number('6010735')->is_valid_number, '京都府南丹市美山町深見');
ok($zip->set_number('6010741')->is_valid_number, '京都府南丹市美山町原');
ok($zip->set_number('6010742')->is_valid_number, '京都府南丹市美山町板橋');
ok($zip->set_number('6010743')->is_valid_number, '京都府南丹市美山町宮脇');
ok($zip->set_number('6010744')->is_valid_number, '京都府南丹市美山町下吉田');
ok($zip->set_number('6010751')->is_valid_number, '京都府南丹市美山町島');
ok($zip->set_number('6010752')->is_valid_number, '京都府南丹市美山町長谷');
ok($zip->set_number('6010753')->is_valid_number, '京都府南丹市美山町上司');
ok($zip->set_number('6010754')->is_valid_number, '京都府南丹市美山町和泉');
ok($zip->set_number('6010755')->is_valid_number, '京都府南丹市美山町静原');
ok($zip->set_number('6010761')->is_valid_number, '京都府南丹市美山町高野');
ok($zip->set_number('6010762')->is_valid_number, '京都府南丹市美山町鶴ケ岡');
ok($zip->set_number('6010763')->is_valid_number, '京都府南丹市美山町豊郷');
ok($zip->set_number('6010764')->is_valid_number, '京都府南丹市美山町盛郷');
ok($zip->set_number('6010765')->is_valid_number, '京都府南丹市美山町福居');
ok($zip->set_number('6010771')->is_valid_number, '京都府南丹市美山町萱野');
ok($zip->set_number('6010772')->is_valid_number, '京都府南丹市美山町大野');
ok($zip->set_number('6010773')->is_valid_number, '京都府南丹市美山町三埜');
ok($zip->set_number('6010774')->is_valid_number, '京都府南丹市美山町肱谷');
ok($zip->set_number('6010775')->is_valid_number, '京都府南丹市美山町小渕');
ok($zip->set_number('6010776')->is_valid_number, '京都府南丹市美山町向山');
ok($zip->set_number('6010777')->is_valid_number, '京都府南丹市美山町樫原');
ok($zip->set_number('6010778')->is_valid_number, '京都府南丹市美山町音海');
ok($zip->set_number('6011101')->is_valid_number, '京都府京都市左京区広河原(各町)');
ok($zip->set_number('6011102')->is_valid_number, '京都府京都市左京区花脊原地町');
ok($zip->set_number('6011103')->is_valid_number, '京都府京都市左京区花脊八桝町');
ok($zip->set_number('6011104')->is_valid_number, '京都府京都市左京区花脊大布施町');
ok($zip->set_number('6011105')->is_valid_number, '京都府京都市左京区花脊別所町');
ok($zip->set_number('6011111')->is_valid_number, '京都府京都市左京区鞍馬本町');
ok($zip->set_number('6011112')->is_valid_number, '京都府京都市左京区鞍馬貴船町');
ok($zip->set_number('6011113')->is_valid_number, '京都府京都市左京区鞍馬二ノ瀬町');
ok($zip->set_number('6011121')->is_valid_number, '京都府京都市左京区静市静原町');
ok($zip->set_number('6011122')->is_valid_number, '京都府京都市左京区静市野中町');
ok($zip->set_number('6011123')->is_valid_number, '京都府京都市左京区静市市原町');
ok($zip->set_number('6011124')->is_valid_number, '京都府京都市左京区岩倉上蔵町(267、268番地)');
ok($zip->set_number('6011125')->is_valid_number, '京都府京都市左京区岩倉木野町(251番地)');
ok($zip->set_number('6011231')->is_valid_number, '京都府京都市左京区大原尾越町');
ok($zip->set_number('6011232')->is_valid_number, '京都府京都市左京区大原大見町');
ok($zip->set_number('6011233')->is_valid_number, '京都府京都市左京区大原百井町');
ok($zip->set_number('6011234')->is_valid_number, '京都府京都市左京区大原小出石町');
ok($zip->set_number('6011235')->is_valid_number, '京都府京都市左京区大原古知平町');
ok($zip->set_number('6011241')->is_valid_number, '京都府京都市左京区大原勝林院町');
ok($zip->set_number('6011242')->is_valid_number, '京都府京都市左京区大原来迎院町');
ok($zip->set_number('6011243')->is_valid_number, '京都府京都市左京区大原大長瀬町');
ok($zip->set_number('6011244')->is_valid_number, '京都府京都市左京区大原上野町');
ok($zip->set_number('6011245')->is_valid_number, '京都府京都市左京区大原戸寺町');
ok($zip->set_number('6011246')->is_valid_number, '京都府京都市左京区大原井出町');
ok($zip->set_number('6011247')->is_valid_number, '京都府京都市左京区大原野村町');
ok($zip->set_number('6011248')->is_valid_number, '京都府京都市左京区大原草生町');
ok($zip->set_number('6011251')->is_valid_number, '京都府京都市左京区八瀬花尻町');
ok($zip->set_number('6011252')->is_valid_number, '京都府京都市左京区八瀬秋元町');
ok($zip->set_number('6011253')->is_valid_number, '京都府京都市左京区八瀬近衛町');
ok($zip->set_number('6011254')->is_valid_number, '京都府京都市左京区八瀬野瀬町(その他)');
ok($zip->set_number('6011255')->is_valid_number, '京都府京都市左京区上高野東山(55、57-6、64、65、71-1、71-21、');
ok($zip->set_number('6011255')->is_valid_number, '京都府京都市左京区72、189、189-1番地)');
ok($zip->set_number('6011301')->is_valid_number, '京都府京都市伏見区醍醐上山田');
ok($zip->set_number('6011302')->is_valid_number, '京都府京都市伏見区醍醐内ケ井戸');
ok($zip->set_number('6011303')->is_valid_number, '京都府京都市伏見区醍醐大畑町');
ok($zip->set_number('6011304')->is_valid_number, '京都府京都市伏見区醍醐山ケ鼻');
ok($zip->set_number('6011305')->is_valid_number, '京都府京都市伏見区醍醐柿原町');
ok($zip->set_number('6011306')->is_valid_number, '京都府京都市伏見区醍醐連蔵');
ok($zip->set_number('6011307')->is_valid_number, '京都府京都市伏見区醍醐狭間');
ok($zip->set_number('6011308')->is_valid_number, '京都府京都市伏見区醍醐御所ノ内');
ok($zip->set_number('6011311')->is_valid_number, '京都府京都市伏見区醍醐大高町');
ok($zip->set_number('6011312')->is_valid_number, '京都府京都市伏見区醍醐片山町');
ok($zip->set_number('6011313')->is_valid_number, '京都府京都市伏見区醍醐御陵東裏町');
ok($zip->set_number('6011314')->is_valid_number, '京都府京都市伏見区醍醐御陵西裏町');
ok($zip->set_number('6011315')->is_valid_number, '京都府京都市伏見区醍醐烏橋町');
ok($zip->set_number('6011316')->is_valid_number, '京都府京都市伏見区醍醐古道町');
ok($zip->set_number('6011317')->is_valid_number, '京都府京都市伏見区醍醐京道町');
ok($zip->set_number('6011318')->is_valid_number, '京都府京都市伏見区醍醐廻り戸町');
ok($zip->set_number('6011321')->is_valid_number, '京都府京都市伏見区醍醐北端山');
ok($zip->set_number('6011322')->is_valid_number, '京都府京都市伏見区醍醐北伽藍町');
ok($zip->set_number('6011323')->is_valid_number, '京都府京都市伏見区醍醐赤間南裏町');
ok($zip->set_number('6011324')->is_valid_number, '京都府京都市伏見区醍醐伽藍町');
ok($zip->set_number('6011325')->is_valid_number, '京都府京都市伏見区醍醐東大路町');
ok($zip->set_number('6011326')->is_valid_number, '京都府京都市伏見区醍醐新町裏町');
ok($zip->set_number('6011327')->is_valid_number, '京都府京都市伏見区醍醐切レ戸町');
ok($zip->set_number('6011331')->is_valid_number, '京都府京都市伏見区醍醐南端山町');
ok($zip->set_number('6011332')->is_valid_number, '京都府京都市伏見区醍醐下端山町');
ok($zip->set_number('6011333')->is_valid_number, '京都府京都市伏見区醍醐上端山町');
ok($zip->set_number('6011334')->is_valid_number, '京都府京都市伏見区醍醐勝口町');
ok($zip->set_number('6011335')->is_valid_number, '京都府京都市伏見区醍醐一言寺裏町');
ok($zip->set_number('6011336')->is_valid_number, '京都府京都市伏見区醍醐柏森町');
ok($zip->set_number('6011337')->is_valid_number, '京都府京都市伏見区醍醐槇ノ内町');
ok($zip->set_number('6011338')->is_valid_number, '京都府京都市伏見区醍醐落保町');
ok($zip->set_number('6011341')->is_valid_number, '京都府京都市伏見区醍醐岸ノ上町');
ok($zip->set_number('6011342')->is_valid_number, '京都府京都市伏見区醍醐上山口町');
ok($zip->set_number('6011343')->is_valid_number, '京都府京都市伏見区醍醐下山口町');
ok($zip->set_number('6011344')->is_valid_number, '京都府京都市伏見区醍醐辰巳町');
ok($zip->set_number('6011345')->is_valid_number, '京都府京都市伏見区醍醐外山街道町');
ok($zip->set_number('6011346')->is_valid_number, '京都府京都市伏見区醍醐東合場町');
ok($zip->set_number('6011347')->is_valid_number, '京都府京都市伏見区醍醐合場町');
ok($zip->set_number('6011351')->is_valid_number, '京都府京都市伏見区醍醐和泉町');
ok($zip->set_number('6011352')->is_valid_number, '京都府京都市伏見区醍醐南里町');
ok($zip->set_number('6011353')->is_valid_number, '京都府京都市伏見区醍醐御園尾町');
ok($zip->set_number('6011354')->is_valid_number, '京都府京都市伏見区醍醐構口町');
ok($zip->set_number('6011355')->is_valid_number, '京都府京都市伏見区醍醐多近田町');
ok($zip->set_number('6011356')->is_valid_number, '京都府京都市伏見区醍醐南西裏町');
ok($zip->set_number('6011357')->is_valid_number, '京都府京都市伏見区醍醐僧尊坊町');
ok($zip->set_number('6011361')->is_valid_number, '京都府京都市伏見区醍醐御霊ケ下町');
ok($zip->set_number('6011362')->is_valid_number, '京都府京都市伏見区醍醐池田町');
ok($zip->set_number('6011363')->is_valid_number, '京都府京都市伏見区醍醐鍵尾町');
ok($zip->set_number('6011364')->is_valid_number, '京都府京都市伏見区醍醐江奈志町');
ok($zip->set_number('6011365')->is_valid_number, '京都府京都市伏見区醍醐新開');
ok($zip->set_number('6011366')->is_valid_number, '京都府京都市伏見区醍醐大構町');
ok($zip->set_number('6011371')->is_valid_number, '京都府京都市伏見区醍醐上ノ山町');
ok($zip->set_number('6011372')->is_valid_number, '京都府京都市伏見区醍醐平松町');
ok($zip->set_number('6011373')->is_valid_number, '京都府京都市伏見区醍醐中山町');
ok($zip->set_number('6011374')->is_valid_number, '京都府京都市伏見区醍醐西大路町');
ok($zip->set_number('6011375')->is_valid_number, '京都府京都市伏見区醍醐高畑町');
ok($zip->set_number('6011376')->is_valid_number, '京都府京都市伏見区醍醐折戸町');
ok($zip->set_number('6011377')->is_valid_number, '京都府京都市伏見区醍醐北西裏町');
ok($zip->set_number('6011378')->is_valid_number, '京都府京都市伏見区醍醐川久保町');
ok($zip->set_number('6011381')->is_valid_number, '京都府京都市伏見区醍醐北谷');
ok($zip->set_number('6011382')->is_valid_number, '京都府京都市伏見区醍醐南谷');
ok($zip->set_number('6011383')->is_valid_number, '京都府京都市伏見区醍醐醍醐山');
ok($zip->set_number('6011384')->is_valid_number, '京都府京都市伏見区醍醐高田');
ok($zip->set_number('6011385')->is_valid_number, '京都府京都市伏見区醍醐宮ノ下町');
ok($zip->set_number('6011386')->is_valid_number, '京都府京都市伏見区醍醐陀羅谷');
ok($zip->set_number('6011387')->is_valid_number, '京都府京都市伏見区醍醐一ノ切町');
ok($zip->set_number('6011387')->is_valid_number, '京都府京都市伏見区醍醐三ノ切');
ok($zip->set_number('6011387')->is_valid_number, '京都府京都市伏見区醍醐二ノ切町');
ok($zip->set_number('6011391')->is_valid_number, '京都府宇治市東笠取');
ok($zip->set_number('6011392')->is_valid_number, '京都府宇治市西笠取');
ok($zip->set_number('6011393')->is_valid_number, '京都府宇治市二尾');
ok($zip->set_number('6011394')->is_valid_number, '京都府宇治市池尾');
ok($zip->set_number('6011395')->is_valid_number, '京都府宇治市炭山');
ok($zip->set_number('6011396')->is_valid_number, '京都府宇治市莵道東垣内');
ok($zip->set_number('6011401')->is_valid_number, '京都府京都市伏見区日野北山');
ok($zip->set_number('6011402')->is_valid_number, '京都府京都市伏見区日野南山');
ok($zip->set_number('6011403')->is_valid_number, '京都府京都市伏見区日野船尾');
ok($zip->set_number('6011404')->is_valid_number, '京都府京都市伏見区日野北川頬');
ok($zip->set_number('6011405')->is_valid_number, '京都府京都市伏見区日野林');
ok($zip->set_number('6011406')->is_valid_number, '京都府京都市伏見区日野谷寺町');
ok($zip->set_number('6011411')->is_valid_number, '京都府京都市伏見区日野慈悲町');
ok($zip->set_number('6011412')->is_valid_number, '京都府京都市伏見区日野畑出町');
ok($zip->set_number('6011413')->is_valid_number, '京都府京都市伏見区日野谷田町');
ok($zip->set_number('6011414')->is_valid_number, '京都府京都市伏見区日野奥出');
ok($zip->set_number('6011415')->is_valid_number, '京都府京都市伏見区日野野色町');
ok($zip->set_number('6011416')->is_valid_number, '京都府京都市伏見区日野岡西町');
ok($zip->set_number('6011417')->is_valid_number, '京都府京都市伏見区日野西大道町');
ok($zip->set_number('6011421')->is_valid_number, '京都府京都市伏見区日野馬場出町');
ok($zip->set_number('6011422')->is_valid_number, '京都府京都市伏見区日野不動講町');
ok($zip->set_number('6011423')->is_valid_number, '京都府京都市伏見区日野西風呂町');
ok($zip->set_number('6011424')->is_valid_number, '京都府京都市伏見区日野田頬町');
ok($zip->set_number('6011425')->is_valid_number, '京都府京都市伏見区日野田中町');
ok($zip->set_number('6011426')->is_valid_number, '京都府京都市伏見区日野西川頬');
ok($zip->set_number('6011431')->is_valid_number, '京都府京都市伏見区石田大受町');
ok($zip->set_number('6011432')->is_valid_number, '京都府京都市伏見区石田内里町');
ok($zip->set_number('6011433')->is_valid_number, '京都府京都市伏見区石田大山町');
ok($zip->set_number('6011434')->is_valid_number, '京都府京都市伏見区石田森南町');
ok($zip->set_number('6011435')->is_valid_number, '京都府京都市伏見区石田桜木');
ok($zip->set_number('6011436')->is_valid_number, '京都府京都市伏見区石田西ノ坪');
ok($zip->set_number('6011437')->is_valid_number, '京都府京都市伏見区石田森西');
ok($zip->set_number('6011438')->is_valid_number, '京都府京都市伏見区石田川向');
ok($zip->set_number('6011439')->is_valid_number, '京都府京都市伏見区石田森東町');
ok($zip->set_number('6011441')->is_valid_number, '京都府京都市伏見区小栗栖北谷町');
ok($zip->set_number('6011442')->is_valid_number, '京都府京都市伏見区小栗栖丸山');
ok($zip->set_number('6011443')->is_valid_number, '京都府京都市伏見区小栗栖岩ケ淵町');
ok($zip->set_number('6011444')->is_valid_number, '京都府京都市伏見区小栗栖牛ケ淵町');
ok($zip->set_number('6011445')->is_valid_number, '京都府京都市伏見区小栗栖森ケ淵町');
ok($zip->set_number('6011446')->is_valid_number, '京都府京都市伏見区小栗栖北後藤町');
ok($zip->set_number('6011451')->is_valid_number, '京都府京都市伏見区小栗栖鉢伏');
ok($zip->set_number('6011452')->is_valid_number, '京都府京都市伏見区小栗栖西ノ峯');
ok($zip->set_number('6011453')->is_valid_number, '京都府京都市伏見区小栗栖西谷町');
ok($zip->set_number('6011454')->is_valid_number, '京都府京都市伏見区小栗栖山口町');
ok($zip->set_number('6011455')->is_valid_number, '京都府京都市伏見区小栗栖小阪町');
ok($zip->set_number('6011456')->is_valid_number, '京都府京都市伏見区小栗栖南後藤町');
ok($zip->set_number('6011461')->is_valid_number, '京都府京都市伏見区小栗栖宮山');
ok($zip->set_number('6011462')->is_valid_number, '京都府京都市伏見区小栗栖森本町');
ok($zip->set_number('6011463')->is_valid_number, '京都府京都市伏見区小栗栖中山田町');
ok($zip->set_number('6011464')->is_valid_number, '京都府京都市伏見区小栗栖石川町');
ok($zip->set_number('6018001')->is_valid_number, '京都府京都市南区東九条室町');
ok($zip->set_number('6018002')->is_valid_number, '京都府京都市南区東九条上殿田町');
ok($zip->set_number('6018003')->is_valid_number, '京都府京都市南区東九条西山王町');
ok($zip->set_number('6018004')->is_valid_number, '京都府京都市南区東九条東山王町');
ok($zip->set_number('6018005')->is_valid_number, '京都府京都市南区東九条西岩本町');
ok($zip->set_number('6018006')->is_valid_number, '京都府京都市南区東九条東岩本町');
ok($zip->set_number('6018007')->is_valid_number, '京都府京都市南区東九条北河原町');
ok($zip->set_number('6018011')->is_valid_number, '京都府京都市南区東九条南山王町');
ok($zip->set_number('6018012')->is_valid_number, '京都府京都市南区東九条南岩本町');
ok($zip->set_number('6018013')->is_valid_number, '京都府京都市南区東九条南河原町');
ok($zip->set_number('6018014')->is_valid_number, '京都府京都市南区東九条河西町');
ok($zip->set_number('6018015')->is_valid_number, '京都府京都市南区東九条上御霊町');
ok($zip->set_number('6018016')->is_valid_number, '京都府京都市南区東九条烏丸町');
ok($zip->set_number('6018017')->is_valid_number, '京都府京都市南区東九条北烏丸町');
ok($zip->set_number('6018021')->is_valid_number, '京都府京都市南区東九条宇賀辺町');
ok($zip->set_number('6018022')->is_valid_number, '京都府京都市南区東九条北松ノ木町');
ok($zip->set_number('6018023')->is_valid_number, '京都府京都市南区東九条南松ノ木町');
ok($zip->set_number('6018024')->is_valid_number, '京都府京都市南区東九条東札辻町');
ok($zip->set_number('6018025')->is_valid_number, '京都府京都市南区東九条柳下町');
ok($zip->set_number('6018026')->is_valid_number, '京都府京都市南区東九条中札辻町');
ok($zip->set_number('6018027')->is_valid_number, '京都府京都市南区東九条中御霊町');
ok($zip->set_number('6018028')->is_valid_number, '京都府京都市南区東九条東御霊町');
ok($zip->set_number('6018029')->is_valid_number, '京都府京都市南区東九条東松ノ木町');
ok($zip->set_number('6018031')->is_valid_number, '京都府京都市南区東九条河辺町');
ok($zip->set_number('6018032')->is_valid_number, '京都府京都市南区東九条石田町');
ok($zip->set_number('6018033')->is_valid_number, '京都府京都市南区東九条南石田町');
ok($zip->set_number('6018034')->is_valid_number, '京都府京都市南区東九条南河辺町');
ok($zip->set_number('6018035')->is_valid_number, '京都府京都市南区東九条南松田町');
ok($zip->set_number('6018036')->is_valid_number, '京都府京都市南区東九条松田町');
ok($zip->set_number('6018037')->is_valid_number, '京都府京都市南区東九条西河辺町');
ok($zip->set_number('6018041')->is_valid_number, '京都府京都市南区東九条南烏丸町');
ok($zip->set_number('6018042')->is_valid_number, '京都府京都市南区東九条西御霊町');
ok($zip->set_number('6018043')->is_valid_number, '京都府京都市南区東九条西札辻町');
ok($zip->set_number('6018044')->is_valid_number, '京都府京都市南区東九条明田町');
ok($zip->set_number('6018045')->is_valid_number, '京都府京都市南区東九条西明田町');
ok($zip->set_number('6018046')->is_valid_number, '京都府京都市南区東九条西山町');
ok($zip->set_number('6018047')->is_valid_number, '京都府京都市南区東九条下殿田町');
ok($zip->set_number('6018048')->is_valid_number, '京都府京都市南区東九条中殿田町');
ok($zip->set_number('6018101')->is_valid_number, '京都府京都市南区上鳥羽高畠町');
ok($zip->set_number('6018102')->is_valid_number, '京都府京都市南区上鳥羽菅田町');
ok($zip->set_number('6018103')->is_valid_number, '京都府京都市南区上鳥羽仏現寺町');
ok($zip->set_number('6018104')->is_valid_number, '京都府京都市南区上鳥羽角田町');
ok($zip->set_number('6018105')->is_valid_number, '京都府京都市南区上鳥羽上調子町');
ok($zip->set_number('6018106')->is_valid_number, '京都府京都市南区上鳥羽北中ノ坪町');
ok($zip->set_number('6018107')->is_valid_number, '京都府京都市南区上鳥羽南唐戸町');
ok($zip->set_number('6018108')->is_valid_number, '京都府京都市南区上鳥羽唐戸町');
ok($zip->set_number('6018111')->is_valid_number, '京都府京都市南区上鳥羽苗代町');
ok($zip->set_number('6018112')->is_valid_number, '京都府京都市南区上鳥羽勧進橋町');
ok($zip->set_number('6018113')->is_valid_number, '京都府京都市南区上鳥羽南苗代町');
ok($zip->set_number('6018114')->is_valid_number, '京都府京都市南区上鳥羽南鉾立町');
ok($zip->set_number('6018115')->is_valid_number, '京都府京都市南区上鳥羽尻切町');
ok($zip->set_number('6018116')->is_valid_number, '京都府京都市南区上鳥羽鉾立町');
ok($zip->set_number('6018121')->is_valid_number, '京都府京都市南区上鳥羽大物町');
ok($zip->set_number('6018122')->is_valid_number, '京都府京都市南区上鳥羽北塔ノ本町');
ok($zip->set_number('6018123')->is_valid_number, '京都府京都市南区上鳥羽南塔ノ本町');
ok($zip->set_number('6018126')->is_valid_number, '京都府京都市南区上鳥羽南花名町');
ok($zip->set_number('6018127')->is_valid_number, '京都府京都市南区上鳥羽北花名町');
ok($zip->set_number('6018128')->is_valid_number, '京都府京都市南区上鳥羽大柳町');
ok($zip->set_number('6018131')->is_valid_number, '京都府京都市南区上鳥羽鴨田町');
ok($zip->set_number('6018132')->is_valid_number, '京都府京都市南区上鳥羽町田町');
ok($zip->set_number('6018133')->is_valid_number, '京都府京都市南区上鳥羽藁田町');
ok($zip->set_number('6018134')->is_valid_number, '京都府京都市南区上鳥羽大溝町');
ok($zip->set_number('6018135')->is_valid_number, '京都府京都市南区上鳥羽石橋町');
ok($zip->set_number('6018136')->is_valid_number, '京都府京都市南区上鳥羽岩ノ本町');
ok($zip->set_number('6018137')->is_valid_number, '京都府京都市南区上鳥羽城ケ前町');
ok($zip->set_number('6018138')->is_valid_number, '京都府京都市南区上鳥羽北岩ノ本町');
ok($zip->set_number('6018139')->is_valid_number, '京都府京都市南区上鳥羽南岩ノ本町');
ok($zip->set_number('6018141')->is_valid_number, '京都府京都市南区上鳥羽卯ノ花町');
ok($zip->set_number('6018142')->is_valid_number, '京都府京都市南区上鳥羽中河原町');
ok($zip->set_number('6018143')->is_valid_number, '京都府京都市南区上鳥羽麻ノ本町');
ok($zip->set_number('6018144')->is_valid_number, '京都府京都市南区上鳥羽火打形町');
ok($zip->set_number('6018145')->is_valid_number, '京都府京都市南区上鳥羽西浦町');
ok($zip->set_number('6018146')->is_valid_number, '京都府京都市南区上鳥羽奈須野町');
ok($zip->set_number('6018151')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森東向町');
ok($zip->set_number('6018152')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森洲崎町');
ok($zip->set_number('6018153')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森下河原');
ok($zip->set_number('6018154')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森柳原');
ok($zip->set_number('6018155')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森上河原');
ok($zip->set_number('6018161')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森梅ノ木');
ok($zip->set_number('6018162')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森柴東町');
ok($zip->set_number('6018163')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森江川町');
ok($zip->set_number('6018164')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森四ツ谷町');
ok($zip->set_number('6018165')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森西河原町');
ok($zip->set_number('6018166')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森下開ノ内');
ok($zip->set_number('6018167')->is_valid_number, '京都府京都市南区上鳥羽塔ノ森上開ノ内');
ok($zip->set_number('6018171')->is_valid_number, '京都府京都市南区上鳥羽川端町');
ok($zip->set_number('6018172')->is_valid_number, '京都府京都市南区上鳥羽鍋ケ渕町');
ok($zip->set_number('6018173')->is_valid_number, '京都府京都市南区上鳥羽八王神町');
ok($zip->set_number('6018174')->is_valid_number, '京都府京都市南区上鳥羽清井町');
ok($zip->set_number('6018175')->is_valid_number, '京都府京都市南区上鳥羽金仏町');
ok($zip->set_number('6018176')->is_valid_number, '京都府京都市南区上鳥羽山ノ本町');
ok($zip->set_number('6018177')->is_valid_number, '京都府京都市南区上鳥羽馬廻町');
ok($zip->set_number('6018178')->is_valid_number, '京都府京都市南区上鳥羽南戒光町');
ok($zip->set_number('6018181')->is_valid_number, '京都府京都市南区上鳥羽堀子町');
ok($zip->set_number('6018182')->is_valid_number, '京都府京都市南区上鳥羽北島田町');
ok($zip->set_number('6018183')->is_valid_number, '京都府京都市南区上鳥羽南島田町');
ok($zip->set_number('6018184')->is_valid_number, '京都府京都市南区上鳥羽南村山町');
ok($zip->set_number('6018185')->is_valid_number, '京都府京都市南区上鳥羽戒光町');
ok($zip->set_number('6018186')->is_valid_number, '京都府京都市南区上鳥羽北戒光町');
ok($zip->set_number('6018187')->is_valid_number, '京都府京都市南区上鳥羽北村山町');
ok($zip->set_number('6018188')->is_valid_number, '京都府京都市南区上鳥羽南中ノ坪町');
ok($zip->set_number('6018201')->is_valid_number, '京都府京都市南区久世川原町');
ok($zip->set_number('6018202')->is_valid_number, '京都府京都市南区久世大築町');
ok($zip->set_number('6018203')->is_valid_number, '京都府京都市南区久世築山町');
ok($zip->set_number('6018204')->is_valid_number, '京都府京都市南区久世東土川町');
ok($zip->set_number('6018205')->is_valid_number, '京都府京都市南区久世殿城町');
ok($zip->set_number('6018206')->is_valid_number, '京都府京都市南区久世大薮町');
ok($zip->set_number('6018207')->is_valid_number, '京都府京都市南区久世中久町');
ok($zip->set_number('6018211')->is_valid_number, '京都府京都市南区久世高田町');
ok($zip->set_number('6018212')->is_valid_number, '京都府京都市南区久世上久世町');
ok($zip->set_number('6018213')->is_valid_number, '京都府京都市南区久世中久世町');
ok($zip->set_number('6018301')->is_valid_number, '京都府京都市南区吉祥院西ノ庄西浦町');
ok($zip->set_number('6018302')->is_valid_number, '京都府京都市南区吉祥院西ノ庄淵ノ西町');
ok($zip->set_number('6018303')->is_valid_number, '京都府京都市南区吉祥院西ノ庄西中町');
ok($zip->set_number('6018304')->is_valid_number, '京都府京都市南区吉祥院前河原町');
ok($zip->set_number('6018305')->is_valid_number, '京都府京都市南区吉祥院宮ノ東町');
ok($zip->set_number('6018306')->is_valid_number, '京都府京都市南区吉祥院宮ノ西町');
ok($zip->set_number('6018307')->is_valid_number, '京都府京都市南区吉祥院向田西町');
ok($zip->set_number('6018308')->is_valid_number, '京都府京都市南区吉祥院向田東町');
ok($zip->set_number('6018309')->is_valid_number, '京都府京都市南区吉祥院西ノ庄向田町');
ok($zip->set_number('6018310')->is_valid_number, '京都府京都市南区吉祥院西ノ庄猪之馬場町');
ok($zip->set_number('6018311')->is_valid_number, '京都府京都市南区吉祥院西ノ庄東屋敷町');
ok($zip->set_number('6018312')->is_valid_number, '京都府京都市南区吉祥院西ノ庄門口町');
ok($zip->set_number('6018313')->is_valid_number, '京都府京都市南区吉祥院中島町');
ok($zip->set_number('6018314')->is_valid_number, '京都府京都市南区吉祥院井ノ口町');
ok($zip->set_number('6018315')->is_valid_number, '京都府京都市南区吉祥院車道町');
ok($zip->set_number('6018316')->is_valid_number, '京都府京都市南区吉祥院池ノ内町');
ok($zip->set_number('6018317')->is_valid_number, '京都府京都市南区吉祥院新田弐ノ段町');
ok($zip->set_number('6018318')->is_valid_number, '京都府京都市南区吉祥院三ノ宮西町');
ok($zip->set_number('6018319')->is_valid_number, '京都府京都市南区吉祥院三ノ宮町');
ok($zip->set_number('6018321')->is_valid_number, '京都府京都市南区吉祥院西定成町');
ok($zip->set_number('6018322')->is_valid_number, '京都府京都市南区吉祥院定成町');
ok($zip->set_number('6018323')->is_valid_number, '京都府京都市南区吉祥院春日町');
ok($zip->set_number('6018324')->is_valid_number, '京都府京都市南区吉祥院落合町');
ok($zip->set_number('6018325')->is_valid_number, '京都府京都市南区吉祥院八反田町');
ok($zip->set_number('6018326')->is_valid_number, '京都府京都市南区吉祥院南落合町');
ok($zip->set_number('6018327')->is_valid_number, '京都府京都市南区吉祥院御池町');
ok($zip->set_number('6018328')->is_valid_number, '京都府京都市南区吉祥院九条町');
ok($zip->set_number('6018329')->is_valid_number, '京都府京都市南区吉祥院清水町');
ok($zip->set_number('6018330')->is_valid_number, '京都府京都市南区吉祥院船戸町');
ok($zip->set_number('6018331')->is_valid_number, '京都府京都市南区吉祥院政所町');
ok($zip->set_number('6018332')->is_valid_number, '京都府京都市南区吉祥院高畑町');
ok($zip->set_number('6018333')->is_valid_number, '京都府京都市南区吉祥院東浦町');
ok($zip->set_number('6018334')->is_valid_number, '京都府京都市南区吉祥院東砂ノ町');
ok($zip->set_number('6018335')->is_valid_number, '京都府京都市南区吉祥院砂ノ町');
ok($zip->set_number('6018336')->is_valid_number, '京都府京都市南区吉祥院菅原町');
ok($zip->set_number('6018337')->is_valid_number, '京都府京都市南区吉祥院這登東町');
ok($zip->set_number('6018338')->is_valid_number, '京都府京都市南区吉祥院西ノ内町');
ok($zip->set_number('6018339')->is_valid_number, '京都府京都市南区吉祥院里ノ内町');
ok($zip->set_number('6018341')->is_valid_number, '京都府京都市南区吉祥院前田町');
ok($zip->set_number('6018342')->is_valid_number, '京都府京都市南区吉祥院東前田町');
ok($zip->set_number('6018343')->is_valid_number, '京都府京都市南区吉祥院稲葉町');
ok($zip->set_number('6018344')->is_valid_number, '京都府京都市南区吉祥院蒔絵町');
ok($zip->set_number('6018345')->is_valid_number, '京都府京都市南区吉祥院蒔絵南町');
ok($zip->set_number('6018346')->is_valid_number, '京都府京都市南区吉祥院池田南町');
ok($zip->set_number('6018347')->is_valid_number, '京都府京都市南区吉祥院観音堂南町');
ok($zip->set_number('6018348')->is_valid_number, '京都府京都市南区吉祥院観音堂町');
ok($zip->set_number('6018349')->is_valid_number, '京都府京都市南区吉祥院池田町');
ok($zip->set_number('6018351')->is_valid_number, '京都府京都市南区吉祥院這登西町');
ok($zip->set_number('6018352')->is_valid_number, '京都府京都市南区吉祥院西浦町');
ok($zip->set_number('6018353')->is_valid_number, '京都府京都市南区吉祥院這登中町');
ok($zip->set_number('6018354')->is_valid_number, '京都府京都市南区吉祥院仁木ノ森町');
ok($zip->set_number('6018355')->is_valid_number, '京都府京都市南区吉祥院石原堂ノ後町');
ok($zip->set_number('6018356')->is_valid_number, '京都府京都市南区吉祥院石原京道町');
ok($zip->set_number('6018357')->is_valid_number, '京都府京都市南区吉祥院石原堂ノ後西町');
ok($zip->set_number('6018361')->is_valid_number, '京都府京都市南区吉祥院石原東之口町');
ok($zip->set_number('6018362')->is_valid_number, '京都府京都市南区吉祥院長田町');
ok($zip->set_number('6018363')->is_valid_number, '京都府京都市南区吉祥院嶋野間詰町');
ok($zip->set_number('6018364')->is_valid_number, '京都府京都市南区吉祥院石原南町');
ok($zip->set_number('6018365')->is_valid_number, '京都府京都市南区吉祥院石原開町');
ok($zip->set_number('6018366')->is_valid_number, '京都府京都市南区吉祥院石原西町');
ok($zip->set_number('6018367')->is_valid_number, '京都府京都市南区吉祥院石原町');
ok($zip->set_number('6018371')->is_valid_number, '京都府京都市南区吉祥院嶋樫山町');
ok($zip->set_number('6018372')->is_valid_number, '京都府京都市南区吉祥院嶋高町');
ok($zip->set_number('6018373')->is_valid_number, '京都府京都市南区吉祥院嶋出在家町');
ok($zip->set_number('6018374')->is_valid_number, '京都府京都市南区吉祥院嶋笠井町');
ok($zip->set_number('6018375')->is_valid_number, '京都府京都市南区吉祥院嶋西浦');
ok($zip->set_number('6018376')->is_valid_number, '京都府京都市南区吉祥院嶋中ノ島');
ok($zip->set_number('6018377')->is_valid_number, '京都府京都市南区吉祥院嶋堂ノ裏');
ok($zip->set_number('6018378')->is_valid_number, '京都府京都市南区吉祥院嶋堤外');
ok($zip->set_number('6018379')->is_valid_number, '京都府京都市南区吉祥院嶋川原田町');
ok($zip->set_number('6018380')->is_valid_number, '京都府京都市南区吉祥院新田下ノ向町');
ok($zip->set_number('6018381')->is_valid_number, '京都府京都市南区吉祥院西ノ茶屋町');
ok($zip->set_number('6018382')->is_valid_number, '京都府京都市南区吉祥院石原上川原町');
ok($zip->set_number('6018383')->is_valid_number, '京都府京都市南区吉祥院石原長田町');
ok($zip->set_number('6018384')->is_valid_number, '京都府京都市南区吉祥院石原野上町');
ok($zip->set_number('6018385')->is_valid_number, '京都府京都市南区吉祥院石原葭縁');
ok($zip->set_number('6018386')->is_valid_number, '京都府京都市南区吉祥院石原割畑');
ok($zip->set_number('6018387')->is_valid_number, '京都府京都市南区吉祥院石原橋裏');
ok($zip->set_number('6018388')->is_valid_number, '京都府京都市南区吉祥院石原西ノ開町');
ok($zip->set_number('6018389')->is_valid_number, '京都府京都市南区吉祥院石原橋上');
ok($zip->set_number('6018390')->is_valid_number, '京都府京都市南区吉祥院流作町');
ok($zip->set_number('6018391')->is_valid_number, '京都府京都市南区吉祥院大河原町');
ok($zip->set_number('6018392')->is_valid_number, '京都府京都市南区吉祥院内河原町');
ok($zip->set_number('6018393')->is_valid_number, '京都府京都市南区吉祥院中河原里西町');
ok($zip->set_number('6018394')->is_valid_number, '京都府京都市南区吉祥院中河原里北町');
ok($zip->set_number('6018395')->is_valid_number, '京都府京都市南区吉祥院中河原西屋敷町');
ok($zip->set_number('6018396')->is_valid_number, '京都府京都市南区吉祥院中河原里南町');
ok($zip->set_number('6018397')->is_valid_number, '京都府京都市南区吉祥院新田壱ノ段町');
ok($zip->set_number('6018398')->is_valid_number, '京都府京都市南区吉祥院新田参ノ段町');
ok($zip->set_number('6018399')->is_valid_number, '京都府京都市南区吉祥院堤外町');
ok($zip->set_number('6018401')->is_valid_number, '京都府京都市南区塩屋町');
ok($zip->set_number('6018402')->is_valid_number, '京都府京都市南区大黒町');
ok($zip->set_number('6018403')->is_valid_number, '京都府京都市南区古御旅町');
ok($zip->set_number('6018404')->is_valid_number, '京都府京都市南区西九条小寺町');
ok($zip->set_number('6018405')->is_valid_number, '京都府京都市南区西九条戒光寺町');
ok($zip->set_number('6018406')->is_valid_number, '京都府京都市南区戒光寺町');
ok($zip->set_number('6018407')->is_valid_number, '京都府京都市南区西九条寺ノ前町');
ok($zip->set_number('6018411')->is_valid_number, '京都府京都市南区西九条北ノ内町');
ok($zip->set_number('6018412')->is_valid_number, '京都府京都市南区西九条院町');
ok($zip->set_number('6018413')->is_valid_number, '京都府京都市南区西九条春日町');
ok($zip->set_number('6018414')->is_valid_number, '京都府京都市南区西九条蔵王町');
ok($zip->set_number('6018415')->is_valid_number, '京都府京都市南区西九条西蔵王町');
ok($zip->set_number('6018416')->is_valid_number, '京都府京都市南区西九条池ノ内町');
ok($zip->set_number('6018417')->is_valid_number, '京都府京都市南区西九条鳥居口町');
ok($zip->set_number('6018421')->is_valid_number, '京都府京都市南区西九条藤ノ木町');
ok($zip->set_number('6018422')->is_valid_number, '京都府京都市南区西九条針小路町');
ok($zip->set_number('6018423')->is_valid_number, '京都府京都市南区西九条唐橋町');
ok($zip->set_number('6018424')->is_valid_number, '京都府京都市南区西九条川原城町');
ok($zip->set_number('6018425')->is_valid_number, '京都府京都市南区西九条南小路町');
ok($zip->set_number('6018426')->is_valid_number, '京都府京都市南区西九条猪熊町');
ok($zip->set_number('6018427')->is_valid_number, '京都府京都市南区西九条横町');
ok($zip->set_number('6018428')->is_valid_number, '京都府京都市南区東寺東門前町');
ok($zip->set_number('6018431')->is_valid_number, '京都府京都市南区西九条島町');
ok($zip->set_number('6018432')->is_valid_number, '京都府京都市南区西九条東島町');
ok($zip->set_number('6018433')->is_valid_number, '京都府京都市南区西九条東柳ノ内町');
ok($zip->set_number('6018434')->is_valid_number, '京都府京都市南区西九条仏現寺町');
ok($zip->set_number('6018435')->is_valid_number, '京都府京都市南区西九条柳ノ内町');
ok($zip->set_number('6018436')->is_valid_number, '京都府京都市南区西九条西柳ノ内町');
ok($zip->set_number('6018437')->is_valid_number, '京都府京都市南区西九条比永城町');
ok($zip->set_number('6018438')->is_valid_number, '京都府京都市南区西九条東比永城町');
ok($zip->set_number('6018439')->is_valid_number, '京都府京都市南区西九条開ケ町');
ok($zip->set_number('6018441')->is_valid_number, '京都府京都市南区西九条南田町');
ok($zip->set_number('6018442')->is_valid_number, '京都府京都市南区西九条御幸田町');
ok($zip->set_number('6018443')->is_valid_number, '京都府京都市南区西九条東御幸田町');
ok($zip->set_number('6018444')->is_valid_number, '京都府京都市南区西九条森本町');
ok($zip->set_number('6018445')->is_valid_number, '京都府京都市南区西九条菅田町');
ok($zip->set_number('6018446')->is_valid_number, '京都府京都市南区西九条高畠町');
ok($zip->set_number('6018447')->is_valid_number, '京都府京都市南区西九条唐戸町');
ok($zip->set_number('6018448')->is_valid_number, '京都府京都市南区西九条豊田町');
ok($zip->set_number('6018449')->is_valid_number, '京都府京都市南区西九条大国町');
ok($zip->set_number('6018451')->is_valid_number, '京都府京都市南区唐橋川久保町');
ok($zip->set_number('6018452')->is_valid_number, '京都府京都市南区唐橋堂ノ前町');
ok($zip->set_number('6018453')->is_valid_number, '京都府京都市南区唐橋羅城門町');
ok($zip->set_number('6018454')->is_valid_number, '京都府京都市南区唐橋経田町');
ok($zip->set_number('6018455')->is_valid_number, '京都府京都市南区唐橋芦辺町');
ok($zip->set_number('6018456')->is_valid_number, '京都府京都市南区唐橋南琵琶町');
ok($zip->set_number('6018457')->is_valid_number, '京都府京都市南区唐橋琵琶町');
ok($zip->set_number('6018461')->is_valid_number, '京都府京都市南区唐橋門脇町');
ok($zip->set_number('6018462')->is_valid_number, '京都府京都市南区唐橋井園町');
ok($zip->set_number('6018463')->is_valid_number, '京都府京都市南区唐橋赤金町');
ok($zip->set_number('6018464')->is_valid_number, '京都府京都市南区唐橋高田町');
ok($zip->set_number('6018465')->is_valid_number, '京都府京都市南区唐橋花園町');
ok($zip->set_number('6018466')->is_valid_number, '京都府京都市南区唐橋西寺町');
ok($zip->set_number('6018467')->is_valid_number, '京都府京都市南区唐橋大宮尻町');
ok($zip->set_number('6018468')->is_valid_number, '京都府京都市南区唐橋西平垣町');
ok($zip->set_number('6018469')->is_valid_number, '京都府京都市南区唐橋平垣町');
ok($zip->set_number('6018471')->is_valid_number, '京都府京都市南区八条町');
ok($zip->set_number('6018472')->is_valid_number, '京都府京都市南区八条坊門町');
ok($zip->set_number('6018473')->is_valid_number, '京都府京都市南区九条町');
ok($zip->set_number('6018474')->is_valid_number, '京都府京都市南区四ツ塚町');
ok($zip->set_number('6018475')->is_valid_number, '京都府京都市南区八条内田町');
ok($zip->set_number('6018476')->is_valid_number, '京都府京都市南区八条寺内町');
ok($zip->set_number('6018477')->is_valid_number, '京都府京都市南区八条源町');
ok($zip->set_number('6018478')->is_valid_number, '京都府京都市南区東寺町');
ok($zip->set_number('6020000')->is_valid_number, '京都府京都市上京区以下に掲載がない場合');
ok($zip->set_number('6020001')->is_valid_number, '京都府京都市上京区竹園町');
ok($zip->set_number('6020002')->is_valid_number, '京都府京都市上京区継孝院町');
ok($zip->set_number('6020003')->is_valid_number, '京都府京都市上京区大心院町');
ok($zip->set_number('6020004')->is_valid_number, '京都府京都市上京区道正町');
ok($zip->set_number('6020005')->is_valid_number, '京都府京都市上京区妙顕寺前町');
ok($zip->set_number('6020006')->is_valid_number, '京都府京都市上京区禅昌院町');
ok($zip->set_number('6020007')->is_valid_number, '京都府京都市上京区下清蔵口町');
ok($zip->set_number('6020008')->is_valid_number, '京都府京都市上京区岩栖院町');
ok($zip->set_number('6020011')->is_valid_number, '京都府京都市上京区森之木町');
ok($zip->set_number('6020012')->is_valid_number, '京都府京都市上京区内構町');
ok($zip->set_number('6020013')->is_valid_number, '京都府京都市上京区上柳原町');
ok($zip->set_number('6020014')->is_valid_number, '京都府京都市上京区下柳原北半町');
ok($zip->set_number('6020015')->is_valid_number, '京都府京都市上京区下柳原南半町');
ok($zip->set_number('6020016')->is_valid_number, '京都府京都市上京区畠中町');
ok($zip->set_number('6020017')->is_valid_number, '京都府京都市上京区上木下町');
ok($zip->set_number('6020018')->is_valid_number, '京都府京都市上京区玄蕃町');
ok($zip->set_number('6020019')->is_valid_number, '京都府京都市上京区下木下町');
ok($zip->set_number('6020021')->is_valid_number, '京都府京都市上京区柳図子町');
ok($zip->set_number('6020022')->is_valid_number, '京都府京都市上京区上立売東町');
ok($zip->set_number('6020023')->is_valid_number, '京都府京都市上京区御所八幡町');
ok($zip->set_number('6020024')->is_valid_number, '京都府京都市上京区上立売町');
ok($zip->set_number('6020025')->is_valid_number, '京都府京都市上京区裏風呂町');
ok($zip->set_number('6020026')->is_valid_number, '京都府京都市上京区古木町');
ok($zip->set_number('6020027')->is_valid_number, '京都府京都市上京区木下突抜町');
ok($zip->set_number('6020028')->is_valid_number, '京都府京都市上京区納屋町');
ok($zip->set_number('6020029')->is_valid_number, '京都府京都市上京区室町頭町');
ok($zip->set_number('6020031')->is_valid_number, '京都府京都市上京区裏築地町');
ok($zip->set_number('6020032')->is_valid_number, '京都府京都市上京区岡松町');
ok($zip->set_number('6020033')->is_valid_number, '京都府京都市上京区今出川町(烏丸通今出川上る、烏丸通今出川下る、今出川通烏丸西');
ok($zip->set_number('6020033')->is_valid_number, '京都府京都市上京区入、今出川通室町東入)');
ok($zip->set_number('6020034')->is_valid_number, '京都府京都市上京区築山南半町');
ok($zip->set_number('6020035')->is_valid_number, '京都府京都市上京区畠山町');
ok($zip->set_number('6020036')->is_valid_number, '京都府京都市上京区蒔鳥屋町');
ok($zip->set_number('6020037')->is_valid_number, '京都府京都市上京区瓢箪図子町');
ok($zip->set_number('6020038')->is_valid_number, '京都府京都市上京区築山北半町');
ok($zip->set_number('6020041')->is_valid_number, '京都府京都市上京区中御霊図子町');
ok($zip->set_number('6020042')->is_valid_number, '京都府京都市上京区元新在家町');
ok($zip->set_number('6020043')->is_valid_number, '京都府京都市上京区元本満寺町');
ok($zip->set_number('6020044')->is_valid_number, '京都府京都市上京区北兼康町');
ok($zip->set_number('6020045')->is_valid_number, '京都府京都市上京区近衛殿北口町');
ok($zip->set_number('6020046')->is_valid_number, '京都府京都市上京区西大路町(上立売通小川東入、上立売通新町西入、上立売通新町東');
ok($zip->set_number('6020046')->is_valid_number, '京都府京都市上京区入、上立売通新町東入上る、新町通上立売上る)');
ok($zip->set_number('6020047')->is_valid_number, '京都府京都市上京区近衛殿表町');
ok($zip->set_number('6020051')->is_valid_number, '京都府京都市上京区御三軒町');
ok($zip->set_number('6020052')->is_valid_number, '京都府京都市上京区上小川町');
ok($zip->set_number('6020053')->is_valid_number, '京都府京都市上京区中小川町');
ok($zip->set_number('6020054')->is_valid_number, '京都府京都市上京区飛鳥井町');
ok($zip->set_number('6020055')->is_valid_number, '京都府京都市上京区南舟橋町');
ok($zip->set_number('6020056')->is_valid_number, '京都府京都市上京区北舟橋町');
ok($zip->set_number('6020057')->is_valid_number, '京都府京都市上京区堀之上町');
ok($zip->set_number('6020058')->is_valid_number, '京都府京都市上京区水落町');
ok($zip->set_number('6020059')->is_valid_number, '京都府京都市上京区実相院町');
ok($zip->set_number('6020061')->is_valid_number, '京都府京都市上京区本法寺前町');
ok($zip->set_number('6020062')->is_valid_number, '京都府京都市上京区宝鏡院東町');
ok($zip->set_number('6020063')->is_valid_number, '京都府京都市上京区内藤町');
ok($zip->set_number('6020064')->is_valid_number, '京都府京都市上京区安楽小路町');
ok($zip->set_number('6020065')->is_valid_number, '京都府京都市上京区挽木町');
ok($zip->set_number('6020066')->is_valid_number, '京都府京都市上京区射場町');
ok($zip->set_number('6020067')->is_valid_number, '京都府京都市上京区竹屋町');
ok($zip->set_number('6020071')->is_valid_number, '京都府京都市上京区扇町(堀川通寺之内上る、堀川通上御霊前上る、上御霊前通堀川東入)');
ok($zip->set_number('6020072')->is_valid_number, '京都府京都市上京区百々町');
ok($zip->set_number('6020073')->is_valid_number, '京都府京都市上京区寺之内竪町');
ok($zip->set_number('6020074')->is_valid_number, '京都府京都市上京区下天神町');
ok($zip->set_number('6020081')->is_valid_number, '京都府京都市上京区瑞光院前町');
ok($zip->set_number('6020082')->is_valid_number, '京都府京都市上京区上天神町');
ok($zip->set_number('6020083')->is_valid_number, '京都府京都市上京区新ン町');
ok($zip->set_number('6020084')->is_valid_number, '京都府京都市上京区若宮横町');
ok($zip->set_number('6020085')->is_valid_number, '京都府京都市上京区若宮竪町');
ok($zip->set_number('6020086')->is_valid_number, '京都府京都市上京区東若宮町');
ok($zip->set_number('6020087')->is_valid_number, '京都府京都市上京区天神北町');
ok($zip->set_number('6020091')->is_valid_number, '京都府京都市上京区筋違橋町');
ok($zip->set_number('6020092')->is_valid_number, '京都府京都市上京区北仲之町');
ok($zip->set_number('6020093')->is_valid_number, '京都府京都市上京区仲之町(大宮通上御霊前上る、大宮通上御霊前下る、大宮通蘆山寺');
ok($zip->set_number('6020093')->is_valid_number, '京都府京都市上京区上る、大宮通寺之内上る、大宮通寺之内上る2丁目、上御霊前通大宮西入、上御');
ok($zip->set_number('6020093')->is_valid_number, '京都府京都市上京区霊前通大宮東入、蘆山寺通大宮西入)');
ok($zip->set_number('6020094')->is_valid_number, '京都府京都市上京区社横町');
ok($zip->set_number('6020095')->is_valid_number, '京都府京都市上京区社突抜町');
ok($zip->set_number('6020096')->is_valid_number, '京都府京都市上京区西若宮南半町');
ok($zip->set_number('6020097')->is_valid_number, '京都府京都市上京区西若宮北半町');
ok($zip->set_number('6020098')->is_valid_number, '京都府京都市上京区竪社北半町');
ok($zip->set_number('6020099')->is_valid_number, '京都府京都市上京区竪社南半町');
ok($zip->set_number('6020801')->is_valid_number, '京都府京都市上京区高徳寺町');
ok($zip->set_number('6020802')->is_valid_number, '京都府京都市上京区鶴山町');
ok($zip->set_number('6020803')->is_valid_number, '京都府京都市上京区阿弥陀寺前町');
ok($zip->set_number('6020804')->is_valid_number, '京都府京都市上京区上片原町');
ok($zip->set_number('6020805')->is_valid_number, '京都府京都市上京区桜木町');
ok($zip->set_number('6020806')->is_valid_number, '京都府京都市上京区藪之下町');
ok($zip->set_number('6020807')->is_valid_number, '京都府京都市上京区不動前町');
ok($zip->set_number('6020808')->is_valid_number, '京都府京都市上京区歓喜寺前町');
ok($zip->set_number('6020811')->is_valid_number, '京都府京都市上京区十念寺前町');
ok($zip->set_number('6020812')->is_valid_number, '京都府京都市上京区本満寺前町');
ok($zip->set_number('6020813')->is_valid_number, '京都府京都市上京区上神輿町');
ok($zip->set_number('6020814')->is_valid_number, '京都府京都市上京区幸神町');
ok($zip->set_number('6020815')->is_valid_number, '京都府京都市上京区上塔之段町');
ok($zip->set_number('6020816')->is_valid_number, '京都府京都市上京区毘沙門町(上立売通寺町西入、上立売通寺町西入上る、上立売通寺');
ok($zip->set_number('6020816')->is_valid_number, '京都府京都市上京区町西入下る、上立売通寺町西入4筋目下る、寺町通今出川上る1筋目西入、寺町');
ok($zip->set_number('6020816')->is_valid_number, '京都府京都市上京区通今出川上る2丁目、寺町通今出川上る2丁目西入、寺町通今出川上る3丁');
ok($zip->set_number('6020816')->is_valid_number, '京都府京都市上京区目、寺町通今出川上る3丁目西入、寺町通今出川上る4丁目、寺町通今出川上');
ok($zip->set_number('6020816')->is_valid_number, '京都府京都市上京区る4丁目西入、寺町通今出川西入、寺町通今出川2丁目上る西入、塔之段寺町通');
ok($zip->set_number('6020816')->is_valid_number, '京都府京都市上京区今出川上る)');
ok($zip->set_number('6020817')->is_valid_number, '京都府京都市上京区毘沙門横町');
ok($zip->set_number('6020818')->is_valid_number, '京都府京都市上京区北横町');
ok($zip->set_number('6020819')->is_valid_number, '京都府京都市上京区松之木町');
ok($zip->set_number('6020821')->is_valid_number, '京都府京都市上京区後藤町');
ok($zip->set_number('6020822')->is_valid_number, '京都府京都市上京区青龍町');
ok($zip->set_number('6020823')->is_valid_number, '京都府京都市上京区三芳町');
ok($zip->set_number('6020824')->is_valid_number, '京都府京都市上京区一真町');
ok($zip->set_number('6020825')->is_valid_number, '京都府京都市上京区表町');
ok($zip->set_number('6020826')->is_valid_number, '京都府京都市上京区三栄町');
ok($zip->set_number('6020827')->is_valid_number, '京都府京都市上京区相生町');
ok($zip->set_number('6020828')->is_valid_number, '京都府京都市上京区二神町');
ok($zip->set_number('6020831')->is_valid_number, '京都府京都市上京区立本寺前町');
ok($zip->set_number('6020832')->is_valid_number, '京都府京都市上京区大原口町');
ok($zip->set_number('6020833')->is_valid_number, '京都府京都市上京区真如堂突抜町');
ok($zip->set_number('6020834')->is_valid_number, '京都府京都市上京区大原口突抜町');
ok($zip->set_number('6020835')->is_valid_number, '京都府京都市上京区革堂内町');
ok($zip->set_number('6020836')->is_valid_number, '京都府京都市上京区常盤井殿町');
ok($zip->set_number('6020837')->is_valid_number, '京都府京都市上京区下塔之段町');
ok($zip->set_number('6020838')->is_valid_number, '京都府京都市上京区柳風呂町');
ok($zip->set_number('6020839')->is_valid_number, '京都府京都市上京区下御輿町');
ok($zip->set_number('6020841')->is_valid_number, '京都府京都市上京区梶井町');
ok($zip->set_number('6020842')->is_valid_number, '京都府京都市上京区栄町(石薬師通河原西入、河原町通石薬師上る、河原町通石薬');
ok($zip->set_number('6020842')->is_valid_number, '京都府京都市上京区師下る、河原町通今出川下る、河原町通今出川2筋目下る西、河原町通今出川');
ok($zip->set_number('6020842')->is_valid_number, '京都府京都市上京区下る2丁目、河原町通今出川下る2筋目西、河原町通今出川下る3丁目)');
ok($zip->set_number('6020843')->is_valid_number, '京都府京都市上京区新夷町');
ok($zip->set_number('6020844')->is_valid_number, '京都府京都市上京区染殿町');
ok($zip->set_number('6020845')->is_valid_number, '京都府京都市上京区真如堂前町');
ok($zip->set_number('6020846')->is_valid_number, '京都府京都市上京区米屋町(今出川通寺町東入、今出川通寺町東入下る、今出川通河');
ok($zip->set_number('6020846')->is_valid_number, '京都府京都市上京区原町西入上る、河原町通今出川下る西入、寺町通今出川下る、寺町通今出川下');
ok($zip->set_number('6020846')->is_valid_number, '京都府京都市上京区る東入、中筋通今出川下る)');
ok($zip->set_number('6020847')->is_valid_number, '京都府京都市上京区大宮町(今出川通河原町西入、今出川通寺町東入、今出川通寺町東');
ok($zip->set_number('6020847')->is_valid_number, '京都府京都市上京区入下る、河原町通今出川下る、河原町通今出川下る西入、寺町通今出川下る東');
ok($zip->set_number('6020847')->is_valid_number, '京都府京都市上京区入、中筋通石薬師上る)');
ok($zip->set_number('6020848')->is_valid_number, '京都府京都市上京区扇町(寺町通今出川下る、寺町通石薬師上る、寺町通石薬師下');
ok($zip->set_number('6020848')->is_valid_number, '京都府京都市上京区る、寺町通広小路上る、石薬師通寺町東入)');
ok($zip->set_number('6020849')->is_valid_number, '京都府京都市上京区大猪熊町(中筋通石薬師上る、石薬師通河原町西入、石薬師通寺町');
ok($zip->set_number('6020849')->is_valid_number, '京都府京都市上京区東入、石薬師通中筋西入、石薬師通中筋東入)');
ok($zip->set_number('6020851')->is_valid_number, '京都府京都市上京区九軒町');
ok($zip->set_number('6020852')->is_valid_number, '京都府京都市上京区北之辺町');
ok($zip->set_number('6020853')->is_valid_number, '京都府京都市上京区宮垣町');
ok($zip->set_number('6020854')->is_valid_number, '京都府京都市上京区亀屋町(河原町通荒神口東入、荒神口通河原町東入)');
ok($zip->set_number('6020855')->is_valid_number, '京都府京都市上京区上生洲町');
ok($zip->set_number('6020856')->is_valid_number, '京都府京都市上京区荒神町(河原町通荒神口上る、荒神口通河原町西入、荒神口通河');
ok($zip->set_number('6020856')->is_valid_number, '京都府京都市上京区原町東入、荒神口通寺町東入、寺町通荒神口上る)');
ok($zip->set_number('6020857')->is_valid_number, '京都府京都市上京区中御霊町');
ok($zip->set_number('6020858')->is_valid_number, '京都府京都市上京区東桜町');
ok($zip->set_number('6020861')->is_valid_number, '京都府京都市上京区新烏丸頭町');
ok($zip->set_number('6020862')->is_valid_number, '京都府京都市上京区出水町');
ok($zip->set_number('6020863')->is_valid_number, '京都府京都市上京区上之町');
ok($zip->set_number('6020864')->is_valid_number, '京都府京都市上京区中之町(東三本木通丸太町上る)');
ok($zip->set_number('6020865')->is_valid_number, '京都府京都市上京区南町');
ok($zip->set_number('6020866')->is_valid_number, '京都府京都市上京区真町');
ok($zip->set_number('6020867')->is_valid_number, '京都府京都市上京区松蔭町');
ok($zip->set_number('6020868')->is_valid_number, '京都府京都市上京区袋町');
ok($zip->set_number('6020871')->is_valid_number, '京都府京都市上京区俵屋町');
ok($zip->set_number('6020872')->is_valid_number, '京都府京都市上京区駒之町');
ok($zip->set_number('6020873')->is_valid_number, '京都府京都市上京区伊勢屋町');
ok($zip->set_number('6020874')->is_valid_number, '京都府京都市上京区東土御門町');
ok($zip->set_number('6020875')->is_valid_number, '京都府京都市上京区信富町');
ok($zip->set_number('6020876')->is_valid_number, '京都府京都市上京区錦砂町');
ok($zip->set_number('6020877')->is_valid_number, '京都府京都市上京区桝屋町(河原町通丸太町上る)');
ok($zip->set_number('6020878')->is_valid_number, '京都府京都市上京区高島町');
ok($zip->set_number('6020881')->is_valid_number, '京都府京都市上京区京都御苑');
ok($zip->set_number('6020891')->is_valid_number, '京都府京都市上京区上御霊馬場町');
ok($zip->set_number('6020892')->is_valid_number, '京都府京都市上京区新北小路町');
ok($zip->set_number('6020893')->is_valid_number, '京都府京都市上京区玄武町');
ok($zip->set_number('6020894')->is_valid_number, '京都府京都市上京区上御霊中町');
ok($zip->set_number('6020895')->is_valid_number, '京都府京都市上京区上御霊前町');
ok($zip->set_number('6020896')->is_valid_number, '京都府京都市上京区上御霊竪町');
ok($zip->set_number('6020897')->is_valid_number, '京都府京都市上京区新御霊口町');
ok($zip->set_number('6020898')->is_valid_number, '京都府京都市上京区相国寺門前町');
ok($zip->set_number('6020901')->is_valid_number, '京都府京都市上京区北小路室町');
ok($zip->set_number('6020902')->is_valid_number, '京都府京都市上京区梅屋町');
ok($zip->set_number('6020903')->is_valid_number, '京都府京都市上京区観三橘町');
ok($zip->set_number('6020904')->is_valid_number, '京都府京都市上京区小島町');
ok($zip->set_number('6020905')->is_valid_number, '京都府京都市上京区一松町');
ok($zip->set_number('6020906')->is_valid_number, '京都府京都市上京区今図子町');
ok($zip->set_number('6020907')->is_valid_number, '京都府京都市上京区福長町');
ok($zip->set_number('6020911')->is_valid_number, '京都府京都市上京区広橋殿町');
ok($zip->set_number('6020912')->is_valid_number, '京都府京都市上京区龍前町');
ok($zip->set_number('6020913')->is_valid_number, '京都府京都市上京区東町(中立売通烏丸西入、中立売通室町東入)');
ok($zip->set_number('6020914')->is_valid_number, '京都府京都市上京区花立町');
ok($zip->set_number('6020915')->is_valid_number, '京都府京都市上京区三丁町');
ok($zip->set_number('6020916')->is_valid_number, '京都府京都市上京区西日野殿町');
ok($zip->set_number('6020917')->is_valid_number, '京都府京都市上京区東日野殿町');
ok($zip->set_number('6020918')->is_valid_number, '京都府京都市上京区薬屋町');
ok($zip->set_number('6020921')->is_valid_number, '京都府京都市上京区正親町');
ok($zip->set_number('6020922')->is_valid_number, '京都府京都市上京区讃州寺町');
ok($zip->set_number('6020923')->is_valid_number, '京都府京都市上京区油橋詰町');
ok($zip->set_number('6020924')->is_valid_number, '京都府京都市上京区小川町');
ok($zip->set_number('6020925')->is_valid_number, '京都府京都市上京区西之口町');
ok($zip->set_number('6020926')->is_valid_number, '京都府京都市上京区元真如堂町');
ok($zip->set_number('6020931')->is_valid_number, '京都府京都市上京区堀出シ町');
ok($zip->set_number('6020932')->is_valid_number, '京都府京都市上京区徳大寺殿町');
ok($zip->set_number('6020933')->is_valid_number, '京都府京都市上京区武者小路町');
ok($zip->set_number('6020934')->is_valid_number, '京都府京都市上京区一条殿町');
ok($zip->set_number('6020935')->is_valid_number, '京都府京都市上京区大峰図子町');
ok($zip->set_number('6020936')->is_valid_number, '京都府京都市上京区西無車小路町');
ok($zip->set_number('6020937')->is_valid_number, '京都府京都市上京区常盤井図子町');
ok($zip->set_number('6020938')->is_valid_number, '京都府京都市上京区元図子町');
ok($zip->set_number('6020939')->is_valid_number, '京都府京都市上京区弁財天町');
ok($zip->set_number('6020941')->is_valid_number, '京都府京都市上京区南兼康町');
ok($zip->set_number('6020942')->is_valid_number, '京都府京都市上京区靭屋町');
ok($zip->set_number('6020943')->is_valid_number, '京都府京都市上京区革堂町(小川通一条上る、小川通武者小路下る、武者小路通小川東入)');
ok($zip->set_number('6020944')->is_valid_number, '京都府京都市上京区一条横町');
ok($zip->set_number('6020945')->is_valid_number, '京都府京都市上京区革堂仲之町');
ok($zip->set_number('6020946')->is_valid_number, '京都府京都市上京区戒光寺町');
ok($zip->set_number('6020947')->is_valid_number, '京都府京都市上京区東町(元誓願寺通小川西入)');
ok($zip->set_number('6020948')->is_valid_number, '京都府京都市上京区針屋町');
ok($zip->set_number('6020951')->is_valid_number, '京都府京都市上京区東今町');
ok($zip->set_number('6020952')->is_valid_number, '京都府京都市上京区頭町(油小路通元誓願寺下る、元誓願寺通油小路西入)');
ok($zip->set_number('6020953')->is_valid_number, '京都府京都市上京区元百万遍町');
ok($zip->set_number('6020954')->is_valid_number, '京都府京都市上京区西川端町');
ok($zip->set_number('6020955')->is_valid_number, '京都府京都市上京区竪富田町');
ok($zip->set_number('6020956')->is_valid_number, '京都府京都市上京区西町(東堀川通元誓願寺下る、元誓願寺通油小路西入、元誓願寺通東堀川東入)');
ok($zip->set_number('6020957')->is_valid_number, '京都府京都市上京区西今町');
ok($zip->set_number('6020958')->is_valid_number, '京都府京都市上京区仲之町(油小路通今出川下る、油小路通元誓願寺上る、元誓願寺通');
ok($zip->set_number('6020958')->is_valid_number, '京都府京都市上京区油小路西入、元誓願寺通油小路東入、元誓願寺通堀川東入)');
ok($zip->set_number('6020959')->is_valid_number, '京都府京都市上京区革堂西町');
ok($zip->set_number('6028001')->is_valid_number, '京都府京都市上京区元浄花院町');
ok($zip->set_number('6028002')->is_valid_number, '京都府京都市上京区鷹司町(下長者町通鳥丸西入)');
ok($zip->set_number('6028003')->is_valid_number, '京都府京都市上京区清和院町');
ok($zip->set_number('6028004')->is_valid_number, '京都府京都市上京区西鷹司町');
ok($zip->set_number('6028005')->is_valid_number, '京都府京都市上京区元頂妙寺町');
ok($zip->set_number('6028006')->is_valid_number, '京都府京都市上京区元土御門町');
ok($zip->set_number('6028007')->is_valid_number, '京都府京都市上京区東長者町');
ok($zip->set_number('6028011')->is_valid_number, '京都府京都市上京区桜鶴円町');
ok($zip->set_number('6028012')->is_valid_number, '京都府京都市上京区中出水町');
ok($zip->set_number('6028013')->is_valid_number, '京都府京都市上京区五町目町');
ok($zip->set_number('6028014')->is_valid_number, '京都府京都市上京区勘解由小路町');
ok($zip->set_number('6028015')->is_valid_number, '京都府京都市上京区常泉院町');
ok($zip->set_number('6028016')->is_valid_number, '京都府京都市上京区両御霊町');
ok($zip->set_number('6028017')->is_valid_number, '京都府京都市上京区西出水町');
ok($zip->set_number('6028018')->is_valid_number, '京都府京都市上京区御霊町');
ok($zip->set_number('6028019')->is_valid_number, '京都府京都市上京区近衛町(下長者町通室町西入、下長者町通室町東入、出水通烏丸西');
ok($zip->set_number('6028019')->is_valid_number, '京都府京都市上京区入、出水通室町東入、室町通下長者町下る、室町通出水上る、室町通出水上る');
ok($zip->set_number('6028019')->is_valid_number, '京都府京都市上京区東入)');
ok($zip->set_number('6028021')->is_valid_number, '京都府京都市上京区堀松町');
ok($zip->set_number('6028022')->is_valid_number, '京都府京都市上京区養安町');
ok($zip->set_number('6028023')->is_valid_number, '京都府京都市上京区春日町');
ok($zip->set_number('6028024')->is_valid_number, '京都府京都市上京区大門町');
ok($zip->set_number('6028025')->is_valid_number, '京都府京都市上京区今薬屋町');
ok($zip->set_number('6028026')->is_valid_number, '京都府京都市上京区春帯町');
ok($zip->set_number('6028027')->is_valid_number, '京都府京都市上京区東立売町');
ok($zip->set_number('6028028')->is_valid_number, '京都府京都市上京区門跡町');
ok($zip->set_number('6028029')->is_valid_number, '京都府京都市上京区武衛陣町');
ok($zip->set_number('6028031')->is_valid_number, '京都府京都市上京区東裏辻町');
ok($zip->set_number('6028032')->is_valid_number, '京都府京都市上京区夷川町');
ok($zip->set_number('6028033')->is_valid_number, '京都府京都市上京区上鍛冶町');
ok($zip->set_number('6028034')->is_valid_number, '京都府京都市上京区米屋町(油小路椹木町下る、油小路通丸太町上る、椹木町通油小');
ok($zip->set_number('6028034')->is_valid_number, '京都府京都市上京区路西入、椹木町通油小路東入、丸太町通油小路西入、丸太町通油小路東入)');
ok($zip->set_number('6028035')->is_valid_number, '京都府京都市上京区六町目');
ok($zip->set_number('6028036')->is_valid_number, '京都府京都市上京区西山崎町');
ok($zip->set_number('6028037')->is_valid_number, '京都府京都市上京区八幡町');
ok($zip->set_number('6028038')->is_valid_number, '京都府京都市上京区東魚屋町');
ok($zip->set_number('6028041')->is_valid_number, '京都府京都市上京区藪之内町');
ok($zip->set_number('6028042')->is_valid_number, '京都府京都市上京区西裏辻町');
ok($zip->set_number('6028043')->is_valid_number, '京都府京都市上京区五町目');
ok($zip->set_number('6028044')->is_valid_number, '京都府京都市上京区東橋詰町(下立売通堀川東入)');
ok($zip->set_number('6028045')->is_valid_number, '京都府京都市上京区四町目(出水通油小路西入、出水通堀川東入、出水通堀川東入');
ok($zip->set_number('6028045')->is_valid_number, '京都府京都市上京区下る、出水通東堀川東入、下立売通堀川東入、下立売通堀川東入上る、下立売通');
ok($zip->set_number('6028045')->is_valid_number, '京都府京都市上京区堀川東入下る、東堀川通下立売上る、東堀川通出水下る)');
ok($zip->set_number('6028046')->is_valid_number, '京都府京都市上京区近衛町(油小路通下立売上る、油小路通出水下る、出水通油小路西');
ok($zip->set_number('6028046')->is_valid_number, '京都府京都市上京区入、出水通油小路東入)');
ok($zip->set_number('6028047')->is_valid_number, '京都府京都市上京区勘兵衛町');
ok($zip->set_number('6028048')->is_valid_number, '京都府京都市上京区西大路町(油小路通下立売上る、小川通下立売上る、小川通下立売下');
ok($zip->set_number('6028048')->is_valid_number, '京都府京都市上京区る、下立売通油小路東入、下立売通小川西入、下立売通小川東入)');
ok($zip->set_number('6028051')->is_valid_number, '京都府京都市上京区中橋詰町');
ok($zip->set_number('6028052')->is_valid_number, '京都府京都市上京区鷹司町(下長者町通小川東入)');
ok($zip->set_number('6028053')->is_valid_number, '京都府京都市上京区茶屋町');
ok($zip->set_number('6028054')->is_valid_number, '京都府京都市上京区丁子風呂町');
ok($zip->set_number('6028055')->is_valid_number, '京都府京都市上京区大黒屋町');
ok($zip->set_number('6028056')->is_valid_number, '京都府京都市上京区三町目(出水通東堀川東入、出水通堀川東入、東堀川通下長者');
ok($zip->set_number('6028056')->is_valid_number, '京都府京都市上京区町下る、東堀川通出水上る)');
ok($zip->set_number('6028057')->is_valid_number, '京都府京都市上京区紹巴町');
ok($zip->set_number('6028058')->is_valid_number, '京都府京都市上京区二町目(上長者町通東堀川東入、東堀川通上長者町下る、東堀川通');
ok($zip->set_number('6028058')->is_valid_number, '京都府京都市上京区下長者町上る、東堀川通上長者町上る)');
ok($zip->set_number('6028061')->is_valid_number, '京都府京都市上京区甲斐守町');
ok($zip->set_number('6028062')->is_valid_number, '京都府京都市上京区亀屋町(油小路通上長者町下る、油小路通下長者町上る、油小路通');
ok($zip->set_number('6028062')->is_valid_number, '京都府京都市上京区中長者町上る、油小路通中長者町下る、上長者町通油小路西入、上長者町通油小');
ok($zip->set_number('6028062')->is_valid_number, '京都府京都市上京区路東入)');
ok($zip->set_number('6028063')->is_valid_number, '京都府京都市上京区橋本町');
ok($zip->set_number('6028064')->is_valid_number, '京都府京都市上京区一町目(上長者町通堀川東入、東堀川通上長者町上る、東堀川通中立売通下る)');
ok($zip->set_number('6028065')->is_valid_number, '京都府京都市上京区突抜町(上長者町通堀川東入上る、中立売通堀川東入下る、油小路');
ok($zip->set_number('6028065')->is_valid_number, '京都府京都市上京区堀川の間中立売下る)');
ok($zip->set_number('6028066')->is_valid_number, '京都府京都市上京区東橋詰町(中立売通堀川東入)');
ok($zip->set_number('6028067')->is_valid_number, '京都府京都市上京区主計町');
ok($zip->set_number('6028068')->is_valid_number, '京都府京都市上京区松之下町');
ok($zip->set_number('6028071')->is_valid_number, '京都府京都市上京区仕丁町');
ok($zip->set_number('6028072')->is_valid_number, '京都府京都市上京区仲之町(新町通下長者町上る、新町通中長者町下る、中長者町通新');
ok($zip->set_number('6028072')->is_valid_number, '京都府京都市上京区町西入、中長者町通西洞院東入、中長者町通西洞院西入、西洞院通中長者町上');
ok($zip->set_number('6028072')->is_valid_number, '京都府京都市上京区る、西洞院通上長者町下る)');
ok($zip->set_number('6028073')->is_valid_number, '京都府京都市上京区頭町(上長者町通西洞院西入、西洞院通上長者町下る、西洞院通');
ok($zip->set_number('6028073')->is_valid_number, '京都府京都市上京区下長者町上る、西洞院通中長者町上る、西洞院通中長者町下る)');
ok($zip->set_number('6028074')->is_valid_number, '京都府京都市上京区有春町');
ok($zip->set_number('6028075')->is_valid_number, '京都府京都市上京区下小川町');
ok($zip->set_number('6028076')->is_valid_number, '京都府京都市上京区菊屋町(西洞院通上長者町上る、西洞院通中立売下る、上長者町通');
ok($zip->set_number('6028076')->is_valid_number, '京都府京都市上京区西洞院西入、上長者町通西洞院東入)');
ok($zip->set_number('6028077')->is_valid_number, '京都府京都市上京区土御門町');
ok($zip->set_number('6028101')->is_valid_number, '京都府京都市上京区東辰巳町');
ok($zip->set_number('6028102')->is_valid_number, '京都府京都市上京区東天秤町');
ok($zip->set_number('6028103')->is_valid_number, '京都府京都市上京区一町目(松屋町通出水下る、松屋町通下立売上る)');
ok($zip->set_number('6028104')->is_valid_number, '京都府京都市上京区浮田町');
ok($zip->set_number('6028105')->is_valid_number, '京都府京都市上京区天秤町');
ok($zip->set_number('6028106')->is_valid_number, '京都府京都市上京区秤口町');
ok($zip->set_number('6028107')->is_valid_number, '京都府京都市上京区西辰巳町');
ok($zip->set_number('6028108')->is_valid_number, '京都府京都市上京区南清水町');
ok($zip->set_number('6028109')->is_valid_number, '京都府京都市上京区西天秤町');
ok($zip->set_number('6028111')->is_valid_number, '京都府京都市上京区桝屋町(西堀川通下長者町下る、西堀川通出水上る)');
ok($zip->set_number('6028112')->is_valid_number, '京都府京都市上京区四町目(西堀川通下立売上る、西堀川通出水下る)');
ok($zip->set_number('6028113')->is_valid_number, '京都府京都市上京区元福大明神町');
ok($zip->set_number('6028114')->is_valid_number, '京都府京都市上京区荒神町(猪熊通下立売上る、猪熊通出水下る、猪熊通椹木町上');
ok($zip->set_number('6028114')->is_valid_number, '京都府京都市上京区る、出水通猪熊西入、出水通猪熊東入、出水通葭屋町西入)');
ok($zip->set_number('6028115')->is_valid_number, '京都府京都市上京区北蟹屋町');
ok($zip->set_number('6028116')->is_valid_number, '京都府京都市上京区清元町');
ok($zip->set_number('6028117')->is_valid_number, '京都府京都市上京区吉野町');
ok($zip->set_number('6028118')->is_valid_number, '京都府京都市上京区蛭子町(猪熊通出水上る、猪熊通下長者町下る、下長者町通');
ok($zip->set_number('6028118')->is_valid_number, '京都府京都市上京区猪熊西入、下長者町通猪熊東入、出水通猪熊西入、出水通猪熊東入)');
ok($zip->set_number('6028119')->is_valid_number, '京都府京都市上京区亀屋町(葭屋町通下長者町下る、葭屋町通出水上る、下長者町通堀');
ok($zip->set_number('6028119')->is_valid_number, '京都府京都市上京区川西入、下長者町通葭屋町東入、下長者町通葭屋町西入、出水通葭屋町西入、出');
ok($zip->set_number('6028119')->is_valid_number, '京都府京都市上京区水通葭屋町東入、出水通堀川西入)');
ok($zip->set_number('6028121')->is_valid_number, '京都府京都市上京区家永町');
ok($zip->set_number('6028122')->is_valid_number, '京都府京都市上京区南蟹屋町');
ok($zip->set_number('6028123')->is_valid_number, '京都府京都市上京区橋西二町目');
ok($zip->set_number('6028124')->is_valid_number, '京都府京都市上京区森中町');
ok($zip->set_number('6028125')->is_valid_number, '京都府京都市上京区菱屋町(大宮通椹木町上る、大宮通下立売下る、椹木町通大宮西');
ok($zip->set_number('6028125')->is_valid_number, '京都府京都市上京区入、椹木町通大宮東入)');
ok($zip->set_number('6028126')->is_valid_number, '京都府京都市上京区中書町');
ok($zip->set_number('6028127')->is_valid_number, '京都府京都市上京区櫛笥町');
ok($zip->set_number('6028128')->is_valid_number, '京都府京都市上京区二町目(松屋町通椹木町上る、松屋町通下立売下る)');
ok($zip->set_number('6028131')->is_valid_number, '京都府京都市上京区長尾町');
ok($zip->set_number('6028132')->is_valid_number, '京都府京都市上京区講堂町');
ok($zip->set_number('6028133')->is_valid_number, '京都府京都市上京区小伝馬町');
ok($zip->set_number('6028134')->is_valid_number, '京都府京都市上京区一町目(大宮通椹木町下る、大宮通丸太町上る、椹木町通大宮西');
ok($zip->set_number('6028134')->is_valid_number, '京都府京都市上京区入、丸太町通大宮東入)');
ok($zip->set_number('6028135')->is_valid_number, '京都府京都市上京区三町目(松屋町通椹木町下る、松屋町通丸太町上る)');
ok($zip->set_number('6028136')->is_valid_number, '京都府京都市上京区中御門横町');
ok($zip->set_number('6028137')->is_valid_number, '京都府京都市上京区大黒町(猪熊通椹木町上る、猪熊通下立売下る、椹木町通猪熊西入)');
ok($zip->set_number('6028138')->is_valid_number, '京都府京都市上京区西橋詰町');
ok($zip->set_number('6028139')->is_valid_number, '京都府京都市上京区丸屋町');
ok($zip->set_number('6028141')->is_valid_number, '京都府京都市上京区上堀川町');
ok($zip->set_number('6028142')->is_valid_number, '京都府京都市上京区下堀川町');
ok($zip->set_number('6028143')->is_valid_number, '京都府京都市上京区中之町(猪熊通竹屋町上る、猪熊通丸太町下る、西堀川通丸太町下る)');
ok($zip->set_number('6028144')->is_valid_number, '京都府京都市上京区藁屋町');
ok($zip->set_number('6028145')->is_valid_number, '京都府京都市上京区左馬松町');
ok($zip->set_number('6028146')->is_valid_number, '京都府京都市上京区木屋之町');
ok($zip->set_number('6028147')->is_valid_number, '京都府京都市上京区直家町');
ok($zip->set_number('6028148')->is_valid_number, '京都府京都市上京区西丸太町');
ok($zip->set_number('6028151')->is_valid_number, '京都府京都市上京区西院町');
ok($zip->set_number('6028152')->is_valid_number, '京都府京都市上京区北伊勢屋町');
ok($zip->set_number('6028153')->is_valid_number, '京都府京都市上京区南伊勢屋町');
ok($zip->set_number('6028154')->is_valid_number, '京都府京都市上京区四町目(竹屋町通日暮西入、日暮通竹屋町上る、日暮通丸太町下');
ok($zip->set_number('6028154')->is_valid_number, '京都府京都市上京区る、日暮通丸太町下る西入)');
ok($zip->set_number('6028155')->is_valid_number, '京都府京都市上京区主税町');
ok($zip->set_number('6028156')->is_valid_number, '京都府京都市上京区聚楽町');
ok($zip->set_number('6028157')->is_valid_number, '京都府京都市上京区小山町');
ok($zip->set_number('6028158')->is_valid_number, '京都府京都市上京区中務町');
ok($zip->set_number('6028161')->is_valid_number, '京都府京都市上京区新御幸町');
ok($zip->set_number('6028162')->is_valid_number, '京都府京都市上京区東神明町');
ok($zip->set_number('6028163')->is_valid_number, '京都府京都市上京区田中町');
ok($zip->set_number('6028164')->is_valid_number, '京都府京都市上京区十四軒町');
ok($zip->set_number('6028165')->is_valid_number, '京都府京都市上京区尼ケ崎横町');
ok($zip->set_number('6028166')->is_valid_number, '京都府京都市上京区福島町');
ok($zip->set_number('6028167')->is_valid_number, '京都府京都市上京区二本松町');
ok($zip->set_number('6028168')->is_valid_number, '京都府京都市上京区弁天町');
ok($zip->set_number('6028169')->is_valid_number, '京都府京都市上京区西神明町');
ok($zip->set_number('6028171')->is_valid_number, '京都府京都市上京区山本町');
ok($zip->set_number('6028172')->is_valid_number, '京都府京都市上京区天秤丸町');
ok($zip->set_number('6028173')->is_valid_number, '京都府京都市上京区金馬場町');
ok($zip->set_number('6028174')->is_valid_number, '京都府京都市上京区分銅町');
ok($zip->set_number('6028175')->is_valid_number, '京都府京都市上京区中村町');
ok($zip->set_number('6028176')->is_valid_number, '京都府京都市上京区下丸屋町');
ok($zip->set_number('6028177')->is_valid_number, '京都府京都市上京区田村備前町');
ok($zip->set_number('6028178')->is_valid_number, '京都府京都市上京区白銀町');
ok($zip->set_number('6028179')->is_valid_number, '京都府京都市上京区坤高町');
ok($zip->set_number('6028201')->is_valid_number, '京都府京都市上京区桝屋町(笹屋町通大宮西入、笹屋町通智恵光院東入)');
ok($zip->set_number('6028202')->is_valid_number, '京都府京都市上京区栄町(大宮通一条上る西入、大宮通中立売下る、智恵光院通一条上る東入)');
ok($zip->set_number('6028203')->is_valid_number, '京都府京都市上京区鏡石町');
ok($zip->set_number('6028204')->is_valid_number, '京都府京都市上京区下鏡石町');
ok($zip->set_number('6028205')->is_valid_number, '京都府京都市上京区新白水丸町');
ok($zip->set_number('6028206')->is_valid_number, '京都府京都市上京区南新在家町');
ok($zip->set_number('6028207')->is_valid_number, '京都府京都市上京区北新在家町');
ok($zip->set_number('6028208')->is_valid_number, '京都府京都市上京区智恵光院前之町');
ok($zip->set_number('6028209')->is_valid_number, '京都府京都市上京区橘町');
ok($zip->set_number('6028211')->is_valid_number, '京都府京都市上京区村雲町');
ok($zip->set_number('6028212')->is_valid_number, '京都府京都市上京区橋詰町');
ok($zip->set_number('6028213')->is_valid_number, '京都府京都市上京区徳屋町');
ok($zip->set_number('6028214')->is_valid_number, '京都府京都市上京区北之御門町');
ok($zip->set_number('6028215')->is_valid_number, '京都府京都市上京区寺今町');
ok($zip->set_number('6028216')->is_valid_number, '京都府京都市上京区竪門前町');
ok($zip->set_number('6028217')->is_valid_number, '京都府京都市上京区南門前町');
ok($zip->set_number('6028218')->is_valid_number, '京都府京都市上京区富小路町');
ok($zip->set_number('6028221')->is_valid_number, '京都府京都市上京区堀川上之町');
ok($zip->set_number('6028222')->is_valid_number, '京都府京都市上京区晴明町');
ok($zip->set_number('6028223')->is_valid_number, '京都府京都市上京区横神明町');
ok($zip->set_number('6028224')->is_valid_number, '京都府京都市上京区弾正町');
ok($zip->set_number('6028225')->is_valid_number, '京都府京都市上京区下石橋町');
ok($zip->set_number('6028226')->is_valid_number, '京都府京都市上京区石薬師町');
ok($zip->set_number('6028227')->is_valid_number, '京都府京都市上京区毘沙門町(大宮通一条上る東入、黒門通一条上る、黒門通元誓願寺');
ok($zip->set_number('6028227')->is_valid_number, '京都府京都市上京区下る、黒門通元誓願寺下る西入、黒門通一条上る西入)');
ok($zip->set_number('6028228')->is_valid_number, '京都府京都市上京区竪神明町');
ok($zip->set_number('6028231')->is_valid_number, '京都府京都市上京区如水町');
ok($zip->set_number('6028232')->is_valid_number, '京都府京都市上京区堀川下之町');
ok($zip->set_number('6028233')->is_valid_number, '京都府京都市上京区福大明神町');
ok($zip->set_number('6028234')->is_valid_number, '京都府京都市上京区小寺町');
ok($zip->set_number('6028235')->is_valid_number, '京都府京都市上京区飛弾殿町');
ok($zip->set_number('6028236')->is_valid_number, '京都府京都市上京区庇町');
ok($zip->set_number('6028237')->is_valid_number, '京都府京都市上京区梨木町');
ok($zip->set_number('6028238')->is_valid_number, '京都府京都市上京区糸屋町');
ok($zip->set_number('6028239')->is_valid_number, '京都府京都市上京区下石橋南半町');
ok($zip->set_number('6028241')->is_valid_number, '京都府京都市上京区役人町');
ok($zip->set_number('6028242')->is_valid_number, '京都府京都市上京区皀莢町');
ok($zip->set_number('6028243')->is_valid_number, '京都府京都市上京区奈良物町');
ok($zip->set_number('6028244')->is_valid_number, '京都府京都市上京区菊屋町(葭屋町通上長者町下る、葭屋町通下長者町上る、上長者町');
ok($zip->set_number('6028244')->is_valid_number, '京都府京都市上京区通葭屋町西入、上長者町通葭屋町東入、下長者町通葭屋町西入、下長者町通葭屋');
ok($zip->set_number('6028244')->is_valid_number, '京都府京都市上京区町東入、下長者町通堀川西入)');
ok($zip->set_number('6028245')->is_valid_number, '京都府京都市上京区猪熊');
ok($zip->set_number('6028246')->is_valid_number, '京都府京都市上京区杉本町');
ok($zip->set_number('6028247')->is_valid_number, '京都府京都市上京区北俵町');
ok($zip->set_number('6028248')->is_valid_number, '京都府京都市上京区南俵町');
ok($zip->set_number('6028251')->is_valid_number, '京都府京都市上京区榎町');
ok($zip->set_number('6028252')->is_valid_number, '京都府京都市上京区北小大門町');
ok($zip->set_number('6028253')->is_valid_number, '京都府京都市上京区南小大門町');
ok($zip->set_number('6028254')->is_valid_number, '京都府京都市上京区藤五郎町');
ok($zip->set_number('6028255')->is_valid_number, '京都府京都市上京区東堀町');
ok($zip->set_number('6028256')->is_valid_number, '京都府京都市上京区神明町(上長者町通松屋町東入、松屋町通上長者町上る、松屋町通中立売下る)');
ok($zip->set_number('6028257')->is_valid_number, '京都府京都市上京区新元町');
ok($zip->set_number('6028258')->is_valid_number, '京都府京都市上京区和水町');
ok($zip->set_number('6028259')->is_valid_number, '京都府京都市上京区常陸町');
ok($zip->set_number('6028261')->is_valid_number, '京都府京都市上京区多門町');
ok($zip->set_number('6028262')->is_valid_number, '京都府京都市上京区須浜池町');
ok($zip->set_number('6028263')->is_valid_number, '京都府京都市上京区須浜東町');
ok($zip->set_number('6028264')->is_valid_number, '京都府京都市上京区須浜町');
ok($zip->set_number('6028265')->is_valid_number, '京都府京都市上京区下山里町');
ok($zip->set_number('6028266')->is_valid_number, '京都府京都市上京区菱丸町');
ok($zip->set_number('6028267')->is_valid_number, '京都府京都市上京区高台院竪町');
ok($zip->set_number('6028268')->is_valid_number, '京都府京都市上京区山里町');
ok($zip->set_number('6028271')->is_valid_number, '京都府京都市上京区高台院町');
ok($zip->set_number('6028272')->is_valid_number, '京都府京都市上京区亀木町');
ok($zip->set_number('6028273')->is_valid_number, '京都府京都市上京区長谷町');
ok($zip->set_number('6028274')->is_valid_number, '京都府京都市上京区山王町');
ok($zip->set_number('6028275')->is_valid_number, '京都府京都市上京区革堂前之町');
ok($zip->set_number('6028276')->is_valid_number, '京都府京都市上京区百万遍町');
ok($zip->set_number('6028277')->is_valid_number, '京都府京都市上京区信濃町');
ok($zip->set_number('6028278')->is_valid_number, '京都府京都市上京区愛染寺町');
ok($zip->set_number('6028279')->is_valid_number, '京都府京都市上京区新柳馬場頭町');
ok($zip->set_number('6028281')->is_valid_number, '京都府京都市上京区加賀屋町');
ok($zip->set_number('6028282')->is_valid_number, '京都府京都市上京区西富仲町');
ok($zip->set_number('6028283')->is_valid_number, '京都府京都市上京区仲御霊町');
ok($zip->set_number('6028284')->is_valid_number, '京都府京都市上京区亀屋町(千本通中立売上る、千本通中立売下る、中立売通千本西入)');
ok($zip->set_number('6028285')->is_valid_number, '京都府京都市上京区西中筋町');
ok($zip->set_number('6028286')->is_valid_number, '京都府京都市上京区玉屋町(千本通中立売上る、中立売通千本東入)');
ok($zip->set_number('6028287')->is_valid_number, '京都府京都市上京区丹波屋町');
ok($zip->set_number('6028288')->is_valid_number, '京都府京都市上京区田丸町');
ok($zip->set_number('6028291')->is_valid_number, '京都府京都市上京区福本町');
ok($zip->set_number('6028292')->is_valid_number, '京都府京都市上京区今新在家町');
ok($zip->set_number('6028293')->is_valid_number, '京都府京都市上京区新桝屋町');
ok($zip->set_number('6028294')->is_valid_number, '京都府京都市上京区東西俵屋町');
ok($zip->set_number('6028295')->is_valid_number, '京都府京都市上京区東石橋町');
ok($zip->set_number('6028296')->is_valid_number, '京都府京都市上京区北伊勢殿構町');
ok($zip->set_number('6028297')->is_valid_number, '京都府京都市上京区伊勢殿構町');
ok($zip->set_number('6028298')->is_valid_number, '京都府京都市上京区泰童町');
ok($zip->set_number('6028299')->is_valid_number, '京都府京都市上京区革堂之内町');
ok($zip->set_number('6028301')->is_valid_number, '京都府京都市上京区西芦山寺町');
ok($zip->set_number('6028302')->is_valid_number, '京都府京都市上京区井田町');
ok($zip->set_number('6028303')->is_valid_number, '京都府京都市上京区姥ケ寺之前町');
ok($zip->set_number('6028304')->is_valid_number, '京都府京都市上京区作庵町');
ok($zip->set_number('6028305')->is_valid_number, '京都府京都市上京区花車町');
ok($zip->set_number('6028306')->is_valid_number, '京都府京都市上京区西五辻北町');
ok($zip->set_number('6028307')->is_valid_number, '京都府京都市上京区閻魔前町');
ok($zip->set_number('6028308')->is_valid_number, '京都府京都市上京区北玄蕃町');
ok($zip->set_number('6028311')->is_valid_number, '京都府京都市上京区柏清盛町');
ok($zip->set_number('6028312')->is_valid_number, '京都府京都市上京区末広町');
ok($zip->set_number('6028313')->is_valid_number, '京都府京都市上京区風呂屋町');
ok($zip->set_number('6028314')->is_valid_number, '京都府京都市上京区佐竹町');
ok($zip->set_number('6028315')->is_valid_number, '京都府京都市上京区突抜町(今出川通七本松東入、今出川通七本松東入上る、五辻通七');
ok($zip->set_number('6028315')->is_valid_number, '京都府京都市上京区本松東入下る、五辻通六軒町西入下る)');
ok($zip->set_number('6028316')->is_valid_number, '京都府京都市上京区片原町');
ok($zip->set_number('6028317')->is_valid_number, '京都府京都市上京区東柳町');
ok($zip->set_number('6028318')->is_valid_number, '京都府京都市上京区老松町');
ok($zip->set_number('6028319')->is_valid_number, '京都府京都市上京区溝前町');
ok($zip->set_number('6028321')->is_valid_number, '京都府京都市上京区南上善寺町');
ok($zip->set_number('6028322')->is_valid_number, '京都府京都市上京区玉屋町(元誓願寺通千本西入、元誓願寺通六軒町東入、六軒町通元');
ok($zip->set_number('6028322')->is_valid_number, '京都府京都市上京区誓願寺上る、六軒町通元誓願寺下る、葭屋町通元誓願寺下る)');
ok($zip->set_number('6028323')->is_valid_number, '京都府京都市上京区大文字町');
ok($zip->set_number('6028324')->is_valid_number, '京都府京都市上京区元観音町');
ok($zip->set_number('6028325')->is_valid_number, '京都府京都市上京区毘沙門町(今出川通七本松西入、今出川通七本松西入上る、七本松通');
ok($zip->set_number('6028325')->is_valid_number, '京都府京都市上京区今出川上る、七本松通今出川下る、七本松通元誓願寺上る、七本松通五辻下る)');
ok($zip->set_number('6028326')->is_valid_number, '京都府京都市上京区西上善寺町');
ok($zip->set_number('6028327')->is_valid_number, '京都府京都市上京区南佐竹町');
ok($zip->set_number('6028331')->is_valid_number, '京都府京都市上京区若松町');
ok($zip->set_number('6028332')->is_valid_number, '京都府京都市上京区烏丸町');
ok($zip->set_number('6028333')->is_valid_number, '京都府京都市上京区三条殿町');
ok($zip->set_number('6028334')->is_valid_number, '京都府京都市上京区西今出川町');
ok($zip->set_number('6028335')->is_valid_number, '京都府京都市上京区一観音町');
ok($zip->set_number('6028336')->is_valid_number, '京都府京都市上京区滝ケ鼻町');
ok($zip->set_number('6028337')->is_valid_number, '京都府京都市上京区新建町');
ok($zip->set_number('6028338')->is_valid_number, '京都府京都市上京区松永町');
ok($zip->set_number('6028341')->is_valid_number, '京都府京都市上京区三軒町');
ok($zip->set_number('6028342')->is_valid_number, '京都府京都市上京区五番町');
ok($zip->set_number('6028343')->is_valid_number, '京都府京都市上京区利生町');
ok($zip->set_number('6028344')->is_valid_number, '京都府京都市上京区二番町');
ok($zip->set_number('6028345')->is_valid_number, '京都府京都市上京区一番町');
ok($zip->set_number('6028346')->is_valid_number, '京都府京都市上京区東町(一条通下ノ森西入、一条通下ノ森東入、一条通七本松西');
ok($zip->set_number('6028346')->is_valid_number, '京都府京都市上京区入、中立売通七本松西入)');
ok($zip->set_number('6028347')->is_valid_number, '京都府京都市上京区四番町');
ok($zip->set_number('6028348')->is_valid_number, '京都府京都市上京区白竹町');
ok($zip->set_number('6028351')->is_valid_number, '京都府京都市上京区六番町');
ok($zip->set_number('6028352')->is_valid_number, '京都府京都市上京区稲葉町');
ok($zip->set_number('6028353')->is_valid_number, '京都府京都市上京区長門町');
ok($zip->set_number('6028354')->is_valid_number, '京都府京都市上京区西東町');
ok($zip->set_number('6028355')->is_valid_number, '京都府京都市上京区天満屋町');
ok($zip->set_number('6028356')->is_valid_number, '京都府京都市上京区三助町');
ok($zip->set_number('6028357')->is_valid_number, '京都府京都市上京区鳳瑞町');
ok($zip->set_number('6028358')->is_valid_number, '京都府京都市上京区三番町');
ok($zip->set_number('6028359')->is_valid_number, '京都府京都市上京区七番町');
ok($zip->set_number('6028361')->is_valid_number, '京都府京都市上京区西上之町');
ok($zip->set_number('6028362')->is_valid_number, '京都府京都市上京区仲之町(御前通上の下立売上る、御前通上の下立売上る東入、御前');
ok($zip->set_number('6028362')->is_valid_number, '京都府京都市上京区通上の下立売上る2丁目、御前通下立売上る、御前通下立売上る2丁目、御前通');
ok($zip->set_number('6028362')->is_valid_number, '京都府京都市上京区下立売上る2丁目西入、御前通下立売上る東入、下ノ森通下立売上る、下ノ森通');
ok($zip->set_number('6028362')->is_valid_number, '京都府京都市上京区下立売上る西入、上の下立売通御前西入上る)');
ok($zip->set_number('6028363')->is_valid_number, '京都府京都市上京区大宮町(上の下立売通御前西入、上の下立売通御前西入上る、');
ok($zip->set_number('6028363')->is_valid_number, '京都府京都市上京区上の下立売通天神道東入、下立売通御前西入、下立売通御前西入上る)');
ok($zip->set_number('6028364')->is_valid_number, '京都府京都市上京区突抜町(下立売通御前西入、下立売通御前西入下る、下立売通天');
ok($zip->set_number('6028364')->is_valid_number, '京都府京都市上京区神道東入、下の下立売通御前西入)');
ok($zip->set_number('6028365')->is_valid_number, '京都府京都市上京区下之町');
ok($zip->set_number('6028366')->is_valid_number, '京都府京都市上京区行衛町');
ok($zip->set_number('6028367')->is_valid_number, '京都府京都市上京区堀川町');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区北町(上の下立売通天神道西入上る、上の下立売通御前西入、上');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区の下立売通御前西入上る、上の下立売通御前西入2丁目、上の下立売通御前西入');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区2筋目、下長者町通御前西入、天神道上の下立売上る、天神道仁和寺街道下る、');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区天神道下立売上る、天神道妙心寺道上る、天神道妙心寺道上る西入、仁和寺街');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区道天神道西入下る、仁和寺街道天神道東入下る、御前通上の下立売上る、御前通');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区上の下立売上る西入、御前通下立売上る、御前通下長者町上る西入、御前通仁');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区和寺街道下る西入、御前通妙心寺道上る西入、御前通西裏上の下立売上る、御前');
ok($zip->set_number('6028368')->is_valid_number, '京都府京都市上京区通西裏下立売上る)');
ok($zip->set_number('6028369')->is_valid_number, '京都府京都市上京区川瀬町');
ok($zip->set_number('6028371')->is_valid_number, '京都府京都市上京区西町(一条通御前東入)');
ok($zip->set_number('6028372')->is_valid_number, '京都府京都市上京区下竪町');
ok($zip->set_number('6028373')->is_valid_number, '京都府京都市上京区下横町');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区西町(一条通御前西入、一条通紙屋川東入、一条通天神道西入、');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区一条通御前3丁目西入、一条通御前西入上る、一条通御前西入上る西入、');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区一条通御前西入2丁目、一条通御前西入2丁目上る、一条通御前西入2丁目');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区下る、一条通御前西入2筋目下る、一条通御前西入3丁目、一条通御前');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区西入3丁目上る、一条通御前西入3丁目下る、一条通御前西入3筋目、');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区一条通御前西入下る、一条通御前西入下る3丁目、一条通紙屋川東入');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区上る、一条通紙屋川東入下る、天神道一条上る、天神道一条下る、天神道');
ok($zip->set_number('6028374')->is_valid_number, '京都府京都市上京区仁和寺街道上る)');
ok($zip->set_number('6028375')->is_valid_number, '京都府京都市上京区大上之町');
ok($zip->set_number('6028376')->is_valid_number, '京都府京都市上京区大東町');
ok($zip->set_number('6028377')->is_valid_number, '京都府京都市上京区東竪町');
ok($zip->set_number('6028381')->is_valid_number, '京都府京都市上京区真盛町');
ok($zip->set_number('6028382')->is_valid_number, '京都府京都市上京区末之口町');
ok($zip->set_number('6028383')->is_valid_number, '京都府京都市上京区西今小路町');
ok($zip->set_number('6028384')->is_valid_number, '京都府京都市上京区紙屋川町');
ok($zip->set_number('6028385')->is_valid_number, '京都府京都市上京区観音寺門前町');
ok($zip->set_number('6028386')->is_valid_number, '京都府京都市上京区馬喰町');
ok($zip->set_number('6028387')->is_valid_number, '京都府京都市上京区東今小路町');
ok($zip->set_number('6028391')->is_valid_number, '京都府京都市上京区神明町(御前通寺之内下る、御前通今出川上る、御前通今出川上');
ok($zip->set_number('6028391')->is_valid_number, '京都府京都市上京区る2丁目、御前通今出川上る3丁目、寺之内通御前西入)');
ok($zip->set_number('6028392')->is_valid_number, '京都府京都市上京区北町(御前通五辻上る、御前通今出川上る、御前通今出川上る1');
ok($zip->set_number('6028392')->is_valid_number, '京都府京都市上京区丁目、御前通今出川上る2丁目、御前通今出川上る2丁目西入、御前通今出川上');
ok($zip->set_number('6028392')->is_valid_number, '京都府京都市上京区る2筋目、御前通今出川上る西入、御前通今出川上る東入、御前通今出川2丁目');
ok($zip->set_number('6028392')->is_valid_number, '京都府京都市上京区上る、御前通寺之内下る)');
ok($zip->set_number('6028393')->is_valid_number, '京都府京都市上京区鳥居前町');
ok($zip->set_number('6028394')->is_valid_number, '京都府京都市上京区西柳町');
ok($zip->set_number('6028395')->is_valid_number, '京都府京都市上京区社家長屋町');
ok($zip->set_number('6028401')->is_valid_number, '京都府京都市上京区薬師前町');
ok($zip->set_number('6028402')->is_valid_number, '京都府京都市上京区田畑町');
ok($zip->set_number('6028403')->is_valid_number, '京都府京都市上京区中社町');
ok($zip->set_number('6028404')->is_valid_number, '京都府京都市上京区西千本町');
ok($zip->set_number('6028405')->is_valid_number, '京都府京都市上京区大猪熊町(寺之内通大宮西入、寺之内通智恵光院西入、寺之内通智');
ok($zip->set_number('6028405')->is_valid_number, '京都府京都市上京区恵光院東入、寺之内通大宮東入、智恵光院通寺之内下る)');
ok($zip->set_number('6028406')->is_valid_number, '京都府京都市上京区花開院町');
ok($zip->set_number('6028407')->is_valid_number, '京都府京都市上京区伊佐町');
ok($zip->set_number('6028408')->is_valid_number, '京都府京都市上京区古美濃部町');
ok($zip->set_number('6028409')->is_valid_number, '京都府京都市上京区新美濃部町');
ok($zip->set_number('6028411')->is_valid_number, '京都府京都市上京区東西町');
ok($zip->set_number('6028412')->is_valid_number, '京都府京都市上京区芝之町');
ok($zip->set_number('6028413')->is_valid_number, '京都府京都市上京区大北小路東町');
ok($zip->set_number('6028414')->is_valid_number, '京都府京都市上京区西北小路町(猪熊通上立売上る、猪熊通寺之内下る、大宮通寺之内下');
ok($zip->set_number('6028414')->is_valid_number, '京都府京都市上京区る東入、大宮通寺之内半丁下る東入、大宮通寺之内下る東入1丁目、寺之内通大');
ok($zip->set_number('6028414')->is_valid_number, '京都府京都市上京区宮東入下る、寺之内通大宮東入1丁目下る)');
ok($zip->set_number('6028415')->is_valid_number, '京都府京都市上京区前之町');
ok($zip->set_number('6028416')->is_valid_number, '京都府京都市上京区東千本町');
ok($zip->set_number('6028417')->is_valid_number, '京都府京都市上京区東社町');
ok($zip->set_number('6028418')->is_valid_number, '京都府京都市上京区妙蓮寺前町');
ok($zip->set_number('6028421')->is_valid_number, '京都府京都市上京区芝薬師町');
ok($zip->set_number('6028422')->is_valid_number, '京都府京都市上京区山名町');
ok($zip->set_number('6028423')->is_valid_number, '京都府京都市上京区藤木町');
ok($zip->set_number('6028424')->is_valid_number, '京都府京都市上京区阿弥陀寺町');
ok($zip->set_number('6028425')->is_valid_number, '京都府京都市上京区樋之口町');
ok($zip->set_number('6028426')->is_valid_number, '京都府京都市上京区曼陀羅町');
ok($zip->set_number('6028427')->is_valid_number, '京都府京都市上京区土田町');
ok($zip->set_number('6028428')->is_valid_number, '京都府京都市上京区幸在町');
ok($zip->set_number('6028431')->is_valid_number, '京都府京都市上京区東石屋町');
ok($zip->set_number('6028432')->is_valid_number, '京都府京都市上京区北猪熊町');
ok($zip->set_number('6028433')->is_valid_number, '京都府京都市上京区橋之上町');
ok($zip->set_number('6028434')->is_valid_number, '京都府京都市上京区西船橋町');
ok($zip->set_number('6028435')->is_valid_number, '京都府京都市上京区元伊佐町');
ok($zip->set_number('6028436')->is_valid_number, '京都府京都市上京区慈眼庵町');
ok($zip->set_number('6028437')->is_valid_number, '京都府京都市上京区西石屋町');
ok($zip->set_number('6028438')->is_valid_number, '京都府京都市上京区芝大宮町');
ok($zip->set_number('6028439')->is_valid_number, '京都府京都市上京区硯屋町');
ok($zip->set_number('6028441')->is_valid_number, '京都府京都市上京区観世町');
ok($zip->set_number('6028442')->is_valid_number, '京都府京都市上京区薬師町');
ok($zip->set_number('6028443')->is_valid_number, '京都府京都市上京区元妙蓮寺町');
ok($zip->set_number('6028444')->is_valid_number, '京都府京都市上京区西北小路町(今出川通浄福寺東入、今出川通智恵光院西入、今出川通智');
ok($zip->set_number('6028444')->is_valid_number, '京都府京都市上京区恵光院東入、智恵光院通今出川上る、智恵光院通今出川下る、五辻通浄福寺');
ok($zip->set_number('6028444')->is_valid_number, '京都府京都市上京区東入)');
ok($zip->set_number('6028445')->is_valid_number, '京都府京都市上京区桜井町');
ok($zip->set_number('6028446')->is_valid_number, '京都府京都市上京区五辻町');
ok($zip->set_number('6028447')->is_valid_number, '京都府京都市上京区紋屋町');
ok($zip->set_number('6028448')->is_valid_number, '京都府京都市上京区元北小路町');
ok($zip->set_number('6028449')->is_valid_number, '京都府京都市上京区横大宮町');
ok($zip->set_number('6028451')->is_valid_number, '京都府京都市上京区菱屋町(中筋通浄福寺東入、中筋通智恵光院西入)');
ok($zip->set_number('6028452')->is_valid_number, '京都府京都市上京区元中之町');
ok($zip->set_number('6028453')->is_valid_number, '京都府京都市上京区笹屋');
ok($zip->set_number('6028454')->is_valid_number, '京都府京都市上京区今出川町(元誓願寺通浄福寺西入、元誓願寺通浄福寺東入、浄福寺通');
ok($zip->set_number('6028454')->is_valid_number, '京都府京都市上京区元誓願寺上る、浄福寺通元誓願寺下る)');
ok($zip->set_number('6028455')->is_valid_number, '京都府京都市上京区泰童片原町');
ok($zip->set_number('6028461')->is_valid_number, '京都府京都市上京区北小路中之町');
ok($zip->set_number('6028462')->is_valid_number, '京都府京都市上京区竪亀屋町');
ok($zip->set_number('6028463')->is_valid_number, '京都府京都市上京区革堂町(元誓願寺通浄福寺西入)');
ok($zip->set_number('6028464')->is_valid_number, '京都府京都市上京区元四丁目');
ok($zip->set_number('6028465')->is_valid_number, '京都府京都市上京区松屋町');
ok($zip->set_number('6028466')->is_valid_number, '京都府京都市上京区南辻町');
ok($zip->set_number('6028467')->is_valid_number, '京都府京都市上京区西亀屋町');
ok($zip->set_number('6028468')->is_valid_number, '京都府京都市上京区東上善寺町');
ok($zip->set_number('6028469')->is_valid_number, '京都府京都市上京区中宮町');
ok($zip->set_number('6028471')->is_valid_number, '京都府京都市上京区一色町');
ok($zip->set_number('6028472')->is_valid_number, '京都府京都市上京区有馬町');
ok($zip->set_number('6028473')->is_valid_number, '京都府京都市上京区般舟院前町');
ok($zip->set_number('6028474')->is_valid_number, '京都府京都市上京区上善寺町');
ok($zip->set_number('6028475')->is_valid_number, '京都府京都市上京区牡丹鉾町');
ok($zip->set_number('6028476')->is_valid_number, '京都府京都市上京区桐木町');
ok($zip->set_number('6028477')->is_valid_number, '京都府京都市上京区姥ケ榎木町');
ok($zip->set_number('6028478')->is_valid_number, '京都府京都市上京区西五辻東町');
ok($zip->set_number('6028481')->is_valid_number, '京都府京都市上京区聖天町');
ok($zip->set_number('6028482')->is_valid_number, '京都府京都市上京区大黒町(上立売通浄福寺西入、上立売通浄福寺東入、浄福寺通上立');
ok($zip->set_number('6028482')->is_valid_number, '京都府京都市上京区売上る、浄福寺通寺之内下る)');
ok($zip->set_number('6028483')->is_valid_number, '京都府京都市上京区杉若町');
ok($zip->set_number('6028484')->is_valid_number, '京都府京都市上京区蛭子町(上立売通浄福寺西入、浄福寺通上立売下る)');
ok($zip->set_number('6028485')->is_valid_number, '京都府京都市上京区姥ケ東西町');
ok($zip->set_number('6028486')->is_valid_number, '京都府京都市上京区姥ケ西町');
ok($zip->set_number('6028487')->is_valid_number, '京都府京都市上京区姥ケ北町');
ok($zip->set_number('6028488')->is_valid_number, '京都府京都市上京区真倉町');
ok($zip->set_number('6028491')->is_valid_number, '京都府京都市上京区西社町');
ok($zip->set_number('6028492')->is_valid_number, '京都府京都市上京区歓喜町');
ok($zip->set_number('6028493')->is_valid_number, '京都府京都市上京区中猪熊町');
ok($zip->set_number('6028494')->is_valid_number, '京都府京都市上京区新猪熊東町');
ok($zip->set_number('6028495')->is_valid_number, '京都府京都市上京区新猪熊町');
ok($zip->set_number('6028496')->is_valid_number, '京都府京都市上京区木瓜原町');
ok($zip->set_number('6028497')->is_valid_number, '京都府京都市上京区戌亥町');
ok($zip->set_number('6028498')->is_valid_number, '京都府京都市上京区西熊町');
ok($zip->set_number('6030000')->is_valid_number, '京都府京都市北区以下に掲載がない場合');
ok($zip->set_number('6038001')->is_valid_number, '京都府京都市北区上賀茂十三石山');
ok($zip->set_number('6038002')->is_valid_number, '京都府京都市北区上賀茂神山');
ok($zip->set_number('6038003')->is_valid_number, '京都府京都市北区上賀茂柊谷町');
ok($zip->set_number('6038004')->is_valid_number, '京都府京都市北区上賀茂六段田町');
ok($zip->set_number('6038005')->is_valid_number, '京都府京都市北区上賀茂前田町');
ok($zip->set_number('6038006')->is_valid_number, '京都府京都市北区上賀茂北ノ原町');
ok($zip->set_number('6038007')->is_valid_number, '京都府京都市北区上賀茂毛穴井町');
ok($zip->set_number('6038008')->is_valid_number, '京都府京都市北区上賀茂中嶋河原町');
ok($zip->set_number('6038011')->is_valid_number, '京都府京都市北区上賀茂二軒家町');
ok($zip->set_number('6038012')->is_valid_number, '京都府京都市北区上賀茂葵田町');
ok($zip->set_number('6038013')->is_valid_number, '京都府京都市北区上賀茂上神原町');
ok($zip->set_number('6038014')->is_valid_number, '京都府京都市北区上賀茂下神原町');
ok($zip->set_number('6038015')->is_valid_number, '京都府京都市北区上賀茂備後田町');
ok($zip->set_number('6038016')->is_valid_number, '京都府京都市北区上賀茂坂口町');
ok($zip->set_number('6038017')->is_valid_number, '京都府京都市北区上賀茂壱町口町');
ok($zip->set_number('6038018')->is_valid_number, '京都府京都市北区上賀茂赤尾町');
ok($zip->set_number('6038021')->is_valid_number, '京都府京都市北区上賀茂西後藤町');
ok($zip->set_number('6038022')->is_valid_number, '京都府京都市北区上賀茂東後藤町');
ok($zip->set_number('6038023')->is_valid_number, '京都府京都市北区上賀茂東上之段町');
ok($zip->set_number('6038024')->is_valid_number, '京都府京都市北区上賀茂中ノ坂町');
ok($zip->set_number('6038025')->is_valid_number, '京都府京都市北区上賀茂舟着町');
ok($zip->set_number('6038026')->is_valid_number, '京都府京都市北区上賀茂中山町');
ok($zip->set_number('6038027')->is_valid_number, '京都府京都市北区上賀茂津ノ国町');
ok($zip->set_number('6038028')->is_valid_number, '京都府京都市北区上賀茂西上之段町');
ok($zip->set_number('6038031')->is_valid_number, '京都府京都市北区上賀茂女夫岩町');
ok($zip->set_number('6038032')->is_valid_number, '京都府京都市北区上賀茂中ノ河原町');
ok($zip->set_number('6038033')->is_valid_number, '京都府京都市北区上賀茂馬ノ目町');
ok($zip->set_number('6038034')->is_valid_number, '京都府京都市北区上賀茂葵之森町');
ok($zip->set_number('6038035')->is_valid_number, '京都府京都市北区上賀茂朝露ケ原町');
ok($zip->set_number('6038036')->is_valid_number, '京都府京都市北区上賀茂西河原町');
ok($zip->set_number('6038037')->is_valid_number, '京都府京都市北区上賀茂大柳町');
ok($zip->set_number('6038038')->is_valid_number, '京都府京都市北区上賀茂音保瀬町');
ok($zip->set_number('6038041')->is_valid_number, '京都府京都市北区上賀茂ケシ山');
ok($zip->set_number('6038042')->is_valid_number, '京都府京都市北区上賀茂狭間町');
ok($zip->set_number('6038043')->is_valid_number, '京都府京都市北区上賀茂池端町');
ok($zip->set_number('6038044')->is_valid_number, '京都府京都市北区上賀茂畔勝町');
ok($zip->set_number('6038045')->is_valid_number, '京都府京都市北区上賀茂豊田町');
ok($zip->set_number('6038046')->is_valid_number, '京都府京都市北区上賀茂深泥池町');
ok($zip->set_number('6038047')->is_valid_number, '京都府京都市北区上賀茂本山');
ok($zip->set_number('6038051')->is_valid_number, '京都府京都市北区上賀茂榊田町');
ok($zip->set_number('6038052')->is_valid_number, '京都府京都市北区上賀茂松本町');
ok($zip->set_number('6038053')->is_valid_number, '京都府京都市北区上賀茂岩ケ垣内町');
ok($zip->set_number('6038054')->is_valid_number, '京都府京都市北区上賀茂桜井町');
ok($zip->set_number('6038055')->is_valid_number, '京都府京都市北区上賀茂高縄手町');
ok($zip->set_number('6038056')->is_valid_number, '京都府京都市北区上賀茂石計町');
ok($zip->set_number('6038061')->is_valid_number, '京都府京都市北区上賀茂荒草町');
ok($zip->set_number('6038062')->is_valid_number, '京都府京都市北区上賀茂薮田町');
ok($zip->set_number('6038063')->is_valid_number, '京都府京都市北区上賀茂今井河原町');
ok($zip->set_number('6038064')->is_valid_number, '京都府京都市北区上賀茂菖蒲園町');
ok($zip->set_number('6038065')->is_valid_number, '京都府京都市北区上賀茂御薗口町');
ok($zip->set_number('6038066')->is_valid_number, '京都府京都市北区上賀茂池殿町');
ok($zip->set_number('6038071')->is_valid_number, '京都府京都市北区上賀茂北大路町');
ok($zip->set_number('6038072')->is_valid_number, '京都府京都市北区上賀茂竹ケ鼻町');
ok($zip->set_number('6038073')->is_valid_number, '京都府京都市北区上賀茂烏帽子ケ垣内町');
ok($zip->set_number('6038074')->is_valid_number, '京都府京都市北区上賀茂南大路町');
ok($zip->set_number('6038075')->is_valid_number, '京都府京都市北区上賀茂中大路町');
ok($zip->set_number('6038076')->is_valid_number, '京都府京都市北区上賀茂山本町');
ok($zip->set_number('6038077')->is_valid_number, '京都府京都市北区上賀茂藤ノ木町');
ok($zip->set_number('6038081')->is_valid_number, '京都府京都市北区上賀茂岡本町');
ok($zip->set_number('6038082')->is_valid_number, '京都府京都市北区上賀茂岡本口町');
ok($zip->set_number('6038083')->is_valid_number, '京都府京都市北区上賀茂向縄手町');
ok($zip->set_number('6038084')->is_valid_number, '京都府京都市北区上賀茂土門町');
ok($zip->set_number('6038085')->is_valid_number, '京都府京都市北区上賀茂蝉ケ垣内町');
ok($zip->set_number('6038086')->is_valid_number, '京都府京都市北区上賀茂向梅町');
ok($zip->set_number('6038087')->is_valid_number, '京都府京都市北区上賀茂梅ケ辻町');
ok($zip->set_number('6038101')->is_valid_number, '京都府京都市北区紫竹上堀川町');
ok($zip->set_number('6038102')->is_valid_number, '京都府京都市北区紫竹上長目町');
ok($zip->set_number('6038103')->is_valid_number, '京都府京都市北区小山北玄以町');
ok($zip->set_number('6038104')->is_valid_number, '京都府京都市北区小山東玄以町');
ok($zip->set_number('6038105')->is_valid_number, '京都府京都市北区小山西玄以町');
ok($zip->set_number('6038106')->is_valid_number, '京都府京都市北区紫竹下長目町');
ok($zip->set_number('6038107')->is_valid_number, '京都府京都市北区紫竹下ノ岸町');
ok($zip->set_number('6038108')->is_valid_number, '京都府京都市北区紫竹上ノ岸町');
ok($zip->set_number('6038111')->is_valid_number, '京都府京都市北区小山東元町');
ok($zip->set_number('6038112')->is_valid_number, '京都府京都市北区小山元町');
ok($zip->set_number('6038113')->is_valid_number, '京都府京都市北区小山西元町');
ok($zip->set_number('6038114')->is_valid_number, '京都府京都市北区紫竹下高才町');
ok($zip->set_number('6038115')->is_valid_number, '京都府京都市北区紫竹下本町');
ok($zip->set_number('6038116')->is_valid_number, '京都府京都市北区紫竹上本町');
ok($zip->set_number('6038117')->is_valid_number, '京都府京都市北区紫竹上高才町');
ok($zip->set_number('6038121')->is_valid_number, '京都府京都市北区小山上花ノ木町');
ok($zip->set_number('6038122')->is_valid_number, '京都府京都市北区小山花ノ木町');
ok($zip->set_number('6038123')->is_valid_number, '京都府京都市北区小山下花ノ木町');
ok($zip->set_number('6038124')->is_valid_number, '京都府京都市北区小山下板倉町');
ok($zip->set_number('6038125')->is_valid_number, '京都府京都市北区小山板倉町');
ok($zip->set_number('6038126')->is_valid_number, '京都府京都市北区小山上板倉町');
ok($zip->set_number('6038131')->is_valid_number, '京都府京都市北区小山上内河原町');
ok($zip->set_number('6038132')->is_valid_number, '京都府京都市北区小山下内河原町');
ok($zip->set_number('6038133')->is_valid_number, '京都府京都市北区出雲路松ノ下町');
ok($zip->set_number('6038134')->is_valid_number, '京都府京都市北区出雲路立テ本町');
ok($zip->set_number('6038135')->is_valid_number, '京都府京都市北区出雲路俵町');
ok($zip->set_number('6038136')->is_valid_number, '京都府京都市北区出雲路神楽町');
ok($zip->set_number('6038137')->is_valid_number, '京都府京都市北区鞍馬口町');
ok($zip->set_number('6038138')->is_valid_number, '京都府京都市北区天寧寺門前町');
ok($zip->set_number('6038139')->is_valid_number, '京都府京都市北区上善寺門前町');
ok($zip->set_number('6038141')->is_valid_number, '京都府京都市北区小山西上総町');
ok($zip->set_number('6038142')->is_valid_number, '京都府京都市北区小山北上総町');
ok($zip->set_number('6038143')->is_valid_number, '京都府京都市北区小山上総町');
ok($zip->set_number('6038144')->is_valid_number, '京都府京都市北区小山東花池町');
ok($zip->set_number('6038145')->is_valid_number, '京都府京都市北区小山堀池町');
ok($zip->set_number('6038146')->is_valid_number, '京都府京都市北区新御霊口町');
ok($zip->set_number('6038147')->is_valid_number, '京都府京都市北区上御霊上江町');
ok($zip->set_number('6038148')->is_valid_number, '京都府京都市北区小山西花池町');
ok($zip->set_number('6038149')->is_valid_number, '京都府京都市北区小山南上総町');
ok($zip->set_number('6038151')->is_valid_number, '京都府京都市北区小山下総町');
ok($zip->set_number('6038152')->is_valid_number, '京都府京都市北区小山町');
ok($zip->set_number('6038153')->is_valid_number, '京都府京都市北区長乗東町');
ok($zip->set_number('6038154')->is_valid_number, '京都府京都市北区長乗西町');
ok($zip->set_number('6038155')->is_valid_number, '京都府京都市北区上清蔵口町');
ok($zip->set_number('6038156')->is_valid_number, '京都府京都市北区小山中溝町');
ok($zip->set_number('6038157')->is_valid_number, '京都府京都市北区紫野宮東町');
ok($zip->set_number('6038158')->is_valid_number, '京都府京都市北区紫野宮西町');
ok($zip->set_number('6038161')->is_valid_number, '京都府京都市北区小山北大野町');
ok($zip->set_number('6038162')->is_valid_number, '京都府京都市北区小山東大野町');
ok($zip->set_number('6038163')->is_valid_number, '京都府京都市北区小山南大野町');
ok($zip->set_number('6038164')->is_valid_number, '京都府京都市北区紫野東御所田町');
ok($zip->set_number('6038165')->is_valid_number, '京都府京都市北区紫野西御所田町');
ok($zip->set_number('6038166')->is_valid_number, '京都府京都市北区紫野上御所田町');
ok($zip->set_number('6038167')->is_valid_number, '京都府京都市北区小山西大野町');
ok($zip->set_number('6038171')->is_valid_number, '京都府京都市北区小山上初音町');
ok($zip->set_number('6038172')->is_valid_number, '京都府京都市北区小山初音町');
ok($zip->set_number('6038173')->is_valid_number, '京都府京都市北区小山下初音町');
ok($zip->set_number('6038174')->is_valid_number, '京都府京都市北区紫野下柳町');
ok($zip->set_number('6038175')->is_valid_number, '京都府京都市北区紫野下鳥田町');
ok($zip->set_number('6038176')->is_valid_number, '京都府京都市北区紫野上鳥田町');
ok($zip->set_number('6038177')->is_valid_number, '京都府京都市北区紫野上柳町');
ok($zip->set_number('6038178')->is_valid_number, '京都府京都市北区紫竹下梅ノ木町');
ok($zip->set_number('6038179')->is_valid_number, '京都府京都市北区紫竹上梅ノ木町');
ok($zip->set_number('6038201')->is_valid_number, '京都府京都市北区紫竹桃ノ本町');
ok($zip->set_number('6038202')->is_valid_number, '京都府京都市北区紫竹東桃ノ本町');
ok($zip->set_number('6038203')->is_valid_number, '京都府京都市北区紫竹東高縄町');
ok($zip->set_number('6038204')->is_valid_number, '京都府京都市北区紫竹高縄町');
ok($zip->set_number('6038205')->is_valid_number, '京都府京都市北区紫竹西高縄町');
ok($zip->set_number('6038206')->is_valid_number, '京都府京都市北区紫竹西南町');
ok($zip->set_number('6038207')->is_valid_number, '京都府京都市北区紫竹牛若町');
ok($zip->set_number('6038208')->is_valid_number, '京都府京都市北区紫竹西桃ノ本町');
ok($zip->set_number('6038211')->is_valid_number, '京都府京都市北区紫野上石龍町');
ok($zip->set_number('6038212')->is_valid_number, '京都府京都市北区紫野石龍町');
ok($zip->set_number('6038213')->is_valid_number, '京都府京都市北区紫野下石龍町');
ok($zip->set_number('6038214')->is_valid_number, '京都府京都市北区紫野雲林院町');
ok($zip->set_number('6038215')->is_valid_number, '京都府京都市北区紫野下門前町');
ok($zip->set_number('6038216')->is_valid_number, '京都府京都市北区紫野門前町');
ok($zip->set_number('6038217')->is_valid_number, '京都府京都市北区紫野上門前町');
ok($zip->set_number('6038221')->is_valid_number, '京都府京都市北区紫野上築山町');
ok($zip->set_number('6038222')->is_valid_number, '京都府京都市北区紫野下築山町');
ok($zip->set_number('6038223')->is_valid_number, '京都府京都市北区紫野東藤ノ森町');
ok($zip->set_number('6038224')->is_valid_number, '京都府京都市北区紫野西藤ノ森町');
ok($zip->set_number('6038225')->is_valid_number, '京都府京都市北区紫野南舟岡町');
ok($zip->set_number('6038226')->is_valid_number, '京都府京都市北区紫野西舟岡町');
ok($zip->set_number('6038227')->is_valid_number, '京都府京都市北区紫野北舟岡町');
ok($zip->set_number('6038228')->is_valid_number, '京都府京都市北区紫野東舟岡町');
ok($zip->set_number('6038231')->is_valid_number, '京都府京都市北区紫野大徳寺町');
ok($zip->set_number('6038232')->is_valid_number, '京都府京都市北区紫野東野町');
ok($zip->set_number('6038233')->is_valid_number, '京都府京都市北区紫野西野町');
ok($zip->set_number('6038234')->is_valid_number, '京都府京都市北区紫野下若草町');
ok($zip->set_number('6038235')->is_valid_number, '京都府京都市北区紫野下御輿町');
ok($zip->set_number('6038236')->is_valid_number, '京都府京都市北区紫野上御輿町');
ok($zip->set_number('6038237')->is_valid_number, '京都府京都市北区紫野上若草町');
ok($zip->set_number('6038241')->is_valid_number, '京都府京都市北区紫野東泉堂町');
ok($zip->set_number('6038242')->is_valid_number, '京都府京都市北区紫野上野町');
ok($zip->set_number('6038243')->is_valid_number, '京都府京都市北区紫野今宮町');
ok($zip->set_number('6038244')->is_valid_number, '京都府京都市北区紫野東蓮台野町');
ok($zip->set_number('6038245')->is_valid_number, '京都府京都市北区紫野西蓮台野町');
ok($zip->set_number('6038246')->is_valid_number, '京都府京都市北区紫野西泉堂町');
ok($zip->set_number('6038247')->is_valid_number, '京都府京都市北区紫野泉堂町');
ok($zip->set_number('6038301')->is_valid_number, '京都府京都市北区紫野北花ノ坊町');
ok($zip->set_number('6038302')->is_valid_number, '京都府京都市北区紫野花ノ坊町');
ok($zip->set_number('6038303')->is_valid_number, '京都府京都市北区紫野十二坊町');
ok($zip->set_number('6038304')->is_valid_number, '京都府京都市北区紫野郷ノ上町');
ok($zip->set_number('6038305')->is_valid_number, '京都府京都市北区紫野南花ノ坊町');
ok($zip->set_number('6038311')->is_valid_number, '京都府京都市北区紫野上柏野町');
ok($zip->set_number('6038312')->is_valid_number, '京都府京都市北区紫野中柏野町');
ok($zip->set_number('6038313')->is_valid_number, '京都府京都市北区紫野下柏野町');
ok($zip->set_number('6038314')->is_valid_number, '京都府京都市北区紫野西土居町');
ok($zip->set_number('6038315')->is_valid_number, '京都府京都市北区衣笠荒見町');
ok($zip->set_number('6038316')->is_valid_number, '京都府京都市北区衣笠北荒見町');
ok($zip->set_number('6038321')->is_valid_number, '京都府京都市北区平野鳥居前町');
ok($zip->set_number('6038322')->is_valid_number, '京都府京都市北区平野宮本町');
ok($zip->set_number('6038323')->is_valid_number, '京都府京都市北区北野東紅梅町');
ok($zip->set_number('6038324')->is_valid_number, '京都府京都市北区北野紅梅町');
ok($zip->set_number('6038325')->is_valid_number, '京都府京都市北区北野上白梅町');
ok($zip->set_number('6038326')->is_valid_number, '京都府京都市北区北野下白梅町');
ok($zip->set_number('6038327')->is_valid_number, '京都府京都市北区北野西白梅町');
ok($zip->set_number('6038331')->is_valid_number, '京都府京都市北区大将軍西町');
ok($zip->set_number('6038332')->is_valid_number, '京都府京都市北区大将軍川端町');
ok($zip->set_number('6038333')->is_valid_number, '京都府京都市北区大将軍東鷹司町');
ok($zip->set_number('6038334')->is_valid_number, '京都府京都市北区大将軍西鷹司町');
ok($zip->set_number('6038335')->is_valid_number, '京都府京都市北区大将軍坂田町');
ok($zip->set_number('6038336')->is_valid_number, '京都府京都市北区大将軍一条町');
ok($zip->set_number('6038337')->is_valid_number, '京都府京都市北区大将軍南一条町');
ok($zip->set_number('6038341')->is_valid_number, '京都府京都市北区小松原北町');
ok($zip->set_number('6038342')->is_valid_number, '京都府京都市北区小松原南町');
ok($zip->set_number('6038343')->is_valid_number, '京都府京都市北区等持院東町');
ok($zip->set_number('6038344')->is_valid_number, '京都府京都市北区等持院南町');
ok($zip->set_number('6038345')->is_valid_number, '京都府京都市北区平野八丁柳町');
ok($zip->set_number('6038346')->is_valid_number, '京都府京都市北区等持院北町');
ok($zip->set_number('6038347')->is_valid_number, '京都府京都市北区等持院中町');
ok($zip->set_number('6038351')->is_valid_number, '京都府京都市北区衣笠大祓町');
ok($zip->set_number('6038352')->is_valid_number, '京都府京都市北区平野宮北町');
ok($zip->set_number('6038353')->is_valid_number, '京都府京都市北区平野上八丁柳町');
ok($zip->set_number('6038354')->is_valid_number, '京都府京都市北区等持院西町');
ok($zip->set_number('6038355')->is_valid_number, '京都府京都市北区平野上柳町');
ok($zip->set_number('6038356')->is_valid_number, '京都府京都市北区平野東柳町');
ok($zip->set_number('6038357')->is_valid_number, '京都府京都市北区平野宮西町');
ok($zip->set_number('6038361')->is_valid_number, '京都府京都市北区金閣寺町');
ok($zip->set_number('6038362')->is_valid_number, '京都府京都市北区衣笠馬場町');
ok($zip->set_number('6038363')->is_valid_number, '京都府京都市北区衣笠総門町');
ok($zip->set_number('6038364')->is_valid_number, '京都府京都市北区平野桜木町');
ok($zip->set_number('6038365')->is_valid_number, '京都府京都市北区平野宮敷町');
ok($zip->set_number('6038366')->is_valid_number, '京都府京都市北区衣笠西馬場町');
ok($zip->set_number('6038371')->is_valid_number, '京都府京都市北区衣笠東御所ノ内町');
ok($zip->set_number('6038372')->is_valid_number, '京都府京都市北区衣笠街道町');
ok($zip->set_number('6038373')->is_valid_number, '京都府京都市北区衣笠北高橋町');
ok($zip->set_number('6038374')->is_valid_number, '京都府京都市北区衣笠高橋町');
ok($zip->set_number('6038375')->is_valid_number, '京都府京都市北区衣笠天神森町');
ok($zip->set_number('6038376')->is_valid_number, '京都府京都市北区衣笠北天神森町');
ok($zip->set_number('6038377')->is_valid_number, '京都府京都市北区衣笠西御所ノ内町');
ok($zip->set_number('6038378')->is_valid_number, '京都府京都市北区衣笠御所ノ内町');
ok($zip->set_number('6038401')->is_valid_number, '京都府京都市北区大宮上ノ岸町');
ok($zip->set_number('6038402')->is_valid_number, '京都府京都市北区大宮南椿原町');
ok($zip->set_number('6038403')->is_valid_number, '京都府京都市北区大宮南林町');
ok($zip->set_number('6038404')->is_valid_number, '京都府京都市北区大宮中林町');
ok($zip->set_number('6038405')->is_valid_number, '京都府京都市北区大宮西小野堀町');
ok($zip->set_number('6038406')->is_valid_number, '京都府京都市北区大宮東小野堀町');
ok($zip->set_number('6038407')->is_valid_number, '京都府京都市北区大宮北林町');
ok($zip->set_number('6038408')->is_valid_number, '京都府京都市北区大宮北椿原町');
ok($zip->set_number('6038411')->is_valid_number, '京都府京都市北区紫竹上竹殿町');
ok($zip->set_number('6038412')->is_valid_number, '京都府京都市北区紫竹下竹殿町');
ok($zip->set_number('6038413')->is_valid_number, '京都府京都市北区紫竹東大門町');
ok($zip->set_number('6038414')->is_valid_number, '京都府京都市北区紫竹大門町');
ok($zip->set_number('6038415')->is_valid_number, '京都府京都市北区紫竹西大門町');
ok($zip->set_number('6038416')->is_valid_number, '京都府京都市北区紫竹北大門町');
ok($zip->set_number('6038417')->is_valid_number, '京都府京都市北区紫竹竹殿町');
ok($zip->set_number('6038421')->is_valid_number, '京都府京都市北区紫竹上園生町');
ok($zip->set_number('6038422')->is_valid_number, '京都府京都市北区紫竹下園生町');
ok($zip->set_number('6038423')->is_valid_number, '京都府京都市北区紫竹上芝本町');
ok($zip->set_number('6038424')->is_valid_number, '京都府京都市北区紫竹下芝本町');
ok($zip->set_number('6038425')->is_valid_number, '京都府京都市北区紫竹下緑町');
ok($zip->set_number('6038426')->is_valid_number, '京都府京都市北区紫竹西北町');
ok($zip->set_number('6038427')->is_valid_number, '京都府京都市北区紫竹上緑町');
ok($zip->set_number('6038431')->is_valid_number, '京都府京都市北区大宮東脇台町');
ok($zip->set_number('6038432')->is_valid_number, '京都府京都市北区大宮西脇台町');
ok($zip->set_number('6038433')->is_valid_number, '京都府京都市北区紫竹北栗栖町');
ok($zip->set_number('6038434')->is_valid_number, '京都府京都市北区紫竹東栗栖町');
ok($zip->set_number('6038435')->is_valid_number, '京都府京都市北区紫竹栗栖町');
ok($zip->set_number('6038436')->is_valid_number, '京都府京都市北区紫竹西栗栖町');
ok($zip->set_number('6038437')->is_valid_number, '京都府京都市北区大宮開町');
ok($zip->set_number('6038441')->is_valid_number, '京都府京都市北区大宮土居町');
ok($zip->set_number('6038442')->is_valid_number, '京都府京都市北区紫竹西野山東町');
ok($zip->set_number('6038443')->is_valid_number, '京都府京都市北区紫竹西野山町');
ok($zip->set_number('6038444')->is_valid_number, '京都府京都市北区大宮西野山町');
ok($zip->set_number('6038445')->is_valid_number, '京都府京都市北区鷹峯藤林町');
ok($zip->set_number('6038446')->is_valid_number, '京都府京都市北区鷹峯上ノ町');
ok($zip->set_number('6038447')->is_valid_number, '京都府京都市北区鷹峯木ノ畑町');
ok($zip->set_number('6038448')->is_valid_number, '京都府京都市北区鷹峯旧土居町');
ok($zip->set_number('6038451')->is_valid_number, '京都府京都市北区衣笠鏡石町');
ok($zip->set_number('6038452')->is_valid_number, '京都府京都市北区衣笠開キ町');
ok($zip->set_number('6038453')->is_valid_number, '京都府京都市北区衣笠東開キ町');
ok($zip->set_number('6038454')->is_valid_number, '京都府京都市北区衣笠西開キ町');
ok($zip->set_number('6038455')->is_valid_number, '京都府京都市北区衣笠東尊上院町');
ok($zip->set_number('6038456')->is_valid_number, '京都府京都市北区衣笠西尊上院町');
ok($zip->set_number('6038457')->is_valid_number, '京都府京都市北区大北山不動山町');
ok($zip->set_number('6038458')->is_valid_number, '京都府京都市北区大北山鷲峯町');
ok($zip->set_number('6038461')->is_valid_number, '京都府京都市北区大宮玄琢北東町');
ok($zip->set_number('6038462')->is_valid_number, '京都府京都市北区大宮玄琢北町');
ok($zip->set_number('6038463')->is_valid_number, '京都府京都市北区大宮玄琢南町');
ok($zip->set_number('6038464')->is_valid_number, '京都府京都市北区鷹峯黒門町');
ok($zip->set_number('6038465')->is_valid_number, '京都府京都市北区鷹峯土天井町');
ok($zip->set_number('6038466')->is_valid_number, '京都府京都市北区鷹峯光悦町');
ok($zip->set_number('6038467')->is_valid_number, '京都府京都市北区鷹峯南鷹峯町');
ok($zip->set_number('6038468')->is_valid_number, '京都府京都市北区鷹峯北鷹峯町');
ok($zip->set_number('6038469')->is_valid_number, '京都府京都市北区鷹峯千束町');
ok($zip->set_number('6038471')->is_valid_number, '京都府京都市北区大宮西山ノ前町');
ok($zip->set_number('6038472')->is_valid_number, '京都府京都市北区大宮北山ノ前町');
ok($zip->set_number('6038473')->is_valid_number, '京都府京都市北区大宮南山ノ前町');
ok($zip->set_number('6038474')->is_valid_number, '京都府京都市北区大宮薬師山東町');
ok($zip->set_number('6038475')->is_valid_number, '京都府京都市北区大宮北箱ノ井町');
ok($zip->set_number('6038476')->is_valid_number, '京都府京都市北区大宮南箱ノ井町');
ok($zip->set_number('6038477')->is_valid_number, '京都府京都市北区大宮一ノ井町');
ok($zip->set_number('6038478')->is_valid_number, '京都府京都市北区大宮釈迦谷');
ok($zip->set_number('6038479')->is_valid_number, '京都府京都市北区大宮薬師山西町');
ok($zip->set_number('6038481')->is_valid_number, '京都府京都市北区大北山鏡石町');
ok($zip->set_number('6038482')->is_valid_number, '京都府京都市北区大北山天神岡町');
ok($zip->set_number('6038483')->is_valid_number, '京都府京都市北区大北山蓮ケ谷町');
ok($zip->set_number('6038484')->is_valid_number, '京都府京都市北区衣笠氷室町');
ok($zip->set_number('6038485')->is_valid_number, '京都府京都市北区衣笠衣笠山町');
ok($zip->set_number('6038486')->is_valid_number, '京都府京都市北区衣笠赤阪町');
ok($zip->set_number('6038487')->is_valid_number, '京都府京都市北区大北山原谷乾町');
ok($zip->set_number('6038488')->is_valid_number, '京都府京都市北区大北山長谷町');
ok($zip->set_number('6038491')->is_valid_number, '京都府京都市北区鷹峯仏谷');
ok($zip->set_number('6038492')->is_valid_number, '京都府京都市北区鷹峯堂ノ庭町');
ok($zip->set_number('6038493')->is_valid_number, '京都府京都市北区鷹峯大谷町');
ok($zip->set_number('6038494')->is_valid_number, '京都府京都市北区鷹峯堀越町');
ok($zip->set_number('6038801')->is_valid_number, '京都府京都市北区西賀茂下庄田町');
ok($zip->set_number('6038802')->is_valid_number, '京都府京都市北区西賀茂上庄田町');
ok($zip->set_number('6038803')->is_valid_number, '京都府京都市北区西賀茂樋ノ口町');
ok($zip->set_number('6038804')->is_valid_number, '京都府京都市北区西賀茂井ノ口町');
ok($zip->set_number('6038805')->is_valid_number, '京都府京都市北区西賀茂蟹ケ坂町');
ok($zip->set_number('6038806')->is_valid_number, '京都府京都市北区西賀茂円峰');
ok($zip->set_number('6038807')->is_valid_number, '京都府京都市北区西賀茂蛙ケ谷');
ok($zip->set_number('6038811')->is_valid_number, '京都府京都市北区西賀茂北山ノ森町');
ok($zip->set_number('6038812')->is_valid_number, '京都府京都市北区西賀茂山ノ森町');
ok($zip->set_number('6038813')->is_valid_number, '京都府京都市北区西賀茂大道口町');
ok($zip->set_number('6038814')->is_valid_number, '京都府京都市北区西賀茂南川上町');
ok($zip->set_number('6038815')->is_valid_number, '京都府京都市北区西賀茂中川上町');
ok($zip->set_number('6038816')->is_valid_number, '京都府京都市北区西賀茂北川上町');
ok($zip->set_number('6038817')->is_valid_number, '京都府京都市北区西賀茂川上町');
ok($zip->set_number('6038821')->is_valid_number, '京都府京都市北区西賀茂柿ノ木町');
ok($zip->set_number('6038822')->is_valid_number, '京都府京都市北区西賀茂鹿ノ下町');
ok($zip->set_number('6038823')->is_valid_number, '京都府京都市北区西賀茂榿ノ木町');
ok($zip->set_number('6038824')->is_valid_number, '京都府京都市北区西賀茂南大栗町');
ok($zip->set_number('6038825')->is_valid_number, '京都府京都市北区西賀茂丸川町');
ok($zip->set_number('6038826')->is_valid_number, '京都府京都市北区西賀茂坊ノ後町');
ok($zip->set_number('6038827')->is_valid_number, '京都府京都市北区西賀茂水垣町');
ok($zip->set_number('6038828')->is_valid_number, '京都府京都市北区西賀茂大栗町');
ok($zip->set_number('6038831')->is_valid_number, '京都府京都市北区大宮北ノ岸町');
ok($zip->set_number('6038832')->is_valid_number, '京都府京都市北区大宮南田尻町');
ok($zip->set_number('6038833')->is_valid_number, '京都府京都市北区大宮東総門口町');
ok($zip->set_number('6038834')->is_valid_number, '京都府京都市北区大宮中総門口町');
ok($zip->set_number('6038835')->is_valid_number, '京都府京都市北区大宮西総門口町');
ok($zip->set_number('6038836')->is_valid_number, '京都府京都市北区西賀茂神光院町');
ok($zip->set_number('6038837')->is_valid_number, '京都府京都市北区大宮中ノ社町');
ok($zip->set_number('6038838')->is_valid_number, '京都府京都市北区大宮田尻町');
ok($zip->set_number('6038841')->is_valid_number, '京都府京都市北区西賀茂北今原町');
ok($zip->set_number('6038842')->is_valid_number, '京都府京都市北区西賀茂今原町');
ok($zip->set_number('6038843')->is_valid_number, '京都府京都市北区西賀茂南今原町');
ok($zip->set_number('6038844')->is_valid_number, '京都府京都市北区西賀茂大深町');
ok($zip->set_number('6038845')->is_valid_number, '京都府京都市北区西賀茂角社町');
ok($zip->set_number('6038846')->is_valid_number, '京都府京都市北区西賀茂鎮守菴町');
ok($zip->set_number('6038847')->is_valid_number, '京都府京都市北区西賀茂北鎮守菴町');
ok($zip->set_number('6038848')->is_valid_number, '京都府京都市北区西賀茂船山');
ok($zip->set_number('6038851')->is_valid_number, '京都府京都市北区西賀茂鑓磨岩');
ok($zip->set_number('6038852')->is_valid_number, '京都府京都市北区西賀茂笠松');
ok($zip->set_number('6038853')->is_valid_number, '京都府京都市北区西賀茂城山');
ok($zip->set_number('6038854')->is_valid_number, '京都府京都市北区西賀茂西氷室町');
ok($zip->set_number('6038855')->is_valid_number, '京都府京都市北区西賀茂氷室町');
ok($zip->set_number('6038856')->is_valid_number, '京都府京都市北区西賀茂蓬来谷');
ok($zip->set_number('6038861')->is_valid_number, '京都府京都市北区雲ケ畑出谷町');
ok($zip->set_number('6038862')->is_valid_number, '京都府京都市北区雲ケ畑中津川町');
ok($zip->set_number('6038863')->is_valid_number, '京都府京都市北区雲ケ畑中畑町');
ok($zip->set_number('6040000')->is_valid_number, '京都府京都市中京区以下に掲載がない場合');
ok($zip->set_number('6040001')->is_valid_number, '京都府京都市中京区道場町');
ok($zip->set_number('6040002')->is_valid_number, '京都府京都市中京区鏡屋町');
ok($zip->set_number('6040003')->is_valid_number, '京都府京都市中京区花立町');
ok($zip->set_number('6040004')->is_valid_number, '京都府京都市中京区相生町');
ok($zip->set_number('6040005')->is_valid_number, '京都府京都市中京区玉植町');
ok($zip->set_number('6040011')->is_valid_number, '京都府京都市中京区冷泉町');
ok($zip->set_number('6040012')->is_valid_number, '京都府京都市中京区竪大恩寺町');
ok($zip->set_number('6040013')->is_valid_number, '京都府京都市中京区二条新町');
ok($zip->set_number('6040014')->is_valid_number, '京都府京都市中京区大黒町(釜座通夷川下る、釜座通二条上る、夷川通釜座東入、夷川通釜座西入)');
ok($zip->set_number('6040015')->is_valid_number, '京都府京都市中京区泉町');
ok($zip->set_number('6040021')->is_valid_number, '京都府京都市中京区蛸薬師町');
ok($zip->set_number('6040022')->is_valid_number, '京都府京都市中京区御池之町');
ok($zip->set_number('6040023')->is_valid_number, '京都府京都市中京区西横町');
ok($zip->set_number('6040024')->is_valid_number, '京都府京都市中京区下妙覚寺町');
ok($zip->set_number('6040025')->is_valid_number, '京都府京都市中京区上妙覚寺町');
ok($zip->set_number('6040026')->is_valid_number, '京都府京都市中京区大恩寺町');
ok($zip->set_number('6040031')->is_valid_number, '京都府京都市中京区頭町');
ok($zip->set_number('6040032')->is_valid_number, '京都府京都市中京区中之町(新町通御池上る、新町通押小路下る)');
ok($zip->set_number('6040033')->is_valid_number, '京都府京都市中京区橋之町');
ok($zip->set_number('6040034')->is_valid_number, '京都府京都市中京区下松屋町');
ok($zip->set_number('6040035')->is_valid_number, '京都府京都市中京区上松屋町');
ok($zip->set_number('6040036')->is_valid_number, '京都府京都市中京区正行寺町');
ok($zip->set_number('6040041')->is_valid_number, '京都府京都市中京区二条西洞院町');
ok($zip->set_number('6040042')->is_valid_number, '京都府京都市中京区押西洞院町');
ok($zip->set_number('6040043')->is_valid_number, '京都府京都市中京区石橋町(御池通小川西入、御池通小川東入、御池通西洞院西入、御池通油小路');
ok($zip->set_number('6040043')->is_valid_number, '京都府京都市中京区東入、小川通御池下る)');
ok($zip->set_number('6040044')->is_valid_number, '京都府京都市中京区下古城町');
ok($zip->set_number('6040045')->is_valid_number, '京都府京都市中京区古城町');
ok($zip->set_number('6040051')->is_valid_number, '京都府京都市中京区二条油小路町');
ok($zip->set_number('6040052')->is_valid_number, '京都府京都市中京区押油小路町');
ok($zip->set_number('6040053')->is_valid_number, '京都府京都市中京区森ノ木町');
ok($zip->set_number('6040054')->is_valid_number, '京都府京都市中京区押堀町');
ok($zip->set_number('6040055')->is_valid_number, '京都府京都市中京区土橋町');
ok($zip->set_number('6040061')->is_valid_number, '京都府京都市中京区槌屋町(小川通夷川下る、小川通二条上る)');
ok($zip->set_number('6040062')->is_valid_number, '京都府京都市中京区薬師町');
ok($zip->set_number('6040063')->is_valid_number, '京都府京都市中京区西大黒町');
ok($zip->set_number('6040064')->is_valid_number, '京都府京都市中京区矢幡町');
ok($zip->set_number('6040065')->is_valid_number, '京都府京都市中京区九町目');
ok($zip->set_number('6040066')->is_valid_number, '京都府京都市中京区薬屋町');
ok($zip->set_number('6040071')->is_valid_number, '京都府京都市中京区大文字町(丸太町通堀川東入、丸太町通油小路西入、丸太町通油小路東入、丸太');
ok($zip->set_number('6040071')->is_valid_number, '京都府京都市中京区町通小川西入、油小路通竹屋町上る、竹屋町通油小路東入)');
ok($zip->set_number('6040072')->is_valid_number, '京都府京都市中京区橋本町');
ok($zip->set_number('6040073')->is_valid_number, '京都府京都市中京区西夷川町');
ok($zip->set_number('6040074')->is_valid_number, '京都府京都市中京区八町目');
ok($zip->set_number('6040075')->is_valid_number, '京都府京都市中京区西竹屋町');
ok($zip->set_number('6040076')->is_valid_number, '京都府京都市中京区七町目');
ok($zip->set_number('6040077')->is_valid_number, '京都府京都市中京区丸太町');
ok($zip->set_number('6040081')->is_valid_number, '京都府京都市中京区田中町');
ok($zip->set_number('6040082')->is_valid_number, '京都府京都市中京区毘沙門町(西洞院通竹屋町下る、西洞院通夷川上る、竹屋町通西洞院西入、');
ok($zip->set_number('6040082')->is_valid_number, '京都府京都市中京区竹屋町通西洞院東入、夷川通西洞院東入)');
ok($zip->set_number('6040083')->is_valid_number, '京都府京都市中京区東夷川町');
ok($zip->set_number('6040084')->is_valid_number, '京都府京都市中京区下丸屋町(小川通夷川下る、小川通夷川上る)');
ok($zip->set_number('6040085')->is_valid_number, '京都府京都市中京区東竹屋町');
ok($zip->set_number('6040086')->is_valid_number, '京都府京都市中京区中之町(小川通丸太町下る、小川通竹屋町上る)');
ok($zip->set_number('6040087')->is_valid_number, '京都府京都市中京区横鍛冶町');
ok($zip->set_number('6040091')->is_valid_number, '京都府京都市中京区梅屋町(丸太町通釜座西入、丸太町通釜座東入、丸太町通新町西入、丸太町通');
ok($zip->set_number('6040091')->is_valid_number, '京都府京都市中京区西洞院東入、釜座通丸太町上る)');
ok($zip->set_number('6040092')->is_valid_number, '京都府京都市中京区大炊町(新町通丸太町下る、新町通竹屋町上る、丸太町通新町西入、丸太町通');
ok($zip->set_number('6040092')->is_valid_number, '京都府京都市中京区新町東入、竹屋町通新町西入、竹屋町通新町東入)');
ok($zip->set_number('6040093')->is_valid_number, '京都府京都市中京区弁財天町');
ok($zip->set_number('6040094')->is_valid_number, '京都府京都市中京区亀屋町(釜座通竹屋町下る、釜座通夷川上る、夷川通釜座西入、夷川通釜座');
ok($zip->set_number('6040094')->is_valid_number, '京都府京都市中京区東入、夷川通西洞院東入、夷川通新町西入)');
ok($zip->set_number('6040095')->is_valid_number, '京都府京都市中京区指物屋町');
ok($zip->set_number('6040096')->is_valid_number, '京都府京都市中京区桝屋町(釜座通丸太町下る、釜座通竹屋町上る)');
ok($zip->set_number('6040801')->is_valid_number, '京都府京都市中京区鍵屋町(丸太町通堺町東入、丸太町通堺町西入、丸太町通柳馬場東入、丸太町');
ok($zip->set_number('6040801')->is_valid_number, '京都府京都市中京区通高倉東入)');
ok($zip->set_number('6040802')->is_valid_number, '京都府京都市中京区橘町(堺町通丸太町下る、堺町通竹屋町上る、竹屋町通堺町西入、竹屋町通');
ok($zip->set_number('6040802')->is_valid_number, '京都府京都市中京区堺町東入)');
ok($zip->set_number('6040803')->is_valid_number, '京都府京都市中京区和久屋町(竹屋町通柳馬場西入、竹屋町通堺町東入、竹屋町通堺町西入、竹屋');
ok($zip->set_number('6040803')->is_valid_number, '京都府京都市中京区町通高倉東入)');
ok($zip->set_number('6040804')->is_valid_number, '京都府京都市中京区絹屋町');
ok($zip->set_number('6040805')->is_valid_number, '京都府京都市中京区百足屋町(夷川通柳馬場西入、夷川通堺町東入、夷川通堺町西入、夷川通高倉東入)');
ok($zip->set_number('6040811')->is_valid_number, '京都府京都市中京区亀屋町(堺町通夷川下る、堺町通二条上る、夷川通堺町西入、夷川通堺町東入)');
ok($zip->set_number('6040812')->is_valid_number, '京都府京都市中京区天守町');
ok($zip->set_number('6040813')->is_valid_number, '京都府京都市中京区夷町');
ok($zip->set_number('6040814')->is_valid_number, '京都府京都市中京区壺屋町(東洞院通夷川下る、東洞院通二条上る、夷川通東洞院西入、夷川通東');
ok($zip->set_number('6040814')->is_valid_number, '京都府京都市中京区洞院東入)');
ok($zip->set_number('6040815')->is_valid_number, '京都府京都市中京区山中町');
ok($zip->set_number('6040821')->is_valid_number, '京都府京都市中京区観音町');
ok($zip->set_number('6040822')->is_valid_number, '京都府京都市中京区杉屋町');
ok($zip->set_number('6040823')->is_valid_number, '京都府京都市中京区竹屋町');
ok($zip->set_number('6040824')->is_valid_number, '京都府京都市中京区扇屋町');
ok($zip->set_number('6040825')->is_valid_number, '京都府京都市中京区御所八幡町');
ok($zip->set_number('6040826')->is_valid_number, '京都府京都市中京区柊町');
ok($zip->set_number('6040827')->is_valid_number, '京都府京都市中京区瓦町');
ok($zip->set_number('6040831')->is_valid_number, '京都府京都市中京区松屋町');
ok($zip->set_number('6040832')->is_valid_number, '京都府京都市中京区鍵屋町(間之町通二条下る、間之町通押小路上る)');
ok($zip->set_number('6040833')->is_valid_number, '京都府京都市中京区左京町');
ok($zip->set_number('6040834')->is_valid_number, '京都府京都市中京区高田町');
ok($zip->set_number('6040835')->is_valid_number, '京都府京都市中京区高宮町(御池通高倉西入、御池通東洞院東入、御池通間之町東入、御池通間之町');
ok($zip->set_number('6040835')->is_valid_number, '京都府京都市中京区西入)');
ok($zip->set_number('6040836')->is_valid_number, '京都府京都市中京区船屋町(東洞院通押小路下る、東洞院通御池上る、押小路通東洞院西入、');
ok($zip->set_number('6040836')->is_valid_number, '京都府京都市中京区押小路通東洞院東入)');
ok($zip->set_number('6040837')->is_valid_number, '京都府京都市中京区瓦之町');
ok($zip->set_number('6040841')->is_valid_number, '京都府京都市中京区仁王門突抜町');
ok($zip->set_number('6040842')->is_valid_number, '京都府京都市中京区西押小路町');
ok($zip->set_number('6040843')->is_valid_number, '京都府京都市中京区塗師屋町');
ok($zip->set_number('6040844')->is_valid_number, '京都府京都市中京区仲保利町');
ok($zip->set_number('6040845')->is_valid_number, '京都府京都市中京区二条殿町');
ok($zip->set_number('6040846')->is_valid_number, '京都府京都市中京区金吹町');
ok($zip->set_number('6040847')->is_valid_number, '京都府京都市中京区秋野々町');
ok($zip->set_number('6040851')->is_valid_number, '京都府京都市中京区西九軒町');
ok($zip->set_number('6040852')->is_valid_number, '京都府京都市中京区東九軒町');
ok($zip->set_number('6040853')->is_valid_number, '京都府京都市中京区真如堂町');
ok($zip->set_number('6040854')->is_valid_number, '京都府京都市中京区仁王門町');
ok($zip->set_number('6040855')->is_valid_number, '京都府京都市中京区東玉屋町');
ok($zip->set_number('6040856')->is_valid_number, '京都府京都市中京区北小路町');
ok($zip->set_number('6040857')->is_valid_number, '京都府京都市中京区蒔絵屋町');
ok($zip->set_number('6040861')->is_valid_number, '京都府京都市中京区大倉町');
ok($zip->set_number('6040862')->is_valid_number, '京都府京都市中京区少将井町');
ok($zip->set_number('6040863')->is_valid_number, '京都府京都市中京区巴町');
ok($zip->set_number('6040864')->is_valid_number, '京都府京都市中京区松竹町');
ok($zip->set_number('6040865')->is_valid_number, '京都府京都市中京区亀屋町(竹屋町通烏丸西入、竹屋町通両替町東入、竹屋町通両替町西入、竹屋');
ok($zip->set_number('6040865')->is_valid_number, '京都府京都市中京区町通室町東入、両替町通室町下る)');
ok($zip->set_number('6040866')->is_valid_number, '京都府京都市中京区西方寺町');
ok($zip->set_number('6040867')->is_valid_number, '京都府京都市中京区常真横町');
ok($zip->set_number('6040871')->is_valid_number, '京都府京都市中京区三本木町');
ok($zip->set_number('6040872')->is_valid_number, '京都府京都市中京区三本木五丁目');
ok($zip->set_number('6040873')->is_valid_number, '京都府京都市中京区少将井御旅町');
ok($zip->set_number('6040874')->is_valid_number, '京都府京都市中京区清水町(竹屋町通烏丸東入、竹屋町通東洞院西入、竹屋町通車屋町西入、竹屋');
ok($zip->set_number('6040874')->is_valid_number, '京都府京都市中京区町通車屋町東入、車屋町通竹屋町下る)');
ok($zip->set_number('6040875')->is_valid_number, '京都府京都市中京区砂金町');
ok($zip->set_number('6040876')->is_valid_number, '京都府京都市中京区光リ堂町');
ok($zip->set_number('6040881')->is_valid_number, '京都府京都市中京区坂本町');
ok($zip->set_number('6040882')->is_valid_number, '京都府京都市中京区福屋町');
ok($zip->set_number('6040883')->is_valid_number, '京都府京都市中京区楠町');
ok($zip->set_number('6040884')->is_valid_number, '京都府京都市中京区塀之内町');
ok($zip->set_number('6040885')->is_valid_number, '京都府京都市中京区大津町');
ok($zip->set_number('6040886')->is_valid_number, '京都府京都市中京区関東屋町');
ok($zip->set_number('6040901')->is_valid_number, '京都府京都市中京区末丸町');
ok($zip->set_number('6040902')->is_valid_number, '京都府京都市中京区鉾田町');
ok($zip->set_number('6040903')->is_valid_number, '京都府京都市中京区指物町');
ok($zip->set_number('6040904')->is_valid_number, '京都府京都市中京区西革堂町');
ok($zip->set_number('6040905')->is_valid_number, '京都府京都市中京区梅之木町(新烏丸通竹屋町上る、新烏丸通竹屋町下る、新烏丸通夷川上る、');
ok($zip->set_number('6040905')->is_valid_number, '京都府京都市中京区夷川通新烏丸東入、夷川通新椹木町西入、竹屋町通新烏丸東入、竹屋町通椹木');
ok($zip->set_number('6040905')->is_valid_number, '京都府京都市中京区町西入、新烏丸通御霊図子下る)');
ok($zip->set_number('6040906')->is_valid_number, '京都府京都市中京区東椹木町');
ok($zip->set_number('6040907')->is_valid_number, '京都府京都市中京区大文字町(河原町通御霊図子下る、河原町通竹屋町上る)');
ok($zip->set_number('6040911')->is_valid_number, '京都府京都市中京区清水町(河原町通夷川下る、河原町通二条上る、夷川通河原町東入、夷川通');
ok($zip->set_number('6040911')->is_valid_number, '京都府京都市中京区土手町西入、夷川通土手町東入)');
ok($zip->set_number('6040912')->is_valid_number, '京都府京都市中京区樋之口町');
ok($zip->set_number('6040913')->is_valid_number, '京都府京都市中京区角倉町');
ok($zip->set_number('6040914')->is_valid_number, '京都府京都市中京区橘柳町');
ok($zip->set_number('6040915')->is_valid_number, '京都府京都市中京区常盤木町');
ok($zip->set_number('6040916')->is_valid_number, '京都府京都市中京区要法寺前町');
ok($zip->set_number('6040917')->is_valid_number, '京都府京都市中京区丸屋町(夷川通寺町西入、夷川通御幸町東入)');
ok($zip->set_number('6040921')->is_valid_number, '京都府京都市中京区西生洲町');
ok($zip->set_number('6040922')->is_valid_number, '京都府京都市中京区東生洲町');
ok($zip->set_number('6040923')->is_valid_number, '京都府京都市中京区上樵木町');
ok($zip->set_number('6040924')->is_valid_number, '京都府京都市中京区一之船入町');
ok($zip->set_number('6040925')->is_valid_number, '京都府京都市中京区上本能寺前町');
ok($zip->set_number('6040931')->is_valid_number, '京都府京都市中京区榎木町');
ok($zip->set_number('6040932')->is_valid_number, '京都府京都市中京区妙満寺前町');
ok($zip->set_number('6040933')->is_valid_number, '京都府京都市中京区山本町');
ok($zip->set_number('6040934')->is_valid_number, '京都府京都市中京区尾張町');
ok($zip->set_number('6040935')->is_valid_number, '京都府京都市中京区丁子屋町');
ok($zip->set_number('6040941')->is_valid_number, '京都府京都市中京区亀屋町(御幸町通御池上る、御幸町通押小路下る、御幸町通押小路西入、御幸');
ok($zip->set_number('6040941')->is_valid_number, '京都府京都市中京区町通押小路東入、押小路通寺町西入、御池通御幸町西入、御池通御幸町東入)');
ok($zip->set_number('6040942')->is_valid_number, '京都府京都市中京区御池大東町');
ok($zip->set_number('6040943')->is_valid_number, '京都府京都市中京区上白山町');
ok($zip->set_number('6040944')->is_valid_number, '京都府京都市中京区橘町(押小路通御幸町西入、押小路通麩屋町西入、押小路通麩屋町東入、');
ok($zip->set_number('6040944')->is_valid_number, '京都府京都市中京区押小路通富小路西入、押小路通富小路東入、押小路通柳馬場東入)');
ok($zip->set_number('6040951')->is_valid_number, '京都府京都市中京区晴明町');
ok($zip->set_number('6040952')->is_valid_number, '京都府京都市中京区俵屋町(富小路通二条下る、富小路通押小路上る)');
ok($zip->set_number('6040953')->is_valid_number, '京都府京都市中京区守山町');
ok($zip->set_number('6040954')->is_valid_number, '京都府京都市中京区東八幡町');
ok($zip->set_number('6040955')->is_valid_number, '京都府京都市中京区虎石町');
ok($zip->set_number('6040956')->is_valid_number, '京都府京都市中京区等持寺町');
ok($zip->set_number('6040961')->is_valid_number, '京都府京都市中京区木屋町');
ok($zip->set_number('6040962')->is_valid_number, '京都府京都市中京区達磨町');
ok($zip->set_number('6040963')->is_valid_number, '京都府京都市中京区布袋屋町');
ok($zip->set_number('6040964')->is_valid_number, '京都府京都市中京区鍛冶屋町(富小路通夷川下る、富小路通二条上る、夷川通富小路西入、夷川通');
ok($zip->set_number('6040964')->is_valid_number, '京都府京都市中京区富小路東入)');
ok($zip->set_number('6040965')->is_valid_number, '京都府京都市中京区六丁目');
ok($zip->set_number('6040966')->is_valid_number, '京都府京都市中京区俵屋町(夷川通富小路西入、夷川通柳馬場東入)');
ok($zip->set_number('6040971')->is_valid_number, '京都府京都市中京区桝屋町(富小路通丸太町下る、富小路通竹屋町上る、丸太町通富小路東入、');
ok($zip->set_number('6040971')->is_valid_number, '京都府京都市中京区竹屋町通富小路東入、丸太町通富小路西入、竹屋町通富小路西入)');
ok($zip->set_number('6040972')->is_valid_number, '京都府京都市中京区大炊町(富小路通竹屋町下る、富小路通夷川上る、竹屋町通富小路西入、竹屋');
ok($zip->set_number('6040972')->is_valid_number, '京都府京都市中京区町通富小路東入、夷川通富小路西入、夷川通富小路東入)');
ok($zip->set_number('6040973')->is_valid_number, '京都府京都市中京区五丁目');
ok($zip->set_number('6040974')->is_valid_number, '京都府京都市中京区四丁目');
ok($zip->set_number('6040975')->is_valid_number, '京都府京都市中京区菊屋町(竹屋町通富小路西入、竹屋町通柳馬場東入)');
ok($zip->set_number('6040976')->is_valid_number, '京都府京都市中京区桑原町');
ok($zip->set_number('6040981')->is_valid_number, '京都府京都市中京区毘沙門町(御幸町通丸太町下る、御幸町通竹屋町上る、丸太町通御幸町西入、');
ok($zip->set_number('6040981')->is_valid_number, '京都府京都市中京区丸太町通御幸町東入、竹屋町通御幸町西入、竹屋町通御幸町東入、');
ok($zip->set_number('6040981')->is_valid_number, '京都府京都市中京区竹屋町通麩屋町東入)');
ok($zip->set_number('6040982')->is_valid_number, '京都府京都市中京区松本町(御幸町通竹屋町下る、御幸町通夷川上る、御幸町通竹屋町西入、御幸');
ok($zip->set_number('6040982')->is_valid_number, '京都府京都市中京区町通竹屋町東入、夷川通御幸町西入、夷川通御幸町東入)');
ok($zip->set_number('6040983')->is_valid_number, '京都府京都市中京区笹屋町(麩屋町通竹屋町下る、麩屋町通夷川上る、竹屋町通麩屋町西入、竹屋');
ok($zip->set_number('6040983')->is_valid_number, '京都府京都市中京区町通麩屋町東入、竹屋町通御幸町西入、夷川通麩屋町西入、夷川通麩屋町東入)');
ok($zip->set_number('6040984')->is_valid_number, '京都府京都市中京区魚屋町');
ok($zip->set_number('6040985')->is_valid_number, '京都府京都市中京区舟屋町');
ok($zip->set_number('6040986')->is_valid_number, '京都府京都市中京区昆布屋町');
ok($zip->set_number('6040991')->is_valid_number, '京都府京都市中京区行願寺門前町');
ok($zip->set_number('6040992')->is_valid_number, '京都府京都市中京区藤木町');
ok($zip->set_number('6040993')->is_valid_number, '京都府京都市中京区久遠院前町');
ok($zip->set_number('6040994')->is_valid_number, '京都府京都市中京区甘露町');
ok($zip->set_number('6040995')->is_valid_number, '京都府京都市中京区下御霊前町');
ok($zip->set_number('6040996')->is_valid_number, '京都府京都市中京区石屋町(丸太町通寺町西入、丸太町通御幸町東入)');
ok($zip->set_number('6048001')->is_valid_number, '京都府京都市中京区上大阪町');
ok($zip->set_number('6048002')->is_valid_number, '京都府京都市中京区石屋町(木屋町通三条下る、先斗町通三条下る、木屋町通四条上る)');
ok($zip->set_number('6048003')->is_valid_number, '京都府京都市中京区橋下町');
ok($zip->set_number('6048004')->is_valid_number, '京都府京都市中京区中島町');
ok($zip->set_number('6048005')->is_valid_number, '京都府京都市中京区恵比須町');
ok($zip->set_number('6048006')->is_valid_number, '京都府京都市中京区下丸屋町(御池通河原町東入、河原町通御池下る、河原町通姉小路上る、');
ok($zip->set_number('6048006')->is_valid_number, '京都府京都市中京区御池通木屋町西入、木屋町通御池下る、木屋町通姉小路上る)');
ok($zip->set_number('6048011')->is_valid_number, '京都府京都市中京区若松町');
ok($zip->set_number('6048012')->is_valid_number, '京都府京都市中京区梅之木町(先斗町通三条下る、先斗町通蛸薬師上る、先斗町通蛸薬師下る、');
ok($zip->set_number('6048012')->is_valid_number, '京都府京都市中京区先斗町通四条上る)');
ok($zip->set_number('6048013')->is_valid_number, '京都府京都市中京区松本町(先斗町通四条上る、先斗町通三条下る)');
ok($zip->set_number('6048014')->is_valid_number, '京都府京都市中京区柏屋町');
ok($zip->set_number('6048015')->is_valid_number, '京都府京都市中京区鍋屋町');
ok($zip->set_number('6048016')->is_valid_number, '京都府京都市中京区下樵木町');
ok($zip->set_number('6048017')->is_valid_number, '京都府京都市中京区材木町');
ok($zip->set_number('6048021')->is_valid_number, '京都府京都市中京区北車屋町');
ok($zip->set_number('6048022')->is_valid_number, '京都府京都市中京区南車屋町');
ok($zip->set_number('6048023')->is_valid_number, '京都府京都市中京区備前島町');
ok($zip->set_number('6048024')->is_valid_number, '京都府京都市中京区紙屋町');
ok($zip->set_number('6048025')->is_valid_number, '京都府京都市中京区下大阪町');
ok($zip->set_number('6048026')->is_valid_number, '京都府京都市中京区米屋町');
ok($zip->set_number('6048027')->is_valid_number, '京都府京都市中京区塩屋町(河原町通蛸薬師下る、河原町通四条上る、蛸薬師通河原町西入)');
ok($zip->set_number('6048031')->is_valid_number, '京都府京都市中京区大黒町(河原町通三条下る、三条通河原町東入、三条通河原町西入、河原町通');
ok($zip->set_number('6048031')->is_valid_number, '京都府京都市中京区六角上る、西木屋町通三条下る、西木屋町通六角上る)');
ok($zip->set_number('6048032')->is_valid_number, '京都府京都市中京区山崎町');
ok($zip->set_number('6048033')->is_valid_number, '京都府京都市中京区奈良屋町');
ok($zip->set_number('6048034')->is_valid_number, '京都府京都市中京区松ケ枝町');
ok($zip->set_number('6048035')->is_valid_number, '京都府京都市中京区桜之町');
ok($zip->set_number('6048036')->is_valid_number, '京都府京都市中京区石橋町(三条通河原町西入、三条通寺町東入、三条通新京極西入、三条通新');
ok($zip->set_number('6048036')->is_valid_number, '京都府京都市中京区京極東入、寺町通三条下る、寺町通三条上る)');
ok($zip->set_number('6048041')->is_valid_number, '京都府京都市中京区裏寺町');
ok($zip->set_number('6048042')->is_valid_number, '京都府京都市中京区中之町(寺町通錦小路下る、寺町通四条上る、新京極通錦小路下る、新京極通');
ok($zip->set_number('6048042')->is_valid_number, '京都府京都市中京区四条上る、錦小路通寺町東入、裏寺町通蛸薬師下る、裏寺町通四条上る)');
ok($zip->set_number('6048043')->is_valid_number, '京都府京都市中京区東大文字町');
ok($zip->set_number('6048044')->is_valid_number, '京都府京都市中京区大日町');
ok($zip->set_number('6048045')->is_valid_number, '京都府京都市中京区円福寺前町');
ok($zip->set_number('6048046')->is_valid_number, '京都府京都市中京区東側町');
ok($zip->set_number('6048047')->is_valid_number, '京都府京都市中京区中筋町');
ok($zip->set_number('6048051')->is_valid_number, '京都府京都市中京区船屋町(御幸町通蛸薬師下る、御幸町通錦小路上る、蛸薬師通御幸町東入、');
ok($zip->set_number('6048051')->is_valid_number, '京都府京都市中京区錦小路通御幸町東入)');
ok($zip->set_number('6048052')->is_valid_number, '京都府京都市中京区鍛冶屋町(錦小路通御幸町西入、錦小路通麸屋町東入)');
ok($zip->set_number('6048053')->is_valid_number, '京都府京都市中京区桝屋町(麩屋町通錦小路下る、麩屋町通四条上る、錦小路通麩屋町西入、');
ok($zip->set_number('6048053')->is_valid_number, '京都府京都市中京区錦小路通麩屋町東入)');
ok($zip->set_number('6048054')->is_valid_number, '京都府京都市中京区西大文字町');
ok($zip->set_number('6048055')->is_valid_number, '京都府京都市中京区東魚屋町');
ok($zip->set_number('6048056')->is_valid_number, '京都府京都市中京区高宮町(富小路通錦小路上る、富小路通蛸薬師下る)');
ok($zip->set_number('6048057')->is_valid_number, '京都府京都市中京区梅屋町(麸屋町通錦小路上る、麸屋町通蛸薬師下る)');
ok($zip->set_number('6048061')->is_valid_number, '京都府京都市中京区式部町');
ok($zip->set_number('6048062')->is_valid_number, '京都府京都市中京区蛸屋町');
ok($zip->set_number('6048063')->is_valid_number, '京都府京都市中京区油屋町(蛸薬師通麸屋町西入、蛸薬師通富小路東入、蛸薬師通富小路西入、');
ok($zip->set_number('6048063')->is_valid_number, '京都府京都市中京区蛸薬師通柳馬場東入、富小路通蛸薬師上る、富小路通蛸薬師下る)');
ok($zip->set_number('6048064')->is_valid_number, '京都府京都市中京区骨屋之町');
ok($zip->set_number('6048065')->is_valid_number, '京都府京都市中京区坂井町');
ok($zip->set_number('6048066')->is_valid_number, '京都府京都市中京区伊勢屋町');
ok($zip->set_number('6048071')->is_valid_number, '京都府京都市中京区永楽町');
ok($zip->set_number('6048072')->is_valid_number, '京都府京都市中京区八百屋町(六角通寺町西入、六角通御幸町東入、六角通御幸町西入、六角通麩');
ok($zip->set_number('6048072')->is_valid_number, '京都府京都市中京区屋町東入、御幸町通麩屋町下る、麩屋町通六角下る)');
ok($zip->set_number('6048073')->is_valid_number, '京都府京都市中京区大黒町(麩屋町通六角上る、麩屋町通六角下る、六角通麩屋町西入、富小路通');
ok($zip->set_number('6048073')->is_valid_number, '京都府京都市中京区六角上る、富小路通六角下る、六角通富小路西入、六角通富小路東入、六角通柳');
ok($zip->set_number('6048073')->is_valid_number, '京都府京都市中京区馬場東入)');
ok($zip->set_number('6048074')->is_valid_number, '京都府京都市中京区朝倉町');
ok($zip->set_number('6048075')->is_valid_number, '京都府京都市中京区白壁町');
ok($zip->set_number('6048076')->is_valid_number, '京都府京都市中京区海老屋町');
ok($zip->set_number('6048081')->is_valid_number, '京都府京都市中京区天性寺前町');
ok($zip->set_number('6048082')->is_valid_number, '京都府京都市中京区弁慶石町');
ok($zip->set_number('6048083')->is_valid_number, '京都府京都市中京区中之町(三条通麩屋町西入、三条通富小路西入、三条通富小路東入、三条通柳');
ok($zip->set_number('6048083')->is_valid_number, '京都府京都市中京区馬場東入、富小路通三条下る)');
ok($zip->set_number('6048084')->is_valid_number, '京都府京都市中京区福長町');
ok($zip->set_number('6048085')->is_valid_number, '京都府京都市中京区下白山町');
ok($zip->set_number('6048086')->is_valid_number, '京都府京都市中京区丸屋町(御幸町通姉小路下る、御幸町通三条上る、姉小路通御幸町西入、');
ok($zip->set_number('6048086')->is_valid_number, '京都府京都市中京区姉小路通御幸町東入)');
ok($zip->set_number('6048091')->is_valid_number, '京都府京都市中京区下本能寺前町');
ok($zip->set_number('6048092')->is_valid_number, '京都府京都市中京区姉大東町');
ok($zip->set_number('6048093')->is_valid_number, '京都府京都市中京区松下町');
ok($zip->set_number('6048094')->is_valid_number, '京都府京都市中京区中白山町');
ok($zip->set_number('6048095')->is_valid_number, '京都府京都市中京区大文字町(御幸町通御池下る、御幸町通姉小路上る、御池通御幸町西入、');
ok($zip->set_number('6048095')->is_valid_number, '京都府京都市中京区御池通御幸町東入、姉小路通御幸町西入、姉小路通御幸町東入)');
ok($zip->set_number('6048101')->is_valid_number, '京都府京都市中京区柳八幡町');
ok($zip->set_number('6048102')->is_valid_number, '京都府京都市中京区菊屋町(姉小路通富小路西入、姉小路通柳馬場東入)');
ok($zip->set_number('6048103')->is_valid_number, '京都府京都市中京区油屋町(柳馬場通姉小路下る、柳馬場通三条上る、姉小路通柳馬場東入、姉小');
ok($zip->set_number('6048103')->is_valid_number, '京都府京都市中京区路通柳馬場西入)');
ok($zip->set_number('6048104')->is_valid_number, '京都府京都市中京区木之下町');
ok($zip->set_number('6048105')->is_valid_number, '京都府京都市中京区亀甲屋町');
ok($zip->set_number('6048106')->is_valid_number, '京都府京都市中京区丸木材木町');
ok($zip->set_number('6048111')->is_valid_number, '京都府京都市中京区桝屋町(柳馬場通三条上る、柳馬場通三条下る、堺町通三条上る、堺町通三条');
ok($zip->set_number('6048111')->is_valid_number, '京都府京都市中京区下る、高倉通三条上る、高倉通三条下る、三条通柳馬場西入、三条通堺町');
ok($zip->set_number('6048111')->is_valid_number, '京都府京都市中京区西入、三条通堺町東入、三条通高倉東入)');
ok($zip->set_number('6048112')->is_valid_number, '京都府京都市中京区槌屋町(柳馬場通三条下る、柳馬場通六角上る、六角通柳馬場西入、六角通柳');
ok($zip->set_number('6048112')->is_valid_number, '京都府京都市中京区馬場東入)');
ok($zip->set_number('6048113')->is_valid_number, '京都府京都市中京区井筒屋町');
ok($zip->set_number('6048114')->is_valid_number, '京都府京都市中京区甲屋町');
ok($zip->set_number('6048115')->is_valid_number, '京都府京都市中京区雁金町');
ok($zip->set_number('6048116')->is_valid_number, '京都府京都市中京区和久屋町(高倉通六角下る、高倉通蛸薬師上る)');
ok($zip->set_number('6048117')->is_valid_number, '京都府京都市中京区堀之上町');
ok($zip->set_number('6048118')->is_valid_number, '京都府京都市中京区道祐町');
ok($zip->set_number('6048121')->is_valid_number, '京都府京都市中京区十文字町');
ok($zip->set_number('6048122')->is_valid_number, '京都府京都市中京区瀬戸屋町');
ok($zip->set_number('6048123')->is_valid_number, '京都府京都市中京区八百屋町(堺町通錦小路下る、堺町通四条上る)');
ok($zip->set_number('6048124')->is_valid_number, '京都府京都市中京区帯屋町');
ok($zip->set_number('6048125')->is_valid_number, '京都府京都市中京区中魚屋町');
ok($zip->set_number('6048126')->is_valid_number, '京都府京都市中京区貝屋町');
ok($zip->set_number('6048127')->is_valid_number, '京都府京都市中京区菊屋町(堺町通蛸薬師下る、堺町通錦小路上る、錦小路通堺町東入、錦小路通');
ok($zip->set_number('6048127')->is_valid_number, '京都府京都市中京区柳馬場西入)');
ok($zip->set_number('6048131')->is_valid_number, '京都府京都市中京区菱屋町');
ok($zip->set_number('6048132')->is_valid_number, '京都府京都市中京区丸屋町(高倉通三条下る、高倉通六角上る)');
ok($zip->set_number('6048133')->is_valid_number, '京都府京都市中京区滕屋町');
ok($zip->set_number('6048134')->is_valid_number, '京都府京都市中京区堂之前町');
ok($zip->set_number('6048135')->is_valid_number, '京都府京都市中京区三文字町(東洞院通三条下る、東洞院通六角上る、六角通東洞院');
ok($zip->set_number('6048135')->is_valid_number, '京都府京都市中京区西入、六角通東洞院東入)');
ok($zip->set_number('6048136')->is_valid_number, '京都府京都市中京区梅忠町');
ok($zip->set_number('6048141')->is_valid_number, '京都府京都市中京区泉正寺町');
ok($zip->set_number('6048142')->is_valid_number, '京都府京都市中京区西魚屋町');
ok($zip->set_number('6048143')->is_valid_number, '京都府京都市中京区阪東屋町');
ok($zip->set_number('6048144')->is_valid_number, '京都府京都市中京区元法然寺町');
ok($zip->set_number('6048145')->is_valid_number, '京都府京都市中京区元竹田町');
ok($zip->set_number('6048146')->is_valid_number, '京都府京都市中京区一蓮社町');
ok($zip->set_number('6048147')->is_valid_number, '京都府京都市中京区御射山町');
ok($zip->set_number('6048151')->is_valid_number, '京都府京都市中京区橋弁慶町');
ok($zip->set_number('6048152')->is_valid_number, '京都府京都市中京区手洗水町');
ok($zip->set_number('6048153')->is_valid_number, '京都府京都市中京区笋町');
ok($zip->set_number('6048154')->is_valid_number, '京都府京都市中京区菊水鉾町');
ok($zip->set_number('6048155')->is_valid_number, '京都府京都市中京区占出山町');
ok($zip->set_number('6048156')->is_valid_number, '京都府京都市中京区山伏山町');
ok($zip->set_number('6048161')->is_valid_number, '京都府京都市中京区饅頭屋町');
ok($zip->set_number('6048162')->is_valid_number, '京都府京都市中京区七観音町');
ok($zip->set_number('6048163')->is_valid_number, '京都府京都市中京区鯉山町');
ok($zip->set_number('6048164')->is_valid_number, '京都府京都市中京区骨屋町');
ok($zip->set_number('6048165')->is_valid_number, '京都府京都市中京区烏帽子屋町');
ok($zip->set_number('6048166')->is_valid_number, '京都府京都市中京区御倉町');
ok($zip->set_number('6048171')->is_valid_number, '京都府京都市中京区虎屋町');
ok($zip->set_number('6048172')->is_valid_number, '京都府京都市中京区場之町');
ok($zip->set_number('6048173')->is_valid_number, '京都府京都市中京区柿本町');
ok($zip->set_number('6048174')->is_valid_number, '京都府京都市中京区役行者町');
ok($zip->set_number('6048175')->is_valid_number, '京都府京都市中京区円福寺町');
ok($zip->set_number('6048176')->is_valid_number, '京都府京都市中京区龍池町');
ok($zip->set_number('6048181')->is_valid_number, '京都府京都市中京区綿屋町');
ok($zip->set_number('6048182')->is_valid_number, '京都府京都市中京区大阪材木町');
ok($zip->set_number('6048183')->is_valid_number, '京都府京都市中京区東片町');
ok($zip->set_number('6048184')->is_valid_number, '京都府京都市中京区曇華院前町');
ok($zip->set_number('6048185')->is_valid_number, '京都府京都市中京区車屋町');
ok($zip->set_number('6048186')->is_valid_number, '京都府京都市中京区梅屋町(御池通烏丸東入、御池通東洞院西入)');
ok($zip->set_number('6048187')->is_valid_number, '京都府京都市中京区笹屋町(御池通東洞院東入、御池通東洞院西入、御池通烏丸東入、東洞院通');
ok($zip->set_number('6048187')->is_valid_number, '京都府京都市中京区姉小路上る、姉小路通東洞院東入)');
ok($zip->set_number('6048201')->is_valid_number, '京都府京都市中京区長浜町');
ok($zip->set_number('6048202')->is_valid_number, '京都府京都市中京区突抜町(衣棚通姉小路下る、衣棚通三条上る、姉小路通室町西入、姉小路通衣');
ok($zip->set_number('6048202')->is_valid_number, '京都府京都市中京区棚西入、姉小路通衣棚東入、姉小路通新町東入)');
ok($zip->set_number('6048203')->is_valid_number, '京都府京都市中京区衣棚町');
ok($zip->set_number('6048204')->is_valid_number, '京都府京都市中京区了頓図子町');
ok($zip->set_number('6048205')->is_valid_number, '京都府京都市中京区三条町');
ok($zip->set_number('6048206')->is_valid_number, '京都府京都市中京区町頭町');
ok($zip->set_number('6048207')->is_valid_number, '京都府京都市中京区神明町');
ok($zip->set_number('6048211')->is_valid_number, '京都府京都市中京区玉蔵町');
ok($zip->set_number('6048212')->is_valid_number, '京都府京都市中京区六角町');
ok($zip->set_number('6048213')->is_valid_number, '京都府京都市中京区姥柳町');
ok($zip->set_number('6048214')->is_valid_number, '京都府京都市中京区百足屋町(新町通蛸薬師下る、新町通錦小路上る、蛸薬師通新町西入、錦小路');
ok($zip->set_number('6048214')->is_valid_number, '京都府京都市中京区通新町西入、錦小路通新町東入)');
ok($zip->set_number('6048215')->is_valid_number, '京都府京都市中京区不動町');
ok($zip->set_number('6048216')->is_valid_number, '京都府京都市中京区池須町');
ok($zip->set_number('6048217')->is_valid_number, '京都府京都市中京区西六角町');
ok($zip->set_number('6048221')->is_valid_number, '京都府京都市中京区天神山町');
ok($zip->set_number('6048222')->is_valid_number, '京都府京都市中京区観音堂町');
ok($zip->set_number('6048223')->is_valid_number, '京都府京都市中京区小結棚町');
ok($zip->set_number('6048224')->is_valid_number, '京都府京都市中京区炭之座町');
ok($zip->set_number('6048225')->is_valid_number, '京都府京都市中京区蟷螂山町');
ok($zip->set_number('6048226')->is_valid_number, '京都府京都市中京区西錦小路町');
ok($zip->set_number('6048227')->is_valid_number, '京都府京都市中京区古西町');
ok($zip->set_number('6048231')->is_valid_number, '京都府京都市中京区元本能寺南町');
ok($zip->set_number('6048232')->is_valid_number, '京都府京都市中京区空也町');
ok($zip->set_number('6048233')->is_valid_number, '京都府京都市中京区藤本町');
ok($zip->set_number('6048234')->is_valid_number, '京都府京都市中京区藤西町');
ok($zip->set_number('6048235')->is_valid_number, '京都府京都市中京区錦堀川町');
ok($zip->set_number('6048236')->is_valid_number, '京都府京都市中京区三文字町(錦小路通堀川東入、錦小路通油小路西入、堀川通錦小路下る、醒ケ');
ok($zip->set_number('6048236')->is_valid_number, '京都府京都市中京区井通錦小路下る、醒ケ井通錦小路東入、醒ケ井通錦小路西入)');
ok($zip->set_number('6048237')->is_valid_number, '京都府京都市中京区山田町');
ok($zip->set_number('6048241')->is_valid_number, '京都府京都市中京区釜座町');
ok($zip->set_number('6048242')->is_valid_number, '京都府京都市中京区柳水町');
ok($zip->set_number('6048243')->is_valid_number, '京都府京都市中京区本能寺町');
ok($zip->set_number('6048244')->is_valid_number, '京都府京都市中京区元本能寺町');
ok($zip->set_number('6048245')->is_valid_number, '京都府京都市中京区六角油小路町');
ok($zip->set_number('6048246')->is_valid_number, '京都府京都市中京区猩々町');
ok($zip->set_number('6048247')->is_valid_number, '京都府京都市中京区塩屋町(三条通西洞院西入、三条通小川東入、三条通小川西入、三条通油小路東入)');
ok($zip->set_number('6048251')->is_valid_number, '京都府京都市中京区三条油小路町');
ok($zip->set_number('6048252')->is_valid_number, '京都府京都市中京区越後突抜町');
ok($zip->set_number('6048253')->is_valid_number, '京都府京都市中京区亀屋町(蛸薬師通堀川東入、堀川通蛸薬師下る、蛸薬師通油小路西入)');
ok($zip->set_number('6048254')->is_valid_number, '京都府京都市中京区四坊堀川町');
ok($zip->set_number('6048255')->is_valid_number, '京都府京都市中京区壺屋町(堀川通六角下る、六角通堀川東入、堀川通蛸薬師上る)');
ok($zip->set_number('6048256')->is_valid_number, '京都府京都市中京区越後町');
ok($zip->set_number('6048257')->is_valid_number, '京都府京都市中京区橋浦町');
ok($zip->set_number('6048258')->is_valid_number, '京都府京都市中京区橋東詰町');
ok($zip->set_number('6048261')->is_valid_number, '京都府京都市中京区式阿弥町');
ok($zip->set_number('6048262')->is_valid_number, '京都府京都市中京区宗林町');
ok($zip->set_number('6048263')->is_valid_number, '京都府京都市中京区姉東堀川町');
ok($zip->set_number('6048264')->is_valid_number, '京都府京都市中京区姉西堀川町');
ok($zip->set_number('6048265')->is_valid_number, '京都府京都市中京区西三坊堀川町');
ok($zip->set_number('6048266')->is_valid_number, '京都府京都市中京区三坊堀川町');
ok($zip->set_number('6048267')->is_valid_number, '京都府京都市中京区鍛冶町');
ok($zip->set_number('6048271')->is_valid_number, '京都府京都市中京区津軽町');
ok($zip->set_number('6048272')->is_valid_number, '京都府京都市中京区突抜町(釜座通姉小路下る、釜座通三条上る、姉小路通新町西入、姉小路通釜');
ok($zip->set_number('6048272')->is_valid_number, '京都府京都市中京区座西入、姉小路通釜座東入、姉小路通西洞院東入)');
ok($zip->set_number('6048273')->is_valid_number, '京都府京都市中京区姉西洞院町');
ok($zip->set_number('6048274')->is_valid_number, '京都府京都市中京区西堂町');
ok($zip->set_number('6048275')->is_valid_number, '京都府京都市中京区宮木町');
ok($zip->set_number('6048276')->is_valid_number, '京都府京都市中京区壺屋町(小川通御池下る、小川通姉小路上る)');
ok($zip->set_number('6048277')->is_valid_number, '京都府京都市中京区三坊西洞院町');
ok($zip->set_number('6048301')->is_valid_number, '京都府京都市中京区二条城町');
ok($zip->set_number('6048302')->is_valid_number, '京都府京都市中京区池元町');
ok($zip->set_number('6048303')->is_valid_number, '京都府京都市中京区最上町');
ok($zip->set_number('6048304')->is_valid_number, '京都府京都市中京区織物屋町');
ok($zip->set_number('6048305')->is_valid_number, '京都府京都市中京区市之町');
ok($zip->set_number('6048306')->is_valid_number, '京都府京都市中京区門前町');
ok($zip->set_number('6048311')->is_valid_number, '京都府京都市中京区俵屋町(御池通猪熊西入、御池通黒門東入)');
ok($zip->set_number('6048312')->is_valid_number, '京都府京都市中京区上巴町');
ok($zip->set_number('6048313')->is_valid_number, '京都府京都市中京区三坊猪熊町北組');
ok($zip->set_number('6048314')->is_valid_number, '京都府京都市中京区三坊猪熊町南組');
ok($zip->set_number('6048315')->is_valid_number, '京都府京都市中京区大文字町(黒門通御池下る、黒門通姉小路上る、御池通黒門西入、御池通黒門');
ok($zip->set_number('6048315')->is_valid_number, '京都府京都市中京区東入、御池通猪熊西入)');
ok($zip->set_number('6048316')->is_valid_number, '京都府京都市中京区三坊大宮町');
ok($zip->set_number('6048321')->is_valid_number, '京都府京都市中京区倉本町');
ok($zip->set_number('6048322')->is_valid_number, '京都府京都市中京区樽屋町');
ok($zip->set_number('6048323')->is_valid_number, '京都府京都市中京区上八文字町');
ok($zip->set_number('6048324')->is_valid_number, '京都府京都市中京区姉猪熊町');
ok($zip->set_number('6048325')->is_valid_number, '京都府京都市中京区上一文字町');
ok($zip->set_number('6048326')->is_valid_number, '京都府京都市中京区姉大宮町東側');
ok($zip->set_number('6048327')->is_valid_number, '京都府京都市中京区姉大宮町西側');
ok($zip->set_number('6048331')->is_valid_number, '京都府京都市中京区御供町');
ok($zip->set_number('6048332')->is_valid_number, '京都府京都市中京区橋西町');
ok($zip->set_number('6048333')->is_valid_number, '京都府京都市中京区下八文字町');
ok($zip->set_number('6048334')->is_valid_number, '京都府京都市中京区三条猪熊町');
ok($zip->set_number('6048335')->is_valid_number, '京都府京都市中京区下一文字町');
ok($zip->set_number('6048336')->is_valid_number, '京都府京都市中京区三条大宮町');
ok($zip->set_number('6048341')->is_valid_number, '京都府京都市中京区岩上町');
ok($zip->set_number('6048342')->is_valid_number, '京都府京都市中京区六角猪熊町');
ok($zip->set_number('6048343')->is_valid_number, '京都府京都市中京区上黒門町');
ok($zip->set_number('6048344')->is_valid_number, '京都府京都市中京区六角大宮町');
ok($zip->set_number('6048345')->is_valid_number, '京都府京都市中京区鍛冶屋町(六角通猪熊西入、六角通黒門東入、六角通黒門西入、六角通大宮東入)');
ok($zip->set_number('6048351')->is_valid_number, '京都府京都市中京区畳屋町');
ok($zip->set_number('6048352')->is_valid_number, '京都府京都市中京区金屋町');
ok($zip->set_number('6048353')->is_valid_number, '京都府京都市中京区宮本町');
ok($zip->set_number('6048354')->is_valid_number, '京都府京都市中京区下瓦町');
ok($zip->set_number('6048355')->is_valid_number, '京都府京都市中京区下黒門町');
ok($zip->set_number('6048356')->is_valid_number, '京都府京都市中京区四坊大宮町');
ok($zip->set_number('6048361')->is_valid_number, '京都府京都市中京区吉野町');
ok($zip->set_number('6048362')->is_valid_number, '京都府京都市中京区松浦町');
ok($zip->set_number('6048363')->is_valid_number, '京都府京都市中京区錦猪熊町');
ok($zip->set_number('6048364')->is_valid_number, '京都府京都市中京区藤岡町');
ok($zip->set_number('6048365')->is_valid_number, '京都府京都市中京区錦大宮町');
ok($zip->set_number('6048366')->is_valid_number, '京都府京都市中京区七軒町');
ok($zip->set_number('6048371')->is_valid_number, '京都府京都市中京区神泉苑町');
ok($zip->set_number('6048372')->is_valid_number, '京都府京都市中京区姉西町');
ok($zip->set_number('6048373')->is_valid_number, '京都府京都市中京区瓦師町');
ok($zip->set_number('6048374')->is_valid_number, '京都府京都市中京区上瓦町');
ok($zip->set_number('6048375')->is_valid_number, '京都府京都市中京区西ノ京池ノ内町');
ok($zip->set_number('6048381')->is_valid_number, '京都府京都市中京区西ノ京職司町');
ok($zip->set_number('6048382')->is_valid_number, '京都府京都市中京区西ノ京北聖町');
ok($zip->set_number('6048383')->is_valid_number, '京都府京都市中京区西ノ京小堀町');
ok($zip->set_number('6048384')->is_valid_number, '京都府京都市中京区西ノ京式部町');
ok($zip->set_number('6048401')->is_valid_number, '京都府京都市中京区聚楽廻松下町');
ok($zip->set_number('6048402')->is_valid_number, '京都府京都市中京区聚楽廻西町');
ok($zip->set_number('6048403')->is_valid_number, '京都府京都市中京区聚楽廻中町');
ok($zip->set_number('6048404')->is_valid_number, '京都府京都市中京区聚楽廻東町');
ok($zip->set_number('6048405')->is_valid_number, '京都府京都市中京区西ノ京車坂町');
ok($zip->set_number('6048411')->is_valid_number, '京都府京都市中京区聚楽廻南町');
ok($zip->set_number('6048412')->is_valid_number, '京都府京都市中京区西ノ京南聖町');
ok($zip->set_number('6048413')->is_valid_number, '京都府京都市中京区西ノ京勧学院町');
ok($zip->set_number('6048414')->is_valid_number, '京都府京都市中京区西ノ京小倉町');
ok($zip->set_number('6048415')->is_valid_number, '京都府京都市中京区西ノ京栂尾町');
ok($zip->set_number('6048416')->is_valid_number, '京都府京都市中京区西ノ京星池町');
ok($zip->set_number('6048417')->is_valid_number, '京都府京都市中京区西ノ京内畑町');
ok($zip->set_number('6048418')->is_valid_number, '京都府京都市中京区西ノ京東栂尾町');
ok($zip->set_number('6048421')->is_valid_number, '京都府京都市中京区西ノ京永本町');
ok($zip->set_number('6048422')->is_valid_number, '京都府京都市中京区西ノ京東月光町');
ok($zip->set_number('6048423')->is_valid_number, '京都府京都市中京区西ノ京西月光町');
ok($zip->set_number('6048424')->is_valid_number, '京都府京都市中京区西ノ京樋ノ口町');
ok($zip->set_number('6048425')->is_valid_number, '京都府京都市中京区西ノ京銅駝町');
ok($zip->set_number('6048426')->is_valid_number, '京都府京都市中京区西ノ京船塚町');
ok($zip->set_number('6048431')->is_valid_number, '京都府京都市中京区西ノ京原町');
ok($zip->set_number('6048432')->is_valid_number, '京都府京都市中京区西ノ京南原町');
ok($zip->set_number('6048433')->is_valid_number, '京都府京都市中京区西ノ京北小路町');
ok($zip->set_number('6048434')->is_valid_number, '京都府京都市中京区西ノ京新建町');
ok($zip->set_number('6048435')->is_valid_number, '京都府京都市中京区西ノ京三条坊町');
ok($zip->set_number('6048436')->is_valid_number, '京都府京都市中京区西ノ京下合町');
ok($zip->set_number('6048437')->is_valid_number, '京都府京都市中京区西ノ京東中合町');
ok($zip->set_number('6048441')->is_valid_number, '京都府京都市中京区西ノ京西中合町');
ok($zip->set_number('6048442')->is_valid_number, '京都府京都市中京区西ノ京桑原町');
ok($zip->set_number('6048443')->is_valid_number, '京都府京都市中京区西ノ京島ノ内町');
ok($zip->set_number('6048444')->is_valid_number, '京都府京都市中京区西ノ京月輪町');
ok($zip->set_number('6048445')->is_valid_number, '京都府京都市中京区西ノ京徳大寺町');
ok($zip->set_number('6048446')->is_valid_number, '京都府京都市中京区西ノ京日扇町');
ok($zip->set_number('6048451')->is_valid_number, '京都府京都市中京区西ノ京御輿岡町');
ok($zip->set_number('6048452')->is_valid_number, '京都府京都市中京区西ノ京伯楽町');
ok($zip->set_number('6048453')->is_valid_number, '京都府京都市中京区西ノ京春日町');
ok($zip->set_number('6048454')->is_valid_number, '京都府京都市中京区西ノ京小堀池町');
ok($zip->set_number('6048455')->is_valid_number, '京都府京都市中京区西ノ京藤ノ木町');
ok($zip->set_number('6048456')->is_valid_number, '京都府京都市中京区西ノ京壺ノ内町');
ok($zip->set_number('6048457')->is_valid_number, '京都府京都市中京区西ノ京馬代町');
ok($zip->set_number('6048461')->is_valid_number, '京都府京都市中京区西ノ京中保町');
ok($zip->set_number('6048462')->is_valid_number, '京都府京都市中京区西ノ京北円町');
ok($zip->set_number('6048463')->is_valid_number, '京都府京都市中京区西ノ京円町');
ok($zip->set_number('6048464')->is_valid_number, '京都府京都市中京区西ノ京南円町');
ok($zip->set_number('6048465')->is_valid_number, '京都府京都市中京区西ノ京西円町');
ok($zip->set_number('6048466')->is_valid_number, '京都府京都市中京区西ノ京南大炊御門町');
ok($zip->set_number('6048467')->is_valid_number, '京都府京都市中京区西ノ京大炊御門町');
ok($zip->set_number('6048471')->is_valid_number, '京都府京都市中京区西ノ京中御門東町');
ok($zip->set_number('6048472')->is_valid_number, '京都府京都市中京区西ノ京北壺井町');
ok($zip->set_number('6048473')->is_valid_number, '京都府京都市中京区西ノ京南壺井町');
ok($zip->set_number('6048474')->is_valid_number, '京都府京都市中京区西ノ京塚本町');
ok($zip->set_number('6048475')->is_valid_number, '京都府京都市中京区西ノ京中御門西町');
ok($zip->set_number('6048481')->is_valid_number, '京都府京都市中京区西ノ京冷泉町');
ok($zip->set_number('6048482')->is_valid_number, '京都府京都市中京区西ノ京笠殿町');
ok($zip->set_number('6048483')->is_valid_number, '京都府京都市中京区西ノ京南上合町');
ok($zip->set_number('6048484')->is_valid_number, '京都府京都市中京区西ノ京上合町');
ok($zip->set_number('6048485')->is_valid_number, '京都府京都市中京区西ノ京平町');
ok($zip->set_number('6048491')->is_valid_number, '京都府京都市中京区西ノ京左馬寮町');
ok($zip->set_number('6048492')->is_valid_number, '京都府京都市中京区西ノ京右馬寮町');
ok($zip->set_number('6048493')->is_valid_number, '京都府京都市中京区西ノ京南両町');
ok($zip->set_number('6048494')->is_valid_number, '京都府京都市中京区西ノ京上平町');
ok($zip->set_number('6048495')->is_valid_number, '京都府京都市中京区西ノ京西鹿垣町');
ok($zip->set_number('6048496')->is_valid_number, '京都府京都市中京区西ノ京鹿垣町');
ok($zip->set_number('6048497')->is_valid_number, '京都府京都市中京区西ノ京両町');
ok($zip->set_number('6048801')->is_valid_number, '京都府京都市中京区今新在家西町');
ok($zip->set_number('6048802')->is_valid_number, '京都府京都市中京区今新在家東町');
ok($zip->set_number('6048803')->is_valid_number, '京都府京都市中京区因幡町');
ok($zip->set_number('6048804')->is_valid_number, '京都府京都市中京区壬生坊城町');
ok($zip->set_number('6048805')->is_valid_number, '京都府京都市中京区壬生馬場町');
ok($zip->set_number('6048811')->is_valid_number, '京都府京都市中京区壬生賀陽御所町');
ok($zip->set_number('6048812')->is_valid_number, '京都府京都市中京区壬生相合町');
ok($zip->set_number('6048821')->is_valid_number, '京都府京都市中京区壬生梛ノ宮町');
ok($zip->set_number('6048822')->is_valid_number, '京都府京都市中京区壬生辻町');
ok($zip->set_number('6048823')->is_valid_number, '京都府京都市中京区壬生松原町');
ok($zip->set_number('6048824')->is_valid_number, '京都府京都市中京区壬生高樋町');
ok($zip->set_number('6048831')->is_valid_number, '京都府京都市中京区壬生森前町');
ok($zip->set_number('6048832')->is_valid_number, '京都府京都市中京区壬生下溝町');
ok($zip->set_number('6048841')->is_valid_number, '京都府京都市中京区壬生東土居ノ内町');
ok($zip->set_number('6048842')->is_valid_number, '京都府京都市中京区壬生土居ノ内町');
ok($zip->set_number('6048843')->is_valid_number, '京都府京都市中京区壬生東桧町');
ok($zip->set_number('6048844')->is_valid_number, '京都府京都市中京区壬生桧町');
ok($zip->set_number('6048845')->is_valid_number, '京都府京都市中京区壬生東高田町');
ok($zip->set_number('6048846')->is_valid_number, '京都府京都市中京区壬生西桧町');
ok($zip->set_number('6048847')->is_valid_number, '京都府京都市中京区壬生西土居ノ内町');
ok($zip->set_number('6048851')->is_valid_number, '京都府京都市中京区壬生上大竹町');
ok($zip->set_number('6048852')->is_valid_number, '京都府京都市中京区壬生東大竹町');
ok($zip->set_number('6048853')->is_valid_number, '京都府京都市中京区壬生東淵田町');
ok($zip->set_number('6048854')->is_valid_number, '京都府京都市中京区壬生仙念町');
ok($zip->set_number('6048855')->is_valid_number, '京都府京都市中京区壬生淵田町');
ok($zip->set_number('6048856')->is_valid_number, '京都府京都市中京区壬生西大竹町');
ok($zip->set_number('6048861')->is_valid_number, '京都府京都市中京区壬生神明町');
ok($zip->set_number('6048862')->is_valid_number, '京都府京都市中京区壬生森町');
ok($zip->set_number('6048863')->is_valid_number, '京都府京都市中京区壬生中川町');
ok($zip->set_number('6048871')->is_valid_number, '京都府京都市中京区壬生朱雀町');
ok($zip->set_number('6048872')->is_valid_number, '京都府京都市中京区壬生御所ノ内町');
ok($zip->set_number('6048873')->is_valid_number, '京都府京都市中京区壬生花井町');
ok($zip->set_number('6048874')->is_valid_number, '京都府京都市中京区壬生天池町');
ok($zip->set_number('6050000')->is_valid_number, '京都府京都市東山区以下に掲載がない場合');
ok($zip->set_number('6050001')->is_valid_number, '京都府京都市東山区二町目');
ok($zip->set_number('6050002')->is_valid_number, '京都府京都市東山区教業町');
ok($zip->set_number('6050003')->is_valid_number, '京都府京都市東山区若竹町');
ok($zip->set_number('6050004')->is_valid_number, '京都府京都市東山区若松町');
ok($zip->set_number('6050005')->is_valid_number, '京都府京都市東山区三町目');
ok($zip->set_number('6050006')->is_valid_number, '京都府京都市東山区新五軒町');
ok($zip->set_number('6050007')->is_valid_number, '京都府京都市東山区五軒町(大和大路通三条下る、大和大路通三条下る西入)');
ok($zip->set_number('6050008')->is_valid_number, '京都府京都市東山区大黒町(大和大路三条下る)');
ok($zip->set_number('6050009')->is_valid_number, '京都府京都市東山区大橋町');
ok($zip->set_number('6050011')->is_valid_number, '京都府京都市東山区七軒町(三条大橋東4丁目、三条大橋東入4丁目)');
ok($zip->set_number('6050012')->is_valid_number, '京都府京都市東山区西海子町');
ok($zip->set_number('6050013')->is_valid_number, '京都府京都市東山区南西海子町');
ok($zip->set_number('6050014')->is_valid_number, '京都府京都市東山区北木之元町');
ok($zip->set_number('6050015')->is_valid_number, '京都府京都市東山区南木之元町');
ok($zip->set_number('6050016')->is_valid_number, '京都府京都市東山区進之町');
ok($zip->set_number('6050017')->is_valid_number, '京都府京都市東山区高畑町');
ok($zip->set_number('6050018')->is_valid_number, '京都府京都市東山区巽町');
ok($zip->set_number('6050019')->is_valid_number, '京都府京都市東山区長光町');
ok($zip->set_number('6050021')->is_valid_number, '京都府京都市東山区石泉院町');
ok($zip->set_number('6050022')->is_valid_number, '京都府京都市東山区大井手町');
ok($zip->set_number('6050023')->is_valid_number, '京都府京都市東山区今小路町');
ok($zip->set_number('6050024')->is_valid_number, '京都府京都市東山区土居之内町');
ok($zip->set_number('6050025')->is_valid_number, '京都府京都市東山区堤町');
ok($zip->set_number('6050026')->is_valid_number, '京都府京都市東山区古川町');
ok($zip->set_number('6050027')->is_valid_number, '京都府京都市東山区八軒町');
ok($zip->set_number('6050028')->is_valid_number, '京都府京都市東山区分木町');
ok($zip->set_number('6050029')->is_valid_number, '京都府京都市東山区東姉小路町');
ok($zip->set_number('6050031')->is_valid_number, '京都府京都市東山区定法寺町');
ok($zip->set_number('6050032')->is_valid_number, '京都府京都市東山区柚之木町');
ok($zip->set_number('6050033')->is_valid_number, '京都府京都市東山区夷町');
ok($zip->set_number('6050034')->is_valid_number, '京都府京都市東山区中之町(三条通神宮道東入2丁目、三条通白川橋東入4丁目、三条通白川橋東');
ok($zip->set_number('6050034')->is_valid_number, '京都府京都市東山区4丁目)');
ok($zip->set_number('6050035')->is_valid_number, '京都府京都市東山区粟田口三条坊町');
ok($zip->set_number('6050036')->is_valid_number, '京都府京都市東山区五軒町(三条通白川橋東入、三条通白川橋下る東入、');
ok($zip->set_number('6050036')->is_valid_number, '京都府京都市東山区白川筋三条下る)');
ok($zip->set_number('6050037')->is_valid_number, '京都府京都市東山区西町');
ok($zip->set_number('6050038')->is_valid_number, '京都府京都市東山区堀池町');
ok($zip->set_number('6050041')->is_valid_number, '京都府京都市東山区東町');
ok($zip->set_number('6050042')->is_valid_number, '京都府京都市東山区今道町');
ok($zip->set_number('6050043')->is_valid_number, '京都府京都市東山区西小物座町');
ok($zip->set_number('6050044')->is_valid_number, '京都府京都市東山区東小物座町');
ok($zip->set_number('6050045')->is_valid_number, '京都府京都市東山区谷川町');
ok($zip->set_number('6050046')->is_valid_number, '京都府京都市東山区東分木町');
ok($zip->set_number('6050051')->is_valid_number, '京都府京都市東山区粟田口鍛冶町');
ok($zip->set_number('6050052')->is_valid_number, '京都府京都市東山区粟田口華頂町');
ok($zip->set_number('6050061')->is_valid_number, '京都府京都市東山区梅宮町');
ok($zip->set_number('6050062')->is_valid_number, '京都府京都市東山区林下町');
ok($zip->set_number('6050063')->is_valid_number, '京都府京都市東山区松原町');
ok($zip->set_number('6050064')->is_valid_number, '京都府京都市東山区梅本町');
ok($zip->set_number('6050065')->is_valid_number, '京都府京都市東山区古西町');
ok($zip->set_number('6050066')->is_valid_number, '京都府京都市東山区石橋町');
ok($zip->set_number('6050067')->is_valid_number, '京都府京都市東山区稲荷町南組');
ok($zip->set_number('6050068')->is_valid_number, '京都府京都市東山区稲荷町北組');
ok($zip->set_number('6050069')->is_valid_number, '京都府京都市東山区唐戸鼻町');
ok($zip->set_number('6050071')->is_valid_number, '京都府京都市東山区円山町');
ok($zip->set_number('6050072')->is_valid_number, '京都府京都市東山区鷲尾町');
ok($zip->set_number('6050073')->is_valid_number, '京都府京都市東山区祇園町北側');
ok($zip->set_number('6050074')->is_valid_number, '京都府京都市東山区祇園町南側');
ok($zip->set_number('6050075')->is_valid_number, '京都府京都市東山区中之町(四条通大和大路西入)');
ok($zip->set_number('6050076')->is_valid_number, '京都府京都市東山区川端町');
ok($zip->set_number('6050077')->is_valid_number, '京都府京都市東山区廿一軒町');
ok($zip->set_number('6050078')->is_valid_number, '京都府京都市東山区富永町');
ok($zip->set_number('6050079')->is_valid_number, '京都府京都市東山区常盤町(大和大路通四条上る、川端通四条上る)');
ok($zip->set_number('6050081')->is_valid_number, '京都府京都市東山区三吉町');
ok($zip->set_number('6050082')->is_valid_number, '京都府京都市東山区中之町(新門前通大和大路東入、新門前通大和大路東入2丁目)');
ok($zip->set_number('6050083')->is_valid_number, '京都府京都市東山区橋本町');
ok($zip->set_number('6050084')->is_valid_number, '京都府京都市東山区清本町');
ok($zip->set_number('6050085')->is_valid_number, '京都府京都市東山区末吉町');
ok($zip->set_number('6050086')->is_valid_number, '京都府京都市東山区弁財天町');
ok($zip->set_number('6050087')->is_valid_number, '京都府京都市東山区元吉町');
ok($zip->set_number('6050088')->is_valid_number, '京都府京都市東山区西之町');
ok($zip->set_number('6050089')->is_valid_number, '京都府京都市東山区元町');
ok($zip->set_number('6050801')->is_valid_number, '京都府京都市東山区宮川筋');
ok($zip->set_number('6050802')->is_valid_number, '京都府京都市東山区大和町');
ok($zip->set_number('6050803')->is_valid_number, '京都府京都市東山区亀井町');
ok($zip->set_number('6050804')->is_valid_number, '京都府京都市東山区井手町');
ok($zip->set_number('6050805')->is_valid_number, '京都府京都市東山区博多町');
ok($zip->set_number('6050806')->is_valid_number, '京都府京都市東山区六軒町');
ok($zip->set_number('6050807')->is_valid_number, '京都府京都市東山区上柳町');
ok($zip->set_number('6050808')->is_valid_number, '京都府京都市東山区下柳町');
ok($zip->set_number('6050811')->is_valid_number, '京都府京都市東山区小松町');
ok($zip->set_number('6050812')->is_valid_number, '京都府京都市東山区毘沙門町');
ok($zip->set_number('6050813')->is_valid_number, '京都府京都市東山区轆轤町');
ok($zip->set_number('6050814')->is_valid_number, '京都府京都市東山区薬師町');
ok($zip->set_number('6050815')->is_valid_number, '京都府京都市東山区北御門町');
ok($zip->set_number('6050816')->is_valid_number, '京都府京都市東山区西御門町');
ok($zip->set_number('6050817')->is_valid_number, '京都府京都市東山区弓矢町');
ok($zip->set_number('6050821')->is_valid_number, '京都府京都市東山区清井町');
ok($zip->set_number('6050822')->is_valid_number, '京都府京都市東山区上弁天町');
ok($zip->set_number('6050823')->is_valid_number, '京都府京都市東山区下弁天町');
ok($zip->set_number('6050824')->is_valid_number, '京都府京都市東山区南町');
ok($zip->set_number('6050825')->is_valid_number, '京都府京都市東山区下河原町');
ok($zip->set_number('6050826')->is_valid_number, '京都府京都市東山区桝屋町');
ok($zip->set_number('6050827')->is_valid_number, '京都府京都市東山区八坂上町');
ok($zip->set_number('6050828')->is_valid_number, '京都府京都市東山区金園町');
ok($zip->set_number('6050829')->is_valid_number, '京都府京都市東山区月見町');
ok($zip->set_number('6050831')->is_valid_number, '京都府京都市東山区山城町');
ok($zip->set_number('6050832')->is_valid_number, '京都府京都市東山区大黒町(大黒町通柿町下る、大黒町通五条上る、大黒町通五条上る2丁目、');
ok($zip->set_number('6050832')->is_valid_number, '京都府京都市東山区大黒町通松原下る3丁目)');
ok($zip->set_number('6050833')->is_valid_number, '京都府京都市東山区音羽町');
ok($zip->set_number('6050834')->is_valid_number, '京都府京都市東山区金屋町');
ok($zip->set_number('6050835')->is_valid_number, '京都府京都市東山区田中町');
ok($zip->set_number('6050836')->is_valid_number, '京都府京都市東山区森下町');
ok($zip->set_number('6050837')->is_valid_number, '京都府京都市東山区山田町');
ok($zip->set_number('6050838')->is_valid_number, '京都府京都市東山区西川原町');
ok($zip->set_number('6050839')->is_valid_number, '京都府京都市東山区東川原町');
ok($zip->set_number('6050841')->is_valid_number, '京都府京都市東山区山崎町');
ok($zip->set_number('6050842')->is_valid_number, '京都府京都市東山区三盛町');
ok($zip->set_number('6050843')->is_valid_number, '京都府京都市東山区門脇町');
ok($zip->set_number('6050844')->is_valid_number, '京都府京都市東山区多門町');
ok($zip->set_number('6050845')->is_valid_number, '京都府京都市東山区竹村町');
ok($zip->set_number('6050846')->is_valid_number, '京都府京都市東山区五条橋東');
ok($zip->set_number('6050847')->is_valid_number, '京都府京都市東山区東橋詰町');
ok($zip->set_number('6050848')->is_valid_number, '京都府京都市東山区池殿町');
ok($zip->set_number('6050851')->is_valid_number, '京都府京都市東山区玉水町');
ok($zip->set_number('6050852')->is_valid_number, '京都府京都市東山区上田町');
ok($zip->set_number('6050853')->is_valid_number, '京都府京都市東山区星野町');
ok($zip->set_number('6050854')->is_valid_number, '京都府京都市東山区月輪町');
ok($zip->set_number('6050855')->is_valid_number, '京都府京都市東山区辰巳町(東大路松原上る)');
ok($zip->set_number('6050856')->is_valid_number, '京都府京都市東山区新シ町');
ok($zip->set_number('6050857')->is_valid_number, '京都府京都市東山区興善町');
ok($zip->set_number('6050858')->is_valid_number, '京都府京都市東山区小島町');
ok($zip->set_number('6050861')->is_valid_number, '京都府京都市東山区清閑寺霊山町');
ok($zip->set_number('6050862')->is_valid_number, '京都府京都市東山区清水');
ok($zip->set_number('6050863')->is_valid_number, '京都府京都市東山区梅林町');
ok($zip->set_number('6050864')->is_valid_number, '京都府京都市東山区遊行前町');
ok($zip->set_number('6050865')->is_valid_number, '京都府京都市東山区白糸町');
ok($zip->set_number('6050871')->is_valid_number, '京都府京都市東山区慈法院庵町');
ok($zip->set_number('6050872')->is_valid_number, '京都府京都市東山区東音羽町');
ok($zip->set_number('6050873')->is_valid_number, '京都府京都市東山区下馬町');
ok($zip->set_number('6050874')->is_valid_number, '京都府京都市東山区常盤町(東大路通渋谷上る、渋谷通東大路東入、渋谷通東大路東入2丁目、');
ok($zip->set_number('6050874')->is_valid_number, '京都府京都市東山区東大路五条下る)');
ok($zip->set_number('6050875')->is_valid_number, '京都府京都市東山区鐘鋳町');
ok($zip->set_number('6050876')->is_valid_number, '京都府京都市東山区上梅屋町');
ok($zip->set_number('6050877')->is_valid_number, '京都府京都市東山区上新シ町');
ok($zip->set_number('6050878')->is_valid_number, '京都府京都市東山区芳野町');
ok($zip->set_number('6050901')->is_valid_number, '京都府京都市東山区朱雀町');
ok($zip->set_number('6050902')->is_valid_number, '京都府京都市東山区鞘町');
ok($zip->set_number('6050903')->is_valid_number, '京都府京都市東山区上人町');
ok($zip->set_number('6050904')->is_valid_number, '京都府京都市東山区大阪町');
ok($zip->set_number('6050905')->is_valid_number, '京都府京都市東山区豊浦町');
ok($zip->set_number('6050906')->is_valid_number, '京都府京都市東山区東橘町');
ok($zip->set_number('6050907')->is_valid_number, '京都府京都市東山区西橘町');
ok($zip->set_number('6050908')->is_valid_number, '京都府京都市東山区正面町');
ok($zip->set_number('6050909')->is_valid_number, '京都府京都市東山区鍵屋町');
ok($zip->set_number('6050911')->is_valid_number, '京都府京都市東山区袋町');
ok($zip->set_number('6050912')->is_valid_number, '京都府京都市東山区石垣町西側');
ok($zip->set_number('6050913')->is_valid_number, '京都府京都市東山区石垣町東側');
ok($zip->set_number('6050914')->is_valid_number, '京都府京都市東山区下新シ町');
ok($zip->set_number('6050915')->is_valid_number, '京都府京都市東山区下梅屋町');
ok($zip->set_number('6050916')->is_valid_number, '京都府京都市東山区上棟梁町');
ok($zip->set_number('6050917')->is_valid_number, '京都府京都市東山区蛭子町北組');
ok($zip->set_number('6050918')->is_valid_number, '京都府京都市東山区北棟梁町');
ok($zip->set_number('6050921')->is_valid_number, '京都府京都市東山区瓦役町');
ok($zip->set_number('6050922')->is_valid_number, '京都府京都市東山区清閑寺山ノ内町');
ok($zip->set_number('6050923')->is_valid_number, '京都府京都市東山区清閑寺池田町');
ok($zip->set_number('6050924')->is_valid_number, '京都府京都市東山区今熊野阿弥陀ケ峰町');
ok($zip->set_number('6050925')->is_valid_number, '京都府京都市東山区今熊野日吉町');
ok($zip->set_number('6050926')->is_valid_number, '京都府京都市東山区今熊野北日吉町');
ok($zip->set_number('6050927')->is_valid_number, '京都府京都市東山区上馬町');
ok($zip->set_number('6050931')->is_valid_number, '京都府京都市東山区茶屋町');
ok($zip->set_number('6050932')->is_valid_number, '京都府京都市東山区妙法院前側町');
ok($zip->set_number('6050933')->is_valid_number, '京都府京都市東山区大和大路');
ok($zip->set_number('6050934')->is_valid_number, '京都府京都市東山区塗師屋町');
ok($zip->set_number('6050935')->is_valid_number, '京都府京都市東山区西棟梁町');
ok($zip->set_number('6050936')->is_valid_number, '京都府京都市東山区蛭子町南組');
ok($zip->set_number('6050937')->is_valid_number, '京都府京都市東山区下棟梁町');
ok($zip->set_number('6050938')->is_valid_number, '京都府京都市東山区南梅屋町');
ok($zip->set_number('6050941')->is_valid_number, '京都府京都市東山区三十三間堂廻り町');
ok($zip->set_number('6050942')->is_valid_number, '京都府京都市東山区蒔田町');
ok($zip->set_number('6050943')->is_valid_number, '京都府京都市東山区七軒町(大和大路通七条下る3丁目、塩小路通大和大路西入)');
ok($zip->set_number('6050944')->is_valid_number, '京都府京都市東山区南棟梁町');
ok($zip->set_number('6050945')->is_valid_number, '京都府京都市東山区辰巳町(大和大路通七条下る2丁目)');
ok($zip->set_number('6050946')->is_valid_number, '京都府京都市東山区北斗町');
ok($zip->set_number('6050947')->is_valid_number, '京都府京都市東山区西之門町');
ok($zip->set_number('6050951')->is_valid_number, '京都府京都市東山区東瓦町');
ok($zip->set_number('6050952')->is_valid_number, '京都府京都市東山区今熊野宝蔵町');
ok($zip->set_number('6050953')->is_valid_number, '京都府京都市東山区今熊野南日吉町');
ok($zip->set_number('6050954')->is_valid_number, '京都府京都市東山区今熊野小松山町');
ok($zip->set_number('6050955')->is_valid_number, '京都府京都市東山区今熊野総山町');
ok($zip->set_number('6050956')->is_valid_number, '京都府京都市東山区今熊野梅ケ谷町');
ok($zip->set_number('6050957')->is_valid_number, '京都府京都市東山区今熊野泉山町');
ok($zip->set_number('6050961')->is_valid_number, '京都府京都市東山区新瓦町西組');
ok($zip->set_number('6050962')->is_valid_number, '京都府京都市東山区新瓦町東組');
ok($zip->set_number('6050963')->is_valid_number, '京都府京都市東山区本瓦町');
ok($zip->set_number('6050964')->is_valid_number, '京都府京都市東山区南瓦町');
ok($zip->set_number('6050965')->is_valid_number, '京都府京都市東山区今熊野池田町');
ok($zip->set_number('6050966')->is_valid_number, '京都府京都市東山区下池田町');
ok($zip->set_number('6050967')->is_valid_number, '京都府京都市東山区本池田町');
ok($zip->set_number('6050968')->is_valid_number, '京都府京都市東山区上池田町');
ok($zip->set_number('6050971')->is_valid_number, '京都府京都市東山区今熊野椥ノ森町');
ok($zip->set_number('6050972')->is_valid_number, '京都府京都市東山区今熊野剣宮町');
ok($zip->set_number('6050973')->is_valid_number, '京都府京都市東山区泉涌寺門前町');
ok($zip->set_number('6050974')->is_valid_number, '京都府京都市東山区泉涌寺五葉ノ辻町');
ok($zip->set_number('6050975')->is_valid_number, '京都府京都市東山区泉涌寺雀ケ森町');
ok($zip->set_number('6050976')->is_valid_number, '京都府京都市東山区泉涌寺東林町');
ok($zip->set_number('6050977')->is_valid_number, '京都府京都市東山区泉涌寺山内町');
ok($zip->set_number('6050978')->is_valid_number, '京都府京都市東山区今熊野本多山町');
ok($zip->set_number('6050979')->is_valid_number, '京都府京都市東山区今熊野南谷町');
ok($zip->set_number('6050981')->is_valid_number, '京都府京都市東山区本町');
ok($zip->set_number('6050982')->is_valid_number, '京都府京都市東山区福稲下高松町');
ok($zip->set_number('6050983')->is_valid_number, '京都府京都市東山区福稲上高松町');
ok($zip->set_number('6050984')->is_valid_number, '京都府京都市東山区福稲高原町');
ok($zip->set_number('6050985')->is_valid_number, '京都府京都市東山区福稲柿本町');
ok($zip->set_number('6050986')->is_valid_number, '京都府京都市東山区福稲岸ノ上町');
ok($zip->set_number('6050987')->is_valid_number, '京都府京都市東山区福稲御所ノ内町');
ok($zip->set_number('6050988')->is_valid_number, '京都府京都市東山区福稲川原町');
ok($zip->set_number('6050989')->is_valid_number, '京都府京都市東山区本町新');
ok($zip->set_number('6050991')->is_valid_number, '京都府京都市東山区上堀詰町');
ok($zip->set_number('6050992')->is_valid_number, '京都府京都市東山区下堀詰町');
ok($zip->set_number('6050993')->is_valid_number, '京都府京都市東山区日吉町');
ok($zip->set_number('6050994')->is_valid_number, '京都府京都市東山区一橋宮ノ内町');
ok($zip->set_number('6050995')->is_valid_number, '京都府京都市東山区一橋野本町');
ok($zip->set_number('6060000')->is_valid_number, '京都府京都市左京区以下に掲載がない場合');
ok($zip->set_number('6060001')->is_valid_number, '京都府京都市左京区岩倉大鷺町');
ok($zip->set_number('6060002')->is_valid_number, '京都府京都市左京区岩倉中大鷺町');
ok($zip->set_number('6060003')->is_valid_number, '京都府京都市左京区岩倉南大鷺町');
ok($zip->set_number('6060004')->is_valid_number, '京都府京都市左京区岩倉北池田町');
ok($zip->set_number('6060005')->is_valid_number, '京都府京都市左京区岩倉南池田町');
ok($zip->set_number('6060006')->is_valid_number, '京都府京都市左京区岩倉西五田町');
ok($zip->set_number('6060007')->is_valid_number, '京都府京都市左京区岩倉東五田町');
ok($zip->set_number('6060008')->is_valid_number, '京都府京都市左京区岩倉三笠町');
ok($zip->set_number('6060009')->is_valid_number, '京都府京都市左京区岩倉北桑原町');
ok($zip->set_number('6060010')->is_valid_number, '京都府京都市左京区岩倉北四ノ坪町');
ok($zip->set_number('6060011')->is_valid_number, '京都府京都市左京区岩倉西宮田町');
ok($zip->set_number('6060012')->is_valid_number, '京都府京都市左京区岩倉東宮田町');
ok($zip->set_number('6060013')->is_valid_number, '京都府京都市左京区岩倉下在地町');
ok($zip->set_number('6060014')->is_valid_number, '京都府京都市左京区岩倉西河原町');
ok($zip->set_number('6060015')->is_valid_number, '京都府京都市左京区岩倉幡枝町');
ok($zip->set_number('6060016')->is_valid_number, '京都府京都市左京区岩倉木野町(その他)');
ok($zip->set_number('6060017')->is_valid_number, '京都府京都市左京区岩倉上蔵町(その他)');
ok($zip->set_number('6060018')->is_valid_number, '京都府京都市左京区岩倉中河原町');
ok($zip->set_number('6060019')->is_valid_number, '京都府京都市左京区岩倉南河原町');
ok($zip->set_number('6060021')->is_valid_number, '京都府京都市左京区岩倉忠在地町');
ok($zip->set_number('6060022')->is_valid_number, '京都府京都市左京区岩倉三宅町');
ok($zip->set_number('6060023')->is_valid_number, '京都府京都市左京区岩倉南三宅町');
ok($zip->set_number('6060024')->is_valid_number, '京都府京都市左京区岩倉花園町');
ok($zip->set_number('6060025')->is_valid_number, '京都府京都市左京区岩倉中町');
ok($zip->set_number('6060026')->is_valid_number, '京都府京都市左京区岩倉長谷町');
ok($zip->set_number('6060027')->is_valid_number, '京都府京都市左京区岩倉中在地町');
ok($zip->set_number('6060028')->is_valid_number, '京都府京都市左京区岩倉南木野町');
ok($zip->set_number('6060029')->is_valid_number, '京都府京都市左京区岩倉北平岡町');
ok($zip->set_number('6060031')->is_valid_number, '京都府京都市左京区岩倉南桑原町');
ok($zip->set_number('6060032')->is_valid_number, '京都府京都市左京区岩倉南平岡町');
ok($zip->set_number('6060033')->is_valid_number, '京都府京都市左京区岩倉南四ノ坪町');
ok($zip->set_number('6060034')->is_valid_number, '京都府京都市左京区岩倉村松町');
ok($zip->set_number('6060035')->is_valid_number, '京都府京都市左京区上高野三宅町');
ok($zip->set_number('6060036')->is_valid_number, '京都府京都市左京区上高野北田町');
ok($zip->set_number('6060037')->is_valid_number, '京都府京都市左京区上高野流田町');
ok($zip->set_number('6060041')->is_valid_number, '京都府京都市左京区上高野石田町');
ok($zip->set_number('6060042')->is_valid_number, '京都府京都市左京区上高野鷺町');
ok($zip->set_number('6060043')->is_valid_number, '京都府京都市左京区上高野古川町');
ok($zip->set_number('6060044')->is_valid_number, '京都府京都市左京区上高野仲町');
ok($zip->set_number('6060045')->is_valid_number, '京都府京都市左京区上高野深田町');
ok($zip->set_number('6060046')->is_valid_number, '京都府京都市左京区上高野諸木町');
ok($zip->set_number('6060047')->is_valid_number, '京都府京都市左京区上高野薩田町');
ok($zip->set_number('6060048')->is_valid_number, '京都府京都市左京区上高野大湯手町');
ok($zip->set_number('6060051')->is_valid_number, '京都府京都市左京区上高野野上町');
ok($zip->set_number('6060052')->is_valid_number, '京都府京都市左京区上高野鳥脇町');
ok($zip->set_number('6060053')->is_valid_number, '京都府京都市左京区上高野車地町');
ok($zip->set_number('6060054')->is_valid_number, '京都府京都市左京区上高野三反田町');
ok($zip->set_number('6060055')->is_valid_number, '京都府京都市左京区上高野尾保地町');
ok($zip->set_number('6060056')->is_valid_number, '京都府京都市左京区上高野市川町');
ok($zip->set_number('6060057')->is_valid_number, '京都府京都市左京区上高野池ノ内町');
ok($zip->set_number('6060058')->is_valid_number, '京都府京都市左京区上高野小野町');
ok($zip->set_number('6060059')->is_valid_number, '京都府京都市左京区上高野北川原町');
ok($zip->set_number('6060061')->is_valid_number, '京都府京都市左京区上高野川原町');
ok($zip->set_number('6060062')->is_valid_number, '京都府京都市左京区上高野大橋町');
ok($zip->set_number('6060063')->is_valid_number, '京都府京都市左京区上高野大明神町');
ok($zip->set_number('6060064')->is_valid_number, '京都府京都市左京区上高野西明寺山');
ok($zip->set_number('6060065')->is_valid_number, '京都府京都市左京区上高野八幡町');
ok($zip->set_number('6060066')->is_valid_number, '京都府京都市左京区上高野水車町');
ok($zip->set_number('6060067')->is_valid_number, '京都府京都市左京区上高野東山(その他)');
ok($zip->set_number('6060068')->is_valid_number, '京都府京都市左京区八瀬野瀬町(277の2、279の1、3~5、281の2~9、11');
ok($zip->set_number('6060068')->is_valid_number, '京都府京都市左京区~18、20~22、24~26、32、287、300番地)');
ok($zip->set_number('6060071')->is_valid_number, '京都府京都市左京区上高野防山');
ok($zip->set_number('6060072')->is_valid_number, '京都府京都市左京区上高野掃部林町');
ok($zip->set_number('6060073')->is_valid_number, '京都府京都市左京区上高野釜土町');
ok($zip->set_number('6060074')->is_valid_number, '京都府京都市左京区上高野下東野町');
ok($zip->set_number('6060075')->is_valid_number, '京都府京都市左京区上高野奥東野町');
ok($zip->set_number('6060076')->is_valid_number, '京都府京都市左京区上高野口小森町');
ok($zip->set_number('6060077')->is_valid_number, '京都府京都市左京区上高野奥小森町');
ok($zip->set_number('6060078')->is_valid_number, '京都府京都市左京区上高野東田町');
ok($zip->set_number('6060081')->is_valid_number, '京都府京都市左京区上高野畑町');
ok($zip->set_number('6060082')->is_valid_number, '京都府京都市左京区上高野畑ケ田町');
ok($zip->set_number('6060083')->is_valid_number, '京都府京都市左京区上高野松田町');
ok($zip->set_number('6060084')->is_valid_number, '京都府京都市左京区上高野鐘突町');
ok($zip->set_number('6060085')->is_valid_number, '京都府京都市左京区上高野隣好町');
ok($zip->set_number('6060086')->is_valid_number, '京都府京都市左京区上高野木ノ下町');
ok($zip->set_number('6060087')->is_valid_number, '京都府京都市左京区上高野稲荷町');
ok($zip->set_number('6060088')->is_valid_number, '京都府京都市左京区上高野植ノ町');
ok($zip->set_number('6060089')->is_valid_number, '京都府京都市左京区上高野上畑町');
ok($zip->set_number('6060091')->is_valid_number, '京都府京都市左京区上高野大塚町');
ok($zip->set_number('6060092')->is_valid_number, '京都府京都市左京区上高野下荒蒔町');
ok($zip->set_number('6060093')->is_valid_number, '京都府京都市左京区上高野上荒蒔町');
ok($zip->set_number('6060094')->is_valid_number, '京都府京都市左京区上高野東氷室町');
ok($zip->set_number('6060095')->is_valid_number, '京都府京都市左京区上高野西氷室町');
ok($zip->set_number('6060096')->is_valid_number, '京都府京都市左京区上高野山ノ橋町');
ok($zip->set_number('6060097')->is_valid_number, '京都府京都市左京区上高野前田町');
ok($zip->set_number('6060098')->is_valid_number, '京都府京都市左京区上高野沢渕町');
ok($zip->set_number('6060801')->is_valid_number, '京都府京都市左京区下鴨宮河町');
ok($zip->set_number('6060802')->is_valid_number, '京都府京都市左京区下鴨宮崎町');
ok($zip->set_number('6060803')->is_valid_number, '京都府京都市左京区下鴨下川原町');
ok($zip->set_number('6060804')->is_valid_number, '京都府京都市左京区下鴨松原町');
ok($zip->set_number('6060805')->is_valid_number, '京都府京都市左京区下鴨森本町');
ok($zip->set_number('6060806')->is_valid_number, '京都府京都市左京区下鴨蓼倉町');
ok($zip->set_number('6060807')->is_valid_number, '京都府京都市左京区下鴨泉川町');
ok($zip->set_number('6060811')->is_valid_number, '京都府京都市左京区下鴨中川原町');
ok($zip->set_number('6060812')->is_valid_number, '京都府京都市左京区下鴨上川原町');
ok($zip->set_number('6060813')->is_valid_number, '京都府京都市左京区下鴨貴船町');
ok($zip->set_number('6060814')->is_valid_number, '京都府京都市左京区下鴨芝本町');
ok($zip->set_number('6060815')->is_valid_number, '京都府京都市左京区下鴨膳部町');
ok($zip->set_number('6060816')->is_valid_number, '京都府京都市左京区下鴨松ノ木町');
ok($zip->set_number('6060817')->is_valid_number, '京都府京都市左京区下鴨西林町');
ok($zip->set_number('6060821')->is_valid_number, '京都府京都市左京区賀茂今井町');
ok($zip->set_number('6060822')->is_valid_number, '京都府京都市左京区賀茂半木町');
ok($zip->set_number('6060823')->is_valid_number, '京都府京都市左京区下鴨半木町');
ok($zip->set_number('6060824')->is_valid_number, '京都府京都市左京区下鴨東半木町');
ok($zip->set_number('6060825')->is_valid_number, '京都府京都市左京区下鴨西梅ノ木町');
ok($zip->set_number('6060826')->is_valid_number, '京都府京都市左京区下鴨西本町');
ok($zip->set_number('6060827')->is_valid_number, '京都府京都市左京区下鴨西半木町');
ok($zip->set_number('6060831')->is_valid_number, '京都府京都市左京区下鴨北園町');
ok($zip->set_number('6060832')->is_valid_number, '京都府京都市左京区下鴨萩ケ垣内町');
ok($zip->set_number('6060833')->is_valid_number, '京都府京都市左京区下鴨前萩町');
ok($zip->set_number('6060834')->is_valid_number, '京都府京都市左京区下鴨狗子田町');
ok($zip->set_number('6060835')->is_valid_number, '京都府京都市左京区下鴨神殿町');
ok($zip->set_number('6060836')->is_valid_number, '京都府京都市左京区下鴨梁田町');
ok($zip->set_number('6060837')->is_valid_number, '京都府京都市左京区下鴨夜光町');
ok($zip->set_number('6060841')->is_valid_number, '京都府京都市左京区下鴨南芝町');
ok($zip->set_number('6060842')->is_valid_number, '京都府京都市左京区下鴨北芝町');
ok($zip->set_number('6060843')->is_valid_number, '京都府京都市左京区下鴨水口町');
ok($zip->set_number('6060844')->is_valid_number, '京都府京都市左京区下鴨北茶ノ木町');
ok($zip->set_number('6060845')->is_valid_number, '京都府京都市左京区下鴨南茶ノ木町');
ok($zip->set_number('6060846')->is_valid_number, '京都府京都市左京区下鴨北野々神町');
ok($zip->set_number('6060847')->is_valid_number, '京都府京都市左京区下鴨南野々神町');
ok($zip->set_number('6060851')->is_valid_number, '京都府京都市左京区下鴨梅ノ木町');
ok($zip->set_number('6060852')->is_valid_number, '京都府京都市左京区下鴨東梅ノ木町');
ok($zip->set_number('6060853')->is_valid_number, '京都府京都市左京区下鴨岸本町');
ok($zip->set_number('6060854')->is_valid_number, '京都府京都市左京区下鴨東岸本町');
ok($zip->set_number('6060855')->is_valid_number, '京都府京都市左京区下鴨東塚本町');
ok($zip->set_number('6060856')->is_valid_number, '京都府京都市左京区下鴨塚本町');
ok($zip->set_number('6060861')->is_valid_number, '京都府京都市左京区下鴨西高木町');
ok($zip->set_number('6060862')->is_valid_number, '京都府京都市左京区下鴨本町');
ok($zip->set_number('6060863')->is_valid_number, '京都府京都市左京区下鴨東本町');
ok($zip->set_number('6060864')->is_valid_number, '京都府京都市左京区下鴨高木町');
ok($zip->set_number('6060865')->is_valid_number, '京都府京都市左京区下鴨東高木町');
ok($zip->set_number('6060866')->is_valid_number, '京都府京都市左京区下鴨東森ケ前町');
ok($zip->set_number('6060867')->is_valid_number, '京都府京都市左京区下鴨森ケ前町');
ok($zip->set_number('6060901')->is_valid_number, '京都府京都市左京区松ケ崎東桜木町');
ok($zip->set_number('6060902')->is_valid_number, '京都府京都市左京区松ケ崎桜木町');
ok($zip->set_number('6060903')->is_valid_number, '京都府京都市左京区松ケ崎西桜木町');
ok($zip->set_number('6060904')->is_valid_number, '京都府京都市左京区松ケ崎柳井田町');
ok($zip->set_number('6060905')->is_valid_number, '京都府京都市左京区松ケ崎杉ケ海道町');
ok($zip->set_number('6060906')->is_valid_number, '京都府京都市左京区松ケ崎中海道町');
ok($zip->set_number('6060907')->is_valid_number, '京都府京都市左京区松ケ崎村ケ内町');
ok($zip->set_number('6060911')->is_valid_number, '京都府京都市左京区松ケ崎泉川町');
ok($zip->set_number('6060912')->is_valid_number, '京都府京都市左京区松ケ崎呼返町');
ok($zip->set_number('6060913')->is_valid_number, '京都府京都市左京区松ケ崎芝本町');
ok($zip->set_number('6060914')->is_valid_number, '京都府京都市左京区松ケ崎今海道町');
ok($zip->set_number('6060915')->is_valid_number, '京都府京都市左京区松ケ崎六ノ坪町');
ok($zip->set_number('6060916')->is_valid_number, '京都府京都市左京区松ケ崎三反長町');
ok($zip->set_number('6060917')->is_valid_number, '京都府京都市左京区松ケ崎堂ノ上町');
ok($zip->set_number('6060921')->is_valid_number, '京都府京都市左京区松ケ崎平田町');
ok($zip->set_number('6060922')->is_valid_number, '京都府京都市左京区松ケ崎南池ノ内町');
ok($zip->set_number('6060923')->is_valid_number, '京都府京都市左京区松ケ崎総作町');
ok($zip->set_number('6060924')->is_valid_number, '京都府京都市左京区松ケ崎東池ノ内町');
ok($zip->set_number('6060925')->is_valid_number, '京都府京都市左京区松ケ崎林山');
ok($zip->set_number('6060926')->is_valid_number, '京都府京都市左京区松ケ崎中町');
ok($zip->set_number('6060927')->is_valid_number, '京都府京都市左京区松ケ崎西町');
ok($zip->set_number('6060931')->is_valid_number, '京都府京都市左京区松ケ崎井出ケ海道町');
ok($zip->set_number('6060932')->is_valid_number, '京都府京都市左京区松ケ崎西池ノ内町');
ok($zip->set_number('6060933')->is_valid_number, '京都府京都市左京区松ケ崎西山');
ok($zip->set_number('6060934')->is_valid_number, '京都府京都市左京区松ケ崎狐坂');
ok($zip->set_number('6060935')->is_valid_number, '京都府京都市左京区松ケ崎高山');
ok($zip->set_number('6060936')->is_valid_number, '京都府京都市左京区松ケ崎榎実ケ芝');
ok($zip->set_number('6060937')->is_valid_number, '京都府京都市左京区松ケ崎北裏町');
ok($zip->set_number('6060938')->is_valid_number, '京都府京都市左京区松ケ崎木燈籠町');
ok($zip->set_number('6060941')->is_valid_number, '京都府京都市左京区松ケ崎河原田町');
ok($zip->set_number('6060942')->is_valid_number, '京都府京都市左京区松ケ崎樋ノ上町');
ok($zip->set_number('6060943')->is_valid_number, '京都府京都市左京区松ケ崎東町');
ok($zip->set_number('6060944')->is_valid_number, '京都府京都市左京区松ケ崎御所ノ内町');
ok($zip->set_number('6060945')->is_valid_number, '京都府京都市左京区松ケ崎堀町');
ok($zip->set_number('6060946')->is_valid_number, '京都府京都市左京区松ケ崎東山');
ok($zip->set_number('6060947')->is_valid_number, '京都府京都市左京区松ケ崎井出ケ鼻町');
ok($zip->set_number('6060951')->is_valid_number, '京都府京都市左京区松ケ崎橋上町');
ok($zip->set_number('6060952')->is_valid_number, '京都府京都市左京区松ケ崎木ノ本町');
ok($zip->set_number('6060953')->is_valid_number, '京都府京都市左京区松ケ崎海尻町');
ok($zip->set_number('6060954')->is_valid_number, '京都府京都市左京区松ケ崎壱町田町');
ok($zip->set_number('6060955')->is_valid_number, '京都府京都市左京区松ケ崎雲路町');
ok($zip->set_number('6060956')->is_valid_number, '京都府京都市左京区松ケ崎鞍馬田町');
ok($zip->set_number('6060957')->is_valid_number, '京都府京都市左京区松ケ崎小脇町');
ok($zip->set_number('6060961')->is_valid_number, '京都府京都市左京区松ケ崎久土町');
ok($zip->set_number('6060962')->is_valid_number, '京都府京都市左京区松ケ崎御所海道町');
ok($zip->set_number('6060963')->is_valid_number, '京都府京都市左京区松ケ崎糺田町');
ok($zip->set_number('6060964')->is_valid_number, '京都府京都市左京区松ケ崎修理式町');
ok($zip->set_number('6060965')->is_valid_number, '京都府京都市左京区松ケ崎横縄手町');
ok($zip->set_number('6060966')->is_valid_number, '京都府京都市左京区松ケ崎正田町');
ok($zip->set_number('6060967')->is_valid_number, '京都府京都市左京区松ケ崎小竹薮町');
ok($zip->set_number('6068001')->is_valid_number, '京都府京都市左京区山端柳ケ坪町');
ok($zip->set_number('6068002')->is_valid_number, '京都府京都市左京区山端大城田町');
ok($zip->set_number('6068003')->is_valid_number, '京都府京都市左京区山端川原町');
ok($zip->set_number('6068004')->is_valid_number, '京都府京都市左京区山端川端町');
ok($zip->set_number('6068005')->is_valid_number, '京都府京都市左京区山端川岸町');
ok($zip->set_number('6068006')->is_valid_number, '京都府京都市左京区山端橋ノ本町');
ok($zip->set_number('6068007')->is_valid_number, '京都府京都市左京区山端壱町田町');
ok($zip->set_number('6068011')->is_valid_number, '京都府京都市左京区山端森本町');
ok($zip->set_number('6068012')->is_valid_number, '京都府京都市左京区山端滝ケ鼻町');
ok($zip->set_number('6068013')->is_valid_number, '京都府京都市左京区山端大君町');
ok($zip->set_number('6068014')->is_valid_number, '京都府京都市左京区山端大塚町');
ok($zip->set_number('6068021')->is_valid_number, '京都府京都市左京区修学院沖殿町');
ok($zip->set_number('6068022')->is_valid_number, '京都府京都市左京区修学院高部町');
ok($zip->set_number('6068023')->is_valid_number, '京都府京都市左京区修学院水上田町');
ok($zip->set_number('6068024')->is_valid_number, '京都府京都市左京区修学院千万田町');
ok($zip->set_number('6068025')->is_valid_number, '京都府京都市左京区修学院山ノ鼻町');
ok($zip->set_number('6068026')->is_valid_number, '京都府京都市左京区修学院川尻町');
ok($zip->set_number('6068027')->is_valid_number, '京都府京都市左京区修学院水川原町');
ok($zip->set_number('6068031')->is_valid_number, '京都府京都市左京区修学院西沮沢町');
ok($zip->set_number('6068032')->is_valid_number, '京都府京都市左京区修学院北沮沢町');
ok($zip->set_number('6068033')->is_valid_number, '京都府京都市左京区修学院山添町');
ok($zip->set_number('6068034')->is_valid_number, '京都府京都市左京区修学院桧峠町');
ok($zip->set_number('6068035')->is_valid_number, '京都府京都市左京区修学院守禅庵');
ok($zip->set_number('6068036')->is_valid_number, '京都府京都市左京区修学院開根坊町');
ok($zip->set_number('6068037')->is_valid_number, '京都府京都市左京区修学院大道町');
ok($zip->set_number('6068041')->is_valid_number, '京都府京都市左京区修学院仏者町');
ok($zip->set_number('6068042')->is_valid_number, '京都府京都市左京区修学院泉殿町');
ok($zip->set_number('6068043')->is_valid_number, '京都府京都市左京区修学院貝原町');
ok($zip->set_number('6068044')->is_valid_number, '京都府京都市左京区修学院馬場脇町');
ok($zip->set_number('6068045')->is_valid_number, '京都府京都市左京区修学院安養坊');
ok($zip->set_number('6068046')->is_valid_number, '京都府京都市左京区修学院室町');
ok($zip->set_number('6068047')->is_valid_number, '京都府京都市左京区修学院烏丸町');
ok($zip->set_number('6068051')->is_valid_number, '京都府京都市左京区修学院中新開');
ok($zip->set_number('6068052')->is_valid_number, '京都府京都市左京区修学院薮添');
ok($zip->set_number('6068053')->is_valid_number, '京都府京都市左京区修学院宮ノ前');
ok($zip->set_number('6068054')->is_valid_number, '京都府京都市左京区修学院山神町');
ok($zip->set_number('6068055')->is_valid_number, '京都府京都市左京区修学院高岸町');
ok($zip->set_number('6068056')->is_valid_number, '京都府京都市左京区修学院松本町');
ok($zip->set_number('6068057')->is_valid_number, '京都府京都市左京区修学院林ノ脇');
ok($zip->set_number('6068061')->is_valid_number, '京都府京都市左京区修学院宮ノ脇町');
ok($zip->set_number('6068062')->is_valid_number, '京都府京都市左京区修学院南代');
ok($zip->set_number('6068063')->is_valid_number, '京都府京都市左京区修学院後安堂');
ok($zip->set_number('6068064')->is_valid_number, '京都府京都市左京区修学院辻ノ田町');
ok($zip->set_number('6068065')->is_valid_number, '京都府京都市左京区修学院月輪寺町');
ok($zip->set_number('6068071')->is_valid_number, '京都府京都市左京区修学院狭間町');
ok($zip->set_number('6068072')->is_valid_number, '京都府京都市左京区修学院登リ内町');
ok($zip->set_number('6068073')->is_valid_number, '京都府京都市左京区修学院茶屋ノ前町');
ok($zip->set_number('6068074')->is_valid_number, '京都府京都市左京区修学院石掛町');
ok($zip->set_number('6068075')->is_valid_number, '京都府京都市左京区修学院坪江町');
ok($zip->set_number('6068081')->is_valid_number, '京都府京都市左京区修学院大林町');
ok($zip->set_number('6068082')->is_valid_number, '京都府京都市左京区修学院鹿ノ下町');
ok($zip->set_number('6068083')->is_valid_number, '京都府京都市左京区修学院犬塚町');
ok($zip->set_number('6068084')->is_valid_number, '京都府京都市左京区修学院薬師堂町');
ok($zip->set_number('6068085')->is_valid_number, '京都府京都市左京区修学院中林町');
ok($zip->set_number('6068086')->is_valid_number, '京都府京都市左京区修学院十権寺町');
ok($zip->set_number('6068101')->is_valid_number, '京都府京都市左京区高野蓼原町');
ok($zip->set_number('6068102')->is_valid_number, '京都府京都市左京区高野清水町');
ok($zip->set_number('6068103')->is_valid_number, '京都府京都市左京区高野西開町');
ok($zip->set_number('6068104')->is_valid_number, '京都府京都市左京区高野竹屋町');
ok($zip->set_number('6068105')->is_valid_number, '京都府京都市左京区高野上竹屋町');
ok($zip->set_number('6068106')->is_valid_number, '京都府京都市左京区高野玉岡町');
ok($zip->set_number('6068107')->is_valid_number, '京都府京都市左京区高野東開町');
ok($zip->set_number('6068111')->is_valid_number, '京都府京都市左京区高野泉町');
ok($zip->set_number('6068112')->is_valid_number, '京都府京都市左京区一乗寺西杉ノ宮町');
ok($zip->set_number('6068113')->is_valid_number, '京都府京都市左京区一乗寺東杉ノ宮町');
ok($zip->set_number('6068114')->is_valid_number, '京都府京都市左京区一乗寺北大丸町');
ok($zip->set_number('6068115')->is_valid_number, '京都府京都市左京区一乗寺里ノ西町');
ok($zip->set_number('6068116')->is_valid_number, '京都府京都市左京区一乗寺宮ノ東町');
ok($zip->set_number('6068117')->is_valid_number, '京都府京都市左京区一乗寺里ノ前町');
ok($zip->set_number('6068121')->is_valid_number, '京都府京都市左京区一乗寺青城町');
ok($zip->set_number('6068122')->is_valid_number, '京都府京都市左京区一乗寺東閉川原町');
ok($zip->set_number('6068123')->is_valid_number, '京都府京都市左京区一乗寺西閉川原町');
ok($zip->set_number('6068124')->is_valid_number, '京都府京都市左京区一乗寺松田町');
ok($zip->set_number('6068125')->is_valid_number, '京都府京都市左京区一乗寺清水町');
ok($zip->set_number('6068126')->is_valid_number, '京都府京都市左京区一乗寺向畑町');
ok($zip->set_number('6068127')->is_valid_number, '京都府京都市左京区一乗寺西浦畑町');
ok($zip->set_number('6068131')->is_valid_number, '京都府京都市左京区一乗寺稲荷町');
ok($zip->set_number('6068132')->is_valid_number, '京都府京都市左京区一乗寺馬場町');
ok($zip->set_number('6068133')->is_valid_number, '京都府京都市左京区一乗寺月輪寺町');
ok($zip->set_number('6068134')->is_valid_number, '京都府京都市左京区一乗寺竹ノ内町');
ok($zip->set_number('6068135')->is_valid_number, '京都府京都市左京区一乗寺水掛町');
ok($zip->set_number('6068136')->is_valid_number, '京都府京都市左京区一乗寺東浦町');
ok($zip->set_number('6068141')->is_valid_number, '京都府京都市左京区一乗寺釈迦堂町');
ok($zip->set_number('6068142')->is_valid_number, '京都府京都市左京区一乗寺燈籠本町');
ok($zip->set_number('6068143')->is_valid_number, '京都府京都市左京区一乗寺堀ノ内町');
ok($zip->set_number('6068144')->is_valid_number, '京都府京都市左京区一乗寺堂ノ前町');
ok($zip->set_number('6068145')->is_valid_number, '京都府京都市左京区一乗寺葉山町');
ok($zip->set_number('6068146')->is_valid_number, '京都府京都市左京区一乗寺病ダレ');
ok($zip->set_number('6068147')->is_valid_number, '京都府京都市左京区一乗寺小谷町');
ok($zip->set_number('6068151')->is_valid_number, '京都府京都市左京区一乗寺花ノ木町');
ok($zip->set_number('6068152')->is_valid_number, '京都府京都市左京区一乗寺下リ松町');
ok($zip->set_number('6068153')->is_valid_number, '京都府京都市左京区一乗寺谷田町');
ok($zip->set_number('6068154')->is_valid_number, '京都府京都市左京区一乗寺門口町');
ok($zip->set_number('6068155')->is_valid_number, '京都府京都市左京区一乗寺薬師堂町');
ok($zip->set_number('6068156')->is_valid_number, '京都府京都市左京区一乗寺松原町');
ok($zip->set_number('6068157')->is_valid_number, '京都府京都市左京区一乗寺才形町');
ok($zip->set_number('6068158')->is_valid_number, '京都府京都市左京区一乗寺大谷');
ok($zip->set_number('6068161')->is_valid_number, '京都府京都市左京区一乗寺木ノ本町');
ok($zip->set_number('6068162')->is_valid_number, '京都府京都市左京区一乗寺御祭田町');
ok($zip->set_number('6068163')->is_valid_number, '京都府京都市左京区一乗寺中ノ田町');
ok($zip->set_number('6068164')->is_valid_number, '京都府京都市左京区一乗寺出口町');
ok($zip->set_number('6068165')->is_valid_number, '京都府京都市左京区一乗寺野田町');
ok($zip->set_number('6068166')->is_valid_number, '京都府京都市左京区一乗寺庵野町');
ok($zip->set_number('6068167')->is_valid_number, '京都府京都市左京区一乗寺樋ノ口町');
ok($zip->set_number('6068171')->is_valid_number, '京都府京都市左京区一乗寺西水干町');
ok($zip->set_number('6068172')->is_valid_number, '京都府京都市左京区一乗寺河原田町');
ok($zip->set_number('6068173')->is_valid_number, '京都府京都市左京区一乗寺梅ノ木町');
ok($zip->set_number('6068174')->is_valid_number, '京都府京都市左京区一乗寺染殿町');
ok($zip->set_number('6068175')->is_valid_number, '京都府京都市左京区一乗寺築田町');
ok($zip->set_number('6068176')->is_valid_number, '京都府京都市左京区一乗寺塚本町');
ok($zip->set_number('6068177')->is_valid_number, '京都府京都市左京区一乗寺東水干町');
ok($zip->set_number('6068181')->is_valid_number, '京都府京都市左京区一乗寺地蔵本町');
ok($zip->set_number('6068182')->is_valid_number, '京都府京都市左京区一乗寺赤ノ宮町');
ok($zip->set_number('6068183')->is_valid_number, '京都府京都市左京区一乗寺大新開町');
ok($zip->set_number('6068184')->is_valid_number, '京都府京都市左京区一乗寺払殿町');
ok($zip->set_number('6068185')->is_valid_number, '京都府京都市左京区一乗寺高槻町');
ok($zip->set_number('6068186')->is_valid_number, '京都府京都市左京区一乗寺南大丸町');
ok($zip->set_number('6068187')->is_valid_number, '京都府京都市左京区一乗寺大原田町');
ok($zip->set_number('6068201')->is_valid_number, '京都府京都市左京区田中玄京町');
ok($zip->set_number('6068202')->is_valid_number, '京都府京都市左京区田中大堰町');
ok($zip->set_number('6068203')->is_valid_number, '京都府京都市左京区田中関田町');
ok($zip->set_number('6068204')->is_valid_number, '京都府京都市左京区田中下柳町');
ok($zip->set_number('6068205')->is_valid_number, '京都府京都市左京区田中上柳町');
ok($zip->set_number('6068206')->is_valid_number, '京都府京都市左京区田中馬場町');
ok($zip->set_number('6068211')->is_valid_number, '京都府京都市左京区田中西大久保町');
ok($zip->set_number('6068212')->is_valid_number, '京都府京都市左京区田中里ノ内町');
ok($zip->set_number('6068213')->is_valid_number, '京都府京都市左京区田中野神町');
ok($zip->set_number('6068214')->is_valid_number, '京都府京都市左京区田中南大久保町');
ok($zip->set_number('6068215')->is_valid_number, '京都府京都市左京区田中上玄京町');
ok($zip->set_number('6068216')->is_valid_number, '京都府京都市左京区田中南西浦町');
ok($zip->set_number('6068217')->is_valid_number, '京都府京都市左京区田中西浦町');
ok($zip->set_number('6068221')->is_valid_number, '京都府京都市左京区田中西樋ノ口町');
ok($zip->set_number('6068222')->is_valid_number, '京都府京都市左京区田中樋ノ口町');
ok($zip->set_number('6068223')->is_valid_number, '京都府京都市左京区田中東樋ノ口町');
ok($zip->set_number('6068224')->is_valid_number, '京都府京都市左京区北白川追分町');
ok($zip->set_number('6068225')->is_valid_number, '京都府京都市左京区田中門前町');
ok($zip->set_number('6068226')->is_valid_number, '京都府京都市左京区田中飛鳥井町');
ok($zip->set_number('6068227')->is_valid_number, '京都府京都市左京区田中里ノ前町');
ok($zip->set_number('6068231')->is_valid_number, '京都府京都市左京区田中上古川町');
ok($zip->set_number('6068232')->is_valid_number, '京都府京都市左京区田中古川町');
ok($zip->set_number('6068233')->is_valid_number, '京都府京都市左京区田中北春菜町');
ok($zip->set_number('6068234')->is_valid_number, '京都府京都市左京区田中春菜町');
ok($zip->set_number('6068235')->is_valid_number, '京都府京都市左京区田中西春菜町');
ok($zip->set_number('6068236')->is_valid_number, '京都府京都市左京区田中大久保町');
ok($zip->set_number('6068237')->is_valid_number, '京都府京都市左京区田中上大久保町');
ok($zip->set_number('6068241')->is_valid_number, '京都府京都市左京区田中西高原町');
ok($zip->set_number('6068242')->is_valid_number, '京都府京都市左京区田中高原町');
ok($zip->set_number('6068243')->is_valid_number, '京都府京都市左京区田中東高原町');
ok($zip->set_number('6068244')->is_valid_number, '京都府京都市左京区北白川東平井町');
ok($zip->set_number('6068245')->is_valid_number, '京都府京都市左京区北白川平井町');
ok($zip->set_number('6068246')->is_valid_number, '京都府京都市左京区北白川西平井町');
ok($zip->set_number('6068247')->is_valid_number, '京都府京都市左京区田中東春菜町');
ok($zip->set_number('6068251')->is_valid_number, '京都府京都市左京区北白川東伊織町');
ok($zip->set_number('6068252')->is_valid_number, '京都府京都市左京区北白川上終町');
ok($zip->set_number('6068253')->is_valid_number, '京都府京都市左京区北白川瀬ノ内町');
ok($zip->set_number('6068254')->is_valid_number, '京都府京都市左京区北白川東瀬ノ内町');
ok($zip->set_number('6068255')->is_valid_number, '京都府京都市左京区北白川西瀬ノ内町');
ok($zip->set_number('6068256')->is_valid_number, '京都府京都市左京区北白川伊織町');
ok($zip->set_number('6068257')->is_valid_number, '京都府京都市左京区北白川西伊織町');
ok($zip->set_number('6068261')->is_valid_number, '京都府京都市左京区北白川西蔦町');
ok($zip->set_number('6068262')->is_valid_number, '京都府京都市左京区北白川蔦町');
ok($zip->set_number('6068263')->is_valid_number, '京都府京都市左京区北白川東蔦町');
ok($zip->set_number('6068264')->is_valid_number, '京都府京都市左京区北白川小倉町');
ok($zip->set_number('6068265')->is_valid_number, '京都府京都市左京区北白川東小倉町');
ok($zip->set_number('6068266')->is_valid_number, '京都府京都市左京区北白川久保田町');
ok($zip->set_number('6068267')->is_valid_number, '京都府京都市左京区北白川西町');
ok($zip->set_number('6068271')->is_valid_number, '京都府京都市左京区北白川瓜生山町');
ok($zip->set_number('6068272')->is_valid_number, '京都府京都市左京区北白川山田町');
ok($zip->set_number('6068273')->is_valid_number, '京都府京都市左京区北白川山ノ元町');
ok($zip->set_number('6068274')->is_valid_number, '京都府京都市左京区北白川大堂町');
ok($zip->set_number('6068275')->is_valid_number, '京都府京都市左京区北白川上別当町');
ok($zip->set_number('6068276')->is_valid_number, '京都府京都市左京区北白川別当町');
ok($zip->set_number('6068277')->is_valid_number, '京都府京都市左京区北白川堂ノ前町');
ok($zip->set_number('6068281')->is_valid_number, '京都府京都市左京区北白川丸山町');
ok($zip->set_number('6068282')->is_valid_number, '京都府京都市左京区北白川外山町');
ok($zip->set_number('6068283')->is_valid_number, '京都府京都市左京区北白川仕伏町');
ok($zip->set_number('6068284')->is_valid_number, '京都府京都市左京区北白川下池田町');
ok($zip->set_number('6068285')->is_valid_number, '京都府京都市左京区北白川東久保田町');
ok($zip->set_number('6068286')->is_valid_number, '京都府京都市左京区北白川下別当町');
ok($zip->set_number('6068287')->is_valid_number, '京都府京都市左京区北白川上池田町');
ok($zip->set_number('6068291')->is_valid_number, '京都府京都市左京区北白川岩坂町');
ok($zip->set_number('6068292')->is_valid_number, '京都府京都市左京区北白川重石町');
ok($zip->set_number('6068293')->is_valid_number, '京都府京都市左京区北白川琵琶町');
ok($zip->set_number('6068294')->is_valid_number, '京都府京都市左京区北白川地蔵谷町');
ok($zip->set_number('6068295')->is_valid_number, '京都府京都市左京区北白川清沢口町');
ok($zip->set_number('6068301')->is_valid_number, '京都府京都市左京区吉田泉殿町');
ok($zip->set_number('6068302')->is_valid_number, '京都府京都市左京区吉田牛ノ宮町');
ok($zip->set_number('6068303')->is_valid_number, '京都府京都市左京区吉田橘町');
ok($zip->set_number('6068304')->is_valid_number, '京都府京都市左京区吉田下阿達町');
ok($zip->set_number('6068305')->is_valid_number, '京都府京都市左京区吉田河原町');
ok($zip->set_number('6068306')->is_valid_number, '京都府京都市左京区吉田中阿達町');
ok($zip->set_number('6068307')->is_valid_number, '京都府京都市左京区吉田上阿達町');
ok($zip->set_number('6068311')->is_valid_number, '京都府京都市左京区吉田神楽岡町');
ok($zip->set_number('6068312')->is_valid_number, '京都府京都市左京区吉田上大路町');
ok($zip->set_number('6068313')->is_valid_number, '京都府京都市左京区吉田中大路町');
ok($zip->set_number('6068314')->is_valid_number, '京都府京都市左京区吉田下大路町');
ok($zip->set_number('6068315')->is_valid_number, '京都府京都市左京区吉田近衛町');
ok($zip->set_number('6068316')->is_valid_number, '京都府京都市左京区吉田二本松町');
ok($zip->set_number('6068317')->is_valid_number, '京都府京都市左京区吉田本町');
ok($zip->set_number('6068321')->is_valid_number, '京都府京都市左京区岡崎東福ノ川町');
ok($zip->set_number('6068322')->is_valid_number, '京都府京都市左京区岡崎入江町');
ok($zip->set_number('6068323')->is_valid_number, '京都府京都市左京区聖護院円頓美町');
ok($zip->set_number('6068324')->is_valid_number, '京都府京都市左京区聖護院中町');
ok($zip->set_number('6068325')->is_valid_number, '京都府京都市左京区聖護院東町');
ok($zip->set_number('6068326')->is_valid_number, '京都府京都市左京区岡崎西福ノ川町');
ok($zip->set_number('6068331')->is_valid_number, '京都府京都市左京区黒谷町');
ok($zip->set_number('6068332')->is_valid_number, '京都府京都市左京区岡崎東天王町');
ok($zip->set_number('6068333')->is_valid_number, '京都府京都市左京区岡崎法勝寺町');
ok($zip->set_number('6068334')->is_valid_number, '京都府京都市左京区岡崎南御所町');
ok($zip->set_number('6068335')->is_valid_number, '京都府京都市左京区岡崎天王町');
ok($zip->set_number('6068336')->is_valid_number, '京都府京都市左京区岡崎北御所町');
ok($zip->set_number('6068341')->is_valid_number, '京都府京都市左京区岡崎西天王町');
ok($zip->set_number('6068342')->is_valid_number, '京都府京都市左京区岡崎最勝寺町');
ok($zip->set_number('6068343')->is_valid_number, '京都府京都市左京区岡崎成勝寺町');
ok($zip->set_number('6068344')->is_valid_number, '京都府京都市左京区岡崎円勝寺町');
ok($zip->set_number('6068345')->is_valid_number, '京都府京都市左京区東門前町');
ok($zip->set_number('6068346')->is_valid_number, '京都府京都市左京区南門前町');
ok($zip->set_number('6068351')->is_valid_number, '京都府京都市左京区岡崎徳成町');
ok($zip->set_number('6068352')->is_valid_number, '京都府京都市左京区北門前町');
ok($zip->set_number('6068353')->is_valid_number, '京都府京都市左京区正往寺町');
ok($zip->set_number('6068354')->is_valid_number, '京都府京都市左京区頭町');
ok($zip->set_number('6068355')->is_valid_number, '京都府京都市左京区新東洞院町');
ok($zip->set_number('6068356')->is_valid_number, '京都府京都市左京区石原町');
ok($zip->set_number('6068357')->is_valid_number, '京都府京都市左京区聖護院蓮華蔵町');
ok($zip->set_number('6068361')->is_valid_number, '京都府京都市左京区福本町');
ok($zip->set_number('6068362')->is_valid_number, '京都府京都市左京区法皇寺町');
ok($zip->set_number('6068363')->is_valid_number, '京都府京都市左京区和国町');
ok($zip->set_number('6068364')->is_valid_number, '京都府京都市左京区菊鉾町');
ok($zip->set_number('6068365')->is_valid_number, '京都府京都市左京区讃州寺町');
ok($zip->set_number('6068366')->is_valid_number, '京都府京都市左京区超勝寺門前町');
ok($zip->set_number('6068371')->is_valid_number, '京都府京都市左京区秋築町');
ok($zip->set_number('6068372')->is_valid_number, '京都府京都市左京区吉永町');
ok($zip->set_number('6068373')->is_valid_number, '京都府京都市左京区杉本町');
ok($zip->set_number('6068374')->is_valid_number, '京都府京都市左京区難波町');
ok($zip->set_number('6068375')->is_valid_number, '京都府京都市左京区新車屋町');
ok($zip->set_number('6068376')->is_valid_number, '京都府京都市左京区大菊町');
ok($zip->set_number('6068381')->is_valid_number, '京都府京都市左京区中川町');
ok($zip->set_number('6068382')->is_valid_number, '京都府京都市左京区大文字町');
ok($zip->set_number('6068383')->is_valid_number, '京都府京都市左京区新先斗町');
ok($zip->set_number('6068384')->is_valid_number, '京都府京都市左京区新生洲町');
ok($zip->set_number('6068385')->is_valid_number, '京都府京都市左京区孫橋町');
ok($zip->set_number('6068386')->is_valid_number, '京都府京都市左京区新丸太町');
ok($zip->set_number('6068387')->is_valid_number, '京都府京都市左京区法林寺門前町');
ok($zip->set_number('6068391')->is_valid_number, '京都府京都市左京区聖護院西町');
ok($zip->set_number('6068392')->is_valid_number, '京都府京都市左京区聖護院山王町');
ok($zip->set_number('6068393')->is_valid_number, '京都府京都市左京区東竹屋町');
ok($zip->set_number('6068394')->is_valid_number, '京都府京都市左京区聖護院東寺領町');
ok($zip->set_number('6068395')->is_valid_number, '京都府京都市左京区東丸太町');
ok($zip->set_number('6068396')->is_valid_number, '京都府京都市左京区下堤町');
ok($zip->set_number('6068397')->is_valid_number, '京都府京都市左京区聖護院川原町');
ok($zip->set_number('6068401')->is_valid_number, '京都府京都市左京区浄土寺小山町');
ok($zip->set_number('6068402')->is_valid_number, '京都府京都市左京区銀閣寺町');
ok($zip->set_number('6068403')->is_valid_number, '京都府京都市左京区浄土寺南田町');
ok($zip->set_number('6068404')->is_valid_number, '京都府京都市左京区浄土寺下南田町');
ok($zip->set_number('6068405')->is_valid_number, '京都府京都市左京区浄土寺上南田町');
ok($zip->set_number('6068406')->is_valid_number, '京都府京都市左京区浄土寺石橋町');
ok($zip->set_number('6068407')->is_valid_number, '京都府京都市左京区銀閣寺前町');
ok($zip->set_number('6068411')->is_valid_number, '京都府京都市左京区浄土寺東田町');
ok($zip->set_number('6068412')->is_valid_number, '京都府京都市左京区浄土寺馬場町');
ok($zip->set_number('6068413')->is_valid_number, '京都府京都市左京区浄土寺下馬場町');
ok($zip->set_number('6068414')->is_valid_number, '京都府京都市左京区浄土寺真如町');
ok($zip->set_number('6068415')->is_valid_number, '京都府京都市左京区岡崎真如堂前町');
ok($zip->set_number('6068416')->is_valid_number, '京都府京都市左京区浄土寺上馬場町');
ok($zip->set_number('6068417')->is_valid_number, '京都府京都市左京区浄土寺西田町');
ok($zip->set_number('6068421')->is_valid_number, '京都府京都市左京区鹿ケ谷法然院町');
ok($zip->set_number('6068422')->is_valid_number, '京都府京都市左京区鹿ケ谷御所ノ段町');
ok($zip->set_number('6068423')->is_valid_number, '京都府京都市左京区鹿ケ谷桜谷町');
ok($zip->set_number('6068424')->is_valid_number, '京都府京都市左京区鹿ケ谷宮ノ前町');
ok($zip->set_number('6068425')->is_valid_number, '京都府京都市左京区鹿ケ谷西寺ノ前町');
ok($zip->set_number('6068426')->is_valid_number, '京都府京都市左京区鹿ケ谷寺ノ前町');
ok($zip->set_number('6068427')->is_valid_number, '京都府京都市左京区鹿ケ谷法然院西町');
ok($zip->set_number('6068428')->is_valid_number, '京都府京都市左京区鹿ケ谷栗木谷町');
ok($zip->set_number('6068431')->is_valid_number, '京都府京都市左京区鹿ケ谷下宮ノ前町');
ok($zip->set_number('6068432')->is_valid_number, '京都府京都市左京区鹿ケ谷高岸町');
ok($zip->set_number('6068433')->is_valid_number, '京都府京都市左京区永観堂西町');
ok($zip->set_number('6068434')->is_valid_number, '京都府京都市左京区南禅寺下河原町');
ok($zip->set_number('6068435')->is_valid_number, '京都府京都市左京区南禅寺福地町');
ok($zip->set_number('6068436')->is_valid_number, '京都府京都市左京区粟田口鳥居町');
ok($zip->set_number('6068437')->is_valid_number, '京都府京都市左京区南禅寺草川町');
ok($zip->set_number('6068441')->is_valid_number, '京都府京都市左京区鹿ケ谷徳善谷町');
ok($zip->set_number('6068442')->is_valid_number, '京都府京都市左京区鹿ケ谷大黒谷町');
ok($zip->set_number('6068443')->is_valid_number, '京都府京都市左京区粟田口山下町');
ok($zip->set_number('6068444')->is_valid_number, '京都府京都市左京区若王子町');
ok($zip->set_number('6068445')->is_valid_number, '京都府京都市左京区永観堂町');
ok($zip->set_number('6068446')->is_valid_number, '京都府京都市左京区南禅寺北ノ坊町');
ok($zip->set_number('6068447')->is_valid_number, '京都府京都市左京区鹿ケ谷上宮ノ前町');
ok($zip->set_number('6068451')->is_valid_number, '京都府京都市左京区北白川中山町');
ok($zip->set_number('6068452')->is_valid_number, '京都府京都市左京区粟田口如意ケ嶽町');
ok($zip->set_number('6068453')->is_valid_number, '京都府京都市左京区北白川南ケ原町');
ok($zip->set_number('6068454')->is_valid_number, '京都府京都市左京区北白川向ケ谷町');
ok($zip->set_number('6068455')->is_valid_number, '京都府京都市左京区北白川小亀谷町');
ok($zip->set_number('6070000')->is_valid_number, '京都府京都市山科区以下に掲載がない場合');
ok($zip->set_number('6078001')->is_valid_number, '京都府京都市山科区安朱毘沙門堂町');
ok($zip->set_number('6078002')->is_valid_number, '京都府京都市山科区安朱東谷');
ok($zip->set_number('6078003')->is_valid_number, '京都府京都市山科区安朱稲荷山町');
ok($zip->set_number('6078004')->is_valid_number, '京都府京都市山科区安朱屋敷町');
ok($zip->set_number('6078005')->is_valid_number, '京都府京都市山科区安朱堂ノ後町');
ok($zip->set_number('6078006')->is_valid_number, '京都府京都市山科区安朱馬場ノ東町');
ok($zip->set_number('6078007')->is_valid_number, '京都府京都市山科区安朱馬場ノ西町');
ok($zip->set_number('6078008')->is_valid_number, '京都府京都市山科区安朱東海道町');
ok($zip->set_number('6078009')->is_valid_number, '京都府京都市山科区安朱北屋敷町');
ok($zip->set_number('6078011')->is_valid_number, '京都府京都市山科区安朱南屋敷町');
ok($zip->set_number('6078012')->is_valid_number, '京都府京都市山科区安朱桟敷町');
ok($zip->set_number('6078013')->is_valid_number, '京都府京都市山科区安朱中小路町');
ok($zip->set_number('6078014')->is_valid_number, '京都府京都市山科区安朱山田');
ok($zip->set_number('6078015')->is_valid_number, '京都府京都市山科区安朱山川町');
ok($zip->set_number('6078016')->is_valid_number, '京都府京都市山科区安朱中溝町');
ok($zip->set_number('6078017')->is_valid_number, '京都府京都市山科区安朱川向町');
ok($zip->set_number('6078018')->is_valid_number, '京都府京都市山科区安朱奥ノ田');
ok($zip->set_number('6078021')->is_valid_number, '京都府京都市山科区四ノ宮行者谷');
ok($zip->set_number('6078022')->is_valid_number, '京都府京都市山科区四ノ宮小金塚');
ok($zip->set_number('6078023')->is_valid_number, '京都府京都市山科区四ノ宮新開畑');
ok($zip->set_number('6078024')->is_valid_number, '京都府京都市山科区四ノ宮熊ケ谷');
ok($zip->set_number('6078025')->is_valid_number, '京都府京都市山科区四ノ宮柳山町');
ok($zip->set_number('6078026')->is_valid_number, '京都府京都市山科区四ノ宮山田町');
ok($zip->set_number('6078027')->is_valid_number, '京都府京都市山科区四ノ宮川原町');
ok($zip->set_number('6078028')->is_valid_number, '京都府京都市山科区四ノ宮岩久保町');
ok($zip->set_number('6078029')->is_valid_number, '京都府京都市山科区四ノ宮大将軍町');
ok($zip->set_number('6078031')->is_valid_number, '京都府京都市山科区四ノ宮鎌手町');
ok($zip->set_number('6078032')->is_valid_number, '京都府京都市山科区四ノ宮奈良野町');
ok($zip->set_number('6078033')->is_valid_number, '京都府京都市山科区四ノ宮芝畑町');
ok($zip->set_number('6078034')->is_valid_number, '京都府京都市山科区四ノ宮泓');
ok($zip->set_number('6078035')->is_valid_number, '京都府京都市山科区四ノ宮神田町');
ok($zip->set_number('6078041')->is_valid_number, '京都府京都市山科区四ノ宮垣ノ内町');
ok($zip->set_number('6078042')->is_valid_number, '京都府京都市山科区四ノ宮南河原町');
ok($zip->set_number('6078043')->is_valid_number, '京都府京都市山科区四ノ宮中在寺町');
ok($zip->set_number('6078044')->is_valid_number, '京都府京都市山科区四ノ宮泉水町');
ok($zip->set_number('6078045')->is_valid_number, '京都府京都市山科区四ノ宮堂ノ後町');
ok($zip->set_number('6078051')->is_valid_number, '京都府京都市山科区髭茶屋桃燈町');
ok($zip->set_number('6078052')->is_valid_number, '京都府京都市山科区髭茶屋屋敷町');
ok($zip->set_number('6078061')->is_valid_number, '京都府京都市山科区音羽草田町');
ok($zip->set_number('6078062')->is_valid_number, '京都府京都市山科区音羽珍事町');
ok($zip->set_number('6078063')->is_valid_number, '京都府京都市山科区音羽平林町');
ok($zip->set_number('6078064')->is_valid_number, '京都府京都市山科区音羽八ノ坪');
ok($zip->set_number('6078065')->is_valid_number, '京都府京都市山科区音羽山等地');
ok($zip->set_number('6078066')->is_valid_number, '京都府京都市山科区音羽森廻り町');
ok($zip->set_number('6078067')->is_valid_number, '京都府京都市山科区音羽前田町');
ok($zip->set_number('6078068')->is_valid_number, '京都府京都市山科区音羽稲芝');
ok($zip->set_number('6078069')->is_valid_number, '京都府京都市山科区音羽中芝町');
ok($zip->set_number('6078071')->is_valid_number, '京都府京都市山科区音羽千本町');
ok($zip->set_number('6078072')->is_valid_number, '京都府京都市山科区音羽伊勢宿町');
ok($zip->set_number('6078073')->is_valid_number, '京都府京都市山科区音羽西林');
ok($zip->set_number('6078074')->is_valid_number, '京都府京都市山科区音羽乙出町');
ok($zip->set_number('6078075')->is_valid_number, '京都府京都市山科区音羽野田町');
ok($zip->set_number('6078076')->is_valid_number, '京都府京都市山科区音羽役出町');
ok($zip->set_number('6078077')->is_valid_number, '京都府京都市山科区音羽沢町');
ok($zip->set_number('6078078')->is_valid_number, '京都府京都市山科区音羽初田町');
ok($zip->set_number('6078079')->is_valid_number, '京都府京都市山科区音羽前出町');
ok($zip->set_number('6078080')->is_valid_number, '京都府京都市山科区竹鼻竹ノ街道町');
ok($zip->set_number('6078081')->is_valid_number, '京都府京都市山科区竹鼻外田町');
ok($zip->set_number('6078082')->is_valid_number, '京都府京都市山科区竹鼻扇町');
ok($zip->set_number('6078083')->is_valid_number, '京都府京都市山科区竹鼻木ノ本町');
ok($zip->set_number('6078084')->is_valid_number, '京都府京都市山科区竹鼻立原町');
ok($zip->set_number('6078085')->is_valid_number, '京都府京都市山科区竹鼻堂ノ前町');
ok($zip->set_number('6078086')->is_valid_number, '京都府京都市山科区竹鼻四丁野町');
ok($zip->set_number('6078087')->is_valid_number, '京都府京都市山科区竹鼻サイカシ町');
ok($zip->set_number('6078088')->is_valid_number, '京都府京都市山科区竹鼻地蔵寺南町');
ok($zip->set_number('6078089')->is_valid_number, '京都府京都市山科区竹鼻西ノ口町');
ok($zip->set_number('6078091')->is_valid_number, '京都府京都市山科区八軒屋敷町');
ok($zip->set_number('6078101')->is_valid_number, '京都府京都市山科区小山神無森町');
ok($zip->set_number('6078102')->is_valid_number, '京都府京都市山科区小山下ノ池');
ok($zip->set_number('6078103')->is_valid_number, '京都府京都市山科区小山一石畑');
ok($zip->set_number('6078104')->is_valid_number, '京都府京都市山科区小山谷田町');
ok($zip->set_number('6078105')->is_valid_number, '京都府京都市山科区小山松原畑町');
ok($zip->set_number('6078106')->is_valid_number, '京都府京都市山科区小山御坊ノ内町');
ok($zip->set_number('6078107')->is_valid_number, '京都府京都市山科区小山小川町');
ok($zip->set_number('6078108')->is_valid_number, '京都府京都市山科区小山中島町');
ok($zip->set_number('6078109')->is_valid_number, '京都府京都市山科区小山西御所町');
ok($zip->set_number('6078111')->is_valid_number, '京都府京都市山科区小山南溝町');
ok($zip->set_number('6078112')->is_valid_number, '京都府京都市山科区小山中ノ川町');
ok($zip->set_number('6078113')->is_valid_number, '京都府京都市山科区小山北溝町');
ok($zip->set_number('6078114')->is_valid_number, '京都府京都市山科区小山姫子町');
ok($zip->set_number('6078115')->is_valid_number, '京都府京都市山科区小山北林町');
ok($zip->set_number('6078116')->is_valid_number, '京都府京都市山科区小山鎮守町');
ok($zip->set_number('6078121')->is_valid_number, '京都府京都市山科区大塚向畑町');
ok($zip->set_number('6078122')->is_valid_number, '京都府京都市山科区大塚高岩');
ok($zip->set_number('6078123')->is_valid_number, '京都府京都市山科区大塚大岩');
ok($zip->set_number('6078124')->is_valid_number, '京都府京都市山科区大塚檀ノ浦');
ok($zip->set_number('6078125')->is_valid_number, '京都府京都市山科区大塚西浦町');
ok($zip->set_number('6078126')->is_valid_number, '京都府京都市山科区大塚元屋敷町');
ok($zip->set_number('6078131')->is_valid_number, '京都府京都市山科区大塚南溝町');
ok($zip->set_number('6078132')->is_valid_number, '京都府京都市山科区大塚森町');
ok($zip->set_number('6078133')->is_valid_number, '京都府京都市山科区大塚中溝');
ok($zip->set_number('6078134')->is_valid_number, '京都府京都市山科区大塚北溝町');
ok($zip->set_number('6078135')->is_valid_number, '京都府京都市山科区大塚野溝町');
ok($zip->set_number('6078136')->is_valid_number, '京都府京都市山科区大塚丹田');
ok($zip->set_number('6078141')->is_valid_number, '京都府京都市山科区東野北井ノ上町');
ok($zip->set_number('6078142')->is_valid_number, '京都府京都市山科区東野中井ノ上町');
ok($zip->set_number('6078143')->is_valid_number, '京都府京都市山科区東野南井ノ上町');
ok($zip->set_number('6078144')->is_valid_number, '京都府京都市山科区東野井ノ上町');
ok($zip->set_number('6078145')->is_valid_number, '京都府京都市山科区東野八反畑町');
ok($zip->set_number('6078146')->is_valid_number, '京都府京都市山科区東野舞台町');
ok($zip->set_number('6078147')->is_valid_number, '京都府京都市山科区東野森野町');
ok($zip->set_number('6078151')->is_valid_number, '京都府京都市山科区東野竹田');
ok($zip->set_number('6078152')->is_valid_number, '京都府京都市山科区東野八代');
ok($zip->set_number('6078153')->is_valid_number, '京都府京都市山科区東野百拍子町');
ok($zip->set_number('6078154')->is_valid_number, '京都府京都市山科区東野門口町');
ok($zip->set_number('6078155')->is_valid_number, '京都府京都市山科区東野狐藪町');
ok($zip->set_number('6078156')->is_valid_number, '京都府京都市山科区東野片下リ町');
ok($zip->set_number('6078160')->is_valid_number, '京都府京都市山科区椥辻東浦町');
ok($zip->set_number('6078161')->is_valid_number, '京都府京都市山科区椥辻中在家町');
ok($zip->set_number('6078162')->is_valid_number, '京都府京都市山科区椥辻草海道町');
ok($zip->set_number('6078163')->is_valid_number, '京都府京都市山科区椥辻東潰');
ok($zip->set_number('6078164')->is_valid_number, '京都府京都市山科区椥辻西潰');
ok($zip->set_number('6078165')->is_valid_number, '京都府京都市山科区椥辻平田町');
ok($zip->set_number('6078166')->is_valid_number, '京都府京都市山科区椥辻番所ケ口町');
ok($zip->set_number('6078167')->is_valid_number, '京都府京都市山科区椥辻封シ川町');
ok($zip->set_number('6078168')->is_valid_number, '京都府京都市山科区椥辻池尻町');
ok($zip->set_number('6078169')->is_valid_number, '京都府京都市山科区椥辻西浦町');
ok($zip->set_number('6078170')->is_valid_number, '京都府京都市山科区大宅向山');
ok($zip->set_number('6078171')->is_valid_number, '京都府京都市山科区大宅御所山');
ok($zip->set_number('6078172')->is_valid_number, '京都府京都市山科区大宅岩屋殿');
ok($zip->set_number('6078173')->is_valid_number, '京都府京都市山科区大宅奥山田');
ok($zip->set_number('6078174')->is_valid_number, '京都府京都市山科区大宅鳥井脇町');
ok($zip->set_number('6078175')->is_valid_number, '京都府京都市山科区大宅山田');
ok($zip->set_number('6078176')->is_valid_number, '京都府京都市山科区大宅中小路町');
ok($zip->set_number('6078177')->is_valid_number, '京都府京都市山科区大宅古海道町');
ok($zip->set_number('6078178')->is_valid_number, '京都府京都市山科区大宅五反畑町');
ok($zip->set_number('6078179')->is_valid_number, '京都府京都市山科区大宅御所田町');
ok($zip->set_number('6078181')->is_valid_number, '京都府京都市山科区大宅打明町');
ok($zip->set_number('6078182')->is_valid_number, '京都府京都市山科区大宅坂ノ辻町');
ok($zip->set_number('6078183')->is_valid_number, '京都府京都市山科区大宅辻脇町');
ok($zip->set_number('6078184')->is_valid_number, '京都府京都市山科区大宅甲ノ辻町');
ok($zip->set_number('6078185')->is_valid_number, '京都府京都市山科区大宅神納町');
ok($zip->set_number('6078186')->is_valid_number, '京都府京都市山科区大宅早稲ノ内町');
ok($zip->set_number('6078187')->is_valid_number, '京都府京都市山科区大宅石郡町');
ok($zip->set_number('6078188')->is_valid_number, '京都府京都市山科区大宅関生町');
ok($zip->set_number('6078189')->is_valid_number, '京都府京都市山科区大宅細田町');
ok($zip->set_number('6078191')->is_valid_number, '京都府京都市山科区大宅烏田町');
ok($zip->set_number('6078192')->is_valid_number, '京都府京都市山科区大宅御供田町');
ok($zip->set_number('6078193')->is_valid_number, '京都府京都市山科区大宅沢町');
ok($zip->set_number('6078194')->is_valid_number, '京都府京都市山科区大宅桟敷');
ok($zip->set_number('6078201')->is_valid_number, '京都府京都市山科区栗栖野狐塚');
ok($zip->set_number('6078202')->is_valid_number, '京都府京都市山科区栗栖野中臣町');
ok($zip->set_number('6078203')->is_valid_number, '京都府京都市山科区栗栖野打越町');
ok($zip->set_number('6078204')->is_valid_number, '京都府京都市山科区栗栖野華ノ木町');
ok($zip->set_number('6078211')->is_valid_number, '京都府京都市山科区勧修寺東栗栖野町');
ok($zip->set_number('6078212')->is_valid_number, '京都府京都市山科区勧修寺西栗栖野町');
ok($zip->set_number('6078213')->is_valid_number, '京都府京都市山科区勧修寺東金ケ崎町');
ok($zip->set_number('6078214')->is_valid_number, '京都府京都市山科区勧修寺平田町');
ok($zip->set_number('6078215')->is_valid_number, '京都府京都市山科区勧修寺縄手町');
ok($zip->set_number('6078216')->is_valid_number, '京都府京都市山科区勧修寺東出町');
ok($zip->set_number('6078217')->is_valid_number, '京都府京都市山科区勧修寺閑林寺');
ok($zip->set_number('6078218')->is_valid_number, '京都府京都市山科区勧修寺御所内町');
ok($zip->set_number('6078219')->is_valid_number, '京都府京都市山科区勧修寺風呂尻町');
ok($zip->set_number('6078221')->is_valid_number, '京都府京都市山科区勧修寺西金ケ崎');
ok($zip->set_number('6078222')->is_valid_number, '京都府京都市山科区勧修寺東堂田町');
ok($zip->set_number('6078223')->is_valid_number, '京都府京都市山科区勧修寺瀬戸河原町');
ok($zip->set_number('6078224')->is_valid_number, '京都府京都市山科区勧修寺東北出町');
ok($zip->set_number('6078225')->is_valid_number, '京都府京都市山科区勧修寺西北出町');
ok($zip->set_number('6078226')->is_valid_number, '京都府京都市山科区勧修寺仁王堂町');
ok($zip->set_number('6078227')->is_valid_number, '京都府京都市山科区勧修寺下ノ茶屋町');
ok($zip->set_number('6078228')->is_valid_number, '京都府京都市山科区勧修寺本堂山町');
ok($zip->set_number('6078229')->is_valid_number, '京都府京都市山科区勧修寺泉玉町');
ok($zip->set_number('6078231')->is_valid_number, '京都府京都市山科区勧修寺堂田');
ok($zip->set_number('6078232')->is_valid_number, '京都府京都市山科区勧修寺福岡町');
ok($zip->set_number('6078233')->is_valid_number, '京都府京都市山科区勧修寺南谷町');
ok($zip->set_number('6078234')->is_valid_number, '京都府京都市山科区勧修寺南大日町');
ok($zip->set_number('6078235')->is_valid_number, '京都府京都市山科区勧修寺南大日');
ok($zip->set_number('6078236')->is_valid_number, '京都府京都市山科区勧修寺小松原町');
ok($zip->set_number('6078237')->is_valid_number, '京都府京都市山科区勧修寺北大日町');
ok($zip->set_number('6078238')->is_valid_number, '京都府京都市山科区勧修寺北大日');
ok($zip->set_number('6078239')->is_valid_number, '京都府京都市山科区勧修寺丸山町');
ok($zip->set_number('6078241')->is_valid_number, '京都府京都市山科区勧修寺冷尻');
ok($zip->set_number('6078242')->is_valid_number, '京都府京都市山科区勧修寺柴山');
ok($zip->set_number('6078251')->is_valid_number, '京都府京都市山科区小野蚊ケ瀬町');
ok($zip->set_number('6078252')->is_valid_number, '京都府京都市山科区小野河原町');
ok($zip->set_number('6078253')->is_valid_number, '京都府京都市山科区小野弓田町');
ok($zip->set_number('6078254')->is_valid_number, '京都府京都市山科区小野高芝町');
ok($zip->set_number('6078255')->is_valid_number, '京都府京都市山科区小野御所ノ内町');
ok($zip->set_number('6078256')->is_valid_number, '京都府京都市山科区小野荘司町');
ok($zip->set_number('6078257')->is_valid_number, '京都府京都市山科区小野御霊町');
ok($zip->set_number('6078258')->is_valid_number, '京都府京都市山科区小野西浦');
ok($zip->set_number('6078259')->is_valid_number, '京都府京都市山科区小野葛篭尻町');
ok($zip->set_number('6078261')->is_valid_number, '京都府京都市山科区小野鐘付田町');
ok($zip->set_number('6078301')->is_valid_number, '京都府京都市山科区西野山百々町');
ok($zip->set_number('6078302')->is_valid_number, '京都府京都市山科区西野山欠ノ上町');
ok($zip->set_number('6078303')->is_valid_number, '京都府京都市山科区西野山中畑町');
ok($zip->set_number('6078304')->is_valid_number, '京都府京都市山科区西野山南畑町');
ok($zip->set_number('6078305')->is_valid_number, '京都府京都市山科区西野山中臣町');
ok($zip->set_number('6078306')->is_valid_number, '京都府京都市山科区西野山中鳥井町');
ok($zip->set_number('6078307')->is_valid_number, '京都府京都市山科区西野山射庭ノ上町');
ok($zip->set_number('6078308')->is_valid_number, '京都府京都市山科区西野山桜ノ馬場町');
ok($zip->set_number('6078309')->is_valid_number, '京都府京都市山科区西野山岩ケ谷町');
ok($zip->set_number('6078311')->is_valid_number, '京都府京都市山科区西野山山田');
ok($zip->set_number('6078321')->is_valid_number, '京都府京都市山科区川田岩ケ谷');
ok($zip->set_number('6078322')->is_valid_number, '京都府京都市山科区川田清水焼団地町');
ok($zip->set_number('6078323')->is_valid_number, '京都府京都市山科区川田岡ノ西');
ok($zip->set_number('6078324')->is_valid_number, '京都府京都市山科区川田百々');
ok($zip->set_number('6078325')->is_valid_number, '京都府京都市山科区川田土仏');
ok($zip->set_number('6078326')->is_valid_number, '京都府京都市山科区川田御出町');
ok($zip->set_number('6078327')->is_valid_number, '京都府京都市山科区川田山田');
ok($zip->set_number('6078328')->is_valid_number, '京都府京都市山科区川田南山');
ok($zip->set_number('6078329')->is_valid_number, '京都府京都市山科区川田梅ケ谷町');
ok($zip->set_number('6078331')->is_valid_number, '京都府京都市山科区川田御輿塚町');
ok($zip->set_number('6078332')->is_valid_number, '京都府京都市山科区川田西浦町');
ok($zip->set_number('6078333')->is_valid_number, '京都府京都市山科区川田前畑町');
ok($zip->set_number('6078334')->is_valid_number, '京都府京都市山科区川田欠ノ上');
ok($zip->set_number('6078335')->is_valid_number, '京都府京都市山科区川田南畑町');
ok($zip->set_number('6078336')->is_valid_number, '京都府京都市山科区川田中畑町');
ok($zip->set_number('6078337')->is_valid_number, '京都府京都市山科区川田菱尾田');
ok($zip->set_number('6078341')->is_valid_number, '京都府京都市山科区西野今屋敷町');
ok($zip->set_number('6078342')->is_valid_number, '京都府京都市山科区西野様子見町');
ok($zip->set_number('6078343')->is_valid_number, '京都府京都市山科区西野阿芸沢町');
ok($zip->set_number('6078344')->is_valid_number, '京都府京都市山科区西野大手先町');
ok($zip->set_number('6078345')->is_valid_number, '京都府京都市山科区西野離宮町');
ok($zip->set_number('6078346')->is_valid_number, '京都府京都市山科区西野山階町');
ok($zip->set_number('6078347')->is_valid_number, '京都府京都市山科区西野左義長町');
ok($zip->set_number('6078348')->is_valid_number, '京都府京都市山科区西野広見町');
ok($zip->set_number('6078351')->is_valid_number, '京都府京都市山科区西野八幡田町');
ok($zip->set_number('6078352')->is_valid_number, '京都府京都市山科区西野岸ノ下町');
ok($zip->set_number('6078353')->is_valid_number, '京都府京都市山科区西野野色町');
ok($zip->set_number('6078354')->is_valid_number, '京都府京都市山科区西野小柳町');
ok($zip->set_number('6078355')->is_valid_number, '京都府京都市山科区西野大鳥井町');
ok($zip->set_number('6078356')->is_valid_number, '京都府京都市山科区西野後藤');
ok($zip->set_number('6078357')->is_valid_number, '京都府京都市山科区西野櫃川町');
ok($zip->set_number('6078358')->is_valid_number, '京都府京都市山科区西野楳本町');
ok($zip->set_number('6078401')->is_valid_number, '京都府京都市山科区御陵沢ノ川町');
ok($zip->set_number('6078402')->is_valid_number, '京都府京都市山科区御陵黒岩');
ok($zip->set_number('6078403')->is_valid_number, '京都府京都市山科区御陵大岩');
ok($zip->set_number('6078404')->is_valid_number, '京都府京都市山科区御陵大谷町');
ok($zip->set_number('6078405')->is_valid_number, '京都府京都市山科区御陵田山町');
ok($zip->set_number('6078406')->is_valid_number, '京都府京都市山科区御陵平林町');
ok($zip->set_number('6078407')->is_valid_number, '京都府京都市山科区御陵安祥寺町');
ok($zip->set_number('6078408')->is_valid_number, '京都府京都市山科区御陵鳥ノ向町');
ok($zip->set_number('6078409')->is_valid_number, '京都府京都市山科区御陵天徳町');
ok($zip->set_number('6078411')->is_valid_number, '京都府京都市山科区御陵大津畑町');
ok($zip->set_number('6078412')->is_valid_number, '京都府京都市山科区御陵四丁野町');
ok($zip->set_number('6078413')->is_valid_number, '京都府京都市山科区御陵三蔵町');
ok($zip->set_number('6078414')->is_valid_number, '京都府京都市山科区御陵中内町');
ok($zip->set_number('6078415')->is_valid_number, '京都府京都市山科区御陵中筋町');
ok($zip->set_number('6078416')->is_valid_number, '京都府京都市山科区御陵進藤町');
ok($zip->set_number('6078417')->is_valid_number, '京都府京都市山科区御陵別所町');
ok($zip->set_number('6078418')->is_valid_number, '京都府京都市山科区御陵牛尾町');
ok($zip->set_number('6078419')->is_valid_number, '京都府京都市山科区御陵檀ノ後');
ok($zip->set_number('6078421')->is_valid_number, '京都府京都市山科区御陵岡ノ西町');
ok($zip->set_number('6078422')->is_valid_number, '京都府京都市山科区御陵封ジ山町');
ok($zip->set_number('6078423')->is_valid_number, '京都府京都市山科区御陵山ノ谷');
ok($zip->set_number('6078424')->is_valid_number, '京都府京都市山科区御陵原西町');
ok($zip->set_number('6078425')->is_valid_number, '京都府京都市山科区御陵上御廟野町');
ok($zip->set_number('6078426')->is_valid_number, '京都府京都市山科区御陵下御廟野町');
ok($zip->set_number('6078427')->is_valid_number, '京都府京都市山科区御陵久保町');
ok($zip->set_number('6078428')->is_valid_number, '京都府京都市山科区御陵血洗町');
ok($zip->set_number('6078429')->is_valid_number, '京都府京都市山科区御陵荒巻町');
ok($zip->set_number('6078431')->is_valid_number, '京都府京都市山科区御陵岡町');
ok($zip->set_number('6078432')->is_valid_number, '京都府京都市山科区御陵鴨戸町');
ok($zip->set_number('6078433')->is_valid_number, '京都府京都市山科区御陵池堤町');
ok($zip->set_number('6078441')->is_valid_number, '京都府京都市山科区上野御所ノ内町');
ok($zip->set_number('6078442')->is_valid_number, '京都府京都市山科区上野山田');
ok($zip->set_number('6078443')->is_valid_number, '京都府京都市山科区上野寺井町');
ok($zip->set_number('6078451')->is_valid_number, '京都府京都市山科区厨子奥若林町');
ok($zip->set_number('6078452')->is_valid_number, '京都府京都市山科区厨子奥矢倉町');
ok($zip->set_number('6078453')->is_valid_number, '京都府京都市山科区厨子奥尾上町');
ok($zip->set_number('6078454')->is_valid_number, '京都府京都市山科区厨子奥苗代元町');
ok($zip->set_number('6078455')->is_valid_number, '京都府京都市山科区厨子奥長通');
ok($zip->set_number('6078456')->is_valid_number, '京都府京都市山科区厨子奥花鳥町');
ok($zip->set_number('6078461')->is_valid_number, '京都府京都市山科区上花山旭山町');
ok($zip->set_number('6078462')->is_valid_number, '京都府京都市山科区上花山花ノ岡町');
ok($zip->set_number('6078463')->is_valid_number, '京都府京都市山科区上花山講田町');
ok($zip->set_number('6078464')->is_valid_number, '京都府京都市山科区上花山久保町');
ok($zip->set_number('6078465')->is_valid_number, '京都府京都市山科区上花山坂尻');
ok($zip->set_number('6078466')->is_valid_number, '京都府京都市山科区上花山桜谷');
ok($zip->set_number('6078471')->is_valid_number, '京都府京都市山科区北花山大峰町');
ok($zip->set_number('6078472')->is_valid_number, '京都府京都市山科区北花山山田町');
ok($zip->set_number('6078473')->is_valid_number, '京都府京都市山科区北花山六反田町');
ok($zip->set_number('6078474')->is_valid_number, '京都府京都市山科区北花山寺内町');
ok($zip->set_number('6078475')->is_valid_number, '京都府京都市山科区北花山横田町');
ok($zip->set_number('6078476')->is_valid_number, '京都府京都市山科区北花山河原町');
ok($zip->set_number('6078481')->is_valid_number, '京都府京都市山科区北花山中道町');
ok($zip->set_number('6078482')->is_valid_number, '京都府京都市山科区北花山大林町');
ok($zip->set_number('6078483')->is_valid_number, '京都府京都市山科区北花山市田町');
ok($zip->set_number('6078484')->is_valid_number, '京都府京都市山科区北花山西ノ野町');
ok($zip->set_number('6078485')->is_valid_number, '京都府京都市山科区北花山上稚児ケ池');
ok($zip->set_number('6078491')->is_valid_number, '京都府京都市山科区日ノ岡一切経谷町');
ok($zip->set_number('6078492')->is_valid_number, '京都府京都市山科区日ノ岡夷谷町');
ok($zip->set_number('6078493')->is_valid_number, '京都府京都市山科区日ノ岡朝田町');
ok($zip->set_number('6078494')->is_valid_number, '京都府京都市山科区日ノ岡堤谷町');
ok($zip->set_number('6078495')->is_valid_number, '京都府京都市山科区日ノ岡鴨土町');
ok($zip->set_number('6078496')->is_valid_number, '京都府京都市山科区日ノ岡坂脇町');
ok($zip->set_number('6078497')->is_valid_number, '京都府京都市山科区日ノ岡ホッパラ町');
ok($zip->set_number('6078498')->is_valid_number, '京都府京都市山科区日ノ岡石塚町');
ok($zip->set_number('6100000')->is_valid_number, '京都府京都市西京区以下に掲載がない場合');
ok($zip->set_number('6100100')->is_valid_number, '京都府城陽市以下に掲載がない場合');
ok($zip->set_number('6100101')->is_valid_number, '京都府城陽市平川');
ok($zip->set_number('6100102')->is_valid_number, '京都府城陽市久世');
ok($zip->set_number('6100103')->is_valid_number, '京都府城陽市上津屋');
ok($zip->set_number('6100111')->is_valid_number, '京都府城陽市富野');
ok($zip->set_number('6100112')->is_valid_number, '京都府城陽市長池');
ok($zip->set_number('6100113')->is_valid_number, '京都府城陽市中');
ok($zip->set_number('6100114')->is_valid_number, '京都府城陽市市辺');
ok($zip->set_number('6100115')->is_valid_number, '京都府城陽市観音堂');
ok($zip->set_number('6100116')->is_valid_number, '京都府城陽市奈島');
ok($zip->set_number('6100117')->is_valid_number, '京都府城陽市枇杷庄');
ok($zip->set_number('6100118')->is_valid_number, '京都府城陽市水主');
ok($zip->set_number('6100119')->is_valid_number, '京都府城陽市令涼つむぎ');
ok($zip->set_number('6100121')->is_valid_number, '京都府城陽市寺田');
ok($zip->set_number('6100200')->is_valid_number, '京都府綴喜郡宇治田原町以下に掲載がない場合');
ok($zip->set_number('6100201')->is_valid_number, '京都府綴喜郡宇治田原町禅定寺');
ok($zip->set_number('6100202')->is_valid_number, '京都府綴喜郡宇治田原町緑苑坂');
ok($zip->set_number('6100211')->is_valid_number, '京都府綴喜郡宇治田原町奥山田');
ok($zip->set_number('6100221')->is_valid_number, '京都府綴喜郡宇治田原町湯屋谷');
ok($zip->set_number('6100231')->is_valid_number, '京都府綴喜郡宇治田原町立川');
ok($zip->set_number('6100241')->is_valid_number, '京都府綴喜郡宇治田原町南');
ok($zip->set_number('6100251')->is_valid_number, '京都府綴喜郡宇治田原町高尾');
ok($zip->set_number('6100252')->is_valid_number, '京都府綴喜郡宇治田原町荒木');
ok($zip->set_number('6100253')->is_valid_number, '京都府綴喜郡宇治田原町贄田');
ok($zip->set_number('6100254')->is_valid_number, '京都府綴喜郡宇治田原町銘城台');
ok($zip->set_number('6100255')->is_valid_number, '京都府綴喜郡宇治田原町郷之口');
ok($zip->set_number('6100261')->is_valid_number, '京都府綴喜郡宇治田原町岩山');
ok($zip->set_number('6100300')->is_valid_number, '京都府京田辺市以下に掲載がない場合');
ok($zip->set_number('6100300')->is_valid_number, '京都府綴喜郡井手町以下に掲載がない場合');
ok($zip->set_number('6100301')->is_valid_number, '京都府綴喜郡井手町多賀');
ok($zip->set_number('6100302')->is_valid_number, '京都府綴喜郡井手町井手');
ok($zip->set_number('6100303')->is_valid_number, '京都府綴喜郡井手町田村新田');
ok($zip->set_number('6100311')->is_valid_number, '京都府京田辺市草内');
ok($zip->set_number('6100312')->is_valid_number, '京都府京田辺市飯岡');
ok($zip->set_number('6100313')->is_valid_number, '京都府京田辺市三山木');
ok($zip->set_number('6100314')->is_valid_number, '京都府京田辺市宮津');
ok($zip->set_number('6100315')->is_valid_number, '京都府京田辺市同志社山手');
ok($zip->set_number('6100321')->is_valid_number, '京都府京田辺市多々羅');
ok($zip->set_number('6100322')->is_valid_number, '京都府京田辺市普賢寺');
ok($zip->set_number('6100323')->is_valid_number, '京都府京田辺市水取');
ok($zip->set_number('6100324')->is_valid_number, '京都府京田辺市打田');
ok($zip->set_number('6100325')->is_valid_number, '京都府京田辺市高船');
ok($zip->set_number('6100326')->is_valid_number, '京都府京田辺市天王');
ok($zip->set_number('6100331')->is_valid_number, '京都府京田辺市田辺');
ok($zip->set_number('6100332')->is_valid_number, '京都府京田辺市興戸');
ok($zip->set_number('6100333')->is_valid_number, '京都府京田辺市甘南備台');
ok($zip->set_number('6100334')->is_valid_number, '京都府京田辺市田辺中央');
ok($zip->set_number('6100341')->is_valid_number, '京都府京田辺市薪');
ok($zip->set_number('6100342')->is_valid_number, '京都府京田辺市松井');
ok($zip->set_number('6100343')->is_valid_number, '京都府京田辺市大住');
ok($zip->set_number('6100351')->is_valid_number, '京都府京田辺市大住ケ丘');
ok($zip->set_number('6100352')->is_valid_number, '京都府京田辺市花住坂');
ok($zip->set_number('6100353')->is_valid_number, '京都府京田辺市松井ケ丘');
ok($zip->set_number('6100354')->is_valid_number, '京都府京田辺市山手南');
ok($zip->set_number('6100355')->is_valid_number, '京都府京田辺市山手西');
ok($zip->set_number('6100356')->is_valid_number, '京都府京田辺市山手中央');
ok($zip->set_number('6100357')->is_valid_number, '京都府京田辺市山手東');
ok($zip->set_number('6100361')->is_valid_number, '京都府京田辺市河原');
ok($zip->set_number('6100362')->is_valid_number, '京都府京田辺市東');
ok($zip->set_number('6101101')->is_valid_number, '京都府京都市西京区大枝北沓掛町');
ok($zip->set_number('6101102')->is_valid_number, '京都府京都市西京区御陵大枝山町');
ok($zip->set_number('6101103')->is_valid_number, '京都府京都市西京区御陵峰ケ堂町');
ok($zip->set_number('6101104')->is_valid_number, '京都府京都市西京区大枝中山町');
ok($zip->set_number('6101105')->is_valid_number, '京都府京都市西京区大枝塚原町');
ok($zip->set_number('6101106')->is_valid_number, '京都府京都市西京区大枝沓掛町');
ok($zip->set_number('6101107')->is_valid_number, '京都府京都市西京区御陵北大枝山町');
ok($zip->set_number('6101111')->is_valid_number, '京都府京都市西京区大枝東長町');
ok($zip->set_number('6101112')->is_valid_number, '京都府京都市西京区大枝北福西町');
ok($zip->set_number('6101113')->is_valid_number, '京都府京都市西京区大枝南福西町');
ok($zip->set_number('6101121')->is_valid_number, '京都府京都市西京区大原野上里北ノ町');
ok($zip->set_number('6101122')->is_valid_number, '京都府京都市西京区大原野東野町');
ok($zip->set_number('6101123')->is_valid_number, '京都府京都市西京区大原野上里南ノ町');
ok($zip->set_number('6101124')->is_valid_number, '京都府京都市西京区大原野上里紅葉町');
ok($zip->set_number('6101125')->is_valid_number, '京都府京都市西京区大原野上里勝山町');
ok($zip->set_number('6101126')->is_valid_number, '京都府京都市西京区大原野上里男鹿町');
ok($zip->set_number('6101127')->is_valid_number, '京都府京都市西京区大原野上里鳥見町');
ok($zip->set_number('6101128')->is_valid_number, '京都府京都市西京区大原野石見町');
ok($zip->set_number('6101131')->is_valid_number, '京都府京都市西京区大原野上羽町');
ok($zip->set_number('6101132')->is_valid_number, '京都府京都市西京区大原野灰方町');
ok($zip->set_number('6101133')->is_valid_number, '京都府京都市西京区大原野小塩町');
ok($zip->set_number('6101134')->is_valid_number, '京都府京都市西京区大原野石作町');
ok($zip->set_number('6101135')->is_valid_number, '京都府京都市西京区大原野出灰町');
ok($zip->set_number('6101136')->is_valid_number, '京都府京都市西京区大原野外畑町');
ok($zip->set_number('6101141')->is_valid_number, '京都府京都市西京区大枝西新林町');
ok($zip->set_number('6101142')->is_valid_number, '京都府京都市西京区大枝東新林町');
ok($zip->set_number('6101143')->is_valid_number, '京都府京都市西京区大原野東境谷町');
ok($zip->set_number('6101144')->is_valid_number, '京都府京都市西京区大原野東竹の里町');
ok($zip->set_number('6101145')->is_valid_number, '京都府京都市西京区大原野西竹の里町');
ok($zip->set_number('6101146')->is_valid_number, '京都府京都市西京区大原野西境谷町');
ok($zip->set_number('6101151')->is_valid_number, '京都府京都市西京区大枝西長町');
ok($zip->set_number('6101152')->is_valid_number, '京都府京都市西京区大原野北春日町');
ok($zip->set_number('6101153')->is_valid_number, '京都府京都市西京区大原野南春日町');
ok($zip->set_number('6110000')->is_valid_number, '京都府宇治市以下に掲載がない場合');
ok($zip->set_number('6110001')->is_valid_number, '京都府宇治市六地蔵');
ok($zip->set_number('6110002')->is_valid_number, '京都府宇治市木幡');
ok($zip->set_number('6110003')->is_valid_number, '京都府宇治市平尾台');
ok($zip->set_number('6110011')->is_valid_number, '京都府宇治市五ケ庄');
ok($zip->set_number('6110012')->is_valid_number, '京都府宇治市羽戸山');
ok($zip->set_number('6110013')->is_valid_number, '京都府宇治市莵道(その他)');
ok($zip->set_number('6110014')->is_valid_number, '京都府宇治市明星町');
ok($zip->set_number('6110015')->is_valid_number, '京都府宇治市志津川');
ok($zip->set_number('6110021')->is_valid_number, '京都府宇治市宇治');
ok($zip->set_number('6110022')->is_valid_number, '京都府宇治市白川');
ok($zip->set_number('6110023')->is_valid_number, '京都府宇治市折居台');
ok($zip->set_number('6110024')->is_valid_number, '京都府宇治市琵琶台');
ok($zip->set_number('6110025')->is_valid_number, '京都府宇治市神明');
ok($zip->set_number('6110026')->is_valid_number, '京都府宇治市開町');
ok($zip->set_number('6110027')->is_valid_number, '京都府宇治市羽拍子町');
ok($zip->set_number('6110028')->is_valid_number, '京都府宇治市南陵町');
ok($zip->set_number('6110029')->is_valid_number, '京都府宇治市天神台');
ok($zip->set_number('6110031')->is_valid_number, '京都府宇治市広野町');
ok($zip->set_number('6110032')->is_valid_number, '京都府宇治市寺山台');
ok($zip->set_number('6110033')->is_valid_number, '京都府宇治市大久保町');
ok($zip->set_number('6110041')->is_valid_number, '京都府宇治市槇島町');
ok($zip->set_number('6110042')->is_valid_number, '京都府宇治市小倉町');
ok($zip->set_number('6110043')->is_valid_number, '京都府宇治市伊勢田町');
ok($zip->set_number('6110044')->is_valid_number, '京都府宇治市伊勢田町名木');
ok($zip->set_number('6110045')->is_valid_number, '京都府宇治市安田町');
ok($zip->set_number('6120000')->is_valid_number, '京都府京都市伏見区以下に掲載がない場合');
ok($zip->set_number('6120001')->is_valid_number, '京都府京都市伏見区深草下高松町');
ok($zip->set_number('6120002')->is_valid_number, '京都府京都市伏見区深草中川原町');
ok($zip->set_number('6120003')->is_valid_number, '京都府京都市伏見区深草藤田坪町');
ok($zip->set_number('6120004')->is_valid_number, '京都府京都市伏見区深草相深町');
ok($zip->set_number('6120005')->is_valid_number, '京都府京都市伏見区深草森吉町');
ok($zip->set_number('6120006')->is_valid_number, '京都府京都市伏見区深草上横縄町');
ok($zip->set_number('6120007')->is_valid_number, '京都府京都市伏見区深草下横縄町');
ok($zip->set_number('6120008')->is_valid_number, '京都府京都市伏見区深草六反田町');
ok($zip->set_number('6120009')->is_valid_number, '京都府京都市伏見区深草西川原町');
ok($zip->set_number('6120011')->is_valid_number, '京都府京都市伏見区深草鈴塚町');
ok($zip->set_number('6120012')->is_valid_number, '京都府京都市伏見区深草一ノ坪町');
ok($zip->set_number('6120013')->is_valid_number, '京都府京都市伏見区深草祓川町');
ok($zip->set_number('6120014')->is_valid_number, '京都府京都市伏見区深草稲荷鳥居前町');
ok($zip->set_number('6120015')->is_valid_number, '京都府京都市伏見区深草ススハキ町');
ok($zip->set_number('6120016')->is_valid_number, '京都府京都市伏見区深草ケナサ町');
ok($zip->set_number('6120017')->is_valid_number, '京都府京都市伏見区深草今在家町');
ok($zip->set_number('6120018')->is_valid_number, '京都府京都市伏見区深草フケノ内町');
ok($zip->set_number('6120019')->is_valid_number, '京都府京都市伏見区深草平田町');
ok($zip->set_number('6120021')->is_valid_number, '京都府京都市伏見区深草塚本町');
ok($zip->set_number('6120022')->is_valid_number, '京都府京都市伏見区深草綿森町');
ok($zip->set_number('6120023')->is_valid_number, '京都府京都市伏見区深草町通町');
ok($zip->set_number('6120024')->is_valid_number, '京都府京都市伏見区深草野田町');
ok($zip->set_number('6120025')->is_valid_number, '京都府京都市伏見区深草キトロ町');
ok($zip->set_number('6120026')->is_valid_number, '京都府京都市伏見区深草堀田町');
ok($zip->set_number('6120027')->is_valid_number, '京都府京都市伏見区深草極楽町');
ok($zip->set_number('6120028')->is_valid_number, '京都府京都市伏見区深草飯食町');
ok($zip->set_number('6120029')->is_valid_number, '京都府京都市伏見区深草西浦町');
ok($zip->set_number('6120031')->is_valid_number, '京都府京都市伏見区深草池ノ内町');
ok($zip->set_number('6120032')->is_valid_number, '京都府京都市伏見区深草西飯食町');
ok($zip->set_number('6120033')->is_valid_number, '京都府京都市伏見区深草寺内町');
ok($zip->set_number('6120034')->is_valid_number, '京都府京都市伏見区深草七瀬川町');
ok($zip->set_number('6120035')->is_valid_number, '京都府京都市伏見区深草北蓮池町');
ok($zip->set_number('6120036')->is_valid_number, '京都府京都市伏見区深草南蓮池町');
ok($zip->set_number('6120037')->is_valid_number, '京都府京都市伏見区深草関屋敷町');
ok($zip->set_number('6120038')->is_valid_number, '京都府京都市伏見区深草仙石屋敷町');
ok($zip->set_number('6120041')->is_valid_number, '京都府京都市伏見区深草北鍵屋町');
ok($zip->set_number('6120042')->is_valid_number, '京都府京都市伏見区深草芳永町');
ok($zip->set_number('6120043')->is_valid_number, '京都府京都市伏見区深草芳本町');
ok($zip->set_number('6120044')->is_valid_number, '京都府京都市伏見区深草北新町');
ok($zip->set_number('6120045')->is_valid_number, '京都府京都市伏見区深草石橋町');
ok($zip->set_number('6120046')->is_valid_number, '京都府京都市伏見区深草大亀谷八島町');
ok($zip->set_number('6120047')->is_valid_number, '京都府京都市伏見区深草大亀谷内膳町');
ok($zip->set_number('6120048')->is_valid_number, '京都府京都市伏見区深草大亀谷金森出雲町');
ok($zip->set_number('6120049')->is_valid_number, '京都府京都市伏見区深草中ノ島町');
ok($zip->set_number('6120051')->is_valid_number, '京都府京都市伏見区墨染町');
ok($zip->set_number('6120052')->is_valid_number, '京都府京都市伏見区深草墨染町');
ok($zip->set_number('6120053')->is_valid_number, '京都府京都市伏見区桃山町丹下');
ok($zip->set_number('6120054')->is_valid_number, '京都府京都市伏見区桃山最上町');
ok($zip->set_number('6120055')->is_valid_number, '京都府京都市伏見区桃山水野左近東町');
ok($zip->set_number('6120056')->is_valid_number, '京都府京都市伏見区桃山長岡越中北町');
ok($zip->set_number('6120057')->is_valid_number, '京都府京都市伏見区桃山長岡越中東町');
ok($zip->set_number('6120058')->is_valid_number, '京都府京都市伏見区桃山長岡越中南町');
ok($zip->set_number('6120059')->is_valid_number, '京都府京都市伏見区桃山水野左近西町');
ok($zip->set_number('6120061')->is_valid_number, '京都府京都市伏見区桃山福島太夫北町');
ok($zip->set_number('6120062')->is_valid_number, '京都府京都市伏見区桃山福島太夫南町');
ok($zip->set_number('6120063')->is_valid_number, '京都府京都市伏見区桃山毛利長門東町');
ok($zip->set_number('6120064')->is_valid_number, '京都府京都市伏見区桃山毛利長門西町');
ok($zip->set_number('6120065')->is_valid_number, '京都府京都市伏見区桃山羽柴長吉東町');
ok($zip->set_number('6120066')->is_valid_number, '京都府京都市伏見区桃山羽柴長吉中町');
ok($zip->set_number('6120067')->is_valid_number, '京都府京都市伏見区桃山羽柴長吉西町');
ok($zip->set_number('6120068')->is_valid_number, '京都府京都市伏見区桃山福島太夫西町');
ok($zip->set_number('6120071')->is_valid_number, '京都府京都市伏見区桃山井伊掃部東町');
ok($zip->set_number('6120072')->is_valid_number, '京都府京都市伏見区桃山筒井伊賀東町');
ok($zip->set_number('6120073')->is_valid_number, '京都府京都市伏見区桃山筒井伊賀西町');
ok($zip->set_number('6120074')->is_valid_number, '京都府京都市伏見区桃山井伊掃部西町');
ok($zip->set_number('6120081')->is_valid_number, '京都府京都市伏見区深草大島屋敷町');
ok($zip->set_number('6120082')->is_valid_number, '京都府京都市伏見区深草山村町');
ok($zip->set_number('6120083')->is_valid_number, '京都府京都市伏見区西桝屋町');
ok($zip->set_number('6120084')->is_valid_number, '京都府京都市伏見区鑓屋町');
ok($zip->set_number('6120085')->is_valid_number, '京都府京都市伏見区撞木町');
ok($zip->set_number('6120086')->is_valid_number, '京都府京都市伏見区桃山町真斉');
ok($zip->set_number('6120087')->is_valid_number, '京都府京都市伏見区深草紺屋町');
ok($zip->set_number('6120088')->is_valid_number, '京都府京都市伏見区深草出羽屋敷町');
ok($zip->set_number('6120089')->is_valid_number, '京都府京都市伏見区深草佐野屋敷町');
ok($zip->set_number('6120801')->is_valid_number, '京都府京都市伏見区深草正覚町');
ok($zip->set_number('6120802')->is_valid_number, '京都府京都市伏見区深草南明町');
ok($zip->set_number('6120803')->is_valid_number, '京都府京都市伏見区深草車阪町');
ok($zip->set_number('6120804')->is_valid_number, '京都府京都市伏見区稲荷山官有地');
ok($zip->set_number('6120805')->is_valid_number, '京都府京都市伏見区深草開土口町');
ok($zip->set_number('6120806')->is_valid_number, '京都府京都市伏見区深草開土町');
ok($zip->set_number('6120807')->is_valid_number, '京都府京都市伏見区深草稲荷中之町');
ok($zip->set_number('6120808')->is_valid_number, '京都府京都市伏見区深草稲荷榎木橋町');
ok($zip->set_number('6120809')->is_valid_number, '京都府京都市伏見区深草願成町');
ok($zip->set_number('6120811')->is_valid_number, '京都府京都市伏見区深草笹山町');
ok($zip->set_number('6120812')->is_valid_number, '京都府京都市伏見区深草坊山町');
ok($zip->set_number('6120813')->is_valid_number, '京都府京都市伏見区深草極楽寺山町');
ok($zip->set_number('6120814')->is_valid_number, '京都府京都市伏見区深草砥粉山町');
ok($zip->set_number('6120815')->is_valid_number, '京都府京都市伏見区深草飯食山町');
ok($zip->set_number('6120816')->is_valid_number, '京都府京都市伏見区深草馬谷町');
ok($zip->set_number('6120817')->is_valid_number, '京都府京都市伏見区深草向ケ原町');
ok($zip->set_number('6120818')->is_valid_number, '京都府京都市伏見区深草中ノ郷山町');
ok($zip->set_number('6120819')->is_valid_number, '京都府京都市伏見区深草僧坊山町');
ok($zip->set_number('6120821')->is_valid_number, '京都府京都市伏見区深草東瓦町');
ok($zip->set_number('6120822')->is_valid_number, '京都府京都市伏見区深草鞍ケ谷');
ok($zip->set_number('6120823')->is_valid_number, '京都府京都市伏見区深草東軸町');
ok($zip->set_number('6120824')->is_valid_number, '京都府京都市伏見区深草霧ケ谷町');
ok($zip->set_number('6120825')->is_valid_number, '京都府京都市伏見区深草鐙ケ谷町');
ok($zip->set_number('6120826')->is_valid_number, '京都府京都市伏見区深草兜山町');
ok($zip->set_number('6120827')->is_valid_number, '京都府京都市伏見区深草宮谷町');
ok($zip->set_number('6120828')->is_valid_number, '京都府京都市伏見区深草砂子谷町');
ok($zip->set_number('6120829')->is_valid_number, '京都府京都市伏見区深草谷口町');
ok($zip->set_number('6120831')->is_valid_number, '京都府京都市伏見区桃山町古城山');
ok($zip->set_number('6120832')->is_valid_number, '京都府京都市伏見区深草大亀谷東安信町');
ok($zip->set_number('6120833')->is_valid_number, '京都府京都市伏見区深草大亀谷岩山町');
ok($zip->set_number('6120834')->is_valid_number, '京都府京都市伏見区桃山町安芸山');
ok($zip->set_number('6120835')->is_valid_number, '京都府京都市伏見区桃山紅雪町');
ok($zip->set_number('6120836')->is_valid_number, '京都府京都市伏見区深草大亀谷安信町');
ok($zip->set_number('6120837')->is_valid_number, '京都府京都市伏見区深草稲荷山町');
ok($zip->set_number('6120838')->is_valid_number, '京都府京都市伏見区深草神明講谷町');
ok($zip->set_number('6120839')->is_valid_number, '京都府京都市伏見区深草本寺山町');
ok($zip->set_number('6120841')->is_valid_number, '京都府京都市伏見区深草大亀谷東久宝寺町');
ok($zip->set_number('6120842')->is_valid_number, '京都府京都市伏見区深草大亀谷大谷町');
ok($zip->set_number('6120843')->is_valid_number, '京都府京都市伏見区深草大亀谷古御香町');
ok($zip->set_number('6120844')->is_valid_number, '京都府京都市伏見区深草大亀谷東古御香町');
ok($zip->set_number('6120845')->is_valid_number, '京都府京都市伏見区深草大亀谷敦賀町');
ok($zip->set_number('6120846')->is_valid_number, '京都府京都市伏見区深草大亀谷万帖敷町');
ok($zip->set_number('6120847')->is_valid_number, '京都府京都市伏見区深草大亀谷大山町');
ok($zip->set_number('6120848')->is_valid_number, '京都府京都市伏見区深草大亀谷東寺町');
ok($zip->set_number('6120849')->is_valid_number, '京都府京都市伏見区深草大亀谷西寺町');
ok($zip->set_number('6120851')->is_valid_number, '京都府京都市伏見区深草大亀谷六躰町');
ok($zip->set_number('6120852')->is_valid_number, '京都府京都市伏見区深草大亀谷五郎太町');
ok($zip->set_number('6120853')->is_valid_number, '京都府京都市伏見区桃山町大蔵');
ok($zip->set_number('6120854')->is_valid_number, '京都府京都市伏見区桃山町島津');
ok($zip->set_number('6120855')->is_valid_number, '京都府京都市伏見区桃山町永井久太郎');
ok($zip->set_number('6120856')->is_valid_number, '京都府京都市伏見区桃山町正宗');
ok($zip->set_number('6120861')->is_valid_number, '京都府京都市伏見区深草向畑町');
ok($zip->set_number('6120862')->is_valid_number, '京都府京都市伏見区深草大亀谷西久宝寺町');
ok($zip->set_number('6120863')->is_valid_number, '京都府京都市伏見区深草藤森町');
ok($zip->set_number('6120864')->is_valid_number, '京都府京都市伏見区深草鳥居崎町');
ok($zip->set_number('6120865')->is_valid_number, '京都府京都市伏見区深草藤森玄蕃町');
ok($zip->set_number('6120866')->is_valid_number, '京都府京都市伏見区深草十九軒町');
ok($zip->set_number('6120867')->is_valid_number, '京都府京都市伏見区深草直違橋片町');
ok($zip->set_number('6120868')->is_valid_number, '京都府京都市伏見区深草直違橋南');
ok($zip->set_number('6120869')->is_valid_number, '京都府京都市伏見区深草直違橋北');
ok($zip->set_number('6120871')->is_valid_number, '京都府京都市伏見区深草坊町');
ok($zip->set_number('6120872')->is_valid_number, '京都府京都市伏見区深草真宗院山町');
ok($zip->set_number('6120873')->is_valid_number, '京都府京都市伏見区深草瓦町');
ok($zip->set_number('6120874')->is_valid_number, '京都府京都市伏見区深草東伊達町');
ok($zip->set_number('6120875')->is_valid_number, '京都府京都市伏見区深草枯木町');
ok($zip->set_number('6120876')->is_valid_number, '京都府京都市伏見区深草西伊達町');
ok($zip->set_number('6120877')->is_valid_number, '京都府京都市伏見区深草僧坊町');
ok($zip->set_number('6120878')->is_valid_number, '京都府京都市伏見区深草田谷町');
ok($zip->set_number('6120879')->is_valid_number, '京都府京都市伏見区深草西出町');
ok($zip->set_number('6120881')->is_valid_number, '京都府京都市伏見区深草稲荷御前町');
ok($zip->set_number('6120882')->is_valid_number, '京都府京都市伏見区深草薮之内町');
ok($zip->set_number('6120883')->is_valid_number, '京都府京都市伏見区深草石峰寺山町');
ok($zip->set_number('6120884')->is_valid_number, '京都府京都市伏見区深草西出山町');
ok($zip->set_number('6120885')->is_valid_number, '京都府京都市伏見区深草宝塔寺山町');
ok($zip->set_number('6120886')->is_valid_number, '京都府京都市伏見区深草極楽寺町');
ok($zip->set_number('6120887')->is_valid_number, '京都府京都市伏見区深草野手町');
ok($zip->set_number('6120888')->is_valid_number, '京都府京都市伏見区深草大門町');
ok($zip->set_number('6120889')->is_valid_number, '京都府京都市伏見区深草直違橋');
ok($zip->set_number('6128001')->is_valid_number, '京都府京都市伏見区桃山町日向');
ok($zip->set_number('6128002')->is_valid_number, '京都府京都市伏見区桃山町山ノ下');
ok($zip->set_number('6128003')->is_valid_number, '京都府京都市伏見区桃山町西尾');
ok($zip->set_number('6128004')->is_valid_number, '京都府京都市伏見区桃山町町並');
ok($zip->set_number('6128005')->is_valid_number, '京都府京都市伏見区桃山町中島町');
ok($zip->set_number('6128006')->is_valid_number, '京都府京都市伏見区桃山町大島');
ok($zip->set_number('6128007')->is_valid_number, '京都府京都市伏見区桃山町因幡');
ok($zip->set_number('6128008')->is_valid_number, '京都府京都市伏見区桃山町東町');
ok($zip->set_number('6128009')->is_valid_number, '京都府京都市伏見区桃山町見附町');
ok($zip->set_number('6128011')->is_valid_number, '京都府京都市伏見区桃山町伊庭');
ok($zip->set_number('6128012')->is_valid_number, '京都府京都市伏見区桃山町遠山');
ok($zip->set_number('6128013')->is_valid_number, '京都府京都市伏見区桃山町西町');
ok($zip->set_number('6128014')->is_valid_number, '京都府京都市伏見区桃山町大津町');
ok($zip->set_number('6128015')->is_valid_number, '京都府京都市伏見区桃山町和泉');
ok($zip->set_number('6128016')->is_valid_number, '京都府京都市伏見区桃山町養斉');
ok($zip->set_number('6128017')->is_valid_number, '京都府京都市伏見区桃山南大島町');
ok($zip->set_number('6128018')->is_valid_number, '京都府京都市伏見区桃山町丹後');
ok($zip->set_number('6128019')->is_valid_number, '京都府京都市伏見区桃山町新町');
ok($zip->set_number('6128021')->is_valid_number, '京都府京都市伏見区桃山町下野');
ok($zip->set_number('6128022')->is_valid_number, '京都府京都市伏見区桃山町駿河');
ok($zip->set_number('6128023')->is_valid_number, '京都府京都市伏見区桃山町美濃');
ok($zip->set_number('6128024')->is_valid_number, '京都府京都市伏見区桃山町根来');
ok($zip->set_number('6128025')->is_valid_number, '京都府京都市伏見区桃山与五郎町');
ok($zip->set_number('6128026')->is_valid_number, '京都府京都市伏見区桃山町伊賀');
ok($zip->set_number('6128027')->is_valid_number, '京都府京都市伏見区桃山町本多上野');
ok($zip->set_number('6128028')->is_valid_number, '京都府京都市伏見区桃山町板倉周防');
ok($zip->set_number('6128029')->is_valid_number, '京都府京都市伏見区桃山町三河');
ok($zip->set_number('6128031')->is_valid_number, '京都府京都市伏見区桃山町松平筑前');
ok($zip->set_number('6128032')->is_valid_number, '京都府京都市伏見区桃山筑前台町');
ok($zip->set_number('6128033')->is_valid_number, '京都府京都市伏見区桃山町松平武蔵');
ok($zip->set_number('6128034')->is_valid_number, '京都府京都市伏見区桃山町泰長老');
ok($zip->set_number('6128035')->is_valid_number, '京都府京都市伏見区常盤町');
ok($zip->set_number('6128036')->is_valid_number, '京都府京都市伏見区桃山町立売');
ok($zip->set_number('6128037')->is_valid_number, '京都府京都市伏見区桃山町鍋島');
ok($zip->set_number('6128038')->is_valid_number, '京都府京都市伏見区鍋島町');
ok($zip->set_number('6128039')->is_valid_number, '京都府京都市伏見区御香宮門前町');
ok($zip->set_number('6128041')->is_valid_number, '京都府京都市伏見区魚屋町');
ok($zip->set_number('6128042')->is_valid_number, '京都府京都市伏見区柿木浜町');
ok($zip->set_number('6128043')->is_valid_number, '京都府京都市伏見区本材木町');
ok($zip->set_number('6128044')->is_valid_number, '京都府京都市伏見区丹後町');
ok($zip->set_number('6128045')->is_valid_number, '京都府京都市伏見区南浜町');
ok($zip->set_number('6128046')->is_valid_number, '京都府京都市伏見区塩屋町');
ok($zip->set_number('6128047')->is_valid_number, '京都府京都市伏見区上油掛町');
ok($zip->set_number('6128048')->is_valid_number, '京都府京都市伏見区大阪町');
ok($zip->set_number('6128051')->is_valid_number, '京都府京都市伏見区今町');
ok($zip->set_number('6128052')->is_valid_number, '京都府京都市伏見区瀬戸物町');
ok($zip->set_number('6128053')->is_valid_number, '京都府京都市伏見区東大手町');
ok($zip->set_number('6128054')->is_valid_number, '京都府京都市伏見区御堂前町');
ok($zip->set_number('6128055')->is_valid_number, '京都府京都市伏見区伯耆町');
ok($zip->set_number('6128056')->is_valid_number, '京都府京都市伏見区中油掛町');
ok($zip->set_number('6128057')->is_valid_number, '京都府京都市伏見区平野町');
ok($zip->set_number('6128058')->is_valid_number, '京都府京都市伏見区風呂屋町');
ok($zip->set_number('6128059')->is_valid_number, '京都府京都市伏見区南部町');
ok($zip->set_number('6128061')->is_valid_number, '京都府京都市伏見区竹中町');
ok($zip->set_number('6128062')->is_valid_number, '京都府京都市伏見区鷹匠町');
ok($zip->set_number('6128063')->is_valid_number, '京都府京都市伏見区東組町');
ok($zip->set_number('6128064')->is_valid_number, '京都府京都市伏見区紺屋町');
ok($zip->set_number('6128065')->is_valid_number, '京都府京都市伏見区御駕籠町');
ok($zip->set_number('6128066')->is_valid_number, '京都府京都市伏見区東堺町');
ok($zip->set_number('6128067')->is_valid_number, '京都府京都市伏見区城通町');
ok($zip->set_number('6128071')->is_valid_number, '京都府京都市伏見区鍛冶屋町');
ok($zip->set_number('6128072')->is_valid_number, '京都府京都市伏見区丹波橋町');
ok($zip->set_number('6128073')->is_valid_number, '京都府京都市伏見区下板橋町');
ok($zip->set_number('6128074')->is_valid_number, '京都府京都市伏見区指物町');
ok($zip->set_number('6128075')->is_valid_number, '京都府京都市伏見区桝形町');
ok($zip->set_number('6128076')->is_valid_number, '京都府京都市伏見区南尼崎町');
ok($zip->set_number('6128077')->is_valid_number, '京都府京都市伏見区北尼崎町');
ok($zip->set_number('6128078')->is_valid_number, '京都府京都市伏見区大宮町');
ok($zip->set_number('6128081')->is_valid_number, '京都府京都市伏見区新町');
ok($zip->set_number('6128082')->is_valid_number, '京都府京都市伏見区両替町');
ok($zip->set_number('6128083')->is_valid_number, '京都府京都市伏見区京町');
ok($zip->set_number('6128084')->is_valid_number, '京都府京都市伏見区京町8丁目横町');
ok($zip->set_number('6128085')->is_valid_number, '京都府京都市伏見区京町南');
ok($zip->set_number('6128086')->is_valid_number, '京都府京都市伏見区京町北');
ok($zip->set_number('6128087')->is_valid_number, '京都府京都市伏見区京町大黒町');
ok($zip->set_number('6128088')->is_valid_number, '京都府京都市伏見区桃山町金森出雲');
ok($zip->set_number('6128089')->is_valid_number, '京都府京都市伏見区銀座町');
ok($zip->set_number('6128101')->is_valid_number, '京都府京都市伏見区観音寺町');
ok($zip->set_number('6128102')->is_valid_number, '京都府京都市伏見区道阿弥町');
ok($zip->set_number('6128103')->is_valid_number, '京都府京都市伏見区片桐町');
ok($zip->set_number('6128104')->is_valid_number, '京都府京都市伏見区西奉行町');
ok($zip->set_number('6128105')->is_valid_number, '京都府京都市伏見区東奉行町');
ok($zip->set_number('6128106')->is_valid_number, '京都府京都市伏見区豊後橋町');
ok($zip->set_number('6128107')->is_valid_number, '京都府京都市伏見区桃陵町');
ok($zip->set_number('6128108')->is_valid_number, '京都府京都市伏見区奉行前町');
ok($zip->set_number('6128109')->is_valid_number, '京都府京都市伏見区讃岐町');
ok($zip->set_number('6128111')->is_valid_number, '京都府京都市伏見区向島橋詰町');
ok($zip->set_number('6128112')->is_valid_number, '京都府京都市伏見区向島本丸町');
ok($zip->set_number('6128113')->is_valid_number, '京都府京都市伏見区向島中島町');
ok($zip->set_number('6128114')->is_valid_number, '京都府京都市伏見区向島下之町');
ok($zip->set_number('6128115')->is_valid_number, '京都府京都市伏見区向島中之町');
ok($zip->set_number('6128116')->is_valid_number, '京都府京都市伏見区向島西堤町');
ok($zip->set_number('6128121')->is_valid_number, '京都府京都市伏見区向島善阿弥町');
ok($zip->set_number('6128122')->is_valid_number, '京都府京都市伏見区向島庚申町');
ok($zip->set_number('6128123')->is_valid_number, '京都府京都市伏見区向島立河原町');
ok($zip->set_number('6128124')->is_valid_number, '京都府京都市伏見区向島吹田河原町');
ok($zip->set_number('6128125')->is_valid_number, '京都府京都市伏見区向島東泉寺町');
ok($zip->set_number('6128131')->is_valid_number, '京都府京都市伏見区向島丸町');
ok($zip->set_number('6128132')->is_valid_number, '京都府京都市伏見区向島藤ノ木町');
ok($zip->set_number('6128133')->is_valid_number, '京都府京都市伏見区向島鷹場町');
ok($zip->set_number('6128134')->is_valid_number, '京都府京都市伏見区向島清水町');
ok($zip->set_number('6128135')->is_valid_number, '京都府京都市伏見区向島渡シ場町');
ok($zip->set_number('6128136')->is_valid_number, '京都府京都市伏見区向島四ツ谷池');
ok($zip->set_number('6128141')->is_valid_number, '京都府京都市伏見区向島二ノ丸町');
ok($zip->set_number('6128151')->is_valid_number, '京都府京都市伏見区向島上林町');
ok($zip->set_number('6128152')->is_valid_number, '京都府京都市伏見区向島新上林');
ok($zip->set_number('6128153')->is_valid_number, '京都府京都市伏見区向島二本柳');
ok($zip->set_number('6128154')->is_valid_number, '京都府京都市伏見区向島津田町');
ok($zip->set_number('6128155')->is_valid_number, '京都府京都市伏見区向島東定請');
ok($zip->set_number('6128156')->is_valid_number, '京都府京都市伏見区向島西定請');
ok($zip->set_number('6128157')->is_valid_number, '京都府京都市伏見区向島大黒');
ok($zip->set_number('6128158')->is_valid_number, '京都府京都市伏見区向島上五反田');
ok($zip->set_number('6128201')->is_valid_number, '京都府京都市伏見区恵美酒町');
ok($zip->set_number('6128202')->is_valid_number, '京都府京都市伏見区過書町');
ok($zip->set_number('6128203')->is_valid_number, '京都府京都市伏見区阿波橋町');
ok($zip->set_number('6128204')->is_valid_number, '京都府京都市伏見区八幡町');
ok($zip->set_number('6128205')->is_valid_number, '京都府京都市伏見区横大路三栖大黒町');
ok($zip->set_number('6128206')->is_valid_number, '京都府京都市伏見区下鳥羽六反長町');
ok($zip->set_number('6128207')->is_valid_number, '京都府京都市伏見区横大路三栖山城屋敷町');
ok($zip->set_number('6128208')->is_valid_number, '京都府京都市伏見区下鳥羽但馬町');
ok($zip->set_number('6128209')->is_valid_number, '京都府京都市伏見区下鳥羽南六反長町');
ok($zip->set_number('6128211')->is_valid_number, '京都府京都市伏見区東柳町');
ok($zip->set_number('6128212')->is_valid_number, '京都府京都市伏見区西柳町');
ok($zip->set_number('6128213')->is_valid_number, '京都府京都市伏見区東浜南町');
ok($zip->set_number('6128214')->is_valid_number, '京都府京都市伏見区西浜町');
ok($zip->set_number('6128215')->is_valid_number, '京都府京都市伏見区新中町');
ok($zip->set_number('6128216')->is_valid_number, '京都府京都市伏見区下中町');
ok($zip->set_number('6128217')->is_valid_number, '京都府京都市伏見区上中町');
ok($zip->set_number('6128218')->is_valid_number, '京都府京都市伏見区北浜町');
ok($zip->set_number('6128219')->is_valid_number, '京都府京都市伏見区表町');
ok($zip->set_number('6128221')->is_valid_number, '京都府京都市伏見区弾正町');
ok($zip->set_number('6128222')->is_valid_number, '京都府京都市伏見区平戸町');
ok($zip->set_number('6128223')->is_valid_number, '京都府京都市伏見区桃山町弾正島');
ok($zip->set_number('6128224')->is_valid_number, '京都府京都市伏見区葭島矢倉町');
ok($zip->set_number('6128225')->is_valid_number, '京都府京都市伏見区葭島金井戸町');
ok($zip->set_number('6128226')->is_valid_number, '京都府京都市伏見区桃山町金井戸島');
ok($zip->set_number('6128227')->is_valid_number, '京都府京都市伏見区三栖向町');
ok($zip->set_number('6128228')->is_valid_number, '京都府京都市伏見区南新地');
ok($zip->set_number('6128231')->is_valid_number, '京都府京都市伏見区杉本町');
ok($zip->set_number('6128232')->is_valid_number, '京都府京都市伏見区三栖半町');
ok($zip->set_number('6128233')->is_valid_number, '京都府京都市伏見区三栖町');
ok($zip->set_number('6128234')->is_valid_number, '京都府京都市伏見区横大路三栖木下屋敷町');
ok($zip->set_number('6128235')->is_valid_number, '京都府京都市伏見区横大路下三栖東ノ口');
ok($zip->set_number('6128236')->is_valid_number, '京都府京都市伏見区横大路下三栖里ノ内');
ok($zip->set_number('6128237')->is_valid_number, '京都府京都市伏見区横大路三栖池田屋敷町');
ok($zip->set_number('6128238')->is_valid_number, '京都府京都市伏見区横大路下三栖山殿');
ok($zip->set_number('6128239')->is_valid_number, '京都府京都市伏見区横大路三栖泥町跡町');
ok($zip->set_number('6128241')->is_valid_number, '京都府京都市伏見区横大路下三栖辻堂町');
ok($zip->set_number('6128242')->is_valid_number, '京都府京都市伏見区横大路下三栖梶原町');
ok($zip->set_number('6128243')->is_valid_number, '京都府京都市伏見区横大路下三栖城ノ前町');
ok($zip->set_number('6128244')->is_valid_number, '京都府京都市伏見区横大路千両松町');
ok($zip->set_number('6128245')->is_valid_number, '京都府京都市伏見区横大路下三栖宮ノ後');
ok($zip->set_number('6128246')->is_valid_number, '京都府京都市伏見区横大路芝生');
ok($zip->set_number('6128247')->is_valid_number, '京都府京都市伏見区横大路下三栖南郷');
ok($zip->set_number('6128248')->is_valid_number, '京都府京都市伏見区下鳥羽上三栖町');
ok($zip->set_number('6128249')->is_valid_number, '京都府京都市伏見区横大路沼');
ok($zip->set_number('6128251')->is_valid_number, '京都府京都市伏見区横大路菅本');
ok($zip->set_number('6128252')->is_valid_number, '京都府京都市伏見区横大路一本木');
ok($zip->set_number('6128253')->is_valid_number, '京都府京都市伏見区横大路八反田');
ok($zip->set_number('6128254')->is_valid_number, '京都府京都市伏見区横大路北ノ口町');
ok($zip->set_number('6128255')->is_valid_number, '京都府京都市伏見区横大路六反畑');
ok($zip->set_number('6128256')->is_valid_number, '京都府京都市伏見区横大路前川町');
ok($zip->set_number('6128257')->is_valid_number, '京都府京都市伏見区横大路富ノ森町');
ok($zip->set_number('6128261')->is_valid_number, '京都府京都市伏見区横大路西海道');
ok($zip->set_number('6128262')->is_valid_number, '京都府京都市伏見区横大路神宮寺');
ok($zip->set_number('6128263')->is_valid_number, '京都府京都市伏見区横大路下ノ坪');
ok($zip->set_number('6128264')->is_valid_number, '京都府京都市伏見区横大路松林');
ok($zip->set_number('6128265')->is_valid_number, '京都府京都市伏見区葭島渡場島町');
ok($zip->set_number('6128266')->is_valid_number, '京都府京都市伏見区向島又兵衛');
ok($zip->set_number('6128267')->is_valid_number, '京都府京都市伏見区納所下野');
ok($zip->set_number('6128268')->is_valid_number, '京都府京都市伏見区納所大野');
ok($zip->set_number('6128271')->is_valid_number, '京都府京都市伏見区納所岸ノ下');
ok($zip->set_number('6128272')->is_valid_number, '京都府京都市伏見区納所中河原');
ok($zip->set_number('6128273')->is_valid_number, '京都府京都市伏見区納所和泉屋');
ok($zip->set_number('6128274')->is_valid_number, '京都府京都市伏見区納所星柳');
ok($zip->set_number('6128275')->is_valid_number, '京都府京都市伏見区納所町');
ok($zip->set_number('6128276')->is_valid_number, '京都府京都市伏見区納所薬師堂');
ok($zip->set_number('6128277')->is_valid_number, '京都府京都市伏見区納所妙徳寺');
ok($zip->set_number('6128278')->is_valid_number, '京都府京都市伏見区納所南城堀');
ok($zip->set_number('6128279')->is_valid_number, '京都府京都市伏見区納所北城堀');
ok($zip->set_number('6128281')->is_valid_number, '京都府京都市伏見区横大路上ノ浜町');
ok($zip->set_number('6128282')->is_valid_number, '京都府京都市伏見区横大路畑中町');
ok($zip->set_number('6128283')->is_valid_number, '京都府京都市伏見区横大路向ヒ');
ok($zip->set_number('6128284')->is_valid_number, '京都府京都市伏見区横大路畔ノ内');
ok($zip->set_number('6128285')->is_valid_number, '京都府京都市伏見区横大路龍ケ池');
ok($zip->set_number('6128286')->is_valid_number, '京都府京都市伏見区横大路長畑町');
ok($zip->set_number('6128287')->is_valid_number, '京都府京都市伏見区横大路中ノ島町');
ok($zip->set_number('6128291')->is_valid_number, '京都府京都市伏見区横大路天王後');
ok($zip->set_number('6128292')->is_valid_number, '京都府京都市伏見区横大路朱雀');
ok($zip->set_number('6128293')->is_valid_number, '京都府京都市伏見区横大路橋本');
ok($zip->set_number('6128294')->is_valid_number, '京都府京都市伏見区横大路天王前');
ok($zip->set_number('6128295')->is_valid_number, '京都府京都市伏見区横大路鍬ノ本');
ok($zip->set_number('6128296')->is_valid_number, '京都府京都市伏見区横大路柿ノ本町');
ok($zip->set_number('6128297')->is_valid_number, '京都府京都市伏見区横大路貴船');
ok($zip->set_number('6128301')->is_valid_number, '京都府京都市伏見区加賀屋町');
ok($zip->set_number('6128302')->is_valid_number, '京都府京都市伏見区雁金町');
ok($zip->set_number('6128303')->is_valid_number, '京都府京都市伏見区菱屋町');
ok($zip->set_number('6128304')->is_valid_number, '京都府京都市伏見区榎町');
ok($zip->set_number('6128305')->is_valid_number, '京都府京都市伏見区上神泉苑町');
ok($zip->set_number('6128306')->is_valid_number, '京都府京都市伏見区下神泉苑町');
ok($zip->set_number('6128307')->is_valid_number, '京都府京都市伏見区景勝町');
ok($zip->set_number('6128308')->is_valid_number, '京都府京都市伏見区鳥羽町');
ok($zip->set_number('6128311')->is_valid_number, '京都府京都市伏見区奈良屋町');
ok($zip->set_number('6128312')->is_valid_number, '京都府京都市伏見区津知橋町');
ok($zip->set_number('6128313')->is_valid_number, '京都府京都市伏見区西鍵屋町');
ok($zip->set_number('6128314')->is_valid_number, '京都府京都市伏見区住吉町');
ok($zip->set_number('6128315')->is_valid_number, '京都府京都市伏見区中之町');
ok($zip->set_number('6128316')->is_valid_number, '京都府京都市伏見区上板橋町');
ok($zip->set_number('6128317')->is_valid_number, '京都府京都市伏見区堀詰町');
ok($zip->set_number('6128318')->is_valid_number, '京都府京都市伏見区紙子屋町');
ok($zip->set_number('6128319')->is_valid_number, '京都府京都市伏見区石屋町');
ok($zip->set_number('6128321')->is_valid_number, '京都府京都市伏見区越前町');
ok($zip->set_number('6128322')->is_valid_number, '京都府京都市伏見区桝屋町');
ok($zip->set_number('6128323')->is_valid_number, '京都府京都市伏見区大和町');
ok($zip->set_number('6128324')->is_valid_number, '京都府京都市伏見区小豆屋町');
ok($zip->set_number('6128325')->is_valid_number, '京都府京都市伏見区清水町');
ok($zip->set_number('6128326')->is_valid_number, '京都府京都市伏見区東朱雀町');
ok($zip->set_number('6128327')->is_valid_number, '京都府京都市伏見区西朱雀町');
ok($zip->set_number('6128328')->is_valid_number, '京都府京都市伏見区等安町');
ok($zip->set_number('6128329')->is_valid_number, '京都府京都市伏見区黒茶屋町');
ok($zip->set_number('6128331')->is_valid_number, '京都府京都市伏見区菊屋町');
ok($zip->set_number('6128332')->is_valid_number, '京都府京都市伏見区樽屋町');
ok($zip->set_number('6128333')->is_valid_number, '京都府京都市伏見区白銀町');
ok($zip->set_number('6128334')->is_valid_number, '京都府京都市伏見区東大文字町');
ok($zip->set_number('6128335')->is_valid_number, '京都府京都市伏見区海老屋町');
ok($zip->set_number('6128336')->is_valid_number, '京都府京都市伏見区東大黒町');
ok($zip->set_number('6128337')->is_valid_number, '京都府京都市伏見区西大黒町');
ok($zip->set_number('6128338')->is_valid_number, '京都府京都市伏見区舞台町');
ok($zip->set_number('6128341')->is_valid_number, '京都府京都市伏見区聚楽町(丁目)');
ok($zip->set_number('6128342')->is_valid_number, '京都府京都市伏見区久米町');
ok($zip->set_number('6128343')->is_valid_number, '京都府京都市伏見区聚楽町(番地)');
ok($zip->set_number('6128344')->is_valid_number, '京都府京都市伏見区大津町');
ok($zip->set_number('6128345')->is_valid_number, '京都府京都市伏見区西堺町');
ok($zip->set_number('6128346')->is_valid_number, '京都府京都市伏見区松屋町');
ok($zip->set_number('6128347')->is_valid_number, '京都府京都市伏見区成町');
ok($zip->set_number('6128351')->is_valid_number, '京都府京都市伏見区土橋町');
ok($zip->set_number('6128352')->is_valid_number, '京都府京都市伏見区肥後町');
ok($zip->set_number('6128353')->is_valid_number, '京都府京都市伏見区東町');
ok($zip->set_number('6128354')->is_valid_number, '京都府京都市伏見区西町');
ok($zip->set_number('6128355')->is_valid_number, '京都府京都市伏見区東菱屋町');
ok($zip->set_number('6128356')->is_valid_number, '京都府京都市伏見区革屋町');
ok($zip->set_number('6128357')->is_valid_number, '京都府京都市伏見区帯屋町');
ok($zip->set_number('6128358')->is_valid_number, '京都府京都市伏見区西尼崎町');
ok($zip->set_number('6128359')->is_valid_number, '京都府京都市伏見区問屋町');
ok($zip->set_number('6128361')->is_valid_number, '京都府京都市伏見区片原町');
ok($zip->set_number('6128362')->is_valid_number, '京都府京都市伏見区西大手町');
ok($zip->set_number('6128363')->is_valid_number, '京都府京都市伏見区納屋町');
ok($zip->set_number('6128364')->is_valid_number, '京都府京都市伏見区下油掛町');
ok($zip->set_number('6128365')->is_valid_number, '京都府京都市伏見区車町');
ok($zip->set_number('6128366')->is_valid_number, '京都府京都市伏見区京橋町');
ok($zip->set_number('6128367')->is_valid_number, '京都府京都市伏見区山崎町');
ok($zip->set_number('6128368')->is_valid_number, '京都府京都市伏見区周防町');
ok($zip->set_number('6128369')->is_valid_number, '京都府京都市伏見区村上町');
ok($zip->set_number('6128371')->is_valid_number, '京都府京都市伏見区竹田松林町');
ok($zip->set_number('6128372')->is_valid_number, '京都府京都市伏見区北端町');
ok($zip->set_number('6128373')->is_valid_number, '京都府京都市伏見区毛利町');
ok($zip->set_number('6128374')->is_valid_number, '京都府京都市伏見区治部町');
ok($zip->set_number('6128375')->is_valid_number, '京都府京都市伏見区川東町');
ok($zip->set_number('6128376')->is_valid_number, '京都府京都市伏見区西大文字町');
ok($zip->set_number('6128377')->is_valid_number, '京都府京都市伏見区島津町');
ok($zip->set_number('6128379')->is_valid_number, '京都府京都市伏見区南寝小屋町');
ok($zip->set_number('6128381')->is_valid_number, '京都府京都市伏見区下鳥羽葭田町');
ok($zip->set_number('6128384')->is_valid_number, '京都府京都市伏見区下鳥羽浄春ケ前町');
ok($zip->set_number('6128385')->is_valid_number, '京都府京都市伏見区下鳥羽小柳町');
ok($zip->set_number('6128386')->is_valid_number, '京都府京都市伏見区下鳥羽澱女町');
ok($zip->set_number('6128387')->is_valid_number, '京都府京都市伏見区下鳥羽平塚町');
ok($zip->set_number('6128388')->is_valid_number, '京都府京都市伏見区北寝小屋町');
ok($zip->set_number('6128391')->is_valid_number, '京都府京都市伏見区下鳥羽芹川町');
ok($zip->set_number('6128392')->is_valid_number, '京都府京都市伏見区下鳥羽北ノ口町');
ok($zip->set_number('6128393')->is_valid_number, '京都府京都市伏見区下鳥羽渡瀬町');
ok($zip->set_number('6128394')->is_valid_number, '京都府京都市伏見区下鳥羽西芹川町');
ok($zip->set_number('6128395')->is_valid_number, '京都府京都市伏見区下鳥羽東芹川町');
ok($zip->set_number('6128401')->is_valid_number, '京都府京都市伏見区深草下川原町');
ok($zip->set_number('6128402')->is_valid_number, '京都府京都市伏見区深草川久保町');
ok($zip->set_number('6128403')->is_valid_number, '京都府京都市伏見区深草ヲカヤ町');
ok($zip->set_number('6128404')->is_valid_number, '京都府京都市伏見区深草向川原町');
ok($zip->set_number('6128405')->is_valid_number, '京都府京都市伏見区深草勧進橋町');
ok($zip->set_number('6128411')->is_valid_number, '京都府京都市伏見区竹田久保町');
ok($zip->set_number('6128412')->is_valid_number, '京都府京都市伏見区竹田中川原町');
ok($zip->set_number('6128413')->is_valid_number, '京都府京都市伏見区竹田三ツ杭町');
ok($zip->set_number('6128414')->is_valid_number, '京都府京都市伏見区竹田段川原町');
ok($zip->set_number('6128415')->is_valid_number, '京都府京都市伏見区竹田中島町');
ok($zip->set_number('6128416')->is_valid_number, '京都府京都市伏見区竹田流池町');
ok($zip->set_number('6128417')->is_valid_number, '京都府京都市伏見区竹田向代町川町');
ok($zip->set_number('6128418')->is_valid_number, '京都府京都市伏見区竹田向代町');
ok($zip->set_number('6128419')->is_valid_number, '京都府京都市伏見区竹田北三ツ杭町');
ok($zip->set_number('6128421')->is_valid_number, '京都府京都市伏見区竹田桶ノ井町');
ok($zip->set_number('6128422')->is_valid_number, '京都府京都市伏見区竹田七瀬川町');
ok($zip->set_number('6128423')->is_valid_number, '京都府京都市伏見区竹田内畑町');
ok($zip->set_number('6128425')->is_valid_number, '京都府京都市伏見区竹田田中殿町');
ok($zip->set_number('6128426')->is_valid_number, '京都府京都市伏見区竹田青池町');
ok($zip->set_number('6128427')->is_valid_number, '京都府京都市伏見区竹田真幡木町');
ok($zip->set_number('6128428')->is_valid_number, '京都府京都市伏見区竹田西桶ノ井町');
ok($zip->set_number('6128429')->is_valid_number, '京都府京都市伏見区竹田西段川原町');
ok($zip->set_number('6128431')->is_valid_number, '京都府京都市伏見区深草越後屋敷町');
ok($zip->set_number('6128432')->is_valid_number, '京都府京都市伏見区深草柴田屋敷町');
ok($zip->set_number('6128433')->is_valid_number, '京都府京都市伏見区深草善導寺町');
ok($zip->set_number('6128434')->is_valid_number, '京都府京都市伏見区深草加賀屋敷町');
ok($zip->set_number('6128435')->is_valid_number, '京都府京都市伏見区深草泓ノ壺町');
ok($zip->set_number('6128436')->is_valid_number, '京都府京都市伏見区深草新門丈町');
ok($zip->set_number('6128437')->is_valid_number, '京都府京都市伏見区深草小久保町');
ok($zip->set_number('6128438')->is_valid_number, '京都府京都市伏見区深草フチ町');
ok($zip->set_number('6128439')->is_valid_number, '京都府京都市伏見区深草五反田町');
ok($zip->set_number('6128441')->is_valid_number, '京都府京都市伏見区竹田醍醐田町');
ok($zip->set_number('6128442')->is_valid_number, '京都府京都市伏見区竹田狩賀町');
ok($zip->set_number('6128443')->is_valid_number, '京都府京都市伏見区竹田藁屋町');
ok($zip->set_number('6128444')->is_valid_number, '京都府京都市伏見区竹田田中宮町');
ok($zip->set_number('6128445')->is_valid_number, '京都府京都市伏見区竹田浄菩提院町');
ok($zip->set_number('6128446')->is_valid_number, '京都府京都市伏見区竹田中内畑町');
ok($zip->set_number('6128447')->is_valid_number, '京都府京都市伏見区竹田西内畑町');
ok($zip->set_number('6128448')->is_valid_number, '京都府京都市伏見区竹田東小屋ノ内町');
ok($zip->set_number('6128449')->is_valid_number, '京都府京都市伏見区竹田西小屋ノ内町');
ok($zip->set_number('6128450')->is_valid_number, '京都府京都市伏見区竹田鳥羽殿町');
ok($zip->set_number('6128451')->is_valid_number, '京都府京都市伏見区中島北ノ口町');
ok($zip->set_number('6128452')->is_valid_number, '京都府京都市伏見区中島堀端町');
ok($zip->set_number('6128454')->is_valid_number, '京都府京都市伏見区竹田泓ノ川町');
ok($zip->set_number('6128455')->is_valid_number, '京都府京都市伏見区中島外山町');
ok($zip->set_number('6128456')->is_valid_number, '京都府京都市伏見区中島中道町');
ok($zip->set_number('6128457')->is_valid_number, '京都府京都市伏見区中島宮ノ前町');
ok($zip->set_number('6128459')->is_valid_number, '京都府京都市伏見区中島鳥羽離宮町');
ok($zip->set_number('6128461')->is_valid_number, '京都府京都市伏見区中島流作町');
ok($zip->set_number('6128462')->is_valid_number, '京都府京都市伏見区中島秋ノ山町');
ok($zip->set_number('6128463')->is_valid_number, '京都府京都市伏見区中島御所ノ内町');
ok($zip->set_number('6128464')->is_valid_number, '京都府京都市伏見区中島前山町');
ok($zip->set_number('6128465')->is_valid_number, '京都府京都市伏見区中島樋ノ上町');
ok($zip->set_number('6128466')->is_valid_number, '京都府京都市伏見区下鳥羽城ノ越町');
ok($zip->set_number('6128467')->is_valid_number, '京都府京都市伏見区下鳥羽前田町');
ok($zip->set_number('6128468')->is_valid_number, '京都府京都市伏見区下鳥羽上向島町');
ok($zip->set_number('6128469')->is_valid_number, '京都府京都市伏見区中島河原田町');
ok($zip->set_number('6128471')->is_valid_number, '京都府京都市伏見区下鳥羽長田町');
ok($zip->set_number('6128473')->is_valid_number, '京都府京都市伏見区下鳥羽広長町');
ok($zip->set_number('6128476')->is_valid_number, '京都府京都市伏見区下鳥羽北三町');
ok($zip->set_number('6128477')->is_valid_number, '京都府京都市伏見区下鳥羽中三町');
ok($zip->set_number('6128478')->is_valid_number, '京都府京都市伏見区下鳥羽南三町');
ok($zip->set_number('6128481')->is_valid_number, '京都府京都市伏見区横大路東裏町');
ok($zip->set_number('6128482')->is_valid_number, '京都府京都市伏見区横大路中ノ庄町');
ok($zip->set_number('6128483')->is_valid_number, '京都府京都市伏見区横大路草津町');
ok($zip->set_number('6128484')->is_valid_number, '京都府京都市伏見区羽束師鴨川町');
ok($zip->set_number('6128485')->is_valid_number, '京都府京都市伏見区羽束師志水町');
ok($zip->set_number('6128486')->is_valid_number, '京都府京都市伏見区羽束師古川町');
ok($zip->set_number('6128487')->is_valid_number, '京都府京都市伏見区羽束師菱川町');
ok($zip->set_number('6128488')->is_valid_number, '京都府京都市伏見区下鳥羽東柳長町');
ok($zip->set_number('6128489')->is_valid_number, '京都府京都市伏見区下鳥羽西柳長町');
ok($zip->set_number('6128490')->is_valid_number, '京都府京都市伏見区下鳥羽南柳長町');
ok($zip->set_number('6128491')->is_valid_number, '京都府京都市伏見区久我石原町');
ok($zip->set_number('6128492')->is_valid_number, '京都府京都市伏見区久我本町');
ok($zip->set_number('6128493')->is_valid_number, '京都府京都市伏見区久我御旅町');
ok($zip->set_number('6128494')->is_valid_number, '京都府京都市伏見区久我東町');
ok($zip->set_number('6128495')->is_valid_number, '京都府京都市伏見区久我森の宮町');
ok($zip->set_number('6128496')->is_valid_number, '京都府京都市伏見区久我西出町');
ok($zip->set_number('6128497')->is_valid_number, '京都府京都市伏見区下鳥羽北円面田町');
ok($zip->set_number('6128498')->is_valid_number, '京都府京都市伏見区下鳥羽中円面田町');
ok($zip->set_number('6128499')->is_valid_number, '京都府京都市伏見区下鳥羽南円面田町');
ok($zip->set_number('6130000')->is_valid_number, '京都府久世郡久御山町以下に掲載がない場合');
ok($zip->set_number('6130021')->is_valid_number, '京都府久世郡久御山町東一口');
ok($zip->set_number('6130022')->is_valid_number, '京都府久世郡久御山町市田');
ok($zip->set_number('6130023')->is_valid_number, '京都府久世郡久御山町野村');
ok($zip->set_number('6130024')->is_valid_number, '京都府久世郡久御山町森');
ok($zip->set_number('6130025')->is_valid_number, '京都府久世郡久御山町相島');
ok($zip->set_number('6130026')->is_valid_number, '京都府久世郡久御山町西一口');
ok($zip->set_number('6130031')->is_valid_number, '京都府久世郡久御山町佐古');
ok($zip->set_number('6130032')->is_valid_number, '京都府久世郡久御山町栄');
ok($zip->set_number('6130033')->is_valid_number, '京都府久世郡久御山町林');
ok($zip->set_number('6130034')->is_valid_number, '京都府久世郡久御山町佐山');
ok($zip->set_number('6130035')->is_valid_number, '京都府久世郡久御山町下津屋');
ok($zip->set_number('6130036')->is_valid_number, '京都府久世郡久御山町田井');
ok($zip->set_number('6130041')->is_valid_number, '京都府久世郡久御山町中島');
ok($zip->set_number('6130042')->is_valid_number, '京都府久世郡久御山町坊之池');
ok($zip->set_number('6130043')->is_valid_number, '京都府久世郡久御山町島田');
ok($zip->set_number('6130044')->is_valid_number, '京都府久世郡久御山町藤和田');
ok($zip->set_number('6130045')->is_valid_number, '京都府久世郡久御山町北川顔');
ok($zip->set_number('6130046')->is_valid_number, '京都府久世郡久御山町大橋辺');
ok($zip->set_number('6130851')->is_valid_number, '京都府八幡市川口高原');
ok($zip->set_number('6130852')->is_valid_number, '京都府八幡市八幡樋ノ口');
ok($zip->set_number('6130853')->is_valid_number, '京都府八幡市八幡長町');
ok($zip->set_number('6130901')->is_valid_number, '京都府京都市伏見区淀樋爪町');
ok($zip->set_number('6130902')->is_valid_number, '京都府京都市伏見区淀水垂町');
ok($zip->set_number('6130903')->is_valid_number, '京都府京都市伏見区淀本町');
ok($zip->set_number('6130904')->is_valid_number, '京都府京都市伏見区淀池上町');
ok($zip->set_number('6130905')->is_valid_number, '京都府京都市伏見区淀下津町');
ok($zip->set_number('6130906')->is_valid_number, '京都府京都市伏見区淀新町');
ok($zip->set_number('6130907')->is_valid_number, '京都府京都市伏見区淀大下津町');
ok($zip->set_number('6130911')->is_valid_number, '京都府京都市伏見区淀木津町');
ok($zip->set_number('6130912')->is_valid_number, '京都府京都市伏見区淀川顔町');
ok($zip->set_number('6130913')->is_valid_number, '京都府京都市伏見区向島下五反田');
ok($zip->set_number('6130914')->is_valid_number, '京都府京都市伏見区淀生津町');
ok($zip->set_number('6130915')->is_valid_number, '京都府京都市伏見区淀際目町');
ok($zip->set_number('6130916')->is_valid_number, '京都府京都市伏見区淀美豆町');
ok($zip->set_number('6140000')->is_valid_number, '京都府八幡市以下に掲載がない場合');
ok($zip->set_number('6148001')->is_valid_number, '京都府八幡市八幡科手');
ok($zip->set_number('6148002')->is_valid_number, '京都府八幡市八幡土井');
ok($zip->set_number('6148003')->is_valid_number, '京都府八幡市八幡千束');
ok($zip->set_number('6148004')->is_valid_number, '京都府八幡市八幡山柴');
ok($zip->set_number('6148005')->is_valid_number, '京都府八幡市八幡高坊');
ok($zip->set_number('6148006')->is_valid_number, '京都府八幡市八幡大谷');
ok($zip->set_number('6148007')->is_valid_number, '京都府八幡市八幡西高坊');
ok($zip->set_number('6148008')->is_valid_number, '京都府八幡市八幡平ノ山');
ok($zip->set_number('6148011')->is_valid_number, '京都府八幡市八幡垣内山');
ok($zip->set_number('6148012')->is_valid_number, '京都府八幡市八幡吉野');
ok($zip->set_number('6148013')->is_valid_number, '京都府八幡市八幡吉野垣内');
ok($zip->set_number('6148014')->is_valid_number, '京都府八幡市八幡北浦');
ok($zip->set_number('6148015')->is_valid_number, '京都府八幡市八幡旦所');
ok($zip->set_number('6148016')->is_valid_number, '京都府八幡市八幡山路');
ok($zip->set_number('6148017')->is_valid_number, '京都府八幡市八幡柴座');
ok($zip->set_number('6148021')->is_valid_number, '京都府八幡市八幡森垣内');
ok($zip->set_number('6148022')->is_valid_number, '京都府八幡市八幡東浦');
ok($zip->set_number('6148023')->is_valid_number, '京都府八幡市八幡名残');
ok($zip->set_number('6148024')->is_valid_number, '京都府八幡市八幡双栗');
ok($zip->set_number('6148025')->is_valid_number, '京都府八幡市八幡源氏垣外');
ok($zip->set_number('6148026')->is_valid_number, '京都府八幡市八幡森');
ok($zip->set_number('6148030')->is_valid_number, '京都府八幡市八幡東島');
ok($zip->set_number('6148031')->is_valid_number, '京都府八幡市八幡小西');
ok($zip->set_number('6148032')->is_valid_number, '京都府八幡市八幡番賀');
ok($zip->set_number('6148033')->is_valid_number, '京都府八幡市八幡西島');
ok($zip->set_number('6148034')->is_valid_number, '京都府八幡市八幡舞台');
ok($zip->set_number('6148035')->is_valid_number, '京都府八幡市八幡小松');
ok($zip->set_number('6148036')->is_valid_number, '京都府八幡市八幡柿木垣内');
ok($zip->set_number('6148037')->is_valid_number, '京都府八幡市八幡高畑');
ok($zip->set_number('6148038')->is_valid_number, '京都府八幡市八幡園内');
ok($zip->set_number('6148039')->is_valid_number, '京都府八幡市八幡苗田');
ok($zip->set_number('6148041')->is_valid_number, '京都府八幡市八幡吉原');
ok($zip->set_number('6148042')->is_valid_number, '京都府八幡市八幡盛戸');
ok($zip->set_number('6148043')->is_valid_number, '京都府八幡市八幡一ノ坪');
ok($zip->set_number('6148044')->is_valid_number, '京都府八幡市八幡御幸谷');
ok($zip->set_number('6148045')->is_valid_number, '京都府八幡市八幡久保田');
ok($zip->set_number('6148046')->is_valid_number, '京都府八幡市八幡砂田');
ok($zip->set_number('6148047')->is_valid_number, '京都府八幡市八幡月夜田');
ok($zip->set_number('6148048')->is_valid_number, '京都府八幡市八幡備前');
ok($zip->set_number('6148051')->is_valid_number, '京都府八幡市八幡山田');
ok($zip->set_number('6148052')->is_valid_number, '京都府八幡市八幡武蔵芝');
ok($zip->set_number('6148053')->is_valid_number, '京都府八幡市八幡水珀');
ok($zip->set_number('6148054')->is_valid_number, '京都府八幡市八幡南山');
ok($zip->set_number('6148055')->is_valid_number, '京都府八幡市八幡柿ケ谷');
ok($zip->set_number('6148056')->is_valid_number, '京都府八幡市八幡福禄谷');
ok($zip->set_number('6148057')->is_valid_number, '京都府八幡市八幡安居塚');
ok($zip->set_number('6148058')->is_valid_number, '京都府八幡市八幡長谷');
ok($zip->set_number('6148061')->is_valid_number, '京都府八幡市八幡式部谷');
ok($zip->set_number('6148062')->is_valid_number, '京都府八幡市八幡清水井');
ok($zip->set_number('6148063')->is_valid_number, '京都府八幡市八幡岸本');
ok($zip->set_number('6148064')->is_valid_number, '京都府八幡市八幡松原');
ok($zip->set_number('6148065')->is_valid_number, '京都府八幡市八幡山下');
ok($zip->set_number('6148066')->is_valid_number, '京都府八幡市八幡大芝');
ok($zip->set_number('6148067')->is_valid_number, '京都府八幡市八幡中ノ山');
ok($zip->set_number('6148068')->is_valid_number, '京都府八幡市八幡隅田口');
ok($zip->set_number('6148071')->is_valid_number, '京都府八幡市八幡五反田');
ok($zip->set_number('6148072')->is_valid_number, '京都府八幡市八幡長田');
ok($zip->set_number('6148073')->is_valid_number, '京都府八幡市八幡軸');
ok($zip->set_number('6148074')->is_valid_number, '京都府八幡市八幡渡ル瀬');
ok($zip->set_number('6148075')->is_valid_number, '京都府八幡市八幡三反長');
ok($zip->set_number('6148076')->is_valid_number, '京都府八幡市八幡植松');
ok($zip->set_number('6148077')->is_valid_number, '京都府八幡市八幡女郎花');
ok($zip->set_number('6148078')->is_valid_number, '京都府八幡市八幡広門');
ok($zip->set_number('6148079')->is_valid_number, '京都府八幡市八幡東林');
ok($zip->set_number('6148081')->is_valid_number, '京都府八幡市八幡御馬所');
ok($zip->set_number('6148082')->is_valid_number, '京都府八幡市八幡菖蒲池');
ok($zip->set_number('6148083')->is_valid_number, '京都府八幡市八幡山本');
ok($zip->set_number('6148084')->is_valid_number, '京都府八幡市八幡今田');
ok($zip->set_number('6148085')->is_valid_number, '京都府八幡市八幡馬場');
ok($zip->set_number('6148086')->is_valid_number, '京都府八幡市八幡河原崎');
ok($zip->set_number('6148087')->is_valid_number, '京都府八幡市八幡神原');
ok($zip->set_number('6148088')->is_valid_number, '京都府八幡市八幡石不動');
ok($zip->set_number('6148091')->is_valid_number, '京都府八幡市八幡平谷');
ok($zip->set_number('6148092')->is_valid_number, '京都府八幡市八幡城ノ内');
ok($zip->set_number('6148093')->is_valid_number, '京都府八幡市八幡三本橋');
ok($zip->set_number('6148094')->is_valid_number, '京都府八幡市八幡平田');
ok($zip->set_number('6148095')->is_valid_number, '京都府八幡市八幡沓田');
ok($zip->set_number('6148096')->is_valid_number, '京都府八幡市八幡三ノ甲');
ok($zip->set_number('6148101')->is_valid_number, '京都府八幡市川口浜');
ok($zip->set_number('6148102')->is_valid_number, '京都府八幡市川口北浦');
ok($zip->set_number('6148103')->is_valid_number, '京都府八幡市川口堀ノ内');
ok($zip->set_number('6148104')->is_valid_number, '京都府八幡市川口東頭');
ok($zip->set_number('6148105')->is_valid_number, '京都府八幡市川口擬宝珠');
ok($zip->set_number('6148106')->is_valid_number, '京都府八幡市川口天神崎');
ok($zip->set_number('6148111')->is_valid_number, '京都府八幡市川口小西');
ok($zip->set_number('6148112')->is_valid_number, '京都府八幡市川口馬屋尻');
ok($zip->set_number('6148113')->is_valid_number, '京都府八幡市川口萩原');
ok($zip->set_number('6148114')->is_valid_number, '京都府八幡市川口別所');
ok($zip->set_number('6148115')->is_valid_number, '京都府八幡市川口扇ノ芝');
ok($zip->set_number('6148116')->is_valid_number, '京都府八幡市川口東扇');
ok($zip->set_number('6148117')->is_valid_number, '京都府八幡市川口西扇');
ok($zip->set_number('6148121')->is_valid_number, '京都府八幡市下奈良小宮');
ok($zip->set_number('6148122')->is_valid_number, '京都府八幡市下奈良一丁堤');
ok($zip->set_number('6148123')->is_valid_number, '京都府八幡市下奈良名越');
ok($zip->set_number('6148124')->is_valid_number, '京都府八幡市下奈良奥垣内');
ok($zip->set_number('6148125')->is_valid_number, '京都府八幡市下奈良出垣内');
ok($zip->set_number('6148126')->is_valid_number, '京都府八幡市下奈良下三床');
ok($zip->set_number('6148127')->is_valid_number, '京都府八幡市下奈良隅田');
ok($zip->set_number('6148128')->is_valid_number, '京都府八幡市下奈良野神');
ok($zip->set_number('6148131')->is_valid_number, '京都府八幡市下奈良宮ノ道');
ok($zip->set_number('6148132')->is_valid_number, '京都府八幡市下奈良榊');
ok($zip->set_number('6148133')->is_valid_number, '京都府八幡市下奈良新下');
ok($zip->set_number('6148134')->is_valid_number, '京都府八幡市下奈良中ノ坪');
ok($zip->set_number('6148135')->is_valid_number, '京都府八幡市下奈良蜻蛉尻筋');
ok($zip->set_number('6148136')->is_valid_number, '京都府八幡市下奈良蜻蛉尻');
ok($zip->set_number('6148141')->is_valid_number, '京都府八幡市下奈良上三床');
ok($zip->set_number('6148142')->is_valid_number, '京都府八幡市下奈良南頭');
ok($zip->set_number('6148143')->is_valid_number, '京都府八幡市下奈良一丁地');
ok($zip->set_number('6148144')->is_valid_number, '京都府八幡市下奈良奈良元');
ok($zip->set_number('6148145')->is_valid_number, '京都府八幡市下奈良二階堂');
ok($zip->set_number('6148146')->is_valid_number, '京都府八幡市下奈良上ノ段');
ok($zip->set_number('6148147')->is_valid_number, '京都府八幡市下奈良今里');
ok($zip->set_number('6148148')->is_valid_number, '京都府八幡市下奈良井関');
ok($zip->set_number('6148149')->is_valid_number, '京都府八幡市下奈良竹垣内');
ok($zip->set_number('6148151')->is_valid_number, '京都府八幡市上奈良小端');
ok($zip->set_number('6148152')->is_valid_number, '京都府八幡市上奈良御園');
ok($zip->set_number('6148153')->is_valid_number, '京都府八幡市上奈良サグリ前');
ok($zip->set_number('6148154')->is_valid_number, '京都府八幡市上奈良宮ノ西');
ok($zip->set_number('6148155')->is_valid_number, '京都府八幡市上奈良城垣内');
ok($zip->set_number('6148156')->is_valid_number, '京都府八幡市上奈良奈良里');
ok($zip->set_number('6148157')->is_valid_number, '京都府八幡市上奈良東ノ口');
ok($zip->set_number('6148158')->is_valid_number, '京都府八幡市上奈良北ノ口');
ok($zip->set_number('6148159')->is_valid_number, '京都府八幡市上奈良大門');
ok($zip->set_number('6148161')->is_valid_number, '京都府八幡市上奈良宮ノ東');
ok($zip->set_number('6148162')->is_valid_number, '京都府八幡市上奈良日ノ尾');
ok($zip->set_number('6148163')->is_valid_number, '京都府八幡市上奈良長池');
ok($zip->set_number('6148164')->is_valid_number, '京都府八幡市上奈良南ノ口');
ok($zip->set_number('6148165')->is_valid_number, '京都府八幡市上奈良池ノ向');
ok($zip->set_number('6148166')->is_valid_number, '京都府八幡市上奈良堂島');
ok($zip->set_number('6148171')->is_valid_number, '京都府八幡市上津屋尼ケ池');
ok($zip->set_number('6148172')->is_valid_number, '京都府八幡市上津屋林');
ok($zip->set_number('6148173')->is_valid_number, '京都府八幡市上津屋里垣内');
ok($zip->set_number('6148174')->is_valid_number, '京都府八幡市上津屋八王子');
ok($zip->set_number('6148175')->is_valid_number, '京都府八幡市上津屋石ノ塔');
ok($zip->set_number('6148176')->is_valid_number, '京都府八幡市上津屋中堤');
ok($zip->set_number('6148181')->is_valid_number, '京都府八幡市上津屋浜垣内');
ok($zip->set_number('6148182')->is_valid_number, '京都府八幡市上津屋南村');
ok($zip->set_number('6148183')->is_valid_number, '京都府八幡市上津屋西久保');
ok($zip->set_number('6148184')->is_valid_number, '京都府八幡市上津屋八丁');
ok($zip->set_number('6148191')->is_valid_number, '京都府八幡市野尻北ノ口');
ok($zip->set_number('6148192')->is_valid_number, '京都府八幡市野尻土井ノ内');
ok($zip->set_number('6148193')->is_valid_number, '京都府八幡市野尻一庵');
ok($zip->set_number('6148194')->is_valid_number, '京都府八幡市野尻円ノ元');
ok($zip->set_number('6148195')->is_valid_number, '京都府八幡市野尻城究');
ok($zip->set_number('6148196')->is_valid_number, '京都府八幡市野尻正畑');
ok($zip->set_number('6148197')->is_valid_number, '京都府八幡市野尻倉掛');
ok($zip->set_number('6148201')->is_valid_number, '京都府八幡市戸津南小路');
ok($zip->set_number('6148202')->is_valid_number, '京都府八幡市戸津東ノ口');
ok($zip->set_number('6148203')->is_valid_number, '京都府八幡市戸津中垣内');
ok($zip->set_number('6148204')->is_valid_number, '京都府八幡市戸津蜻蛉尻');
ok($zip->set_number('6148205')->is_valid_number, '京都府八幡市戸津東代');
ok($zip->set_number('6148206')->is_valid_number, '京都府八幡市戸津正ノ竹');
ok($zip->set_number('6148207')->is_valid_number, '京都府八幡市戸津北小路');
ok($zip->set_number('6148208')->is_valid_number, '京都府八幡市戸津荒堀');
ok($zip->set_number('6148211')->is_valid_number, '京都府八幡市戸津小中代');
ok($zip->set_number('6148212')->is_valid_number, '京都府八幡市戸津中代');
ok($zip->set_number('6148213')->is_valid_number, '京都府八幡市戸津南代');
ok($zip->set_number('6148214')->is_valid_number, '京都府八幡市戸津水戸城');
ok($zip->set_number('6148215')->is_valid_number, '京都府八幡市戸津堂田');
ok($zip->set_number('6148216')->is_valid_number, '京都府八幡市戸津谷ノ口');
ok($zip->set_number('6148221')->is_valid_number, '京都府八幡市内里蜻蛉尻');
ok($zip->set_number('6148222')->is_valid_number, '京都府八幡市内里極楽橋');
ok($zip->set_number('6148223')->is_valid_number, '京都府八幡市内里北ノ山');
ok($zip->set_number('6148224')->is_valid_number, '京都府八幡市内里別所');
ok($zip->set_number('6148225')->is_valid_number, '京都府八幡市内里砂田');
ok($zip->set_number('6148226')->is_valid_number, '京都府八幡市内里東ノ口');
ok($zip->set_number('6148227')->is_valid_number, '京都府八幡市内里内');
ok($zip->set_number('6148228')->is_valid_number, '京都府八幡市内里菅井');
ok($zip->set_number('6148229')->is_valid_number, '京都府八幡市内里北ノ口');
ok($zip->set_number('6148230')->is_valid_number, '京都府八幡市内里平尾');
ok($zip->set_number('6148231')->is_valid_number, '京都府八幡市内里安居芝');
ok($zip->set_number('6148232')->is_valid_number, '京都府八幡市内里荒場');
ok($zip->set_number('6148233')->is_valid_number, '京都府八幡市内里河原');
ok($zip->set_number('6148234')->is_valid_number, '京都府八幡市内里女谷');
ok($zip->set_number('6148235')->is_valid_number, '京都府八幡市内里穴ケ谷');
ok($zip->set_number('6148236')->is_valid_number, '京都府八幡市内里柿谷');
ok($zip->set_number('6148237')->is_valid_number, '京都府八幡市内里西山川');
ok($zip->set_number('6148238')->is_valid_number, '京都府八幡市内里砂畠');
ok($zip->set_number('6148239')->is_valid_number, '京都府八幡市内里大谷');
ok($zip->set_number('6148241')->is_valid_number, '京都府八幡市内里宮ノ前');
ok($zip->set_number('6148242')->is_valid_number, '京都府八幡市内里巽ノ口');
ok($zip->set_number('6148243')->is_valid_number, '京都府八幡市内里松ケ外');
ok($zip->set_number('6148244')->is_valid_number, '京都府八幡市内里東山川');
ok($zip->set_number('6148245')->is_valid_number, '京都府八幡市内里古溜池');
ok($zip->set_number('6148246')->is_valid_number, '京都府八幡市内里南ノ口');
ok($zip->set_number('6148247')->is_valid_number, '京都府八幡市内里日向堂');
ok($zip->set_number('6148248')->is_valid_number, '京都府八幡市内里中島');
ok($zip->set_number('6148249')->is_valid_number, '京都府八幡市内里五丁');
ok($zip->set_number('6148251')->is_valid_number, '京都府八幡市岩田茶屋ノ前');
ok($zip->set_number('6148252')->is_valid_number, '京都府八幡市岩田大将軍');
ok($zip->set_number('6148253')->is_valid_number, '京都府八幡市岩田西玉造');
ok($zip->set_number('6148254')->is_valid_number, '京都府八幡市岩田北ノ口');
ok($zip->set_number('6148255')->is_valid_number, '京都府八幡市岩田竹綱');
ok($zip->set_number('6148256')->is_valid_number, '京都府八幡市岩田岩ノ前');
ok($zip->set_number('6148257')->is_valid_number, '京都府八幡市岩田橋溝');
ok($zip->set_number('6148258')->is_valid_number, '京都府八幡市岩田加賀ノ辻');
ok($zip->set_number('6148261')->is_valid_number, '京都府八幡市岩田辻垣内');
ok($zip->set_number('6148262')->is_valid_number, '京都府八幡市岩田松原');
ok($zip->set_number('6148263')->is_valid_number, '京都府八幡市岩田六ノ坪');
ok($zip->set_number('6148264')->is_valid_number, '京都府八幡市岩田南野');
ok($zip->set_number('6148265')->is_valid_number, '京都府八幡市岩田南浅地');
ok($zip->set_number('6148266')->is_valid_number, '京都府八幡市岩田八丁');
ok($zip->set_number('6148267')->is_valid_number, '京都府八幡市岩田北浅地');
ok($zip->set_number('6148268')->is_valid_number, '京都府八幡市岩田高木');
ok($zip->set_number('6148271')->is_valid_number, '京都府八幡市美濃山ヒル塚');
ok($zip->set_number('6148272')->is_valid_number, '京都府八幡市美濃山御幸');
ok($zip->set_number('6148273')->is_valid_number, '京都府八幡市美濃山井ノ元');
ok($zip->set_number('6148274')->is_valid_number, '京都府八幡市美濃山野神');
ok($zip->set_number('6148275')->is_valid_number, '京都府八幡市美濃山中尾');
ok($zip->set_number('6148276')->is_valid_number, '京都府八幡市美濃山宮道');
ok($zip->set_number('6148277')->is_valid_number, '京都府八幡市美濃山宮ノ背');
ok($zip->set_number('6148278')->is_valid_number, '京都府八幡市美濃山西ノ口');
ok($zip->set_number('6148279')->is_valid_number, '京都府八幡市美濃山幸水');
ok($zip->set_number('6148280')->is_valid_number, '京都府八幡市戸津奥谷');
ok($zip->set_number('6148281')->is_valid_number, '京都府八幡市美濃山狐谷');
ok($zip->set_number('6148282')->is_valid_number, '京都府八幡市美濃山大塚');
ok($zip->set_number('6148283')->is_valid_number, '京都府八幡市美濃山細谷');
ok($zip->set_number('6148284')->is_valid_number, '京都府八幡市美濃山馬ケ背');
ok($zip->set_number('6148285')->is_valid_number, '京都府八幡市美濃山御幸谷');
ok($zip->set_number('6148286')->is_valid_number, '京都府八幡市美濃山千原谷');
ok($zip->set_number('6148287')->is_valid_number, '京都府八幡市美濃山出口');
ok($zip->set_number('6148288')->is_valid_number, '京都府八幡市美濃山出島');
ok($zip->set_number('6148289')->is_valid_number, '京都府八幡市美濃山一ノ谷');
ok($zip->set_number('6148294')->is_valid_number, '京都府八幡市欽明台北');
ok($zip->set_number('6148295')->is_valid_number, '京都府八幡市欽明台中央');
ok($zip->set_number('6148296')->is_valid_number, '京都府八幡市欽明台東');
ok($zip->set_number('6148297')->is_valid_number, '京都府八幡市欽明台西');
ok($zip->set_number('6148298')->is_valid_number, '京都府八幡市美濃山古寺');
ok($zip->set_number('6148301')->is_valid_number, '京都府八幡市八幡池ノ首');
ok($zip->set_number('6148302')->is_valid_number, '京都府八幡市八幡カイトリ');
ok($zip->set_number('6148303')->is_valid_number, '京都府八幡市八幡菰池');
ok($zip->set_number('6148304')->is_valid_number, '京都府八幡市八幡源野');
ok($zip->set_number('6148305')->is_valid_number, '京都府八幡市八幡焼木');
ok($zip->set_number('6148306')->is_valid_number, '京都府八幡市八幡沢');
ok($zip->set_number('6148307')->is_valid_number, '京都府八幡市八幡在応寺');
ok($zip->set_number('6148308')->is_valid_number, '京都府八幡市八幡八萩');
ok($zip->set_number('6148311')->is_valid_number, '京都府八幡市橋本奥ノ町');
ok($zip->set_number('6148312')->is_valid_number, '京都府八幡市橋本尻江');
ok($zip->set_number('6148313')->is_valid_number, '京都府八幡市橋本東山本');
ok($zip->set_number('6148314')->is_valid_number, '京都府八幡市橋本西山本');
ok($zip->set_number('6148315')->is_valid_number, '京都府八幡市橋本北ノ町');
ok($zip->set_number('6148321')->is_valid_number, '京都府八幡市橋本米ノ尾');
ok($zip->set_number('6148322')->is_valid_number, '京都府八幡市橋本狩尾');
ok($zip->set_number('6148323')->is_valid_number, '京都府八幡市橋本興正');
ok($zip->set_number('6148324')->is_valid_number, '京都府八幡市橋本東浄土ケ原');
ok($zip->set_number('6148325')->is_valid_number, '京都府八幡市橋本北浄土ケ原');
ok($zip->set_number('6148326')->is_valid_number, '京都府八幡市橋本石ケ谷');
ok($zip->set_number('6148327')->is_valid_number, '京都府八幡市橋本栗ケ谷');
ok($zip->set_number('6148331')->is_valid_number, '京都府八幡市橋本意足');
ok($zip->set_number('6148332')->is_valid_number, '京都府八幡市橋本新石');
ok($zip->set_number('6148333')->is_valid_number, '京都府八幡市橋本東刈又');
ok($zip->set_number('6148334')->is_valid_number, '京都府八幡市橋本西刈又');
ok($zip->set_number('6148335')->is_valid_number, '京都府八幡市橋本中ノ池尻');
ok($zip->set_number('6148336')->is_valid_number, '京都府八幡市橋本向山');
ok($zip->set_number('6148341')->is_valid_number, '京都府八幡市橋本中ノ町');
ok($zip->set_number('6148342')->is_valid_number, '京都府八幡市橋本小金川');
ok($zip->set_number('6148343')->is_valid_number, '京都府八幡市橋本焼野');
ok($zip->set_number('6148344')->is_valid_number, '京都府八幡市橋本堂ケ原');
ok($zip->set_number('6148345')->is_valid_number, '京都府八幡市橋本愛宕山');
ok($zip->set_number('6148346')->is_valid_number, '京都府八幡市橋本塩釜');
ok($zip->set_number('6148347')->is_valid_number, '京都府八幡市橋本平野山');
ok($zip->set_number('6148348')->is_valid_number, '京都府八幡市橋本東原');
ok($zip->set_number('6148349')->is_valid_number, '京都府八幡市橋本糸ケ上');
ok($zip->set_number('6148351')->is_valid_number, '京都府八幡市西山足立');
ok($zip->set_number('6148352')->is_valid_number, '京都府八幡市西山和気');
ok($zip->set_number('6148353')->is_valid_number, '京都府八幡市西山丸尾');
ok($zip->set_number('6148361')->is_valid_number, '京都府八幡市男山指月');
ok($zip->set_number('6148362')->is_valid_number, '京都府八幡市男山美桜');
ok($zip->set_number('6148363')->is_valid_number, '京都府八幡市男山吉井');
ok($zip->set_number('6148364')->is_valid_number, '京都府八幡市男山松里');
ok($zip->set_number('6148365')->is_valid_number, '京都府八幡市男山金振');
ok($zip->set_number('6148366')->is_valid_number, '京都府八幡市男山泉');
ok($zip->set_number('6148367')->is_valid_number, '京都府八幡市男山長沢');
ok($zip->set_number('6148371')->is_valid_number, '京都府八幡市男山雄徳');
ok($zip->set_number('6148372')->is_valid_number, '京都府八幡市男山笹谷');
ok($zip->set_number('6148373')->is_valid_number, '京都府八幡市男山八望');
ok($zip->set_number('6148374')->is_valid_number, '京都府八幡市男山石城');
ok($zip->set_number('6148375')->is_valid_number, '京都府八幡市男山弓岡');
ok($zip->set_number('6148376')->is_valid_number, '京都府八幡市男山竹園');
ok($zip->set_number('6148377')->is_valid_number, '京都府八幡市男山香呂');
ok($zip->set_number('6150001')->is_valid_number, '京都府京都市右京区西院上今田町');
ok($zip->set_number('6150002')->is_valid_number, '京都府京都市右京区西院東今田町');
ok($zip->set_number('6150003')->is_valid_number, '京都府京都市右京区西院西今田町');
ok($zip->set_number('6150004')->is_valid_number, '京都府京都市右京区西院下花田町');
ok($zip->set_number('6150005')->is_valid_number, '京都府京都市右京区西院春栄町');
ok($zip->set_number('6150006')->is_valid_number, '京都府京都市右京区西院金槌町');
ok($zip->set_number('6150007')->is_valid_number, '京都府京都市右京区西院上花田町');
ok($zip->set_number('6150011')->is_valid_number, '京都府京都市右京区西院東淳和院町');
ok($zip->set_number('6150012')->is_valid_number, '京都府京都市右京区西院高山寺町');
ok($zip->set_number('6150013')->is_valid_number, '京都府京都市右京区西院松井町');
ok($zip->set_number('6150014')->is_valid_number, '京都府京都市右京区西院巽町');
ok($zip->set_number('6150015')->is_valid_number, '京都府京都市右京区西院春日町');
ok($zip->set_number('6150016')->is_valid_number, '京都府京都市右京区西院西淳和院町');
ok($zip->set_number('6150021')->is_valid_number, '京都府京都市右京区西院三蔵町');
ok($zip->set_number('6150022')->is_valid_number, '京都府京都市右京区西院平町');
ok($zip->set_number('6150023')->is_valid_number, '京都府京都市右京区西院西平町');
ok($zip->set_number('6150024')->is_valid_number, '京都府京都市右京区西院矢掛町');
ok($zip->set_number('6150025')->is_valid_number, '京都府京都市右京区西院西矢掛町');
ok($zip->set_number('6150026')->is_valid_number, '京都府京都市右京区西院北矢掛町');
ok($zip->set_number('6150027')->is_valid_number, '京都府京都市右京区西院西三蔵町');
ok($zip->set_number('6150031')->is_valid_number, '京都府京都市右京区西院高田町');
ok($zip->set_number('6150032')->is_valid_number, '京都府京都市右京区西院西高田町');
ok($zip->set_number('6150033')->is_valid_number, '京都府京都市右京区西院寿町');
ok($zip->set_number('6150034')->is_valid_number, '京都府京都市右京区西院西寿町');
ok($zip->set_number('6150035')->is_valid_number, '京都府京都市右京区西院追分町');
ok($zip->set_number('6150036')->is_valid_number, '京都府京都市右京区西院太田町');
ok($zip->set_number('6150037')->is_valid_number, '京都府京都市右京区西院南井御料町');
ok($zip->set_number('6150041')->is_valid_number, '京都府京都市右京区西院南高田町');
ok($zip->set_number('6150042')->is_valid_number, '京都府京都市右京区西院東中水町');
ok($zip->set_number('6150043')->is_valid_number, '京都府京都市右京区西院中水町');
ok($zip->set_number('6150044')->is_valid_number, '京都府京都市右京区西院西中水町');
ok($zip->set_number('6150045')->is_valid_number, '京都府京都市右京区西院溝崎町');
ok($zip->set_number('6150046')->is_valid_number, '京都府京都市右京区西院西溝崎町');
ok($zip->set_number('6150047')->is_valid_number, '京都府京都市右京区西院六反田町');
ok($zip->set_number('6150048')->is_valid_number, '京都府京都市右京区西院南寿町');
ok($zip->set_number('6150051')->is_valid_number, '京都府京都市右京区西院安塚町');
ok($zip->set_number('6150052')->is_valid_number, '京都府京都市右京区西院清水町');
ok($zip->set_number('6150053')->is_valid_number, '京都府京都市右京区西院久保田町');
ok($zip->set_number('6150054')->is_valid_number, '京都府京都市右京区西院月双町');
ok($zip->set_number('6150055')->is_valid_number, '京都府京都市右京区西院西田町');
ok($zip->set_number('6150056')->is_valid_number, '京都府京都市右京区西院西貝川町');
ok($zip->set_number('6150057')->is_valid_number, '京都府京都市右京区西院東貝川町');
ok($zip->set_number('6150058')->is_valid_number, '京都府京都市右京区西院笠目町');
ok($zip->set_number('6150061')->is_valid_number, '京都府京都市右京区西院乾町');
ok($zip->set_number('6150062')->is_valid_number, '京都府京都市右京区西院坤町');
ok($zip->set_number('6150063')->is_valid_number, '京都府京都市右京区西院北井御料町');
ok($zip->set_number('6150064')->is_valid_number, '京都府京都市右京区西院久田町');
ok($zip->set_number('6150065')->is_valid_number, '京都府京都市右京区西院日照町');
ok($zip->set_number('6150066')->is_valid_number, '京都府京都市右京区西院四条畑町');
ok($zip->set_number('6150067')->is_valid_number, '京都府京都市右京区西院小米町');
ok($zip->set_number('6150071')->is_valid_number, '京都府京都市右京区山ノ内西裏町');
ok($zip->set_number('6150072')->is_valid_number, '京都府京都市右京区山ノ内池尻町');
ok($zip->set_number('6150073')->is_valid_number, '京都府京都市右京区山ノ内荒木町');
ok($zip->set_number('6150074')->is_valid_number, '京都府京都市右京区山ノ内苗町');
ok($zip->set_number('6150081')->is_valid_number, '京都府京都市右京区山ノ内養老町');
ok($zip->set_number('6150082')->is_valid_number, '京都府京都市右京区山ノ内赤山町');
ok($zip->set_number('6150083')->is_valid_number, '京都府京都市右京区山ノ内瀬戸畑町');
ok($zip->set_number('6150084')->is_valid_number, '京都府京都市右京区山ノ内山ノ下町');
ok($zip->set_number('6150085')->is_valid_number, '京都府京都市右京区山ノ内中畑町');
ok($zip->set_number('6150091')->is_valid_number, '京都府京都市右京区山ノ内御堂殿町');
ok($zip->set_number('6150092')->is_valid_number, '京都府京都市右京区山ノ内宮脇町');
ok($zip->set_number('6150093')->is_valid_number, '京都府京都市右京区山ノ内宮前町');
ok($zip->set_number('6150094')->is_valid_number, '京都府京都市右京区山ノ内北ノ口町');
ok($zip->set_number('6150095')->is_valid_number, '京都府京都市右京区山ノ内西八反田町');
ok($zip->set_number('6150096')->is_valid_number, '京都府京都市右京区山ノ内五反田町');
ok($zip->set_number('6150097')->is_valid_number, '京都府京都市右京区山ノ内大町');
ok($zip->set_number('6150801')->is_valid_number, '京都府京都市右京区西京極豆田町');
ok($zip->set_number('6150802')->is_valid_number, '京都府京都市右京区西京極北庄境町');
ok($zip->set_number('6150803')->is_valid_number, '京都府京都市右京区西京極南庄境町');
ok($zip->set_number('6150804')->is_valid_number, '京都府京都市右京区西京極町ノ坪町');
ok($zip->set_number('6150805')->is_valid_number, '京都府京都市右京区西京極東池田町');
ok($zip->set_number('6150806')->is_valid_number, '京都府京都市右京区西京極畔勝町');
ok($zip->set_number('6150807')->is_valid_number, '京都府京都市右京区西京極東大丸町');
ok($zip->set_number('6150811')->is_valid_number, '京都府京都市右京区西京極中溝町');
ok($zip->set_number('6150812')->is_valid_number, '京都府京都市右京区西京極大門町');
ok($zip->set_number('6150813')->is_valid_number, '京都府京都市右京区西京極佃田町');
ok($zip->set_number('6150814')->is_valid_number, '京都府京都市右京区西京極下沢町');
ok($zip->set_number('6150815')->is_valid_number, '京都府京都市右京区西京極中沢町');
ok($zip->set_number('6150816')->is_valid_number, '京都府京都市右京区西京極東町');
ok($zip->set_number('6150817')->is_valid_number, '京都府京都市右京区西京極宮ノ東町');
ok($zip->set_number('6150818')->is_valid_number, '京都府京都市右京区西京極三反田町');
ok($zip->set_number('6150821')->is_valid_number, '京都府京都市右京区西京極北裏町');
ok($zip->set_number('6150822')->is_valid_number, '京都府京都市右京区西京極中町');
ok($zip->set_number('6150823')->is_valid_number, '京都府京都市右京区西京極前田町');
ok($zip->set_number('6150824')->is_valid_number, '京都府京都市右京区西京極畑田町');
ok($zip->set_number('6150825')->is_valid_number, '京都府京都市右京区西京極東向河原町');
ok($zip->set_number('6150826')->is_valid_number, '京都府京都市右京区西京極芝ノ下町');
ok($zip->set_number('6150827')->is_valid_number, '京都府京都市右京区西京極南方町');
ok($zip->set_number('6150831')->is_valid_number, '京都府京都市右京区西京極長町');
ok($zip->set_number('6150832')->is_valid_number, '京都府京都市右京区西京極走上リ町');
ok($zip->set_number('6150833')->is_valid_number, '京都府京都市右京区西京極橋詰町');
ok($zip->set_number('6150834')->is_valid_number, '京都府京都市右京区西京極殿田町');
ok($zip->set_number('6150835')->is_valid_number, '京都府京都市右京区西京極堤下町');
ok($zip->set_number('6150836')->is_valid_number, '京都府京都市右京区西京極河原町裏町');
ok($zip->set_number('6150837')->is_valid_number, '京都府京都市右京区西京極西向河原町');
ok($zip->set_number('6150838')->is_valid_number, '京都府京都市右京区西京極薮ノ下町');
ok($zip->set_number('6150841')->is_valid_number, '京都府京都市右京区西京極火打畑町');
ok($zip->set_number('6150842')->is_valid_number, '京都府京都市右京区西京極薮開町');
ok($zip->set_number('6150843')->is_valid_number, '京都府京都市右京区西京極河原町');
ok($zip->set_number('6150844')->is_valid_number, '京都府京都市右京区西京極東側町');
ok($zip->set_number('6150845')->is_valid_number, '京都府京都市右京区西京極末広町');
ok($zip->set_number('6150846')->is_valid_number, '京都府京都市右京区西京極徳大寺団子田町');
ok($zip->set_number('6150851')->is_valid_number, '京都府京都市右京区西京極西池田町');
ok($zip->set_number('6150852')->is_valid_number, '京都府京都市右京区西京極西川町');
ok($zip->set_number('6150853')->is_valid_number, '京都府京都市右京区西京極郡醍醐田町');
ok($zip->set_number('6150854')->is_valid_number, '京都府京都市右京区西京極堤外町');
ok($zip->set_number('6150855')->is_valid_number, '京都府京都市右京区西京極西団子田町');
ok($zip->set_number('6150856')->is_valid_number, '京都府京都市右京区西京極古浜町');
ok($zip->set_number('6150857')->is_valid_number, '京都府京都市右京区西京極郡猪馬場町');
ok($zip->set_number('6150858')->is_valid_number, '京都府京都市右京区西京極郡沢町');
ok($zip->set_number('6150861')->is_valid_number, '京都府京都市右京区西京極野田町');
ok($zip->set_number('6150862')->is_valid_number, '京都府京都市右京区西京極西大丸町');
ok($zip->set_number('6150863')->is_valid_number, '京都府京都市右京区西京極堤町');
ok($zip->set_number('6150864')->is_valid_number, '京都府京都市右京区西京極新明町');
ok($zip->set_number('6150871')->is_valid_number, '京都府京都市右京区西京極東衣手町');
ok($zip->set_number('6150872')->is_valid_number, '京都府京都市右京区西京極南衣手町');
ok($zip->set_number('6150873')->is_valid_number, '京都府京都市右京区西京極浜ノ本町');
ok($zip->set_number('6150874')->is_valid_number, '京都府京都市右京区西京極新田町');
ok($zip->set_number('6150875')->is_valid_number, '京都府京都市右京区西京極徳大寺西団子田町');
ok($zip->set_number('6150876')->is_valid_number, '京都府京都市右京区西京極郡附洲町');
ok($zip->set_number('6150877')->is_valid_number, '京都府京都市右京区西京極西衣手町');
ok($zip->set_number('6150878')->is_valid_number, '京都府京都市右京区西京極北衣手町');
ok($zip->set_number('6150881')->is_valid_number, '京都府京都市右京区西京極北大入町');
ok($zip->set_number('6150882')->is_valid_number, '京都府京都市右京区西京極葛野町');
ok($zip->set_number('6150883')->is_valid_number, '京都府京都市右京区西京極南大入町');
ok($zip->set_number('6150884')->is_valid_number, '京都府京都市右京区西京極郡町');
ok($zip->set_number('6150885')->is_valid_number, '京都府京都市右京区西京極午塚町');
ok($zip->set_number('6150901')->is_valid_number, '京都府京都市右京区梅津南広町');
ok($zip->set_number('6150902')->is_valid_number, '京都府京都市右京区梅津神田町');
ok($zip->set_number('6150903')->is_valid_number, '京都府京都市右京区梅津堤下町');
ok($zip->set_number('6150904')->is_valid_number, '京都府京都市右京区梅津堤上町');
ok($zip->set_number('6150905')->is_valid_number, '京都府京都市右京区梅津石灘町');
ok($zip->set_number('6150906')->is_valid_number, '京都府京都市右京区梅津高畝町');
ok($zip->set_number('6150907')->is_valid_number, '京都府京都市右京区梅津段町');
ok($zip->set_number('6150911')->is_valid_number, '京都府京都市右京区梅津北町');
ok($zip->set_number('6150912')->is_valid_number, '京都府京都市右京区梅津構口町');
ok($zip->set_number('6150913')->is_valid_number, '京都府京都市右京区梅津南上田町');
ok($zip->set_number('6150914')->is_valid_number, '京都府京都市右京区梅津東構口町');
ok($zip->set_number('6150915')->is_valid_number, '京都府京都市右京区梅津南町');
ok($zip->set_number('6150916')->is_valid_number, '京都府京都市右京区梅津中村町');
ok($zip->set_number('6150917')->is_valid_number, '京都府京都市右京区梅津西浦町');
ok($zip->set_number('6150921')->is_valid_number, '京都府京都市右京区梅津フケノ川町');
ok($zip->set_number('6150922')->is_valid_number, '京都府京都市右京区梅津前田町');
ok($zip->set_number('6150923')->is_valid_number, '京都府京都市右京区梅津中倉町');
ok($zip->set_number('6150924')->is_valid_number, '京都府京都市右京区梅津尻溝町');
ok($zip->set_number('6150925')->is_valid_number, '京都府京都市右京区梅津大縄場町');
ok($zip->set_number('6150926')->is_valid_number, '京都府京都市右京区梅津罧原町');
ok($zip->set_number('6150931')->is_valid_number, '京都府京都市右京区梅津開キ町');
ok($zip->set_number('6150932')->is_valid_number, '京都府京都市右京区梅津上田町');
ok($zip->set_number('6150933')->is_valid_number, '京都府京都市右京区梅津後藤町');
ok($zip->set_number('6150934')->is_valid_number, '京都府京都市右京区梅津北浦町');
ok($zip->set_number('6150935')->is_valid_number, '京都府京都市右京区梅津徳丸町');
ok($zip->set_number('6150936')->is_valid_number, '京都府京都市右京区梅津林口町');
ok($zip->set_number('6150937')->is_valid_number, '京都府京都市右京区梅津北川町');
ok($zip->set_number('6150938')->is_valid_number, '京都府京都市右京区梅津坂本町');
ok($zip->set_number('6158001')->is_valid_number, '京都府京都市西京区桂上野北町');
ok($zip->set_number('6158002')->is_valid_number, '京都府京都市西京区桂上野中町');
ok($zip->set_number('6158003')->is_valid_number, '京都府京都市西京区桂上野東町');
ok($zip->set_number('6158004')->is_valid_number, '京都府京都市西京区桂畑ケ田町');
ok($zip->set_number('6158005')->is_valid_number, '京都府京都市西京区桂上野南町');
ok($zip->set_number('6158006')->is_valid_number, '京都府京都市西京区桂上野西町');
ok($zip->set_number('6158007')->is_valid_number, '京都府京都市西京区桂上野今井町');
ok($zip->set_number('6158008')->is_valid_number, '京都府京都市西京区桂上野川原町');
ok($zip->set_number('6158011')->is_valid_number, '京都府京都市西京区桂大縄町');
ok($zip->set_number('6158012')->is_valid_number, '京都府京都市西京区桂後水町');
ok($zip->set_number('6158013')->is_valid_number, '京都府京都市西京区桂清水町');
ok($zip->set_number('6158014')->is_valid_number, '京都府京都市西京区桂御園');
ok($zip->set_number('6158015')->is_valid_number, '京都府京都市西京区徳大寺清水町');
ok($zip->set_number('6158016')->is_valid_number, '京都府京都市西京区桂久方町');
ok($zip->set_number('6158017')->is_valid_number, '京都府京都市西京区桂河田町');
ok($zip->set_number('6158018')->is_valid_number, '京都府京都市西京区桂徳大寺町');
ok($zip->set_number('6158021')->is_valid_number, '京都府京都市西京区桂浅原町');
ok($zip->set_number('6158022')->is_valid_number, '京都府京都市西京区桂北滝川町');
ok($zip->set_number('6158023')->is_valid_number, '京都府京都市西京区桂南滝川町');
ok($zip->set_number('6158024')->is_valid_number, '京都府京都市西京区桂西滝川町');
ok($zip->set_number('6158025')->is_valid_number, '京都府京都市西京区桂稲荷山町');
ok($zip->set_number('6158026')->is_valid_number, '京都府京都市西京区桂市ノ前町');
ok($zip->set_number('6158027')->is_valid_number, '京都府京都市西京区桂朝日町');
ok($zip->set_number('6158031')->is_valid_number, '京都府京都市西京区牛ケ瀬林ノ本町');
ok($zip->set_number('6158032')->is_valid_number, '京都府京都市西京区牛ケ瀬奥ノ防町');
ok($zip->set_number('6158033')->is_valid_number, '京都府京都市西京区下津林東大般若町');
ok($zip->set_number('6158034')->is_valid_number, '京都府京都市西京区下津林東芝ノ宮町');
ok($zip->set_number('6158035')->is_valid_number, '京都府京都市西京区下津林芝ノ宮町');
ok($zip->set_number('6158036')->is_valid_number, '京都府京都市西京区下津林南大般若町');
ok($zip->set_number('6158037')->is_valid_number, '京都府京都市西京区下津林大般若町');
ok($zip->set_number('6158041')->is_valid_number, '京都府京都市西京区牛ケ瀬青柳町');
ok($zip->set_number('6158042')->is_valid_number, '京都府京都市西京区牛ケ瀬川原口町');
ok($zip->set_number('6158043')->is_valid_number, '京都府京都市西京区牛ケ瀬新田泓町');
ok($zip->set_number('6158044')->is_valid_number, '京都府京都市西京区牛ケ瀬山柿町');
ok($zip->set_number('6158045')->is_valid_number, '京都府京都市西京区牛ケ瀬南ノ口町');
ok($zip->set_number('6158046')->is_valid_number, '京都府京都市西京区牛ケ瀬弥生町');
ok($zip->set_number('6158051')->is_valid_number, '京都府京都市西京区牛ケ瀬西柿町');
ok($zip->set_number('6158052')->is_valid_number, '京都府京都市西京区牛ケ瀬堂田町');
ok($zip->set_number('6158053')->is_valid_number, '京都府京都市西京区下津林中島町');
ok($zip->set_number('6158054')->is_valid_number, '京都府京都市西京区下津林南中島町');
ok($zip->set_number('6158055')->is_valid_number, '京都府京都市西京区下津林佃');
ok($zip->set_number('6158056')->is_valid_number, '京都府京都市西京区下津林番条');
ok($zip->set_number('6158057')->is_valid_number, '京都府京都市西京区下津林番条町');
ok($zip->set_number('6158061')->is_valid_number, '京都府京都市西京区下津林北浦町');
ok($zip->set_number('6158062')->is_valid_number, '京都府京都市西京区下津林前泓町');
ok($zip->set_number('6158063')->is_valid_number, '京都府京都市西京区下津林六反田');
ok($zip->set_number('6158064')->is_valid_number, '京都府京都市西京区下津林水掛町');
ok($zip->set_number('6158065')->is_valid_number, '京都府京都市西京区下津林楠町');
ok($zip->set_number('6158071')->is_valid_number, '京都府京都市西京区桂春日町');
ok($zip->set_number('6158072')->is_valid_number, '京都府京都市西京区桂木ノ下町');
ok($zip->set_number('6158073')->is_valid_number, '京都府京都市西京区桂野里町');
ok($zip->set_number('6158074')->is_valid_number, '京都府京都市西京区桂南巽町');
ok($zip->set_number('6158075')->is_valid_number, '京都府京都市西京区桂巽町');
ok($zip->set_number('6158076')->is_valid_number, '京都府京都市西京区桂下豆田町');
ok($zip->set_number('6158077')->is_valid_number, '京都府京都市西京区桂芝ノ下町');
ok($zip->set_number('6158081')->is_valid_number, '京都府京都市西京区桂池尻町');
ok($zip->set_number('6158082')->is_valid_number, '京都府京都市西京区桂上豆田町');
ok($zip->set_number('6158083')->is_valid_number, '京都府京都市西京区桂艮町');
ok($zip->set_number('6158084')->is_valid_number, '京都府京都市西京区桂坤町');
ok($zip->set_number('6158085')->is_valid_number, '京都府京都市西京区桂千代原町');
ok($zip->set_number('6158086')->is_valid_number, '京都府京都市西京区桂乾町');
ok($zip->set_number('6158087')->is_valid_number, '京都府京都市西京区桂御所町');
ok($zip->set_number('6158101')->is_valid_number, '京都府京都市西京区川島東代町');
ok($zip->set_number('6158102')->is_valid_number, '京都府京都市西京区川島松ノ木本町');
ok($zip->set_number('6158103')->is_valid_number, '京都府京都市西京区川島六ノ坪町');
ok($zip->set_number('6158104')->is_valid_number, '京都府京都市西京区川島五反長町');
ok($zip->set_number('6158105')->is_valid_number, '京都府京都市西京区川島莚田町');
ok($zip->set_number('6158106')->is_valid_number, '京都府京都市西京区川島滑樋町');
ok($zip->set_number('6158107')->is_valid_number, '京都府京都市西京区川島北裏町');
ok($zip->set_number('6158111')->is_valid_number, '京都府京都市西京区川島松園町');
ok($zip->set_number('6158112')->is_valid_number, '京都府京都市西京区川島竹園町');
ok($zip->set_number('6158113')->is_valid_number, '京都府京都市西京区川島梅園町');
ok($zip->set_number('6158114')->is_valid_number, '京都府京都市西京区川島桜園町');
ok($zip->set_number('6158115')->is_valid_number, '京都府京都市西京区川島流田町');
ok($zip->set_number('6158116')->is_valid_number, '京都府京都市西京区樫原甲水');
ok($zip->set_number('6158117')->is_valid_number, '京都府京都市西京区樫原六反田');
ok($zip->set_number('6158118')->is_valid_number, '京都府京都市西京区川島三重町');
ok($zip->set_number('6158121')->is_valid_number, '京都府京都市西京区川島野田町');
ok($zip->set_number('6158122')->is_valid_number, '京都府京都市西京区樫原八反田');
ok($zip->set_number('6158123')->is_valid_number, '京都府京都市西京区樫原山路');
ok($zip->set_number('6158124')->is_valid_number, '京都府京都市西京区樫原三宅町');
ok($zip->set_number('6158125')->is_valid_number, '京都府京都市西京区川島調子町');
ok($zip->set_number('6158131')->is_valid_number, '京都府京都市西京区樫原五反田');
ok($zip->set_number('6158132')->is_valid_number, '京都府京都市西京区樫原庭井');
ok($zip->set_number('6158133')->is_valid_number, '京都府京都市西京区樫原井戸');
ok($zip->set_number('6158134')->is_valid_number, '京都府京都市西京区樫原比恵田町');
ok($zip->set_number('6158135')->is_valid_number, '京都府京都市西京区樫原江ノ本町');
ok($zip->set_number('6158136')->is_valid_number, '京都府京都市西京区樫原口戸');
ok($zip->set_number('6158141')->is_valid_number, '京都府京都市西京区樫原平田町');
ok($zip->set_number('6158142')->is_valid_number, '京都府京都市西京区樫原畔ノ海道');
ok($zip->set_number('6158143')->is_valid_number, '京都府京都市西京区樫原里ノ垣外町');
ok($zip->set_number('6158144')->is_valid_number, '京都府京都市西京区樫原釘貫');
ok($zip->set_number('6158145')->is_valid_number, '京都府京都市西京区樫原角田町');
ok($zip->set_number('6158146')->is_valid_number, '京都府京都市西京区樫原田中町');
ok($zip->set_number('6158147')->is_valid_number, '京都府京都市西京区樫原塚ノ本町');
ok($zip->set_number('6158151')->is_valid_number, '京都府京都市西京区樫原杉原町');
ok($zip->set_number('6158152')->is_valid_number, '京都府京都市西京区樫原内垣外町');
ok($zip->set_number('6158153')->is_valid_number, '京都府京都市西京区樫原前田町');
ok($zip->set_number('6158154')->is_valid_number, '京都府京都市西京区樫原岡南ノ庄');
ok($zip->set_number('6158155')->is_valid_number, '京都府京都市西京区樫原大亀谷');
ok($zip->set_number('6158156')->is_valid_number, '京都府京都市西京区樫原百々ケ池');
ok($zip->set_number('6158157')->is_valid_number, '京都府京都市西京区樫原芋峠');
ok($zip->set_number('6158158')->is_valid_number, '京都府京都市西京区樫原秤谷町');
ok($zip->set_number('6158161')->is_valid_number, '京都府京都市西京区樫原蛸田町');
ok($zip->set_number('6158162')->is_valid_number, '京都府京都市西京区樫原上ノ町');
ok($zip->set_number('6158163')->is_valid_number, '京都府京都市西京区樫原山ノ上町');
ok($zip->set_number('6158164')->is_valid_number, '京都府京都市西京区樫原鴫谷');
ok($zip->set_number('6158165')->is_valid_number, '京都府京都市西京区樫原盆山');
ok($zip->set_number('6158171')->is_valid_number, '京都府京都市西京区樫原久保町');
ok($zip->set_number('6158172')->is_valid_number, '京都府京都市西京区樫原宇治井西町');
ok($zip->set_number('6158173')->is_valid_number, '京都府京都市西京区樫原下池田町');
ok($zip->set_number('6158174')->is_valid_number, '京都府京都市西京区樫原中垣外');
ok($zip->set_number('6158175')->is_valid_number, '京都府京都市西京区樫原硲町');
ok($zip->set_number('6158176')->is_valid_number, '京都府京都市西京区樫原上池田町');
ok($zip->set_number('6158177')->is_valid_number, '京都府京都市西京区樫原下ノ町');
ok($zip->set_number('6158178')->is_valid_number, '京都府京都市西京区樫原池ノ上町');
ok($zip->set_number('6158181')->is_valid_number, '京都府京都市西京区樫原石畑町');
ok($zip->set_number('6158182')->is_valid_number, '京都府京都市西京区樫原茶ノ木本町');
ok($zip->set_number('6158183')->is_valid_number, '京都府京都市西京区樫原分田');
ok($zip->set_number('6158184')->is_valid_number, '京都府京都市西京区樫原水築町');
ok($zip->set_number('6158185')->is_valid_number, '京都府京都市西京区樫原宇治井町');
ok($zip->set_number('6158186')->is_valid_number, '京都府京都市西京区樫原佃');
ok($zip->set_number('6158191')->is_valid_number, '京都府京都市西京区川島有栖川町');
ok($zip->set_number('6158192')->is_valid_number, '京都府京都市西京区川島寺田町');
ok($zip->set_number('6158193')->is_valid_number, '京都府京都市西京区川島玉頭町');
ok($zip->set_number('6158194')->is_valid_number, '京都府京都市西京区川島粟田町');
ok($zip->set_number('6158195')->is_valid_number, '京都府京都市西京区川島権田町');
ok($zip->set_number('6158196')->is_valid_number, '京都府京都市西京区川島尻堀町');
ok($zip->set_number('6158201')->is_valid_number, '京都府京都市西京区上桂今井町');
ok($zip->set_number('6158202')->is_valid_number, '京都府京都市西京区松室吾田神町');
ok($zip->set_number('6158203')->is_valid_number, '京都府京都市西京区松室荒堀町');
ok($zip->set_number('6158204')->is_valid_number, '京都府京都市西京区松室北河原町');
ok($zip->set_number('6158205')->is_valid_number, '京都府京都市西京区松室中溝町');
ok($zip->set_number('6158206')->is_valid_number, '京都府京都市西京区松室追上ゲ町');
ok($zip->set_number('6158207')->is_valid_number, '京都府京都市西京区松室河原町');
ok($zip->set_number('6158208')->is_valid_number, '京都府京都市西京区上桂樋ノ口町');
ok($zip->set_number('6158211')->is_valid_number, '京都府京都市西京区上桂前川町');
ok($zip->set_number('6158212')->is_valid_number, '京都府京都市西京区上桂北ノ口町');
ok($zip->set_number('6158213')->is_valid_number, '京都府京都市西京区上桂北村町');
ok($zip->set_number('6158214')->is_valid_number, '京都府京都市西京区上桂東居町');
ok($zip->set_number('6158215')->is_valid_number, '京都府京都市西京区上桂大野町');
ok($zip->set_number('6158216')->is_valid_number, '京都府京都市西京区松尾鈴川町');
ok($zip->set_number('6158217')->is_valid_number, '京都府京都市西京区松尾東ノ口町');
ok($zip->set_number('6158221')->is_valid_number, '京都府京都市西京区上桂東ノ口町');
ok($zip->set_number('6158222')->is_valid_number, '京都府京都市西京区上桂御正町');
ok($zip->set_number('6158223')->is_valid_number, '京都府京都市西京区上桂前田町');
ok($zip->set_number('6158224')->is_valid_number, '京都府京都市西京区上桂三ノ宮町');
ok($zip->set_number('6158225')->is_valid_number, '京都府京都市西京区上桂森下町');
ok($zip->set_number('6158226')->is_valid_number, '京都府京都市西京区上桂森上町');
ok($zip->set_number('6158227')->is_valid_number, '京都府京都市西京区上桂宮ノ後町');
ok($zip->set_number('6158228')->is_valid_number, '京都府京都市西京区上桂西居町');
ok($zip->set_number('6158231')->is_valid_number, '京都府京都市西京区御陵溝浦町');
ok($zip->set_number('6158232')->is_valid_number, '京都府京都市西京区御陵南荒木町');
ok($zip->set_number('6158233')->is_valid_number, '京都府京都市西京区御陵荒木町');
ok($zip->set_number('6158234')->is_valid_number, '京都府京都市西京区御陵塚ノ越町');
ok($zip->set_number('6158235')->is_valid_number, '京都府京都市西京区御陵内町');
ok($zip->set_number('6158236')->is_valid_number, '京都府京都市西京区山田大吉見町');
ok($zip->set_number('6158237')->is_valid_number, '京都府京都市西京区山田中吉見町');
ok($zip->set_number('6158238')->is_valid_number, '京都府京都市西京区山田車塚町');
ok($zip->set_number('6158241')->is_valid_number, '京都府京都市西京区御陵谷町');
ok($zip->set_number('6158242')->is_valid_number, '京都府京都市西京区御陵鴫谷');
ok($zip->set_number('6158243')->is_valid_number, '京都府京都市西京区御陵御茶屋山');
ok($zip->set_number('6158244')->is_valid_number, '京都府京都市西京区御陵池ノ谷');
ok($zip->set_number('6158245')->is_valid_number, '京都府京都市西京区御陵大原');
ok($zip->set_number('6158246')->is_valid_number, '京都府京都市西京区京都大学桂');
ok($zip->set_number('6158251')->is_valid_number, '京都府京都市西京区山田猫塚町');
ok($zip->set_number('6158252')->is_valid_number, '京都府京都市西京区御陵北山下町');
ok($zip->set_number('6158253')->is_valid_number, '京都府京都市西京区御陵北山町');
ok($zip->set_number('6158254')->is_valid_number, '京都府京都市西京区御陵細谷');
ok($zip->set_number('6158255')->is_valid_number, '京都府京都市西京区山田箱塚町');
ok($zip->set_number('6158256')->is_valid_number, '京都府京都市西京区山田平尾町');
ok($zip->set_number('6158261')->is_valid_number, '京都府京都市西京区山田庄田町');
ok($zip->set_number('6158262')->is_valid_number, '京都府京都市西京区山田四ノ坪町');
ok($zip->set_number('6158263')->is_valid_number, '京都府京都市西京区山田久田町');
ok($zip->set_number('6158264')->is_valid_number, '京都府京都市西京区山田六ノ坪町');
ok($zip->set_number('6158265')->is_valid_number, '京都府京都市西京区山田御道路町');
ok($zip->set_number('6158266')->is_valid_number, '京都府京都市西京区山田南山田町');
ok($zip->set_number('6158267')->is_valid_number, '京都府京都市西京区山田北山田町');
ok($zip->set_number('6158271')->is_valid_number, '京都府京都市西京区山田弦馳町');
ok($zip->set_number('6158272')->is_valid_number, '京都府京都市西京区山田畑田町');
ok($zip->set_number('6158273')->is_valid_number, '京都府京都市西京区山田出口町');
ok($zip->set_number('6158274')->is_valid_number, '京都府京都市西京区山田上ノ町');
ok($zip->set_number('6158275')->is_valid_number, '京都府京都市西京区山田南町');
ok($zip->set_number('6158276')->is_valid_number, '京都府京都市西京区山田開キ町');
ok($zip->set_number('6158277')->is_valid_number, '京都府京都市西京区山田葉室町');
ok($zip->set_number('6158281')->is_valid_number, '京都府京都市西京区松尾木ノ曽町');
ok($zip->set_number('6158282')->is_valid_number, '京都府京都市西京区松尾大利町');
ok($zip->set_number('6158283')->is_valid_number, '京都府京都市西京区松尾井戸町');
ok($zip->set_number('6158284')->is_valid_number, '京都府京都市西京区松尾上ノ山町');
ok($zip->set_number('6158285')->is_valid_number, '京都府京都市西京区山田北ノ町');
ok($zip->set_number('6158286')->is_valid_number, '京都府京都市西京区松尾神ケ谷町');
ok($zip->set_number('6158287')->is_valid_number, '京都府京都市西京区松尾万石町');
ok($zip->set_number('6158291')->is_valid_number, '京都府京都市西京区松室扇田町');
ok($zip->set_number('6158292')->is_valid_number, '京都府京都市西京区松室田中町');
ok($zip->set_number('6158293')->is_valid_number, '京都府京都市西京区松室庄田町');
ok($zip->set_number('6158294')->is_valid_number, '京都府京都市西京区松室地家町');
ok($zip->set_number('6158295')->is_valid_number, '京都府京都市西京区松室地家山');
ok($zip->set_number('6158296')->is_valid_number, '京都府京都市西京区松室山添町');
ok($zip->set_number('6158301')->is_valid_number, '京都府京都市西京区桂徳大寺北町');
ok($zip->set_number('6158302')->is_valid_number, '京都府京都市西京区桂徳大寺南町');
ok($zip->set_number('6158303')->is_valid_number, '京都府京都市西京区桂徳大寺東町');
ok($zip->set_number('6160000')->is_valid_number, '京都府京都市右京区以下に掲載がない場合');
ok($zip->set_number('6160001')->is_valid_number, '京都府京都市西京区嵐山上河原町');
ok($zip->set_number('6160002')->is_valid_number, '京都府京都市西京区嵐山東一川町');
ok($zip->set_number('6160003')->is_valid_number, '京都府京都市西京区嵐山西一川町');
ok($zip->set_number('6160004')->is_valid_number, '京都府京都市西京区嵐山中尾下町');
ok($zip->set_number('6160005')->is_valid_number, '京都府京都市西京区嵐山山田町');
ok($zip->set_number('6160006')->is_valid_number, '京都府京都市西京区嵐山虚空蔵山町');
ok($zip->set_number('6160007')->is_valid_number, '京都府京都市西京区嵐山元録山町');
ok($zip->set_number('6160011')->is_valid_number, '京都府京都市西京区嵐山樋ノ上町');
ok($zip->set_number('6160012')->is_valid_number, '京都府京都市西京区嵐山東海道町');
ok($zip->set_number('6160013')->is_valid_number, '京都府京都市西京区嵐山風呂ノ橋町');
ok($zip->set_number('6160014')->is_valid_number, '京都府京都市西京区嵐山谷ケ辻子町');
ok($zip->set_number('6160015')->is_valid_number, '京都府京都市西京区嵐山山ノ下町');
ok($zip->set_number('6160016')->is_valid_number, '京都府京都市西京区嵐山上海道町');
ok($zip->set_number('6160017')->is_valid_number, '京都府京都市西京区嵐山茶尻町');
ok($zip->set_number('6160021')->is_valid_number, '京都府京都市西京区嵐山森ノ前町');
ok($zip->set_number('6160022')->is_valid_number, '京都府京都市西京区嵐山朝月町');
ok($zip->set_number('6160023')->is_valid_number, '京都府京都市西京区嵐山宮ノ前町');
ok($zip->set_number('6160024')->is_valid_number, '京都府京都市西京区嵐山宮町');
ok($zip->set_number('6160025')->is_valid_number, '京都府京都市西京区嵐山宮ノ北町');
ok($zip->set_number('6160026')->is_valid_number, '京都府京都市西京区嵐山薬師下町');
ok($zip->set_number('6160027')->is_valid_number, '京都府京都市西京区嵐山内田町');
ok($zip->set_number('6168001')->is_valid_number, '京都府京都市右京区龍安寺御陵ノ下町');
ok($zip->set_number('6168002')->is_valid_number, '京都府京都市右京区龍安寺衣笠下町');
ok($zip->set_number('6168003')->is_valid_number, '京都府京都市右京区龍安寺池ノ下町');
ok($zip->set_number('6168004')->is_valid_number, '京都府京都市右京区龍安寺玉津芝町');
ok($zip->set_number('6168005')->is_valid_number, '京都府京都市右京区龍安寺塔ノ下町');
ok($zip->set_number('6168006')->is_valid_number, '京都府京都市右京区龍安寺住吉町');
ok($zip->set_number('6168007')->is_valid_number, '京都府京都市右京区龍安寺山田町');
ok($zip->set_number('6168011')->is_valid_number, '京都府京都市右京区龍安寺斎宮町');
ok($zip->set_number('6168012')->is_valid_number, '京都府京都市右京区谷口垣ノ内町');
ok($zip->set_number('6168013')->is_valid_number, '京都府京都市右京区谷口唐田ノ内町');
ok($zip->set_number('6168014')->is_valid_number, '京都府京都市右京区谷口梅津間町');
ok($zip->set_number('6168015')->is_valid_number, '京都府京都市右京区谷口園町');
ok($zip->set_number('6168016')->is_valid_number, '京都府京都市右京区龍安寺西ノ川町');
ok($zip->set_number('6168017')->is_valid_number, '京都府京都市右京区龍安寺五反田町');
ok($zip->set_number('6168021')->is_valid_number, '京都府京都市右京区花園天授ケ岡町');
ok($zip->set_number('6168022')->is_valid_number, '京都府京都市右京区谷口円成寺町');
ok($zip->set_number('6168023')->is_valid_number, '京都府京都市右京区花園大薮町');
ok($zip->set_number('6168024')->is_valid_number, '京都府京都市右京区花園一条田町');
ok($zip->set_number('6168025')->is_valid_number, '京都府京都市右京区花園土堂町');
ok($zip->set_number('6168026')->is_valid_number, '京都府京都市右京区花園岡ノ本町');
ok($zip->set_number('6168027')->is_valid_number, '京都府京都市右京区花園円成寺町');
ok($zip->set_number('6168031')->is_valid_number, '京都府京都市右京区花園鷹司町');
ok($zip->set_number('6168032')->is_valid_number, '京都府京都市右京区花園馬代町');
ok($zip->set_number('6168033')->is_valid_number, '京都府京都市右京区花園艮北町');
ok($zip->set_number('6168034')->is_valid_number, '京都府京都市右京区花園木辻北町');
ok($zip->set_number('6168035')->is_valid_number, '京都府京都市右京区花園妙心寺町');
ok($zip->set_number('6168036')->is_valid_number, '京都府京都市右京区花園寺ノ中町');
ok($zip->set_number('6168037')->is_valid_number, '京都府京都市右京区花園猪ノ毛町');
ok($zip->set_number('6168041')->is_valid_number, '京都府京都市右京区花園寺ノ前町');
ok($zip->set_number('6168042')->is_valid_number, '京都府京都市右京区花園伊町');
ok($zip->set_number('6168043')->is_valid_number, '京都府京都市右京区花園寺ノ内町');
ok($zip->set_number('6168044')->is_valid_number, '京都府京都市右京区花園扇野町');
ok($zip->set_number('6168045')->is_valid_number, '京都府京都市右京区花園内畑町');
ok($zip->set_number('6168046')->is_valid_number, '京都府京都市右京区花園段ノ岡町');
ok($zip->set_number('6168047')->is_valid_number, '京都府京都市右京区花園宮ノ上町');
ok($zip->set_number('6168051')->is_valid_number, '京都府京都市右京区花園巽南町');
ok($zip->set_number('6168052')->is_valid_number, '京都府京都市右京区花園薮ノ下町');
ok($zip->set_number('6168053')->is_valid_number, '京都府京都市右京区花園八ツ口町');
ok($zip->set_number('6168054')->is_valid_number, '京都府京都市右京区花園中御門町');
ok($zip->set_number('6168055')->is_valid_number, '京都府京都市右京区花園車道町');
ok($zip->set_number('6168056')->is_valid_number, '京都府京都市右京区花園坤南町');
ok($zip->set_number('6168057')->is_valid_number, '京都府京都市右京区花園木辻南町');
ok($zip->set_number('6168061')->is_valid_number, '京都府京都市右京区花園春日町');
ok($zip->set_number('6168062')->is_valid_number, '京都府京都市右京区太秦安井春日町');
ok($zip->set_number('6168063')->is_valid_number, '京都府京都市右京区太秦安井東裏町');
ok($zip->set_number('6168064')->is_valid_number, '京都府京都市右京区太秦安井北御所町');
ok($zip->set_number('6168065')->is_valid_number, '京都府京都市右京区太秦安井西裏町');
ok($zip->set_number('6168066')->is_valid_number, '京都府京都市右京区太秦安井車道町');
ok($zip->set_number('6168067')->is_valid_number, '京都府京都市右京区太秦安井小山町');
ok($zip->set_number('6168071')->is_valid_number, '京都府京都市右京区太秦安井藤ノ木町');
ok($zip->set_number('6168072')->is_valid_number, '京都府京都市右京区太秦安井辰巳町');
ok($zip->set_number('6168073')->is_valid_number, '京都府京都市右京区太秦安井水戸田町');
ok($zip->set_number('6168074')->is_valid_number, '京都府京都市右京区太秦安井二条裏町');
ok($zip->set_number('6168075')->is_valid_number, '京都府京都市右京区太秦安井柳通町');
ok($zip->set_number('6168076')->is_valid_number, '京都府京都市右京区太秦安井辻ノ内町');
ok($zip->set_number('6168077')->is_valid_number, '京都府京都市右京区太秦安井馬塚町');
ok($zip->set_number('6168081')->is_valid_number, '京都府京都市右京区太秦安井池田町');
ok($zip->set_number('6168082')->is_valid_number, '京都府京都市右京区太秦安井奥畑町');
ok($zip->set_number('6168083')->is_valid_number, '京都府京都市右京区太秦安井西沢町');
ok($zip->set_number('6168084')->is_valid_number, '京都府京都市右京区太秦安井一町田町');
ok($zip->set_number('6168085')->is_valid_number, '京都府京都市右京区太秦安井松本町');
ok($zip->set_number('6168091')->is_valid_number, '京都府京都市右京区御室住吉山町');
ok($zip->set_number('6168092')->is_valid_number, '京都府京都市右京区御室大内');
ok($zip->set_number('6168093')->is_valid_number, '京都府京都市右京区御室竪町');
ok($zip->set_number('6168094')->is_valid_number, '京都府京都市右京区御室小松野町');
ok($zip->set_number('6168095')->is_valid_number, '京都府京都市右京区御室芝橋町');
ok($zip->set_number('6168096')->is_valid_number, '京都府京都市右京区御室岡ノ裾町');
ok($zip->set_number('6168097')->is_valid_number, '京都府京都市右京区御室双岡町');
ok($zip->set_number('6168101')->is_valid_number, '京都府京都市右京区太秦和泉式部町');
ok($zip->set_number('6168102')->is_valid_number, '京都府京都市右京区太秦森ケ東町');
ok($zip->set_number('6168103')->is_valid_number, '京都府京都市右京区太秦上刑部町');
ok($zip->set_number('6168104')->is_valid_number, '京都府京都市右京区太秦下刑部町');
ok($zip->set_number('6168105')->is_valid_number, '京都府京都市右京区太秦森ケ前町');
ok($zip->set_number('6168106')->is_valid_number, '京都府京都市右京区太秦森ケ西町');
ok($zip->set_number('6168107')->is_valid_number, '京都府京都市右京区太秦一ノ井町');
ok($zip->set_number('6168111')->is_valid_number, '京都府京都市右京区太秦下角田町');
ok($zip->set_number('6168112')->is_valid_number, '京都府京都市右京区太秦木ノ下町');
ok($zip->set_number('6168113')->is_valid_number, '京都府京都市右京区太秦野元町');
ok($zip->set_number('6168114')->is_valid_number, '京都府京都市右京区太秦巽町');
ok($zip->set_number('6168115')->is_valid_number, '京都府京都市右京区太秦東唐渡町');
ok($zip->set_number('6168116')->is_valid_number, '京都府京都市右京区太秦松本町');
ok($zip->set_number('6168117')->is_valid_number, '京都府京都市右京区太秦門田町');
ok($zip->set_number('6168121')->is_valid_number, '京都府京都市右京区太秦垣内町');
ok($zip->set_number('6168122')->is_valid_number, '京都府京都市右京区太秦井戸ケ尻町');
ok($zip->set_number('6168123')->is_valid_number, '京都府京都市右京区太秦海正寺町');
ok($zip->set_number('6168124')->is_valid_number, '京都府京都市右京区太秦辻ケ本町');
ok($zip->set_number('6168125')->is_valid_number, '京都府京都市右京区太秦組石町');
ok($zip->set_number('6168126')->is_valid_number, '京都府京都市右京区太秦椙ケ本町');
ok($zip->set_number('6168127')->is_valid_number, '京都府京都市右京区太秦奥殿町');
ok($zip->set_number('6168131')->is_valid_number, '京都府京都市右京区太秦藤ケ森町');
ok($zip->set_number('6168132')->is_valid_number, '京都府京都市右京区太秦滝ケ花町');
ok($zip->set_number('6168133')->is_valid_number, '京都府京都市右京区太秦中堤町');
ok($zip->set_number('6168134')->is_valid_number, '京都府京都市右京区太秦唐渡町');
ok($zip->set_number('6168135')->is_valid_number, '京都府京都市右京区太秦小手角町');
ok($zip->set_number('6168136')->is_valid_number, '京都府京都市右京区太秦荒木町');
ok($zip->set_number('6168137')->is_valid_number, '京都府京都市右京区太秦朱雀町');
ok($zip->set_number('6168141')->is_valid_number, '京都府京都市右京区太秦棚森町');
ok($zip->set_number('6168142')->is_valid_number, '京都府京都市右京区太秦樋ノ内町');
ok($zip->set_number('6168143')->is_valid_number, '京都府京都市右京区太秦川所町');
ok($zip->set_number('6168144')->is_valid_number, '京都府京都市右京区太秦百合ケ本町');
ok($zip->set_number('6168145')->is_valid_number, '京都府京都市右京区太秦八反田町');
ok($zip->set_number('6168146')->is_valid_number, '京都府京都市右京区太秦前ノ田町');
ok($zip->set_number('6168147')->is_valid_number, '京都府京都市右京区太秦土本町');
ok($zip->set_number('6168151')->is_valid_number, '京都府京都市右京区太秦帷子ケ辻町');
ok($zip->set_number('6168152')->is_valid_number, '京都府京都市右京区太秦堀ケ内町');
ok($zip->set_number('6168153')->is_valid_number, '京都府京都市右京区太秦面影町');
ok($zip->set_number('6168154')->is_valid_number, '京都府京都市右京区太秦皆正寺町');
ok($zip->set_number('6168155')->is_valid_number, '京都府京都市右京区太秦袴田町');
ok($zip->set_number('6168156')->is_valid_number, '京都府京都市右京区太秦西野町');
ok($zip->set_number('6168157')->is_valid_number, '京都府京都市右京区太秦御所ノ内町');
ok($zip->set_number('6168161')->is_valid_number, '京都府京都市右京区太秦東蜂岡町');
ok($zip->set_number('6168162')->is_valid_number, '京都府京都市右京区太秦蜂岡町');
ok($zip->set_number('6168163')->is_valid_number, '京都府京都市右京区太秦西蜂岡町');
ok($zip->set_number('6168164')->is_valid_number, '京都府京都市右京区太秦桂木町');
ok($zip->set_number('6168165')->is_valid_number, '京都府京都市右京区太秦桂ケ原町');
ok($zip->set_number('6168166')->is_valid_number, '京都府京都市右京区太秦石垣町');
ok($zip->set_number('6168167')->is_valid_number, '京都府京都市右京区太秦多薮町');
ok($zip->set_number('6168171')->is_valid_number, '京都府京都市右京区太秦青木ケ原町');
ok($zip->set_number('6168172')->is_valid_number, '京都府京都市右京区太秦青木元町');
ok($zip->set_number('6168173')->is_valid_number, '京都府京都市右京区太秦上ノ段町');
ok($zip->set_number('6168174')->is_valid_number, '京都府京都市右京区太秦垂箕山町');
ok($zip->set_number('6168175')->is_valid_number, '京都府京都市右京区太秦一町芝町');
ok($zip->set_number('6168176')->is_valid_number, '京都府京都市右京区太秦乾町');
ok($zip->set_number('6168177')->is_valid_number, '京都府京都市右京区太秦馬塚町');
ok($zip->set_number('6168181')->is_valid_number, '京都府京都市右京区太秦京ノ道町');
ok($zip->set_number('6168182')->is_valid_number, '京都府京都市右京区太秦北路町');
ok($zip->set_number('6168183')->is_valid_number, '京都府京都市右京区太秦宮ノ前町');
ok($zip->set_number('6168184')->is_valid_number, '京都府京都市右京区太秦中筋町');
ok($zip->set_number('6168185')->is_valid_number, '京都府京都市右京区太秦開日町');
ok($zip->set_number('6168186')->is_valid_number, '京都府京都市右京区太秦堀池町');
ok($zip->set_number('6168187')->is_valid_number, '京都府京都市右京区太秦御領田町');
ok($zip->set_number('6168191')->is_valid_number, '京都府京都市右京区太秦中山町');
ok($zip->set_number('6168192')->is_valid_number, '京都府京都市右京区太秦三尾町');
ok($zip->set_number('6168193')->is_valid_number, '京都府京都市右京区山越巽町');
ok($zip->set_number('6168194')->is_valid_number, '京都府京都市右京区山越東町');
ok($zip->set_number('6168195')->is_valid_number, '京都府京都市右京区山越中町');
ok($zip->set_number('6168196')->is_valid_number, '京都府京都市右京区山越西町');
ok($zip->set_number('6168197')->is_valid_number, '京都府京都市右京区山越乾町');
ok($zip->set_number('6168201')->is_valid_number, '京都府京都市右京区宇多野北ノ院町');
ok($zip->set_number('6168202')->is_valid_number, '京都府京都市右京区宇多野馬場町');
ok($zip->set_number('6168203')->is_valid_number, '京都府京都市右京区宇多野柴橋町');
ok($zip->set_number('6168204')->is_valid_number, '京都府京都市右京区宇多野御池町');
ok($zip->set_number('6168205')->is_valid_number, '京都府京都市右京区宇多野御屋敷町');
ok($zip->set_number('6168206')->is_valid_number, '京都府京都市右京区宇多野法安寺町');
ok($zip->set_number('6168207')->is_valid_number, '京都府京都市右京区宇多野長尾町');
ok($zip->set_number('6168208')->is_valid_number, '京都府京都市右京区宇多野福王子町');
ok($zip->set_number('6168209')->is_valid_number, '京都府京都市右京区宇多野芝町');
ok($zip->set_number('6168211')->is_valid_number, '京都府京都市右京区常盤御池町');
ok($zip->set_number('6168212')->is_valid_number, '京都府京都市右京区常盤山下町');
ok($zip->set_number('6168213')->is_valid_number, '京都府京都市右京区常盤音戸町');
ok($zip->set_number('6168214')->is_valid_number, '京都府京都市右京区常盤古御所町');
ok($zip->set_number('6168215')->is_valid_number, '京都府京都市右京区常盤森町');
ok($zip->set_number('6168216')->is_valid_number, '京都府京都市右京区常盤一ノ井町');
ok($zip->set_number('6168217')->is_valid_number, '京都府京都市右京区常盤東ノ町');
ok($zip->set_number('6168218')->is_valid_number, '京都府京都市右京区常盤出口町');
ok($zip->set_number('6168219')->is_valid_number, '京都府京都市右京区常盤神田町');
ok($zip->set_number('6168221')->is_valid_number, '京都府京都市右京区常盤村ノ内町');
ok($zip->set_number('6168222')->is_valid_number, '京都府京都市右京区常盤仲之町');
ok($zip->set_number('6168223')->is_valid_number, '京都府京都市右京区常盤西町');
ok($zip->set_number('6168224')->is_valid_number, '京都府京都市右京区常盤窪町');
ok($zip->set_number('6168225')->is_valid_number, '京都府京都市右京区常盤馬塚町');
ok($zip->set_number('6168226')->is_valid_number, '京都府京都市右京区常盤段ノ上町');
ok($zip->set_number('6168227')->is_valid_number, '京都府京都市右京区常盤草木町');
ok($zip->set_number('6168228')->is_valid_number, '京都府京都市右京区常盤下田町');
ok($zip->set_number('6168229')->is_valid_number, '京都府京都市右京区常盤北裏町');
ok($zip->set_number('6168231')->is_valid_number, '京都府京都市右京区常盤柏ノ木町');
ok($zip->set_number('6168232')->is_valid_number, '京都府京都市右京区鳴滝蓮花寺町');
ok($zip->set_number('6168233')->is_valid_number, '京都府京都市右京区鳴滝中道町');
ok($zip->set_number('6168234')->is_valid_number, '京都府京都市右京区鳴滝嵯峨園町');
ok($zip->set_number('6168235')->is_valid_number, '京都府京都市右京区鳴滝西嵯峨園町');
ok($zip->set_number('6168236')->is_valid_number, '京都府京都市右京区鳴滝春木町');
ok($zip->set_number('6168237')->is_valid_number, '京都府京都市右京区鳴滝瑞穂町');
ok($zip->set_number('6168238')->is_valid_number, '京都府京都市右京区鳴滝桐ケ淵町');
ok($zip->set_number('6168241')->is_valid_number, '京都府京都市右京区鳴滝泉殿町');
ok($zip->set_number('6168242')->is_valid_number, '京都府京都市右京区鳴滝本町');
ok($zip->set_number('6168243')->is_valid_number, '京都府京都市右京区鳴滝安井殿町');
ok($zip->set_number('6168244')->is_valid_number, '京都府京都市右京区鳴滝藤ノ木町');
ok($zip->set_number('6168245')->is_valid_number, '京都府京都市右京区音戸山山ノ茶屋町');
ok($zip->set_number('6168246')->is_valid_number, '京都府京都市右京区鳴滝川西町');
ok($zip->set_number('6168247')->is_valid_number, '京都府京都市右京区鳴滝蓮池町');
ok($zip->set_number('6168251')->is_valid_number, '京都府京都市右京区鳴滝宇多野谷');
ok($zip->set_number('6168252')->is_valid_number, '京都府京都市右京区宇多野上ノ谷町');
ok($zip->set_number('6168253')->is_valid_number, '京都府京都市右京区鳴滝泉谷町');
ok($zip->set_number('6168254')->is_valid_number, '京都府京都市右京区鳴滝宅間町');
ok($zip->set_number('6168255')->is_valid_number, '京都府京都市右京区鳴滝音戸山町');
ok($zip->set_number('6168256')->is_valid_number, '京都府京都市右京区鳴滝松本町');
ok($zip->set_number('6168257')->is_valid_number, '京都府京都市右京区鳴滝白砂');
ok($zip->set_number('6168258')->is_valid_number, '京都府京都市右京区鳴滝般若寺町');
ok($zip->set_number('6168261')->is_valid_number, '京都府京都市右京区梅ケ畑高鼻町');
ok($zip->set_number('6168262')->is_valid_number, '京都府京都市右京区梅ケ畑向ノ地町');
ok($zip->set_number('6168263')->is_valid_number, '京都府京都市右京区梅ケ畑畑ノ下町');
ok($zip->set_number('6168264')->is_valid_number, '京都府京都市右京区梅ケ畑薮ノ下町');
ok($zip->set_number('6168265')->is_valid_number, '京都府京都市右京区梅ケ畑畑町');
ok($zip->set_number('6168266')->is_valid_number, '京都府京都市右京区梅ケ畑中田町');
ok($zip->set_number('6168267')->is_valid_number, '京都府京都市右京区梅ケ畑山崎町');
ok($zip->set_number('6168268')->is_valid_number, '京都府京都市右京区梅ケ畑古田町');
ok($zip->set_number('6168271')->is_valid_number, '京都府京都市右京区梅ケ畑宮ノ口町');
ok($zip->set_number('6168272')->is_valid_number, '京都府京都市右京区梅ケ畑猪ノ尻町');
ok($zip->set_number('6168273')->is_valid_number, '京都府京都市右京区梅ケ畑中縄手町');
ok($zip->set_number('6168274')->is_valid_number, '京都府京都市右京区梅ケ畑上ノ町');
ok($zip->set_number('6168275')->is_valid_number, '京都府京都市右京区梅ケ畑篝町');
ok($zip->set_number('6168276')->is_valid_number, '京都府京都市右京区梅ケ畑清水町');
ok($zip->set_number('6168277')->is_valid_number, '京都府京都市右京区梅ケ畑広芝町');
ok($zip->set_number('6168278')->is_valid_number, '京都府京都市右京区梅ケ畑菖蒲谷');
ok($zip->set_number('6168281')->is_valid_number, '京都府京都市右京区梅ケ畑久保谷町');
ok($zip->set_number('6168282')->is_valid_number, '京都府京都市右京区梅ケ畑上砥町');
ok($zip->set_number('6168283')->is_valid_number, '京都府京都市右京区梅ケ畑奥殿町');
ok($zip->set_number('6168284')->is_valid_number, '京都府京都市右京区梅ケ畑御経坂町');
ok($zip->set_number('6168285')->is_valid_number, '京都府京都市右京区梅ケ畑檜社町');
ok($zip->set_number('6168286')->is_valid_number, '京都府京都市右京区梅ケ畑御所ノ口町');
ok($zip->set_number('6168287')->is_valid_number, '京都府京都市右京区梅ケ畑中嶋町');
ok($zip->set_number('6168288')->is_valid_number, '京都府京都市右京区梅ケ畑笹江辺町');
ok($zip->set_number('6168289')->is_valid_number, '京都府京都市右京区梅ケ畑西ノ畑町');
ok($zip->set_number('6168291')->is_valid_number, '京都府京都市右京区梅ケ畑槇尾町');
ok($zip->set_number('6168292')->is_valid_number, '京都府京都市右京区梅ケ畑高雄町');
ok($zip->set_number('6168293')->is_valid_number, '京都府京都市右京区梅ケ畑殿畑町');
ok($zip->set_number('6168294')->is_valid_number, '京都府京都市右京区梅ケ畑引地町');
ok($zip->set_number('6168295')->is_valid_number, '京都府京都市右京区梅ケ畑栂尾町');
ok($zip->set_number('6168296')->is_valid_number, '京都府京都市右京区梅ケ畑川西町');
ok($zip->set_number('6168297')->is_valid_number, '京都府京都市右京区梅ケ畑亀石町');
ok($zip->set_number('6168301')->is_valid_number, '京都府京都市右京区嵯峨広沢町');
ok($zip->set_number('6168302')->is_valid_number, '京都府京都市右京区嵯峨広沢北下馬野町');
ok($zip->set_number('6168303')->is_valid_number, '京都府京都市右京区嵯峨広沢南下馬野町');
ok($zip->set_number('6168304')->is_valid_number, '京都府京都市右京区嵯峨広沢南野町');
ok($zip->set_number('6168305')->is_valid_number, '京都府京都市右京区嵯峨広沢御所ノ内町');
ok($zip->set_number('6168306')->is_valid_number, '京都府京都市右京区嵯峨広沢西裏町');
ok($zip->set_number('6168307')->is_valid_number, '京都府京都市右京区嵯峨広沢池下町');
ok($zip->set_number('6168311')->is_valid_number, '京都府京都市右京区嵯峨野嵯峨ノ段町');
ok($zip->set_number('6168312')->is_valid_number, '京都府京都市右京区嵯峨野清水町');
ok($zip->set_number('6168313')->is_valid_number, '京都府京都市右京区嵯峨野開町');
ok($zip->set_number('6168314')->is_valid_number, '京都府京都市右京区嵯峨野秋街道町');
ok($zip->set_number('6168315')->is_valid_number, '京都府京都市右京区嵯峨野宮ノ元町');
ok($zip->set_number('6168316')->is_valid_number, '京都府京都市右京区嵯峨野有栖川町');
ok($zip->set_number('6168317')->is_valid_number, '京都府京都市右京区嵯峨野神ノ木町');
ok($zip->set_number('6168321')->is_valid_number, '京都府京都市右京区嵯峨野千代ノ道町');
ok($zip->set_number('6168322')->is_valid_number, '京都府京都市右京区嵯峨野芝野町');
ok($zip->set_number('6168323')->is_valid_number, '京都府京都市右京区嵯峨野投渕町');
ok($zip->set_number('6168324')->is_valid_number, '京都府京都市右京区嵯峨野南浦町');
ok($zip->set_number('6168325')->is_valid_number, '京都府京都市右京区嵯峨野高田町');
ok($zip->set_number('6168326')->is_valid_number, '京都府京都市右京区嵯峨野東田町');
ok($zip->set_number('6168327')->is_valid_number, '京都府京都市右京区嵯峨野六反田町');
ok($zip->set_number('6168331')->is_valid_number, '京都府京都市右京区嵯峨野内田町');
ok($zip->set_number('6168332')->is_valid_number, '京都府京都市右京区嵯峨野北野町');
ok($zip->set_number('6168333')->is_valid_number, '京都府京都市右京区嵯峨野西ノ藤町');
ok($zip->set_number('6168334')->is_valid_number, '京都府京都市右京区嵯峨罧原町');
ok($zip->set_number('6168335')->is_valid_number, '京都府京都市右京区嵯峨石ケ坪町');
ok($zip->set_number('6168336')->is_valid_number, '京都府京都市右京区嵯峨蜻蛉尻町');
ok($zip->set_number('6168337')->is_valid_number, '京都府京都市右京区嵯峨明星町');
ok($zip->set_number('6168341')->is_valid_number, '京都府京都市右京区嵯峨甲塚町');
ok($zip->set_number('6168342')->is_valid_number, '京都府京都市右京区嵯峨苅分町');
ok($zip->set_number('6168343')->is_valid_number, '京都府京都市右京区嵯峨朝日町');
ok($zip->set_number('6168344')->is_valid_number, '京都府京都市右京区嵯峨梅ノ木町');
ok($zip->set_number('6168345')->is_valid_number, '京都府京都市右京区嵯峨折戸町');
ok($zip->set_number('6168346')->is_valid_number, '京都府京都市右京区嵯峨天龍寺油掛町');
ok($zip->set_number('6168347')->is_valid_number, '京都府京都市右京区嵯峨中又町');
ok($zip->set_number('6168351')->is_valid_number, '京都府京都市右京区嵯峨釣殿町');
ok($zip->set_number('6168352')->is_valid_number, '京都府京都市右京区嵯峨大沢落久保町');
ok($zip->set_number('6168353')->is_valid_number, '京都府京都市右京区嵯峨大沢柳井手町');
ok($zip->set_number('6168354')->is_valid_number, '京都府京都市右京区嵯峨一本木町');
ok($zip->set_number('6168355')->is_valid_number, '京都府京都市右京区嵯峨新宮町');
ok($zip->set_number('6168356')->is_valid_number, '京都府京都市右京区嵯峨天龍寺中島町');
ok($zip->set_number('6168357')->is_valid_number, '京都府京都市右京区嵯峨天龍寺椎野町');
ok($zip->set_number('6168361')->is_valid_number, '京都府京都市右京区嵯峨中通町');
ok($zip->set_number('6168362')->is_valid_number, '京都府京都市右京区嵯峨五島町');
ok($zip->set_number('6168363')->is_valid_number, '京都府京都市右京区嵯峨柳田町');
ok($zip->set_number('6168364')->is_valid_number, '京都府京都市右京区嵯峨中山町');
ok($zip->set_number('6168365')->is_valid_number, '京都府京都市右京区嵯峨伊勢ノ上町');
ok($zip->set_number('6168366')->is_valid_number, '京都府京都市右京区嵯峨天龍寺今堀町');
ok($zip->set_number('6168367')->is_valid_number, '京都府京都市右京区嵯峨北堀町');
ok($zip->set_number('6168371')->is_valid_number, '京都府京都市右京区嵯峨天龍寺若宮町');
ok($zip->set_number('6168372')->is_valid_number, '京都府京都市右京区嵯峨天龍寺広道町');
ok($zip->set_number('6168373')->is_valid_number, '京都府京都市右京区嵯峨天龍寺車道町');
ok($zip->set_number('6168374')->is_valid_number, '京都府京都市右京区嵯峨天龍寺北造路町');
ok($zip->set_number('6168375')->is_valid_number, '京都府京都市右京区嵯峨天龍寺立石町');
ok($zip->set_number('6168376')->is_valid_number, '京都府京都市右京区嵯峨天龍寺瀬戸川町');
ok($zip->set_number('6168381')->is_valid_number, '京都府京都市右京区嵯峨天龍寺龍門町');
ok($zip->set_number('6168382')->is_valid_number, '京都府京都市右京区嵯峨天龍寺角倉町');
ok($zip->set_number('6168383')->is_valid_number, '京都府京都市右京区嵯峨中之島町');
ok($zip->set_number('6168384')->is_valid_number, '京都府京都市右京区嵯峨天龍寺造路町');
ok($zip->set_number('6168385')->is_valid_number, '京都府京都市右京区嵯峨天龍寺芒ノ馬場町');
ok($zip->set_number('6168386')->is_valid_number, '京都府京都市右京区嵯峨亀ノ尾町');
ok($zip->set_number('6168387')->is_valid_number, '京都府京都市右京区嵯峨亀山町');
ok($zip->set_number('6168391')->is_valid_number, '京都府京都市右京区嵯峨小倉山緋明神町');
ok($zip->set_number('6168392')->is_valid_number, '京都府京都市右京区嵯峨小倉山堂ノ前町');
ok($zip->set_number('6168393')->is_valid_number, '京都府京都市右京区嵯峨野々宮町');
ok($zip->set_number('6168394')->is_valid_number, '京都府京都市右京区嵯峨小倉山田渕山町');
ok($zip->set_number('6168395')->is_valid_number, '京都府京都市右京区嵯峨小倉山町');
ok($zip->set_number('6168396')->is_valid_number, '京都府京都市右京区嵯峨小倉山山本町');
ok($zip->set_number('6168397')->is_valid_number, '京都府京都市右京区嵯峨小倉山小倉町');
ok($zip->set_number('6168401')->is_valid_number, '京都府京都市右京区北嵯峨長刀坂町');
ok($zip->set_number('6168402')->is_valid_number, '京都府京都市右京区北嵯峨六代芝町');
ok($zip->set_number('6168403')->is_valid_number, '京都府京都市右京区北嵯峨洞ノ内町');
ok($zip->set_number('6168404')->is_valid_number, '京都府京都市右京区北嵯峨八丈町');
ok($zip->set_number('6168405')->is_valid_number, '京都府京都市右京区北嵯峨名古曽町');
ok($zip->set_number('6168406')->is_valid_number, '京都府京都市右京区北嵯峨山王町');
ok($zip->set_number('6168407')->is_valid_number, '京都府京都市右京区北嵯峨赤坂町');
ok($zip->set_number('6168411')->is_valid_number, '京都府京都市右京区嵯峨大沢町');
ok($zip->set_number('6168412')->is_valid_number, '京都府京都市右京区嵯峨大覚寺門前登り町');
ok($zip->set_number('6168413')->is_valid_number, '京都府京都市右京区嵯峨大覚寺門前堂ノ前町');
ok($zip->set_number('6168414')->is_valid_number, '京都府京都市右京区嵯峨大覚寺門前八軒町');
ok($zip->set_number('6168415')->is_valid_number, '京都府京都市右京区嵯峨大覚寺門前宮ノ下町');
ok($zip->set_number('6168416')->is_valid_number, '京都府京都市右京区嵯峨大覚寺門前井頭町');
ok($zip->set_number('6168417')->is_valid_number, '京都府京都市右京区嵯峨大覚寺門前六道町');
ok($zip->set_number('6168421')->is_valid_number, '京都府京都市右京区嵯峨釈迦堂門前瀬戸川町');
ok($zip->set_number('6168422')->is_valid_number, '京都府京都市右京区嵯峨釈迦堂大門町');
ok($zip->set_number('6168423')->is_valid_number, '京都府京都市右京区嵯峨釈迦堂門前裏柳町');
ok($zip->set_number('6168424')->is_valid_number, '京都府京都市右京区嵯峨釈迦堂門前南中院町');
ok($zip->set_number('6168425')->is_valid_number, '京都府京都市右京区嵯峨二尊院門前長神町');
ok($zip->set_number('6168426')->is_valid_number, '京都府京都市右京区嵯峨二尊院門前往生院町');
ok($zip->set_number('6168427')->is_valid_number, '京都府京都市右京区嵯峨二尊院門前善光寺山町');
ok($zip->set_number('6168428')->is_valid_number, '京都府京都市右京区嵯峨二尊院門前北中院町');
ok($zip->set_number('6168431')->is_valid_number, '京都府京都市右京区嵯峨鳥居本一華表町');
ok($zip->set_number('6168432')->is_valid_number, '京都府京都市右京区嵯峨鳥居本北代町');
ok($zip->set_number('6168433')->is_valid_number, '京都府京都市右京区嵯峨鳥居本中筋町');
ok($zip->set_number('6168434')->is_valid_number, '京都府京都市右京区嵯峨鳥居本仏餉田町');
ok($zip->set_number('6168435')->is_valid_number, '京都府京都市右京区嵯峨鳥居本小坂町');
ok($zip->set_number('6168436')->is_valid_number, '京都府京都市右京区嵯峨鳥居本化野町');
ok($zip->set_number('6168437')->is_valid_number, '京都府京都市右京区嵯峨鳥居本仙翁町');
ok($zip->set_number('6168438')->is_valid_number, '京都府京都市右京区嵯峨鳥居本六反町');
ok($zip->set_number('6168439')->is_valid_number, '京都府京都市右京区嵯峨鳥居本深谷町');
ok($zip->set_number('6168441')->is_valid_number, '京都府京都市右京区北嵯峨北ノ段町');
ok($zip->set_number('6168442')->is_valid_number, '京都府京都市右京区北嵯峨気比社町');
ok($zip->set_number('6168443')->is_valid_number, '京都府京都市右京区嵯峨観空寺明水町');
ok($zip->set_number('6168444')->is_valid_number, '京都府京都市右京区嵯峨観空寺久保殿町');
ok($zip->set_number('6168445')->is_valid_number, '京都府京都市右京区嵯峨観空寺岡崎町');
ok($zip->set_number('6168446')->is_valid_number, '京都府京都市右京区嵯峨観空寺谷町');
ok($zip->set_number('6168447')->is_valid_number, '京都府京都市右京区嵯峨釈迦堂藤ノ木町');
ok($zip->set_number('6168451')->is_valid_number, '京都府京都市右京区嵯峨清滝一華表町');
ok($zip->set_number('6168452')->is_valid_number, '京都府京都市右京区嵯峨清滝町');
ok($zip->set_number('6168453')->is_valid_number, '京都府京都市右京区嵯峨清滝大谷町');
ok($zip->set_number('6168454')->is_valid_number, '京都府京都市右京区嵯峨清滝深谷町');
ok($zip->set_number('6168455')->is_valid_number, '京都府京都市右京区嵯峨清滝田鶴原町');
ok($zip->set_number('6168456')->is_valid_number, '京都府京都市右京区嵯峨清滝月ノ輪町');
ok($zip->set_number('6168457')->is_valid_number, '京都府京都市右京区嵯峨清滝空也滝町');
ok($zip->set_number('6168458')->is_valid_number, '京都府京都市右京区嵯峨愛宕町');
ok($zip->set_number('6168461')->is_valid_number, '京都府京都市右京区嵯峨水尾鳩ケ巣');
ok($zip->set_number('6168462')->is_valid_number, '京都府京都市右京区嵯峨水尾岡ノ窪町');
ok($zip->set_number('6168463')->is_valid_number, '京都府京都市右京区嵯峨水尾竹ノ尻町');
ok($zip->set_number('6168464')->is_valid_number, '京都府京都市右京区嵯峨水尾武蔵嶋町');
ok($zip->set_number('6168465')->is_valid_number, '京都府京都市右京区嵯峨水尾宮ノ脇町');
ok($zip->set_number('6168466')->is_valid_number, '京都府京都市右京区嵯峨水尾清和');
ok($zip->set_number('6168467')->is_valid_number, '京都府京都市右京区嵯峨水尾大岩');
ok($zip->set_number('6168468')->is_valid_number, '京都府京都市右京区嵯峨水尾北垣内町');
ok($zip->set_number('6168471')->is_valid_number, '京都府京都市右京区嵯峨樒原稲荷元町');
ok($zip->set_number('6168472')->is_valid_number, '京都府京都市右京区嵯峨樒原高見町');
ok($zip->set_number('6168473')->is_valid_number, '京都府京都市右京区嵯峨樒原若宮下町');
ok($zip->set_number('6168474')->is_valid_number, '京都府京都市右京区嵯峨樒原清水町');
ok($zip->set_number('6168475')->is_valid_number, '京都府京都市右京区嵯峨樒原宮ノ上町');
ok($zip->set_number('6168481')->is_valid_number, '京都府京都市右京区嵯峨越畑桃原');
ok($zip->set_number('6168482')->is_valid_number, '京都府京都市右京区嵯峨越畑正権条');
ok($zip->set_number('6168483')->is_valid_number, '京都府京都市右京区嵯峨越畑鍋浦');
ok($zip->set_number('6168484')->is_valid_number, '京都府京都市右京区嵯峨越畑筋違');
ok($zip->set_number('6168485')->is_valid_number, '京都府京都市右京区嵯峨越畑兵庫前町');
ok($zip->set_number('6168486')->is_valid_number, '京都府京都市右京区嵯峨越畑南ノ町');
ok($zip->set_number('6168487')->is_valid_number, '京都府京都市右京区嵯峨越畑中ノ町');
ok($zip->set_number('6168491')->is_valid_number, '京都府京都市右京区嵯峨越畑北ノ町');
ok($zip->set_number('6168492')->is_valid_number, '京都府京都市右京区嵯峨越畑天慶');
ok($zip->set_number('6168493')->is_valid_number, '京都府京都市右京区嵯峨越畑桃原垣内');
ok($zip->set_number('6168494')->is_valid_number, '京都府京都市右京区嵯峨越畑尻谷');
ok($zip->set_number('6170000')->is_valid_number, '京都府向日市以下に掲載がない場合');
ok($zip->set_number('6170000')->is_valid_number, '京都府長岡京市以下に掲載がない場合');
ok($zip->set_number('6170001')->is_valid_number, '京都府向日市物集女町');
ok($zip->set_number('6170002')->is_valid_number, '京都府向日市寺戸町');
ok($zip->set_number('6170003')->is_valid_number, '京都府向日市森本町');
ok($zip->set_number('6170004')->is_valid_number, '京都府向日市鶏冠井町');
ok($zip->set_number('6170005')->is_valid_number, '京都府向日市向日町');
ok($zip->set_number('6170006')->is_valid_number, '京都府向日市上植野町');
ok($zip->set_number('6170811')->is_valid_number, '京都府長岡京市粟生');
ok($zip->set_number('6170812')->is_valid_number, '京都府長岡京市長法寺');
ok($zip->set_number('6170813')->is_valid_number, '京都府長岡京市井ノ内');
ok($zip->set_number('6170814')->is_valid_number, '京都府長岡京市今里');
ok($zip->set_number('6170815')->is_valid_number, '京都府長岡京市うぐいす台');
ok($zip->set_number('6170816')->is_valid_number, '京都府長岡京市西の京');
ok($zip->set_number('6170817')->is_valid_number, '京都府長岡京市滝ノ町');
ok($zip->set_number('6170818')->is_valid_number, '京都府長岡京市柴の里');
ok($zip->set_number('6170821')->is_valid_number, '京都府長岡京市野添');
ok($zip->set_number('6170822')->is_valid_number, '京都府長岡京市八条が丘');
ok($zip->set_number('6170823')->is_valid_number, '京都府長岡京市長岡');
ok($zip->set_number('6170824')->is_valid_number, '京都府長岡京市天神');
ok($zip->set_number('6170825')->is_valid_number, '京都府長岡京市一文橋');
ok($zip->set_number('6170826')->is_valid_number, '京都府長岡京市開田');
ok($zip->set_number('6170827')->is_valid_number, '京都府長岡京市竹の台');
ok($zip->set_number('6170828')->is_valid_number, '京都府長岡京市馬場');
ok($zip->set_number('6170831')->is_valid_number, '京都府長岡京市一里塚');
ok($zip->set_number('6170832')->is_valid_number, '京都府長岡京市東神足');
ok($zip->set_number('6170833')->is_valid_number, '京都府長岡京市神足');
ok($zip->set_number('6170834')->is_valid_number, '京都府長岡京市東和苑');
ok($zip->set_number('6170835')->is_valid_number, '京都府長岡京市城の里');
ok($zip->set_number('6170836')->is_valid_number, '京都府長岡京市勝竜寺');
ok($zip->set_number('6170837')->is_valid_number, '京都府長岡京市久貝');
ok($zip->set_number('6170838')->is_valid_number, '京都府長岡京市緑が丘');
ok($zip->set_number('6170841')->is_valid_number, '京都府長岡京市梅が丘');
ok($zip->set_number('6170842')->is_valid_number, '京都府長岡京市花山');
ok($zip->set_number('6170843')->is_valid_number, '京都府長岡京市友岡');
ok($zip->set_number('6170844')->is_valid_number, '京都府長岡京市調子');
ok($zip->set_number('6170845')->is_valid_number, '京都府長岡京市下海印寺');
ok($zip->set_number('6170846')->is_valid_number, '京都府長岡京市泉が丘');
ok($zip->set_number('6170847')->is_valid_number, '京都府長岡京市高台');
ok($zip->set_number('6170851')->is_valid_number, '京都府長岡京市光風台');
ok($zip->set_number('6170852')->is_valid_number, '京都府長岡京市河陽が丘');
ok($zip->set_number('6170853')->is_valid_number, '京都府長岡京市奥海印寺');
ok($zip->set_number('6170854')->is_valid_number, '京都府長岡京市こがねが丘');
ok($zip->set_number('6170855')->is_valid_number, '京都府長岡京市浄土谷');
ok($zip->set_number('6170856')->is_valid_number, '京都府長岡京市金ケ原');
ok($zip->set_number('6170857')->is_valid_number, '京都府長岡京市高台西');
ok($zip->set_number('6180000')->is_valid_number, '京都府乙訓郡大山崎町以下に掲載がない場合');
ok($zip->set_number('6180000')->is_valid_number, '大阪府三島郡島本町以下に掲載がない場合');
ok($zip->set_number('6180001')->is_valid_number, '大阪府三島郡島本町山崎');
ok($zip->set_number('6180002')->is_valid_number, '大阪府三島郡島本町東大寺');
ok($zip->set_number('6180003')->is_valid_number, '大阪府三島郡島本町尺代');
ok($zip->set_number('6180004')->is_valid_number, '大阪府三島郡島本町大沢');
ok($zip->set_number('6180011')->is_valid_number, '大阪府三島郡島本町広瀬');
ok($zip->set_number('6180012')->is_valid_number, '大阪府三島郡島本町高浜');
ok($zip->set_number('6180013')->is_valid_number, '大阪府三島郡島本町江川');
ok($zip->set_number('6180014')->is_valid_number, '大阪府三島郡島本町水無瀬');
ok($zip->set_number('6180015')->is_valid_number, '大阪府三島郡島本町青葉');
ok($zip->set_number('6180021')->is_valid_number, '大阪府三島郡島本町百山');
ok($zip->set_number('6180022')->is_valid_number, '大阪府三島郡島本町桜井');
ok($zip->set_number('6180023')->is_valid_number, '大阪府三島郡島本町桜井台');
ok($zip->set_number('6180024')->is_valid_number, '大阪府三島郡島本町若山台');
ok($zip->set_number('6180071')->is_valid_number, '京都府乙訓郡大山崎町大山崎');
ok($zip->set_number('6180081')->is_valid_number, '京都府乙訓郡大山崎町下植野');
ok($zip->set_number('6180091')->is_valid_number, '京都府乙訓郡大山崎町円明寺');
ok($zip->set_number('6190200')->is_valid_number, '京都府木津川市以下に掲載がない場合');
ok($zip->set_number('6190200')->is_valid_number, '京都府相楽郡精華町以下に掲載がない場合');
ok($zip->set_number('6190201')->is_valid_number, '京都府木津川市山城町綺田');
ok($zip->set_number('6190202')->is_valid_number, '京都府木津川市山城町平尾');
ok($zip->set_number('6190203')->is_valid_number, '京都府木津川市山城町神童子');
ok($zip->set_number('6190204')->is_valid_number, '京都府木津川市山城町上狛');
ok($zip->set_number('6190205')->is_valid_number, '京都府木津川市山城町椿井');
ok($zip->set_number('6190206')->is_valid_number, '京都府木津川市山城町北河原');
ok($zip->set_number('6190211')->is_valid_number, '京都府木津川市鹿背山');
ok($zip->set_number('6190212')->is_valid_number, '京都府木津川市梅谷');
ok($zip->set_number('6190213')->is_valid_number, '京都府木津川市市坂');
ok($zip->set_number('6190214')->is_valid_number, '京都府木津川市木津');
ok($zip->set_number('6190214')->is_valid_number, '京都府木津川市木津駅前');
ok($zip->set_number('6190215')->is_valid_number, '京都府木津川市梅美台');
ok($zip->set_number('6190216')->is_valid_number, '京都府木津川市州見台');
ok($zip->set_number('6190217')->is_valid_number, '京都府木津川市木津町');
ok($zip->set_number('6190218')->is_valid_number, '京都府木津川市城山台');
ok($zip->set_number('6190221')->is_valid_number, '京都府木津川市吐師');
ok($zip->set_number('6190222')->is_valid_number, '京都府木津川市相楽');
ok($zip->set_number('6190223')->is_valid_number, '京都府木津川市相楽台');
ok($zip->set_number('6190224')->is_valid_number, '京都府木津川市兜台');
ok($zip->set_number('6190225')->is_valid_number, '京都府木津川市木津川台');
ok($zip->set_number('6190231')->is_valid_number, '京都府相楽郡精華町山田');
ok($zip->set_number('6190232')->is_valid_number, '京都府相楽郡精華町桜が丘');
ok($zip->set_number('6190233')->is_valid_number, '京都府相楽郡精華町乾谷');
ok($zip->set_number('6190234')->is_valid_number, '京都府相楽郡精華町柘榴');
ok($zip->set_number('6190235')->is_valid_number, '京都府相楽郡精華町東畑');
ok($zip->set_number('6190236')->is_valid_number, '京都府相楽郡精華町植田');
ok($zip->set_number('6190237')->is_valid_number, '京都府相楽郡精華町光台');
ok($zip->set_number('6190238')->is_valid_number, '京都府相楽郡精華町精華台');
ok($zip->set_number('6190240')->is_valid_number, '京都府相楽郡精華町祝園西');
ok($zip->set_number('6190241')->is_valid_number, '京都府相楽郡精華町祝園');
ok($zip->set_number('6190242')->is_valid_number, '京都府相楽郡精華町菅井');
ok($zip->set_number('6190243')->is_valid_number, '京都府相楽郡精華町南稲八妻');
ok($zip->set_number('6190244')->is_valid_number, '京都府相楽郡精華町北稲八間');
ok($zip->set_number('6190245')->is_valid_number, '京都府相楽郡精華町下狛');
ok($zip->set_number('6190246')->is_valid_number, '京都府相楽郡精華町菱田');
ok($zip->set_number('6190247')->is_valid_number, '京都府相楽郡精華町狛田');
ok($zip->set_number('6191101')->is_valid_number, '京都府木津川市加茂町銭司');
ok($zip->set_number('6191102')->is_valid_number, '京都府木津川市加茂町井平尾');
ok($zip->set_number('6191103')->is_valid_number, '京都府木津川市加茂町岡崎');
ok($zip->set_number('6191104')->is_valid_number, '京都府木津川市加茂町河原');
ok($zip->set_number('6191105')->is_valid_number, '京都府木津川市加茂町西');
ok($zip->set_number('6191106')->is_valid_number, '京都府木津川市加茂町例幣');
ok($zip->set_number('6191107')->is_valid_number, '京都府木津川市加茂町奥畑');
ok($zip->set_number('6191111')->is_valid_number, '京都府木津川市加茂町山田');
ok($zip->set_number('6191112')->is_valid_number, '京都府木津川市加茂町兎並');
ok($zip->set_number('6191113')->is_valid_number, '京都府木津川市加茂町北');
ok($zip->set_number('6191121')->is_valid_number, '京都府木津川市加茂町北下手');
ok($zip->set_number('6191122')->is_valid_number, '京都府木津川市加茂町南下手');
ok($zip->set_number('6191123')->is_valid_number, '京都府木津川市加茂町森');
ok($zip->set_number('6191124')->is_valid_number, '京都府木津川市加茂町勝風');
ok($zip->set_number('6191125')->is_valid_number, '京都府木津川市加茂町高去');
ok($zip->set_number('6191126')->is_valid_number, '京都府木津川市加茂町尻枝');
ok($zip->set_number('6191127')->is_valid_number, '京都府木津川市南加茂台');
ok($zip->set_number('6191131')->is_valid_number, '京都府木津川市加茂町辻');
ok($zip->set_number('6191132')->is_valid_number, '京都府木津川市加茂町大畑');
ok($zip->set_number('6191133')->is_valid_number, '京都府木津川市加茂町岩船');
ok($zip->set_number('6191134')->is_valid_number, '京都府木津川市加茂町東小上');
ok($zip->set_number('6191134')->is_valid_number, '京都府木津川市加茂町東小下');
ok($zip->set_number('6191135')->is_valid_number, '京都府木津川市加茂町西小');
ok($zip->set_number('6191136')->is_valid_number, '京都府木津川市加茂町北大門');
ok($zip->set_number('6191136')->is_valid_number, '京都府木津川市加茂町南大門');
ok($zip->set_number('6191141')->is_valid_number, '京都府木津川市加茂町法花寺野');
ok($zip->set_number('6191142')->is_valid_number, '京都府木津川市加茂町大野');
ok($zip->set_number('6191143')->is_valid_number, '京都府木津川市加茂町観音寺');
ok($zip->set_number('6191144')->is_valid_number, '京都府木津川市加茂町高田');
ok($zip->set_number('6191151')->is_valid_number, '京都府木津川市加茂町美浪');
ok($zip->set_number('6191152')->is_valid_number, '京都府木津川市加茂町里');
ok($zip->set_number('6191153')->is_valid_number, '京都府木津川市加茂町駅西');
ok($zip->set_number('6191154')->is_valid_number, '京都府木津川市加茂町駅東');
ok($zip->set_number('6191200')->is_valid_number, '京都府相楽郡和束町以下に掲載がない場合');
ok($zip->set_number('6191201')->is_valid_number, '京都府相楽郡和束町園');
ok($zip->set_number('6191202')->is_valid_number, '京都府相楽郡和束町原山');
ok($zip->set_number('6191203')->is_valid_number, '京都府相楽郡和束町湯船');
ok($zip->set_number('6191204')->is_valid_number, '京都府相楽郡和束町門前');
ok($zip->set_number('6191205')->is_valid_number, '京都府相楽郡和束町中');
ok($zip->set_number('6191211')->is_valid_number, '京都府相楽郡和束町別所');
ok($zip->set_number('6191212')->is_valid_number, '京都府相楽郡和束町釜塚');
ok($zip->set_number('6191213')->is_valid_number, '京都府相楽郡和束町南');
ok($zip->set_number('6191221')->is_valid_number, '京都府相楽郡和束町石寺');
ok($zip->set_number('6191222')->is_valid_number, '京都府相楽郡和束町白栖');
ok($zip->set_number('6191223')->is_valid_number, '京都府相楽郡和束町杣田');
ok($zip->set_number('6191224')->is_valid_number, '京都府相楽郡和束町木屋');
ok($zip->set_number('6191225')->is_valid_number, '京都府相楽郡和束町撰原');
ok($zip->set_number('6191226')->is_valid_number, '京都府相楽郡和束町下島');
ok($zip->set_number('6191300')->is_valid_number, '京都府相楽郡笠置町以下に掲載がない場合');
ok($zip->set_number('6191301')->is_valid_number, '京都府相楽郡笠置町有市');
ok($zip->set_number('6191302')->is_valid_number, '京都府相楽郡笠置町飛鳥路');
ok($zip->set_number('6191303')->is_valid_number, '京都府相楽郡笠置町笠置');
ok($zip->set_number('6191304')->is_valid_number, '京都府相楽郡笠置町切山');
ok($zip->set_number('6191400')->is_valid_number, '京都府相楽郡南山城村以下に掲載がない場合');
ok($zip->set_number('6191401')->is_valid_number, '京都府相楽郡南山城村童仙房');
ok($zip->set_number('6191402')->is_valid_number, '京都府相楽郡南山城村野殿');
ok($zip->set_number('6191411')->is_valid_number, '京都府相楽郡南山城村北大河原');
ok($zip->set_number('6191412')->is_valid_number, '京都府相楽郡南山城村南大河原');
ok($zip->set_number('6191421')->is_valid_number, '京都府相楽郡南山城村田山');
ok($zip->set_number('6191422')->is_valid_number, '京都府相楽郡南山城村高尾');
ok($zip->set_number('6200000')->is_valid_number, '京都府福知山市以下に掲載がない場合');
ok($zip->set_number('6200001')->is_valid_number, '京都府福知山市山野口');
ok($zip->set_number('6200002')->is_valid_number, '京都府福知山市報恩寺');
ok($zip->set_number('6200003')->is_valid_number, '京都府福知山市私市');
ok($zip->set_number('6200004')->is_valid_number, '京都府福知山市川北');
ok($zip->set_number('6200005')->is_valid_number, '京都府福知山市印内');
ok($zip->set_number('6200011')->is_valid_number, '京都府福知山市筈巻');
ok($zip->set_number('6200012')->is_valid_number, '京都府福知山市安井');
ok($zip->set_number('6200013')->is_valid_number, '京都府福知山市池部');
ok($zip->set_number('6200014')->is_valid_number, '京都府福知山市中');
ok($zip->set_number('6200015')->is_valid_number, '京都府福知山市下猪崎');
ok($zip->set_number('6200016')->is_valid_number, '京都府福知山市城山');
ok($zip->set_number('6200017')->is_valid_number, '京都府福知山市猪崎');
ok($zip->set_number('6200021')->is_valid_number, '京都府福知山市寺');
ok($zip->set_number('6200022')->is_valid_number, '京都府福知山市下柳');
ok($zip->set_number('6200023')->is_valid_number, '京都府福知山市菱屋');
ok($zip->set_number('6200024')->is_valid_number, '京都府福知山市東長町');
ok($zip->set_number('6200025')->is_valid_number, '京都府福知山市西長町');
ok($zip->set_number('6200026')->is_valid_number, '京都府福知山市呉服');
ok($zip->set_number('6200027')->is_valid_number, '京都府福知山市京');
ok($zip->set_number('6200028')->is_valid_number, '京都府福知山市上新');
ok($zip->set_number('6200029')->is_valid_number, '京都府福知山市下新');
ok($zip->set_number('6200031')->is_valid_number, '京都府福知山市鋳物師');
ok($zip->set_number('6200032')->is_valid_number, '京都府福知山市下紺屋');
ok($zip->set_number('6200033')->is_valid_number, '京都府福知山市上紺屋');
ok($zip->set_number('6200034')->is_valid_number, '京都府福知山市鍛冶');
ok($zip->set_number('6200035')->is_valid_number, '京都府福知山市内記');
ok($zip->set_number('6200036')->is_valid_number, '京都府福知山市中ノ町');
ok($zip->set_number('6200037')->is_valid_number, '京都府福知山市東中ノ町');
ok($zip->set_number('6200038')->is_valid_number, '京都府福知山市西中ノ町');
ok($zip->set_number('6200039')->is_valid_number, '京都府福知山市西町');
ok($zip->set_number('6200041')->is_valid_number, '京都府福知山市北本町一区');
ok($zip->set_number('6200042')->is_valid_number, '京都府福知山市北本町二区');
ok($zip->set_number('6200043')->is_valid_number, '京都府福知山市北栄町');
ok($zip->set_number('6200044')->is_valid_number, '京都府福知山市南栄町');
ok($zip->set_number('6200045')->is_valid_number, '京都府福知山市駅前町');
ok($zip->set_number('6200046')->is_valid_number, '京都府福知山市南本町');
ok($zip->set_number('6200047')->is_valid_number, '京都府福知山市東本町');
ok($zip->set_number('6200051')->is_valid_number, '京都府福知山市昭和新町');
ok($zip->set_number('6200052')->is_valid_number, '京都府福知山市昭和町');
ok($zip->set_number('6200053')->is_valid_number, '京都府福知山市西本町');
ok($zip->set_number('6200054')->is_valid_number, '京都府福知山市末広町');
ok($zip->set_number('6200055')->is_valid_number, '京都府福知山市篠尾(篠尾新町)');
ok($zip->set_number('6200055')->is_valid_number, '京都府福知山市篠尾新町');
ok($zip->set_number('6200056')->is_valid_number, '京都府福知山市厚中町');
ok($zip->set_number('6200057')->is_valid_number, '京都府福知山市問屋町');
ok($zip->set_number('6200058')->is_valid_number, '京都府福知山市厚');
ok($zip->set_number('6200059')->is_valid_number, '京都府福知山市厚東町');
ok($zip->set_number('6200061')->is_valid_number, '京都府福知山市荒河東町');
ok($zip->set_number('6200062')->is_valid_number, '京都府福知山市和久市町');
ok($zip->set_number('6200063')->is_valid_number, '京都府福知山市荒河新町');
ok($zip->set_number('6200064')->is_valid_number, '京都府福知山市岩井東町');
ok($zip->set_number('6200065')->is_valid_number, '京都府福知山市上荒河');
ok($zip->set_number('6200066')->is_valid_number, '京都府福知山市下荒河');
ok($zip->set_number('6200067')->is_valid_number, '京都府福知山市荒河ヒルズ');
ok($zip->set_number('6200071')->is_valid_number, '京都府福知山市一尾');
ok($zip->set_number('6200072')->is_valid_number, '京都府福知山市下天津');
ok($zip->set_number('6200073')->is_valid_number, '京都府福知山市勅使');
ok($zip->set_number('6200074')->is_valid_number, '京都府福知山市石本');
ok($zip->set_number('6200075')->is_valid_number, '京都府福知山市波江');
ok($zip->set_number('6200076')->is_valid_number, '京都府福知山市漆端');
ok($zip->set_number('6200077')->is_valid_number, '京都府福知山市大呂');
ok($zip->set_number('6200078')->is_valid_number, '京都府福知山市瘤木');
ok($zip->set_number('6200201')->is_valid_number, '京都府福知山市天座');
ok($zip->set_number('6200211')->is_valid_number, '京都府福知山市下野条');
ok($zip->set_number('6200212')->is_valid_number, '京都府福知山市行積');
ok($zip->set_number('6200213')->is_valid_number, '京都府福知山市長尾');
ok($zip->set_number('6200214')->is_valid_number, '京都府福知山市上野条');
ok($zip->set_number('6200221')->is_valid_number, '京都府福知山市雲原');
ok($zip->set_number('6200301')->is_valid_number, '京都府福知山市大江町河守');
ok($zip->set_number('6200302')->is_valid_number, '京都府福知山市大江町関');
ok($zip->set_number('6200303')->is_valid_number, '京都府福知山市大江町金屋');
ok($zip->set_number('6200304')->is_valid_number, '京都府福知山市大江町上野');
ok($zip->set_number('6200305')->is_valid_number, '京都府福知山市大江町波美');
ok($zip->set_number('6200311')->is_valid_number, '京都府福知山市大江町蓼原');
ok($zip->set_number('6200312')->is_valid_number, '京都府福知山市大江町公庄');
ok($zip->set_number('6200313')->is_valid_number, '京都府福知山市大江町日藤');
ok($zip->set_number('6200314')->is_valid_number, '京都府福知山市大江町小原田');
ok($zip->set_number('6200321')->is_valid_number, '京都府福知山市大江町仏性寺');
ok($zip->set_number('6200322')->is_valid_number, '京都府福知山市大江町毛原');
ok($zip->set_number('6200323')->is_valid_number, '京都府福知山市大江町内宮');
ok($zip->set_number('6200324')->is_valid_number, '京都府福知山市大江町二俣');
ok($zip->set_number('6200325')->is_valid_number, '京都府福知山市大江町天田内');
ok($zip->set_number('6200326')->is_valid_number, '京都府福知山市大江町橋谷');
ok($zip->set_number('6200327')->is_valid_number, '京都府福知山市大江町北原');
ok($zip->set_number('6200331')->is_valid_number, '京都府福知山市大江町三河');
ok($zip->set_number('6200332')->is_valid_number, '京都府福知山市大江町高津江');
ok($zip->set_number('6200333')->is_valid_number, '京都府福知山市大江町二箇');
ok($zip->set_number('6200334')->is_valid_number, '京都府福知山市大江町市原谷');
ok($zip->set_number('6200341')->is_valid_number, '京都府福知山市大江町北有路');
ok($zip->set_number('6200342')->is_valid_number, '京都府福知山市大江町南有路');
ok($zip->set_number('6200351')->is_valid_number, '京都府福知山市大江町千原');
ok($zip->set_number('6200352')->is_valid_number, '京都府福知山市大江町南山');
ok($zip->set_number('6200353')->is_valid_number, '京都府福知山市大江町夏間');
ok($zip->set_number('6200354')->is_valid_number, '京都府福知山市大江町在田');
ok($zip->set_number('6200355')->is_valid_number, '京都府福知山市大江町常津');
ok($zip->set_number('6200356')->is_valid_number, '京都府福知山市大江町尾藤');
ok($zip->set_number('6200801')->is_valid_number, '京都府福知山市戸田');
ok($zip->set_number('6200802')->is_valid_number, '京都府福知山市興');
ok($zip->set_number('6200803')->is_valid_number, '京都府福知山市観音寺');
ok($zip->set_number('6200804')->is_valid_number, '京都府福知山市石原');
ok($zip->set_number('6200805')->is_valid_number, '京都府福知山市南土野町');
ok($zip->set_number('6200806')->is_valid_number, '京都府福知山市聖佳町');
ok($zip->set_number('6200807')->is_valid_number, '京都府福知山市東野町');
ok($zip->set_number('6200808')->is_valid_number, '京都府福知山市土');
ok($zip->set_number('6200811')->is_valid_number, '京都府福知山市北平野町');
ok($zip->set_number('6200812')->is_valid_number, '京都府福知山市東平野町');
ok($zip->set_number('6200813')->is_valid_number, '京都府福知山市南平野町');
ok($zip->set_number('6200814')->is_valid_number, '京都府福知山市西平野町');
ok($zip->set_number('6200815')->is_valid_number, '京都府福知山市長山町');
ok($zip->set_number('6200816')->is_valid_number, '京都府福知山市大池坂町');
ok($zip->set_number('6200817')->is_valid_number, '京都府福知山市中坂町');
ok($zip->set_number('6200821')->is_valid_number, '京都府福知山市三俣');
ok($zip->set_number('6200822')->is_valid_number, '京都府福知山市萩原');
ok($zip->set_number('6200823')->is_valid_number, '京都府福知山市生野');
ok($zip->set_number('6200824')->is_valid_number, '京都府福知山市堀越');
ok($zip->set_number('6200825')->is_valid_number, '京都府福知山市上野');
ok($zip->set_number('6200826')->is_valid_number, '京都府福知山市正後寺');
ok($zip->set_number('6200827')->is_valid_number, '京都府福知山市坂室');
ok($zip->set_number('6200828')->is_valid_number, '京都府福知山市正坂');
ok($zip->set_number('6200831')->is_valid_number, '京都府福知山市岩崎');
ok($zip->set_number('6200832')->is_valid_number, '京都府福知山市池田');
ok($zip->set_number('6200833')->is_valid_number, '京都府福知山市宮');
ok($zip->set_number('6200834')->is_valid_number, '京都府福知山市中地');
ok($zip->set_number('6200835')->is_valid_number, '京都府福知山市後正寺');
ok($zip->set_number('6200836')->is_valid_number, '京都府福知山市大内');
ok($zip->set_number('6200837')->is_valid_number, '京都府福知山市田野');
ok($zip->set_number('6200838')->is_valid_number, '京都府福知山市笹場');
ok($zip->set_number('6200839')->is_valid_number, '京都府福知山市下地');
ok($zip->set_number('6200841')->is_valid_number, '京都府福知山市駒場新町');
ok($zip->set_number('6200842')->is_valid_number, '京都府福知山市長田北');
ok($zip->set_number('6200843')->is_valid_number, '京都府福知山市長田南');
ok($zip->set_number('6200844')->is_valid_number, '京都府福知山市多保市');
ok($zip->set_number('6200845')->is_valid_number, '京都府福知山市上松');
ok($zip->set_number('6200846')->is_valid_number, '京都府福知山市長田段');
ok($zip->set_number('6200847')->is_valid_number, '京都府福知山市岩間');
ok($zip->set_number('6200848')->is_valid_number, '京都府福知山市市の谷');
ok($zip->set_number('6200849')->is_valid_number, '京都府福知山市砂子町');
ok($zip->set_number('6200851')->is_valid_number, '京都府福知山市大野下');
ok($zip->set_number('6200852')->is_valid_number, '京都府福知山市大野上');
ok($zip->set_number('6200853')->is_valid_number, '京都府福知山市長田野町');
ok($zip->set_number('6200854')->is_valid_number, '京都府福知山市高畑');
ok($zip->set_number('6200855')->is_valid_number, '京都府福知山市土師(新町)');
ok($zip->set_number('6200856')->is_valid_number, '京都府福知山市土師(宮町)');
ok($zip->set_number('6200857')->is_valid_number, '京都府福知山市土師');
ok($zip->set_number('6200858')->is_valid_number, '京都府福知山市大野');
ok($zip->set_number('6200859')->is_valid_number, '京都府福知山市桔梗が丘');
ok($zip->set_number('6200861')->is_valid_number, '京都府福知山市秋津が丘');
ok($zip->set_number('6200862')->is_valid_number, '京都府福知山市東佳屋野町');
ok($zip->set_number('6200863')->is_valid_number, '京都府福知山市小松ケ丘');
ok($zip->set_number('6200864')->is_valid_number, '京都府福知山市南佳屋野町');
ok($zip->set_number('6200865')->is_valid_number, '京都府福知山市西佳屋野町');
ok($zip->set_number('6200866')->is_valid_number, '京都府福知山市前田新町');
ok($zip->set_number('6200867')->is_valid_number, '京都府福知山市前田');
ok($zip->set_number('6200871')->is_valid_number, '京都府福知山市岡ノ二町');
ok($zip->set_number('6200872')->is_valid_number, '京都府福知山市岡ノ一町');
ok($zip->set_number('6200873')->is_valid_number, '京都府福知山市岡ノ三町');
ok($zip->set_number('6200874')->is_valid_number, '京都府福知山市堀口');
ok($zip->set_number('6200875')->is_valid_number, '京都府福知山市蛇ケ端');
ok($zip->set_number('6200876')->is_valid_number, '京都府福知山市水内');
ok($zip->set_number('6200877')->is_valid_number, '京都府福知山市森垣');
ok($zip->set_number('6200878')->is_valid_number, '京都府福知山市日吉ケ丘');
ok($zip->set_number('6200879')->is_valid_number, '京都府福知山市荒木');
ok($zip->set_number('6200881')->is_valid_number, '京都府福知山市内田町');
ok($zip->set_number('6200882')->is_valid_number, '京都府福知山市東堀');
ok($zip->set_number('6200883')->is_valid_number, '京都府福知山市本堀');
ok($zip->set_number('6200884')->is_valid_number, '京都府福知山市南本堀');
ok($zip->set_number('6200885')->is_valid_number, '京都府福知山市南小谷ケ丘');
ok($zip->set_number('6200886')->is_valid_number, '京都府福知山市西小谷ケ丘');
ok($zip->set_number('6200887')->is_valid_number, '京都府福知山市東小谷ケ丘');
ok($zip->set_number('6200888')->is_valid_number, '京都府福知山市野家');
ok($zip->set_number('6200891')->is_valid_number, '京都府福知山市岡ノ上町');
ok($zip->set_number('6200892')->is_valid_number, '京都府福知山市東岡町');
ok($zip->set_number('6200893')->is_valid_number, '京都府福知山市北小谷ケ丘');
ok($zip->set_number('6200894')->is_valid_number, '京都府福知山市丸田ケ丘');
ok($zip->set_number('6200895')->is_valid_number, '京都府福知山市緑ケ丘町');
ok($zip->set_number('6200901')->is_valid_number, '京都府福知山市上佐々木');
ok($zip->set_number('6200902')->is_valid_number, '京都府福知山市喜多');
ok($zip->set_number('6200903')->is_valid_number, '京都府福知山市日尾');
ok($zip->set_number('6200904')->is_valid_number, '京都府福知山市常願寺');
ok($zip->set_number('6200905')->is_valid_number, '京都府福知山市田和');
ok($zip->set_number('6200906')->is_valid_number, '京都府福知山市新宮');
ok($zip->set_number('6200907')->is_valid_number, '京都府福知山市一ノ宮');
ok($zip->set_number('6200908')->is_valid_number, '京都府福知山市下佐々木');
ok($zip->set_number('6200909')->is_valid_number, '京都府福知山市中佐々木');
ok($zip->set_number('6200911')->is_valid_number, '京都府福知山市上大内');
ok($zip->set_number('6200912')->is_valid_number, '京都府福知山市下大内');
ok($zip->set_number('6200913')->is_valid_number, '京都府福知山市牧');
ok($zip->set_number('6200914')->is_valid_number, '京都府福知山市立原');
ok($zip->set_number('6200915')->is_valid_number, '京都府福知山市十二');
ok($zip->set_number('6200916')->is_valid_number, '京都府福知山市六十内');
ok($zip->set_number('6200917')->is_valid_number, '京都府福知山市野花');
ok($zip->set_number('6200918')->is_valid_number, '京都府福知山市夷');
ok($zip->set_number('6200920')->is_valid_number, '京都府福知山市岩井新町');
ok($zip->set_number('6200921')->is_valid_number, '京都府福知山市かしの木台');
ok($zip->set_number('6200922')->is_valid_number, '京都府福知山市岩井');
ok($zip->set_number('6200923')->is_valid_number, '京都府福知山市本庄');
ok($zip->set_number('6200924')->is_valid_number, '京都府福知山市篠尾(下篠尾)');
ok($zip->set_number('6200924')->is_valid_number, '京都府福知山市下篠尾');
ok($zip->set_number('6200925')->is_valid_number, '京都府福知山市上篠尾');
ok($zip->set_number('6200925')->is_valid_number, '京都府福知山市篠尾(上篠尾)');
ok($zip->set_number('6200926')->is_valid_number, '京都府福知山市新庄');
ok($zip->set_number('6200927')->is_valid_number, '京都府福知山市和久寺');
ok($zip->set_number('6200928')->is_valid_number, '京都府福知山市奥野部');
ok($zip->set_number('6200931')->is_valid_number, '京都府福知山市北羽合');
ok($zip->set_number('6200931')->is_valid_number, '京都府福知山市篠尾(北羽合)');
ok($zip->set_number('6200932')->is_valid_number, '京都府福知山市篠尾(西羽合)');
ok($zip->set_number('6200932')->is_valid_number, '京都府福知山市西羽合');
ok($zip->set_number('6200933')->is_valid_number, '京都府福知山市篠尾(東羽合)');
ok($zip->set_number('6200933')->is_valid_number, '京都府福知山市東羽合');
ok($zip->set_number('6200934')->is_valid_number, '京都府福知山市篠尾(南羽合)');
ok($zip->set_number('6200934')->is_valid_number, '京都府福知山市南羽合');
ok($zip->set_number('6200935')->is_valid_number, '京都府福知山市向野');
ok($zip->set_number('6200936')->is_valid_number, '京都府福知山市正明寺');
ok($zip->set_number('6200937')->is_valid_number, '京都府福知山市室');
ok($zip->set_number('6200938')->is_valid_number, '京都府福知山市小野脇');
ok($zip->set_number('6200939')->is_valid_number, '京都府福知山市市寺');
ok($zip->set_number('6200940')->is_valid_number, '京都府福知山市駅南町');
ok($zip->set_number('6200943')->is_valid_number, '京都府福知山市北岡町');
ok($zip->set_number('6200944')->is_valid_number, '京都府福知山市南岡町');
ok($zip->set_number('6200945')->is_valid_number, '京都府福知山市広峯町');
ok($zip->set_number('6200946')->is_valid_number, '京都府福知山市南天田町');
ok($zip->set_number('6200947')->is_valid_number, '京都府福知山市旭が丘');
ok($zip->set_number('6200948')->is_valid_number, '京都府福知山市篠尾(夕陽が丘)');
ok($zip->set_number('6200948')->is_valid_number, '京都府福知山市夕陽が丘');
ok($zip->set_number('6200949')->is_valid_number, '京都府福知山市つつじケ丘');
ok($zip->set_number('6200951')->is_valid_number, '京都府福知山市十三丘');
ok($zip->set_number('6200952')->is_valid_number, '京都府福知山市大門');
ok($zip->set_number('6200953')->is_valid_number, '京都府福知山市今安');
ok($zip->set_number('6200954')->is_valid_number, '京都府福知山市半田');
ok($zip->set_number('6200955')->is_valid_number, '京都府福知山市拝師');
ok($zip->set_number('6200956')->is_valid_number, '京都府福知山市額塚');
ok($zip->set_number('6200957')->is_valid_number, '京都府福知山市山崎');
ok($zip->set_number('6200958')->is_valid_number, '京都府福知山市さつきケ丘');
ok($zip->set_number('6200961')->is_valid_number, '京都府福知山市石場');
ok($zip->set_number('6200962')->is_valid_number, '京都府福知山市口榎原');
ok($zip->set_number('6200963')->is_valid_number, '京都府福知山市奥榎原');
ok($zip->set_number('6200964')->is_valid_number, '京都府福知山市甘栗');
ok($zip->set_number('6200965')->is_valid_number, '京都府福知山市樽水');
ok($zip->set_number('6200966')->is_valid_number, '京都府福知山市辻');
ok($zip->set_number('6200967')->is_valid_number, '京都府福知山市畑中');
ok($zip->set_number('6200968')->is_valid_number, '京都府福知山市北山');
ok($zip->set_number('6200969')->is_valid_number, '京都府福知山市茅ノ台');
ok($zip->set_number('6200971')->is_valid_number, '京都府福知山市下戸');
ok($zip->set_number('6200972')->is_valid_number, '京都府福知山市小牧');
ok($zip->set_number('6200973')->is_valid_number, '京都府福知山市談');
ok($zip->set_number('6200974')->is_valid_number, '京都府福知山市法用');
ok($zip->set_number('6200981')->is_valid_number, '京都府福知山市小田');
ok($zip->set_number('6200982')->is_valid_number, '京都府福知山市下小田');
ok($zip->set_number('6200983')->is_valid_number, '京都府福知山市野笹');
ok($zip->set_number('6200984')->is_valid_number, '京都府福知山市猪野々');
ok($zip->set_number('6200985')->is_valid_number, '京都府福知山市梅谷');
ok($zip->set_number('6200986')->is_valid_number, '京都府福知山市宮垣');
ok($zip->set_number('6200987')->is_valid_number, '京都府福知山市鴨野町');
ok($zip->set_number('6200988')->is_valid_number, '京都府福知山市大見長祖');
ok($zip->set_number('6200989')->is_valid_number, '京都府福知山市住所大山');
ok($zip->set_number('6201301')->is_valid_number, '京都府福知山市三和町大原');
ok($zip->set_number('6201302')->is_valid_number, '京都府福知山市三和町台頭');
ok($zip->set_number('6201311')->is_valid_number, '京都府福知山市三和町上川合');
ok($zip->set_number('6201312')->is_valid_number, '京都府福知山市三和町岼');
ok($zip->set_number('6201313')->is_valid_number, '京都府福知山市三和町下川合');
ok($zip->set_number('6201314')->is_valid_number, '京都府福知山市三和町加用');
ok($zip->set_number('6201421')->is_valid_number, '京都府福知山市三和町大身');
ok($zip->set_number('6201422')->is_valid_number, '京都府福知山市三和町菟原中');
ok($zip->set_number('6201423')->is_valid_number, '京都府福知山市三和町高杉');
ok($zip->set_number('6201424')->is_valid_number, '京都府福知山市三和町友渕');
ok($zip->set_number('6201425')->is_valid_number, '京都府福知山市三和町菟原下');
ok($zip->set_number('6201431')->is_valid_number, '京都府福知山市三和町辻');
ok($zip->set_number('6201432')->is_valid_number, '京都府福知山市三和町中出');
ok($zip->set_number('6201433')->is_valid_number, '京都府福知山市三和町田ノ谷');
ok($zip->set_number('6201434')->is_valid_number, '京都府福知山市三和町西松');
ok($zip->set_number('6201435')->is_valid_number, '京都府福知山市三和町草山');
ok($zip->set_number('6201441')->is_valid_number, '京都府福知山市三和町梅原');
ok($zip->set_number('6201442')->is_valid_number, '京都府福知山市三和町千束');
ok($zip->set_number('6201443')->is_valid_number, '京都府福知山市三和町寺尾');
ok($zip->set_number('6201444')->is_valid_number, '京都府福知山市三和町芦渕');
ok($zip->set_number('6201445')->is_valid_number, '京都府福知山市三和町みわ');
ok($zip->set_number('6210000')->is_valid_number, '京都府亀岡市以下に掲載がない場合');
ok($zip->set_number('6210001')->is_valid_number, '京都府亀岡市旭町');
ok($zip->set_number('6210002')->is_valid_number, '京都府亀岡市千歳町千歳');
ok($zip->set_number('6210003')->is_valid_number, '京都府亀岡市千歳町国分');
ok($zip->set_number('6210004')->is_valid_number, '京都府亀岡市千歳町毘沙門');
ok($zip->set_number('6210005')->is_valid_number, '京都府亀岡市保津町');
ok($zip->set_number('6210006')->is_valid_number, '京都府亀岡市河原林町勝林島');
ok($zip->set_number('6210007')->is_valid_number, '京都府亀岡市河原林町河原尻');
ok($zip->set_number('6210008')->is_valid_number, '京都府亀岡市馬路町');
ok($zip->set_number('6210011')->is_valid_number, '京都府亀岡市大井町土田');
ok($zip->set_number('6210012')->is_valid_number, '京都府亀岡市大井町かすみケ丘');
ok($zip->set_number('6210013')->is_valid_number, '京都府亀岡市大井町並河');
ok($zip->set_number('6210014')->is_valid_number, '京都府亀岡市吉川町穴川');
ok($zip->set_number('6210015')->is_valid_number, '京都府亀岡市吉川町吉田');
ok($zip->set_number('6210016')->is_valid_number, '京都府亀岡市大井町南金岐');
ok($zip->set_number('6210017')->is_valid_number, '京都府亀岡市大井町北金岐');
ok($zip->set_number('6210018')->is_valid_number, '京都府亀岡市大井町小金岐');
ok($zip->set_number('6210021')->is_valid_number, '京都府亀岡市曽我部町重利');
ok($zip->set_number('6210022')->is_valid_number, '京都府亀岡市曽我部町南条');
ok($zip->set_number('6210023')->is_valid_number, '京都府亀岡市曽我部町寺');
ok($zip->set_number('6210024')->is_valid_number, '京都府亀岡市曽我部町春日部');
ok($zip->set_number('6210025')->is_valid_number, '京都府亀岡市曽我部町中');
ok($zip->set_number('6210026')->is_valid_number, '京都府亀岡市曽我部町法貴');
ok($zip->set_number('6210027')->is_valid_number, '京都府亀岡市曽我部町犬飼');
ok($zip->set_number('6210028')->is_valid_number, '京都府亀岡市曽我部町西条');
ok($zip->set_number('6210029')->is_valid_number, '京都府亀岡市曽我部町穴太');
ok($zip->set_number('6210031')->is_valid_number, '京都府亀岡市ひえ田野町太田');
ok($zip->set_number('6210032')->is_valid_number, '京都府亀岡市ひえ田野町天川');
ok($zip->set_number('6210033')->is_valid_number, '京都府亀岡市ひえ田野町佐伯');
ok($zip->set_number('6210034')->is_valid_number, '京都府亀岡市ひえ田野町芦ノ山');
ok($zip->set_number('6210035')->is_valid_number, '京都府亀岡市ひえ田野町奥条');
ok($zip->set_number('6210036')->is_valid_number, '京都府亀岡市ひえ田野町柿花');
ok($zip->set_number('6210037')->is_valid_number, '京都府亀岡市ひえ田野町鹿谷');
ok($zip->set_number('6210041')->is_valid_number, '京都府亀岡市千代川町小川');
ok($zip->set_number('6210042')->is_valid_number, '京都府亀岡市千代川町高野林');
ok($zip->set_number('6210043')->is_valid_number, '京都府亀岡市千代川町小林');
ok($zip->set_number('6210044')->is_valid_number, '京都府亀岡市千代川町日吉台');
ok($zip->set_number('6210045')->is_valid_number, '京都府亀岡市千代川町湯井');
ok($zip->set_number('6210046')->is_valid_number, '京都府亀岡市千代川町北ノ庄');
ok($zip->set_number('6210051')->is_valid_number, '京都府亀岡市千代川町今津');
ok($zip->set_number('6210052')->is_valid_number, '京都府亀岡市千代川町千原');
ok($zip->set_number('6210053')->is_valid_number, '京都府亀岡市千代川町拝田');
ok($zip->set_number('6210054')->is_valid_number, '京都府亀岡市千代川町川関');
ok($zip->set_number('6210101')->is_valid_number, '京都府亀岡市東別院町小泉');
ok($zip->set_number('6210102')->is_valid_number, '京都府亀岡市東別院町神原');
ok($zip->set_number('6210103')->is_valid_number, '京都府亀岡市東別院町東掛');
ok($zip->set_number('6210104')->is_valid_number, '京都府亀岡市東別院町大野');
ok($zip->set_number('6210111')->is_valid_number, '京都府亀岡市東別院町南掛');
ok($zip->set_number('6210112')->is_valid_number, '京都府亀岡市東別院町湯谷');
ok($zip->set_number('6210113')->is_valid_number, '京都府亀岡市東別院町倉谷');
ok($zip->set_number('6210114')->is_valid_number, '京都府亀岡市東別院町鎌倉');
ok($zip->set_number('6210115')->is_valid_number, '京都府亀岡市東別院町栢原');
ok($zip->set_number('6210121')->is_valid_number, '京都府亀岡市西別院町大槻並');
ok($zip->set_number('6210122')->is_valid_number, '京都府亀岡市西別院町万願寺');
ok($zip->set_number('6210123')->is_valid_number, '京都府亀岡市西別院町寺田');
ok($zip->set_number('6210124')->is_valid_number, '京都府亀岡市西別院町柚原');
ok($zip->set_number('6210125')->is_valid_number, '京都府亀岡市西別院町笑路');
ok($zip->set_number('6210126')->is_valid_number, '京都府亀岡市西別院町犬甘野');
ok($zip->set_number('6210127')->is_valid_number, '京都府亀岡市西別院町神地');
ok($zip->set_number('6210231')->is_valid_number, '京都府亀岡市東本梅町大内');
ok($zip->set_number('6210232')->is_valid_number, '京都府亀岡市東本梅町松熊');
ok($zip->set_number('6210233')->is_valid_number, '京都府亀岡市東本梅町中野');
ok($zip->set_number('6210234')->is_valid_number, '京都府亀岡市東本梅町赤熊');
ok($zip->set_number('6210235')->is_valid_number, '京都府亀岡市東本梅町東大谷');
ok($zip->set_number('6210241')->is_valid_number, '京都府亀岡市宮前町猪倉');
ok($zip->set_number('6210242')->is_valid_number, '京都府亀岡市宮前町神前');
ok($zip->set_number('6210243')->is_valid_number, '京都府亀岡市宮前町宮川');
ok($zip->set_number('6210251')->is_valid_number, '京都府亀岡市本梅町平松');
ok($zip->set_number('6210252')->is_valid_number, '京都府亀岡市本梅町中野');
ok($zip->set_number('6210253')->is_valid_number, '京都府亀岡市本梅町井手');
ok($zip->set_number('6210254')->is_valid_number, '京都府亀岡市本梅町東加舎');
ok($zip->set_number('6210255')->is_valid_number, '京都府亀岡市本梅町西加舎');
ok($zip->set_number('6210261')->is_valid_number, '京都府亀岡市畑野町千ケ畑');
ok($zip->set_number('6210262')->is_valid_number, '京都府亀岡市畑野町広野');
ok($zip->set_number('6210263')->is_valid_number, '京都府亀岡市畑野町土ケ畑');
ok($zip->set_number('6210801')->is_valid_number, '京都府亀岡市宇津根町');
ok($zip->set_number('6210802')->is_valid_number, '京都府亀岡市北河原町');
ok($zip->set_number('6210803')->is_valid_number, '京都府亀岡市河原町');
ok($zip->set_number('6210804')->is_valid_number, '京都府亀岡市追分町');
ok($zip->set_number('6210805')->is_valid_number, '京都府亀岡市安町');
ok($zip->set_number('6210806')->is_valid_number, '京都府亀岡市余部町');
ok($zip->set_number('6210807')->is_valid_number, '京都府亀岡市亀岡駅北');
ok($zip->set_number('6210811')->is_valid_number, '京都府亀岡市北古世町');
ok($zip->set_number('6210812')->is_valid_number, '京都府亀岡市横町');
ok($zip->set_number('6210813')->is_valid_number, '京都府亀岡市突抜町');
ok($zip->set_number('6210814')->is_valid_number, '京都府亀岡市三宅町');
ok($zip->set_number('6210815')->is_valid_number, '京都府亀岡市古世町');
ok($zip->set_number('6210816')->is_valid_number, '京都府亀岡市東竪町');
ok($zip->set_number('6210817')->is_valid_number, '京都府亀岡市西竪町');
ok($zip->set_number('6210818')->is_valid_number, '京都府亀岡市京町');
ok($zip->set_number('6210819')->is_valid_number, '京都府亀岡市呉服町');
ok($zip->set_number('6210821')->is_valid_number, '京都府亀岡市篠町柏原');
ok($zip->set_number('6210822')->is_valid_number, '京都府亀岡市篠町野条');
ok($zip->set_number('6210823')->is_valid_number, '京都府亀岡市篠町馬堀');
ok($zip->set_number('6210824')->is_valid_number, '京都府亀岡市篠町見晴');
ok($zip->set_number('6210825')->is_valid_number, '京都府亀岡市篠町山本');
ok($zip->set_number('6210826')->is_valid_number, '京都府亀岡市篠町篠');
ok($zip->set_number('6210827')->is_valid_number, '京都府亀岡市篠町王子');
ok($zip->set_number('6210828')->is_valid_number, '京都府亀岡市篠町馬堀駅前');
ok($zip->set_number('6210829')->is_valid_number, '京都府亀岡市篠町夕日ケ丘');
ok($zip->set_number('6210831')->is_valid_number, '京都府亀岡市篠町森');
ok($zip->set_number('6210832')->is_valid_number, '京都府亀岡市東つつじケ丘都台');
ok($zip->set_number('6210833')->is_valid_number, '京都府亀岡市東つつじケ丘曙台');
ok($zip->set_number('6210834')->is_valid_number, '京都府亀岡市篠町広田');
ok($zip->set_number('6210835')->is_valid_number, '京都府亀岡市篠町浄法寺');
ok($zip->set_number('6210841')->is_valid_number, '京都府亀岡市西つつじケ丘五月台');
ok($zip->set_number('6210842')->is_valid_number, '京都府亀岡市西つつじケ丘雲仙台');
ok($zip->set_number('6210843')->is_valid_number, '京都府亀岡市西つつじケ丘大山台');
ok($zip->set_number('6210844')->is_valid_number, '京都府亀岡市西つつじケ丘霧島台');
ok($zip->set_number('6210845')->is_valid_number, '京都府亀岡市西つつじケ丘美山台');
ok($zip->set_number('6210846')->is_valid_number, '京都府亀岡市南つつじケ丘大葉台');
ok($zip->set_number('6210847')->is_valid_number, '京都府亀岡市南つつじケ丘桜台');
ok($zip->set_number('6210851')->is_valid_number, '京都府亀岡市荒塚町');
ok($zip->set_number('6210852')->is_valid_number, '京都府亀岡市紺屋町');
ok($zip->set_number('6210853')->is_valid_number, '京都府亀岡市矢田町');
ok($zip->set_number('6210854')->is_valid_number, '京都府亀岡市下矢田町');
ok($zip->set_number('6210855')->is_valid_number, '京都府亀岡市中矢田町');
ok($zip->set_number('6210856')->is_valid_number, '京都府亀岡市上矢田町');
ok($zip->set_number('6210861')->is_valid_number, '京都府亀岡市北町');
ok($zip->set_number('6210862')->is_valid_number, '京都府亀岡市西町');
ok($zip->set_number('6210863')->is_valid_number, '京都府亀岡市南郷町');
ok($zip->set_number('6210864')->is_valid_number, '京都府亀岡市内丸町');
ok($zip->set_number('6210865')->is_valid_number, '京都府亀岡市新町');
ok($zip->set_number('6210866')->is_valid_number, '京都府亀岡市旅籠町');
ok($zip->set_number('6210867')->is_valid_number, '京都府亀岡市塩屋町');
ok($zip->set_number('6210868')->is_valid_number, '京都府亀岡市柳町');
ok($zip->set_number('6210869')->is_valid_number, '京都府亀岡市本町');
ok($zip->set_number('6220000')->is_valid_number, '京都府南丹市以下に掲載がない場合');
ok($zip->set_number('6220001')->is_valid_number, '京都府南丹市園部町宮町');
ok($zip->set_number('6220002')->is_valid_number, '京都府南丹市園部町美園町');
ok($zip->set_number('6220003')->is_valid_number, '京都府南丹市園部町新町');
ok($zip->set_number('6220004')->is_valid_number, '京都府南丹市園部町小桜町');
ok($zip->set_number('6220011')->is_valid_number, '京都府南丹市園部町上木崎町');
ok($zip->set_number('6220012')->is_valid_number, '京都府南丹市園部町内林町');
ok($zip->set_number('6220013')->is_valid_number, '京都府南丹市園部町本町');
ok($zip->set_number('6220014')->is_valid_number, '京都府南丹市園部町上本町');
ok($zip->set_number('6220015')->is_valid_number, '京都府南丹市園部町木崎町');
ok($zip->set_number('6220016')->is_valid_number, '京都府南丹市園部町河原町');
ok($zip->set_number('6220017')->is_valid_number, '京都府南丹市園部町若松町');
ok($zip->set_number('6220021')->is_valid_number, '京都府南丹市園部町瓜生野');
ok($zip->set_number('6220022')->is_valid_number, '京都府南丹市園部町熊崎');
ok($zip->set_number('6220023')->is_valid_number, '京都府南丹市園部町新堂');
ok($zip->set_number('6220024')->is_valid_number, '京都府南丹市園部町千妻');
ok($zip->set_number('6220025')->is_valid_number, '京都府南丹市園部町曽我谷');
ok($zip->set_number('6220031')->is_valid_number, '京都府南丹市園部町船岡');
ok($zip->set_number('6220032')->is_valid_number, '京都府南丹市園部町高屋');
ok($zip->set_number('6220033')->is_valid_number, '京都府南丹市園部町大戸');
ok($zip->set_number('6220034')->is_valid_number, '京都府南丹市園部町熊原');
ok($zip->set_number('6220035')->is_valid_number, '京都府南丹市園部町佐切');
ok($zip->set_number('6220036')->is_valid_number, '京都府南丹市園部町越方');
ok($zip->set_number('6220041')->is_valid_number, '京都府南丹市園部町小山東町');
ok($zip->set_number('6220042')->is_valid_number, '京都府南丹市園部町栄町');
ok($zip->set_number('6220043')->is_valid_number, '京都府南丹市園部町小山西町');
ok($zip->set_number('6220044')->is_valid_number, '京都府南丹市園部町城南町');
ok($zip->set_number('6220045')->is_valid_number, '京都府南丹市園部町半田');
ok($zip->set_number('6220046')->is_valid_number, '京都府南丹市園部町口人');
ok($zip->set_number('6220047')->is_valid_number, '京都府南丹市園部町口司');
ok($zip->set_number('6220051')->is_valid_number, '京都府南丹市園部町横田');
ok($zip->set_number('6220052')->is_valid_number, '京都府南丹市園部町黒田');
ok($zip->set_number('6220053')->is_valid_number, '京都府南丹市園部町船阪');
ok($zip->set_number('6220054')->is_valid_number, '京都府南丹市園部町大西');
ok($zip->set_number('6220055')->is_valid_number, '京都府南丹市園部町宍人');
ok($zip->set_number('6220056')->is_valid_number, '京都府南丹市園部町埴生');
ok($zip->set_number('6220057')->is_valid_number, '京都府南丹市園部町殿谷');
ok($zip->set_number('6220058')->is_valid_number, '京都府南丹市園部町若森');
ok($zip->set_number('6220059')->is_valid_number, '京都府南丹市園部町南大谷');
ok($zip->set_number('6220061')->is_valid_number, '京都府南丹市園部町仁江');
ok($zip->set_number('6220062')->is_valid_number, '京都府南丹市園部町竹井');
ok($zip->set_number('6220063')->is_valid_number, '京都府南丹市園部町天引');
ok($zip->set_number('6220064')->is_valid_number, '京都府南丹市園部町法京');
ok($zip->set_number('6220065')->is_valid_number, '京都府南丹市園部町大河内');
ok($zip->set_number('6220066')->is_valid_number, '京都府南丹市園部町南八田');
ok($zip->set_number('6220200')->is_valid_number, '京都府船井郡京丹波町以下に掲載がない場合');
ok($zip->set_number('6220201')->is_valid_number, '京都府船井郡京丹波町下山');
ok($zip->set_number('6220202')->is_valid_number, '京都府船井郡京丹波町実勢');
ok($zip->set_number('6220203')->is_valid_number, '京都府船井郡京丹波町富田');
ok($zip->set_number('6220211')->is_valid_number, '京都府船井郡京丹波町上野');
ok($zip->set_number('6220212')->is_valid_number, '京都府船井郡京丹波町市森');
ok($zip->set_number('6220213')->is_valid_number, '京都府船井郡京丹波町須知');
ok($zip->set_number('6220214')->is_valid_number, '京都府船井郡京丹波町蒲生');
ok($zip->set_number('6220221')->is_valid_number, '京都府船井郡京丹波町水戸');
ok($zip->set_number('6220222')->is_valid_number, '京都府船井郡京丹波町新水戸');
ok($zip->set_number('6220223')->is_valid_number, '京都府船井郡京丹波町口八田');
ok($zip->set_number('6220224')->is_valid_number, '京都府船井郡京丹波町高岡');
ok($zip->set_number('6220231')->is_valid_number, '京都府船井郡京丹波町豊田');
ok($zip->set_number('6220232')->is_valid_number, '京都府船井郡京丹波町曽根');
ok($zip->set_number('6220233')->is_valid_number, '京都府船井郡京丹波町森');
ok($zip->set_number('6220234')->is_valid_number, '京都府船井郡京丹波町塩田谷');
ok($zip->set_number('6220235')->is_valid_number, '京都府船井郡京丹波町安井');
ok($zip->set_number('6220236')->is_valid_number, '京都府船井郡京丹波町院内');
ok($zip->set_number('6220301')->is_valid_number, '京都府船井郡京丹波町粟野');
ok($zip->set_number('6220302')->is_valid_number, '京都府船井郡京丹波町妙楽寺');
ok($zip->set_number('6220303')->is_valid_number, '京都府船井郡京丹波町三ノ宮');
ok($zip->set_number('6220304')->is_valid_number, '京都府船井郡京丹波町猪鼻');
ok($zip->set_number('6220311')->is_valid_number, '京都府船井郡京丹波町和田');
ok($zip->set_number('6220312')->is_valid_number, '京都府船井郡京丹波町井脇');
ok($zip->set_number('6220313')->is_valid_number, '京都府船井郡京丹波町保井谷');
ok($zip->set_number('6220314')->is_valid_number, '京都府船井郡京丹波町水呑');
ok($zip->set_number('6220315')->is_valid_number, '京都府船井郡京丹波町質志');
ok($zip->set_number('6220316')->is_valid_number, '京都府船井郡京丹波町戸津川');
ok($zip->set_number('6220321')->is_valid_number, '京都府船井郡京丹波町橋爪');
ok($zip->set_number('6220322')->is_valid_number, '京都府船井郡京丹波町大朴');
ok($zip->set_number('6220323')->is_valid_number, '京都府船井郡京丹波町井尻');
ok($zip->set_number('6220324')->is_valid_number, '京都府船井郡京丹波町八田');
ok($zip->set_number('6220325')->is_valid_number, '京都府船井郡京丹波町小野');
ok($zip->set_number('6220331')->is_valid_number, '京都府船井郡京丹波町中台');
ok($zip->set_number('6220332')->is_valid_number, '京都府船井郡京丹波町質美');
ok($zip->set_number('6220441')->is_valid_number, '京都府船井郡京丹波町坂井');
ok($zip->set_number('6220442')->is_valid_number, '京都府船井郡京丹波町鎌谷下');
ok($zip->set_number('6220443')->is_valid_number, '京都府船井郡京丹波町東又');
ok($zip->set_number('6220444')->is_valid_number, '京都府船井郡京丹波町鎌谷中');
ok($zip->set_number('6220445')->is_valid_number, '京都府船井郡京丹波町鎌谷奥');
ok($zip->set_number('6220451')->is_valid_number, '京都府船井郡京丹波町下大久保');
ok($zip->set_number('6220452')->is_valid_number, '京都府船井郡京丹波町上大久保');
ok($zip->set_number('6220453')->is_valid_number, '京都府船井郡京丹波町水原');
ok($zip->set_number('6230000')->is_valid_number, '京都府綾部市以下に掲載がない場合');
ok($zip->set_number('6230001')->is_valid_number, '京都府綾部市小呂町');
ok($zip->set_number('6230002')->is_valid_number, '京都府綾部市高倉町');
ok($zip->set_number('6230003')->is_valid_number, '京都府綾部市城山町');
ok($zip->set_number('6230004')->is_valid_number, '京都府綾部市多田町');
ok($zip->set_number('6230005')->is_valid_number, '京都府綾部市里町');
ok($zip->set_number('6230006')->is_valid_number, '京都府綾部市有岡町');
ok($zip->set_number('6230007')->is_valid_number, '京都府綾部市星原町');
ok($zip->set_number('6230008')->is_valid_number, '京都府綾部市桜が丘');
ok($zip->set_number('6230011')->is_valid_number, '京都府綾部市青野町');
ok($zip->set_number('6230012')->is_valid_number, '京都府綾部市川糸町');
ok($zip->set_number('6230013')->is_valid_number, '京都府綾部市綾中町');
ok($zip->set_number('6230014')->is_valid_number, '京都府綾部市若竹町');
ok($zip->set_number('6230015')->is_valid_number, '京都府綾部市若松町');
ok($zip->set_number('6230016')->is_valid_number, '京都府綾部市西町');
ok($zip->set_number('6230021')->is_valid_number, '京都府綾部市本町');
ok($zip->set_number('6230022')->is_valid_number, '京都府綾部市新宮町');
ok($zip->set_number('6230023')->is_valid_number, '京都府綾部市新町');
ok($zip->set_number('6230024')->is_valid_number, '京都府綾部市田町');
ok($zip->set_number('6230025')->is_valid_number, '京都府綾部市月見町');
ok($zip->set_number('6230026')->is_valid_number, '京都府綾部市神宮寺町');
ok($zip->set_number('6230031')->is_valid_number, '京都府綾部市味方町');
ok($zip->set_number('6230032')->is_valid_number, '京都府綾部市野田町');
ok($zip->set_number('6230033')->is_valid_number, '京都府綾部市寺町');
ok($zip->set_number('6230034')->is_valid_number, '京都府綾部市田野町');
ok($zip->set_number('6230035')->is_valid_number, '京都府綾部市上野町');
ok($zip->set_number('6230036')->is_valid_number, '京都府綾部市本宮町');
ok($zip->set_number('6230037')->is_valid_number, '京都府綾部市並松町');
ok($zip->set_number('6230041')->is_valid_number, '京都府綾部市延町');
ok($zip->set_number('6230042')->is_valid_number, '京都府綾部市岡町');
ok($zip->set_number('6230043')->is_valid_number, '京都府綾部市上延町');
ok($zip->set_number('6230044')->is_valid_number, '京都府綾部市安場町');
ok($zip->set_number('6230045')->is_valid_number, '京都府綾部市高津町');
ok($zip->set_number('6230046')->is_valid_number, '京都府綾部市大島町');
ok($zip->set_number('6230051')->is_valid_number, '京都府綾部市井倉新町');
ok($zip->set_number('6230052')->is_valid_number, '京都府綾部市幸通');
ok($zip->set_number('6230053')->is_valid_number, '京都府綾部市宮代町');
ok($zip->set_number('6230054')->is_valid_number, '京都府綾部市井倉町');
ok($zip->set_number('6230061')->is_valid_number, '京都府綾部市天神町');
ok($zip->set_number('6230062')->is_valid_number, '京都府綾部市相生町');
ok($zip->set_number('6230063')->is_valid_number, '京都府綾部市広小路');
ok($zip->set_number('6230064')->is_valid_number, '京都府綾部市中ノ町');
ok($zip->set_number('6230065')->is_valid_number, '京都府綾部市西新町');
ok($zip->set_number('6230066')->is_valid_number, '京都府綾部市駅前通');
ok($zip->set_number('6230101')->is_valid_number, '京都府綾部市於与岐町');
ok($zip->set_number('6230102')->is_valid_number, '京都府綾部市上杉町');
ok($zip->set_number('6230103')->is_valid_number, '京都府綾部市梅迫町');
ok($zip->set_number('6230104')->is_valid_number, '京都府綾部市安国寺町');
ok($zip->set_number('6230105')->is_valid_number, '京都府綾部市中山町');
ok($zip->set_number('6230106')->is_valid_number, '京都府綾部市高槻町');
ok($zip->set_number('6230107')->is_valid_number, '京都府綾部市八代町');
ok($zip->set_number('6230108')->is_valid_number, '京都府綾部市黒谷町');
ok($zip->set_number('6230111')->is_valid_number, '京都府綾部市七百石町');
ok($zip->set_number('6230112')->is_valid_number, '京都府綾部市上八田町');
ok($zip->set_number('6230113')->is_valid_number, '京都府綾部市中筋町');
ok($zip->set_number('6230114')->is_valid_number, '京都府綾部市岡安町');
ok($zip->set_number('6230115')->is_valid_number, '京都府綾部市渕垣町');
ok($zip->set_number('6230116')->is_valid_number, '京都府綾部市下八田町');
ok($zip->set_number('6230117')->is_valid_number, '京都府綾部市とよさか町');
ok($zip->set_number('6230221')->is_valid_number, '京都府綾部市位田町');
ok($zip->set_number('6230222')->is_valid_number, '京都府綾部市栗町');
ok($zip->set_number('6230223')->is_valid_number, '京都府綾部市豊里町');
ok($zip->set_number('6230224')->is_valid_number, '京都府綾部市石原町');
ok($zip->set_number('6230225')->is_valid_number, '京都府綾部市小貝町');
ok($zip->set_number('6230226')->is_valid_number, '京都府綾部市私市町');
ok($zip->set_number('6230231')->is_valid_number, '京都府綾部市大畠町');
ok($zip->set_number('6230232')->is_valid_number, '京都府綾部市舘町');
ok($zip->set_number('6230233')->is_valid_number, '京都府綾部市今田町');
ok($zip->set_number('6230234')->is_valid_number, '京都府綾部市小西町');
ok($zip->set_number('6230235')->is_valid_number, '京都府綾部市鍛治屋町');
ok($zip->set_number('6230236')->is_valid_number, '京都府綾部市小畑町');
ok($zip->set_number('6230341')->is_valid_number, '京都府綾部市内久井町');
ok($zip->set_number('6230342')->is_valid_number, '京都府綾部市金河内町');
ok($zip->set_number('6230343')->is_valid_number, '京都府綾部市志賀郷町');
ok($zip->set_number('6230344')->is_valid_number, '京都府綾部市西方町');
ok($zip->set_number('6230345')->is_valid_number, '京都府綾部市仁和町');
ok($zip->set_number('6230346')->is_valid_number, '京都府綾部市坊口町');
ok($zip->set_number('6230351')->is_valid_number, '京都府綾部市篠田町');
ok($zip->set_number('6230352')->is_valid_number, '京都府綾部市向田町');
ok($zip->set_number('6230353')->is_valid_number, '京都府綾部市別所町');
ok($zip->set_number('6230361')->is_valid_number, '京都府綾部市白道路町');
ok($zip->set_number('6230362')->is_valid_number, '京都府綾部市物部町');
ok($zip->set_number('6230363')->is_valid_number, '京都府綾部市新庄町');
ok($zip->set_number('6230364')->is_valid_number, '京都府綾部市西坂町');
ok($zip->set_number('6231121')->is_valid_number, '京都府綾部市睦合町');
ok($zip->set_number('6231122')->is_valid_number, '京都府綾部市八津合町');
ok($zip->set_number('6231123')->is_valid_number, '京都府綾部市五津合町');
ok($zip->set_number('6231124')->is_valid_number, '京都府綾部市五泉町');
ok($zip->set_number('6231131')->is_valid_number, '京都府綾部市睦寄町');
ok($zip->set_number('6231132')->is_valid_number, '京都府綾部市故屋岡町');
ok($zip->set_number('6231133')->is_valid_number, '京都府綾部市光野町');
ok($zip->set_number('6231134')->is_valid_number, '京都府綾部市老富町');
ok($zip->set_number('6240101')->is_valid_number, '京都府舞鶴市大川');
ok($zip->set_number('6240102')->is_valid_number, '京都府舞鶴市志高');
ok($zip->set_number('6240103')->is_valid_number, '京都府舞鶴市久田美');
ok($zip->set_number('6240111')->is_valid_number, '京都府舞鶴市長谷');
ok($zip->set_number('6240112')->is_valid_number, '京都府舞鶴市上漆原');
ok($zip->set_number('6240113')->is_valid_number, '京都府舞鶴市下漆原');
ok($zip->set_number('6240114')->is_valid_number, '京都府舞鶴市下見谷');
ok($zip->set_number('6240115')->is_valid_number, '京都府舞鶴市河原');
ok($zip->set_number('6240116')->is_valid_number, '京都府舞鶴市富室');
ok($zip->set_number('6240117')->is_valid_number, '京都府舞鶴市岡田由里');
ok($zip->set_number('6240118')->is_valid_number, '京都府舞鶴市西方寺');
ok($zip->set_number('6240121')->is_valid_number, '京都府舞鶴市滝ケ宇呂');
ok($zip->set_number('6240122')->is_valid_number, '京都府舞鶴市地頭');
ok($zip->set_number('6240123')->is_valid_number, '京都府舞鶴市大俣');
ok($zip->set_number('6240124')->is_valid_number, '京都府舞鶴市桑飼下');
ok($zip->set_number('6240125')->is_valid_number, '京都府舞鶴市桑飼上');
ok($zip->set_number('6240801')->is_valid_number, '京都府舞鶴市寺田');
ok($zip->set_number('6240802')->is_valid_number, '京都府舞鶴市上根');
ok($zip->set_number('6240803')->is_valid_number, '京都府舞鶴市白滝');
ok($zip->set_number('6240804')->is_valid_number, '京都府舞鶴市岸谷');
ok($zip->set_number('6240805')->is_valid_number, '京都府舞鶴市別所');
ok($zip->set_number('6240806')->is_valid_number, '京都府舞鶴市布敷');
ok($zip->set_number('6240811')->is_valid_number, '京都府舞鶴市池ノ内下');
ok($zip->set_number('6240812')->is_valid_number, '京都府舞鶴市堀');
ok($zip->set_number('6240813')->is_valid_number, '京都府舞鶴市今田');
ok($zip->set_number('6240814')->is_valid_number, '京都府舞鶴市万願寺');
ok($zip->set_number('6240815')->is_valid_number, '京都府舞鶴市境谷');
ok($zip->set_number('6240816')->is_valid_number, '京都府舞鶴市伊佐津');
ok($zip->set_number('6240821')->is_valid_number, '京都府舞鶴市公文名');
ok($zip->set_number('6240822')->is_valid_number, '京都府舞鶴市七日市');
ok($zip->set_number('6240823')->is_valid_number, '京都府舞鶴市京田');
ok($zip->set_number('6240824')->is_valid_number, '京都府舞鶴市真倉');
ok($zip->set_number('6240825')->is_valid_number, '京都府舞鶴市十倉');
ok($zip->set_number('6240826')->is_valid_number, '京都府舞鶴市京田新町');
ok($zip->set_number('6240831')->is_valid_number, '京都府舞鶴市女布');
ok($zip->set_number('6240832')->is_valid_number, '京都府舞鶴市高野台');
ok($zip->set_number('6240833')->is_valid_number, '京都府舞鶴市野村寺');
ok($zip->set_number('6240834')->is_valid_number, '京都府舞鶴市城屋');
ok($zip->set_number('6240835')->is_valid_number, '京都府舞鶴市高野由里');
ok($zip->set_number('6240836')->is_valid_number, '京都府舞鶴市女布北町');
ok($zip->set_number('6240841')->is_valid_number, '京都府舞鶴市引土');
ok($zip->set_number('6240842')->is_valid_number, '京都府舞鶴市朝代');
ok($zip->set_number('6240843')->is_valid_number, '京都府舞鶴市引土新');
ok($zip->set_number('6240851')->is_valid_number, '京都府舞鶴市大内野町');
ok($zip->set_number('6240852')->is_valid_number, '京都府舞鶴市大内');
ok($zip->set_number('6240853')->is_valid_number, '京都府舞鶴市南田辺');
ok($zip->set_number('6240854')->is_valid_number, '京都府舞鶴市円満寺');
ok($zip->set_number('6240855')->is_valid_number, '京都府舞鶴市北田辺');
ok($zip->set_number('6240901')->is_valid_number, '京都府舞鶴市清美が丘');
ok($zip->set_number('6240902')->is_valid_number, '京都府舞鶴市清道');
ok($zip->set_number('6240903')->is_valid_number, '京都府舞鶴市天台');
ok($zip->set_number('6240904')->is_valid_number, '京都府舞鶴市昭和台');
ok($zip->set_number('6240905')->is_valid_number, '京都府舞鶴市福来');
ok($zip->set_number('6240906')->is_valid_number, '京都府舞鶴市倉谷');
ok($zip->set_number('6240907')->is_valid_number, '京都府舞鶴市福来問屋町');
ok($zip->set_number('6240908')->is_valid_number, '京都府舞鶴市清道新町');
ok($zip->set_number('6240909')->is_valid_number, '京都府舞鶴市天台新町');
ok($zip->set_number('6240911')->is_valid_number, '京都府舞鶴市上安東町');
ok($zip->set_number('6240912')->is_valid_number, '京都府舞鶴市上安');
ok($zip->set_number('6240913')->is_valid_number, '京都府舞鶴市上安久');
ok($zip->set_number('6240914')->is_valid_number, '京都府舞鶴市下安久');
ok($zip->set_number('6240921')->is_valid_number, '京都府舞鶴市東吉原');
ok($zip->set_number('6240922')->is_valid_number, '京都府舞鶴市西吉原');
ok($zip->set_number('6240923')->is_valid_number, '京都府舞鶴市魚屋');
ok($zip->set_number('6240924')->is_valid_number, '京都府舞鶴市職人');
ok($zip->set_number('6240925')->is_valid_number, '京都府舞鶴市丹波');
ok($zip->set_number('6240926')->is_valid_number, '京都府舞鶴市本');
ok($zip->set_number('6240927')->is_valid_number, '京都府舞鶴市平野屋');
ok($zip->set_number('6240928')->is_valid_number, '京都府舞鶴市竹屋');
ok($zip->set_number('6240929')->is_valid_number, '京都府舞鶴市寺内');
ok($zip->set_number('6240931')->is_valid_number, '京都府舞鶴市松陰');
ok($zip->set_number('6240932')->is_valid_number, '京都府舞鶴市宮津口');
ok($zip->set_number('6240933')->is_valid_number, '京都府舞鶴市新');
ok($zip->set_number('6240934')->is_valid_number, '京都府舞鶴市堀上');
ok($zip->set_number('6240935')->is_valid_number, '京都府舞鶴市京口');
ok($zip->set_number('6240936')->is_valid_number, '京都府舞鶴市紺屋');
ok($zip->set_number('6240937')->is_valid_number, '京都府舞鶴市西');
ok($zip->set_number('6240941')->is_valid_number, '京都府舞鶴市白杉');
ok($zip->set_number('6240942')->is_valid_number, '京都府舞鶴市青井');
ok($zip->set_number('6240943')->is_valid_number, '京都府舞鶴市吉田');
ok($zip->set_number('6240944')->is_valid_number, '京都府舞鶴市大君');
ok($zip->set_number('6240945')->is_valid_number, '京都府舞鶴市喜多');
ok($zip->set_number('6240946')->is_valid_number, '京都府舞鶴市下福井');
ok($zip->set_number('6240951')->is_valid_number, '京都府舞鶴市上福井');
ok($zip->set_number('6240952')->is_valid_number, '京都府舞鶴市三日市');
ok($zip->set_number('6240953')->is_valid_number, '京都府舞鶴市八戸地');
ok($zip->set_number('6240954')->is_valid_number, '京都府舞鶴市八田');
ok($zip->set_number('6240955')->is_valid_number, '京都府舞鶴市丸田');
ok($zip->set_number('6240956')->is_valid_number, '京都府舞鶴市和江');
ok($zip->set_number('6240961')->is_valid_number, '京都府舞鶴市西神崎');
ok($zip->set_number('6240962')->is_valid_number, '京都府舞鶴市東神崎');
ok($zip->set_number('6240963')->is_valid_number, '京都府舞鶴市油江');
ok($zip->set_number('6240964')->is_valid_number, '京都府舞鶴市蒲江');
ok($zip->set_number('6240965')->is_valid_number, '京都府舞鶴市水間');
ok($zip->set_number('6240966')->is_valid_number, '京都府舞鶴市中山');
ok($zip->set_number('6240967')->is_valid_number, '京都府舞鶴市下東');
ok($zip->set_number('6240968')->is_valid_number, '京都府舞鶴市上東');
ok($zip->set_number('6250000')->is_valid_number, '京都府舞鶴市以下に掲載がない場合');
ok($zip->set_number('6250001')->is_valid_number, '京都府舞鶴市杉山');
ok($zip->set_number('6250002')->is_valid_number, '京都府舞鶴市登尾');
ok($zip->set_number('6250003')->is_valid_number, '京都府舞鶴市吉野');
ok($zip->set_number('6250004')->is_valid_number, '京都府舞鶴市朝来西町');
ok($zip->set_number('6250005')->is_valid_number, '京都府舞鶴市朝来中');
ok($zip->set_number('6250006')->is_valid_number, '京都府舞鶴市大波上');
ok($zip->set_number('6250007')->is_valid_number, '京都府舞鶴市大波下');
ok($zip->set_number('6250010')->is_valid_number, '京都府舞鶴市松尾');
ok($zip->set_number('6250011')->is_valid_number, '京都府舞鶴市吉坂');
ok($zip->set_number('6250012')->is_valid_number, '京都府舞鶴市白屋町');
ok($zip->set_number('6250013')->is_valid_number, '京都府舞鶴市鹿原西町');
ok($zip->set_number('6250014')->is_valid_number, '京都府舞鶴市鹿原');
ok($zip->set_number('6250015')->is_valid_number, '京都府舞鶴市岡安');
ok($zip->set_number('6250016')->is_valid_number, '京都府舞鶴市白屋');
ok($zip->set_number('6250020')->is_valid_number, '京都府舞鶴市小倉');
ok($zip->set_number('6250021')->is_valid_number, '京都府舞鶴市安岡');
ok($zip->set_number('6250022')->is_valid_number, '京都府舞鶴市安岡町');
ok($zip->set_number('6250023')->is_valid_number, '京都府舞鶴市田中');
ok($zip->set_number('6250024')->is_valid_number, '京都府舞鶴市田中町');
ok($zip->set_number('6250025')->is_valid_number, '京都府舞鶴市市場');
ok($zip->set_number('6250026')->is_valid_number, '京都府舞鶴市泉源寺');
ok($zip->set_number('6250027')->is_valid_number, '京都府舞鶴市田園町');
ok($zip->set_number('6250030')->is_valid_number, '京都府舞鶴市愛宕上町');
ok($zip->set_number('6250031')->is_valid_number, '京都府舞鶴市愛宕中町');
ok($zip->set_number('6250032')->is_valid_number, '京都府舞鶴市愛宕下町');
ok($zip->set_number('6250033')->is_valid_number, '京都府舞鶴市愛宕浜町');
ok($zip->set_number('6250034')->is_valid_number, '京都府舞鶴市竜宮町');
ok($zip->set_number('6250035')->is_valid_number, '京都府舞鶴市溝尻');
ok($zip->set_number('6250036')->is_valid_number, '京都府舞鶴市浜');
ok($zip->set_number('6250037')->is_valid_number, '京都府舞鶴市浜町');
ok($zip->set_number('6250040')->is_valid_number, '京都府舞鶴市矢之助町');
ok($zip->set_number('6250041')->is_valid_number, '京都府舞鶴市溝尻中町');
ok($zip->set_number('6250042')->is_valid_number, '京都府舞鶴市溝尻町');
ok($zip->set_number('6250043')->is_valid_number, '京都府舞鶴市梅ケ谷');
ok($zip->set_number('6250044')->is_valid_number, '京都府舞鶴市堂奥');
ok($zip->set_number('6250045')->is_valid_number, '京都府舞鶴市多門院');
ok($zip->set_number('6250050')->is_valid_number, '京都府舞鶴市北浜町');
ok($zip->set_number('6250051')->is_valid_number, '京都府舞鶴市行永東町');
ok($zip->set_number('6250052')->is_valid_number, '京都府舞鶴市行永');
ok($zip->set_number('6250053')->is_valid_number, '京都府舞鶴市金屋町');
ok($zip->set_number('6250054')->is_valid_number, '京都府舞鶴市七条中町');
ok($zip->set_number('6250055')->is_valid_number, '京都府舞鶴市倉梯中町');
ok($zip->set_number('6250056')->is_valid_number, '京都府舞鶴市倉梯町');
ok($zip->set_number('6250057')->is_valid_number, '京都府舞鶴市南浜町');
ok($zip->set_number('6250058')->is_valid_number, '京都府舞鶴市行永桜通り');
ok($zip->set_number('6250060')->is_valid_number, '京都府舞鶴市桃山町');
ok($zip->set_number('6250061')->is_valid_number, '京都府舞鶴市森町');
ok($zip->set_number('6250062')->is_valid_number, '京都府舞鶴市森');
ok($zip->set_number('6250063')->is_valid_number, '京都府舞鶴市丸山町');
ok($zip->set_number('6250064')->is_valid_number, '京都府舞鶴市丸山西町');
ok($zip->set_number('6250065')->is_valid_number, '京都府舞鶴市丸山中町');
ok($zip->set_number('6250066')->is_valid_number, '京都府舞鶴市丸山口町');
ok($zip->set_number('6250067')->is_valid_number, '京都府舞鶴市森本町');
ok($zip->set_number('6250070')->is_valid_number, '京都府舞鶴市八反田北町');
ok($zip->set_number('6250071')->is_valid_number, '京都府舞鶴市常新町');
ok($zip->set_number('6250072')->is_valid_number, '京都府舞鶴市常');
ok($zip->set_number('6250073')->is_valid_number, '京都府舞鶴市木ノ下');
ok($zip->set_number('6250074')->is_valid_number, '京都府舞鶴市与保呂');
ok($zip->set_number('6250075')->is_valid_number, '京都府舞鶴市京月東町');
ok($zip->set_number('6250076')->is_valid_number, '京都府舞鶴市京月町');
ok($zip->set_number('6250077')->is_valid_number, '京都府舞鶴市亀岩町');
ok($zip->set_number('6250078')->is_valid_number, '京都府舞鶴市八反田南町');
ok($zip->set_number('6250080')->is_valid_number, '京都府舞鶴市北吸');
ok($zip->set_number('6250081')->is_valid_number, '京都府舞鶴市三宅');
ok($zip->set_number('6250082')->is_valid_number, '京都府舞鶴市つつじケ丘');
ok($zip->set_number('6250083')->is_valid_number, '京都府舞鶴市余部上');
ok($zip->set_number('6250084')->is_valid_number, '京都府舞鶴市白浜台');
ok($zip->set_number('6250085')->is_valid_number, '京都府舞鶴市和田');
ok($zip->set_number('6250086')->is_valid_number, '京都府舞鶴市長浜');
ok($zip->set_number('6250087')->is_valid_number, '京都府舞鶴市余部下');
ok($zip->set_number('6250131')->is_valid_number, '京都府舞鶴市中田町');
ok($zip->set_number('6250132')->is_valid_number, '京都府舞鶴市中田');
ok($zip->set_number('6250133')->is_valid_number, '京都府舞鶴市平');
ok($zip->set_number('6250134')->is_valid_number, '京都府舞鶴市佐波賀');
ok($zip->set_number('6250135')->is_valid_number, '京都府舞鶴市千歳');
ok($zip->set_number('6250136')->is_valid_number, '京都府舞鶴市大丹生');
ok($zip->set_number('6250137')->is_valid_number, '京都府舞鶴市瀬崎');
ok($zip->set_number('6250141')->is_valid_number, '京都府舞鶴市河辺中');
ok($zip->set_number('6250142')->is_valid_number, '京都府舞鶴市西屋');
ok($zip->set_number('6250143')->is_valid_number, '京都府舞鶴市室牛');
ok($zip->set_number('6250144')->is_valid_number, '京都府舞鶴市河辺由里');
ok($zip->set_number('6250145')->is_valid_number, '京都府舞鶴市観音寺');
ok($zip->set_number('6250146')->is_valid_number, '京都府舞鶴市河辺原');
ok($zip->set_number('6250147')->is_valid_number, '京都府舞鶴市栃尾');
ok($zip->set_number('6250151')->is_valid_number, '京都府舞鶴市赤野');
ok($zip->set_number('6250152')->is_valid_number, '京都府舞鶴市多祢寺');
ok($zip->set_number('6250153')->is_valid_number, '京都府舞鶴市三浜');
ok($zip->set_number('6250154')->is_valid_number, '京都府舞鶴市小橋');
ok($zip->set_number('6250155')->is_valid_number, '京都府舞鶴市野原');
ok($zip->set_number('6250156')->is_valid_number, '京都府舞鶴市成生');
ok($zip->set_number('6250157')->is_valid_number, '京都府舞鶴市田井');
ok($zip->set_number('6250158')->is_valid_number, '京都府舞鶴市大山');
ok($zip->set_number('6260000')->is_valid_number, '京都府宮津市以下に掲載がない場合');
ok($zip->set_number('6260001')->is_valid_number, '京都府宮津市文珠');
ok($zip->set_number('6260002')->is_valid_number, '京都府宮津市杉末');
ok($zip->set_number('6260003')->is_valid_number, '京都府宮津市漁師');
ok($zip->set_number('6260004')->is_valid_number, '京都府宮津市川向');
ok($zip->set_number('6260005')->is_valid_number, '京都府宮津市宮町');
ok($zip->set_number('6260006')->is_valid_number, '京都府宮津市蛭子');
ok($zip->set_number('6260007')->is_valid_number, '京都府宮津市池ノ谷');
ok($zip->set_number('6260008')->is_valid_number, '京都府宮津市万年');
ok($zip->set_number('6260011')->is_valid_number, '京都府宮津市白柏');
ok($zip->set_number('6260012')->is_valid_number, '京都府宮津市浜町');
ok($zip->set_number('6260013')->is_valid_number, '京都府宮津市住吉');
ok($zip->set_number('6260014')->is_valid_number, '京都府宮津市河原');
ok($zip->set_number('6260015')->is_valid_number, '京都府宮津市魚屋');
ok($zip->set_number('6260016')->is_valid_number, '京都府宮津市新浜');
ok($zip->set_number('6260017')->is_valid_number, '京都府宮津市島崎');
ok($zip->set_number('6260018')->is_valid_number, '京都府宮津市本町');
ok($zip->set_number('6260019')->is_valid_number, '京都府宮津市万年新地');
ok($zip->set_number('6260020')->is_valid_number, '京都府宮津市猟師');
ok($zip->set_number('6260021')->is_valid_number, '京都府宮津市小川');
ok($zip->set_number('6260022')->is_valid_number, '京都府宮津市万町');
ok($zip->set_number('6260023')->is_valid_number, '京都府宮津市宮本');
ok($zip->set_number('6260024')->is_valid_number, '京都府宮津市柳縄手');
ok($zip->set_number('6260025')->is_valid_number, '京都府宮津市木ノ部');
ok($zip->set_number('6260026')->is_valid_number, '京都府宮津市京口町');
ok($zip->set_number('6260027')->is_valid_number, '京都府宮津市京街道');
ok($zip->set_number('6260028')->is_valid_number, '京都府宮津市大久保');
ok($zip->set_number('6260029')->is_valid_number, '京都府宮津市金屋谷');
ok($zip->set_number('6260031')->is_valid_number, '京都府宮津市京口');
ok($zip->set_number('6260032')->is_valid_number, '京都府宮津市松原');
ok($zip->set_number('6260033')->is_valid_number, '京都府宮津市宮村');
ok($zip->set_number('6260034')->is_valid_number, '京都府宮津市滝馬');
ok($zip->set_number('6260035')->is_valid_number, '京都府宮津市喜多');
ok($zip->set_number('6260036')->is_valid_number, '京都府宮津市今福');
ok($zip->set_number('6260037')->is_valid_number, '京都府宮津市小田');
ok($zip->set_number('6260041')->is_valid_number, '京都府宮津市鶴賀');
ok($zip->set_number('6260042')->is_valid_number, '京都府宮津市安智');
ok($zip->set_number('6260043')->is_valid_number, '京都府宮津市惣');
ok($zip->set_number('6260044')->is_valid_number, '京都府宮津市吉原');
ok($zip->set_number('6260045')->is_valid_number, '京都府宮津市馬場先');
ok($zip->set_number('6260046')->is_valid_number, '京都府宮津市中ノ丁');
ok($zip->set_number('6260047')->is_valid_number, '京都府宮津市外側');
ok($zip->set_number('6260051')->is_valid_number, '京都府宮津市島陰');
ok($zip->set_number('6260052')->is_valid_number, '京都府宮津市小田宿野');
ok($zip->set_number('6260053')->is_valid_number, '京都府宮津市中津');
ok($zip->set_number('6260054')->is_valid_number, '京都府宮津市銀丘');
ok($zip->set_number('6260055')->is_valid_number, '京都府宮津市鏡ケ浦');
ok($zip->set_number('6260061')->is_valid_number, '京都府宮津市波路');
ok($zip->set_number('6260062')->is_valid_number, '京都府宮津市山中');
ok($zip->set_number('6260063')->is_valid_number, '京都府宮津市皆原');
ok($zip->set_number('6260064')->is_valid_number, '京都府宮津市波路町');
ok($zip->set_number('6260065')->is_valid_number, '京都府宮津市獅子崎');
ok($zip->set_number('6260066')->is_valid_number, '京都府宮津市獅子');
ok($zip->set_number('6260067')->is_valid_number, '京都府宮津市矢原');
ok($zip->set_number('6260068')->is_valid_number, '京都府宮津市田井');
ok($zip->set_number('6260071')->is_valid_number, '京都府宮津市由良');
ok($zip->set_number('6260072')->is_valid_number, '京都府宮津市石浦');
ok($zip->set_number('6260073')->is_valid_number, '京都府宮津市新宮');
ok($zip->set_number('6260074')->is_valid_number, '京都府宮津市上司');
ok($zip->set_number('6260075')->is_valid_number, '京都府宮津市小寺');
ok($zip->set_number('6260076')->is_valid_number, '京都府宮津市中村');
ok($zip->set_number('6260077')->is_valid_number, '京都府宮津市脇');
ok($zip->set_number('6260201')->is_valid_number, '京都府宮津市田原');
ok($zip->set_number('6260202')->is_valid_number, '京都府宮津市大島');
ok($zip->set_number('6260203')->is_valid_number, '京都府宮津市岩ケ鼻');
ok($zip->set_number('6260204')->is_valid_number, '京都府宮津市長江');
ok($zip->set_number('6260205')->is_valid_number, '京都府宮津市外垣');
ok($zip->set_number('6260206')->is_valid_number, '京都府宮津市日ケ谷');
ok($zip->set_number('6260211')->is_valid_number, '京都府宮津市里波見');
ok($zip->set_number('6260212')->is_valid_number, '京都府宮津市中波見');
ok($zip->set_number('6260213')->is_valid_number, '京都府宮津市奥波見');
ok($zip->set_number('6260221')->is_valid_number, '京都府宮津市木子');
ok($zip->set_number('6260222')->is_valid_number, '京都府宮津市東野');
ok($zip->set_number('6260223')->is_valid_number, '京都府宮津市松尾');
ok($zip->set_number('6260224')->is_valid_number, '京都府宮津市下世屋');
ok($zip->set_number('6260225')->is_valid_number, '京都府宮津市日置');
ok($zip->set_number('6260226')->is_valid_number, '京都府宮津市畑');
ok($zip->set_number('6260227')->is_valid_number, '京都府宮津市上世屋');
ok($zip->set_number('6260400')->is_valid_number, '京都府与謝郡伊根町以下に掲載がない場合');
ok($zip->set_number('6260401')->is_valid_number, '京都府与謝郡伊根町蒲入');
ok($zip->set_number('6260402')->is_valid_number, '京都府与謝郡伊根町長延');
ok($zip->set_number('6260403')->is_valid_number, '京都府与謝郡伊根町本庄浜');
ok($zip->set_number('6260404')->is_valid_number, '京都府与謝郡伊根町本庄宇治');
ok($zip->set_number('6260405')->is_valid_number, '京都府与謝郡伊根町本庄上');
ok($zip->set_number('6260411')->is_valid_number, '京都府与謝郡伊根町野室');
ok($zip->set_number('6260412')->is_valid_number, '京都府与謝郡伊根町津母');
ok($zip->set_number('6260413')->is_valid_number, '京都府与謝郡伊根町泊');
ok($zip->set_number('6260414')->is_valid_number, '京都府与謝郡伊根町六万部');
ok($zip->set_number('6260415')->is_valid_number, '京都府与謝郡伊根町井室');
ok($zip->set_number('6260416')->is_valid_number, '京都府与謝郡伊根町畑谷');
ok($zip->set_number('6260417')->is_valid_number, '京都府与謝郡伊根町峠');
ok($zip->set_number('6260421')->is_valid_number, '京都府与謝郡伊根町新井');
ok($zip->set_number('6260422')->is_valid_number, '京都府与謝郡伊根町大原');
ok($zip->set_number('6260423')->is_valid_number, '京都府与謝郡伊根町平田');
ok($zip->set_number('6260424')->is_valid_number, '京都府与謝郡伊根町亀島');
ok($zip->set_number('6260425')->is_valid_number, '京都府与謝郡伊根町日出');
ok($zip->set_number('6260431')->is_valid_number, '京都府与謝郡伊根町菅野');
ok($zip->set_number('6260432')->is_valid_number, '京都府与謝郡伊根町本坂');
ok($zip->set_number('6260433')->is_valid_number, '京都府与謝郡伊根町野村');
ok($zip->set_number('6270000')->is_valid_number, '京都府京丹後市以下に掲載がない場合');
ok($zip->set_number('6270001')->is_valid_number, '京都府京丹後市峰山町橋木');
ok($zip->set_number('6270002')->is_valid_number, '京都府京丹後市峰山町矢田');
ok($zip->set_number('6270003')->is_valid_number, '京都府京丹後市峰山町内記');
ok($zip->set_number('6270004')->is_valid_number, '京都府京丹後市峰山町荒山');
ok($zip->set_number('6270005')->is_valid_number, '京都府京丹後市峰山町新町');
ok($zip->set_number('6270006')->is_valid_number, '京都府京丹後市峰山町赤坂');
ok($zip->set_number('6270007')->is_valid_number, '京都府京丹後市峰山町石丸');
ok($zip->set_number('6270011')->is_valid_number, '京都府京丹後市峰山町丹波');
ok($zip->set_number('6270012')->is_valid_number, '京都府京丹後市峰山町杉谷');
ok($zip->set_number('6270013')->is_valid_number, '京都府京丹後市峰山町不断');
ok($zip->set_number('6270014')->is_valid_number, '京都府京丹後市峰山町四軒');
ok($zip->set_number('6270021')->is_valid_number, '京都府京丹後市峰山町吉原');
ok($zip->set_number('6270022')->is_valid_number, '京都府京丹後市峰山町上');
ok($zip->set_number('6270023')->is_valid_number, '京都府京丹後市峰山町織元');
ok($zip->set_number('6270024')->is_valid_number, '京都府京丹後市峰山町室');
ok($zip->set_number('6270025')->is_valid_number, '京都府京丹後市峰山町堺');
ok($zip->set_number('6270026')->is_valid_number, '京都府京丹後市峰山町古殿');
ok($zip->set_number('6270027')->is_valid_number, '京都府京丹後市峰山町安');
ok($zip->set_number('6270031')->is_valid_number, '京都府京丹後市峰山町呉服');
ok($zip->set_number('6270032')->is_valid_number, '京都府京丹後市峰山町浪花');
ok($zip->set_number('6270033')->is_valid_number, '京都府京丹後市峰山町白銀');
ok($zip->set_number('6270034')->is_valid_number, '京都府京丹後市峰山町泉');
ok($zip->set_number('6270035')->is_valid_number, '京都府京丹後市峰山町光明寺');
ok($zip->set_number('6270036')->is_valid_number, '京都府京丹後市峰山町御旅');
ok($zip->set_number('6270037')->is_valid_number, '京都府京丹後市峰山町千歳');
ok($zip->set_number('6270038')->is_valid_number, '京都府京丹後市峰山町富貴屋');
ok($zip->set_number('6270041')->is_valid_number, '京都府京丹後市峰山町菅');
ok($zip->set_number('6270042')->is_valid_number, '京都府京丹後市峰山町長岡');
ok($zip->set_number('6270043')->is_valid_number, '京都府京丹後市峰山町新治');
ok($zip->set_number('6270044')->is_valid_number, '京都府京丹後市峰山町小西');
ok($zip->set_number('6270045')->is_valid_number, '京都府京丹後市峰山町西山');
ok($zip->set_number('6270051')->is_valid_number, '京都府京丹後市峰山町二箇');
ok($zip->set_number('6270052')->is_valid_number, '京都府京丹後市峰山町五箇');
ok($zip->set_number('6270053')->is_valid_number, '京都府京丹後市峰山町鱒留');
ok($zip->set_number('6270054')->is_valid_number, '京都府京丹後市峰山町久次');
ok($zip->set_number('6270101')->is_valid_number, '京都府京丹後市弥栄町野中');
ok($zip->set_number('6270102')->is_valid_number, '京都府京丹後市弥栄町須川');
ok($zip->set_number('6270111')->is_valid_number, '京都府京丹後市弥栄町溝谷');
ok($zip->set_number('6270112')->is_valid_number, '京都府京丹後市弥栄町等楽寺');
ok($zip->set_number('6270121')->is_valid_number, '京都府京丹後市弥栄町堤');
ok($zip->set_number('6270122')->is_valid_number, '京都府京丹後市弥栄町芋野');
ok($zip->set_number('6270123')->is_valid_number, '京都府京丹後市弥栄町吉沢');
ok($zip->set_number('6270131')->is_valid_number, '京都府京丹後市弥栄町和田野');
ok($zip->set_number('6270132')->is_valid_number, '京都府京丹後市弥栄町木橋');
ok($zip->set_number('6270133')->is_valid_number, '京都府京丹後市弥栄町鳥取');
ok($zip->set_number('6270141')->is_valid_number, '京都府京丹後市弥栄町小田');
ok($zip->set_number('6270142')->is_valid_number, '京都府京丹後市弥栄町黒部');
ok($zip->set_number('6270143')->is_valid_number, '京都府京丹後市弥栄町船木');
ok($zip->set_number('6270144')->is_valid_number, '京都府京丹後市弥栄町井辺');
ok($zip->set_number('6270145')->is_valid_number, '京都府京丹後市弥栄町国久');
ok($zip->set_number('6270201')->is_valid_number, '京都府京丹後市丹後町間人');
ok($zip->set_number('6270202')->is_valid_number, '京都府京丹後市丹後町砂方');
ok($zip->set_number('6270211')->is_valid_number, '京都府京丹後市丹後町大山');
ok($zip->set_number('6270212')->is_valid_number, '京都府京丹後市丹後町三宅');
ok($zip->set_number('6270213')->is_valid_number, '京都府京丹後市丹後町吉永');
ok($zip->set_number('6270214')->is_valid_number, '京都府京丹後市丹後町是安');
ok($zip->set_number('6270215')->is_valid_number, '京都府京丹後市丹後町成願寺');
ok($zip->set_number('6270216')->is_valid_number, '京都府京丹後市丹後町徳光');
ok($zip->set_number('6270221')->is_valid_number, '京都府京丹後市丹後町竹野');
ok($zip->set_number('6270222')->is_valid_number, '京都府京丹後市丹後町筆石');
ok($zip->set_number('6270223')->is_valid_number, '京都府京丹後市丹後町矢畑');
ok($zip->set_number('6270224')->is_valid_number, '京都府京丹後市丹後町岩木');
ok($zip->set_number('6270225')->is_valid_number, '京都府京丹後市丹後町願興寺');
ok($zip->set_number('6270226')->is_valid_number, '京都府京丹後市丹後町牧ノ谷');
ok($zip->set_number('6270227')->is_valid_number, '京都府京丹後市丹後町家ノ谷');
ok($zip->set_number('6270228')->is_valid_number, '京都府京丹後市丹後町宮');
ok($zip->set_number('6270231')->is_valid_number, '京都府京丹後市丹後町乗原');
ok($zip->set_number('6270232')->is_valid_number, '京都府京丹後市丹後町此代');
ok($zip->set_number('6270233')->is_valid_number, '京都府京丹後市丹後町平');
ok($zip->set_number('6270234')->is_valid_number, '京都府京丹後市丹後町中野');
ok($zip->set_number('6270235')->is_valid_number, '京都府京丹後市丹後町井上');
ok($zip->set_number('6270236')->is_valid_number, '京都府京丹後市丹後町畑');
ok($zip->set_number('6270237')->is_valid_number, '京都府京丹後市丹後町井谷');
ok($zip->set_number('6270238')->is_valid_number, '京都府京丹後市丹後町鞍内');
ok($zip->set_number('6270239')->is_valid_number, '京都府京丹後市丹後町遠下');
ok($zip->set_number('6270241')->is_valid_number, '京都府京丹後市丹後町上野');
ok($zip->set_number('6270242')->is_valid_number, '京都府京丹後市丹後町久僧');
ok($zip->set_number('6270243')->is_valid_number, '京都府京丹後市丹後町中浜');
ok($zip->set_number('6270244')->is_valid_number, '京都府京丹後市丹後町尾和');
ok($zip->set_number('6270245')->is_valid_number, '京都府京丹後市丹後町袖志');
ok($zip->set_number('6270246')->is_valid_number, '京都府京丹後市丹後町谷内');
ok($zip->set_number('6270247')->is_valid_number, '京都府京丹後市丹後町上山');
ok($zip->set_number('6270248')->is_valid_number, '京都府京丹後市丹後町碇');
ok($zip->set_number('6270249')->is_valid_number, '京都府京丹後市丹後町三山');
ok($zip->set_number('6290101')->is_valid_number, '京都府南丹市八木町船枝');
ok($zip->set_number('6290102')->is_valid_number, '京都府南丹市八木町室橋');
ok($zip->set_number('6290103')->is_valid_number, '京都府南丹市八木町諸畑');
ok($zip->set_number('6290104')->is_valid_number, '京都府南丹市八木町日置');
ok($zip->set_number('6290111')->is_valid_number, '京都府南丹市八木町野条');
ok($zip->set_number('6290112')->is_valid_number, '京都府南丹市八木町池上');
ok($zip->set_number('6290113')->is_valid_number, '京都府南丹市八木町刑部');
ok($zip->set_number('6290114')->is_valid_number, '京都府南丹市八木町北廣瀬');
ok($zip->set_number('6290115')->is_valid_number, '京都府南丹市八木町山室');
ok($zip->set_number('6290121')->is_valid_number, '京都府南丹市八木町氷所');
ok($zip->set_number('6290122')->is_valid_number, '京都府南丹市八木町青戸');
ok($zip->set_number('6290131')->is_valid_number, '京都府南丹市八木町北屋賀');
ok($zip->set_number('6290132')->is_valid_number, '京都府南丹市八木町屋賀');
ok($zip->set_number('6290133')->is_valid_number, '京都府南丹市八木町観音寺');
ok($zip->set_number('6290134')->is_valid_number, '京都府南丹市八木町西田');
ok($zip->set_number('6290141')->is_valid_number, '京都府南丹市八木町八木');
ok($zip->set_number('6290151')->is_valid_number, '京都府南丹市八木町南廣瀬');
ok($zip->set_number('6290152')->is_valid_number, '京都府南丹市八木町大藪');
ok($zip->set_number('6290153')->is_valid_number, '京都府南丹市八木町八木嶋');
ok($zip->set_number('6290154')->is_valid_number, '京都府南丹市八木町柴山');
ok($zip->set_number('6290161')->is_valid_number, '京都府南丹市八木町美里');
ok($zip->set_number('6290162')->is_valid_number, '京都府南丹市八木町鳥羽');
ok($zip->set_number('6290163')->is_valid_number, '京都府南丹市八木町玉ノ井');
ok($zip->set_number('6290164')->is_valid_number, '京都府南丹市八木町池ノ内');
ok($zip->set_number('6290165')->is_valid_number, '京都府南丹市八木町木原');
ok($zip->set_number('6290166')->is_valid_number, '京都府南丹市八木町室河原');
ok($zip->set_number('6290271')->is_valid_number, '京都府南丹市八木町神吉');
ok($zip->set_number('6290301')->is_valid_number, '京都府南丹市日吉町保野田');
ok($zip->set_number('6290302')->is_valid_number, '京都府南丹市日吉町志和賀');
ok($zip->set_number('6290311')->is_valid_number, '京都府南丹市日吉町胡麻');
ok($zip->set_number('6290312')->is_valid_number, '京都府南丹市日吉町上胡麻');
ok($zip->set_number('6290313')->is_valid_number, '京都府南丹市日吉町畑郷');
ok($zip->set_number('6290321')->is_valid_number, '京都府南丹市日吉町佐々江');
ok($zip->set_number('6290322')->is_valid_number, '京都府南丹市日吉町四ツ谷');
ok($zip->set_number('6290323')->is_valid_number, '京都府南丹市日吉町田原');
ok($zip->set_number('6290331')->is_valid_number, '京都府南丹市日吉町生畑');
ok($zip->set_number('6290332')->is_valid_number, '京都府南丹市日吉町木住');
ok($zip->set_number('6290333')->is_valid_number, '京都府南丹市日吉町中世木');
ok($zip->set_number('6290334')->is_valid_number, '京都府南丹市日吉町天若');
ok($zip->set_number('6290335')->is_valid_number, '京都府南丹市日吉町中');
ok($zip->set_number('6290341')->is_valid_number, '京都府南丹市日吉町殿田');
ok($zip->set_number('6291101')->is_valid_number, '京都府船井郡京丹波町仏主');
ok($zip->set_number('6291102')->is_valid_number, '京都府船井郡京丹波町上乙見');
ok($zip->set_number('6291103')->is_valid_number, '京都府船井郡京丹波町下乙見');
ok($zip->set_number('6291104')->is_valid_number, '京都府船井郡京丹波町篠原');
ok($zip->set_number('6291105')->is_valid_number, '京都府船井郡京丹波町下粟野');
ok($zip->set_number('6291106')->is_valid_number, '京都府船井郡京丹波町細谷');
ok($zip->set_number('6291107')->is_valid_number, '京都府船井郡京丹波町西河内');
ok($zip->set_number('6291108')->is_valid_number, '京都府船井郡京丹波町上粟野');
ok($zip->set_number('6291111')->is_valid_number, '京都府船井郡京丹波町大迫');
ok($zip->set_number('6291112')->is_valid_number, '京都府船井郡京丹波町塩谷');
ok($zip->set_number('6291113')->is_valid_number, '京都府船井郡京丹波町長瀬');
ok($zip->set_number('6291114')->is_valid_number, '京都府船井郡京丹波町升谷');
ok($zip->set_number('6291115')->is_valid_number, '京都府船井郡京丹波町中山');
ok($zip->set_number('6291116')->is_valid_number, '京都府船井郡京丹波町市場');
ok($zip->set_number('6291117')->is_valid_number, '京都府船井郡京丹波町大倉');
ok($zip->set_number('6291121')->is_valid_number, '京都府船井郡京丹波町本庄');
ok($zip->set_number('6291122')->is_valid_number, '京都府船井郡京丹波町小畑');
ok($zip->set_number('6291131')->is_valid_number, '京都府船井郡京丹波町坂原');
ok($zip->set_number('6291132')->is_valid_number, '京都府船井郡京丹波町中');
ok($zip->set_number('6291133')->is_valid_number, '京都府船井郡京丹波町角');
ok($zip->set_number('6291134')->is_valid_number, '京都府船井郡京丹波町広瀬');
ok($zip->set_number('6291135')->is_valid_number, '京都府船井郡京丹波町才原');
ok($zip->set_number('6291141')->is_valid_number, '京都府船井郡京丹波町安栖里');
ok($zip->set_number('6291142')->is_valid_number, '京都府船井郡京丹波町稲次');
ok($zip->set_number('6291143')->is_valid_number, '京都府船井郡京丹波町出野');
ok($zip->set_number('6291144')->is_valid_number, '京都府船井郡京丹波町広野');
ok($zip->set_number('6291145')->is_valid_number, '京都府船井郡京丹波町大簾');
ok($zip->set_number('6291241')->is_valid_number, '京都府綾部市井根町');
ok($zip->set_number('6291242')->is_valid_number, '京都府綾部市十倉名畑町');
ok($zip->set_number('6291243')->is_valid_number, '京都府綾部市十倉向町');
ok($zip->set_number('6291244')->is_valid_number, '京都府綾部市十倉中町');
ok($zip->set_number('6291245')->is_valid_number, '京都府綾部市十倉志茂町');
ok($zip->set_number('6291251')->is_valid_number, '京都府綾部市忠町');
ok($zip->set_number('6291252')->is_valid_number, '京都府綾部市佃町');
ok($zip->set_number('6291253')->is_valid_number, '京都府綾部市武吉町');
ok($zip->set_number('6291254')->is_valid_number, '京都府綾部市釜輪町');
ok($zip->set_number('6291255')->is_valid_number, '京都府綾部市戸奈瀬町');
ok($zip->set_number('6291256')->is_valid_number, '京都府綾部市広瀬町');
ok($zip->set_number('6291257')->is_valid_number, '京都府綾部市橋上町');
ok($zip->set_number('6291261')->is_valid_number, '京都府綾部市旭町');
ok($zip->set_number('6291262')->is_valid_number, '京都府綾部市東山町');
ok($zip->set_number('6291263')->is_valid_number, '京都府綾部市鷹栖町');
ok($zip->set_number('6291264')->is_valid_number, '京都府綾部市西原町');
ok($zip->set_number('6291271')->is_valid_number, '京都府綾部市上原町');
ok($zip->set_number('6291272')->is_valid_number, '京都府綾部市下替地町');
ok($zip->set_number('6291273')->is_valid_number, '京都府綾部市下原町');
ok($zip->set_number('6291274')->is_valid_number, '京都府綾部市和木町');
ok($zip->set_number('6291301')->is_valid_number, '京都府福知山市夜久野町畑');
ok($zip->set_number('6291302')->is_valid_number, '京都府福知山市夜久野町今西中');
ok($zip->set_number('6291303')->is_valid_number, '京都府福知山市夜久野町井田');
ok($zip->set_number('6291304')->is_valid_number, '京都府福知山市夜久野町額田');
ok($zip->set_number('6291305')->is_valid_number, '京都府福知山市夜久野町千原');
ok($zip->set_number('6291311')->is_valid_number, '京都府福知山市夜久野町日置');
ok($zip->set_number('6291312')->is_valid_number, '京都府福知山市夜久野町末');
ok($zip->set_number('6291313')->is_valid_number, '京都府福知山市夜久野町高内');
ok($zip->set_number('6291314')->is_valid_number, '京都府福知山市夜久野町小倉');
ok($zip->set_number('6291315')->is_valid_number, '京都府福知山市夜久野町大油子');
ok($zip->set_number('6291321')->is_valid_number, '京都府福知山市夜久野町直見');
ok($zip->set_number('6291322')->is_valid_number, '京都府福知山市夜久野町平野');
ok($zip->set_number('6291323')->is_valid_number, '京都府福知山市夜久野町板生');
ok($zip->set_number('6292200')->is_valid_number, '京都府与謝郡与謝野町以下に掲載がない場合');
ok($zip->set_number('6292231')->is_valid_number, '京都府宮津市小松');
ok($zip->set_number('6292232')->is_valid_number, '京都府宮津市中野');
ok($zip->set_number('6292233')->is_valid_number, '京都府宮津市溝尻');
ok($zip->set_number('6292234')->is_valid_number, '京都府宮津市国分');
ok($zip->set_number('6292241')->is_valid_number, '京都府宮津市成相寺');
ok($zip->set_number('6292242')->is_valid_number, '京都府宮津市大垣');
ok($zip->set_number('6292243')->is_valid_number, '京都府宮津市難波野');
ok($zip->set_number('6292244')->is_valid_number, '京都府宮津市江尻');
ok($zip->set_number('6292251')->is_valid_number, '京都府宮津市須津');
ok($zip->set_number('6292261')->is_valid_number, '京都府与謝郡与謝野町男山');
ok($zip->set_number('6292262')->is_valid_number, '京都府与謝郡与謝野町岩滝');
ok($zip->set_number('6292263')->is_valid_number, '京都府与謝郡与謝野町弓木');
ok($zip->set_number('6292301')->is_valid_number, '京都府与謝郡与謝野町上山田');
ok($zip->set_number('6292302')->is_valid_number, '京都府与謝郡与謝野町下山田');
ok($zip->set_number('6292303')->is_valid_number, '京都府与謝郡与謝野町石川');
ok($zip->set_number('6292311')->is_valid_number, '京都府与謝郡与謝野町幾地');
ok($zip->set_number('6292312')->is_valid_number, '京都府与謝郡与謝野町四辻');
ok($zip->set_number('6292313')->is_valid_number, '京都府与謝郡与謝野町三河内');
ok($zip->set_number('6292314')->is_valid_number, '京都府与謝郡与謝野町岩屋');
ok($zip->set_number('6292401')->is_valid_number, '京都府与謝郡与謝野町加悦奥');
ok($zip->set_number('6292402')->is_valid_number, '京都府与謝郡与謝野町算所');
ok($zip->set_number('6292403')->is_valid_number, '京都府与謝郡与謝野町加悦');
ok($zip->set_number('6292404')->is_valid_number, '京都府与謝郡与謝野町後野');
ok($zip->set_number('6292411')->is_valid_number, '京都府与謝郡与謝野町明石');
ok($zip->set_number('6292412')->is_valid_number, '京都府与謝郡与謝野町香河');
ok($zip->set_number('6292413')->is_valid_number, '京都府与謝郡与謝野町温江');
ok($zip->set_number('6292421')->is_valid_number, '京都府与謝郡与謝野町金屋');
ok($zip->set_number('6292422')->is_valid_number, '京都府与謝郡与謝野町滝');
ok($zip->set_number('6292423')->is_valid_number, '京都府与謝郡与謝野町与謝');
ok($zip->set_number('6292501')->is_valid_number, '京都府京丹後市大宮町口大野');
ok($zip->set_number('6292502')->is_valid_number, '京都府京丹後市大宮町河辺');
ok($zip->set_number('6292503')->is_valid_number, '京都府京丹後市大宮町周枳');
ok($zip->set_number('6292504')->is_valid_number, '京都府京丹後市大宮町善王寺');
ok($zip->set_number('6292511')->is_valid_number, '京都府京丹後市大宮町久住');
ok($zip->set_number('6292512')->is_valid_number, '京都府京丹後市大宮町五十河');
ok($zip->set_number('6292513')->is_valid_number, '京都府京丹後市大宮町延利');
ok($zip->set_number('6292514')->is_valid_number, '京都府京丹後市大宮町明田');
ok($zip->set_number('6292515')->is_valid_number, '京都府京丹後市大宮町新宮');
ok($zip->set_number('6292521')->is_valid_number, '京都府京丹後市大宮町森本');
ok($zip->set_number('6292522')->is_valid_number, '京都府京丹後市大宮町三重');
ok($zip->set_number('6292523')->is_valid_number, '京都府京丹後市大宮町三坂');
ok($zip->set_number('6292531')->is_valid_number, '京都府京丹後市大宮町奥大野');
ok($zip->set_number('6292532')->is_valid_number, '京都府京丹後市大宮町谷内');
ok($zip->set_number('6292533')->is_valid_number, '京都府京丹後市大宮町上常吉');
ok($zip->set_number('6292534')->is_valid_number, '京都府京丹後市大宮町下常吉');
ok($zip->set_number('6293101')->is_valid_number, '京都府京丹後市網野町網野');
ok($zip->set_number('6293102')->is_valid_number, '京都府京丹後市網野町下岡');
ok($zip->set_number('6293103')->is_valid_number, '京都府京丹後市網野町磯');
ok($zip->set_number('6293104')->is_valid_number, '京都府京丹後市網野町浅茂川');
ok($zip->set_number('6293111')->is_valid_number, '京都府京丹後市網野町三津');
ok($zip->set_number('6293112')->is_valid_number, '京都府京丹後市網野町掛津');
ok($zip->set_number('6293113')->is_valid_number, '京都府京丹後市網野町小浜');
ok($zip->set_number('6293121')->is_valid_number, '京都府京丹後市網野町島津');
ok($zip->set_number('6293122')->is_valid_number, '京都府京丹後市網野町仲禅寺');
ok($zip->set_number('6293131')->is_valid_number, '京都府京丹後市網野町高橋');
ok($zip->set_number('6293132')->is_valid_number, '京都府京丹後市網野町公庄');
ok($zip->set_number('6293133')->is_valid_number, '京都府京丹後市網野町郷');
ok($zip->set_number('6293134')->is_valid_number, '京都府京丹後市網野町生野内');
ok($zip->set_number('6293135')->is_valid_number, '京都府京丹後市網野町切畑');
ok($zip->set_number('6293136')->is_valid_number, '京都府京丹後市網野町新庄');
ok($zip->set_number('6293241')->is_valid_number, '京都府京丹後市網野町木津');
ok($zip->set_number('6293242')->is_valid_number, '京都府京丹後市網野町日和田');
ok($zip->set_number('6293243')->is_valid_number, '京都府京丹後市網野町溝野');
ok($zip->set_number('6293244')->is_valid_number, '京都府京丹後市網野町俵野');
ok($zip->set_number('6293245')->is_valid_number, '京都府京丹後市網野町浜詰');
ok($zip->set_number('6293246')->is_valid_number, '京都府京丹後市網野町塩江');
ok($zip->set_number('6293401')->is_valid_number, '京都府京丹後市久美浜町十楽');
ok($zip->set_number('6293402')->is_valid_number, '京都府京丹後市久美浜町仲町');
ok($zip->set_number('6293403')->is_valid_number, '京都府京丹後市久美浜町向町');
ok($zip->set_number('6293404')->is_valid_number, '京都府京丹後市久美浜町土居');
ok($zip->set_number('6293405')->is_valid_number, '京都府京丹後市久美浜町栄町');
ok($zip->set_number('6293406')->is_valid_number, '京都府京丹後市久美浜町東本町');
ok($zip->set_number('6293407')->is_valid_number, '京都府京丹後市久美浜町新橋');
ok($zip->set_number('6293408')->is_valid_number, '京都府京丹後市久美浜町新町');
ok($zip->set_number('6293409')->is_valid_number, '京都府京丹後市久美浜町西本町');
ok($zip->set_number('6293410')->is_valid_number, '京都府京丹後市久美浜町');
ok($zip->set_number('6293411')->is_valid_number, '京都府京丹後市久美浜町甲坂');
ok($zip->set_number('6293411')->is_valid_number, '京都府京丹後市久美浜町栃谷');
ok($zip->set_number('6293412')->is_valid_number, '京都府京丹後市久美浜町奥三谷');
ok($zip->set_number('6293412')->is_valid_number, '京都府京丹後市久美浜町口三谷');
ok($zip->set_number('6293412')->is_valid_number, '京都府京丹後市久美浜町三谷');
ok($zip->set_number('6293413')->is_valid_number, '京都府京丹後市久美浜町口馬地');
ok($zip->set_number('6293414')->is_valid_number, '京都府京丹後市久美浜町奥馬地');
ok($zip->set_number('6293415')->is_valid_number, '京都府京丹後市久美浜町河梨');
ok($zip->set_number('6293416')->is_valid_number, '京都府京丹後市久美浜町神谷');
ok($zip->set_number('6293421')->is_valid_number, '京都府京丹後市久美浜町葛野');
ok($zip->set_number('6293422')->is_valid_number, '京都府京丹後市久美浜町河内');
ok($zip->set_number('6293422')->is_valid_number, '京都府京丹後市久美浜町箱石');
ok($zip->set_number('6293422')->is_valid_number, '京都府京丹後市久美浜町湊宮');
ok($zip->set_number('6293423')->is_valid_number, '京都府京丹後市久美浜町大向');
ok($zip->set_number('6293424')->is_valid_number, '京都府京丹後市久美浜町旭');
ok($zip->set_number('6293424')->is_valid_number, '京都府京丹後市久美浜町蒲井');
ok($zip->set_number('6293431')->is_valid_number, '京都府京丹後市久美浜町鹿野');
ok($zip->set_number('6293432')->is_valid_number, '京都府京丹後市久美浜町平田');
ok($zip->set_number('6293433')->is_valid_number, '京都府京丹後市久美浜町三分');
ok($zip->set_number('6293434')->is_valid_number, '京都府京丹後市久美浜町三原');
ok($zip->set_number('6293435')->is_valid_number, '京都府京丹後市久美浜町壱分');
ok($zip->set_number('6293436')->is_valid_number, '京都府京丹後市久美浜町大井');
ok($zip->set_number('6293437')->is_valid_number, '京都府京丹後市久美浜町関');
ok($zip->set_number('6293438')->is_valid_number, '京都府京丹後市久美浜町浦明');
ok($zip->set_number('6293438')->is_valid_number, '京都府京丹後市久美浜町長柄');
ok($zip->set_number('6293441')->is_valid_number, '京都府京丹後市久美浜町神崎');
ok($zip->set_number('6293442')->is_valid_number, '京都府京丹後市久美浜町甲山');
ok($zip->set_number('6293443')->is_valid_number, '京都府京丹後市久美浜町海士');
ok($zip->set_number('6293444')->is_valid_number, '京都府京丹後市久美浜町西橋爪');
ok($zip->set_number('6293444')->is_valid_number, '京都府京丹後市久美浜町橋爪');
ok($zip->set_number('6293445')->is_valid_number, '京都府京丹後市久美浜町島');
ok($zip->set_number('6293446')->is_valid_number, '京都府京丹後市久美浜町品田');
ok($zip->set_number('6293447')->is_valid_number, '京都府京丹後市久美浜町友重');
ok($zip->set_number('6293448')->is_valid_number, '京都府京丹後市久美浜町坂井');
ok($zip->set_number('6293449')->is_valid_number, '京都府京丹後市久美浜町油池');
ok($zip->set_number('6293551')->is_valid_number, '京都府京丹後市久美浜町永留');
ok($zip->set_number('6293552')->is_valid_number, '京都府京丹後市久美浜町女布');
ok($zip->set_number('6293553')->is_valid_number, '京都府京丹後市久美浜町長野');
ok($zip->set_number('6293554')->is_valid_number, '京都府京丹後市久美浜町坂谷');
ok($zip->set_number('6293555')->is_valid_number, '京都府京丹後市久美浜町円頓寺');
ok($zip->set_number('6293556')->is_valid_number, '京都府京丹後市久美浜町郷');
ok($zip->set_number('6293557')->is_valid_number, '京都府京丹後市久美浜町竹藤');
ok($zip->set_number('6293558')->is_valid_number, '京都府京丹後市久美浜町丸山');
ok($zip->set_number('6293559')->is_valid_number, '京都府京丹後市久美浜町谷');
ok($zip->set_number('6293561')->is_valid_number, '京都府京丹後市久美浜町野中');
ok($zip->set_number('6293562')->is_valid_number, '京都府京丹後市久美浜町佐野');
ok($zip->set_number('6293563')->is_valid_number, '京都府京丹後市久美浜町二俣');
ok($zip->set_number('6293564')->is_valid_number, '京都府京丹後市久美浜町尉ケ畑');
ok($zip->set_number('6293565')->is_valid_number, '京都府京丹後市久美浜町小桑');
ok($zip->set_number('6293566')->is_valid_number, '京都府京丹後市久美浜町安養寺');
ok($zip->set_number('6293570')->is_valid_number, '京都府京丹後市久美浜町新庄');
ok($zip->set_number('6293571')->is_valid_number, '京都府京丹後市久美浜町芦原');
ok($zip->set_number('6293572')->is_valid_number, '京都府京丹後市久美浜町新谷');
ok($zip->set_number('6293573')->is_valid_number, '京都府京丹後市久美浜町出角');
ok($zip->set_number('6293574')->is_valid_number, '京都府京丹後市久美浜町市場');
ok($zip->set_number('6293575')->is_valid_number, '京都府京丹後市久美浜町金谷');
ok($zip->set_number('6293576')->is_valid_number, '京都府京丹後市久美浜町市野々');
ok($zip->set_number('6293577')->is_valid_number, '京都府京丹後市久美浜町布袋野');
ok($zip->set_number('6293578')->is_valid_number, '京都府京丹後市久美浜町畑');
ok($zip->set_number('6293579')->is_valid_number, '京都府京丹後市久美浜町須田');
ok($zip->set_number('6300000')->is_valid_number, '奈良県奈良市以下に掲載がない場合');
ok($zip->set_number('6300000')->is_valid_number, '奈良県山辺郡山添村以下に掲載がない場合');
ok($zip->set_number('6300101')->is_valid_number, '奈良県生駒市高山町');
ok($zip->set_number('6300111')->is_valid_number, '奈良県生駒市鹿ノ台北');
ok($zip->set_number('6300112')->is_valid_number, '奈良県生駒市鹿ノ台東');
ok($zip->set_number('6300113')->is_valid_number, '奈良県生駒市鹿ノ台南');
ok($zip->set_number('6300114')->is_valid_number, '奈良県生駒市鹿ノ台西');
ok($zip->set_number('6300115')->is_valid_number, '奈良県生駒市鹿畑町');
ok($zip->set_number('6300116')->is_valid_number, '奈良県生駒市美鹿の台');
ok($zip->set_number('6300121')->is_valid_number, '奈良県生駒市北大和');
ok($zip->set_number('6300122')->is_valid_number, '奈良県生駒市真弓');
ok($zip->set_number('6300123')->is_valid_number, '奈良県生駒市真弓南');
ok($zip->set_number('6300131')->is_valid_number, '奈良県生駒市上町');
ok($zip->set_number('6300132')->is_valid_number, '奈良県生駒市あすか台');
ok($zip->set_number('6300133')->is_valid_number, '奈良県生駒市あすか野南');
ok($zip->set_number('6300134')->is_valid_number, '奈良県生駒市あすか野北');
ok($zip->set_number('6300135')->is_valid_number, '奈良県生駒市南田原町');
ok($zip->set_number('6300136')->is_valid_number, '奈良県生駒市白庭台');
ok($zip->set_number('6300137')->is_valid_number, '奈良県生駒市西白庭台');
ok($zip->set_number('6300138')->is_valid_number, '奈良県生駒市上町台');
ok($zip->set_number('6300141')->is_valid_number, '奈良県生駒市ひかりが丘');
ok($zip->set_number('6300142')->is_valid_number, '奈良県生駒市北田原町');
ok($zip->set_number('6300200')->is_valid_number, '奈良県生駒市以下に掲載がない場合');
ok($zip->set_number('6300201')->is_valid_number, '奈良県生駒市小明町');
ok($zip->set_number('6300202')->is_valid_number, '奈良県生駒市生駒台南');
ok($zip->set_number('6300203')->is_valid_number, '奈良県生駒市生駒台北');
ok($zip->set_number('6300211')->is_valid_number, '奈良県生駒市桜ケ丘');
ok($zip->set_number('6300212')->is_valid_number, '奈良県生駒市辻町');
ok($zip->set_number('6300213')->is_valid_number, '奈良県生駒市東生駒');
ok($zip->set_number('6300214')->is_valid_number, '奈良県生駒市東生駒月見町');
ok($zip->set_number('6300215')->is_valid_number, '奈良県生駒市東菜畑');
ok($zip->set_number('6300221')->is_valid_number, '奈良県生駒市さつき台');
ok($zip->set_number('6300222')->is_valid_number, '奈良県生駒市壱分町');
ok($zip->set_number('6300223')->is_valid_number, '奈良県生駒市小瀬町');
ok($zip->set_number('6300224')->is_valid_number, '奈良県生駒市萩の台');
ok($zip->set_number('6300225')->is_valid_number, '奈良県生駒市東山町');
ok($zip->set_number('6300226')->is_valid_number, '奈良県生駒市小平尾町');
ok($zip->set_number('6300227')->is_valid_number, '奈良県生駒市乙田町');
ok($zip->set_number('6300228')->is_valid_number, '奈良県生駒市南山手台');
ok($zip->set_number('6300229')->is_valid_number, '奈良県生駒市翠光台');
ok($zip->set_number('6300231')->is_valid_number, '奈良県生駒市菜畑町');
ok($zip->set_number('6300232')->is_valid_number, '奈良県生駒市小倉寺町');
ok($zip->set_number('6300233')->is_valid_number, '奈良県生駒市有里町');
ok($zip->set_number('6300234')->is_valid_number, '奈良県生駒市萩原町');
ok($zip->set_number('6300235')->is_valid_number, '奈良県生駒市藤尾町');
ok($zip->set_number('6300236')->is_valid_number, '奈良県生駒市西畑町');
ok($zip->set_number('6300237')->is_valid_number, '奈良県生駒市鬼取町');
ok($zip->set_number('6300238')->is_valid_number, '奈良県生駒市大門町');
ok($zip->set_number('6300239')->is_valid_number, '奈良県生駒市青山台');
ok($zip->set_number('6300241')->is_valid_number, '奈良県生駒市松美台');
ok($zip->set_number('6300242')->is_valid_number, '奈良県生駒市新生駒台');
ok($zip->set_number('6300243')->is_valid_number, '奈良県生駒市俵口町');
ok($zip->set_number('6300244')->is_valid_number, '奈良県生駒市東松ケ丘');
ok($zip->set_number('6300245')->is_valid_number, '奈良県生駒市北新町');
ok($zip->set_number('6300246')->is_valid_number, '奈良県生駒市西松ケ丘');
ok($zip->set_number('6300247')->is_valid_number, '奈良県生駒市光陽台');
ok($zip->set_number('6300248')->is_valid_number, '奈良県生駒市喜里が丘');
ok($zip->set_number('6300251')->is_valid_number, '奈良県生駒市谷田町');
ok($zip->set_number('6300252')->is_valid_number, '奈良県生駒市山崎町');
ok($zip->set_number('6300253')->is_valid_number, '奈良県生駒市新旭ケ丘');
ok($zip->set_number('6300254')->is_valid_number, '奈良県生駒市東旭ケ丘');
ok($zip->set_number('6300255')->is_valid_number, '奈良県生駒市山崎新町');
ok($zip->set_number('6300256')->is_valid_number, '奈良県生駒市本町');
ok($zip->set_number('6300257')->is_valid_number, '奈良県生駒市元町');
ok($zip->set_number('6300258')->is_valid_number, '奈良県生駒市東新町');
ok($zip->set_number('6300261')->is_valid_number, '奈良県生駒市西旭ケ丘');
ok($zip->set_number('6300262')->is_valid_number, '奈良県生駒市緑ケ丘');
ok($zip->set_number('6300263')->is_valid_number, '奈良県生駒市中菜畑');
ok($zip->set_number('6300264')->is_valid_number, '奈良県生駒市西菜畑町');
ok($zip->set_number('6300265')->is_valid_number, '奈良県生駒市軽井沢町');
ok($zip->set_number('6300266')->is_valid_number, '奈良県生駒市門前町');
ok($zip->set_number('6300267')->is_valid_number, '奈良県生駒市仲之町');
ok($zip->set_number('6300271')->is_valid_number, '大阪府東大阪市上石切町(2丁目863、1451番地)');
ok($zip->set_number('6300272')->is_valid_number, '大阪府東大阪市山手町(2017、2018、2027、2028番地)');
ok($zip->set_number('6301101')->is_valid_number, '奈良県奈良市広岡町');
ok($zip->set_number('6301102')->is_valid_number, '奈良県奈良市下狭川町');
ok($zip->set_number('6301103')->is_valid_number, '奈良県奈良市狭川東町');
ok($zip->set_number('6301104')->is_valid_number, '奈良県奈良市狭川両町');
ok($zip->set_number('6301105')->is_valid_number, '奈良県奈良市西狭川町');
ok($zip->set_number('6301111')->is_valid_number, '奈良県奈良市須川町');
ok($zip->set_number('6301112')->is_valid_number, '奈良県奈良市南庄町');
ok($zip->set_number('6301113')->is_valid_number, '奈良県奈良市北村町');
ok($zip->set_number('6301121')->is_valid_number, '奈良県奈良市園田町');
ok($zip->set_number('6301122')->is_valid_number, '奈良県奈良市平清水町');
ok($zip->set_number('6301123')->is_valid_number, '奈良県奈良市生琉里町');
ok($zip->set_number('6301124')->is_valid_number, '奈良県奈良市中ノ川町(106~305、405-3、638)');
ok($zip->set_number('6301125')->is_valid_number, '奈良県奈良市東鳴川町');
ok($zip->set_number('6301126')->is_valid_number, '奈良県奈良市法用町');
ok($zip->set_number('6301231')->is_valid_number, '奈良県奈良市柳生下町');
ok($zip->set_number('6301232')->is_valid_number, '奈良県奈良市興ヶ原町');
ok($zip->set_number('6301233')->is_valid_number, '奈良県奈良市邑地町');
ok($zip->set_number('6301234')->is_valid_number, '奈良県奈良市北野山町');
ok($zip->set_number('6301235')->is_valid_number, '奈良県奈良市丹生町');
ok($zip->set_number('6301236')->is_valid_number, '奈良県奈良市大保町');
ok($zip->set_number('6301237')->is_valid_number, '奈良県奈良市柳生町');
ok($zip->set_number('6301241')->is_valid_number, '奈良県奈良市阪原町');
ok($zip->set_number('6301242')->is_valid_number, '奈良県奈良市大柳生町');
ok($zip->set_number('6301243')->is_valid_number, '奈良県奈良市大平尾町');
ok($zip->set_number('6301244')->is_valid_number, '奈良県奈良市忍辱山町');
ok($zip->set_number('6301245')->is_valid_number, '奈良県奈良市大慈仙町');
ok($zip->set_number('6302151')->is_valid_number, '奈良県奈良市水間町');
ok($zip->set_number('6302152')->is_valid_number, '奈良県奈良市杣ノ川町');
ok($zip->set_number('6302153')->is_valid_number, '奈良県奈良市別所町');
ok($zip->set_number('6302161')->is_valid_number, '奈良県奈良市大野町');
ok($zip->set_number('6302162')->is_valid_number, '奈良県奈良市中貫町');
ok($zip->set_number('6302163')->is_valid_number, '奈良県奈良市中之庄町');
ok($zip->set_number('6302164')->is_valid_number, '奈良県奈良市南田原町');
ok($zip->set_number('6302165')->is_valid_number, '奈良県奈良市長谷町');
ok($zip->set_number('6302166')->is_valid_number, '奈良県奈良市矢田原町');
ok($zip->set_number('6302167')->is_valid_number, '奈良県奈良市田原春日野町');
ok($zip->set_number('6302168')->is_valid_number, '奈良県奈良市菩提山町(173~257番地「鉢伏峠」)');
ok($zip->set_number('6302171')->is_valid_number, '奈良県奈良市誓多林町');
ok($zip->set_number('6302172')->is_valid_number, '奈良県奈良市沓掛町');
ok($zip->set_number('6302173')->is_valid_number, '奈良県奈良市日笠町');
ok($zip->set_number('6302174')->is_valid_number, '奈良県奈良市横田町');
ok($zip->set_number('6302175')->is_valid_number, '奈良県奈良市茗荷町');
ok($zip->set_number('6302176')->is_valid_number, '奈良県奈良市和田町');
ok($zip->set_number('6302177')->is_valid_number, '奈良県奈良市此瀬町');
ok($zip->set_number('6302178')->is_valid_number, '奈良県奈良市須山町');
ok($zip->set_number('6302201')->is_valid_number, '奈良県山辺郡山添村峰寺');
ok($zip->set_number('6302202')->is_valid_number, '奈良県山辺郡山添村的野');
ok($zip->set_number('6302203')->is_valid_number, '奈良県山辺郡山添村松尾');
ok($zip->set_number('6302204')->is_valid_number, '奈良県山辺郡山添村室津');
ok($zip->set_number('6302205')->is_valid_number, '奈良県山辺郡山添村桐山');
ok($zip->set_number('6302211')->is_valid_number, '奈良県山辺郡山添村北野');
ok($zip->set_number('6302212')->is_valid_number, '奈良県山辺郡山添村大塩');
ok($zip->set_number('6302221')->is_valid_number, '奈良県山辺郡山添村箕輪');
ok($zip->set_number('6302222')->is_valid_number, '奈良県山辺郡山添村堂前');
ok($zip->set_number('6302223')->is_valid_number, '奈良県山辺郡山添村三ケ谷');
ok($zip->set_number('6302224')->is_valid_number, '奈良県山辺郡山添村助命');
ok($zip->set_number('6302225')->is_valid_number, '奈良県山辺郡山添村伏拝');
ok($zip->set_number('6302231')->is_valid_number, '奈良県山辺郡山添村勝原');
ok($zip->set_number('6302232')->is_valid_number, '奈良県山辺郡山添村岩屋');
ok($zip->set_number('6302233')->is_valid_number, '奈良県山辺郡山添村毛原');
ok($zip->set_number('6302234')->is_valid_number, '奈良県山辺郡山添村切幡');
ok($zip->set_number('6302301')->is_valid_number, '奈良県奈良市月ヶ瀬石打');
ok($zip->set_number('6302302')->is_valid_number, '奈良県奈良市月ヶ瀬尾山');
ok($zip->set_number('6302303')->is_valid_number, '奈良県奈良市月ヶ瀬長引');
ok($zip->set_number('6302304')->is_valid_number, '奈良県奈良市月ヶ瀬嵩');
ok($zip->set_number('6302305')->is_valid_number, '奈良県奈良市月ヶ瀬月瀬');
ok($zip->set_number('6302306')->is_valid_number, '奈良県奈良市月ヶ瀬桃香野');
ok($zip->set_number('6302341')->is_valid_number, '奈良県山辺郡山添村遅瀬');
ok($zip->set_number('6302342')->is_valid_number, '奈良県山辺郡山添村広代');
ok($zip->set_number('6302343')->is_valid_number, '奈良県山辺郡山添村春日');
ok($zip->set_number('6302344')->is_valid_number, '奈良県山辺郡山添村大西');
ok($zip->set_number('6302345')->is_valid_number, '奈良県山辺郡山添村菅生');
ok($zip->set_number('6302346')->is_valid_number, '奈良県山辺郡山添村西波多');
ok($zip->set_number('6302351')->is_valid_number, '奈良県山辺郡山添村中峰山');
ok($zip->set_number('6302352')->is_valid_number, '奈良県山辺郡山添村中之庄');
ok($zip->set_number('6302353')->is_valid_number, '奈良県山辺郡山添村吉田');
ok($zip->set_number('6302354')->is_valid_number, '奈良県山辺郡山添村広瀬');
ok($zip->set_number('6302355')->is_valid_number, '奈良県山辺郡山添村鵜山');
ok($zip->set_number('6302356')->is_valid_number, '奈良県山辺郡山添村片平');
ok($zip->set_number('6302357')->is_valid_number, '奈良県山辺郡山添村葛尾');
ok($zip->set_number('6308001')->is_valid_number, '奈良県奈良市法華寺町');
ok($zip->set_number('6308002')->is_valid_number, '奈良県奈良市二条町');
ok($zip->set_number('6308003')->is_valid_number, '奈良県奈良市佐紀町');
ok($zip->set_number('6308011')->is_valid_number, '奈良県奈良市北新町');
ok($zip->set_number('6308012')->is_valid_number, '奈良県奈良市二条大路南');
ok($zip->set_number('6308013')->is_valid_number, '奈良県奈良市三条大路');
ok($zip->set_number('6308014')->is_valid_number, '奈良県奈良市四条大路');
ok($zip->set_number('6308015')->is_valid_number, '奈良県奈良市四条大路南町');
ok($zip->set_number('6308016')->is_valid_number, '奈良県奈良市南新町(52~212番地)');
ok($zip->set_number('6308021')->is_valid_number, '奈良県奈良市尼辻町');
ok($zip->set_number('6308022')->is_valid_number, '奈良県奈良市尼辻南町');
ok($zip->set_number('6308023')->is_valid_number, '奈良県奈良市尼辻西町');
ok($zip->set_number('6308024')->is_valid_number, '奈良県奈良市尼辻中町');
ok($zip->set_number('6308025')->is_valid_number, '奈良県奈良市尼辻北町');
ok($zip->set_number('6308031')->is_valid_number, '奈良県奈良市柏木町');
ok($zip->set_number('6308032')->is_valid_number, '奈良県奈良市五条町');
ok($zip->set_number('6308033')->is_valid_number, '奈良県奈良市五条');
ok($zip->set_number('6308034')->is_valid_number, '奈良県奈良市五条西');
ok($zip->set_number('6308035')->is_valid_number, '奈良県奈良市赤膚町');
ok($zip->set_number('6308036')->is_valid_number, '奈良県奈良市五条畑');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市中町(5115~5149、5171、5183、5186、');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市5192~5196、5198~5212、5227~5229、');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市5239~5257、5263、5269~5271、5275、');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市5276-4、5276-5、5277~5280、5284~');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市5312、5314、5316~5327、5346、5349、');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市5351~5352、5355~5362、5364~5424、');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市5426、5429~5430、5445、5455、5461、');
ok($zip->set_number('6308037')->is_valid_number, '奈良県奈良市5463、5470、5472、5475、5482~5529)');
ok($zip->set_number('6308041')->is_valid_number, '奈良県奈良市六条町');
ok($zip->set_number('6308042')->is_valid_number, '奈良県奈良市西ノ京町');
ok($zip->set_number('6308043')->is_valid_number, '奈良県奈良市六条');
ok($zip->set_number('6308044')->is_valid_number, '奈良県奈良市六条西');
ok($zip->set_number('6308045')->is_valid_number, '奈良県奈良市六条緑町');
ok($zip->set_number('6308051')->is_valid_number, '奈良県奈良市七条町');
ok($zip->set_number('6308052')->is_valid_number, '奈良県奈良市七条東町');
ok($zip->set_number('6308053')->is_valid_number, '奈良県奈良市七条');
ok($zip->set_number('6308054')->is_valid_number, '奈良県奈良市七条西町');
ok($zip->set_number('6308101')->is_valid_number, '奈良県奈良市青山');
ok($zip->set_number('6308102')->is_valid_number, '奈良県奈良市般若寺町');
ok($zip->set_number('6308103')->is_valid_number, '奈良県奈良市興善院町');
ok($zip->set_number('6308104')->is_valid_number, '奈良県奈良市奈良阪町');
ok($zip->set_number('6308105')->is_valid_number, '奈良県奈良市佐保台');
ok($zip->set_number('6308106')->is_valid_number, '奈良県奈良市佐保台西町');
ok($zip->set_number('6308107')->is_valid_number, '奈良県奈良市奈保町');
ok($zip->set_number('6308108')->is_valid_number, '奈良県奈良市法蓮佐保山');
ok($zip->set_number('6308111')->is_valid_number, '奈良県奈良市半田開町');
ok($zip->set_number('6308112')->is_valid_number, '奈良県奈良市多門町');
ok($zip->set_number('6308113')->is_valid_number, '奈良県奈良市法蓮町');
ok($zip->set_number('6308114')->is_valid_number, '奈良県奈良市芝辻町');
ok($zip->set_number('6308115')->is_valid_number, '奈良県奈良市大宮町');
ok($zip->set_number('6308121')->is_valid_number, '奈良県奈良市三条宮前町');
ok($zip->set_number('6308122')->is_valid_number, '奈良県奈良市三条本町');
ok($zip->set_number('6308123')->is_valid_number, '奈良県奈良市三条大宮町');
ok($zip->set_number('6308124')->is_valid_number, '奈良県奈良市三条桧町');
ok($zip->set_number('6308125')->is_valid_number, '奈良県奈良市三条川西町');
ok($zip->set_number('6308126')->is_valid_number, '奈良県奈良市三条栄町');
ok($zip->set_number('6308127')->is_valid_number, '奈良県奈良市三条添川町');
ok($zip->set_number('6308131')->is_valid_number, '奈良県奈良市大森町');
ok($zip->set_number('6308132')->is_valid_number, '奈良県奈良市大森西町');
ok($zip->set_number('6308133')->is_valid_number, '奈良県奈良市大安寺');
ok($zip->set_number('6308134')->is_valid_number, '奈良県奈良市大安寺町');
ok($zip->set_number('6308135')->is_valid_number, '奈良県奈良市大安寺西');
ok($zip->set_number('6308136')->is_valid_number, '奈良県奈良市恋の窪');
ok($zip->set_number('6308137')->is_valid_number, '奈良県奈良市恋の窪東町');
ok($zip->set_number('6308141')->is_valid_number, '奈良県奈良市南京終町');
ok($zip->set_number('6308142')->is_valid_number, '奈良県奈良市肘塚町');
ok($zip->set_number('6308143')->is_valid_number, '奈良県奈良市桂木町');
ok($zip->set_number('6308144')->is_valid_number, '奈良県奈良市東九条町');
ok($zip->set_number('6308145')->is_valid_number, '奈良県奈良市八条');
ok($zip->set_number('6308146')->is_valid_number, '奈良県奈良市八条町');
ok($zip->set_number('6308201')->is_valid_number, '奈良県奈良市中ノ川町(その他)');
ok($zip->set_number('6308202')->is_valid_number, '奈良県奈良市川上町');
ok($zip->set_number('6308203')->is_valid_number, '奈良県奈良市東之阪町');
ok($zip->set_number('6308204')->is_valid_number, '奈良県奈良市北御門町');
ok($zip->set_number('6308205')->is_valid_number, '奈良県奈良市今在家町');
ok($zip->set_number('6308206')->is_valid_number, '奈良県奈良市手貝町');
ok($zip->set_number('6308207')->is_valid_number, '奈良県奈良市今小路町');
ok($zip->set_number('6308208')->is_valid_number, '奈良県奈良市水門町');
ok($zip->set_number('6308211')->is_valid_number, '奈良県奈良市雑司町');
ok($zip->set_number('6308212')->is_valid_number, '奈良県奈良市春日野町');
ok($zip->set_number('6308213')->is_valid_number, '奈良県奈良市登大路町');
ok($zip->set_number('6308214')->is_valid_number, '奈良県奈良市東向北町');
ok($zip->set_number('6308215')->is_valid_number, '奈良県奈良市東向中町');
ok($zip->set_number('6308216')->is_valid_number, '奈良県奈良市東向南町');
ok($zip->set_number('6308217')->is_valid_number, '奈良県奈良市橋本町');
ok($zip->set_number('6308218')->is_valid_number, '奈良県奈良市樽井町');
ok($zip->set_number('6308221')->is_valid_number, '奈良県奈良市元林院町');
ok($zip->set_number('6308222')->is_valid_number, '奈良県奈良市餅飯殿町');
ok($zip->set_number('6308223')->is_valid_number, '奈良県奈良市角振新屋町');
ok($zip->set_number('6308224')->is_valid_number, '奈良県奈良市角振町');
ok($zip->set_number('6308225')->is_valid_number, '奈良県奈良市西御門町');
ok($zip->set_number('6308226')->is_valid_number, '奈良県奈良市小西町');
ok($zip->set_number('6308227')->is_valid_number, '奈良県奈良市林小路町');
ok($zip->set_number('6308228')->is_valid_number, '奈良県奈良市上三条町');
ok($zip->set_number('6308231')->is_valid_number, '奈良県奈良市本子守町');
ok($zip->set_number('6308232')->is_valid_number, '奈良県奈良市北向町');
ok($zip->set_number('6308233')->is_valid_number, '奈良県奈良市小川町');
ok($zip->set_number('6308234')->is_valid_number, '奈良県奈良市寺町');
ok($zip->set_number('6308235')->is_valid_number, '奈良県奈良市奥子守町');
ok($zip->set_number('6308236')->is_valid_number, '奈良県奈良市下三条町');
ok($zip->set_number('6308237')->is_valid_number, '奈良県奈良市中筋町');
ok($zip->set_number('6308238')->is_valid_number, '奈良県奈良市高天市町');
ok($zip->set_number('6308241')->is_valid_number, '奈良県奈良市高天町');
ok($zip->set_number('6308242')->is_valid_number, '奈良県奈良市漢国町');
ok($zip->set_number('6308243')->is_valid_number, '奈良県奈良市今辻子町');
ok($zip->set_number('6308244')->is_valid_number, '奈良県奈良市三条町');
ok($zip->set_number('6308245')->is_valid_number, '奈良県奈良市西之阪町');
ok($zip->set_number('6308246')->is_valid_number, '奈良県奈良市油阪地方町');
ok($zip->set_number('6308247')->is_valid_number, '奈良県奈良市油阪町');
ok($zip->set_number('6308248')->is_valid_number, '奈良県奈良市西新在家町');
ok($zip->set_number('6308251')->is_valid_number, '奈良県奈良市西新在家号所町');
ok($zip->set_number('6308252')->is_valid_number, '奈良県奈良市北小路町');
ok($zip->set_number('6308253')->is_valid_number, '奈良県奈良市内侍原町');
ok($zip->set_number('6308254')->is_valid_number, '奈良県奈良市菖蒲池町');
ok($zip->set_number('6308255')->is_valid_number, '奈良県奈良市阪新屋町');
ok($zip->set_number('6308256')->is_valid_number, '奈良県奈良市奥芝町');
ok($zip->set_number('6308257')->is_valid_number, '奈良県奈良市畑中町');
ok($zip->set_number('6308258')->is_valid_number, '奈良県奈良市船橋町');
ok($zip->set_number('6308261')->is_valid_number, '奈良県奈良市北市町');
ok($zip->set_number('6308262')->is_valid_number, '奈良県奈良市北袋町');
ok($zip->set_number('6308263')->is_valid_number, '奈良県奈良市北魚屋西町');
ok($zip->set_number('6308264')->is_valid_number, '奈良県奈良市鍋屋町');
ok($zip->set_number('6308265')->is_valid_number, '奈良県奈良市宿院町');
ok($zip->set_number('6308266')->is_valid_number, '奈良県奈良市花芝町');
ok($zip->set_number('6308267')->is_valid_number, '奈良県奈良市大豆山突抜町');
ok($zip->set_number('6308268')->is_valid_number, '奈良県奈良市大豆山町');
ok($zip->set_number('6308271')->is_valid_number, '奈良県奈良市坊屋敷町');
ok($zip->set_number('6308272')->is_valid_number, '奈良県奈良市東新在家町');
ok($zip->set_number('6308273')->is_valid_number, '奈良県奈良市押上町');
ok($zip->set_number('6308274')->is_valid_number, '奈良県奈良市北半田東町');
ok($zip->set_number('6308275')->is_valid_number, '奈良県奈良市北半田中町');
ok($zip->set_number('6308276')->is_valid_number, '奈良県奈良市北半田西町');
ok($zip->set_number('6308277')->is_valid_number, '奈良県奈良市南半田東町');
ok($zip->set_number('6308281')->is_valid_number, '奈良県奈良市南半田中町');
ok($zip->set_number('6308282')->is_valid_number, '奈良県奈良市南半田西町');
ok($zip->set_number('6308283')->is_valid_number, '奈良県奈良市油留木町');
ok($zip->set_number('6308284')->is_valid_number, '奈良県奈良市半田横町');
ok($zip->set_number('6308285')->is_valid_number, '奈良県奈良市北魚屋東町');
ok($zip->set_number('6308286')->is_valid_number, '奈良県奈良市東包永町');
ok($zip->set_number('6308287')->is_valid_number, '奈良県奈良市西包永町');
ok($zip->set_number('6308288')->is_valid_number, '奈良県奈良市東笹鉾町');
ok($zip->set_number('6308291')->is_valid_number, '奈良県奈良市西笹鉾町');
ok($zip->set_number('6308292')->is_valid_number, '奈良県奈良市中御門町');
ok($zip->set_number('6308293')->is_valid_number, '奈良県奈良市川久保町');
ok($zip->set_number('6308294')->is_valid_number, '奈良県奈良市押小路町');
ok($zip->set_number('6308295')->is_valid_number, '奈良県奈良市半田突抜町');
ok($zip->set_number('6308296')->is_valid_number, '奈良県奈良市後藤町');
ok($zip->set_number('6308297')->is_valid_number, '奈良県奈良市北川端町');
ok($zip->set_number('6308301')->is_valid_number, '奈良県奈良市高畑町');
ok($zip->set_number('6308302')->is_valid_number, '奈良県奈良市白毫寺町');
ok($zip->set_number('6308303')->is_valid_number, '奈良県奈良市南紀寺町');
ok($zip->set_number('6308304')->is_valid_number, '奈良県奈良市南肘塚町');
ok($zip->set_number('6308305')->is_valid_number, '奈良県奈良市東紀寺町');
ok($zip->set_number('6308306')->is_valid_number, '奈良県奈良市紀寺町');
ok($zip->set_number('6308307')->is_valid_number, '奈良県奈良市西紀寺町');
ok($zip->set_number('6308311')->is_valid_number, '奈良県奈良市十輪院畑町');
ok($zip->set_number('6308312')->is_valid_number, '奈良県奈良市十輪院町');
ok($zip->set_number('6308313')->is_valid_number, '奈良県奈良市川之上町');
ok($zip->set_number('6308314')->is_valid_number, '奈良県奈良市川之上突抜町');
ok($zip->set_number('6308315')->is_valid_number, '奈良県奈良市中辻町');
ok($zip->set_number('6308316')->is_valid_number, '奈良県奈良市築地之内町');
ok($zip->set_number('6308317')->is_valid_number, '奈良県奈良市井上町');
ok($zip->set_number('6308318')->is_valid_number, '奈良県奈良市納院町');
ok($zip->set_number('6308321')->is_valid_number, '奈良県奈良市薬師堂町');
ok($zip->set_number('6308322')->is_valid_number, '奈良県奈良市北京終町');
ok($zip->set_number('6308323')->is_valid_number, '奈良県奈良市京終地方東側町');
ok($zip->set_number('6308324')->is_valid_number, '奈良県奈良市京終地方西側町');
ok($zip->set_number('6308325')->is_valid_number, '奈良県奈良市西木辻町');
ok($zip->set_number('6308326')->is_valid_number, '奈良県奈良市瓦堂町');
ok($zip->set_number('6308327')->is_valid_number, '奈良県奈良市東木辻町');
ok($zip->set_number('6308328')->is_valid_number, '奈良県奈良市花園町');
ok($zip->set_number('6308331')->is_valid_number, '奈良県奈良市三棟町');
ok($zip->set_number('6308332')->is_valid_number, '奈良県奈良市元興寺町');
ok($zip->set_number('6308333')->is_valid_number, '奈良県奈良市中新屋町');
ok($zip->set_number('6308334')->is_valid_number, '奈良県奈良市西新屋町');
ok($zip->set_number('6308335')->is_valid_number, '奈良県奈良市鳴川町');
ok($zip->set_number('6308336')->is_valid_number, '奈良県奈良市高御門町');
ok($zip->set_number('6308337')->is_valid_number, '奈良県奈良市脇戸町');
ok($zip->set_number('6308338')->is_valid_number, '奈良県奈良市陰陽町');
ok($zip->set_number('6308341')->is_valid_number, '奈良県奈良市南城戸町');
ok($zip->set_number('6308342')->is_valid_number, '奈良県奈良市南袋町');
ok($zip->set_number('6308343')->is_valid_number, '奈良県奈良市椿井町');
ok($zip->set_number('6308344')->is_valid_number, '奈良県奈良市東城戸町');
ok($zip->set_number('6308345')->is_valid_number, '奈良県奈良市西城戸町');
ok($zip->set_number('6308346')->is_valid_number, '奈良県奈良市阿字万字町');
ok($zip->set_number('6308347')->is_valid_number, '奈良県奈良市南中町');
ok($zip->set_number('6308348')->is_valid_number, '奈良県奈良市小太郎町');
ok($zip->set_number('6308351')->is_valid_number, '奈良県奈良市南風呂町');
ok($zip->set_number('6308352')->is_valid_number, '奈良県奈良市北風呂町');
ok($zip->set_number('6308353')->is_valid_number, '奈良県奈良市柳町');
ok($zip->set_number('6308354')->is_valid_number, '奈良県奈良市馬場町');
ok($zip->set_number('6308355')->is_valid_number, '奈良県奈良市南魚屋町');
ok($zip->set_number('6308356')->is_valid_number, '奈良県奈良市南新町(1~32番地)');
ok($zip->set_number('6308357')->is_valid_number, '奈良県奈良市杉ヶ町');
ok($zip->set_number('6308361')->is_valid_number, '奈良県奈良市池之町');
ok($zip->set_number('6308362')->is_valid_number, '奈良県奈良市東寺林町');
ok($zip->set_number('6308363')->is_valid_number, '奈良県奈良市勝南院町');
ok($zip->set_number('6308364')->is_valid_number, '奈良県奈良市北室町');
ok($zip->set_number('6308365')->is_valid_number, '奈良県奈良市下御門町');
ok($zip->set_number('6308371')->is_valid_number, '奈良県奈良市光明院町');
ok($zip->set_number('6308372')->is_valid_number, '奈良県奈良市西寺林町');
ok($zip->set_number('6308373')->is_valid_number, '奈良県奈良市南市町');
ok($zip->set_number('6308374')->is_valid_number, '奈良県奈良市今御門町');
ok($zip->set_number('6308381')->is_valid_number, '奈良県奈良市福智院町');
ok($zip->set_number('6308382')->is_valid_number, '奈良県奈良市公納堂町');
ok($zip->set_number('6308383')->is_valid_number, '奈良県奈良市毘沙門町');
ok($zip->set_number('6308384')->is_valid_number, '奈良県奈良市芝新屋町');
ok($zip->set_number('6308385')->is_valid_number, '奈良県奈良市芝突抜町');
ok($zip->set_number('6308391')->is_valid_number, '奈良県奈良市鵲町');
ok($zip->set_number('6308392')->is_valid_number, '奈良県奈良市中院町');
ok($zip->set_number('6308393')->is_valid_number, '奈良県奈良市鶴福院町');
ok($zip->set_number('6308394')->is_valid_number, '奈良県奈良市不審ヶ辻子町');
ok($zip->set_number('6308401')->is_valid_number, '奈良県奈良市中畑町');
ok($zip->set_number('6308402')->is_valid_number, '奈良県奈良市米谷町');
ok($zip->set_number('6308403')->is_valid_number, '奈良県奈良市興隆寺町');
ok($zip->set_number('6308404')->is_valid_number, '奈良県奈良市南椿尾町');
ok($zip->set_number('6308405')->is_valid_number, '奈良県奈良市北椿尾町');
ok($zip->set_number('6308411')->is_valid_number, '奈良県奈良市高樋町');
ok($zip->set_number('6308412')->is_valid_number, '奈良県奈良市虚空蔵町');
ok($zip->set_number('6308413')->is_valid_number, '奈良県奈良市菩提山町(その他)');
ok($zip->set_number('6308414')->is_valid_number, '奈良県奈良市鉢伏町');
ok($zip->set_number('6308421')->is_valid_number, '奈良県奈良市藤原町');
ok($zip->set_number('6308422')->is_valid_number, '奈良県奈良市横井');
ok($zip->set_number('6308422')->is_valid_number, '奈良県奈良市横井町');
ok($zip->set_number('6308423')->is_valid_number, '奈良県奈良市出屋敷町');
ok($zip->set_number('6308424')->is_valid_number, '奈良県奈良市古市町');
ok($zip->set_number('6308425')->is_valid_number, '奈良県奈良市鹿野園町');
ok($zip->set_number('6308431')->is_valid_number, '奈良県奈良市窪之庄町');
ok($zip->set_number('6308432')->is_valid_number, '奈良県奈良市田中町');
ok($zip->set_number('6308433')->is_valid_number, '奈良県奈良市柴屋町');
ok($zip->set_number('6308434')->is_valid_number, '奈良県奈良市山町');
ok($zip->set_number('6308435')->is_valid_number, '奈良県奈良市八島町');
ok($zip->set_number('6308441')->is_valid_number, '奈良県奈良市神殿町');
ok($zip->set_number('6308442')->is_valid_number, '奈良県奈良市北永井町');
ok($zip->set_number('6308443')->is_valid_number, '奈良県奈良市南永井町');
ok($zip->set_number('6308444')->is_valid_number, '奈良県奈良市今市町');
ok($zip->set_number('6308445')->is_valid_number, '奈良県奈良市池田町');
ok($zip->set_number('6308451')->is_valid_number, '奈良県奈良市北之庄町');
ok($zip->set_number('6308452')->is_valid_number, '奈良県奈良市北之庄西町');
ok($zip->set_number('6308453')->is_valid_number, '奈良県奈良市西九条町');
ok($zip->set_number('6308454')->is_valid_number, '奈良県奈良市杏町');
ok($zip->set_number('6310001')->is_valid_number, '奈良県奈良市北登美ヶ丘');
ok($zip->set_number('6310002')->is_valid_number, '奈良県奈良市東登美ヶ丘');
ok($zip->set_number('6310003')->is_valid_number, '奈良県奈良市中登美ヶ丘');
ok($zip->set_number('6310004')->is_valid_number, '奈良県奈良市登美ヶ丘');
ok($zip->set_number('6310005')->is_valid_number, '奈良県奈良市大渕町');
ok($zip->set_number('6310006')->is_valid_number, '奈良県奈良市西登美ヶ丘');
ok($zip->set_number('6310007')->is_valid_number, '奈良県奈良市松陽台');
ok($zip->set_number('6310008')->is_valid_number, '奈良県奈良市二名町');
ok($zip->set_number('6310011')->is_valid_number, '奈良県奈良市押熊町');
ok($zip->set_number('6310012')->is_valid_number, '奈良県奈良市中山町');
ok($zip->set_number('6310013')->is_valid_number, '奈良県奈良市中山町西');
ok($zip->set_number('6310014')->is_valid_number, '奈良県奈良市朝日町');
ok($zip->set_number('6310015')->is_valid_number, '奈良県奈良市学園朝日元町');
ok($zip->set_number('6310016')->is_valid_number, '奈良県奈良市学園朝日町');
ok($zip->set_number('6310021')->is_valid_number, '奈良県奈良市鶴舞東町');
ok($zip->set_number('6310022')->is_valid_number, '奈良県奈良市鶴舞西町');
ok($zip->set_number('6310023')->is_valid_number, '奈良県奈良市南登美ヶ丘');
ok($zip->set_number('6310024')->is_valid_number, '奈良県奈良市百楽園');
ok($zip->set_number('6310025')->is_valid_number, '奈良県奈良市学園新田町');
ok($zip->set_number('6310026')->is_valid_number, '奈良県奈良市学園緑ヶ丘');
ok($zip->set_number('6310027')->is_valid_number, '奈良県奈良市学園赤松町');
ok($zip->set_number('6310031')->is_valid_number, '奈良県奈良市敷島町');
ok($zip->set_number('6310032')->is_valid_number, '奈良県奈良市あやめ池北');
ok($zip->set_number('6310033')->is_valid_number, '奈良県奈良市あやめ池南');
ok($zip->set_number('6310034')->is_valid_number, '奈良県奈良市学園南');
ok($zip->set_number('6310035')->is_valid_number, '奈良県奈良市学園中');
ok($zip->set_number('6310036')->is_valid_number, '奈良県奈良市学園北');
ok($zip->set_number('6310041')->is_valid_number, '奈良県奈良市学園大和町');
ok($zip->set_number('6310042')->is_valid_number, '奈良県奈良市大倭町');
ok($zip->set_number('6310043')->is_valid_number, '奈良県奈良市菅野台');
ok($zip->set_number('6310044')->is_valid_number, '奈良県奈良市藤ノ木台');
ok($zip->set_number('6310045')->is_valid_number, '奈良県奈良市千代ヶ丘');
ok($zip->set_number('6310046')->is_valid_number, '奈良県奈良市西千代ヶ丘');
ok($zip->set_number('6310051')->is_valid_number, '奈良県奈良市富雄泉ヶ丘');
ok($zip->set_number('6310052')->is_valid_number, '奈良県奈良市中町(その他)');
ok($zip->set_number('6310053')->is_valid_number, '奈良県奈良市青垣台');
ok($zip->set_number('6310054')->is_valid_number, '奈良県奈良市石木町');
ok($zip->set_number('6310055')->is_valid_number, '奈良県奈良市大和田町');
ok($zip->set_number('6310056')->is_valid_number, '奈良県奈良市丸山');
ok($zip->set_number('6310061')->is_valid_number, '奈良県奈良市三碓');
ok($zip->set_number('6310061')->is_valid_number, '奈良県奈良市三碓町');
ok($zip->set_number('6310062')->is_valid_number, '奈良県奈良市帝塚山');
ok($zip->set_number('6310063')->is_valid_number, '奈良県奈良市帝塚山中町');
ok($zip->set_number('6310064')->is_valid_number, '奈良県奈良市帝塚山南');
ok($zip->set_number('6310065')->is_valid_number, '奈良県奈良市鳥見町');
ok($zip->set_number('6310066')->is_valid_number, '奈良県奈良市帝塚山西');
ok($zip->set_number('6310071')->is_valid_number, '奈良県奈良市二名平野');
ok($zip->set_number('6310072')->is_valid_number, '奈良県奈良市二名');
ok($zip->set_number('6310073')->is_valid_number, '奈良県奈良市二名東町');
ok($zip->set_number('6310074')->is_valid_number, '奈良県奈良市三松');
ok($zip->set_number('6310075')->is_valid_number, '奈良県奈良市三松ヶ丘');
ok($zip->set_number('6310076')->is_valid_number, '奈良県奈良市富雄北');
ok($zip->set_number('6310077')->is_valid_number, '奈良県奈良市富雄川西');
ok($zip->set_number('6310078')->is_valid_number, '奈良県奈良市富雄元町');
ok($zip->set_number('6310801')->is_valid_number, '奈良県奈良市左京');
ok($zip->set_number('6310802')->is_valid_number, '奈良県奈良市歌姫町');
ok($zip->set_number('6310803')->is_valid_number, '奈良県奈良市山陵町');
ok($zip->set_number('6310804')->is_valid_number, '奈良県奈良市神功');
ok($zip->set_number('6310805')->is_valid_number, '奈良県奈良市右京');
ok($zip->set_number('6310806')->is_valid_number, '奈良県奈良市朱雀');
ok($zip->set_number('6310811')->is_valid_number, '奈良県奈良市秋篠町');
ok($zip->set_number('6310812')->is_valid_number, '奈良県奈良市秋篠早月町');
ok($zip->set_number('6310813')->is_valid_number, '奈良県奈良市秋篠新町');
ok($zip->set_number('6310814')->is_valid_number, '奈良県奈良市秋篠三和町');
ok($zip->set_number('6310815')->is_valid_number, '奈良県奈良市西大寺新町');
ok($zip->set_number('6310816')->is_valid_number, '奈良県奈良市西大寺本町');
ok($zip->set_number('6310817')->is_valid_number, '奈良県奈良市西大寺北町');
ok($zip->set_number('6310818')->is_valid_number, '奈良県奈良市西大寺赤田町');
ok($zip->set_number('6310821')->is_valid_number, '奈良県奈良市西大寺東町');
ok($zip->set_number('6310822')->is_valid_number, '奈良県奈良市西大寺栄町');
ok($zip->set_number('6310823')->is_valid_number, '奈良県奈良市西大寺国見町');
ok($zip->set_number('6310824')->is_valid_number, '奈良県奈良市西大寺南町');
ok($zip->set_number('6310825')->is_valid_number, '奈良県奈良市西大寺芝町');
ok($zip->set_number('6310826')->is_valid_number, '奈良県奈良市西大寺町');
ok($zip->set_number('6310827')->is_valid_number, '奈良県奈良市西大寺小坊町');
ok($zip->set_number('6310831')->is_valid_number, '奈良県奈良市西大寺宝ヶ丘');
ok($zip->set_number('6310832')->is_valid_number, '奈良県奈良市西大寺新田町');
ok($zip->set_number('6310833')->is_valid_number, '奈良県奈良市西大寺野神町');
ok($zip->set_number('6310834')->is_valid_number, '奈良県奈良市西大寺新池町');
ok($zip->set_number('6310835')->is_valid_number, '奈良県奈良市西大寺高塚町');
ok($zip->set_number('6310836')->is_valid_number, '奈良県奈良市西大寺竜王町');
ok($zip->set_number('6310837')->is_valid_number, '奈良県奈良市若葉台');
ok($zip->set_number('6310841')->is_valid_number, '奈良県奈良市青野町');
ok($zip->set_number('6310842')->is_valid_number, '奈良県奈良市菅原町');
ok($zip->set_number('6310842')->is_valid_number, '奈良県奈良市菅原東');
ok($zip->set_number('6310843')->is_valid_number, '奈良県奈良市疋田町');
ok($zip->set_number('6310844')->is_valid_number, '奈良県奈良市宝来町');
ok($zip->set_number('6310845')->is_valid_number, '奈良県奈良市宝来');
ok($zip->set_number('6310846')->is_valid_number, '奈良県奈良市平松');
ok($zip->set_number('6320000')->is_valid_number, '奈良県天理市以下に掲載がない場合');
ok($zip->set_number('6320001')->is_valid_number, '奈良県天理市中之庄町');
ok($zip->set_number('6320002')->is_valid_number, '奈良県天理市和爾町');
ok($zip->set_number('6320003')->is_valid_number, '奈良県天理市岩屋町');
ok($zip->set_number('6320004')->is_valid_number, '奈良県天理市櫟本町');
ok($zip->set_number('6320005')->is_valid_number, '奈良県天理市楢町');
ok($zip->set_number('6320006')->is_valid_number, '奈良県天理市蔵之庄町');
ok($zip->set_number('6320007')->is_valid_number, '奈良県天理市森本町');
ok($zip->set_number('6320011')->is_valid_number, '奈良県天理市石上町');
ok($zip->set_number('6320012')->is_valid_number, '奈良県天理市豊田町');
ok($zip->set_number('6320013')->is_valid_number, '奈良県天理市豊井町');
ok($zip->set_number('6320014')->is_valid_number, '奈良県天理市布留町');
ok($zip->set_number('6320015')->is_valid_number, '奈良県天理市三島町');
ok($zip->set_number('6320016')->is_valid_number, '奈良県天理市川原城町');
ok($zip->set_number('6320017')->is_valid_number, '奈良県天理市田部町');
ok($zip->set_number('6320018')->is_valid_number, '奈良県天理市別所町');
ok($zip->set_number('6320021')->is_valid_number, '奈良県天理市滝本町');
ok($zip->set_number('6320022')->is_valid_number, '奈良県天理市苣原町');
ok($zip->set_number('6320023')->is_valid_number, '奈良県天理市下仁興町');
ok($zip->set_number('6320024')->is_valid_number, '奈良県天理市上仁興町');
ok($zip->set_number('6320025')->is_valid_number, '奈良県天理市藤井町');
ok($zip->set_number('6320031')->is_valid_number, '奈良県天理市内馬場町');
ok($zip->set_number('6320032')->is_valid_number, '奈良県天理市杣之内町');
ok($zip->set_number('6320033')->is_valid_number, '奈良県天理市勾田町');
ok($zip->set_number('6320034')->is_valid_number, '奈良県天理市丹波市町');
ok($zip->set_number('6320035')->is_valid_number, '奈良県天理市守目堂町');
ok($zip->set_number('6320036')->is_valid_number, '奈良県天理市御経野町');
ok($zip->set_number('6320041')->is_valid_number, '奈良県天理市竹之内町');
ok($zip->set_number('6320042')->is_valid_number, '奈良県天理市萱生町');
ok($zip->set_number('6320043')->is_valid_number, '奈良県天理市佐保庄町');
ok($zip->set_number('6320044')->is_valid_number, '奈良県天理市兵庫町');
ok($zip->set_number('6320045')->is_valid_number, '奈良県天理市福知堂町');
ok($zip->set_number('6320046')->is_valid_number, '奈良県天理市三昧田町');
ok($zip->set_number('6320047')->is_valid_number, '奈良県天理市乙木町');
ok($zip->set_number('6320048')->is_valid_number, '奈良県天理市園原町');
ok($zip->set_number('6320051')->is_valid_number, '奈良県天理市中山町');
ok($zip->set_number('6320052')->is_valid_number, '奈良県天理市柳本町');
ok($zip->set_number('6320053')->is_valid_number, '奈良県天理市渋谷町');
ok($zip->set_number('6320054')->is_valid_number, '奈良県天理市檜垣町');
ok($zip->set_number('6320055')->is_valid_number, '奈良県天理市遠田町');
ok($zip->set_number('6320056')->is_valid_number, '奈良県天理市岸田町');
ok($zip->set_number('6320057')->is_valid_number, '奈良県天理市新泉町');
ok($zip->set_number('6320058')->is_valid_number, '奈良県天理市成願寺町');
ok($zip->set_number('6320061')->is_valid_number, '奈良県天理市永原町');
ok($zip->set_number('6320062')->is_valid_number, '奈良県天理市長柄町');
ok($zip->set_number('6320063')->is_valid_number, '奈良県天理市西長柄町');
ok($zip->set_number('6320064')->is_valid_number, '奈良県天理市海知町');
ok($zip->set_number('6320065')->is_valid_number, '奈良県天理市武蔵町');
ok($zip->set_number('6320066')->is_valid_number, '奈良県天理市備前町');
ok($zip->set_number('6320067')->is_valid_number, '奈良県天理市吉田町');
ok($zip->set_number('6320068')->is_valid_number, '奈良県天理市合場町');
ok($zip->set_number('6320069')->is_valid_number, '奈良県天理市九条町');
ok($zip->set_number('6320071')->is_valid_number, '奈良県天理市田井庄町');
ok($zip->set_number('6320072')->is_valid_number, '奈良県天理市富堂町');
ok($zip->set_number('6320073')->is_valid_number, '奈良県天理市田町');
ok($zip->set_number('6320074')->is_valid_number, '奈良県天理市東井戸堂町');
ok($zip->set_number('6320075')->is_valid_number, '奈良県天理市西井戸堂町');
ok($zip->set_number('6320076')->is_valid_number, '奈良県天理市岩室町');
ok($zip->set_number('6320077')->is_valid_number, '奈良県天理市平等坊町');
ok($zip->set_number('6320078')->is_valid_number, '奈良県天理市杉本町');
ok($zip->set_number('6320081')->is_valid_number, '奈良県天理市二階堂上ノ庄町');
ok($zip->set_number('6320082')->is_valid_number, '奈良県天理市荒蒔町');
ok($zip->set_number('6320083')->is_valid_number, '奈良県天理市稲葉町');
ok($zip->set_number('6320084')->is_valid_number, '奈良県天理市嘉幡町');
ok($zip->set_number('6320085')->is_valid_number, '奈良県天理市小島町');
ok($zip->set_number('6320086')->is_valid_number, '奈良県天理市庵治町');
ok($zip->set_number('6320087')->is_valid_number, '奈良県天理市二階堂南菅田町');
ok($zip->set_number('6320088')->is_valid_number, '奈良県天理市二階堂北菅田町');
ok($zip->set_number('6320091')->is_valid_number, '奈良県天理市上総町');
ok($zip->set_number('6320092')->is_valid_number, '奈良県天理市小田中町');
ok($zip->set_number('6320093')->is_valid_number, '奈良県天理市指柳町');
ok($zip->set_number('6320094')->is_valid_number, '奈良県天理市前栽町');
ok($zip->set_number('6320095')->is_valid_number, '奈良県天理市喜殿町');
ok($zip->set_number('6320096')->is_valid_number, '奈良県天理市小路町');
ok($zip->set_number('6320097')->is_valid_number, '奈良県天理市中町');
ok($zip->set_number('6320098')->is_valid_number, '奈良県天理市南六条町');
ok($zip->set_number('6320101')->is_valid_number, '奈良県奈良市下深川町');
ok($zip->set_number('6320102')->is_valid_number, '奈良県奈良市上深川町');
ok($zip->set_number('6320103')->is_valid_number, '奈良県奈良市荻町');
ok($zip->set_number('6320111')->is_valid_number, '奈良県奈良市小倉町');
ok($zip->set_number('6320112')->is_valid_number, '奈良県奈良市針ヶ別所町');
ok($zip->set_number('6320113')->is_valid_number, '奈良県奈良市都祁馬場町');
ok($zip->set_number('6320121')->is_valid_number, '奈良県天理市山田町');
ok($zip->set_number('6320122')->is_valid_number, '奈良県天理市福住町');
ok($zip->set_number('6320123')->is_valid_number, '奈良県天理市長滝町');
ok($zip->set_number('6320201')->is_valid_number, '奈良県宇陀市室生下笠間');
ok($zip->set_number('6320202')->is_valid_number, '奈良県宇陀市室生上笠間');
ok($zip->set_number('6320203')->is_valid_number, '奈良県宇陀市室生深野');
ok($zip->set_number('6320204')->is_valid_number, '奈良県宇陀市室生小原');
ok($zip->set_number('6320205')->is_valid_number, '奈良県宇陀市室生染田');
ok($zip->set_number('6320206')->is_valid_number, '奈良県宇陀市室生多田');
ok($zip->set_number('6320207')->is_valid_number, '奈良県宇陀市室生無山');
ok($zip->set_number('6320221')->is_valid_number, '奈良県奈良市都祁白石町');
ok($zip->set_number('6320231')->is_valid_number, '奈良県奈良市都祁吐山町');
ok($zip->set_number('6320232')->is_valid_number, '奈良県奈良市都祁こぶしが丘');
ok($zip->set_number('6320241')->is_valid_number, '奈良県奈良市都祁南之庄町');
ok($zip->set_number('6320242')->is_valid_number, '奈良県奈良市都祁相河町');
ok($zip->set_number('6320243')->is_valid_number, '奈良県奈良市都祁小山戸町');
ok($zip->set_number('6320244')->is_valid_number, '奈良県奈良市来迎寺町');
ok($zip->set_number('6320245')->is_valid_number, '奈良県奈良市藺生町');
ok($zip->set_number('6320246')->is_valid_number, '奈良県奈良市都祁友田町');
ok($zip->set_number('6320247')->is_valid_number, '奈良県奈良市都祁甲岡町');
ok($zip->set_number('6320251')->is_valid_number, '奈良県奈良市針町');
ok($zip->set_number('6330000')->is_valid_number, '奈良県桜井市以下に掲載がない場合');
ok($zip->set_number('6330001')->is_valid_number, '奈良県桜井市三輪');
ok($zip->set_number('6330002')->is_valid_number, '奈良県桜井市金屋');
ok($zip->set_number('6330003')->is_valid_number, '奈良県桜井市朝倉台東');
ok($zip->set_number('6330004')->is_valid_number, '奈良県桜井市朝倉台西');
ok($zip->set_number('6330005')->is_valid_number, '奈良県桜井市忍阪');
ok($zip->set_number('6330006')->is_valid_number, '奈良県桜井市赤尾');
ok($zip->set_number('6330007')->is_valid_number, '奈良県桜井市外山');
ok($zip->set_number('6330011')->is_valid_number, '奈良県桜井市黒崎');
ok($zip->set_number('6330012')->is_valid_number, '奈良県桜井市狛');
ok($zip->set_number('6330013')->is_valid_number, '奈良県桜井市岩坂');
ok($zip->set_number('6330014')->is_valid_number, '奈良県桜井市粟原');
ok($zip->set_number('6330015')->is_valid_number, '奈良県桜井市下り尾');
ok($zip->set_number('6330016')->is_valid_number, '奈良県桜井市竜谷');
ok($zip->set_number('6330017')->is_valid_number, '奈良県桜井市慈恩寺');
ok($zip->set_number('6330018')->is_valid_number, '奈良県桜井市脇本');
ok($zip->set_number('6330021')->is_valid_number, '奈良県桜井市倉橋');
ok($zip->set_number('6330022')->is_valid_number, '奈良県桜井市北音羽');
ok($zip->set_number('6330023')->is_valid_number, '奈良県桜井市南音羽');
ok($zip->set_number('6330024')->is_valid_number, '奈良県桜井市針道');
ok($zip->set_number('6330025')->is_valid_number, '奈良県桜井市八井内');
ok($zip->set_number('6330026')->is_valid_number, '奈良県桜井市飯盛塚');
ok($zip->set_number('6330027')->is_valid_number, '奈良県桜井市鹿路');
ok($zip->set_number('6330028')->is_valid_number, '奈良県桜井市百市');
ok($zip->set_number('6330031')->is_valid_number, '奈良県桜井市下居');
ok($zip->set_number('6330032')->is_valid_number, '奈良県桜井市多武峰');
ok($zip->set_number('6330033')->is_valid_number, '奈良県桜井市西口');
ok($zip->set_number('6330034')->is_valid_number, '奈良県桜井市北山');
ok($zip->set_number('6330035')->is_valid_number, '奈良県桜井市今井谷');
ok($zip->set_number('6330036')->is_valid_number, '奈良県桜井市横柿');
ok($zip->set_number('6330041')->is_valid_number, '奈良県桜井市上之宮');
ok($zip->set_number('6330042')->is_valid_number, '奈良県桜井市下');
ok($zip->set_number('6330043')->is_valid_number, '奈良県桜井市高田');
ok($zip->set_number('6330044')->is_valid_number, '奈良県桜井市高家');
ok($zip->set_number('6330045')->is_valid_number, '奈良県桜井市山田');
ok($zip->set_number('6330046')->is_valid_number, '奈良県桜井市池之内');
ok($zip->set_number('6330047')->is_valid_number, '奈良県桜井市橋本');
ok($zip->set_number('6330048')->is_valid_number, '奈良県桜井市生田');
ok($zip->set_number('6330051')->is_valid_number, '奈良県桜井市河西');
ok($zip->set_number('6330052')->is_valid_number, '奈良県桜井市浅古');
ok($zip->set_number('6330053')->is_valid_number, '奈良県桜井市谷');
ok($zip->set_number('6330054')->is_valid_number, '奈良県桜井市阿部');
ok($zip->set_number('6330055')->is_valid_number, '奈良県桜井市安倍木材団地');
ok($zip->set_number('6330061')->is_valid_number, '奈良県桜井市上之庄');
ok($zip->set_number('6330062')->is_valid_number, '奈良県桜井市粟殿');
ok($zip->set_number('6330063')->is_valid_number, '奈良県桜井市川合');
ok($zip->set_number('6330064')->is_valid_number, '奈良県桜井市戒重');
ok($zip->set_number('6330065')->is_valid_number, '奈良県桜井市吉備');
ok($zip->set_number('6330066')->is_valid_number, '奈良県桜井市西之宮');
ok($zip->set_number('6330067')->is_valid_number, '奈良県桜井市大福');
ok($zip->set_number('6330068')->is_valid_number, '奈良県桜井市東新堂');
ok($zip->set_number('6330071')->is_valid_number, '奈良県桜井市穴師');
ok($zip->set_number('6330072')->is_valid_number, '奈良県桜井市箸中');
ok($zip->set_number('6330073')->is_valid_number, '奈良県桜井市茅原');
ok($zip->set_number('6330074')->is_valid_number, '奈良県桜井市芝');
ok($zip->set_number('6330075')->is_valid_number, '奈良県桜井市新屋敷');
ok($zip->set_number('6330076')->is_valid_number, '奈良県桜井市大泉');
ok($zip->set_number('6330077')->is_valid_number, '奈良県桜井市大西');
ok($zip->set_number('6330078')->is_valid_number, '奈良県桜井市豊前');
ok($zip->set_number('6330079')->is_valid_number, '奈良県桜井市豊田');
ok($zip->set_number('6330081')->is_valid_number, '奈良県桜井市草川');
ok($zip->set_number('6330082')->is_valid_number, '奈良県桜井市巻野内');
ok($zip->set_number('6330083')->is_valid_number, '奈良県桜井市辻');
ok($zip->set_number('6330084')->is_valid_number, '奈良県桜井市太田');
ok($zip->set_number('6330085')->is_valid_number, '奈良県桜井市東田');
ok($zip->set_number('6330086')->is_valid_number, '奈良県桜井市江包');
ok($zip->set_number('6330087')->is_valid_number, '奈良県桜井市大豆越');
ok($zip->set_number('6330091')->is_valid_number, '奈良県桜井市桜井');
ok($zip->set_number('6330101')->is_valid_number, '奈良県桜井市小夫');
ok($zip->set_number('6330102')->is_valid_number, '奈良県桜井市三谷');
ok($zip->set_number('6330103')->is_valid_number, '奈良県桜井市小夫嵩方');
ok($zip->set_number('6330104')->is_valid_number, '奈良県桜井市芹井');
ok($zip->set_number('6330105')->is_valid_number, '奈良県桜井市白木');
ok($zip->set_number('6330106')->is_valid_number, '奈良県桜井市萱森');
ok($zip->set_number('6330107')->is_valid_number, '奈良県桜井市中谷');
ok($zip->set_number('6330108')->is_valid_number, '奈良県桜井市滝倉');
ok($zip->set_number('6330111')->is_valid_number, '奈良県桜井市吉隠');
ok($zip->set_number('6330112')->is_valid_number, '奈良県桜井市初瀬');
ok($zip->set_number('6330121')->is_valid_number, '奈良県桜井市白河');
ok($zip->set_number('6330122')->is_valid_number, '奈良県桜井市出雲');
ok($zip->set_number('6330131')->is_valid_number, '奈良県桜井市修理枝');
ok($zip->set_number('6330132')->is_valid_number, '奈良県桜井市和田');
ok($zip->set_number('6330133')->is_valid_number, '奈良県桜井市笠');
ok($zip->set_number('6330200')->is_valid_number, '奈良県宇陀市以下に掲載がない場合');
ok($zip->set_number('6330201')->is_valid_number, '奈良県宇陀市榛原戒場');
ok($zip->set_number('6330202')->is_valid_number, '奈良県宇陀市榛原山辺三');
ok($zip->set_number('6330203')->is_valid_number, '奈良県宇陀市榛原長峯');
ok($zip->set_number('6330204')->is_valid_number, '奈良県宇陀市榛原福地');
ok($zip->set_number('6330205')->is_valid_number, '奈良県宇陀市榛原天満台東');
ok($zip->set_number('6330206')->is_valid_number, '奈良県宇陀市榛原天満台西');
ok($zip->set_number('6330207')->is_valid_number, '奈良県宇陀市榛原赤瀬');
ok($zip->set_number('6330208')->is_valid_number, '奈良県宇陀市榛原額井');
ok($zip->set_number('6330211')->is_valid_number, '奈良県宇陀市榛原荷阪');
ok($zip->set_number('6330212')->is_valid_number, '奈良県宇陀市榛原高井');
ok($zip->set_number('6330213')->is_valid_number, '奈良県宇陀市榛原赤埴');
ok($zip->set_number('6330214')->is_valid_number, '奈良県宇陀市榛原諸木野');
ok($zip->set_number('6330215')->is_valid_number, '奈良県宇陀市榛原内牧');
ok($zip->set_number('6330216')->is_valid_number, '奈良県宇陀市榛原八滝');
ok($zip->set_number('6330217')->is_valid_number, '奈良県宇陀市榛原自明');
ok($zip->set_number('6330218')->is_valid_number, '奈良県宇陀市榛原檜牧');
ok($zip->set_number('6330221')->is_valid_number, '奈良県宇陀市榛原萩乃里');
ok($zip->set_number('6330222')->is_valid_number, '奈良県宇陀市榛原上井足');
ok($zip->set_number('6330223')->is_valid_number, '奈良県宇陀市榛原石田');
ok($zip->set_number('6330224')->is_valid_number, '奈良県宇陀市榛原山路');
ok($zip->set_number('6330225')->is_valid_number, '奈良県宇陀市榛原大貝');
ok($zip->set_number('6330226')->is_valid_number, '奈良県宇陀市榛原澤');
ok($zip->set_number('6330227')->is_valid_number, '奈良県宇陀市榛原三宮寺');
ok($zip->set_number('6330228')->is_valid_number, '奈良県宇陀市榛原栗谷');
ok($zip->set_number('6330231')->is_valid_number, '奈良県宇陀市榛原足立');
ok($zip->set_number('6330232')->is_valid_number, '奈良県宇陀市榛原池上');
ok($zip->set_number('6330233')->is_valid_number, '奈良県宇陀市榛原福西');
ok($zip->set_number('6330234')->is_valid_number, '奈良県宇陀市榛原高塚');
ok($zip->set_number('6330235')->is_valid_number, '奈良県宇陀市榛原比布');
ok($zip->set_number('6330236')->is_valid_number, '奈良県宇陀市榛原母里');
ok($zip->set_number('6330241')->is_valid_number, '奈良県宇陀市榛原下井足');
ok($zip->set_number('6330242')->is_valid_number, '奈良県宇陀市榛原篠楽');
ok($zip->set_number('6330243')->is_valid_number, '奈良県宇陀市榛原雨師');
ok($zip->set_number('6330244')->is_valid_number, '奈良県宇陀市榛原安田');
ok($zip->set_number('6330245')->is_valid_number, '奈良県宇陀市榛原笠間');
ok($zip->set_number('6330246')->is_valid_number, '奈良県宇陀市榛原柳');
ok($zip->set_number('6330251')->is_valid_number, '奈良県宇陀市榛原ひのき坂');
ok($zip->set_number('6330252')->is_valid_number, '奈良県宇陀市榛原桜が丘');
ok($zip->set_number('6330253')->is_valid_number, '奈良県宇陀市榛原萩原');
ok($zip->set_number('6330254')->is_valid_number, '奈良県宇陀市榛原高萩台');
ok($zip->set_number('6330255')->is_valid_number, '奈良県宇陀市榛原角柄');
ok($zip->set_number('6330256')->is_valid_number, '奈良県宇陀市榛原あかね台');
ok($zip->set_number('6330257')->is_valid_number, '奈良県宇陀市榛原榛見が丘');
ok($zip->set_number('6330311')->is_valid_number, '奈良県宇陀市室生龍口');
ok($zip->set_number('6330312')->is_valid_number, '奈良県宇陀市室生西谷');
ok($zip->set_number('6330313')->is_valid_number, '奈良県宇陀市室生瀧谷');
ok($zip->set_number('6330314')->is_valid_number, '奈良県宇陀市室生砥取');
ok($zip->set_number('6330315')->is_valid_number, '奈良県宇陀市室生大野');
ok($zip->set_number('6330316')->is_valid_number, '奈良県宇陀市室生向渕');
ok($zip->set_number('6330317')->is_valid_number, '奈良県宇陀市室生三本松');
ok($zip->set_number('6330421')->is_valid_number, '奈良県宇陀市室生');
ok($zip->set_number('6330422')->is_valid_number, '奈良県宇陀市室生下田口');
ok($zip->set_number('6330423')->is_valid_number, '奈良県宇陀市室生田口元角川');
ok($zip->set_number('6330424')->is_valid_number, '奈良県宇陀市室生田口元上田口');
ok($zip->set_number('6330425')->is_valid_number, '奈良県宇陀市室生黒岩');
ok($zip->set_number('6331200')->is_valid_number, '奈良県宇陀郡曽爾村以下に掲載がない場合');
ok($zip->set_number('6331201')->is_valid_number, '奈良県宇陀郡曽爾村伊賀見');
ok($zip->set_number('6331202')->is_valid_number, '奈良県宇陀郡曽爾村太良路');
ok($zip->set_number('6331203')->is_valid_number, '奈良県宇陀郡曽爾村葛');
ok($zip->set_number('6331211')->is_valid_number, '奈良県宇陀郡曽爾村塩井');
ok($zip->set_number('6331212')->is_valid_number, '奈良県宇陀郡曽爾村今井');
ok($zip->set_number('6331213')->is_valid_number, '奈良県宇陀郡曽爾村小長尾');
ok($zip->set_number('6331214')->is_valid_number, '奈良県宇陀郡曽爾村長野');
ok($zip->set_number('6331215')->is_valid_number, '奈良県宇陀郡曽爾村掛');
ok($zip->set_number('6331216')->is_valid_number, '奈良県宇陀郡曽爾村山粕');
ok($zip->set_number('6331300')->is_valid_number, '奈良県宇陀郡御杖村以下に掲載がない場合');
ok($zip->set_number('6331301')->is_valid_number, '奈良県宇陀郡御杖村神末');
ok($zip->set_number('6331302')->is_valid_number, '奈良県宇陀郡御杖村菅野');
ok($zip->set_number('6331303')->is_valid_number, '奈良県宇陀郡御杖村土屋原');
ok($zip->set_number('6331304')->is_valid_number, '奈良県宇陀郡御杖村桃俣');
ok($zip->set_number('6332101')->is_valid_number, '奈良県宇陀市大宇陀五津');
ok($zip->set_number('6332102')->is_valid_number, '奈良県宇陀市大宇陀平尾');
ok($zip->set_number('6332103')->is_valid_number, '奈良県宇陀市大宇陀野依');
ok($zip->set_number('6332104')->is_valid_number, '奈良県宇陀市大宇陀口今井');
ok($zip->set_number('6332105')->is_valid_number, '奈良県宇陀市大宇陀麻生田');
ok($zip->set_number('6332106')->is_valid_number, '奈良県宇陀市大宇陀馬取柿');
ok($zip->set_number('6332107')->is_valid_number, '奈良県宇陀市大宇陀嬉河原');
ok($zip->set_number('6332108')->is_valid_number, '奈良県宇陀市大宇陀半阪');
ok($zip->set_number('6332111')->is_valid_number, '奈良県宇陀市大宇陀内原');
ok($zip->set_number('6332112')->is_valid_number, '奈良県宇陀市大宇陀小附');
ok($zip->set_number('6332113')->is_valid_number, '奈良県宇陀市大宇陀下竹');
ok($zip->set_number('6332114')->is_valid_number, '奈良県宇陀市大宇陀春日');
ok($zip->set_number('6332115')->is_valid_number, '奈良県宇陀市大宇陀西山');
ok($zip->set_number('6332116')->is_valid_number, '奈良県宇陀市大宇陀岩室');
ok($zip->set_number('6332117')->is_valid_number, '奈良県宇陀市大宇陀芝生');
ok($zip->set_number('6332121')->is_valid_number, '奈良県宇陀市大宇陀塚脇');
ok($zip->set_number('6332122')->is_valid_number, '奈良県宇陀市大宇陀調子');
ok($zip->set_number('6332123')->is_valid_number, '奈良県宇陀市大宇陀藤井');
ok($zip->set_number('6332124')->is_valid_number, '奈良県宇陀市大宇陀才ケ辻');
ok($zip->set_number('6332125')->is_valid_number, '奈良県宇陀市大宇陀守道');
ok($zip->set_number('6332126')->is_valid_number, '奈良県宇陀市大宇陀岩清水');
ok($zip->set_number('6332131')->is_valid_number, '奈良県宇陀市大宇陀和田');
ok($zip->set_number('6332132')->is_valid_number, '奈良県宇陀市大宇陀下品');
ok($zip->set_number('6332133')->is_valid_number, '奈良県宇陀市大宇陀上品');
ok($zip->set_number('6332134')->is_valid_number, '奈良県宇陀市大宇陀小和田');
ok($zip->set_number('6332135')->is_valid_number, '奈良県宇陀市大宇陀東平尾');
ok($zip->set_number('6332136')->is_valid_number, '奈良県宇陀市大宇陀大熊');
ok($zip->set_number('6332137')->is_valid_number, '奈良県宇陀市大宇陀下片岡');
ok($zip->set_number('6332138')->is_valid_number, '奈良県宇陀市大宇陀白鳥居');
ok($zip->set_number('6332139')->is_valid_number, '奈良県宇陀市大宇陀山口');
ok($zip->set_number('6332141')->is_valid_number, '奈良県宇陀市大宇陀上片岡');
ok($zip->set_number('6332142')->is_valid_number, '奈良県宇陀市大宇陀田原');
ok($zip->set_number('6332143')->is_valid_number, '奈良県宇陀市大宇陀牧');
ok($zip->set_number('6332144')->is_valid_number, '奈良県宇陀市大宇陀栗野');
ok($zip->set_number('6332151')->is_valid_number, '奈良県宇陀市大宇陀大東');
ok($zip->set_number('6332152')->is_valid_number, '奈良県宇陀市大宇陀関戸');
ok($zip->set_number('6332153')->is_valid_number, '奈良県宇陀市大宇陀下宮奥');
ok($zip->set_number('6332154')->is_valid_number, '奈良県宇陀市大宇陀宮奥');
ok($zip->set_number('6332155')->is_valid_number, '奈良県宇陀市大宇陀黒木');
ok($zip->set_number('6332156')->is_valid_number, '奈良県宇陀市大宇陀本郷');
ok($zip->set_number('6332161')->is_valid_number, '奈良県宇陀市大宇陀上新');
ok($zip->set_number('6332162')->is_valid_number, '奈良県宇陀市大宇陀出新');
ok($zip->set_number('6332163')->is_valid_number, '奈良県宇陀市大宇陀万六');
ok($zip->set_number('6332164')->is_valid_number, '奈良県宇陀市大宇陀拾生');
ok($zip->set_number('6332165')->is_valid_number, '奈良県宇陀市大宇陀中庄');
ok($zip->set_number('6332166')->is_valid_number, '奈良県宇陀市大宇陀迫間');
ok($zip->set_number('6332170')->is_valid_number, '奈良県宇陀市大宇陀下茶');
ok($zip->set_number('6332171')->is_valid_number, '奈良県宇陀市大宇陀上茶');
ok($zip->set_number('6332172')->is_valid_number, '奈良県宇陀市大宇陀上本');
ok($zip->set_number('6332173')->is_valid_number, '奈良県宇陀市大宇陀上中');
ok($zip->set_number('6332174')->is_valid_number, '奈良県宇陀市大宇陀上');
ok($zip->set_number('6332175')->is_valid_number, '奈良県宇陀市大宇陀中新');
ok($zip->set_number('6332176')->is_valid_number, '奈良県宇陀市大宇陀小出口');
ok($zip->set_number('6332177')->is_valid_number, '奈良県宇陀市大宇陀下出口');
ok($zip->set_number('6332178')->is_valid_number, '奈良県宇陀市大宇陀下中');
ok($zip->set_number('6332179')->is_valid_number, '奈良県宇陀市大宇陀下本');
ok($zip->set_number('6332201')->is_valid_number, '奈良県宇陀市菟田野平井');
ok($zip->set_number('6332202')->is_valid_number, '奈良県宇陀市菟田野大神');
ok($zip->set_number('6332203')->is_valid_number, '奈良県宇陀市菟田野見田');
ok($zip->set_number('6332204')->is_valid_number, '奈良県宇陀市菟田野大澤');
ok($zip->set_number('6332205')->is_valid_number, '奈良県宇陀市菟田野別所');
ok($zip->set_number('6332211')->is_valid_number, '奈良県宇陀市菟田野入谷');
ok($zip->set_number('6332212')->is_valid_number, '奈良県宇陀市菟田野下芳野');
ok($zip->set_number('6332213')->is_valid_number, '奈良県宇陀市菟田野上芳野');
ok($zip->set_number('6332214')->is_valid_number, '奈良県宇陀市菟田野岩端');
ok($zip->set_number('6332215')->is_valid_number, '奈良県宇陀市菟田野東郷');
ok($zip->set_number('6332221')->is_valid_number, '奈良県宇陀市菟田野松井');
ok($zip->set_number('6332222')->is_valid_number, '奈良県宇陀市菟田野駒帰');
ok($zip->set_number('6332223')->is_valid_number, '奈良県宇陀市菟田野宇賀志');
ok($zip->set_number('6332224')->is_valid_number, '奈良県宇陀市菟田野佐倉');
ok($zip->set_number('6332225')->is_valid_number, '奈良県宇陀市菟田野稲戸');
ok($zip->set_number('6332226')->is_valid_number, '奈良県宇陀市菟田野古市場');
ok($zip->set_number('6332227')->is_valid_number, '奈良県宇陀市菟田野岩崎');
ok($zip->set_number('6332301')->is_valid_number, '奈良県吉野郡東吉野村滝野');
ok($zip->set_number('6332302')->is_valid_number, '奈良県吉野郡東吉野村谷尻');
ok($zip->set_number('6332303')->is_valid_number, '奈良県吉野郡東吉野村平野');
ok($zip->set_number('6332304')->is_valid_number, '奈良県吉野郡東吉野村杉谷');
ok($zip->set_number('6332311')->is_valid_number, '奈良県吉野郡東吉野村木津');
ok($zip->set_number('6332312')->is_valid_number, '奈良県吉野郡東吉野村伊豆尾');
ok($zip->set_number('6332313')->is_valid_number, '奈良県吉野郡東吉野村日裏');
ok($zip->set_number('6332314')->is_valid_number, '奈良県吉野郡東吉野村萩原');
ok($zip->set_number('6332400')->is_valid_number, '奈良県吉野郡東吉野村以下に掲載がない場合');
ok($zip->set_number('6332421')->is_valid_number, '奈良県吉野郡東吉野村小川');
ok($zip->set_number('6332422')->is_valid_number, '奈良県吉野郡東吉野村鷲家');
ok($zip->set_number('6332423')->is_valid_number, '奈良県吉野郡東吉野村小栗栖');
ok($zip->set_number('6332424')->is_valid_number, '奈良県吉野郡東吉野村中黒');
ok($zip->set_number('6332431')->is_valid_number, '奈良県吉野郡東吉野村小');
ok($zip->set_number('6332432')->is_valid_number, '奈良県吉野郡東吉野村木津川');
ok($zip->set_number('6332433')->is_valid_number, '奈良県吉野郡東吉野村三尾');
ok($zip->set_number('6332441')->is_valid_number, '奈良県吉野郡東吉野村狭戸');
ok($zip->set_number('6332442')->is_valid_number, '奈良県吉野郡東吉野村大豆生');
ok($zip->set_number('6332443')->is_valid_number, '奈良県吉野郡東吉野村麦谷');
ok($zip->set_number('6332444')->is_valid_number, '奈良県吉野郡東吉野村大又');
ok($zip->set_number('6340000')->is_valid_number, '奈良県橿原市以下に掲載がない場合');
ok($zip->set_number('6340001')->is_valid_number, '奈良県橿原市太田市町');
ok($zip->set_number('6340002')->is_valid_number, '奈良県橿原市東竹田町');
ok($zip->set_number('6340003')->is_valid_number, '奈良県橿原市常盤町');
ok($zip->set_number('6340004')->is_valid_number, '奈良県橿原市木原町');
ok($zip->set_number('6340005')->is_valid_number, '奈良県橿原市北八木町');
ok($zip->set_number('6340006')->is_valid_number, '奈良県橿原市新賀町');
ok($zip->set_number('6340007')->is_valid_number, '奈良県橿原市葛本町');
ok($zip->set_number('6340008')->is_valid_number, '奈良県橿原市十市町');
ok($zip->set_number('6340009')->is_valid_number, '奈良県橿原市中町');
ok($zip->set_number('6340011')->is_valid_number, '奈良県橿原市出垣内町');
ok($zip->set_number('6340012')->is_valid_number, '奈良県橿原市膳夫町');
ok($zip->set_number('6340013')->is_valid_number, '奈良県橿原市出合町');
ok($zip->set_number('6340014')->is_valid_number, '奈良県橿原市石原田町');
ok($zip->set_number('6340021')->is_valid_number, '奈良県橿原市東池尻町');
ok($zip->set_number('6340022')->is_valid_number, '奈良県橿原市南浦町');
ok($zip->set_number('6340023')->is_valid_number, '奈良県橿原市戒外町');
ok($zip->set_number('6340024')->is_valid_number, '奈良県橿原市南山町');
ok($zip->set_number('6340025')->is_valid_number, '奈良県橿原市木之本町');
ok($zip->set_number('6340026')->is_valid_number, '奈良県橿原市別所町');
ok($zip->set_number('6340027')->is_valid_number, '奈良県橿原市高殿町');
ok($zip->set_number('6340028')->is_valid_number, '奈良県橿原市法花寺町');
ok($zip->set_number('6340029')->is_valid_number, '奈良県橿原市下八釣町');
ok($zip->set_number('6340031')->is_valid_number, '奈良県橿原市上飛騨町');
ok($zip->set_number('6340032')->is_valid_number, '奈良県橿原市田中町');
ok($zip->set_number('6340033')->is_valid_number, '奈良県橿原市城殿町');
ok($zip->set_number('6340034')->is_valid_number, '奈良県橿原市飛騨町');
ok($zip->set_number('6340041')->is_valid_number, '奈良県橿原市和田町');
ok($zip->set_number('6340042')->is_valid_number, '奈良県橿原市菖蒲町');
ok($zip->set_number('6340043')->is_valid_number, '奈良県橿原市五条野町');
ok($zip->set_number('6340044')->is_valid_number, '奈良県橿原市大軽町');
ok($zip->set_number('6340045')->is_valid_number, '奈良県橿原市石川町');
ok($zip->set_number('6340046')->is_valid_number, '奈良県橿原市栄和町');
ok($zip->set_number('6340051')->is_valid_number, '奈良県橿原市白橿町');
ok($zip->set_number('6340052')->is_valid_number, '奈良県橿原市南妙法寺町');
ok($zip->set_number('6340061')->is_valid_number, '奈良県橿原市大久保町');
ok($zip->set_number('6340062')->is_valid_number, '奈良県橿原市御坊町');
ok($zip->set_number('6340063')->is_valid_number, '奈良県橿原市久米町');
ok($zip->set_number('6340064')->is_valid_number, '奈良県橿原市見瀬町');
ok($zip->set_number('6340065')->is_valid_number, '奈良県橿原市畝傍町');
ok($zip->set_number('6340071')->is_valid_number, '奈良県橿原市山之坊町');
ok($zip->set_number('6340072')->is_valid_number, '奈良県橿原市醍醐町');
ok($zip->set_number('6340073')->is_valid_number, '奈良県橿原市縄手町');
ok($zip->set_number('6340074')->is_valid_number, '奈良県橿原市四分町');
ok($zip->set_number('6340075')->is_valid_number, '奈良県橿原市小房町');
ok($zip->set_number('6340076')->is_valid_number, '奈良県橿原市兵部町');
ok($zip->set_number('6340077')->is_valid_number, '奈良県橿原市南八木町');
ok($zip->set_number('6340078')->is_valid_number, '奈良県橿原市八木町');
ok($zip->set_number('6340100')->is_valid_number, '奈良県高市郡明日香村以下に掲載がない場合');
ok($zip->set_number('6340101')->is_valid_number, '奈良県高市郡明日香村小山');
ok($zip->set_number('6340102')->is_valid_number, '奈良県高市郡明日香村奥山');
ok($zip->set_number('6340103')->is_valid_number, '奈良県高市郡明日香村飛鳥');
ok($zip->set_number('6340104')->is_valid_number, '奈良県高市郡明日香村八釣');
ok($zip->set_number('6340105')->is_valid_number, '奈良県高市郡明日香村東山');
ok($zip->set_number('6340106')->is_valid_number, '奈良県高市郡明日香村小原');
ok($zip->set_number('6340107')->is_valid_number, '奈良県高市郡明日香村豊浦');
ok($zip->set_number('6340108')->is_valid_number, '奈良県高市郡明日香村雷');
ok($zip->set_number('6340111')->is_valid_number, '奈良県高市郡明日香村岡');
ok($zip->set_number('6340112')->is_valid_number, '奈良県高市郡明日香村島庄');
ok($zip->set_number('6340113')->is_valid_number, '奈良県高市郡明日香村上居');
ok($zip->set_number('6340114')->is_valid_number, '奈良県高市郡明日香村細川');
ok($zip->set_number('6340115')->is_valid_number, '奈良県高市郡明日香村上');
ok($zip->set_number('6340116')->is_valid_number, '奈良県高市郡明日香村尾曽');
ok($zip->set_number('6340117')->is_valid_number, '奈良県高市郡明日香村冬野');
ok($zip->set_number('6340118')->is_valid_number, '奈良県高市郡明日香村畑');
ok($zip->set_number('6340121')->is_valid_number, '奈良県高市郡明日香村祝戸');
ok($zip->set_number('6340122')->is_valid_number, '奈良県高市郡明日香村阪田');
ok($zip->set_number('6340123')->is_valid_number, '奈良県高市郡明日香村稲渕');
ok($zip->set_number('6340124')->is_valid_number, '奈良県高市郡明日香村栢森');
ok($zip->set_number('6340125')->is_valid_number, '奈良県高市郡明日香村入谷');
ok($zip->set_number('6340131')->is_valid_number, '奈良県高市郡明日香村御園');
ok($zip->set_number('6340132')->is_valid_number, '奈良県高市郡明日香村栗原');
ok($zip->set_number('6340133')->is_valid_number, '奈良県高市郡明日香村大根田');
ok($zip->set_number('6340134')->is_valid_number, '奈良県高市郡明日香村阿部山');
ok($zip->set_number('6340135')->is_valid_number, '奈良県高市郡明日香村檜前');
ok($zip->set_number('6340136')->is_valid_number, '奈良県高市郡明日香村地ノ窪');
ok($zip->set_number('6340137')->is_valid_number, '奈良県高市郡明日香村真弓');
ok($zip->set_number('6340138')->is_valid_number, '奈良県高市郡明日香村越');
ok($zip->set_number('6340141')->is_valid_number, '奈良県高市郡明日香村川原');
ok($zip->set_number('6340142')->is_valid_number, '奈良県高市郡明日香村橘');
ok($zip->set_number('6340143')->is_valid_number, '奈良県高市郡明日香村立部');
ok($zip->set_number('6340144')->is_valid_number, '奈良県高市郡明日香村平田');
ok($zip->set_number('6340145')->is_valid_number, '奈良県高市郡明日香村野口');
ok($zip->set_number('6340801')->is_valid_number, '奈良県橿原市西新堂町');
ok($zip->set_number('6340802')->is_valid_number, '奈良県橿原市新口町');
ok($zip->set_number('6340803')->is_valid_number, '奈良県橿原市上品寺町');
ok($zip->set_number('6340804')->is_valid_number, '奈良県橿原市内膳町');
ok($zip->set_number('6340805')->is_valid_number, '奈良県橿原市地黄町');
ok($zip->set_number('6340811')->is_valid_number, '奈良県橿原市小綱町');
ok($zip->set_number('6340812')->is_valid_number, '奈良県橿原市今井町');
ok($zip->set_number('6340813')->is_valid_number, '奈良県橿原市四条町');
ok($zip->set_number('6340814')->is_valid_number, '奈良県橿原市山本町');
ok($zip->set_number('6340815')->is_valid_number, '奈良県橿原市大谷町');
ok($zip->set_number('6340816')->is_valid_number, '奈良県橿原市慈明寺町');
ok($zip->set_number('6340817')->is_valid_number, '奈良県橿原市寺田町');
ok($zip->set_number('6340821')->is_valid_number, '奈良県橿原市西池尻町');
ok($zip->set_number('6340822')->is_valid_number, '奈良県橿原市鳥屋町');
ok($zip->set_number('6340823')->is_valid_number, '奈良県橿原市北越智町');
ok($zip->set_number('6340824')->is_valid_number, '奈良県橿原市一町');
ok($zip->set_number('6340825')->is_valid_number, '奈良県橿原市観音寺町');
ok($zip->set_number('6340826')->is_valid_number, '奈良県橿原市川西町');
ok($zip->set_number('6340827')->is_valid_number, '奈良県橿原市光陽町');
ok($zip->set_number('6340828')->is_valid_number, '奈良県橿原市古川町');
ok($zip->set_number('6340829')->is_valid_number, '奈良県橿原市吉田町');
ok($zip->set_number('6340831')->is_valid_number, '奈良県橿原市曽我町');
ok($zip->set_number('6340832')->is_valid_number, '奈良県橿原市五井町');
ok($zip->set_number('6340833')->is_valid_number, '奈良県橿原市忌部町');
ok($zip->set_number('6340834')->is_valid_number, '奈良県橿原市雲梯町');
ok($zip->set_number('6340835')->is_valid_number, '奈良県橿原市東坊城町');
ok($zip->set_number('6340836')->is_valid_number, '奈良県橿原市新堂町');
ok($zip->set_number('6340837')->is_valid_number, '奈良県橿原市曲川町');
ok($zip->set_number('6340841')->is_valid_number, '奈良県橿原市大垣町');
ok($zip->set_number('6340842')->is_valid_number, '奈良県橿原市豊田町');
ok($zip->set_number('6340843')->is_valid_number, '奈良県橿原市北妙法寺町');
ok($zip->set_number('6340844')->is_valid_number, '奈良県橿原市土橋町');
ok($zip->set_number('6340845')->is_valid_number, '奈良県橿原市中曽司町');
ok($zip->set_number('6340846')->is_valid_number, '奈良県橿原市小槻町');
ok($zip->set_number('6340847')->is_valid_number, '奈良県橿原市飯高町');
ok($zip->set_number('6350000')->is_valid_number, '奈良県大和高田市以下に掲載がない場合');
ok($zip->set_number('6350000')->is_valid_number, '奈良県北葛城郡広陵町以下に掲載がない場合');
ok($zip->set_number('6350001')->is_valid_number, '奈良県大和高田市松塚');
ok($zip->set_number('6350002')->is_valid_number, '奈良県大和高田市土庫(丁目)');
ok($zip->set_number('6350003')->is_valid_number, '奈良県大和高田市土庫(番地)');
ok($zip->set_number('6350004')->is_valid_number, '奈良県大和高田市藤森');
ok($zip->set_number('6350011')->is_valid_number, '奈良県大和高田市材木町');
ok($zip->set_number('6350012')->is_valid_number, '奈良県大和高田市曙町');
ok($zip->set_number('6350013')->is_valid_number, '奈良県大和高田市昭和町');
ok($zip->set_number('6350014')->is_valid_number, '奈良県大和高田市三和町');
ok($zip->set_number('6350015')->is_valid_number, '奈良県大和高田市幸町');
ok($zip->set_number('6350016')->is_valid_number, '奈良県大和高田市大東町');
ok($zip->set_number('6350017')->is_valid_number, '奈良県大和高田市東雲町');
ok($zip->set_number('6350021')->is_valid_number, '奈良県大和高田市池尻');
ok($zip->set_number('6350022')->is_valid_number, '奈良県大和高田市高田');
ok($zip->set_number('6350022')->is_valid_number, '奈良県大和高田市日之出町');
ok($zip->set_number('6350023')->is_valid_number, '奈良県大和高田市日之出東本町');
ok($zip->set_number('6350024')->is_valid_number, '奈良県大和高田市日之出西本町');
ok($zip->set_number('6350025')->is_valid_number, '奈良県大和高田市神楽(丁目)');
ok($zip->set_number('6350026')->is_valid_number, '奈良県大和高田市神楽(番地)');
ok($zip->set_number('6350031')->is_valid_number, '奈良県大和高田市今里');
ok($zip->set_number('6350031')->is_valid_number, '奈良県大和高田市今里町');
ok($zip->set_number('6350032')->is_valid_number, '奈良県大和高田市今里川合方');
ok($zip->set_number('6350033')->is_valid_number, '奈良県大和高田市南今里町');
ok($zip->set_number('6350034')->is_valid_number, '奈良県大和高田市東三倉堂町');
ok($zip->set_number('6350035')->is_valid_number, '奈良県大和高田市旭南町');
ok($zip->set_number('6350036')->is_valid_number, '奈良県大和高田市旭北町');
ok($zip->set_number('6350037')->is_valid_number, '奈良県大和高田市中今里町');
ok($zip->set_number('6350041')->is_valid_number, '奈良県大和高田市田井');
ok($zip->set_number('6350042')->is_valid_number, '奈良県大和高田市勝目');
ok($zip->set_number('6350043')->is_valid_number, '奈良県大和高田市出');
ok($zip->set_number('6350044')->is_valid_number, '奈良県大和高田市蔵之宮町');
ok($zip->set_number('6350045')->is_valid_number, '奈良県大和高田市中三倉堂');
ok($zip->set_number('6350046')->is_valid_number, '奈良県大和高田市西三倉堂');
ok($zip->set_number('6350047')->is_valid_number, '奈良県大和高田市田井新町');
ok($zip->set_number('6350051')->is_valid_number, '奈良県大和高田市根成柿');
ok($zip->set_number('6350052')->is_valid_number, '奈良県大和高田市奥田');
ok($zip->set_number('6350053')->is_valid_number, '奈良県大和高田市秋吉');
ok($zip->set_number('6350054')->is_valid_number, '奈良県大和高田市曽大根(番地)');
ok($zip->set_number('6350055')->is_valid_number, '奈良県大和高田市曽大根(丁目)');
ok($zip->set_number('6350056')->is_valid_number, '奈良県大和高田市甘田町');
ok($zip->set_number('6350057')->is_valid_number, '奈良県大和高田市南陽町');
ok($zip->set_number('6350058')->is_valid_number, '奈良県大和高田市西坊城');
ok($zip->set_number('6350059')->is_valid_number, '奈良県大和高田市吉井');
ok($zip->set_number('6350061')->is_valid_number, '奈良県大和高田市礒野東町');
ok($zip->set_number('6350062')->is_valid_number, '奈良県大和高田市礒野南町');
ok($zip->set_number('6350063')->is_valid_number, '奈良県大和高田市礒野新町');
ok($zip->set_number('6350064')->is_valid_number, '奈良県大和高田市栄町');
ok($zip->set_number('6350065')->is_valid_number, '奈良県大和高田市東中(丁目)');
ok($zip->set_number('6350066')->is_valid_number, '奈良県大和高田市東中(番地)');
ok($zip->set_number('6350067')->is_valid_number, '奈良県大和高田市春日町');
ok($zip->set_number('6350071')->is_valid_number, '奈良県大和高田市築山');
ok($zip->set_number('6350072')->is_valid_number, '奈良県大和高田市有井');
ok($zip->set_number('6350073')->is_valid_number, '奈良県大和高田市岡崎');
ok($zip->set_number('6350074')->is_valid_number, '奈良県大和高田市市場');
ok($zip->set_number('6350075')->is_valid_number, '奈良県大和高田市野口');
ok($zip->set_number('6350076')->is_valid_number, '奈良県大和高田市大谷');
ok($zip->set_number('6350077')->is_valid_number, '奈良県大和高田市池田');
ok($zip->set_number('6350081')->is_valid_number, '奈良県大和高田市高砂町');
ok($zip->set_number('6350082')->is_valid_number, '奈良県大和高田市本郷町');
ok($zip->set_number('6350083')->is_valid_number, '奈良県大和高田市永和町');
ok($zip->set_number('6350084')->is_valid_number, '奈良県大和高田市北片塩町');
ok($zip->set_number('6350085')->is_valid_number, '奈良県大和高田市片塩町');
ok($zip->set_number('6350086')->is_valid_number, '奈良県大和高田市南本町');
ok($zip->set_number('6350087')->is_valid_number, '奈良県大和高田市内本町');
ok($zip->set_number('6350091')->is_valid_number, '奈良県大和高田市大中東町');
ok($zip->set_number('6350092')->is_valid_number, '奈良県大和高田市大中南町');
ok($zip->set_number('6350093')->is_valid_number, '奈良県大和高田市礒野');
ok($zip->set_number('6350093')->is_valid_number, '奈良県大和高田市礒野町');
ok($zip->set_number('6350094')->is_valid_number, '奈良県大和高田市礒野北町');
ok($zip->set_number('6350095')->is_valid_number, '奈良県大和高田市大中');
ok($zip->set_number('6350096')->is_valid_number, '奈良県大和高田市西町');
ok($zip->set_number('6350097')->is_valid_number, '奈良県大和高田市北本町');
ok($zip->set_number('6350100')->is_valid_number, '奈良県高市郡高取町以下に掲載がない場合');
ok($zip->set_number('6350101')->is_valid_number, '奈良県高市郡高取町高取');
ok($zip->set_number('6350102')->is_valid_number, '奈良県高市郡高取町壺阪');
ok($zip->set_number('6350103')->is_valid_number, '奈良県高市郡高取町清水谷');
ok($zip->set_number('6350104')->is_valid_number, '奈良県高市郡高取町上子島');
ok($zip->set_number('6350111')->is_valid_number, '奈良県高市郡高取町松山');
ok($zip->set_number('6350112')->is_valid_number, '奈良県高市郡高取町藤井');
ok($zip->set_number('6350113')->is_valid_number, '奈良県高市郡高取町羽内');
ok($zip->set_number('6350121')->is_valid_number, '奈良県高市郡高取町丹生谷');
ok($zip->set_number('6350122')->is_valid_number, '奈良県高市郡高取町谷田');
ok($zip->set_number('6350123')->is_valid_number, '奈良県高市郡高取町市尾');
ok($zip->set_number('6350131')->is_valid_number, '奈良県高市郡高取町佐田');
ok($zip->set_number('6350132')->is_valid_number, '奈良県高市郡高取町森');
ok($zip->set_number('6350133')->is_valid_number, '奈良県高市郡高取町吉備');
ok($zip->set_number('6350134')->is_valid_number, '奈良県高市郡高取町薩摩');
ok($zip->set_number('6350135')->is_valid_number, '奈良県高市郡高取町田井庄');
ok($zip->set_number('6350136')->is_valid_number, '奈良県高市郡高取町兵庫');
ok($zip->set_number('6350141')->is_valid_number, '奈良県高市郡高取町与楽');
ok($zip->set_number('6350142')->is_valid_number, '奈良県高市郡高取町寺崎');
ok($zip->set_number('6350143')->is_valid_number, '奈良県高市郡高取町車木');
ok($zip->set_number('6350144')->is_valid_number, '奈良県高市郡高取町越智');
ok($zip->set_number('6350151')->is_valid_number, '奈良県高市郡高取町下子島');
ok($zip->set_number('6350152')->is_valid_number, '奈良県高市郡高取町上土佐');
ok($zip->set_number('6350153')->is_valid_number, '奈良県高市郡高取町下土佐');
ok($zip->set_number('6350154')->is_valid_number, '奈良県高市郡高取町観覚寺');
ok($zip->set_number('6350801')->is_valid_number, '奈良県北葛城郡広陵町大場');
ok($zip->set_number('6350802')->is_valid_number, '奈良県北葛城郡広陵町的場');
ok($zip->set_number('6350803')->is_valid_number, '奈良県北葛城郡広陵町大野');
ok($zip->set_number('6350804')->is_valid_number, '奈良県北葛城郡広陵町沢');
ok($zip->set_number('6350805')->is_valid_number, '奈良県北葛城郡広陵町萱野');
ok($zip->set_number('6350811')->is_valid_number, '奈良県北葛城郡広陵町弁財天');
ok($zip->set_number('6350812')->is_valid_number, '奈良県北葛城郡広陵町広瀬');
ok($zip->set_number('6350813')->is_valid_number, '奈良県北葛城郡広陵町百済');
ok($zip->set_number('6350814')->is_valid_number, '奈良県北葛城郡広陵町南郷');
ok($zip->set_number('6350815')->is_valid_number, '奈良県北葛城郡広陵町古寺');
ok($zip->set_number('6350816')->is_valid_number, '奈良県北葛城郡広陵町中');
ok($zip->set_number('6350817')->is_valid_number, '奈良県北葛城郡広陵町寺戸');
ok($zip->set_number('6350818')->is_valid_number, '奈良県北葛城郡広陵町南');
ok($zip->set_number('6350821')->is_valid_number, '奈良県北葛城郡広陵町笠');
ok($zip->set_number('6350822')->is_valid_number, '奈良県北葛城郡広陵町平尾');
ok($zip->set_number('6350823')->is_valid_number, '奈良県北葛城郡広陵町三吉');
ok($zip->set_number('6350824')->is_valid_number, '奈良県北葛城郡広陵町疋相');
ok($zip->set_number('6350825')->is_valid_number, '奈良県北葛城郡広陵町安部');
ok($zip->set_number('6350831')->is_valid_number, '奈良県北葛城郡広陵町馬見北');
ok($zip->set_number('6350832')->is_valid_number, '奈良県北葛城郡広陵町馬見中');
ok($zip->set_number('6350833')->is_valid_number, '奈良県北葛城郡広陵町馬見南');
ok($zip->set_number('6350834')->is_valid_number, '奈良県北葛城郡広陵町大塚');
ok($zip->set_number('6350835')->is_valid_number, '奈良県北葛城郡広陵町みささぎ台');
ok($zip->set_number('6360000')->is_valid_number, '奈良県生駒郡平群町以下に掲載がない場合');
ok($zip->set_number('6360000')->is_valid_number, '奈良県生駒郡三郷町以下に掲載がない場合');
ok($zip->set_number('6360000')->is_valid_number, '奈良県北葛城郡王寺町以下に掲載がない場合');
ok($zip->set_number('6360000')->is_valid_number, '奈良県北葛城郡河合町以下に掲載がない場合');
ok($zip->set_number('6360001')->is_valid_number, '奈良県北葛城郡王寺町舟戸');
ok($zip->set_number('6360002')->is_valid_number, '奈良県北葛城郡王寺町王寺');
ok($zip->set_number('6360003')->is_valid_number, '奈良県北葛城郡王寺町久度');
ok($zip->set_number('6360011')->is_valid_number, '奈良県北葛城郡王寺町葛下');
ok($zip->set_number('6360012')->is_valid_number, '奈良県北葛城郡王寺町本町');
ok($zip->set_number('6360013')->is_valid_number, '奈良県北葛城郡王寺町元町');
ok($zip->set_number('6360014')->is_valid_number, '奈良県北葛城郡王寺町藤井');
ok($zip->set_number('6360015')->is_valid_number, '奈良県北葛城郡王寺町南元町');
ok($zip->set_number('6360021')->is_valid_number, '奈良県北葛城郡王寺町畠田');
ok($zip->set_number('6360022')->is_valid_number, '奈良県北葛城郡王寺町明神');
ok($zip->set_number('6360023')->is_valid_number, '奈良県北葛城郡王寺町太子');
ok($zip->set_number('6360051')->is_valid_number, '奈良県北葛城郡河合町川合');
ok($zip->set_number('6360052')->is_valid_number, '奈良県北葛城郡河合町長楽');
ok($zip->set_number('6360053')->is_valid_number, '奈良県北葛城郡河合町池部');
ok($zip->set_number('6360054')->is_valid_number, '奈良県北葛城郡河合町穴闇');
ok($zip->set_number('6360055')->is_valid_number, '奈良県北葛城郡河合町西穴闇');
ok($zip->set_number('6360056')->is_valid_number, '奈良県北葛城郡河合町西山台');
ok($zip->set_number('6360057')->is_valid_number, '奈良県北葛城郡河合町彩りの杜');
ok($zip->set_number('6360061')->is_valid_number, '奈良県北葛城郡河合町山坊');
ok($zip->set_number('6360062')->is_valid_number, '奈良県北葛城郡河合町佐味田');
ok($zip->set_number('6360063')->is_valid_number, '奈良県北葛城郡河合町久美ケ丘');
ok($zip->set_number('6360071')->is_valid_number, '奈良県北葛城郡河合町高塚台');
ok($zip->set_number('6360072')->is_valid_number, '奈良県北葛城郡河合町中山台');
ok($zip->set_number('6360073')->is_valid_number, '奈良県北葛城郡河合町広瀬台');
ok($zip->set_number('6360081')->is_valid_number, '奈良県北葛城郡河合町星和台');
ok($zip->set_number('6360082')->is_valid_number, '奈良県北葛城郡河合町薬井');
ok($zip->set_number('6360091')->is_valid_number, '奈良県北葛城郡河合町泉台');
ok($zip->set_number('6360092')->is_valid_number, '奈良県北葛城郡河合町城内');
ok($zip->set_number('6360093')->is_valid_number, '奈良県北葛城郡河合町大輪田');
ok($zip->set_number('6360100')->is_valid_number, '奈良県生駒郡斑鳩町以下に掲載がない場合');
ok($zip->set_number('6360101')->is_valid_number, '奈良県生駒郡斑鳩町三井');
ok($zip->set_number('6360102')->is_valid_number, '奈良県生駒郡斑鳩町岡本');
ok($zip->set_number('6360103')->is_valid_number, '奈良県生駒郡斑鳩町幸前');
ok($zip->set_number('6360104')->is_valid_number, '奈良県生駒郡斑鳩町高安');
ok($zip->set_number('6360105')->is_valid_number, '奈良県生駒郡斑鳩町東福寺');
ok($zip->set_number('6360106')->is_valid_number, '奈良県生駒郡斑鳩町高安西');
ok($zip->set_number('6360111')->is_valid_number, '奈良県生駒郡斑鳩町法隆寺北');
ok($zip->set_number('6360112')->is_valid_number, '奈良県生駒郡斑鳩町法隆寺東');
ok($zip->set_number('6360113')->is_valid_number, '奈良県生駒郡斑鳩町法隆寺南');
ok($zip->set_number('6360114')->is_valid_number, '奈良県生駒郡斑鳩町法隆寺西');
ok($zip->set_number('6360115')->is_valid_number, '奈良県生駒郡斑鳩町法隆寺山内');
ok($zip->set_number('6360116')->is_valid_number, '奈良県生駒郡斑鳩町法隆寺');
ok($zip->set_number('6360121')->is_valid_number, '奈良県生駒郡斑鳩町興留東');
ok($zip->set_number('6360122')->is_valid_number, '奈良県生駒郡斑鳩町阿波');
ok($zip->set_number('6360123')->is_valid_number, '奈良県生駒郡斑鳩町興留');
ok($zip->set_number('6360124')->is_valid_number, '奈良県生駒郡斑鳩町五百井');
ok($zip->set_number('6360131')->is_valid_number, '奈良県生駒郡斑鳩町服部');
ok($zip->set_number('6360132')->is_valid_number, '奈良県生駒郡斑鳩町目安');
ok($zip->set_number('6360133')->is_valid_number, '奈良県生駒郡斑鳩町目安北');
ok($zip->set_number('6360141')->is_valid_number, '奈良県生駒郡斑鳩町稲葉車瀬');
ok($zip->set_number('6360142')->is_valid_number, '奈良県生駒郡斑鳩町小吉田');
ok($zip->set_number('6360143')->is_valid_number, '奈良県生駒郡斑鳩町神南');
ok($zip->set_number('6360144')->is_valid_number, '奈良県生駒郡斑鳩町稲葉西');
ok($zip->set_number('6360151')->is_valid_number, '奈良県生駒郡斑鳩町龍田北');
ok($zip->set_number('6360152')->is_valid_number, '奈良県生駒郡斑鳩町龍田');
ok($zip->set_number('6360153')->is_valid_number, '奈良県生駒郡斑鳩町龍田南');
ok($zip->set_number('6360154')->is_valid_number, '奈良県生駒郡斑鳩町龍田西');
ok($zip->set_number('6360201')->is_valid_number, '奈良県磯城郡川西町下永');
ok($zip->set_number('6360202')->is_valid_number, '奈良県磯城郡川西町結崎');
ok($zip->set_number('6360203')->is_valid_number, '奈良県磯城郡川西町梅戸');
ok($zip->set_number('6360204')->is_valid_number, '奈良県磯城郡川西町唐院');
ok($zip->set_number('6360205')->is_valid_number, '奈良県磯城郡川西町保田');
ok($zip->set_number('6360206')->is_valid_number, '奈良県磯城郡川西町吐田');
ok($zip->set_number('6360211')->is_valid_number, '奈良県磯城郡三宅町三河');
ok($zip->set_number('6360212')->is_valid_number, '奈良県磯城郡三宅町石見');
ok($zip->set_number('6360213')->is_valid_number, '奈良県磯城郡三宅町伴堂');
ok($zip->set_number('6360214')->is_valid_number, '奈良県磯城郡三宅町但馬');
ok($zip->set_number('6360215')->is_valid_number, '奈良県磯城郡三宅町上但馬');
ok($zip->set_number('6360216')->is_valid_number, '奈良県磯城郡三宅町小柳');
ok($zip->set_number('6360217')->is_valid_number, '奈良県磯城郡三宅町屏風');
ok($zip->set_number('6360221')->is_valid_number, '奈良県磯城郡田原本町八田');
ok($zip->set_number('6360222')->is_valid_number, '奈良県磯城郡田原本町法貴寺');
ok($zip->set_number('6360223')->is_valid_number, '奈良県磯城郡田原本町鍵');
ok($zip->set_number('6360224')->is_valid_number, '奈良県磯城郡田原本町今里');
ok($zip->set_number('6360225')->is_valid_number, '奈良県磯城郡田原本町西代');
ok($zip->set_number('6360226')->is_valid_number, '奈良県磯城郡田原本町唐古');
ok($zip->set_number('6360231')->is_valid_number, '奈良県磯城郡田原本町為川北方');
ok($zip->set_number('6360232')->is_valid_number, '奈良県磯城郡田原本町金沢');
ok($zip->set_number('6360233')->is_valid_number, '奈良県磯城郡田原本町為川南方');
ok($zip->set_number('6360234')->is_valid_number, '奈良県磯城郡田原本町蔵堂');
ok($zip->set_number('6360235')->is_valid_number, '奈良県磯城郡田原本町東井上');
ok($zip->set_number('6360236')->is_valid_number, '奈良県磯城郡田原本町西井上');
ok($zip->set_number('6360237')->is_valid_number, '奈良県磯城郡田原本町小阪');
ok($zip->set_number('6360241')->is_valid_number, '奈良県磯城郡田原本町平田');
ok($zip->set_number('6360242')->is_valid_number, '奈良県磯城郡田原本町大木');
ok($zip->set_number('6360243')->is_valid_number, '奈良県磯城郡田原本町伊与戸');
ok($zip->set_number('6360244')->is_valid_number, '奈良県磯城郡田原本町笠形');
ok($zip->set_number('6360245')->is_valid_number, '奈良県磯城郡田原本町味間');
ok($zip->set_number('6360246')->is_valid_number, '奈良県磯城郡田原本町千代');
ok($zip->set_number('6360247')->is_valid_number, '奈良県磯城郡田原本町阪手');
ok($zip->set_number('6360248')->is_valid_number, '奈良県磯城郡田原本町大安寺');
ok($zip->set_number('6360300')->is_valid_number, '奈良県磯城郡川西町以下に掲載がない場合');
ok($zip->set_number('6360300')->is_valid_number, '奈良県磯城郡三宅町以下に掲載がない場合');
ok($zip->set_number('6360300')->is_valid_number, '奈良県磯城郡田原本町以下に掲載がない場合');
ok($zip->set_number('6360301')->is_valid_number, '奈良県磯城郡田原本町黒田');
ok($zip->set_number('6360302')->is_valid_number, '奈良県磯城郡田原本町宮古');
ok($zip->set_number('6360303')->is_valid_number, '奈良県磯城郡田原本町保津');
ok($zip->set_number('6360304')->is_valid_number, '奈良県磯城郡田原本町十六面');
ok($zip->set_number('6360305')->is_valid_number, '奈良県磯城郡田原本町平野');
ok($zip->set_number('6360306')->is_valid_number, '奈良県磯城郡田原本町西竹田');
ok($zip->set_number('6360307')->is_valid_number, '奈良県磯城郡田原本町富本');
ok($zip->set_number('6360311')->is_valid_number, '奈良県磯城郡田原本町八尾');
ok($zip->set_number('6360312')->is_valid_number, '奈良県磯城郡田原本町新町');
ok($zip->set_number('6360313')->is_valid_number, '奈良県磯城郡田原本町旭町');
ok($zip->set_number('6360314')->is_valid_number, '奈良県磯城郡田原本町戎通');
ok($zip->set_number('6360315')->is_valid_number, '奈良県磯城郡田原本町幸町');
ok($zip->set_number('6360316')->is_valid_number, '奈良県磯城郡田原本町室町');
ok($zip->set_number('6360317')->is_valid_number, '奈良県磯城郡田原本町殿町');
ok($zip->set_number('6360321')->is_valid_number, '奈良県磯城郡田原本町八幡町');
ok($zip->set_number('6360322')->is_valid_number, '奈良県磯城郡田原本町郭内');
ok($zip->set_number('6360323')->is_valid_number, '奈良県磯城郡田原本町根太口');
ok($zip->set_number('6360324')->is_valid_number, '奈良県磯城郡田原本町三輪町');
ok($zip->set_number('6360325')->is_valid_number, '奈良県磯城郡田原本町南町');
ok($zip->set_number('6360326')->is_valid_number, '奈良県磯城郡田原本町新地');
ok($zip->set_number('6360327')->is_valid_number, '奈良県磯城郡田原本町堺町');
ok($zip->set_number('6360328')->is_valid_number, '奈良県磯城郡田原本町材木町');
ok($zip->set_number('6360329')->is_valid_number, '奈良県磯城郡田原本町味間町');
ok($zip->set_number('6360331')->is_valid_number, '奈良県磯城郡田原本町魚町');
ok($zip->set_number('6360332')->is_valid_number, '奈良県磯城郡田原本町市町');
ok($zip->set_number('6360333')->is_valid_number, '奈良県磯城郡田原本町祗園町');
ok($zip->set_number('6360334')->is_valid_number, '奈良県磯城郡田原本町本町');
ok($zip->set_number('6360335')->is_valid_number, '奈良県磯城郡田原本町大門東');
ok($zip->set_number('6360336')->is_valid_number, '奈良県磯城郡田原本町大門中');
ok($zip->set_number('6360337')->is_valid_number, '奈良県磯城郡田原本町大門西');
ok($zip->set_number('6360338')->is_valid_number, '奈良県磯城郡田原本町茶町');
ok($zip->set_number('6360339')->is_valid_number, '奈良県磯城郡田原本町小室');
ok($zip->set_number('6360341')->is_valid_number, '奈良県磯城郡田原本町薬王寺');
ok($zip->set_number('6360342')->is_valid_number, '奈良県磯城郡田原本町三笠');
ok($zip->set_number('6360343')->is_valid_number, '奈良県磯城郡田原本町秦庄');
ok($zip->set_number('6360344')->is_valid_number, '奈良県磯城郡田原本町宮森');
ok($zip->set_number('6360345')->is_valid_number, '奈良県磯城郡田原本町多');
ok($zip->set_number('6360346')->is_valid_number, '奈良県磯城郡田原本町矢部');
ok($zip->set_number('6360347')->is_valid_number, '奈良県磯城郡田原本町新木');
ok($zip->set_number('6360351')->is_valid_number, '奈良県磯城郡田原本町松本');
ok($zip->set_number('6360352')->is_valid_number, '奈良県磯城郡田原本町金剛寺');
ok($zip->set_number('6360353')->is_valid_number, '奈良県磯城郡田原本町大網');
ok($zip->set_number('6360354')->is_valid_number, '奈良県磯城郡田原本町満田');
ok($zip->set_number('6360355')->is_valid_number, '奈良県磯城郡田原本町佐味');
ok($zip->set_number('6360801')->is_valid_number, '奈良県生駒郡三郷町夕陽ケ丘');
ok($zip->set_number('6360802')->is_valid_number, '奈良県生駒郡三郷町三室');
ok($zip->set_number('6360803')->is_valid_number, '奈良県生駒郡三郷町東信貴ケ丘');
ok($zip->set_number('6360804')->is_valid_number, '奈良県生駒郡三郷町美松ケ丘西');
ok($zip->set_number('6360805')->is_valid_number, '奈良県生駒郡三郷町美松ケ丘東');
ok($zip->set_number('6360811')->is_valid_number, '奈良県生駒郡三郷町勢野東');
ok($zip->set_number('6360812')->is_valid_number, '奈良県生駒郡三郷町勢野西');
ok($zip->set_number('6360813')->is_valid_number, '奈良県生駒郡三郷町信貴ケ丘');
ok($zip->set_number('6360814')->is_valid_number, '奈良県生駒郡三郷町勢野');
ok($zip->set_number('6360815')->is_valid_number, '奈良県生駒郡三郷町勢野北');
ok($zip->set_number('6360821')->is_valid_number, '奈良県生駒郡三郷町立野北');
ok($zip->set_number('6360822')->is_valid_number, '奈良県生駒郡三郷町立野南');
ok($zip->set_number('6360823')->is_valid_number, '奈良県生駒郡三郷町立野');
ok($zip->set_number('6360824')->is_valid_number, '奈良県生駒郡三郷町城山台');
ok($zip->set_number('6360831')->is_valid_number, '奈良県生駒郡三郷町信貴山東');
ok($zip->set_number('6360832')->is_valid_number, '奈良県生駒郡三郷町信貴山西');
ok($zip->set_number('6360833')->is_valid_number, '奈良県生駒郡三郷町信貴南畑');
ok($zip->set_number('6360834')->is_valid_number, '奈良県生駒郡三郷町南畑');
ok($zip->set_number('6360901')->is_valid_number, '奈良県生駒郡平群町椣原');
ok($zip->set_number('6360902')->is_valid_number, '奈良県生駒郡平群町白石畑');
ok($zip->set_number('6360903')->is_valid_number, '奈良県生駒郡平群町平等寺');
ok($zip->set_number('6360904')->is_valid_number, '奈良県生駒郡平群町三里');
ok($zip->set_number('6360905')->is_valid_number, '奈良県生駒郡平群町上庄');
ok($zip->set_number('6360906')->is_valid_number, '奈良県生駒郡平群町菊美台');
ok($zip->set_number('6360911')->is_valid_number, '奈良県生駒郡平群町椿井');
ok($zip->set_number('6360912')->is_valid_number, '奈良県生駒郡平群町竜田川');
ok($zip->set_number('6360913')->is_valid_number, '奈良県生駒郡平群町北信貴ケ丘');
ok($zip->set_number('6360914')->is_valid_number, '奈良県生駒郡平群町西宮');
ok($zip->set_number('6360915')->is_valid_number, '奈良県生駒郡平群町春日丘');
ok($zip->set_number('6360916')->is_valid_number, '奈良県生駒郡平群町若井');
ok($zip->set_number('6360921')->is_valid_number, '奈良県生駒郡平群町椹原');
ok($zip->set_number('6360922')->is_valid_number, '奈良県生駒郡平群町信貴畑');
ok($zip->set_number('6360923')->is_valid_number, '奈良県生駒郡平群町信貴山');
ok($zip->set_number('6360924')->is_valid_number, '奈良県生駒郡平群町久安寺');
ok($zip->set_number('6360925')->is_valid_number, '奈良県生駒郡平群町越木塚');
ok($zip->set_number('6360931')->is_valid_number, '奈良県生駒郡平群町梨本');
ok($zip->set_number('6360932')->is_valid_number, '奈良県生駒郡平群町吉新');
ok($zip->set_number('6360933')->is_valid_number, '奈良県生駒郡平群町下垣内');
ok($zip->set_number('6360934')->is_valid_number, '奈良県生駒郡平群町初香台');
ok($zip->set_number('6360935')->is_valid_number, '奈良県生駒郡平群町光ケ丘');
ok($zip->set_number('6360936')->is_valid_number, '奈良県生駒郡平群町福貴');
ok($zip->set_number('6360937')->is_valid_number, '奈良県生駒郡平群町福貴畑');
ok($zip->set_number('6360938')->is_valid_number, '奈良県生駒郡平群町若葉台');
ok($zip->set_number('6360941')->is_valid_number, '奈良県生駒郡平群町緑ケ丘');
ok($zip->set_number('6360942')->is_valid_number, '奈良県生駒郡平群町西向');
ok($zip->set_number('6360943')->is_valid_number, '奈良県生駒郡平群町椿台');
ok($zip->set_number('6360944')->is_valid_number, '奈良県生駒郡平群町櫟原');
ok($zip->set_number('6360945')->is_valid_number, '奈良県生駒郡平群町鳴川');
ok($zip->set_number('6370000')->is_valid_number, '奈良県五條市以下に掲載がない場合');
ok($zip->set_number('6370001')->is_valid_number, '奈良県五條市西河内町');
ok($zip->set_number('6370002')->is_valid_number, '奈良県五條市三在町');
ok($zip->set_number('6370003')->is_valid_number, '奈良県五條市宇野町');
ok($zip->set_number('6370004')->is_valid_number, '奈良県五條市今井');
ok($zip->set_number('6370004')->is_valid_number, '奈良県五條市今井町');
ok($zip->set_number('6370005')->is_valid_number, '奈良県五條市須恵');
ok($zip->set_number('6370006')->is_valid_number, '奈良県五條市岡口');
ok($zip->set_number('6370011')->is_valid_number, '奈良県五條市出屋敷町');
ok($zip->set_number('6370012')->is_valid_number, '奈良県五條市小山町');
ok($zip->set_number('6370013')->is_valid_number, '奈良県五條市居伝町');
ok($zip->set_number('6370014')->is_valid_number, '奈良県五條市住川町');
ok($zip->set_number('6370015')->is_valid_number, '奈良県五條市大野新田町');
ok($zip->set_number('6370016')->is_valid_number, '奈良県五條市近内町');
ok($zip->set_number('6370017')->is_valid_number, '奈良県五條市西久留野町');
ok($zip->set_number('6370018')->is_valid_number, '奈良県五條市久留野町');
ok($zip->set_number('6370019')->is_valid_number, '奈良県五條市小和町');
ok($zip->set_number('6370020')->is_valid_number, '奈良県五條市西阿田町');
ok($zip->set_number('6370021')->is_valid_number, '奈良県五條市東阿田町');
ok($zip->set_number('6370022')->is_valid_number, '奈良県五條市八田町');
ok($zip->set_number('6370023')->is_valid_number, '奈良県五條市南阿田町');
ok($zip->set_number('6370024')->is_valid_number, '奈良県五條市滝町');
ok($zip->set_number('6370025')->is_valid_number, '奈良県五條市車谷町');
ok($zip->set_number('6370026')->is_valid_number, '奈良県五條市湯谷市塚町');
ok($zip->set_number('6370027')->is_valid_number, '奈良県五條市島野町');
ok($zip->set_number('6370028')->is_valid_number, '奈良県五條市原町');
ok($zip->set_number('6370029')->is_valid_number, '奈良県五條市山田町');
ok($zip->set_number('6370031')->is_valid_number, '奈良県五條市小島町');
ok($zip->set_number('6370032')->is_valid_number, '奈良県五條市六倉町');
ok($zip->set_number('6370033')->is_valid_number, '奈良県五條市牧町');
ok($zip->set_number('6370034')->is_valid_number, '奈良県五條市野原町');
ok($zip->set_number('6370035')->is_valid_number, '奈良県五條市霊安寺町');
ok($zip->set_number('6370036')->is_valid_number, '奈良県五條市野原西');
ok($zip->set_number('6370037')->is_valid_number, '奈良県五條市野原中');
ok($zip->set_number('6370038')->is_valid_number, '奈良県五條市野原東');
ok($zip->set_number('6370041')->is_valid_number, '奈良県五條市本町');
ok($zip->set_number('6370042')->is_valid_number, '奈良県五條市五條');
ok($zip->set_number('6370043')->is_valid_number, '奈良県五條市新町');
ok($zip->set_number('6370051')->is_valid_number, '奈良県五條市御山町');
ok($zip->set_number('6370052')->is_valid_number, '奈良県五條市丹原町');
ok($zip->set_number('6370053')->is_valid_number, '奈良県五條市生子町');
ok($zip->set_number('6370054')->is_valid_number, '奈良県五條市樫辻町');
ok($zip->set_number('6370060')->is_valid_number, '奈良県五條市大津町');
ok($zip->set_number('6370061')->is_valid_number, '奈良県五條市中町');
ok($zip->set_number('6370062')->is_valid_number, '奈良県五條市黒駒町');
ok($zip->set_number('6370063')->is_valid_number, '奈良県五條市大野町');
ok($zip->set_number('6370064')->is_valid_number, '奈良県五條市山陰町');
ok($zip->set_number('6370065')->is_valid_number, '奈良県五條市阪合部新田町');
ok($zip->set_number('6370066')->is_valid_number, '奈良県五條市大深町');
ok($zip->set_number('6370067')->is_valid_number, '奈良県五條市田殿町');
ok($zip->set_number('6370068')->is_valid_number, '奈良県五條市火打町');
ok($zip->set_number('6370069')->is_valid_number, '奈良県五條市表野町');
ok($zip->set_number('6370071')->is_valid_number, '奈良県五條市二見');
ok($zip->set_number('6370072')->is_valid_number, '奈良県五條市犬飼町');
ok($zip->set_number('6370073')->is_valid_number, '奈良県五條市上野町');
ok($zip->set_number('6370074')->is_valid_number, '奈良県五條市相谷町');
ok($zip->set_number('6370075')->is_valid_number, '奈良県五條市畑田町');
ok($zip->set_number('6370076')->is_valid_number, '奈良県五條市木ノ原町');
ok($zip->set_number('6370077')->is_valid_number, '奈良県五條市大沢町');
ok($zip->set_number('6370078')->is_valid_number, '奈良県五條市なつみ台');
ok($zip->set_number('6370081')->is_valid_number, '奈良県五條市上之町');
ok($zip->set_number('6370082')->is_valid_number, '奈良県五條市中之町');
ok($zip->set_number('6370083')->is_valid_number, '奈良県五條市下之町');
ok($zip->set_number('6370084')->is_valid_number, '奈良県五條市釜窪町');
ok($zip->set_number('6370091')->is_valid_number, '奈良県五條市北山町');
ok($zip->set_number('6370092')->is_valid_number, '奈良県五條市岡町');
ok($zip->set_number('6370093')->is_valid_number, '奈良県五條市田園');
ok($zip->set_number('6370101')->is_valid_number, '奈良県五條市西吉野町大日川');
ok($zip->set_number('6370102')->is_valid_number, '奈良県五條市西吉野町黒淵');
ok($zip->set_number('6370103')->is_valid_number, '奈良県五條市西吉野町向加名生');
ok($zip->set_number('6370104')->is_valid_number, '奈良県五條市西吉野町屋那瀬');
ok($zip->set_number('6370105')->is_valid_number, '奈良県五條市西吉野町湯塩');
ok($zip->set_number('6370111')->is_valid_number, '奈良県五條市西吉野町江出');
ok($zip->set_number('6370112')->is_valid_number, '奈良県五條市西吉野町老野');
ok($zip->set_number('6370113')->is_valid_number, '奈良県五條市西吉野町神野');
ok($zip->set_number('6370114')->is_valid_number, '奈良県五條市西吉野町滝');
ok($zip->set_number('6370115')->is_valid_number, '奈良県五條市西吉野町北曽木');
ok($zip->set_number('6370116')->is_valid_number, '奈良県五條市西吉野町和田');
ok($zip->set_number('6370117')->is_valid_number, '奈良県五條市西吉野町賀名生');
ok($zip->set_number('6370221')->is_valid_number, '奈良県五條市西吉野町永谷');
ok($zip->set_number('6370222')->is_valid_number, '奈良県五條市西吉野町立川渡');
ok($zip->set_number('6370223')->is_valid_number, '奈良県五條市西吉野町本谷');
ok($zip->set_number('6370224')->is_valid_number, '奈良県五條市西吉野町茄子原');
ok($zip->set_number('6370225')->is_valid_number, '奈良県五條市西吉野町川股');
ok($zip->set_number('6370226')->is_valid_number, '奈良県五條市西吉野町西日裏');
ok($zip->set_number('6370227')->is_valid_number, '奈良県五條市西吉野町勢井');
ok($zip->set_number('6370230')->is_valid_number, '奈良県五條市西吉野町城戸');
ok($zip->set_number('6370231')->is_valid_number, '奈良県五條市西吉野町川岸');
ok($zip->set_number('6370232')->is_valid_number, '奈良県五條市西吉野町津越');
ok($zip->set_number('6370233')->is_valid_number, '奈良県五條市西吉野町桧川迫');
ok($zip->set_number('6370234')->is_valid_number, '奈良県五條市西吉野町大峯');
ok($zip->set_number('6370235')->is_valid_number, '奈良県五條市西吉野町平雄');
ok($zip->set_number('6370236')->is_valid_number, '奈良県五條市西吉野町阪巻');
ok($zip->set_number('6370237')->is_valid_number, '奈良県五條市西吉野町宗川野');
ok($zip->set_number('6370238')->is_valid_number, '奈良県五條市西吉野町西野');
ok($zip->set_number('6370239')->is_valid_number, '奈良県五條市西吉野町陰地');
ok($zip->set_number('6370401')->is_valid_number, '奈良県五條市大塔町篠原');
ok($zip->set_number('6370402')->is_valid_number, '奈良県五條市大塔町惣谷');
ok($zip->set_number('6370403')->is_valid_number, '奈良県五條市大塔町中井傍示');
ok($zip->set_number('6370404')->is_valid_number, '奈良県五條市大塔町中峯');
ok($zip->set_number('6370405')->is_valid_number, '奈良県五條市大塔町宇井');
ok($zip->set_number('6370406')->is_valid_number, '奈良県五條市大塔町清水');
ok($zip->set_number('6370407')->is_valid_number, '奈良県五條市大塔町閉君');
ok($zip->set_number('6370408')->is_valid_number, '奈良県五條市大塔町辻堂');
ok($zip->set_number('6370409')->is_valid_number, '奈良県五條市大塔町殿野');
ok($zip->set_number('6370411')->is_valid_number, '奈良県五條市大塔町堂平');
ok($zip->set_number('6370412')->is_valid_number, '奈良県五條市大塔町飛養曽');
ok($zip->set_number('6370413')->is_valid_number, '奈良県五條市大塔町引土');
ok($zip->set_number('6370414')->is_valid_number, '奈良県五條市大塔町猿谷');
ok($zip->set_number('6370415')->is_valid_number, '奈良県五條市大塔町中原');
ok($zip->set_number('6370416')->is_valid_number, '奈良県五條市大塔町小代');
ok($zip->set_number('6370417')->is_valid_number, '奈良県五條市大塔町阪本');
ok($zip->set_number('6370419')->is_valid_number, '奈良県五條市大塔町簾');
ok($zip->set_number('6370421')->is_valid_number, '奈良県吉野郡野迫川村今井');
ok($zip->set_number('6370422')->is_valid_number, '奈良県吉野郡野迫川村平川');
ok($zip->set_number('6370423')->is_valid_number, '奈良県吉野郡野迫川村柞原');
ok($zip->set_number('6370424')->is_valid_number, '奈良県吉野郡野迫川村中');
ok($zip->set_number('6370425')->is_valid_number, '奈良県吉野郡野迫川村上');
ok($zip->set_number('6371101')->is_valid_number, '奈良県吉野郡十津川村沼田原');
ok($zip->set_number('6371102')->is_valid_number, '奈良県吉野郡十津川村旭');
ok($zip->set_number('6371103')->is_valid_number, '奈良県吉野郡十津川村上野地');
ok($zip->set_number('6371104')->is_valid_number, '奈良県吉野郡十津川村高津');
ok($zip->set_number('6371105')->is_valid_number, '奈良県吉野郡十津川村林');
ok($zip->set_number('6371106')->is_valid_number, '奈良県吉野郡十津川村谷瀬');
ok($zip->set_number('6371107')->is_valid_number, '奈良県吉野郡十津川村宇宮原');
ok($zip->set_number('6371108')->is_valid_number, '奈良県吉野郡十津川村長殿');
ok($zip->set_number('6371211')->is_valid_number, '奈良県吉野郡十津川村滝川');
ok($zip->set_number('6371212')->is_valid_number, '奈良県吉野郡十津川村内原');
ok($zip->set_number('6371213')->is_valid_number, '奈良県吉野郡十津川村野尻');
ok($zip->set_number('6371214')->is_valid_number, '奈良県吉野郡十津川村山崎');
ok($zip->set_number('6371215')->is_valid_number, '奈良県吉野郡十津川村池穴');
ok($zip->set_number('6371216')->is_valid_number, '奈良県吉野郡十津川村川津');
ok($zip->set_number('6371217')->is_valid_number, '奈良県吉野郡十津川村風屋');
ok($zip->set_number('6371221')->is_valid_number, '奈良県吉野郡十津川村内野');
ok($zip->set_number('6371222')->is_valid_number, '奈良県吉野郡十津川村山天');
ok($zip->set_number('6371223')->is_valid_number, '奈良県吉野郡十津川村三浦');
ok($zip->set_number('6371224')->is_valid_number, '奈良県吉野郡十津川村五百瀬');
ok($zip->set_number('6371225')->is_valid_number, '奈良県吉野郡十津川村杉清');
ok($zip->set_number('6371331')->is_valid_number, '奈良県吉野郡十津川村大野');
ok($zip->set_number('6371332')->is_valid_number, '奈良県吉野郡十津川村武蔵');
ok($zip->set_number('6371333')->is_valid_number, '奈良県吉野郡十津川村小原');
ok($zip->set_number('6371334')->is_valid_number, '奈良県吉野郡十津川村小森');
ok($zip->set_number('6371335')->is_valid_number, '奈良県吉野郡十津川村湯之原');
ok($zip->set_number('6371336')->is_valid_number, '奈良県吉野郡十津川村小井');
ok($zip->set_number('6371441')->is_valid_number, '奈良県吉野郡十津川村小川');
ok($zip->set_number('6371442')->is_valid_number, '奈良県吉野郡十津川村高滝');
ok($zip->set_number('6371443')->is_valid_number, '奈良県吉野郡十津川村折立');
ok($zip->set_number('6371444')->is_valid_number, '奈良県吉野郡十津川村山手谷');
ok($zip->set_number('6371445')->is_valid_number, '奈良県吉野郡十津川村込之上');
ok($zip->set_number('6371446')->is_valid_number, '奈良県吉野郡十津川村樫原');
ok($zip->set_number('6371500')->is_valid_number, '奈良県吉野郡十津川村以下に掲載がない場合');
ok($zip->set_number('6371551')->is_valid_number, '奈良県吉野郡十津川村那知合');
ok($zip->set_number('6371552')->is_valid_number, '奈良県吉野郡十津川村谷垣内');
ok($zip->set_number('6371553')->is_valid_number, '奈良県吉野郡十津川村山手');
ok($zip->set_number('6371554')->is_valid_number, '奈良県吉野郡十津川村平谷');
ok($zip->set_number('6371555')->is_valid_number, '奈良県吉野郡十津川村猿飼');
ok($zip->set_number('6371556')->is_valid_number, '奈良県吉野郡十津川村桑畑');
ok($zip->set_number('6371557')->is_valid_number, '奈良県吉野郡十津川村七色');
ok($zip->set_number('6371558')->is_valid_number, '奈良県吉野郡十津川村出谷');
ok($zip->set_number('6371559')->is_valid_number, '奈良県吉野郡十津川村上湯川');
ok($zip->set_number('6371661')->is_valid_number, '奈良県吉野郡十津川村重里');
ok($zip->set_number('6371662')->is_valid_number, '奈良県吉野郡十津川村永井');
ok($zip->set_number('6371663')->is_valid_number, '奈良県吉野郡十津川村玉垣内');
ok($zip->set_number('6371664')->is_valid_number, '奈良県吉野郡十津川村今西');
ok($zip->set_number('6371665')->is_valid_number, '奈良県吉野郡十津川村西中');
ok($zip->set_number('6371666')->is_valid_number, '奈良県吉野郡十津川村小山手');
ok($zip->set_number('6371667')->is_valid_number, '奈良県吉野郡十津川村小坪瀬');
ok($zip->set_number('6371668')->is_valid_number, '奈良県吉野郡十津川村迫西川');
ok($zip->set_number('6380000')->is_valid_number, '奈良県吉野郡大淀町以下に掲載がない場合');
ok($zip->set_number('6380000')->is_valid_number, '奈良県吉野郡下市町以下に掲載がない場合');
ok($zip->set_number('6380001')->is_valid_number, '奈良県吉野郡下市町阿知賀');
ok($zip->set_number('6380002')->is_valid_number, '奈良県吉野郡下市町小路');
ok($zip->set_number('6380003')->is_valid_number, '奈良県吉野郡下市町善城');
ok($zip->set_number('6380011')->is_valid_number, '奈良県吉野郡下市町よ邑');
ok($zip->set_number('6380012')->is_valid_number, '奈良県吉野郡下市町岩森');
ok($zip->set_number('6380013')->is_valid_number, '奈良県吉野郡下市町立石');
ok($zip->set_number('6380014')->is_valid_number, '奈良県吉野郡下市町才谷');
ok($zip->set_number('6380015')->is_valid_number, '奈良県吉野郡下市町広橋');
ok($zip->set_number('6380021')->is_valid_number, '奈良県吉野郡下市町長谷');
ok($zip->set_number('6380022')->is_valid_number, '奈良県吉野郡下市町丹生');
ok($zip->set_number('6380023')->is_valid_number, '奈良県吉野郡下市町黒木');
ok($zip->set_number('6380024')->is_valid_number, '奈良県吉野郡下市町貝原');
ok($zip->set_number('6380025')->is_valid_number, '奈良県吉野郡下市町谷');
ok($zip->set_number('6380026')->is_valid_number, '奈良県吉野郡下市町西山');
ok($zip->set_number('6380031')->is_valid_number, '奈良県吉野郡下市町栃本');
ok($zip->set_number('6380032')->is_valid_number, '奈良県吉野郡下市町原谷');
ok($zip->set_number('6380033')->is_valid_number, '奈良県吉野郡下市町梨子堂');
ok($zip->set_number('6380034')->is_valid_number, '奈良県吉野郡下市町平原');
ok($zip->set_number('6380035')->is_valid_number, '奈良県吉野郡下市町栃原');
ok($zip->set_number('6380041')->is_valid_number, '奈良県吉野郡下市町下市');
ok($zip->set_number('6380042')->is_valid_number, '奈良県吉野郡下市町栄町');
ok($zip->set_number('6380043')->is_valid_number, '奈良県吉野郡下市町大峯');
ok($zip->set_number('6380044')->is_valid_number, '奈良県吉野郡下市町田中');
ok($zip->set_number('6380045')->is_valid_number, '奈良県吉野郡下市町新住');
ok($zip->set_number('6380200')->is_valid_number, '奈良県吉野郡黒滝村以下に掲載がない場合');
ok($zip->set_number('6380201')->is_valid_number, '奈良県吉野郡黒滝村槇尾');
ok($zip->set_number('6380202')->is_valid_number, '奈良県吉野郡黒滝村脇川');
ok($zip->set_number('6380203')->is_valid_number, '奈良県吉野郡黒滝村鳥住');
ok($zip->set_number('6380211')->is_valid_number, '奈良県吉野郡黒滝村赤滝');
ok($zip->set_number('6380221')->is_valid_number, '奈良県吉野郡黒滝村中戸');
ok($zip->set_number('6380231')->is_valid_number, '奈良県吉野郡黒滝村笠木');
ok($zip->set_number('6380232')->is_valid_number, '奈良県吉野郡黒滝村桂原');
ok($zip->set_number('6380233')->is_valid_number, '奈良県吉野郡黒滝村長瀬');
ok($zip->set_number('6380241')->is_valid_number, '奈良県吉野郡黒滝村粟飯谷');
ok($zip->set_number('6380242')->is_valid_number, '奈良県吉野郡黒滝村御吉野');
ok($zip->set_number('6380243')->is_valid_number, '奈良県吉野郡黒滝村堂原');
ok($zip->set_number('6380251')->is_valid_number, '奈良県吉野郡黒滝村寺戸');
ok($zip->set_number('6380300')->is_valid_number, '奈良県吉野郡天川村以下に掲載がない場合');
ok($zip->set_number('6380301')->is_valid_number, '奈良県吉野郡天川村川合');
ok($zip->set_number('6380302')->is_valid_number, '奈良県吉野郡天川村中越');
ok($zip->set_number('6380303')->is_valid_number, '奈良県吉野郡天川村北角');
ok($zip->set_number('6380304')->is_valid_number, '奈良県吉野郡天川村南角');
ok($zip->set_number('6380305')->is_valid_number, '奈良県吉野郡天川村沢谷');
ok($zip->set_number('6380311')->is_valid_number, '奈良県吉野郡天川村沖金');
ok($zip->set_number('6380312')->is_valid_number, '奈良県吉野郡天川村中谷');
ok($zip->set_number('6380313')->is_valid_number, '奈良県吉野郡天川村北小原');
ok($zip->set_number('6380314')->is_valid_number, '奈良県吉野郡天川村五色');
ok($zip->set_number('6380315')->is_valid_number, '奈良県吉野郡天川村沢原');
ok($zip->set_number('6380321')->is_valid_number, '奈良県吉野郡天川村坪内');
ok($zip->set_number('6380322')->is_valid_number, '奈良県吉野郡天川村南日裏');
ok($zip->set_number('6380431')->is_valid_number, '奈良県吉野郡天川村洞川');
ok($zip->set_number('6380541')->is_valid_number, '奈良県吉野郡天川村九尾');
ok($zip->set_number('6380542')->is_valid_number, '奈良県吉野郡天川村栃尾');
ok($zip->set_number('6380543')->is_valid_number, '奈良県吉野郡天川村和田');
ok($zip->set_number('6380551')->is_valid_number, '奈良県吉野郡天川村籠山');
ok($zip->set_number('6380552')->is_valid_number, '奈良県吉野郡天川村庵住');
ok($zip->set_number('6380553')->is_valid_number, '奈良県吉野郡天川村山西');
ok($zip->set_number('6380561')->is_valid_number, '奈良県吉野郡天川村広瀬');
ok($zip->set_number('6380562')->is_valid_number, '奈良県吉野郡天川村滝尾');
ok($zip->set_number('6380563')->is_valid_number, '奈良県吉野郡天川村塩野');
ok($zip->set_number('6380564')->is_valid_number, '奈良県吉野郡天川村塩谷');
ok($zip->set_number('6380641')->is_valid_number, '奈良県五條市西吉野町百谷');
ok($zip->set_number('6380642')->is_valid_number, '奈良県五條市西吉野町平沼田');
ok($zip->set_number('6380643')->is_valid_number, '奈良県五條市西吉野町赤松');
ok($zip->set_number('6380644')->is_valid_number, '奈良県五條市西吉野町湯川');
ok($zip->set_number('6380651')->is_valid_number, '奈良県五條市西吉野町唐戸');
ok($zip->set_number('6380652')->is_valid_number, '奈良県五條市西吉野町尼ケ生');
ok($zip->set_number('6380653')->is_valid_number, '奈良県五條市西吉野町十日市');
ok($zip->set_number('6380654')->is_valid_number, '奈良県五條市西吉野町南山');
ok($zip->set_number('6380655')->is_valid_number, '奈良県五條市西吉野町小古田');
ok($zip->set_number('6380656')->is_valid_number, '奈良県五條市西吉野町鹿場');
ok($zip->set_number('6380657')->is_valid_number, '奈良県五條市西吉野町八ツ川');
ok($zip->set_number('6380661')->is_valid_number, '奈良県五條市西吉野町西新子');
ok($zip->set_number('6380662')->is_valid_number, '奈良県五條市西吉野町夜中');
ok($zip->set_number('6380663')->is_valid_number, '奈良県五條市西吉野町奥谷');
ok($zip->set_number('6380801')->is_valid_number, '奈良県吉野郡大淀町芦原');
ok($zip->set_number('6380802')->is_valid_number, '奈良県吉野郡大淀町畑屋');
ok($zip->set_number('6380803')->is_valid_number, '奈良県吉野郡大淀町越部');
ok($zip->set_number('6380811')->is_valid_number, '奈良県吉野郡大淀町土田');
ok($zip->set_number('6380812')->is_valid_number, '奈良県吉野郡大淀町桧垣本');
ok($zip->set_number('6380821')->is_valid_number, '奈良県吉野郡大淀町下渕');
ok($zip->set_number('6380831')->is_valid_number, '奈良県吉野郡大淀町佐名伝');
ok($zip->set_number('6380832')->is_valid_number, '奈良県吉野郡大淀町薬水');
ok($zip->set_number('6380833')->is_valid_number, '奈良県吉野郡大淀町福神');
ok($zip->set_number('6380841')->is_valid_number, '奈良県吉野郡大淀町今木');
ok($zip->set_number('6380842')->is_valid_number, '奈良県吉野郡大淀町大岩');
ok($zip->set_number('6380843')->is_valid_number, '奈良県吉野郡大淀町鉾立');
ok($zip->set_number('6380851')->is_valid_number, '奈良県吉野郡大淀町岩壺');
ok($zip->set_number('6380852')->is_valid_number, '奈良県吉野郡大淀町持尾');
ok($zip->set_number('6380853')->is_valid_number, '奈良県吉野郡大淀町矢走');
ok($zip->set_number('6390200')->is_valid_number, '奈良県香芝市以下に掲載がない場合');
ok($zip->set_number('6390200')->is_valid_number, '奈良県北葛城郡上牧町以下に掲載がない場合');
ok($zip->set_number('6390201')->is_valid_number, '奈良県北葛城郡上牧町片岡台');
ok($zip->set_number('6390202')->is_valid_number, '奈良県北葛城郡上牧町桜ケ丘');
ok($zip->set_number('6390203')->is_valid_number, '奈良県北葛城郡上牧町友が丘');
ok($zip->set_number('6390204')->is_valid_number, '奈良県北葛城郡上牧町緑ケ丘');
ok($zip->set_number('6390205')->is_valid_number, '奈良県北葛城郡上牧町下牧');
ok($zip->set_number('6390206')->is_valid_number, '奈良県北葛城郡上牧町ゆりが丘');
ok($zip->set_number('6390211')->is_valid_number, '奈良県北葛城郡上牧町滝川台');
ok($zip->set_number('6390212')->is_valid_number, '奈良県北葛城郡上牧町服部台');
ok($zip->set_number('6390213')->is_valid_number, '奈良県北葛城郡上牧町米山台');
ok($zip->set_number('6390214')->is_valid_number, '奈良県北葛城郡上牧町上牧');
ok($zip->set_number('6390215')->is_valid_number, '奈良県北葛城郡上牧町葛城台');
ok($zip->set_number('6390216')->is_valid_number, '奈良県北葛城郡上牧町松里園');
ok($zip->set_number('6390217')->is_valid_number, '奈良県北葛城郡上牧町中筋出作');
ok($zip->set_number('6390218')->is_valid_number, '奈良県北葛城郡上牧町ささゆり台');
ok($zip->set_number('6390221')->is_valid_number, '奈良県香芝市五ケ所');
ok($zip->set_number('6390222')->is_valid_number, '奈良県香芝市西真美');
ok($zip->set_number('6390223')->is_valid_number, '奈良県香芝市真美ケ丘');
ok($zip->set_number('6390224')->is_valid_number, '奈良県香芝市別所');
ok($zip->set_number('6390225')->is_valid_number, '奈良県香芝市瓦口');
ok($zip->set_number('6390226')->is_valid_number, '奈良県香芝市五位堂');
ok($zip->set_number('6390227')->is_valid_number, '奈良県香芝市鎌田');
ok($zip->set_number('6390231')->is_valid_number, '奈良県香芝市下田西');
ok($zip->set_number('6390232')->is_valid_number, '奈良県香芝市下田東');
ok($zip->set_number('6390233')->is_valid_number, '奈良県香芝市下田');
ok($zip->set_number('6390234')->is_valid_number, '奈良県香芝市狐井');
ok($zip->set_number('6390235')->is_valid_number, '奈良県香芝市良福寺');
ok($zip->set_number('6390236')->is_valid_number, '奈良県香芝市磯壁');
ok($zip->set_number('6390237')->is_valid_number, '奈良県香芝市すみれ野');
ok($zip->set_number('6390241')->is_valid_number, '奈良県香芝市高');
ok($zip->set_number('6390242')->is_valid_number, '奈良県香芝市北今市');
ok($zip->set_number('6390243')->is_valid_number, '奈良県香芝市藤山');
ok($zip->set_number('6390244')->is_valid_number, '奈良県香芝市本町');
ok($zip->set_number('6390245')->is_valid_number, '奈良県香芝市畑');
ok($zip->set_number('6390251')->is_valid_number, '奈良県香芝市逢坂');
ok($zip->set_number('6390252')->is_valid_number, '奈良県香芝市穴虫');
ok($zip->set_number('6390253')->is_valid_number, '奈良県香芝市田尻');
ok($zip->set_number('6390254')->is_valid_number, '奈良県香芝市関屋北');
ok($zip->set_number('6390255')->is_valid_number, '奈良県香芝市関屋');
ok($zip->set_number('6390256')->is_valid_number, '奈良県香芝市高山台');
ok($zip->set_number('6390261')->is_valid_number, '奈良県香芝市尼寺');
ok($zip->set_number('6390262')->is_valid_number, '奈良県香芝市白鳳台');
ok($zip->set_number('6390263')->is_valid_number, '奈良県香芝市平野');
ok($zip->set_number('6390264')->is_valid_number, '奈良県香芝市今泉');
ok($zip->set_number('6390265')->is_valid_number, '奈良県香芝市上中');
ok($zip->set_number('6390266')->is_valid_number, '奈良県香芝市旭ケ丘');
ok($zip->set_number('6390271')->is_valid_number, '奈良県葛城市加守');
ok($zip->set_number('6390272')->is_valid_number, '奈良県葛城市新在家');
ok($zip->set_number('6390273')->is_valid_number, '奈良県葛城市染野');
ok($zip->set_number('6390274')->is_valid_number, '奈良県葛城市今在家');
ok($zip->set_number('6390275')->is_valid_number, '奈良県葛城市勝根');
ok($zip->set_number('6390276')->is_valid_number, '奈良県葛城市當麻');
ok($zip->set_number('6391001')->is_valid_number, '奈良県大和郡山市九条町');
ok($zip->set_number('6391002')->is_valid_number, '奈良県大和郡山市九条平野町');
ok($zip->set_number('6391003')->is_valid_number, '奈良県大和郡山市代官町');
ok($zip->set_number('6391004')->is_valid_number, '奈良県大和郡山市城北町');
ok($zip->set_number('6391005')->is_valid_number, '奈良県大和郡山市植槻町');
ok($zip->set_number('6391006')->is_valid_number, '奈良県大和郡山市天理町');
ok($zip->set_number('6391007')->is_valid_number, '奈良県大和郡山市南郡山町');
ok($zip->set_number('6391008')->is_valid_number, '奈良県大和郡山市城の台町');
ok($zip->set_number('6391011')->is_valid_number, '奈良県大和郡山市城内町');
ok($zip->set_number('6391012')->is_valid_number, '奈良県大和郡山市城見町');
ok($zip->set_number('6391013')->is_valid_number, '奈良県大和郡山市朝日町');
ok($zip->set_number('6391014')->is_valid_number, '奈良県大和郡山市西岡町');
ok($zip->set_number('6391015')->is_valid_number, '奈良県大和郡山市箕山町');
ok($zip->set_number('6391016')->is_valid_number, '奈良県大和郡山市城南町');
ok($zip->set_number('6391017')->is_valid_number, '奈良県大和郡山市藤原町');
ok($zip->set_number('6391018')->is_valid_number, '奈良県大和郡山市冠山町');
ok($zip->set_number('6391019')->is_valid_number, '奈良県大和郡山市永慶寺町');
ok($zip->set_number('6391021')->is_valid_number, '奈良県大和郡山市新木町');
ok($zip->set_number('6391022')->is_valid_number, '奈良県大和郡山市豊浦町');
ok($zip->set_number('6391023')->is_valid_number, '奈良県大和郡山市小南町');
ok($zip->set_number('6391024')->is_valid_number, '奈良県大和郡山市南井町');
ok($zip->set_number('6391025')->is_valid_number, '奈良県大和郡山市北西町');
ok($zip->set_number('6391026')->is_valid_number, '奈良県大和郡山市小林町');
ok($zip->set_number('6391027')->is_valid_number, '奈良県大和郡山市池之内町');
ok($zip->set_number('6391028')->is_valid_number, '奈良県大和郡山市田中町');
ok($zip->set_number('6391031')->is_valid_number, '奈良県大和郡山市今国府町');
ok($zip->set_number('6391032')->is_valid_number, '奈良県大和郡山市池沢町');
ok($zip->set_number('6391033')->is_valid_number, '奈良県大和郡山市昭和町');
ok($zip->set_number('6391034')->is_valid_number, '奈良県大和郡山市柏木町');
ok($zip->set_number('6391035')->is_valid_number, '奈良県大和郡山市額田部南町');
ok($zip->set_number('6391036')->is_valid_number, '奈良県大和郡山市額田部寺町');
ok($zip->set_number('6391037')->is_valid_number, '奈良県大和郡山市額田部北町');
ok($zip->set_number('6391038')->is_valid_number, '奈良県大和郡山市西町');
ok($zip->set_number('6391039')->is_valid_number, '奈良県大和郡山市椎木町');
ok($zip->set_number('6391041')->is_valid_number, '奈良県大和郡山市満願寺町');
ok($zip->set_number('6391042')->is_valid_number, '奈良県大和郡山市小泉町');
ok($zip->set_number('6391043')->is_valid_number, '奈良県大和郡山市西田中町');
ok($zip->set_number('6391044')->is_valid_number, '奈良県大和郡山市小泉町東');
ok($zip->set_number('6391045')->is_valid_number, '奈良県大和郡山市小林町西');
ok($zip->set_number('6391051')->is_valid_number, '奈良県大和郡山市城町');
ok($zip->set_number('6391052')->is_valid_number, '奈良県大和郡山市外川町');
ok($zip->set_number('6391053')->is_valid_number, '奈良県大和郡山市千日町');
ok($zip->set_number('6391054')->is_valid_number, '奈良県大和郡山市新町');
ok($zip->set_number('6391055')->is_valid_number, '奈良県大和郡山市矢田山町');
ok($zip->set_number('6391056')->is_valid_number, '奈良県大和郡山市泉原町');
ok($zip->set_number('6391057')->is_valid_number, '奈良県大和郡山市山田町');
ok($zip->set_number('6391058')->is_valid_number, '奈良県大和郡山市矢田町');
ok($zip->set_number('6391061')->is_valid_number, '奈良県生駒郡安堵町東安堵');
ok($zip->set_number('6391062')->is_valid_number, '奈良県生駒郡安堵町岡崎');
ok($zip->set_number('6391063')->is_valid_number, '奈良県生駒郡安堵町かしの木台');
ok($zip->set_number('6391064')->is_valid_number, '奈良県生駒郡安堵町窪田');
ok($zip->set_number('6391065')->is_valid_number, '奈良県生駒郡安堵町笠目');
ok($zip->set_number('6391066')->is_valid_number, '奈良県生駒郡安堵町西安堵');
ok($zip->set_number('6391100')->is_valid_number, '奈良県大和郡山市以下に掲載がない場合');
ok($zip->set_number('6391100')->is_valid_number, '奈良県生駒郡安堵町以下に掲載がない場合');
ok($zip->set_number('6391101')->is_valid_number, '奈良県大和郡山市下三橋町');
ok($zip->set_number('6391102')->is_valid_number, '奈良県大和郡山市上三橋町');
ok($zip->set_number('6391103')->is_valid_number, '奈良県大和郡山市美濃庄町');
ok($zip->set_number('6391104')->is_valid_number, '奈良県大和郡山市井戸野町');
ok($zip->set_number('6391105')->is_valid_number, '奈良県大和郡山市番匠田中町');
ok($zip->set_number('6391106')->is_valid_number, '奈良県大和郡山市大江町');
ok($zip->set_number('6391107')->is_valid_number, '奈良県大和郡山市若槻町');
ok($zip->set_number('6391108')->is_valid_number, '奈良県大和郡山市稗田町');
ok($zip->set_number('6391111')->is_valid_number, '奈良県大和郡山市石川町');
ok($zip->set_number('6391112')->is_valid_number, '奈良県大和郡山市白土町');
ok($zip->set_number('6391113')->is_valid_number, '奈良県大和郡山市櫟枝町');
ok($zip->set_number('6391114')->is_valid_number, '奈良県大和郡山市新庄町');
ok($zip->set_number('6391115')->is_valid_number, '奈良県大和郡山市横田町');
ok($zip->set_number('6391116')->is_valid_number, '奈良県大和郡山市伊豆七条町');
ok($zip->set_number('6391117')->is_valid_number, '奈良県大和郡山市番条町');
ok($zip->set_number('6391118')->is_valid_number, '奈良県大和郡山市中城町');
ok($zip->set_number('6391119')->is_valid_number, '奈良県大和郡山市発志院町');
ok($zip->set_number('6391121')->is_valid_number, '奈良県大和郡山市杉町');
ok($zip->set_number('6391122')->is_valid_number, '奈良県大和郡山市丹後庄町');
ok($zip->set_number('6391123')->is_valid_number, '奈良県大和郡山市筒井町');
ok($zip->set_number('6391124')->is_valid_number, '奈良県大和郡山市馬司町');
ok($zip->set_number('6391125')->is_valid_number, '奈良県大和郡山市八条町');
ok($zip->set_number('6391126')->is_valid_number, '奈良県大和郡山市宮堂町');
ok($zip->set_number('6391127')->is_valid_number, '奈良県大和郡山市長安寺町');
ok($zip->set_number('6391131')->is_valid_number, '奈良県大和郡山市野垣内町');
ok($zip->set_number('6391132')->is_valid_number, '奈良県大和郡山市高田町');
ok($zip->set_number('6391133')->is_valid_number, '奈良県大和郡山市高田口町');
ok($zip->set_number('6391134')->is_valid_number, '奈良県大和郡山市柳');
ok($zip->set_number('6391134')->is_valid_number, '奈良県大和郡山市柳町');
ok($zip->set_number('6391135')->is_valid_number, '奈良県大和郡山市天井町');
ok($zip->set_number('6391136')->is_valid_number, '奈良県大和郡山市本庄町');
ok($zip->set_number('6391137')->is_valid_number, '奈良県大和郡山市東岡町');
ok($zip->set_number('6391138')->is_valid_number, '奈良県大和郡山市大宮町');
ok($zip->set_number('6391141')->is_valid_number, '奈良県大和郡山市材木町');
ok($zip->set_number('6391142')->is_valid_number, '奈良県大和郡山市矢田町通');
ok($zip->set_number('6391143')->is_valid_number, '奈良県大和郡山市新紺屋町');
ok($zip->set_number('6391144')->is_valid_number, '奈良県大和郡山市洞泉寺町');
ok($zip->set_number('6391145')->is_valid_number, '奈良県大和郡山市南大工町');
ok($zip->set_number('6391146')->is_valid_number, '奈良県大和郡山市北大工町');
ok($zip->set_number('6391147')->is_valid_number, '奈良県大和郡山市車町');
ok($zip->set_number('6391148')->is_valid_number, '奈良県大和郡山市紺屋町');
ok($zip->set_number('6391149')->is_valid_number, '奈良県大和郡山市豆腐町');
ok($zip->set_number('6391150')->is_valid_number, '奈良県大和郡山市雑穀町');
ok($zip->set_number('6391151')->is_valid_number, '奈良県大和郡山市本町');
ok($zip->set_number('6391152')->is_valid_number, '奈良県大和郡山市茶町');
ok($zip->set_number('6391153')->is_valid_number, '奈良県大和郡山市西野垣内町');
ok($zip->set_number('6391154')->is_valid_number, '奈良県大和郡山市綿町');
ok($zip->set_number('6391155')->is_valid_number, '奈良県大和郡山市今井町');
ok($zip->set_number('6391156')->is_valid_number, '奈良県大和郡山市堺町');
ok($zip->set_number('6391157')->is_valid_number, '奈良県大和郡山市新中町');
ok($zip->set_number('6391158')->is_valid_number, '奈良県大和郡山市藺町');
ok($zip->set_number('6391159')->is_valid_number, '奈良県大和郡山市奈良町');
ok($zip->set_number('6391160')->is_valid_number, '奈良県大和郡山市北郡山町');
ok($zip->set_number('6391161')->is_valid_number, '奈良県大和郡山市観音寺町');
ok($zip->set_number('6391162')->is_valid_number, '奈良県大和郡山市東奈良口町');
ok($zip->set_number('6391163')->is_valid_number, '奈良県大和郡山市西奈良口町');
ok($zip->set_number('6391164')->is_valid_number, '奈良県大和郡山市西観音寺町');
ok($zip->set_number('6391165')->is_valid_number, '奈良県大和郡山市北鍛冶町');
ok($zip->set_number('6391166')->is_valid_number, '奈良県大和郡山市中鍛冶町');
ok($zip->set_number('6391167')->is_valid_number, '奈良県大和郡山市南鍛冶町');
ok($zip->set_number('6391168')->is_valid_number, '奈良県大和郡山市魚町');
ok($zip->set_number('6391169')->is_valid_number, '奈良県大和郡山市塩町');
ok($zip->set_number('6392100')->is_valid_number, '奈良県葛城市以下に掲載がない場合');
ok($zip->set_number('6392101')->is_valid_number, '奈良県葛城市疋田');
ok($zip->set_number('6392102')->is_valid_number, '奈良県葛城市東室');
ok($zip->set_number('6392103')->is_valid_number, '奈良県葛城市西室');
ok($zip->set_number('6392111')->is_valid_number, '奈良県葛城市柿本');
ok($zip->set_number('6392112')->is_valid_number, '奈良県葛城市笛堂');
ok($zip->set_number('6392113')->is_valid_number, '奈良県葛城市北花内');
ok($zip->set_number('6392121')->is_valid_number, '奈良県葛城市新村');
ok($zip->set_number('6392122')->is_valid_number, '奈良県葛城市薑');
ok($zip->set_number('6392123')->is_valid_number, '奈良県葛城市忍海');
ok($zip->set_number('6392123')->is_valid_number, '奈良県葛城市南新町');
ok($zip->set_number('6392124')->is_valid_number, '奈良県葛城市脇田');
ok($zip->set_number('6392125')->is_valid_number, '奈良県葛城市西辻');
ok($zip->set_number('6392126')->is_valid_number, '奈良県葛城市南花内');
ok($zip->set_number('6392127')->is_valid_number, '奈良県葛城市新町');
ok($zip->set_number('6392131')->is_valid_number, '奈良県葛城市林堂');
ok($zip->set_number('6392132')->is_valid_number, '奈良県葛城市笛吹');
ok($zip->set_number('6392133')->is_valid_number, '奈良県葛城市梅室');
ok($zip->set_number('6392134')->is_valid_number, '奈良県葛城市山口');
ok($zip->set_number('6392135')->is_valid_number, '奈良県葛城市寺口');
ok($zip->set_number('6392136')->is_valid_number, '奈良県葛城市平岡');
ok($zip->set_number('6392137')->is_valid_number, '奈良県葛城市南藤井');
ok($zip->set_number('6392138')->is_valid_number, '奈良県葛城市山田');
ok($zip->set_number('6392141')->is_valid_number, '奈良県葛城市弁之庄');
ok($zip->set_number('6392142')->is_valid_number, '奈良県葛城市北道穂');
ok($zip->set_number('6392143')->is_valid_number, '奈良県葛城市南道穂');
ok($zip->set_number('6392144')->is_valid_number, '奈良県葛城市葛木');
ok($zip->set_number('6392145')->is_valid_number, '奈良県葛城市大屋');
ok($zip->set_number('6392146')->is_valid_number, '奈良県葛城市中戸');
ok($zip->set_number('6392147')->is_valid_number, '奈良県葛城市新庄');
ok($zip->set_number('6392151')->is_valid_number, '奈良県葛城市南今市');
ok($zip->set_number('6392152')->is_valid_number, '奈良県葛城市大畑');
ok($zip->set_number('6392153')->is_valid_number, '奈良県葛城市太田');
ok($zip->set_number('6392154')->is_valid_number, '奈良県葛城市兵家');
ok($zip->set_number('6392155')->is_valid_number, '奈良県葛城市竹内');
ok($zip->set_number('6392161')->is_valid_number, '奈良県葛城市木戸');
ok($zip->set_number('6392162')->is_valid_number, '奈良県葛城市尺土');
ok($zip->set_number('6392163')->is_valid_number, '奈良県葛城市八川');
ok($zip->set_number('6392164')->is_valid_number, '奈良県葛城市長尾');
ok($zip->set_number('6392200')->is_valid_number, '奈良県御所市以下に掲載がない場合');
ok($zip->set_number('6392201')->is_valid_number, '奈良県御所市柳原');
ok($zip->set_number('6392202')->is_valid_number, '奈良県御所市出屋敷');
ok($zip->set_number('6392203')->is_valid_number, '奈良県御所市北十三');
ok($zip->set_number('6392204')->is_valid_number, '奈良県御所市南十三');
ok($zip->set_number('6392205')->is_valid_number, '奈良県御所市東辻');
ok($zip->set_number('6392206')->is_valid_number, '奈良県御所市竹田');
ok($zip->set_number('6392207')->is_valid_number, '奈良県御所市今城');
ok($zip->set_number('6392211')->is_valid_number, '奈良県御所市JR御所駅前通り');
ok($zip->set_number('6392212')->is_valid_number, '奈良県御所市中央通り');
ok($zip->set_number('6392213')->is_valid_number, '奈良県御所市神宮町');
ok($zip->set_number('6392214')->is_valid_number, '奈良県御所市御堂魚棚町');
ok($zip->set_number('6392215')->is_valid_number, '奈良県御所市西町');
ok($zip->set_number('6392216')->is_valid_number, '奈良県御所市御国通り');
ok($zip->set_number('6392217')->is_valid_number, '奈良県御所市新地町');
ok($zip->set_number('6392221')->is_valid_number, '奈良県御所市栄町');
ok($zip->set_number('6392222')->is_valid_number, '奈良県御所市六軒町');
ok($zip->set_number('6392223')->is_valid_number, '奈良県御所市本町');
ok($zip->set_number('6392224')->is_valid_number, '奈良県御所市西柏町');
ok($zip->set_number('6392225')->is_valid_number, '奈良県御所市中本町');
ok($zip->set_number('6392226')->is_valid_number, '奈良県御所市南中町');
ok($zip->set_number('6392227')->is_valid_number, '奈良県御所市東久保町');
ok($zip->set_number('6392228')->is_valid_number, '奈良県御所市西久保本町');
ok($zip->set_number('6392229')->is_valid_number, '奈良県御所市鴨口町');
ok($zip->set_number('6392231')->is_valid_number, '奈良県御所市柿ケ坪町');
ok($zip->set_number('6392232')->is_valid_number, '奈良県御所市御門町');
ok($zip->set_number('6392233')->is_valid_number, '奈良県御所市都町');
ok($zip->set_number('6392234')->is_valid_number, '奈良県御所市柳町');
ok($zip->set_number('6392235')->is_valid_number, '奈良県御所市寺内町');
ok($zip->set_number('6392236')->is_valid_number, '奈良県御所市代官町');
ok($zip->set_number('6392237')->is_valid_number, '奈良県御所市豊年橋通り');
ok($zip->set_number('6392238')->is_valid_number, '奈良県御所市大橋通り');
ok($zip->set_number('6392239')->is_valid_number, '奈良県御所市旭町');
ok($zip->set_number('6392241')->is_valid_number, '奈良県御所市茅原');
ok($zip->set_number('6392242')->is_valid_number, '奈良県御所市本馬');
ok($zip->set_number('6392243')->is_valid_number, '奈良県御所市東寺田');
ok($zip->set_number('6392244')->is_valid_number, '奈良県御所市柏原');
ok($zip->set_number('6392245')->is_valid_number, '奈良県御所市今住');
ok($zip->set_number('6392246')->is_valid_number, '奈良県御所市原谷');
ok($zip->set_number('6392247')->is_valid_number, '奈良県御所市玉手');
ok($zip->set_number('6392248')->is_valid_number, '奈良県御所市緑町');
ok($zip->set_number('6392251')->is_valid_number, '奈良県御所市戸毛');
ok($zip->set_number('6392252')->is_valid_number, '奈良県御所市樋野');
ok($zip->set_number('6392253')->is_valid_number, '奈良県御所市奉膳');
ok($zip->set_number('6392254')->is_valid_number, '奈良県御所市古瀬');
ok($zip->set_number('6392255')->is_valid_number, '奈良県御所市朝町');
ok($zip->set_number('6392256')->is_valid_number, '奈良県御所市栗阪');
ok($zip->set_number('6392257')->is_valid_number, '奈良県御所市小殿');
ok($zip->set_number('6392258')->is_valid_number, '奈良県御所市稲宿');
ok($zip->set_number('6392261')->is_valid_number, '奈良県御所市城山台');
ok($zip->set_number('6392262')->is_valid_number, '奈良県御所市東持田');
ok($zip->set_number('6392262')->is_valid_number, '奈良県御所市持田');
ok($zip->set_number('6392263')->is_valid_number, '奈良県御所市鳥井戸');
ok($zip->set_number('6392264')->is_valid_number, '奈良県御所市五百家');
ok($zip->set_number('6392265')->is_valid_number, '奈良県御所市新田');
ok($zip->set_number('6392266')->is_valid_number, '奈良県御所市重阪');
ok($zip->set_number('6392267')->is_valid_number, '奈良県御所市内谷');
ok($zip->set_number('6392268')->is_valid_number, '奈良県御所市船路');
ok($zip->set_number('6392271')->is_valid_number, '奈良県御所市宮前町');
ok($zip->set_number('6392272')->is_valid_number, '奈良県御所市蛇穴');
ok($zip->set_number('6392273')->is_valid_number, '奈良県御所市池之内');
ok($zip->set_number('6392274')->is_valid_number, '奈良県御所市冨田');
ok($zip->set_number('6392275')->is_valid_number, '奈良県御所市出走');
ok($zip->set_number('6392276')->is_valid_number, '奈良県御所市條');
ok($zip->set_number('6392277')->is_valid_number, '奈良県御所市室');
ok($zip->set_number('6392278')->is_valid_number, '奈良県御所市緑ケ丘');
ok($zip->set_number('6392279')->is_valid_number, '奈良県御所市今出');
ok($zip->set_number('6392301')->is_valid_number, '奈良県御所市元町');
ok($zip->set_number('6392302')->is_valid_number, '奈良県御所市東松本');
ok($zip->set_number('6392303')->is_valid_number, '奈良県御所市末広町');
ok($zip->set_number('6392304')->is_valid_number, '奈良県御所市大広町');
ok($zip->set_number('6392305')->is_valid_number, '奈良県御所市柳田町');
ok($zip->set_number('6392306')->is_valid_number, '奈良県御所市三室');
ok($zip->set_number('6392311')->is_valid_number, '奈良県御所市小林');
ok($zip->set_number('6392312')->is_valid_number, '奈良県御所市櫛羅');
ok($zip->set_number('6392313')->is_valid_number, '奈良県御所市楢原');
ok($zip->set_number('6392314')->is_valid_number, '奈良県御所市幸町');
ok($zip->set_number('6392315')->is_valid_number, '奈良県御所市宮戸');
ok($zip->set_number('6392316')->is_valid_number, '奈良県御所市西寺田');
ok($zip->set_number('6392317')->is_valid_number, '奈良県御所市豊田');
ok($zip->set_number('6392318')->is_valid_number, '奈良県御所市森脇');
ok($zip->set_number('6392321')->is_valid_number, '奈良県御所市名柄');
ok($zip->set_number('6392322')->is_valid_number, '奈良県御所市東名柄');
ok($zip->set_number('6392323')->is_valid_number, '奈良県御所市多田');
ok($zip->set_number('6392324')->is_valid_number, '奈良県御所市下茶屋');
ok($zip->set_number('6392325')->is_valid_number, '奈良県御所市佐田');
ok($zip->set_number('6392326')->is_valid_number, '奈良県御所市井戸');
ok($zip->set_number('6392327')->is_valid_number, '奈良県御所市増');
ok($zip->set_number('6392328')->is_valid_number, '奈良県御所市関屋');
ok($zip->set_number('6392331')->is_valid_number, '奈良県御所市南郷');
ok($zip->set_number('6392332')->is_valid_number, '奈良県御所市西持田');
ok($zip->set_number('6392333')->is_valid_number, '奈良県御所市林');
ok($zip->set_number('6392334')->is_valid_number, '奈良県御所市北窪');
ok($zip->set_number('6392335')->is_valid_number, '奈良県御所市西北窪');
ok($zip->set_number('6392336')->is_valid_number, '奈良県御所市高天');
ok($zip->set_number('6392337')->is_valid_number, '奈良県御所市極楽寺');
ok($zip->set_number('6392341')->is_valid_number, '奈良県御所市朝妻');
ok($zip->set_number('6392342')->is_valid_number, '奈良県御所市僧堂');
ok($zip->set_number('6392343')->is_valid_number, '奈良県御所市鴨神');
ok($zip->set_number('6392344')->is_valid_number, '奈良県御所市東佐味');
ok($zip->set_number('6392345')->is_valid_number, '奈良県御所市西佐味');
ok($zip->set_number('6392346')->is_valid_number, '奈良県御所市伏見');
ok($zip->set_number('6393100')->is_valid_number, '奈良県吉野郡吉野町以下に掲載がない場合');
ok($zip->set_number('6393101')->is_valid_number, '奈良県吉野郡吉野町山口');
ok($zip->set_number('6393102')->is_valid_number, '奈良県吉野郡吉野町河原屋');
ok($zip->set_number('6393102')->is_valid_number, '奈良県吉野郡吉野町津風呂');
ok($zip->set_number('6393103')->is_valid_number, '奈良県吉野郡吉野町平尾');
ok($zip->set_number('6393104')->is_valid_number, '奈良県吉野郡吉野町峰寺');
ok($zip->set_number('6393105')->is_valid_number, '奈良県吉野郡吉野町千股');
ok($zip->set_number('6393106')->is_valid_number, '奈良県吉野郡吉野町志賀');
ok($zip->set_number('6393106')->is_valid_number, '奈良県吉野郡吉野町滝畑');
ok($zip->set_number('6393107')->is_valid_number, '奈良県吉野郡吉野町佐々羅');
ok($zip->set_number('6393108')->is_valid_number, '奈良県吉野郡吉野町西谷');
ok($zip->set_number('6393108')->is_valid_number, '奈良県吉野郡吉野町三津');
ok($zip->set_number('6393111')->is_valid_number, '奈良県吉野郡吉野町上市');
ok($zip->set_number('6393112')->is_valid_number, '奈良県吉野郡吉野町立野');
ok($zip->set_number('6393113')->is_valid_number, '奈良県吉野郡吉野町飯貝');
ok($zip->set_number('6393114')->is_valid_number, '奈良県吉野郡吉野町丹治');
ok($zip->set_number('6393115')->is_valid_number, '奈良県吉野郡吉野町吉野山');
ok($zip->set_number('6393116')->is_valid_number, '奈良県吉野郡吉野町六田');
ok($zip->set_number('6393117')->is_valid_number, '奈良県吉野郡吉野町左曽');
ok($zip->set_number('6393118')->is_valid_number, '奈良県吉野郡吉野町橋屋');
ok($zip->set_number('6393121')->is_valid_number, '奈良県吉野郡大淀町西増');
ok($zip->set_number('6393122')->is_valid_number, '奈良県吉野郡大淀町中増');
ok($zip->set_number('6393123')->is_valid_number, '奈良県吉野郡大淀町増口');
ok($zip->set_number('6393124')->is_valid_number, '奈良県吉野郡大淀町北六田');
ok($zip->set_number('6393125')->is_valid_number, '奈良県吉野郡大淀町北野');
ok($zip->set_number('6393126')->is_valid_number, '奈良県吉野郡大淀町新野');
ok($zip->set_number('6393127')->is_valid_number, '奈良県吉野郡大淀町馬佐');
ok($zip->set_number('6393128')->is_valid_number, '奈良県吉野郡大淀町比曽');
ok($zip->set_number('6393321')->is_valid_number, '奈良県吉野郡吉野町三茶屋');
ok($zip->set_number('6393322')->is_valid_number, '奈良県吉野郡吉野町小名');
ok($zip->set_number('6393323')->is_valid_number, '奈良県吉野郡吉野町色生');
ok($zip->set_number('6393324')->is_valid_number, '奈良県吉野郡吉野町香束');
ok($zip->set_number('6393325')->is_valid_number, '奈良県吉野郡吉野町柳');
ok($zip->set_number('6393431')->is_valid_number, '奈良県吉野郡吉野町入野');
ok($zip->set_number('6393432')->is_valid_number, '奈良県吉野郡吉野町窪垣内');
ok($zip->set_number('6393433')->is_valid_number, '奈良県吉野郡吉野町新子');
ok($zip->set_number('6393434')->is_valid_number, '奈良県吉野郡吉野町国栖');
ok($zip->set_number('6393435')->is_valid_number, '奈良県吉野郡吉野町南国栖');
ok($zip->set_number('6393436')->is_valid_number, '奈良県吉野郡吉野町樫尾');
ok($zip->set_number('6393437')->is_valid_number, '奈良県吉野郡吉野町南大野');
ok($zip->set_number('6393441')->is_valid_number, '奈良県吉野郡吉野町矢治');
ok($zip->set_number('6393442')->is_valid_number, '奈良県吉野郡吉野町喜佐谷');
ok($zip->set_number('6393443')->is_valid_number, '奈良県吉野郡吉野町宮滝');
ok($zip->set_number('6393444')->is_valid_number, '奈良県吉野郡吉野町御園');
ok($zip->set_number('6393445')->is_valid_number, '奈良県吉野郡吉野町楢井');
ok($zip->set_number('6393446')->is_valid_number, '奈良県吉野郡吉野町菜摘');
ok($zip->set_number('6393500')->is_valid_number, '奈良県吉野郡川上村以下に掲載がない場合');
ok($zip->set_number('6393541')->is_valid_number, '奈良県吉野郡川上村東川');
ok($zip->set_number('6393542')->is_valid_number, '奈良県吉野郡川上村西河');
ok($zip->set_number('6393543')->is_valid_number, '奈良県吉野郡川上村大滝');
ok($zip->set_number('6393551')->is_valid_number, '奈良県吉野郡川上村寺尾');
ok($zip->set_number('6393552')->is_valid_number, '奈良県吉野郡川上村北塩谷');
ok($zip->set_number('6393553')->is_valid_number, '奈良県吉野郡川上村迫');
ok($zip->set_number('6393554')->is_valid_number, '奈良県吉野郡川上村高原');
ok($zip->set_number('6393555')->is_valid_number, '奈良県吉野郡川上村白屋');
ok($zip->set_number('6393556')->is_valid_number, '奈良県吉野郡川上村高原土場');
ok($zip->set_number('6393557')->is_valid_number, '奈良県吉野郡川上村人知');
ok($zip->set_number('6393558')->is_valid_number, '奈良県吉野郡川上村井戸(その他)');
ok($zip->set_number('6393601')->is_valid_number, '奈良県吉野郡川上村柏木');
ok($zip->set_number('6393602')->is_valid_number, '奈良県吉野郡川上村上多古');
ok($zip->set_number('6393603')->is_valid_number, '奈良県吉野郡川上村北和田');
ok($zip->set_number('6393604')->is_valid_number, '奈良県吉野郡川上村上谷');
ok($zip->set_number('6393611')->is_valid_number, '奈良県吉野郡川上村入之波');
ok($zip->set_number('6393612')->is_valid_number, '奈良県吉野郡川上村大迫');
ok($zip->set_number('6393613')->is_valid_number, '奈良県吉野郡川上村伯母谷');
ok($zip->set_number('6393621')->is_valid_number, '奈良県吉野郡川上村下多古');
ok($zip->set_number('6393622')->is_valid_number, '奈良県吉野郡川上村井戸(ネジ畑)');
ok($zip->set_number('6393622')->is_valid_number, '奈良県吉野郡川上村武木');
ok($zip->set_number('6393623')->is_valid_number, '奈良県吉野郡川上村井光');
ok($zip->set_number('6393631')->is_valid_number, '奈良県吉野郡川上村白川渡');
ok($zip->set_number('6393632')->is_valid_number, '奈良県吉野郡川上村枌尾');
ok($zip->set_number('6393633')->is_valid_number, '奈良県吉野郡川上村中奥');
ok($zip->set_number('6393634')->is_valid_number, '奈良県吉野郡川上村瀬戸');
ok($zip->set_number('6393635')->is_valid_number, '奈良県吉野郡川上村神之谷');
ok($zip->set_number('6393700')->is_valid_number, '奈良県吉野郡上北山村以下に掲載がない場合');
ok($zip->set_number('6393701')->is_valid_number, '奈良県吉野郡上北山村河合');
ok($zip->set_number('6393702')->is_valid_number, '奈良県吉野郡上北山村小橡');
ok($zip->set_number('6393703')->is_valid_number, '奈良県吉野郡上北山村白川');
ok($zip->set_number('6393704')->is_valid_number, '奈良県吉野郡上北山村西原');
ok($zip->set_number('6393705')->is_valid_number, '奈良県吉野郡上北山村東ノ川');
ok($zip->set_number('6393800')->is_valid_number, '奈良県吉野郡下北山村以下に掲載がない場合');
ok($zip->set_number('6393801')->is_valid_number, '奈良県吉野郡下北山村佐田');
ok($zip->set_number('6393802')->is_valid_number, '奈良県吉野郡下北山村浦向');
ok($zip->set_number('6393803')->is_valid_number, '奈良県吉野郡下北山村寺垣内');
ok($zip->set_number('6393804')->is_valid_number, '奈良県吉野郡下北山村池峰');
ok($zip->set_number('6393805')->is_valid_number, '奈良県吉野郡下北山村上池原');
ok($zip->set_number('6393806')->is_valid_number, '奈良県吉野郡下北山村下池原');
ok($zip->set_number('6393807')->is_valid_number, '奈良県吉野郡下北山村下桑原');
ok($zip->set_number('6393808')->is_valid_number, '奈良県吉野郡下北山村上桑原');
ok($zip->set_number('6393809')->is_valid_number, '奈良県吉野郡下北山村前鬼');
ok($zip->set_number('6400000')->is_valid_number, '和歌山県和歌山市以下に掲載がない場合');
ok($zip->set_number('6400101')->is_valid_number, '和歌山県和歌山市大川');
ok($zip->set_number('6400102')->is_valid_number, '和歌山県和歌山市深山');
ok($zip->set_number('6400103')->is_valid_number, '和歌山県和歌山市加太');
ok($zip->set_number('6400111')->is_valid_number, '和歌山県和歌山市日野');
ok($zip->set_number('6400112')->is_valid_number, '和歌山県和歌山市西庄');
ok($zip->set_number('6400113')->is_valid_number, '和歌山県和歌山市本脇');
ok($zip->set_number('6400114')->is_valid_number, '和歌山県和歌山市磯の浦');
ok($zip->set_number('6400115')->is_valid_number, '和歌山県和歌山市つつじが丘');
ok($zip->set_number('6400301')->is_valid_number, '和歌山県和歌山市木枕');
ok($zip->set_number('6400302')->is_valid_number, '和歌山県和歌山市永山');
ok($zip->set_number('6400303')->is_valid_number, '和歌山県和歌山市山東中');
ok($zip->set_number('6400304')->is_valid_number, '和歌山県和歌山市平尾');
ok($zip->set_number('6400305')->is_valid_number, '和歌山県和歌山市明王寺');
ok($zip->set_number('6400306')->is_valid_number, '和歌山県和歌山市塩ノ谷');
ok($zip->set_number('6400307')->is_valid_number, '和歌山県和歌山市矢田');
ok($zip->set_number('6400311')->is_valid_number, '和歌山県和歌山市黒岩');
ok($zip->set_number('6400312')->is_valid_number, '和歌山県和歌山市黒谷');
ok($zip->set_number('6400313')->is_valid_number, '和歌山県和歌山市境原');
ok($zip->set_number('6400314')->is_valid_number, '和歌山県和歌山市頭陀寺');
ok($zip->set_number('6400315')->is_valid_number, '和歌山県和歌山市南畑');
ok($zip->set_number('6400316')->is_valid_number, '和歌山県和歌山市大河内');
ok($zip->set_number('6400321')->is_valid_number, '和歌山県和歌山市薬勝寺');
ok($zip->set_number('6400322')->is_valid_number, '和歌山県和歌山市仁井辺');
ok($zip->set_number('6400323')->is_valid_number, '和歌山県和歌山市小瀬田');
ok($zip->set_number('6400324')->is_valid_number, '和歌山県和歌山市本渡');
ok($zip->set_number('6400331')->is_valid_number, '和歌山県和歌山市吉原');
ok($zip->set_number('6400332')->is_valid_number, '和歌山県和歌山市冬野');
ok($zip->set_number('6400333')->is_valid_number, '和歌山県和歌山市広原');
ok($zip->set_number('6400341')->is_valid_number, '和歌山県和歌山市相坂');
ok($zip->set_number('6400342')->is_valid_number, '和歌山県和歌山市松原');
ok($zip->set_number('6400343')->is_valid_number, '和歌山県和歌山市江南');
ok($zip->set_number('6400344')->is_valid_number, '和歌山県和歌山市朝日');
ok($zip->set_number('6400345')->is_valid_number, '和歌山県和歌山市桑山');
ok($zip->set_number('6400351')->is_valid_number, '和歌山県和歌山市吉礼');
ok($zip->set_number('6400352')->is_valid_number, '和歌山県和歌山市井戸');
ok($zip->set_number('6400353')->is_valid_number, '和歌山県和歌山市馬場');
ok($zip->set_number('6400361')->is_valid_number, '和歌山県和歌山市伊太祈曽');
ok($zip->set_number('6400362')->is_valid_number, '和歌山県和歌山市奥須佐');
ok($zip->set_number('6400363')->is_valid_number, '和歌山県和歌山市吉里');
ok($zip->set_number('6400364')->is_valid_number, '和歌山県和歌山市口須佐');
ok($zip->set_number('6400401')->is_valid_number, '和歌山県紀の川市貴志川町丸栖');
ok($zip->set_number('6400402')->is_valid_number, '和歌山県紀の川市貴志川町北山');
ok($zip->set_number('6400403')->is_valid_number, '和歌山県紀の川市貴志川町尼寺');
ok($zip->set_number('6400404')->is_valid_number, '和歌山県紀の川市貴志川町鳥居');
ok($zip->set_number('6400405')->is_valid_number, '和歌山県紀の川市貴志川町岸宮');
ok($zip->set_number('6400406')->is_valid_number, '和歌山県紀の川市貴志川町西山');
ok($zip->set_number('6400411')->is_valid_number, '和歌山県紀の川市貴志川町前田');
ok($zip->set_number('6400412')->is_valid_number, '和歌山県紀の川市貴志川町上野山');
ok($zip->set_number('6400413')->is_valid_number, '和歌山県紀の川市貴志川町神戸');
ok($zip->set_number('6400414')->is_valid_number, '和歌山県紀の川市貴志川町国主');
ok($zip->set_number('6400415')->is_valid_number, '和歌山県紀の川市貴志川町長原');
ok($zip->set_number('6400416')->is_valid_number, '和歌山県紀の川市貴志川町長山');
ok($zip->set_number('6400421')->is_valid_number, '和歌山県紀の川市貴志川町北');
ok($zip->set_number('6400422')->is_valid_number, '和歌山県紀の川市貴志川町岸小野');
ok($zip->set_number('6400423')->is_valid_number, '和歌山県紀の川市貴志川町高尾');
ok($zip->set_number('6400424')->is_valid_number, '和歌山県紀の川市貴志川町井ノ口');
ok($zip->set_number('6400441')->is_valid_number, '和歌山県海南市七山');
ok($zip->set_number('6400442')->is_valid_number, '和歌山県海南市原野');
ok($zip->set_number('6400443')->is_valid_number, '和歌山県海南市下津野');
ok($zip->set_number('6400451')->is_valid_number, '和歌山県海南市高津');
ok($zip->set_number('6400452')->is_valid_number, '和歌山県海南市孟子');
ok($zip->set_number('6400453')->is_valid_number, '和歌山県海南市野尻');
ok($zip->set_number('6400454')->is_valid_number, '和歌山県海南市別院');
ok($zip->set_number('6401100')->is_valid_number, '和歌山県海草郡紀美野町以下に掲載がない場合');
ok($zip->set_number('6401101')->is_valid_number, '和歌山県海草郡紀美野町長谷');
ok($zip->set_number('6401102')->is_valid_number, '和歌山県海草郡紀美野町柴目');
ok($zip->set_number('6401103')->is_valid_number, '和歌山県海草郡紀美野町吉野');
ok($zip->set_number('6401111')->is_valid_number, '和歌山県海草郡紀美野町福井');
ok($zip->set_number('6401112')->is_valid_number, '和歌山県海草郡紀美野町坂本');
ok($zip->set_number('6401113')->is_valid_number, '和歌山県海草郡紀美野町梅本');
ok($zip->set_number('6401114')->is_valid_number, '和歌山県海草郡紀美野町中田');
ok($zip->set_number('6401115')->is_valid_number, '和歌山県海草郡紀美野町奥佐々');
ok($zip->set_number('6401121')->is_valid_number, '和歌山県海草郡紀美野町下佐々');
ok($zip->set_number('6401131')->is_valid_number, '和歌山県海草郡紀美野町動木');
ok($zip->set_number('6401141')->is_valid_number, '和歌山県海草郡紀美野町小畑');
ok($zip->set_number('6401161')->is_valid_number, '和歌山県海南市野上新');
ok($zip->set_number('6401162')->is_valid_number, '和歌山県海南市上谷');
ok($zip->set_number('6401163')->is_valid_number, '和歌山県海南市赤沼');
ok($zip->set_number('6401164')->is_valid_number, '和歌山県海南市海老谷');
ok($zip->set_number('6401165')->is_valid_number, '和歌山県海南市ひや水');
ok($zip->set_number('6401166')->is_valid_number, '和歌山県海南市次ケ谷');
ok($zip->set_number('6401167')->is_valid_number, '和歌山県海南市九品寺');
ok($zip->set_number('6401171')->is_valid_number, '和歌山県海南市野上中');
ok($zip->set_number('6401172')->is_valid_number, '和歌山県海南市溝ノ口');
ok($zip->set_number('6401173')->is_valid_number, '和歌山県海南市椋木');
ok($zip->set_number('6401174')->is_valid_number, '和歌山県海南市木津');
ok($zip->set_number('6401175')->is_valid_number, '和歌山県海南市沖野々');
ok($zip->set_number('6401201')->is_valid_number, '和歌山県海草郡紀美野町北野');
ok($zip->set_number('6401202')->is_valid_number, '和歌山県海草郡紀美野町初生谷');
ok($zip->set_number('6401203')->is_valid_number, '和歌山県海草郡紀美野町花野原');
ok($zip->set_number('6401204')->is_valid_number, '和歌山県海草郡紀美野町蓑津呂');
ok($zip->set_number('6401205')->is_valid_number, '和歌山県海草郡紀美野町真国宮');
ok($zip->set_number('6401206')->is_valid_number, '和歌山県海草郡紀美野町蓑垣内');
ok($zip->set_number('6401207')->is_valid_number, '和歌山県海草郡紀美野町井堰');
ok($zip->set_number('6401211')->is_valid_number, '和歌山県海草郡紀美野町桂瀬');
ok($zip->set_number('6401212')->is_valid_number, '和歌山県海草郡紀美野町高畑');
ok($zip->set_number('6401213')->is_valid_number, '和歌山県海草郡紀美野町赤木');
ok($zip->set_number('6401214')->is_valid_number, '和歌山県海草郡紀美野町明添');
ok($zip->set_number('6401215')->is_valid_number, '和歌山県海草郡紀美野町鎌滝');
ok($zip->set_number('6401221')->is_valid_number, '和歌山県海草郡紀美野町三尾川');
ok($zip->set_number('6401222')->is_valid_number, '和歌山県海草郡紀美野町大角');
ok($zip->set_number('6401223')->is_valid_number, '和歌山県海草郡紀美野町津川');
ok($zip->set_number('6401231')->is_valid_number, '和歌山県海草郡紀美野町上ケ井');
ok($zip->set_number('6401232')->is_valid_number, '和歌山県海草郡紀美野町箕六');
ok($zip->set_number('6401233')->is_valid_number, '和歌山県海草郡紀美野町南畑');
ok($zip->set_number('6401234')->is_valid_number, '和歌山県海草郡紀美野町安井');
ok($zip->set_number('6401235')->is_valid_number, '和歌山県海草郡紀美野町野中');
ok($zip->set_number('6401241')->is_valid_number, '和歌山県海草郡紀美野町永谷');
ok($zip->set_number('6401242')->is_valid_number, '和歌山県海草郡紀美野町樋下');
ok($zip->set_number('6401243')->is_valid_number, '和歌山県海草郡紀美野町神野市場');
ok($zip->set_number('6401244')->is_valid_number, '和歌山県海草郡紀美野町福田');
ok($zip->set_number('6401251')->is_valid_number, '和歌山県海草郡紀美野町国木原');
ok($zip->set_number('6401252')->is_valid_number, '和歌山県海草郡紀美野町西野');
ok($zip->set_number('6401253')->is_valid_number, '和歌山県海草郡紀美野町東野');
ok($zip->set_number('6401254')->is_valid_number, '和歌山県海草郡紀美野町松瀬');
ok($zip->set_number('6401255')->is_valid_number, '和歌山県海草郡紀美野町釜滝');
ok($zip->set_number('6401331')->is_valid_number, '和歌山県紀の川市桃山町峯');
ok($zip->set_number('6401332')->is_valid_number, '和歌山県紀の川市桃山町中畑');
ok($zip->set_number('6401333')->is_valid_number, '和歌山県紀の川市桃山町垣内');
ok($zip->set_number('6401351')->is_valid_number, '和歌山県海草郡紀美野町勝谷');
ok($zip->set_number('6401352')->is_valid_number, '和歌山県海草郡紀美野町谷');
ok($zip->set_number('6401353')->is_valid_number, '和歌山県海草郡紀美野町円明寺');
ok($zip->set_number('6401354')->is_valid_number, '和歌山県海草郡紀美野町四郷');
ok($zip->set_number('6401361')->is_valid_number, '和歌山県海草郡紀美野町中');
ok($zip->set_number('6401362')->is_valid_number, '和歌山県海草郡紀美野町滝ノ川');
ok($zip->set_number('6401363')->is_valid_number, '和歌山県海草郡紀美野町田');
ok($zip->set_number('6401364')->is_valid_number, '和歌山県海草郡紀美野町菅沢');
ok($zip->set_number('6401365')->is_valid_number, '和歌山県海草郡紀美野町今西');
ok($zip->set_number('6401366')->is_valid_number, '和歌山県海草郡紀美野町松ケ峯');
ok($zip->set_number('6401471')->is_valid_number, '和歌山県海草郡紀美野町長谷宮');
ok($zip->set_number('6401472')->is_valid_number, '和歌山県海草郡紀美野町毛原上');
ok($zip->set_number('6401473')->is_valid_number, '和歌山県海草郡紀美野町毛原宮');
ok($zip->set_number('6401474')->is_valid_number, '和歌山県海草郡紀美野町毛原中');
ok($zip->set_number('6401475')->is_valid_number, '和歌山県海草郡紀美野町小西');
ok($zip->set_number('6401476')->is_valid_number, '和歌山県海草郡紀美野町毛原下');
ok($zip->set_number('6401481')->is_valid_number, '和歌山県伊都郡かつらぎ町新城');
ok($zip->set_number('6408001')->is_valid_number, '和歌山県和歌山市北新七軒丁');
ok($zip->set_number('6408002')->is_valid_number, '和歌山県和歌山市北新');
ok($zip->set_number('6408003')->is_valid_number, '和歌山県和歌山市北新博労町');
ok($zip->set_number('6408004')->is_valid_number, '和歌山県和歌山市東旅籠町');
ok($zip->set_number('6408005')->is_valid_number, '和歌山県和歌山市元寺町南ノ丁');
ok($zip->set_number('6408006')->is_valid_number, '和歌山県和歌山市元寺町東ノ丁');
ok($zip->set_number('6408007')->is_valid_number, '和歌山県和歌山市元寺町西ノ丁');
ok($zip->set_number('6408008')->is_valid_number, '和歌山県和歌山市元寺町北ノ丁');
ok($zip->set_number('6408009')->is_valid_number, '和歌山県和歌山市鍋屋町');
ok($zip->set_number('6408011')->is_valid_number, '和歌山県和歌山市北新元金屋丁');
ok($zip->set_number('6408012')->is_valid_number, '和歌山県和歌山市北新金屋丁');
ok($zip->set_number('6408013')->is_valid_number, '和歌山県和歌山市東仲間町');
ok($zip->set_number('6408014')->is_valid_number, '和歌山県和歌山市西仲間町');
ok($zip->set_number('6408015')->is_valid_number, '和歌山県和歌山市北新桶屋町');
ok($zip->set_number('6408016')->is_valid_number, '和歌山県和歌山市北新中ノ丁');
ok($zip->set_number('6408017')->is_valid_number, '和歌山県和歌山市北新戎ノ丁');
ok($zip->set_number('6408020')->is_valid_number, '和歌山県和歌山市北桶屋町');
ok($zip->set_number('6408021')->is_valid_number, '和歌山県和歌山市西旅籠町');
ok($zip->set_number('6408022')->is_valid_number, '和歌山県和歌山市住吉町');
ok($zip->set_number('6408023')->is_valid_number, '和歌山県和歌山市中ノ店北ノ丁');
ok($zip->set_number('6408024')->is_valid_number, '和歌山県和歌山市元寺町');
ok($zip->set_number('6408025')->is_valid_number, '和歌山県和歌山市中ノ店中ノ丁');
ok($zip->set_number('6408026')->is_valid_number, '和歌山県和歌山市中ノ店南ノ丁');
ok($zip->set_number('6408027')->is_valid_number, '和歌山県和歌山市米屋町');
ok($zip->set_number('6408028')->is_valid_number, '和歌山県和歌山市匠町');
ok($zip->set_number('6408029')->is_valid_number, '和歌山県和歌山市南桶屋町');
ok($zip->set_number('6408031')->is_valid_number, '和歌山県和歌山市北大工町');
ok($zip->set_number('6408032')->is_valid_number, '和歌山県和歌山市南大工町');
ok($zip->set_number('6408033')->is_valid_number, '和歌山県和歌山市本町');
ok($zip->set_number('6408034')->is_valid_number, '和歌山県和歌山市駿河町');
ok($zip->set_number('6408035')->is_valid_number, '和歌山県和歌山市万町');
ok($zip->set_number('6408036')->is_valid_number, '和歌山県和歌山市東鍛冶屋町');
ok($zip->set_number('6408037')->is_valid_number, '和歌山県和歌山市西大工町');
ok($zip->set_number('6408038')->is_valid_number, '和歌山県和歌山市北町');
ok($zip->set_number('6408039')->is_valid_number, '和歌山県和歌山市宇治袋町');
ok($zip->set_number('6408041')->is_valid_number, '和歌山県和歌山市専光寺門前丁');
ok($zip->set_number('6408042')->is_valid_number, '和歌山県和歌山市西ノ店');
ok($zip->set_number('6408043')->is_valid_number, '和歌山県和歌山市福町');
ok($zip->set_number('6408044')->is_valid_number, '和歌山県和歌山市板屋町');
ok($zip->set_number('6408045')->is_valid_number, '和歌山県和歌山市卜半町');
ok($zip->set_number('6408046')->is_valid_number, '和歌山県和歌山市西鍛冶屋町');
ok($zip->set_number('6408047')->is_valid_number, '和歌山県和歌山市鷺ノ森南ノ丁');
ok($zip->set_number('6408051')->is_valid_number, '和歌山県和歌山市鷺ノ森東ノ丁');
ok($zip->set_number('6408052')->is_valid_number, '和歌山県和歌山市鷺ノ森堂前丁');
ok($zip->set_number('6408053')->is_valid_number, '和歌山県和歌山市鷺ノ森');
ok($zip->set_number('6408054')->is_valid_number, '和歌山県和歌山市鷺ノ森片町');
ok($zip->set_number('6408055')->is_valid_number, '和歌山県和歌山市九家ノ丁');
ok($zip->set_number('6408056')->is_valid_number, '和歌山県和歌山市鷺ノ森西ノ丁');
ok($zip->set_number('6408057')->is_valid_number, '和歌山県和歌山市鷺ノ森新道');
ok($zip->set_number('6408058')->is_valid_number, '和歌山県和歌山市鷺ノ森中ノ丁');
ok($zip->set_number('6408059')->is_valid_number, '和歌山県和歌山市鷺ノ森明神丁');
ok($zip->set_number('6408060')->is_valid_number, '和歌山県和歌山市四筋目');
ok($zip->set_number('6408061')->is_valid_number, '和歌山県和歌山市畳屋町');
ok($zip->set_number('6408062')->is_valid_number, '和歌山県和歌山市北釘貫丁');
ok($zip->set_number('6408063')->is_valid_number, '和歌山県和歌山市西釘貫丁');
ok($zip->set_number('6408064')->is_valid_number, '和歌山県和歌山市東釘貫丁');
ok($zip->set_number('6408065')->is_valid_number, '和歌山県和歌山市山吹丁');
ok($zip->set_number('6408066')->is_valid_number, '和歌山県和歌山市東布経丁');
ok($zip->set_number('6408067')->is_valid_number, '和歌山県和歌山市一筋目');
ok($zip->set_number('6408068')->is_valid_number, '和歌山県和歌山市二筋目');
ok($zip->set_number('6408069')->is_valid_number, '和歌山県和歌山市三筋目');
ok($zip->set_number('6408071')->is_valid_number, '和歌山県和歌山市宇治薮下');
ok($zip->set_number('6408072')->is_valid_number, '和歌山県和歌山市宇治家裏');
ok($zip->set_number('6408073')->is_valid_number, '和歌山県和歌山市嘉家作丁');
ok($zip->set_number('6408074')->is_valid_number, '和歌山県和歌山市新魚町');
ok($zip->set_number('6408075')->is_valid_number, '和歌山県和歌山市源蔵馬場');
ok($zip->set_number('6408076')->is_valid_number, '和歌山県和歌山市五筋目');
ok($zip->set_number('6408077')->is_valid_number, '和歌山県和歌山市六筋目');
ok($zip->set_number('6408078')->is_valid_number, '和歌山県和歌山市宇治鉄砲場');
ok($zip->set_number('6408101')->is_valid_number, '和歌山県和歌山市新雑賀町');
ok($zip->set_number('6408102')->is_valid_number, '和歌山県和歌山市南雑賀町');
ok($zip->set_number('6408103')->is_valid_number, '和歌山県和歌山市北休賀町');
ok($zip->set_number('6408104')->is_valid_number, '和歌山県和歌山市南休賀町');
ok($zip->set_number('6408105')->is_valid_number, '和歌山県和歌山市三木町南ノ丁');
ok($zip->set_number('6408106')->is_valid_number, '和歌山県和歌山市三木町中ノ丁');
ok($zip->set_number('6408107')->is_valid_number, '和歌山県和歌山市三木町堀詰');
ok($zip->set_number('6408108')->is_valid_number, '和歌山県和歌山市雑賀町');
ok($zip->set_number('6408111')->is_valid_number, '和歌山県和歌山市新通');
ok($zip->set_number('6408112')->is_valid_number, '和歌山県和歌山市南材木丁');
ok($zip->set_number('6408113')->is_valid_number, '和歌山県和歌山市広瀬通丁');
ok($zip->set_number('6408114')->is_valid_number, '和歌山県和歌山市船場町');
ok($zip->set_number('6408115')->is_valid_number, '和歌山県和歌山市東紺屋町');
ok($zip->set_number('6408116')->is_valid_number, '和歌山県和歌山市西紺屋町');
ok($zip->set_number('6408117')->is_valid_number, '和歌山県和歌山市南細工町');
ok($zip->set_number('6408118')->is_valid_number, '和歌山県和歌山市北細工町');
ok($zip->set_number('6408119')->is_valid_number, '和歌山県和歌山市和歌町');
ok($zip->set_number('6408121')->is_valid_number, '和歌山県和歌山市雑賀道');
ok($zip->set_number('6408122')->is_valid_number, '和歌山県和歌山市汐見町');
ok($zip->set_number('6408123')->is_valid_number, '和歌山県和歌山市三沢町');
ok($zip->set_number('6408124')->is_valid_number, '和歌山県和歌山市雄松町');
ok($zip->set_number('6408125')->is_valid_number, '和歌山県和歌山市島崎町');
ok($zip->set_number('6408126')->is_valid_number, '和歌山県和歌山市南片原');
ok($zip->set_number('6408127')->is_valid_number, '和歌山県和歌山市元町奉行丁');
ok($zip->set_number('6408128')->is_valid_number, '和歌山県和歌山市広瀬中ノ丁');
ok($zip->set_number('6408131')->is_valid_number, '和歌山県和歌山市弁財天丁');
ok($zip->set_number('6408132')->is_valid_number, '和歌山県和歌山市山蔭丁');
ok($zip->set_number('6408133')->is_valid_number, '和歌山県和歌山市谷町');
ok($zip->set_number('6408134')->is_valid_number, '和歌山県和歌山市芦辺丁');
ok($zip->set_number('6408135')->is_valid_number, '和歌山県和歌山市鷹匠町');
ok($zip->set_number('6408136')->is_valid_number, '和歌山県和歌山市堀止東');
ok($zip->set_number('6408137')->is_valid_number, '和歌山県和歌山市吹上');
ok($zip->set_number('6408138')->is_valid_number, '和歌山県和歌山市薮ノ丁');
ok($zip->set_number('6408139')->is_valid_number, '和歌山県和歌山市片岡町');
ok($zip->set_number('6408141')->is_valid_number, '和歌山県和歌山市五番丁');
ok($zip->set_number('6408142')->is_valid_number, '和歌山県和歌山市三番丁');
ok($zip->set_number('6408143')->is_valid_number, '和歌山県和歌山市二番丁');
ok($zip->set_number('6408144')->is_valid_number, '和歌山県和歌山市四番丁');
ok($zip->set_number('6408145')->is_valid_number, '和歌山県和歌山市岡山丁');
ok($zip->set_number('6408146')->is_valid_number, '和歌山県和歌山市一番丁');
ok($zip->set_number('6408150')->is_valid_number, '和歌山県和歌山市十三番丁');
ok($zip->set_number('6408151')->is_valid_number, '和歌山県和歌山市屋形町');
ok($zip->set_number('6408152')->is_valid_number, '和歌山県和歌山市十番丁');
ok($zip->set_number('6408153')->is_valid_number, '和歌山県和歌山市三木町台所町');
ok($zip->set_number('6408154')->is_valid_number, '和歌山県和歌山市六番丁');
ok($zip->set_number('6408155')->is_valid_number, '和歌山県和歌山市九番丁');
ok($zip->set_number('6408156')->is_valid_number, '和歌山県和歌山市七番丁');
ok($zip->set_number('6408157')->is_valid_number, '和歌山県和歌山市八番丁');
ok($zip->set_number('6408158')->is_valid_number, '和歌山県和歌山市十二番丁');
ok($zip->set_number('6408159')->is_valid_number, '和歌山県和歌山市十一番丁');
ok($zip->set_number('6408201')->is_valid_number, '和歌山県和歌山市石橋丁');
ok($zip->set_number('6408202')->is_valid_number, '和歌山県和歌山市屏風丁');
ok($zip->set_number('6408203')->is_valid_number, '和歌山県和歌山市東蔵前丁');
ok($zip->set_number('6408204')->is_valid_number, '和歌山県和歌山市伝法橋南ノ丁');
ok($zip->set_number('6408205')->is_valid_number, '和歌山県和歌山市西蔵前丁');
ok($zip->set_number('6408206')->is_valid_number, '和歌山県和歌山市徳田木丁');
ok($zip->set_number('6408211')->is_valid_number, '和歌山県和歌山市西布経丁');
ok($zip->set_number('6408212')->is_valid_number, '和歌山県和歌山市杉ノ馬場');
ok($zip->set_number('6408213')->is_valid_number, '和歌山県和歌山市舟大工町');
ok($zip->set_number('6408214')->is_valid_number, '和歌山県和歌山市寄合町');
ok($zip->set_number('6408215')->is_valid_number, '和歌山県和歌山市橋丁');
ok($zip->set_number('6408216')->is_valid_number, '和歌山県和歌山市元博労町');
ok($zip->set_number('6408220')->is_valid_number, '和歌山県和歌山市下町');
ok($zip->set_number('6408221')->is_valid_number, '和歌山県和歌山市湊紺屋町');
ok($zip->set_number('6408222')->is_valid_number, '和歌山県和歌山市湊本町');
ok($zip->set_number('6408223')->is_valid_number, '和歌山県和歌山市湊北町');
ok($zip->set_number('6408224')->is_valid_number, '和歌山県和歌山市小野町');
ok($zip->set_number('6408225')->is_valid_number, '和歌山県和歌山市久保丁');
ok($zip->set_number('6408226')->is_valid_number, '和歌山県和歌山市小人町');
ok($zip->set_number('6408227')->is_valid_number, '和歌山県和歌山市西汀丁');
ok($zip->set_number('6408228')->is_valid_number, '和歌山県和歌山市小人町南ノ丁');
ok($zip->set_number('6408229')->is_valid_number, '和歌山県和歌山市道場町');
ok($zip->set_number('6408230')->is_valid_number, '和歌山県和歌山市男野芝丁');
ok($zip->set_number('6408231')->is_valid_number, '和歌山県和歌山市北汀丁');
ok($zip->set_number('6408232')->is_valid_number, '和歌山県和歌山市南汀丁');
ok($zip->set_number('6408233')->is_valid_number, '和歌山県和歌山市北坂ノ上丁');
ok($zip->set_number('6408234')->is_valid_number, '和歌山県和歌山市西坂ノ上丁');
ok($zip->set_number('6408235')->is_valid_number, '和歌山県和歌山市東長町');
ok($zip->set_number('6408236')->is_valid_number, '和歌山県和歌山市七曲り');
ok($zip->set_number('6408237')->is_valid_number, '和歌山県和歌山市材木丁');
ok($zip->set_number('6408238')->is_valid_number, '和歌山県和歌山市網屋町');
ok($zip->set_number('6408239')->is_valid_number, '和歌山県和歌山市上町');
ok($zip->set_number('6408241')->is_valid_number, '和歌山県和歌山市雑賀屋町東ノ丁');
ok($zip->set_number('6408242')->is_valid_number, '和歌山県和歌山市上野町');
ok($zip->set_number('6408243')->is_valid_number, '和歌山県和歌山市徒町');
ok($zip->set_number('6408244')->is_valid_number, '和歌山県和歌山市久右衛門丁');
ok($zip->set_number('6408245')->is_valid_number, '和歌山県和歌山市有田屋町南ノ丁');
ok($zip->set_number('6408246')->is_valid_number, '和歌山県和歌山市有田屋町西ノ丁');
ok($zip->set_number('6408247')->is_valid_number, '和歌山県和歌山市東坂ノ上丁');
ok($zip->set_number('6408248')->is_valid_number, '和歌山県和歌山市有田屋町');
ok($zip->set_number('6408249')->is_valid_number, '和歌山県和歌山市雑賀屋町');
ok($zip->set_number('6408251')->is_valid_number, '和歌山県和歌山市南中間町');
ok($zip->set_number('6408252')->is_valid_number, '和歌山県和歌山市北田辺丁');
ok($zip->set_number('6408253')->is_valid_number, '和歌山県和歌山市北相生丁');
ok($zip->set_number('6408254')->is_valid_number, '和歌山県和歌山市南田辺丁');
ok($zip->set_number('6408255')->is_valid_number, '和歌山県和歌山市舟津町');
ok($zip->set_number('6408256')->is_valid_number, '和歌山県和歌山市土佐町');
ok($zip->set_number('6408261')->is_valid_number, '和歌山県和歌山市真砂丁');
ok($zip->set_number('6408262')->is_valid_number, '和歌山県和歌山市湊通丁北');
ok($zip->set_number('6408263')->is_valid_number, '和歌山県和歌山市茶屋ノ丁');
ok($zip->set_number('6408264')->is_valid_number, '和歌山県和歌山市湊桶屋町');
ok($zip->set_number('6408265')->is_valid_number, '和歌山県和歌山市小松原');
ok($zip->set_number('6408266')->is_valid_number, '和歌山県和歌山市東長町中ノ丁');
ok($zip->set_number('6408267')->is_valid_number, '和歌山県和歌山市芝ノ丁');
ok($zip->set_number('6408268')->is_valid_number, '和歌山県和歌山市広道');
ok($zip->set_number('6408269')->is_valid_number, '和歌山県和歌山市小松原通');
ok($zip->set_number('6408271')->is_valid_number, '和歌山県和歌山市尾崎丁');
ok($zip->set_number('6408272')->is_valid_number, '和歌山県和歌山市砂山南');
ok($zip->set_number('6408273')->is_valid_number, '和歌山県和歌山市葵町');
ok($zip->set_number('6408274')->is_valid_number, '和歌山県和歌山市金龍寺丁');
ok($zip->set_number('6408275')->is_valid_number, '和歌山県和歌山市南相生丁');
ok($zip->set_number('6408276')->is_valid_number, '和歌山県和歌山市作事丁');
ok($zip->set_number('6408281')->is_valid_number, '和歌山県和歌山市湊通丁南');
ok($zip->set_number('6408282')->is_valid_number, '和歌山県和歌山市出口甲賀丁');
ok($zip->set_number('6408283')->is_valid_number, '和歌山県和歌山市出口中ノ丁');
ok($zip->set_number('6408284')->is_valid_number, '和歌山県和歌山市出口端ノ丁');
ok($zip->set_number('6408285')->is_valid_number, '和歌山県和歌山市出口新端ノ丁');
ok($zip->set_number('6408286')->is_valid_number, '和歌山県和歌山市湊御殿');
ok($zip->set_number('6408287')->is_valid_number, '和歌山県和歌山市築港');
ok($zip->set_number('6408288')->is_valid_number, '和歌山県和歌山市加納町');
ok($zip->set_number('6408290')->is_valid_number, '和歌山県和歌山市西長町');
ok($zip->set_number('6408291')->is_valid_number, '和歌山県和歌山市北甚五兵衛丁');
ok($zip->set_number('6408292')->is_valid_number, '和歌山県和歌山市南甚五兵衛丁');
ok($zip->set_number('6408293')->is_valid_number, '和歌山県和歌山市駕町');
ok($zip->set_number('6408294')->is_valid_number, '和歌山県和歌山市北中間町');
ok($zip->set_number('6408295')->is_valid_number, '和歌山県和歌山市南牛町');
ok($zip->set_number('6408296')->is_valid_number, '和歌山県和歌山市北土佐丁');
ok($zip->set_number('6408297')->is_valid_number, '和歌山県和歌山市西河岸町');
ok($zip->set_number('6408298')->is_valid_number, '和歌山県和歌山市植松丁');
ok($zip->set_number('6408299')->is_valid_number, '和歌山県和歌山市北牛町');
ok($zip->set_number('6408301')->is_valid_number, '和歌山県和歌山市岩橋');
ok($zip->set_number('6408302')->is_valid_number, '和歌山県和歌山市井辺');
ok($zip->set_number('6408303')->is_valid_number, '和歌山県和歌山市鳴神');
ok($zip->set_number('6408304')->is_valid_number, '和歌山県和歌山市松島');
ok($zip->set_number('6408305')->is_valid_number, '和歌山県和歌山市栗栖');
ok($zip->set_number('6408306')->is_valid_number, '和歌山県和歌山市出島');
ok($zip->set_number('6408311')->is_valid_number, '和歌山県和歌山市寺内');
ok($zip->set_number('6408312')->is_valid_number, '和歌山県和歌山市森小手穂');
ok($zip->set_number('6408313')->is_valid_number, '和歌山県和歌山市西');
ok($zip->set_number('6408314')->is_valid_number, '和歌山県和歌山市神前');
ok($zip->set_number('6408315')->is_valid_number, '和歌山県和歌山市津秦');
ok($zip->set_number('6408316')->is_valid_number, '和歌山県和歌山市有家');
ok($zip->set_number('6408317')->is_valid_number, '和歌山県和歌山市北出島');
ok($zip->set_number('6408318')->is_valid_number, '和歌山県和歌山市南出島');
ok($zip->set_number('6408319')->is_valid_number, '和歌山県和歌山市手平');
ok($zip->set_number('6408320')->is_valid_number, '和歌山県和歌山市手平出島');
ok($zip->set_number('6408321')->is_valid_number, '和歌山県和歌山市出水');
ok($zip->set_number('6408322')->is_valid_number, '和歌山県和歌山市秋月');
ok($zip->set_number('6408323')->is_valid_number, '和歌山県和歌山市太田');
ok($zip->set_number('6408324')->is_valid_number, '和歌山県和歌山市吹屋町');
ok($zip->set_number('6408325')->is_valid_number, '和歌山県和歌山市新生町');
ok($zip->set_number('6408326')->is_valid_number, '和歌山県和歌山市新留丁');
ok($zip->set_number('6408327')->is_valid_number, '和歌山県和歌山市橋向丁');
ok($zip->set_number('6408328')->is_valid_number, '和歌山県和歌山市木広町');
ok($zip->set_number('6408329')->is_valid_number, '和歌山県和歌山市田中町');
ok($zip->set_number('6408331')->is_valid_number, '和歌山県和歌山市美園町');
ok($zip->set_number('6408332')->is_valid_number, '和歌山県和歌山市楠右衛門小路');
ok($zip->set_number('6408333')->is_valid_number, '和歌山県和歌山市蔵小路');
ok($zip->set_number('6408334')->is_valid_number, '和歌山県和歌山市茶屋町');
ok($zip->set_number('6408335')->is_valid_number, '和歌山県和歌山市餌差町');
ok($zip->set_number('6408336')->is_valid_number, '和歌山県和歌山市柳丁');
ok($zip->set_number('6408337')->is_valid_number, '和歌山県和歌山市毛革屋丁');
ok($zip->set_number('6408341')->is_valid_number, '和歌山県和歌山市黒田');
ok($zip->set_number('6408342')->is_valid_number, '和歌山県和歌山市友田町');
ok($zip->set_number('6408343')->is_valid_number, '和歌山県和歌山市吉田');
ok($zip->set_number('6408344')->is_valid_number, '和歌山県和歌山市納定');
ok($zip->set_number('6408345')->is_valid_number, '和歌山県和歌山市新在家');
ok($zip->set_number('6408350')->is_valid_number, '和歌山県和歌山市北ノ新地分銅丁');
ok($zip->set_number('6408351')->is_valid_number, '和歌山県和歌山市新内');
ok($zip->set_number('6408352')->is_valid_number, '和歌山県和歌山市北ノ新地裏田町');
ok($zip->set_number('6408353')->is_valid_number, '和歌山県和歌山市北ノ新地榎丁');
ok($zip->set_number('6408354')->is_valid_number, '和歌山県和歌山市北ノ新地東ノ丁');
ok($zip->set_number('6408355')->is_valid_number, '和歌山県和歌山市北ノ新地');
ok($zip->set_number('6408356')->is_valid_number, '和歌山県和歌山市北ノ新地上六軒丁');
ok($zip->set_number('6408357')->is_valid_number, '和歌山県和歌山市北ノ新地中六軒丁');
ok($zip->set_number('6408358')->is_valid_number, '和歌山県和歌山市北ノ新地下六軒丁');
ok($zip->set_number('6408359')->is_valid_number, '和歌山県和歌山市北ノ新地田町');
ok($zip->set_number('6408361')->is_valid_number, '和歌山県和歌山市岡円福院東ノ丁');
ok($zip->set_number('6408362')->is_valid_number, '和歌山県和歌山市岡織屋小路');
ok($zip->set_number('6408363')->is_valid_number, '和歌山県和歌山市岡南ノ丁');
ok($zip->set_number('6408364')->is_valid_number, '和歌山県和歌山市岡円福院西ノ丁');
ok($zip->set_number('6408365')->is_valid_number, '和歌山県和歌山市岡北ノ丁');
ok($zip->set_number('6408371')->is_valid_number, '和歌山県和歌山市新八百屋丁');
ok($zip->set_number('6408372')->is_valid_number, '和歌山県和歌山市新大工町');
ok($zip->set_number('6408373')->is_valid_number, '和歌山県和歌山市木挽丁');
ok($zip->set_number('6408374')->is_valid_number, '和歌山県和歌山市数寄屋丁');
ok($zip->set_number('6408375')->is_valid_number, '和歌山県和歌山市坊主丁');
ok($zip->set_number('6408376')->is_valid_number, '和歌山県和歌山市新中通');
ok($zip->set_number('6408377')->is_valid_number, '和歌山県和歌山市新堺丁');
ok($zip->set_number('6408378')->is_valid_number, '和歌山県和歌山市鈴丸丁');
ok($zip->set_number('6408381')->is_valid_number, '和歌山県和歌山市畑屋敷東ノ丁');
ok($zip->set_number('6408382')->is_valid_number, '和歌山県和歌山市畑屋敷榎丁');
ok($zip->set_number('6408383')->is_valid_number, '和歌山県和歌山市畑屋敷円福院東ノ丁');
ok($zip->set_number('6408384')->is_valid_number, '和歌山県和歌山市畑屋敷葛屋丁');
ok($zip->set_number('6408385')->is_valid_number, '和歌山県和歌山市畑屋敷円福院西ノ丁');
ok($zip->set_number('6408386')->is_valid_number, '和歌山県和歌山市畑屋敷雁木丁');
ok($zip->set_number('6408387')->is_valid_number, '和歌山県和歌山市畑屋敷袋町');
ok($zip->set_number('6408390')->is_valid_number, '和歌山県和歌山市有本');
ok($zip->set_number('6408391')->is_valid_number, '和歌山県和歌山市加納');
ok($zip->set_number('6408392')->is_valid_number, '和歌山県和歌山市中之島');
ok($zip->set_number('6408393')->is_valid_number, '和歌山県和歌山市畑屋敷端ノ丁');
ok($zip->set_number('6408394')->is_valid_number, '和歌山県和歌山市畑屋敷千体仏丁');
ok($zip->set_number('6408395')->is_valid_number, '和歌山県和歌山市畑屋敷中ノ丁');
ok($zip->set_number('6408396')->is_valid_number, '和歌山県和歌山市畑屋敷西ノ丁');
ok($zip->set_number('6408397')->is_valid_number, '和歌山県和歌山市畑屋敷新道丁');
ok($zip->set_number('6408398')->is_valid_number, '和歌山県和歌山市畑屋敷松ケ枝丁');
ok($zip->set_number('6408399')->is_valid_number, '和歌山県和歌山市畑屋敷兵庫ノ丁');
ok($zip->set_number('6408401')->is_valid_number, '和歌山県和歌山市福島');
ok($zip->set_number('6408402')->is_valid_number, '和歌山県和歌山市野崎');
ok($zip->set_number('6408403')->is_valid_number, '和歌山県和歌山市北島');
ok($zip->set_number('6408404')->is_valid_number, '和歌山県和歌山市湊');
ok($zip->set_number('6408411')->is_valid_number, '和歌山県和歌山市梶取');
ok($zip->set_number('6408412')->is_valid_number, '和歌山県和歌山市狐島');
ok($zip->set_number('6408413')->is_valid_number, '和歌山県和歌山市島橋東ノ丁');
ok($zip->set_number('6408414')->is_valid_number, '和歌山県和歌山市島橋西ノ丁');
ok($zip->set_number('6408415')->is_valid_number, '和歌山県和歌山市島橋南ノ丁');
ok($zip->set_number('6408416')->is_valid_number, '和歌山県和歌山市島橋北ノ丁');
ok($zip->set_number('6408421')->is_valid_number, '和歌山県和歌山市松江');
ok($zip->set_number('6408422')->is_valid_number, '和歌山県和歌山市松江東');
ok($zip->set_number('6408423')->is_valid_number, '和歌山県和歌山市松江中');
ok($zip->set_number('6408424')->is_valid_number, '和歌山県和歌山市松江西');
ok($zip->set_number('6408425')->is_valid_number, '和歌山県和歌山市松江北');
ok($zip->set_number('6408431')->is_valid_number, '和歌山県和歌山市向');
ok($zip->set_number('6408432')->is_valid_number, '和歌山県和歌山市土入');
ok($zip->set_number('6408433')->is_valid_number, '和歌山県和歌山市中野');
ok($zip->set_number('6408434')->is_valid_number, '和歌山県和歌山市榎原');
ok($zip->set_number('6408435')->is_valid_number, '和歌山県和歌山市古屋');
ok($zip->set_number('6408441')->is_valid_number, '和歌山県和歌山市栄谷');
ok($zip->set_number('6408442')->is_valid_number, '和歌山県和歌山市平井');
ok($zip->set_number('6408443')->is_valid_number, '和歌山県和歌山市延時');
ok($zip->set_number('6408444')->is_valid_number, '和歌山県和歌山市次郎丸');
ok($zip->set_number('6408451')->is_valid_number, '和歌山県和歌山市中');
ok($zip->set_number('6408452')->is_valid_number, '和歌山県和歌山市梅原');
ok($zip->set_number('6408453')->is_valid_number, '和歌山県和歌山市木ノ本');
ok($zip->set_number('6408461')->is_valid_number, '和歌山県和歌山市船所');
ok($zip->set_number('6408462')->is_valid_number, '和歌山県和歌山市粟');
ok($zip->set_number('6408463')->is_valid_number, '和歌山県和歌山市楠見中');
ok($zip->set_number('6408464')->is_valid_number, '和歌山県和歌山市市小路');
ok($zip->set_number('6408471')->is_valid_number, '和歌山県和歌山市善明寺');
ok($zip->set_number('6408472')->is_valid_number, '和歌山県和歌山市大谷');
ok($zip->set_number('6408481')->is_valid_number, '和歌山県和歌山市直川');
ok($zip->set_number('6408482')->is_valid_number, '和歌山県和歌山市六十谷');
ok($zip->set_number('6408483')->is_valid_number, '和歌山県和歌山市園部');
ok($zip->set_number('6410001')->is_valid_number, '和歌山県和歌山市杭ノ瀬');
ok($zip->set_number('6410002')->is_valid_number, '和歌山県和歌山市新中島');
ok($zip->set_number('6410003')->is_valid_number, '和歌山県和歌山市坂田');
ok($zip->set_number('6410004')->is_valid_number, '和歌山県和歌山市和田');
ok($zip->set_number('6410005')->is_valid_number, '和歌山県和歌山市田尻');
ok($zip->set_number('6410006')->is_valid_number, '和歌山県和歌山市中島');
ok($zip->set_number('6410007')->is_valid_number, '和歌山県和歌山市小雑賀');
ok($zip->set_number('6410008')->is_valid_number, '和歌山県和歌山市北中島');
ok($zip->set_number('6410011')->is_valid_number, '和歌山県和歌山市三葛');
ok($zip->set_number('6410012')->is_valid_number, '和歌山県和歌山市紀三井寺');
ok($zip->set_number('6410013')->is_valid_number, '和歌山県和歌山市内原');
ok($zip->set_number('6410014')->is_valid_number, '和歌山県和歌山市毛見');
ok($zip->set_number('6410015')->is_valid_number, '和歌山県和歌山市布引');
ok($zip->set_number('6410021')->is_valid_number, '和歌山県和歌山市和歌浦東');
ok($zip->set_number('6410022')->is_valid_number, '和歌山県和歌山市和歌浦南');
ok($zip->set_number('6410023')->is_valid_number, '和歌山県和歌山市新和歌浦');
ok($zip->set_number('6410024')->is_valid_number, '和歌山県和歌山市和歌浦西');
ok($zip->set_number('6410025')->is_valid_number, '和歌山県和歌山市和歌浦中');
ok($zip->set_number('6410031')->is_valid_number, '和歌山県和歌山市西小二里');
ok($zip->set_number('6410032')->is_valid_number, '和歌山県和歌山市東小二里町');
ok($zip->set_number('6410033')->is_valid_number, '和歌山県和歌山市松ケ丘');
ok($zip->set_number('6410034')->is_valid_number, '和歌山県和歌山市新高町');
ok($zip->set_number('6410035')->is_valid_number, '和歌山県和歌山市関戸');
ok($zip->set_number('6410036')->is_valid_number, '和歌山県和歌山市西浜');
ok($zip->set_number('6410041')->is_valid_number, '和歌山県和歌山市堀止南ノ丁');
ok($zip->set_number('6410042')->is_valid_number, '和歌山県和歌山市新堀東');
ok($zip->set_number('6410043')->is_valid_number, '和歌山県和歌山市宇須');
ok($zip->set_number('6410044')->is_valid_number, '和歌山県和歌山市今福');
ok($zip->set_number('6410045')->is_valid_number, '和歌山県和歌山市堀止西');
ok($zip->set_number('6410051')->is_valid_number, '和歌山県和歌山市西高松');
ok($zip->set_number('6410052')->is_valid_number, '和歌山県和歌山市東高松');
ok($zip->set_number('6410053')->is_valid_number, '和歌山県和歌山市打越町');
ok($zip->set_number('6410054')->is_valid_number, '和歌山県和歌山市塩屋');
ok($zip->set_number('6410055')->is_valid_number, '和歌山県和歌山市和歌川町');
ok($zip->set_number('6410056')->is_valid_number, '和歌山県和歌山市秋葉町');
ok($zip->set_number('6410061')->is_valid_number, '和歌山県和歌山市田野');
ok($zip->set_number('6410062')->is_valid_number, '和歌山県和歌山市雑賀崎');
ok($zip->set_number('6420000')->is_valid_number, '和歌山県海南市以下に掲載がない場合');
ok($zip->set_number('6420001')->is_valid_number, '和歌山県海南市船尾');
ok($zip->set_number('6420002')->is_valid_number, '和歌山県海南市日方');
ok($zip->set_number('6420003')->is_valid_number, '和歌山県海南市山崎町');
ok($zip->set_number('6420004')->is_valid_number, '和歌山県海南市馬場町');
ok($zip->set_number('6420011')->is_valid_number, '和歌山県海南市黒江');
ok($zip->set_number('6420012')->is_valid_number, '和歌山県海南市岡田');
ok($zip->set_number('6420013')->is_valid_number, '和歌山県海南市多田');
ok($zip->set_number('6420014')->is_valid_number, '和歌山県海南市小野田');
ok($zip->set_number('6420015')->is_valid_number, '和歌山県海南市且来');
ok($zip->set_number('6420016')->is_valid_number, '和歌山県海南市北赤坂');
ok($zip->set_number('6420017')->is_valid_number, '和歌山県海南市南赤坂');
ok($zip->set_number('6420018')->is_valid_number, '和歌山県海南市重根東');
ok($zip->set_number('6420019')->is_valid_number, '和歌山県海南市重根西');
ok($zip->set_number('6420021')->is_valid_number, '和歌山県海南市井田');
ok($zip->set_number('6420022')->is_valid_number, '和歌山県海南市大野中');
ok($zip->set_number('6420023')->is_valid_number, '和歌山県海南市重根');
ok($zip->set_number('6420024')->is_valid_number, '和歌山県海南市阪井');
ok($zip->set_number('6420025')->is_valid_number, '和歌山県海南市東畑');
ok($zip->set_number('6420026')->is_valid_number, '和歌山県海南市別所');
ok($zip->set_number('6420027')->is_valid_number, '和歌山県海南市扱沢');
ok($zip->set_number('6420028')->is_valid_number, '和歌山県海南市幡川');
ok($zip->set_number('6420029')->is_valid_number, '和歌山県海南市山田');
ok($zip->set_number('6420031')->is_valid_number, '和歌山県海南市築地');
ok($zip->set_number('6420032')->is_valid_number, '和歌山県海南市名高');
ok($zip->set_number('6420033')->is_valid_number, '和歌山県海南市鳥居');
ok($zip->set_number('6420034')->is_valid_number, '和歌山県海南市藤白');
ok($zip->set_number('6420035')->is_valid_number, '和歌山県海南市冷水');
ok($zip->set_number('6430000')->is_valid_number, '和歌山県有田郡湯浅町以下に掲載がない場合');
ok($zip->set_number('6430000')->is_valid_number, '和歌山県有田郡広川町以下に掲載がない場合');
ok($zip->set_number('6430000')->is_valid_number, '和歌山県有田郡有田川町以下に掲載がない場合');
ok($zip->set_number('6430001')->is_valid_number, '和歌山県有田郡湯浅町山田');
ok($zip->set_number('6430002')->is_valid_number, '和歌山県有田郡湯浅町青木');
ok($zip->set_number('6430003')->is_valid_number, '和歌山県有田郡湯浅町別所');
ok($zip->set_number('6430004')->is_valid_number, '和歌山県有田郡湯浅町湯浅');
ok($zip->set_number('6430005')->is_valid_number, '和歌山県有田郡湯浅町栖原');
ok($zip->set_number('6430006')->is_valid_number, '和歌山県有田郡湯浅町田');
ok($zip->set_number('6430007')->is_valid_number, '和歌山県有田郡湯浅町吉川');
ok($zip->set_number('6430021')->is_valid_number, '和歌山県有田郡有田川町下津野');
ok($zip->set_number('6430022')->is_valid_number, '和歌山県有田郡有田川町奥');
ok($zip->set_number('6430023')->is_valid_number, '和歌山県有田郡有田川町熊井');
ok($zip->set_number('6430024')->is_valid_number, '和歌山県有田郡有田川町水尻');
ok($zip->set_number('6430025')->is_valid_number, '和歌山県有田郡有田川町土生');
ok($zip->set_number('6430026')->is_valid_number, '和歌山県有田郡有田川町植野');
ok($zip->set_number('6430031')->is_valid_number, '和歌山県有田郡有田川町野田');
ok($zip->set_number('6430032')->is_valid_number, '和歌山県有田郡有田川町天満');
ok($zip->set_number('6430033')->is_valid_number, '和歌山県有田郡有田川町明王寺');
ok($zip->set_number('6430034')->is_valid_number, '和歌山県有田郡有田川町小島');
ok($zip->set_number('6430051')->is_valid_number, '和歌山県有田郡広川町下津木');
ok($zip->set_number('6430052')->is_valid_number, '和歌山県有田郡広川町上津木');
ok($zip->set_number('6430053')->is_valid_number, '和歌山県有田郡広川町河瀬');
ok($zip->set_number('6430054')->is_valid_number, '和歌山県有田郡広川町前田');
ok($zip->set_number('6430055')->is_valid_number, '和歌山県有田郡広川町井関');
ok($zip->set_number('6430061')->is_valid_number, '和歌山県有田郡広川町柳瀬');
ok($zip->set_number('6430062')->is_valid_number, '和歌山県有田郡広川町殿');
ok($zip->set_number('6430063')->is_valid_number, '和歌山県有田郡広川町南金屋');
ok($zip->set_number('6430064')->is_valid_number, '和歌山県有田郡広川町上中野');
ok($zip->set_number('6430065')->is_valid_number, '和歌山県有田郡広川町東中');
ok($zip->set_number('6430066')->is_valid_number, '和歌山県有田郡広川町名島');
ok($zip->set_number('6430071')->is_valid_number, '和歌山県有田郡広川町広');
ok($zip->set_number('6430072')->is_valid_number, '和歌山県有田郡広川町山本');
ok($zip->set_number('6430073')->is_valid_number, '和歌山県有田郡広川町唐尾');
ok($zip->set_number('6430074')->is_valid_number, '和歌山県有田郡広川町西広');
ok($zip->set_number('6430075')->is_valid_number, '和歌山県有田郡広川町和田');
ok($zip->set_number('6430121')->is_valid_number, '和歌山県有田郡有田川町彦ケ瀬');
ok($zip->set_number('6430122')->is_valid_number, '和歌山県有田郡有田川町瀬井');
ok($zip->set_number('6430123')->is_valid_number, '和歌山県有田郡有田川町中');
ok($zip->set_number('6430124')->is_valid_number, '和歌山県有田郡有田川町中峯');
ok($zip->set_number('6430125')->is_valid_number, '和歌山県有田郡有田川町沼田');
ok($zip->set_number('6430126')->is_valid_number, '和歌山県有田郡有田川町本堂');
ok($zip->set_number('6430127')->is_valid_number, '和歌山県有田郡有田川町有原');
ok($zip->set_number('6430128')->is_valid_number, '和歌山県有田郡有田川町西ケ峯');
ok($zip->set_number('6430129')->is_valid_number, '和歌山県有田郡有田川町畦田');
ok($zip->set_number('6430131')->is_valid_number, '和歌山県有田郡有田川町生石');
ok($zip->set_number('6430132')->is_valid_number, '和歌山県有田郡有田川町小原');
ok($zip->set_number('6430133')->is_valid_number, '和歌山県有田郡有田川町尾上');
ok($zip->set_number('6430134')->is_valid_number, '和歌山県有田郡有田川町大薗');
ok($zip->set_number('6430135')->is_valid_number, '和歌山県有田郡有田川町大西');
ok($zip->set_number('6430136')->is_valid_number, '和歌山県有田郡有田川町青田');
ok($zip->set_number('6430137')->is_valid_number, '和歌山県有田郡有田川町延坂');
ok($zip->set_number('6430141')->is_valid_number, '和歌山県有田郡有田川町伏羊');
ok($zip->set_number('6430142')->is_valid_number, '和歌山県有田郡有田川町小川');
ok($zip->set_number('6430143')->is_valid_number, '和歌山県有田郡有田川町中野');
ok($zip->set_number('6430144')->is_valid_number, '和歌山県有田郡有田川町市場');
ok($zip->set_number('6430151')->is_valid_number, '和歌山県有田郡有田川町長谷川');
ok($zip->set_number('6430152')->is_valid_number, '和歌山県有田郡有田川町金屋');
ok($zip->set_number('6430153')->is_valid_number, '和歌山県有田郡有田川町中井原');
ok($zip->set_number('6430161')->is_valid_number, '和歌山県有田郡有田川町歓喜寺');
ok($zip->set_number('6430162')->is_valid_number, '和歌山県有田郡有田川町松原');
ok($zip->set_number('6430163')->is_valid_number, '和歌山県有田郡有田川町修理川');
ok($zip->set_number('6430164')->is_valid_number, '和歌山県有田郡有田川町宇井苔');
ok($zip->set_number('6430165')->is_valid_number, '和歌山県有田郡有田川町糸川');
ok($zip->set_number('6430166')->is_valid_number, '和歌山県有田郡有田川町吉原');
ok($zip->set_number('6430171')->is_valid_number, '和歌山県有田郡有田川町上六川');
ok($zip->set_number('6430172')->is_valid_number, '和歌山県有田郡有田川町黒松');
ok($zip->set_number('6430173')->is_valid_number, '和歌山県有田郡有田川町下六川');
ok($zip->set_number('6430174')->is_valid_number, '和歌山県有田郡有田川町糸野');
ok($zip->set_number('6430175')->is_valid_number, '和歌山県有田郡有田川町丹生');
ok($zip->set_number('6430176')->is_valid_number, '和歌山県有田郡有田川町釜中');
ok($zip->set_number('6430311')->is_valid_number, '和歌山県有田郡有田川町谷');
ok($zip->set_number('6430312')->is_valid_number, '和歌山県有田郡有田川町岩野河');
ok($zip->set_number('6430313')->is_valid_number, '和歌山県有田郡有田川町川口');
ok($zip->set_number('6430314')->is_valid_number, '和歌山県有田郡有田川町立石');
ok($zip->set_number('6430361')->is_valid_number, '和歌山県有田郡有田川町三瀬川');
ok($zip->set_number('6430362')->is_valid_number, '和歌山県有田郡有田川町北野川');
ok($zip->set_number('6430363')->is_valid_number, '和歌山県有田郡有田川町二沢');
ok($zip->set_number('6430364')->is_valid_number, '和歌山県有田郡有田川町川合');
ok($zip->set_number('6430365')->is_valid_number, '和歌山県有田郡有田川町中原');
ok($zip->set_number('6430366')->is_valid_number, '和歌山県有田郡有田川町粟生');
ok($zip->set_number('6430511')->is_valid_number, '和歌山県有田郡有田川町三田');
ok($zip->set_number('6430512')->is_valid_number, '和歌山県有田郡有田川町宮川');
ok($zip->set_number('6430513')->is_valid_number, '和歌山県有田郡有田川町大蔵');
ok($zip->set_number('6430514')->is_valid_number, '和歌山県有田郡有田川町久野原');
ok($zip->set_number('6430515')->is_valid_number, '和歌山県有田郡有田川町室川');
ok($zip->set_number('6430521')->is_valid_number, '和歌山県有田郡有田川町清水');
ok($zip->set_number('6430522')->is_valid_number, '和歌山県有田郡有田川町下湯川');
ok($zip->set_number('6430531')->is_valid_number, '和歌山県有田郡有田川町楠本');
ok($zip->set_number('6430532')->is_valid_number, '和歌山県有田郡有田川町沼');
ok($zip->set_number('6430533')->is_valid_number, '和歌山県有田郡有田川町遠井');
ok($zip->set_number('6430541')->is_valid_number, '和歌山県有田郡有田川町東大谷');
ok($zip->set_number('6430542')->is_valid_number, '和歌山県有田郡有田川町二川');
ok($zip->set_number('6430543')->is_valid_number, '和歌山県有田郡有田川町日物川');
ok($zip->set_number('6430544')->is_valid_number, '和歌山県有田郡有田川町境川');
ok($zip->set_number('6430551')->is_valid_number, '和歌山県有田郡有田川町上湯川');
ok($zip->set_number('6430601')->is_valid_number, '和歌山県有田郡有田川町押手');
ok($zip->set_number('6430602')->is_valid_number, '和歌山県有田郡有田川町杉野原');
ok($zip->set_number('6430603')->is_valid_number, '和歌山県有田郡有田川町板尾');
ok($zip->set_number('6430604')->is_valid_number, '和歌山県有田郡有田川町井谷');
ok($zip->set_number('6430605')->is_valid_number, '和歌山県有田郡有田川町沼谷');
ok($zip->set_number('6430611')->is_valid_number, '和歌山県伊都郡かつらぎ町花園梁瀬');
ok($zip->set_number('6430612')->is_valid_number, '和歌山県伊都郡かつらぎ町花園北寺');
ok($zip->set_number('6430613')->is_valid_number, '和歌山県伊都郡かつらぎ町花園池ノ窪');
ok($zip->set_number('6430614')->is_valid_number, '和歌山県伊都郡かつらぎ町花園新子');
ok($zip->set_number('6430801')->is_valid_number, '和歌山県有田郡有田川町徳田');
ok($zip->set_number('6430802')->is_valid_number, '和歌山県有田郡有田川町吉見');
ok($zip->set_number('6430803')->is_valid_number, '和歌山県有田郡有田川町東丹生図');
ok($zip->set_number('6430811')->is_valid_number, '和歌山県有田郡有田川町庄');
ok($zip->set_number('6430812')->is_valid_number, '和歌山県有田郡有田川町垣倉');
ok($zip->set_number('6430813')->is_valid_number, '和歌山県有田郡有田川町西丹生図');
ok($zip->set_number('6430841')->is_valid_number, '和歌山県有田郡有田川町長谷');
ok($zip->set_number('6430842')->is_valid_number, '和歌山県有田郡有田川町船坂');
ok($zip->set_number('6430843')->is_valid_number, '和歌山県有田郡有田川町賢');
ok($zip->set_number('6430844')->is_valid_number, '和歌山県有田郡有田川町井口');
ok($zip->set_number('6430845')->is_valid_number, '和歌山県有田郡有田川町大谷');
ok($zip->set_number('6430846')->is_valid_number, '和歌山県有田郡有田川町田口');
ok($zip->set_number('6430847')->is_valid_number, '和歌山県有田郡有田川町大賀畑');
ok($zip->set_number('6430848')->is_valid_number, '和歌山県有田郡有田川町田角');
ok($zip->set_number('6430851')->is_valid_number, '和歌山県有田郡有田川町出');
ok($zip->set_number('6430852')->is_valid_number, '和歌山県有田郡有田川町尾中');
ok($zip->set_number('6430853')->is_valid_number, '和歌山県有田郡有田川町角');
ok($zip->set_number('6430854')->is_valid_number, '和歌山県有田郡有田川町長田');
ok($zip->set_number('6430855')->is_valid_number, '和歌山県有田郡有田川町上中島');
ok($zip->set_number('6440000')->is_valid_number, '和歌山県御坊市以下に掲載がない場合');
ok($zip->set_number('6440000')->is_valid_number, '和歌山県日高郡美浜町以下に掲載がない場合');
ok($zip->set_number('6440001')->is_valid_number, '和歌山県御坊市御坊');
ok($zip->set_number('6440002')->is_valid_number, '和歌山県御坊市薗');
ok($zip->set_number('6440003')->is_valid_number, '和歌山県御坊市島');
ok($zip->set_number('6440004')->is_valid_number, '和歌山県御坊市名屋');
ok($zip->set_number('6440005')->is_valid_number, '和歌山県御坊市名屋町');
ok($zip->set_number('6440011')->is_valid_number, '和歌山県御坊市湯川町財部');
ok($zip->set_number('6440012')->is_valid_number, '和歌山県御坊市湯川町小松原');
ok($zip->set_number('6440013')->is_valid_number, '和歌山県御坊市湯川町丸山');
ok($zip->set_number('6440014')->is_valid_number, '和歌山県御坊市湯川町富安');
ok($zip->set_number('6440015')->is_valid_number, '和歌山県御坊市荊木');
ok($zip->set_number('6440021')->is_valid_number, '和歌山県御坊市名田町楠井');
ok($zip->set_number('6440022')->is_valid_number, '和歌山県御坊市名田町上野');
ok($zip->set_number('6440023')->is_valid_number, '和歌山県御坊市名田町野島');
ok($zip->set_number('6440024')->is_valid_number, '和歌山県御坊市塩屋町南塩屋');
ok($zip->set_number('6440025')->is_valid_number, '和歌山県御坊市塩屋町北塩屋');
ok($zip->set_number('6440031')->is_valid_number, '和歌山県御坊市野口');
ok($zip->set_number('6440032')->is_valid_number, '和歌山県御坊市岩内');
ok($zip->set_number('6440033')->is_valid_number, '和歌山県御坊市熊野');
ok($zip->set_number('6440034')->is_valid_number, '和歌山県御坊市明神川');
ok($zip->set_number('6440041')->is_valid_number, '和歌山県日高郡美浜町田井');
ok($zip->set_number('6440042')->is_valid_number, '和歌山県日高郡美浜町浜ノ瀬');
ok($zip->set_number('6440043')->is_valid_number, '和歌山県日高郡美浜町吉原');
ok($zip->set_number('6440044')->is_valid_number, '和歌山県日高郡美浜町和田');
ok($zip->set_number('6440045')->is_valid_number, '和歌山県日高郡美浜町三尾');
ok($zip->set_number('6440201')->is_valid_number, '和歌山県日高郡印南町川又');
ok($zip->set_number('6440202')->is_valid_number, '和歌山県日高郡印南町上洞');
ok($zip->set_number('6440211')->is_valid_number, '和歌山県日高郡印南町高串');
ok($zip->set_number('6440212')->is_valid_number, '和歌山県日高郡印南町田ノ垣内');
ok($zip->set_number('6440213')->is_valid_number, '和歌山県日高郡印南町西神ノ川');
ok($zip->set_number('6440214')->is_valid_number, '和歌山県日高郡印南町小原');
ok($zip->set_number('6440215')->is_valid_number, '和歌山県日高郡印南町皆瀬川');
ok($zip->set_number('6440216')->is_valid_number, '和歌山県日高郡印南町崎ノ原');
ok($zip->set_number('6440217')->is_valid_number, '和歌山県日高郡印南町丹生');
ok($zip->set_number('6440218')->is_valid_number, '和歌山県日高郡印南町松原');
ok($zip->set_number('6441101')->is_valid_number, '和歌山県日高郡日高川町藤野川');
ok($zip->set_number('6441111')->is_valid_number, '和歌山県日高郡日高川町船津');
ok($zip->set_number('6441121')->is_valid_number, '和歌山県日高郡日高川町西原');
ok($zip->set_number('6441122')->is_valid_number, '和歌山県日高郡日高川町高津尾');
ok($zip->set_number('6441123')->is_valid_number, '和歌山県日高郡日高川町高津尾川');
ok($zip->set_number('6441131')->is_valid_number, '和歌山県日高郡日高川町三十井川');
ok($zip->set_number('6441132')->is_valid_number, '和歌山県日高郡日高川町姉子');
ok($zip->set_number('6441133')->is_valid_number, '和歌山県日高郡日高川町原日浦');
ok($zip->set_number('6441134')->is_valid_number, '和歌山県日高郡日高川町三十木');
ok($zip->set_number('6441141')->is_valid_number, '和歌山県日高郡日高川町上田原');
ok($zip->set_number('6441142')->is_valid_number, '和歌山県日高郡日高川町下田原');
ok($zip->set_number('6441143')->is_valid_number, '和歌山県日高郡日高川町小釜本');
ok($zip->set_number('6441151')->is_valid_number, '和歌山県日高郡日高川町田尻');
ok($zip->set_number('6441152')->is_valid_number, '和歌山県日高郡日高川町三佐');
ok($zip->set_number('6441161')->is_valid_number, '和歌山県日高郡日高川町坂野川');
ok($zip->set_number('6441162')->is_valid_number, '和歌山県日高郡日高川町老星');
ok($zip->set_number('6441163')->is_valid_number, '和歌山県日高郡日高川町大又');
ok($zip->set_number('6441164')->is_valid_number, '和歌山県日高郡日高川町佐井');
ok($zip->set_number('6441201')->is_valid_number, '和歌山県日高郡日高川町川原河');
ok($zip->set_number('6441211')->is_valid_number, '和歌山県日高郡日高川町弥谷');
ok($zip->set_number('6441212')->is_valid_number, '和歌山県日高郡日高川町皆瀬');
ok($zip->set_number('6441213')->is_valid_number, '和歌山県日高郡日高川町愛川');
ok($zip->set_number('6441214')->is_valid_number, '和歌山県日高郡日高川町上初湯川');
ok($zip->set_number('6441221')->is_valid_number, '和歌山県日高郡日高川町寒川');
ok($zip->set_number('6441222')->is_valid_number, '和歌山県日高郡日高川町串本');
ok($zip->set_number('6441231')->is_valid_number, '和歌山県日高郡日高川町初湯川');
ok($zip->set_number('6441241')->is_valid_number, '和歌山県日高郡日高川町滝頭');
ok($zip->set_number('6441242')->is_valid_number, '和歌山県日高郡日高川町熊野川');
ok($zip->set_number('6441243')->is_valid_number, '和歌山県日高郡日高川町浅間');
ok($zip->set_number('6441244')->is_valid_number, '和歌山県日高郡日高川町上越方');
ok($zip->set_number('6450000')->is_valid_number, '和歌山県日高郡みなべ町以下に掲載がない場合');
ok($zip->set_number('6450001')->is_valid_number, '和歌山県日高郡みなべ町東吉田');
ok($zip->set_number('6450002')->is_valid_number, '和歌山県日高郡みなべ町芝');
ok($zip->set_number('6450003')->is_valid_number, '和歌山県日高郡みなべ町堺');
ok($zip->set_number('6450004')->is_valid_number, '和歌山県日高郡みなべ町埴田');
ok($zip->set_number('6450005')->is_valid_number, '和歌山県日高郡みなべ町南道');
ok($zip->set_number('6450006')->is_valid_number, '和歌山県日高郡みなべ町北道');
ok($zip->set_number('6450011')->is_valid_number, '和歌山県日高郡みなべ町気佐藤');
ok($zip->set_number('6450012')->is_valid_number, '和歌山県日高郡みなべ町山内');
ok($zip->set_number('6450013')->is_valid_number, '和歌山県日高郡みなべ町東岩代');
ok($zip->set_number('6450014')->is_valid_number, '和歌山県日高郡みなべ町西岩代');
ok($zip->set_number('6450021')->is_valid_number, '和歌山県日高郡みなべ町東本庄');
ok($zip->set_number('6450022')->is_valid_number, '和歌山県日高郡みなべ町晩稲');
ok($zip->set_number('6450023')->is_valid_number, '和歌山県日高郡みなべ町熊岡');
ok($zip->set_number('6450024')->is_valid_number, '和歌山県日高郡みなべ町徳蔵');
ok($zip->set_number('6450025')->is_valid_number, '和歌山県日高郡みなべ町筋');
ok($zip->set_number('6450026')->is_valid_number, '和歌山県日高郡みなべ町谷口');
ok($zip->set_number('6450027')->is_valid_number, '和歌山県日高郡みなべ町西本庄');
ok($zip->set_number('6450028')->is_valid_number, '和歌山県日高郡みなべ町熊瀬川');
ok($zip->set_number('6450201')->is_valid_number, '和歌山県日高郡みなべ町清川');
ok($zip->set_number('6450202')->is_valid_number, '和歌山県日高郡みなべ町東神野川');
ok($zip->set_number('6450203')->is_valid_number, '和歌山県日高郡みなべ町島之瀬');
ok($zip->set_number('6450204')->is_valid_number, '和歌山県日高郡みなべ町広野');
ok($zip->set_number('6450205')->is_valid_number, '和歌山県日高郡みなべ町滝');
ok($zip->set_number('6450206')->is_valid_number, '和歌山県日高郡みなべ町土井');
ok($zip->set_number('6450207')->is_valid_number, '和歌山県日高郡みなべ町高野');
ok($zip->set_number('6450208')->is_valid_number, '和歌山県日高郡みなべ町市井川');
ok($zip->set_number('6450301')->is_valid_number, '和歌山県田辺市龍神村福井');
ok($zip->set_number('6450302')->is_valid_number, '和歌山県田辺市龍神村甲斐ノ川');
ok($zip->set_number('6450303')->is_valid_number, '和歌山県田辺市龍神村小家');
ok($zip->set_number('6450411')->is_valid_number, '和歌山県田辺市龍神村宮代');
ok($zip->set_number('6450412')->is_valid_number, '和歌山県田辺市龍神村丹生ノ川');
ok($zip->set_number('6450413')->is_valid_number, '和歌山県田辺市龍神村殿原');
ok($zip->set_number('6450414')->is_valid_number, '和歌山県田辺市龍神村東');
ok($zip->set_number('6450415')->is_valid_number, '和歌山県田辺市龍神村西');
ok($zip->set_number('6450416')->is_valid_number, '和歌山県田辺市龍神村安井');
ok($zip->set_number('6450417')->is_valid_number, '和歌山県田辺市龍神村柳瀬');
ok($zip->set_number('6450521')->is_valid_number, '和歌山県田辺市龍神村小又川');
ok($zip->set_number('6450522')->is_valid_number, '和歌山県田辺市龍神村三ツ又');
ok($zip->set_number('6450523')->is_valid_number, '和歌山県田辺市龍神村広井原');
ok($zip->set_number('6450524')->is_valid_number, '和歌山県田辺市龍神村湯ノ又');
ok($zip->set_number('6450525')->is_valid_number, '和歌山県田辺市龍神村龍神');
ok($zip->set_number('6450551')->is_valid_number, '和歌山県日高郡日高川町寒川(小川)');
ok($zip->set_number('6460000')->is_valid_number, '和歌山県田辺市以下に掲載がない場合');
ok($zip->set_number('6460001')->is_valid_number, '和歌山県田辺市上秋津');
ok($zip->set_number('6460002')->is_valid_number, '和歌山県田辺市上万呂');
ok($zip->set_number('6460003')->is_valid_number, '和歌山県田辺市中万呂');
ok($zip->set_number('6460004')->is_valid_number, '和歌山県田辺市下万呂');
ok($zip->set_number('6460005')->is_valid_number, '和歌山県田辺市秋津町');
ok($zip->set_number('6460011')->is_valid_number, '和歌山県田辺市新庄町');
ok($zip->set_number('6460012')->is_valid_number, '和歌山県田辺市神島台');
ok($zip->set_number('6460013')->is_valid_number, '和歌山県田辺市南新万');
ok($zip->set_number('6460014')->is_valid_number, '和歌山県田辺市新万');
ok($zip->set_number('6460015')->is_valid_number, '和歌山県田辺市たきない町');
ok($zip->set_number('6460021')->is_valid_number, '和歌山県田辺市あけぼの');
ok($zip->set_number('6460022')->is_valid_number, '和歌山県田辺市東山');
ok($zip->set_number('6460023')->is_valid_number, '和歌山県田辺市文里');
ok($zip->set_number('6460024')->is_valid_number, '和歌山県田辺市学園');
ok($zip->set_number('6460025')->is_valid_number, '和歌山県田辺市神子浜');
ok($zip->set_number('6460026')->is_valid_number, '和歌山県田辺市宝来町');
ok($zip->set_number('6460027')->is_valid_number, '和歌山県田辺市朝日ヶ丘');
ok($zip->set_number('6460028')->is_valid_number, '和歌山県田辺市高雄');
ok($zip->set_number('6460029')->is_valid_number, '和歌山県田辺市東陽');
ok($zip->set_number('6460031')->is_valid_number, '和歌山県田辺市湊');
ok($zip->set_number('6460032')->is_valid_number, '和歌山県田辺市下屋敷町');
ok($zip->set_number('6460033')->is_valid_number, '和歌山県田辺市新屋敷町');
ok($zip->set_number('6460034')->is_valid_number, '和歌山県田辺市扇ケ浜');
ok($zip->set_number('6460035')->is_valid_number, '和歌山県田辺市中屋敷町');
ok($zip->set_number('6460036')->is_valid_number, '和歌山県田辺市上屋敷');
ok($zip->set_number('6460037')->is_valid_number, '和歌山県田辺市磯間');
ok($zip->set_number('6460038')->is_valid_number, '和歌山県田辺市末広町');
ok($zip->set_number('6460041')->is_valid_number, '和歌山県田辺市北新町');
ok($zip->set_number('6460042')->is_valid_number, '和歌山県田辺市南新町');
ok($zip->set_number('6460043')->is_valid_number, '和歌山県田辺市今福町');
ok($zip->set_number('6460044')->is_valid_number, '和歌山県田辺市福路町');
ok($zip->set_number('6460045')->is_valid_number, '和歌山県田辺市片町');
ok($zip->set_number('6460046')->is_valid_number, '和歌山県田辺市本町');
ok($zip->set_number('6460047')->is_valid_number, '和歌山県田辺市紺屋町');
ok($zip->set_number('6460048')->is_valid_number, '和歌山県田辺市栄町');
ok($zip->set_number('6460050')->is_valid_number, '和歌山県田辺市天神崎');
ok($zip->set_number('6460051')->is_valid_number, '和歌山県田辺市稲成町');
ok($zip->set_number('6460052')->is_valid_number, '和歌山県田辺市むつみ');
ok($zip->set_number('6460053')->is_valid_number, '和歌山県田辺市元町');
ok($zip->set_number('6460054')->is_valid_number, '和歌山県田辺市江川');
ok($zip->set_number('6460056')->is_valid_number, '和歌山県田辺市芳養町');
ok($zip->set_number('6460057')->is_valid_number, '和歌山県田辺市中芳養');
ok($zip->set_number('6460058')->is_valid_number, '和歌山県田辺市目良');
ok($zip->set_number('6460059')->is_valid_number, '和歌山県田辺市古尾');
ok($zip->set_number('6460061')->is_valid_number, '和歌山県田辺市上の山');
ok($zip->set_number('6460062')->is_valid_number, '和歌山県田辺市明洋');
ok($zip->set_number('6460063')->is_valid_number, '和歌山県田辺市芳養松原');
ok($zip->set_number('6460101')->is_valid_number, '和歌山県田辺市上芳養');
ok($zip->set_number('6460102')->is_valid_number, '和歌山県田辺市秋津川');
ok($zip->set_number('6460211')->is_valid_number, '和歌山県田辺市伏菟野');
ok($zip->set_number('6460212')->is_valid_number, '和歌山県田辺市上野');
ok($zip->set_number('6460213')->is_valid_number, '和歌山県田辺市長野');
ok($zip->set_number('6460214')->is_valid_number, '和歌山県田辺市上三栖');
ok($zip->set_number('6460215')->is_valid_number, '和歌山県田辺市中三栖');
ok($zip->set_number('6460216')->is_valid_number, '和歌山県田辺市下三栖');
ok($zip->set_number('6460217')->is_valid_number, '和歌山県田辺市城山台');
ok($zip->set_number('6460301')->is_valid_number, '和歌山県西牟婁郡白浜町市鹿野');
ok($zip->set_number('6460302')->is_valid_number, '和歌山県西牟婁郡白浜町上露');
ok($zip->set_number('6460303')->is_valid_number, '和歌山県西牟婁郡白浜町大瀬');
ok($zip->set_number('6460304')->is_valid_number, '和歌山県西牟婁郡白浜町竹垣内');
ok($zip->set_number('6460305')->is_valid_number, '和歌山県西牟婁郡白浜町北谷');
ok($zip->set_number('6460311')->is_valid_number, '和歌山県西牟婁郡白浜町小房');
ok($zip->set_number('6460312')->is_valid_number, '和歌山県西牟婁郡白浜町大');
ok($zip->set_number('6460313')->is_valid_number, '和歌山県西牟婁郡白浜町玉伝');
ok($zip->set_number('6460314')->is_valid_number, '和歌山県西牟婁郡白浜町里谷');
ok($zip->set_number('6461101')->is_valid_number, '和歌山県田辺市鮎川');
ok($zip->set_number('6461211')->is_valid_number, '和歌山県田辺市和田');
ok($zip->set_number('6461212')->is_valid_number, '和歌山県田辺市下川上');
ok($zip->set_number('6461213')->is_valid_number, '和歌山県田辺市下川下');
ok($zip->set_number('6461214')->is_valid_number, '和歌山県田辺市平瀬');
ok($zip->set_number('6461321')->is_valid_number, '和歌山県田辺市熊野');
ok($zip->set_number('6461322')->is_valid_number, '和歌山県田辺市面川');
ok($zip->set_number('6461323')->is_valid_number, '和歌山県田辺市向山');
ok($zip->set_number('6461324')->is_valid_number, '和歌山県田辺市竹ノ平');
ok($zip->set_number('6461325')->is_valid_number, '和歌山県田辺市小谷');
ok($zip->set_number('6461326')->is_valid_number, '和歌山県田辺市深谷');
ok($zip->set_number('6461331')->is_valid_number, '和歌山県田辺市木守');
ok($zip->set_number('6461332')->is_valid_number, '和歌山県田辺市五味');
ok($zip->set_number('6461333')->is_valid_number, '和歌山県田辺市東伏菟野');
ok($zip->set_number('6461334')->is_valid_number, '和歌山県田辺市九川');
ok($zip->set_number('6461335')->is_valid_number, '和歌山県田辺市串');
ok($zip->set_number('6461336')->is_valid_number, '和歌山県田辺市谷野口');
ok($zip->set_number('6461337')->is_valid_number, '和歌山県田辺市下露');
ok($zip->set_number('6461338')->is_valid_number, '和歌山県田辺市合川');
ok($zip->set_number('6461339')->is_valid_number, '和歌山県田辺市長瀬');
ok($zip->set_number('6461401')->is_valid_number, '和歌山県田辺市中辺路町野中');
ok($zip->set_number('6461402')->is_valid_number, '和歌山県田辺市中辺路町近露');
ok($zip->set_number('6461411')->is_valid_number, '和歌山県田辺市中辺路町大内川');
ok($zip->set_number('6461412')->is_valid_number, '和歌山県田辺市中辺路町石船');
ok($zip->set_number('6461413')->is_valid_number, '和歌山県田辺市中辺路町北郡');
ok($zip->set_number('6461414')->is_valid_number, '和歌山県田辺市中辺路町西谷');
ok($zip->set_number('6461415')->is_valid_number, '和歌山県田辺市中辺路町真砂');
ok($zip->set_number('6461416')->is_valid_number, '和歌山県田辺市中辺路町高原');
ok($zip->set_number('6461417')->is_valid_number, '和歌山県田辺市中辺路町川合');
ok($zip->set_number('6461421')->is_valid_number, '和歌山県田辺市中辺路町栗栖川');
ok($zip->set_number('6461431')->is_valid_number, '和歌山県田辺市中辺路町小松原');
ok($zip->set_number('6461432')->is_valid_number, '和歌山県田辺市中辺路町福定');
ok($zip->set_number('6461433')->is_valid_number, '和歌山県田辺市中辺路町大川');
ok($zip->set_number('6461434')->is_valid_number, '和歌山県田辺市中辺路町温川');
ok($zip->set_number('6461435')->is_valid_number, '和歌山県田辺市中辺路町小皆');
ok($zip->set_number('6461436')->is_valid_number, '和歌山県田辺市中辺路町熊野川');
ok($zip->set_number('6461437')->is_valid_number, '和歌山県田辺市中辺路町沢');
ok($zip->set_number('6461438')->is_valid_number, '和歌山県田辺市中辺路町水上');
ok($zip->set_number('6461439')->is_valid_number, '和歌山県田辺市中辺路町内井川');
ok($zip->set_number('6470000')->is_valid_number, '和歌山県新宮市以下に掲載がない場合');
ok($zip->set_number('6470001')->is_valid_number, '和歌山県新宮市相筋');
ok($zip->set_number('6470002')->is_valid_number, '和歌山県新宮市船町');
ok($zip->set_number('6470003')->is_valid_number, '和歌山県新宮市上本町');
ok($zip->set_number('6470004')->is_valid_number, '和歌山県新宮市大橋通');
ok($zip->set_number('6470005')->is_valid_number, '和歌山県新宮市元鍛治町');
ok($zip->set_number('6470006')->is_valid_number, '和歌山県新宮市薬師町');
ok($zip->set_number('6470007')->is_valid_number, '和歌山県新宮市別当屋敷町');
ok($zip->set_number('6470008')->is_valid_number, '和歌山県新宮市馬町');
ok($zip->set_number('6470010')->is_valid_number, '和歌山県新宮市丹鶴');
ok($zip->set_number('6470011')->is_valid_number, '和歌山県新宮市下本町');
ok($zip->set_number('6470012')->is_valid_number, '和歌山県新宮市伊佐田町');
ok($zip->set_number('6470013')->is_valid_number, '和歌山県新宮市春日');
ok($zip->set_number('6470014')->is_valid_number, '和歌山県新宮市浮島');
ok($zip->set_number('6470015')->is_valid_number, '和歌山県新宮市千穂');
ok($zip->set_number('6470016')->is_valid_number, '和歌山県新宮市谷王子町');
ok($zip->set_number('6470017')->is_valid_number, '和歌山県新宮市横町');
ok($zip->set_number('6470018')->is_valid_number, '和歌山県新宮市仲之町');
ok($zip->set_number('6470019')->is_valid_number, '和歌山県新宮市新町');
ok($zip->set_number('6470020')->is_valid_number, '和歌山県新宮市徐福');
ok($zip->set_number('6470021')->is_valid_number, '和歌山県新宮市池田');
ok($zip->set_number('6470022')->is_valid_number, '和歌山県新宮市阿須賀');
ok($zip->set_number('6470023')->is_valid_number, '和歌山県新宮市蓬莱');
ok($zip->set_number('6470024')->is_valid_number, '和歌山県新宮市熊野地');
ok($zip->set_number('6470025')->is_valid_number, '和歌山県新宮市あけぼの');
ok($zip->set_number('6470031')->is_valid_number, '和歌山県新宮市田鶴原町');
ok($zip->set_number('6470032')->is_valid_number, '和歌山県新宮市王子町');
ok($zip->set_number('6470033')->is_valid_number, '和歌山県新宮市清水元');
ok($zip->set_number('6470034')->is_valid_number, '和歌山県新宮市丸山');
ok($zip->set_number('6470041')->is_valid_number, '和歌山県新宮市野田');
ok($zip->set_number('6470042')->is_valid_number, '和歌山県新宮市下田');
ok($zip->set_number('6470043')->is_valid_number, '和歌山県新宮市緑ケ丘');
ok($zip->set_number('6470044')->is_valid_number, '和歌山県新宮市神倉');
ok($zip->set_number('6470045')->is_valid_number, '和歌山県新宮市井の沢');
ok($zip->set_number('6470051')->is_valid_number, '和歌山県新宮市磐盾');
ok($zip->set_number('6470052')->is_valid_number, '和歌山県新宮市橋本');
ok($zip->set_number('6470053')->is_valid_number, '和歌山県新宮市五新');
ok($zip->set_number('6470054')->is_valid_number, '和歌山県新宮市南檜杖');
ok($zip->set_number('6470061')->is_valid_number, '和歌山県新宮市三輪崎');
ok($zip->set_number('6470071')->is_valid_number, '和歌山県新宮市佐野');
ok($zip->set_number('6470072')->is_valid_number, '和歌山県新宮市蜂伏');
ok($zip->set_number('6470073')->is_valid_number, '和歌山県新宮市木ノ川');
ok($zip->set_number('6470081')->is_valid_number, '和歌山県新宮市新宮');
ok($zip->set_number('6471101')->is_valid_number, '和歌山県新宮市高田');
ok($zip->set_number('6471102')->is_valid_number, '和歌山県新宮市相賀');
ok($zip->set_number('6471103')->is_valid_number, '和歌山県新宮市南檜杖(土ノ河)');
ok($zip->set_number('6471201')->is_valid_number, '和歌山県新宮市熊野川町上長井');
ok($zip->set_number('6471202')->is_valid_number, '和歌山県新宮市熊野川町東');
ok($zip->set_number('6471203')->is_valid_number, '和歌山県新宮市熊野川町大山');
ok($zip->set_number('6471204')->is_valid_number, '和歌山県新宮市熊野川町鎌塚');
ok($zip->set_number('6471205')->is_valid_number, '和歌山県新宮市熊野川町滝本');
ok($zip->set_number('6471206')->is_valid_number, '和歌山県新宮市熊野川町西');
ok($zip->set_number('6471207')->is_valid_number, '和歌山県新宮市熊野川町畝畑');
ok($zip->set_number('6471211')->is_valid_number, '和歌山県新宮市熊野川町日足');
ok($zip->set_number('6471212')->is_valid_number, '和歌山県新宮市熊野川町田長');
ok($zip->set_number('6471213')->is_valid_number, '和歌山県新宮市熊野川町能城山本');
ok($zip->set_number('6471214')->is_valid_number, '和歌山県新宮市熊野川町赤木');
ok($zip->set_number('6471215')->is_valid_number, '和歌山県新宮市熊野川町椋井');
ok($zip->set_number('6471216')->is_valid_number, '和歌山県新宮市熊野川町相須');
ok($zip->set_number('6471221')->is_valid_number, '和歌山県新宮市熊野川町西敷屋');
ok($zip->set_number('6471222')->is_valid_number, '和歌山県新宮市熊野川町東敷屋');
ok($zip->set_number('6471223')->is_valid_number, '和歌山県新宮市熊野川町篠尾');
ok($zip->set_number('6471231')->is_valid_number, '和歌山県新宮市熊野川町玉置口');
ok($zip->set_number('6471232')->is_valid_number, '和歌山県新宮市熊野川町嶋津');
ok($zip->set_number('6471233')->is_valid_number, '和歌山県新宮市熊野川町九重');
ok($zip->set_number('6471234')->is_valid_number, '和歌山県新宮市熊野川町四滝');
ok($zip->set_number('6471235')->is_valid_number, '和歌山県新宮市熊野川町宮井');
ok($zip->set_number('6471271')->is_valid_number, '奈良県吉野郡十津川村竹筒');
ok($zip->set_number('6471321')->is_valid_number, '三重県熊野市紀和町花井');
ok($zip->set_number('6471322')->is_valid_number, '三重県熊野市紀和町小船');
ok($zip->set_number('6471323')->is_valid_number, '三重県熊野市紀和町楊枝川');
ok($zip->set_number('6471324')->is_valid_number, '三重県熊野市紀和町和気');
ok($zip->set_number('6471325')->is_valid_number, '三重県熊野市紀和町楊枝');
ok($zip->set_number('6471581')->is_valid_number, '奈良県吉野郡十津川村神下');
ok($zip->set_number('6471582')->is_valid_number, '奈良県吉野郡十津川村玉置川');
ok($zip->set_number('6471583')->is_valid_number, '奈良県吉野郡十津川村東中');
ok($zip->set_number('6471584')->is_valid_number, '奈良県吉野郡十津川村上葛川');
ok($zip->set_number('6471600')->is_valid_number, '和歌山県東牟婁郡北山村以下に掲載がない場合');
ok($zip->set_number('6471601')->is_valid_number, '和歌山県東牟婁郡北山村七色');
ok($zip->set_number('6471602')->is_valid_number, '和歌山県東牟婁郡北山村竹原');
ok($zip->set_number('6471603')->is_valid_number, '和歌山県東牟婁郡北山村大沼');
ok($zip->set_number('6471604')->is_valid_number, '和歌山県東牟婁郡北山村下尾井');
ok($zip->set_number('6471605')->is_valid_number, '和歌山県東牟婁郡北山村小松');
ok($zip->set_number('6471701')->is_valid_number, '和歌山県田辺市本宮町小津荷');
ok($zip->set_number('6471702')->is_valid_number, '和歌山県田辺市本宮町大津荷');
ok($zip->set_number('6471703')->is_valid_number, '和歌山県田辺市本宮町請川');
ok($zip->set_number('6471704')->is_valid_number, '和歌山県田辺市本宮町耳打');
ok($zip->set_number('6471705')->is_valid_number, '和歌山県田辺市本宮町高山');
ok($zip->set_number('6471711')->is_valid_number, '和歌山県田辺市本宮町皆瀬川');
ok($zip->set_number('6471712')->is_valid_number, '和歌山県田辺市本宮町田代');
ok($zip->set_number('6471713')->is_valid_number, '和歌山県田辺市本宮町簑尾谷');
ok($zip->set_number('6471714')->is_valid_number, '和歌山県田辺市本宮町静川');
ok($zip->set_number('6471715')->is_valid_number, '和歌山県田辺市本宮町東和田');
ok($zip->set_number('6471716')->is_valid_number, '和歌山県田辺市本宮町上大野');
ok($zip->set_number('6471717')->is_valid_number, '和歌山県田辺市本宮町川湯');
ok($zip->set_number('6471721')->is_valid_number, '和歌山県田辺市本宮町檜葉');
ok($zip->set_number('6471722')->is_valid_number, '和歌山県田辺市本宮町小々森');
ok($zip->set_number('6471723')->is_valid_number, '和歌山県田辺市本宮町皆地');
ok($zip->set_number('6471724')->is_valid_number, '和歌山県田辺市本宮町野竹');
ok($zip->set_number('6471725')->is_valid_number, '和歌山県田辺市本宮町大瀬');
ok($zip->set_number('6471726')->is_valid_number, '和歌山県田辺市本宮町武住');
ok($zip->set_number('6471731')->is_valid_number, '和歌山県田辺市本宮町本宮');
ok($zip->set_number('6471732')->is_valid_number, '和歌山県田辺市本宮町湯峯');
ok($zip->set_number('6471733')->is_valid_number, '和歌山県田辺市本宮町渡瀬');
ok($zip->set_number('6471734')->is_valid_number, '和歌山県田辺市本宮町下湯川');
ok($zip->set_number('6471735')->is_valid_number, '和歌山県田辺市本宮町曲川');
ok($zip->set_number('6471736')->is_valid_number, '和歌山県田辺市本宮町久保野');
ok($zip->set_number('6471741')->is_valid_number, '和歌山県田辺市本宮町大居');
ok($zip->set_number('6471742')->is_valid_number, '和歌山県田辺市本宮町一本松');
ok($zip->set_number('6471743')->is_valid_number, '和歌山県田辺市本宮町伏拝');
ok($zip->set_number('6471744')->is_valid_number, '和歌山県田辺市本宮町三越');
ok($zip->set_number('6471751')->is_valid_number, '和歌山県田辺市本宮町上切原');
ok($zip->set_number('6471752')->is_valid_number, '和歌山県田辺市本宮町切畑');
ok($zip->set_number('6471753')->is_valid_number, '和歌山県田辺市本宮町土河屋');
ok($zip->set_number('6480000')->is_valid_number, '和歌山県橋本市以下に掲載がない場合');
ok($zip->set_number('6480001')->is_valid_number, '和歌山県橋本市杉尾');
ok($zip->set_number('6480002')->is_valid_number, '和歌山県橋本市隅田町平野');
ok($zip->set_number('6480003')->is_valid_number, '和歌山県橋本市隅田町山内');
ok($zip->set_number('6480004')->is_valid_number, '和歌山県橋本市隅田町霜草');
ok($zip->set_number('6480005')->is_valid_number, '和歌山県橋本市小峰台');
ok($zip->set_number('6480006')->is_valid_number, '和歌山県橋本市境原');
ok($zip->set_number('6480007')->is_valid_number, '和歌山県橋本市紀ノ光台');
ok($zip->set_number('6480011')->is_valid_number, '和歌山県橋本市隅田町真土');
ok($zip->set_number('6480012')->is_valid_number, '和歌山県橋本市隅田町芋生');
ok($zip->set_number('6480013')->is_valid_number, '和歌山県橋本市隅田町中下');
ok($zip->set_number('6480014')->is_valid_number, '和歌山県橋本市隅田町上兵庫');
ok($zip->set_number('6480015')->is_valid_number, '和歌山県橋本市隅田町河瀬');
ok($zip->set_number('6480016')->is_valid_number, '和歌山県橋本市隅田町下兵庫');
ok($zip->set_number('6480017')->is_valid_number, '和歌山県橋本市隅田町中島');
ok($zip->set_number('6480018')->is_valid_number, '和歌山県橋本市隅田町垂井');
ok($zip->set_number('6480019')->is_valid_number, '和歌山県橋本市あやの台');
ok($zip->set_number('6480021')->is_valid_number, '和歌山県橋本市恋野');
ok($zip->set_number('6480022')->is_valid_number, '和歌山県橋本市赤塚');
ok($zip->set_number('6480023')->is_valid_number, '和歌山県橋本市中道');
ok($zip->set_number('6480024')->is_valid_number, '和歌山県橋本市上田');
ok($zip->set_number('6480025')->is_valid_number, '和歌山県橋本市向副');
ok($zip->set_number('6480031')->is_valid_number, '和歌山県橋本市只野');
ok($zip->set_number('6480032')->is_valid_number, '和歌山県橋本市谷奥深');
ok($zip->set_number('6480033')->is_valid_number, '和歌山県橋本市北宿');
ok($zip->set_number('6480034')->is_valid_number, '和歌山県橋本市南宿');
ok($zip->set_number('6480035')->is_valid_number, '和歌山県橋本市彦谷');
ok($zip->set_number('6480036')->is_valid_number, '和歌山県橋本市横座');
ok($zip->set_number('6480037')->is_valid_number, '和歌山県橋本市賢堂');
ok($zip->set_number('6480038')->is_valid_number, '和歌山県橋本市須河');
ok($zip->set_number('6480041')->is_valid_number, '和歌山県橋本市清水');
ok($zip->set_number('6480042')->is_valid_number, '和歌山県橋本市西畑');
ok($zip->set_number('6480043')->is_valid_number, '和歌山県橋本市学文路');
ok($zip->set_number('6480044')->is_valid_number, '和歌山県橋本市南馬場');
ok($zip->set_number('6480051')->is_valid_number, '和歌山県橋本市細川');
ok($zip->set_number('6480052')->is_valid_number, '和歌山県橋本市紀見');
ok($zip->set_number('6480053')->is_valid_number, '和歌山県橋本市しらさぎ台');
ok($zip->set_number('6480054')->is_valid_number, '和歌山県橋本市城山台');
ok($zip->set_number('6480061')->is_valid_number, '和歌山県橋本市北馬場');
ok($zip->set_number('6480062')->is_valid_number, '和歌山県橋本市妻');
ok($zip->set_number('6480063')->is_valid_number, '和歌山県橋本市原田');
ok($zip->set_number('6480064')->is_valid_number, '和歌山県橋本市橋本');
ok($zip->set_number('6480065')->is_valid_number, '和歌山県橋本市古佐田');
ok($zip->set_number('6480066')->is_valid_number, '和歌山県橋本市胡麻生');
ok($zip->set_number('6480071')->is_valid_number, '和歌山県橋本市小原田');
ok($zip->set_number('6480072')->is_valid_number, '和歌山県橋本市東家');
ok($zip->set_number('6480073')->is_valid_number, '和歌山県橋本市市脇');
ok($zip->set_number('6480074')->is_valid_number, '和歌山県橋本市野');
ok($zip->set_number('6480075')->is_valid_number, '和歌山県橋本市さつき台');
ok($zip->set_number('6480081')->is_valid_number, '和歌山県橋本市山田');
ok($zip->set_number('6480082')->is_valid_number, '和歌山県橋本市菖蒲谷');
ok($zip->set_number('6480083')->is_valid_number, '和歌山県橋本市出塔');
ok($zip->set_number('6480084')->is_valid_number, '和歌山県橋本市柏原');
ok($zip->set_number('6480085')->is_valid_number, '和歌山県橋本市岸上');
ok($zip->set_number('6480086')->is_valid_number, '和歌山県橋本市神野々');
ok($zip->set_number('6480087')->is_valid_number, '和歌山県橋本市吉原');
ok($zip->set_number('6480088')->is_valid_number, '和歌山県橋本市みゆき台');
ok($zip->set_number('6480091')->is_valid_number, '和歌山県橋本市柱本');
ok($zip->set_number('6480092')->is_valid_number, '和歌山県橋本市紀見ケ丘');
ok($zip->set_number('6480093')->is_valid_number, '和歌山県橋本市慶賀野');
ok($zip->set_number('6480094')->is_valid_number, '和歌山県橋本市三石台');
ok($zip->set_number('6480095')->is_valid_number, '和歌山県橋本市橋谷');
ok($zip->set_number('6480096')->is_valid_number, '和歌山県橋本市御幸辻');
ok($zip->set_number('6480097')->is_valid_number, '和歌山県橋本市柿の木坂');
ok($zip->set_number('6480098')->is_valid_number, '和歌山県橋本市矢倉脇');
ok($zip->set_number('6480099')->is_valid_number, '和歌山県橋本市光陽台');
ok($zip->set_number('6480100')->is_valid_number, '和歌山県伊都郡九度山町以下に掲載がない場合');
ok($zip->set_number('6480101')->is_valid_number, '和歌山県伊都郡九度山町九度山');
ok($zip->set_number('6480111')->is_valid_number, '和歌山県伊都郡九度山町河根');
ok($zip->set_number('6480121')->is_valid_number, '和歌山県伊都郡九度山町丹生川');
ok($zip->set_number('6480131')->is_valid_number, '和歌山県伊都郡九度山町市平');
ok($zip->set_number('6480132')->is_valid_number, '和歌山県伊都郡九度山町北又');
ok($zip->set_number('6480133')->is_valid_number, '和歌山県伊都郡九度山町東郷');
ok($zip->set_number('6480141')->is_valid_number, '和歌山県伊都郡九度山町椎出');
ok($zip->set_number('6480142')->is_valid_number, '和歌山県伊都郡九度山町笠木');
ok($zip->set_number('6480143')->is_valid_number, '和歌山県伊都郡九度山町上古沢');
ok($zip->set_number('6480144')->is_valid_number, '和歌山県伊都郡九度山町中古沢');
ok($zip->set_number('6480145')->is_valid_number, '和歌山県伊都郡九度山町下古沢');
ok($zip->set_number('6480151')->is_valid_number, '和歌山県伊都郡九度山町慈尊院');
ok($zip->set_number('6480161')->is_valid_number, '和歌山県伊都郡九度山町入郷');
ok($zip->set_number('6480171')->is_valid_number, '和歌山県伊都郡高野町西郷(その他)');
ok($zip->set_number('6480200')->is_valid_number, '和歌山県伊都郡高野町以下に掲載がない場合');
ok($zip->set_number('6480201')->is_valid_number, '和歌山県伊都郡かつらぎ町花園久木');
ok($zip->set_number('6480202')->is_valid_number, '和歌山県伊都郡かつらぎ町花園中南');
ok($zip->set_number('6480211')->is_valid_number, '和歌山県伊都郡高野町高野山');
ok($zip->set_number('6480221')->is_valid_number, '和歌山県伊都郡高野町西ケ峰');
ok($zip->set_number('6480222')->is_valid_number, '和歌山県伊都郡高野町南');
ok($zip->set_number('6480223')->is_valid_number, '和歌山県伊都郡高野町林');
ok($zip->set_number('6480224')->is_valid_number, '和歌山県伊都郡高野町平原');
ok($zip->set_number('6480225')->is_valid_number, '和歌山県伊都郡高野町杖ケ薮');
ok($zip->set_number('6480226')->is_valid_number, '和歌山県伊都郡高野町東又');
ok($zip->set_number('6480227')->is_valid_number, '和歌山県伊都郡高野町樫原');
ok($zip->set_number('6480231')->is_valid_number, '和歌山県伊都郡高野町大滝');
ok($zip->set_number('6480241')->is_valid_number, '和歌山県伊都郡高野町相ノ浦');
ok($zip->set_number('6480251')->is_valid_number, '和歌山県伊都郡高野町湯川');
ok($zip->set_number('6480261')->is_valid_number, '和歌山県伊都郡高野町西郷(神谷)');
ok($zip->set_number('6480262')->is_valid_number, '和歌山県伊都郡高野町細川');
ok($zip->set_number('6480263')->is_valid_number, '和歌山県伊都郡高野町花坂');
ok($zip->set_number('6480300')->is_valid_number, '奈良県吉野郡野迫川村以下に掲載がない場合');
ok($zip->set_number('6480301')->is_valid_number, '奈良県吉野郡野迫川村池津川');
ok($zip->set_number('6480302')->is_valid_number, '奈良県吉野郡野迫川村紫園');
ok($zip->set_number('6480303')->is_valid_number, '奈良県吉野郡野迫川村中津川');
ok($zip->set_number('6480304')->is_valid_number, '奈良県吉野郡野迫川村立里');
ok($zip->set_number('6480305')->is_valid_number, '奈良県吉野郡野迫川村北股');
ok($zip->set_number('6480306')->is_valid_number, '奈良県吉野郡野迫川村平');
ok($zip->set_number('6480307')->is_valid_number, '奈良県吉野郡野迫川村北今西');
ok($zip->set_number('6480308')->is_valid_number, '奈良県吉野郡野迫川村桧股');
ok($zip->set_number('6480309')->is_valid_number, '奈良県吉野郡野迫川村弓手原');
ok($zip->set_number('6480401')->is_valid_number, '和歌山県伊都郡高野町西富貴');
ok($zip->set_number('6480402')->is_valid_number, '和歌山県伊都郡高野町東富貴');
ok($zip->set_number('6480403')->is_valid_number, '和歌山県伊都郡高野町上筒香');
ok($zip->set_number('6480404')->is_valid_number, '和歌山県伊都郡高野町中筒香');
ok($zip->set_number('6480405')->is_valid_number, '和歌山県伊都郡高野町下筒香');
ok($zip->set_number('6490101')->is_valid_number, '和歌山県海南市下津町下津');
ok($zip->set_number('6490111')->is_valid_number, '和歌山県海南市下津町方');
ok($zip->set_number('6490112')->is_valid_number, '和歌山県海南市下津町大崎');
ok($zip->set_number('6490121')->is_valid_number, '和歌山県海南市下津町丸田');
ok($zip->set_number('6490122')->is_valid_number, '和歌山県海南市下津町黒田');
ok($zip->set_number('6490123')->is_valid_number, '和歌山県海南市下津町丁');
ok($zip->set_number('6490131')->is_valid_number, '和歌山県海南市下津町塩津');
ok($zip->set_number('6490132')->is_valid_number, '和歌山県海南市下津町梅田');
ok($zip->set_number('6490133')->is_valid_number, '和歌山県海南市下津町下');
ok($zip->set_number('6490141')->is_valid_number, '和歌山県海南市下津町小南');
ok($zip->set_number('6490142')->is_valid_number, '和歌山県海南市下津町中');
ok($zip->set_number('6490143')->is_valid_number, '和歌山県海南市下津町小松原');
ok($zip->set_number('6490144')->is_valid_number, '和歌山県海南市下津町橘本');
ok($zip->set_number('6490145')->is_valid_number, '和歌山県海南市下津町市坪');
ok($zip->set_number('6490146')->is_valid_number, '和歌山県海南市下津町沓掛');
ok($zip->set_number('6490147')->is_valid_number, '和歌山県海南市下津町青枝');
ok($zip->set_number('6490151')->is_valid_number, '和歌山県海南市下津町曽根田');
ok($zip->set_number('6490152')->is_valid_number, '和歌山県海南市下津町引尾');
ok($zip->set_number('6490153')->is_valid_number, '和歌山県海南市下津町興');
ok($zip->set_number('6490154')->is_valid_number, '和歌山県海南市下津町笠畑');
ok($zip->set_number('6490155')->is_valid_number, '和歌山県海南市下津町大窪');
ok($zip->set_number('6490156')->is_valid_number, '和歌山県海南市下津町百垣内');
ok($zip->set_number('6490161')->is_valid_number, '和歌山県海南市下津町小畑');
ok($zip->set_number('6490162')->is_valid_number, '和歌山県海南市下津町小原');
ok($zip->set_number('6490163')->is_valid_number, '和歌山県海南市下津町鰈川');
ok($zip->set_number('6490164')->is_valid_number, '和歌山県海南市下津町上');
ok($zip->set_number('6490300')->is_valid_number, '和歌山県有田市以下に掲載がない場合');
ok($zip->set_number('6490301')->is_valid_number, '和歌山県有田市下中島');
ok($zip->set_number('6490302')->is_valid_number, '和歌山県有田市山田原');
ok($zip->set_number('6490303')->is_valid_number, '和歌山県有田市新堂');
ok($zip->set_number('6490304')->is_valid_number, '和歌山県有田市箕島');
ok($zip->set_number('6490305')->is_valid_number, '和歌山県有田市港町');
ok($zip->set_number('6490306')->is_valid_number, '和歌山県有田市初島町浜');
ok($zip->set_number('6490307')->is_valid_number, '和歌山県有田市初島町里');
ok($zip->set_number('6490311')->is_valid_number, '和歌山県有田市辻堂');
ok($zip->set_number('6490312')->is_valid_number, '和歌山県有田市星尾');
ok($zip->set_number('6490313')->is_valid_number, '和歌山県有田市千田');
ok($zip->set_number('6490314')->is_valid_number, '和歌山県有田市野');
ok($zip->set_number('6490315')->is_valid_number, '和歌山県有田市山地');
ok($zip->set_number('6490316')->is_valid_number, '和歌山県有田市宮崎町');
ok($zip->set_number('6490317')->is_valid_number, '和歌山県有田市古江見');
ok($zip->set_number('6490421')->is_valid_number, '和歌山県有田市糸我町中番');
ok($zip->set_number('6490422')->is_valid_number, '和歌山県有田市糸我町西');
ok($zip->set_number('6490431')->is_valid_number, '和歌山県有田市宮原町畑');
ok($zip->set_number('6490432')->is_valid_number, '和歌山県有田市宮原町東');
ok($zip->set_number('6490433')->is_valid_number, '和歌山県有田市宮原町須谷');
ok($zip->set_number('6490434')->is_valid_number, '和歌山県有田市宮原町新町');
ok($zip->set_number('6490435')->is_valid_number, '和歌山県有田市宮原町滝川原');
ok($zip->set_number('6490436')->is_valid_number, '和歌山県有田市宮原町道');
ok($zip->set_number('6490437')->is_valid_number, '和歌山県有田市宮原町滝');
ok($zip->set_number('6491100')->is_valid_number, '和歌山県日高郡由良町以下に掲載がない場合');
ok($zip->set_number('6491101')->is_valid_number, '和歌山県日高郡由良町畑');
ok($zip->set_number('6491102')->is_valid_number, '和歌山県日高郡由良町中');
ok($zip->set_number('6491103')->is_valid_number, '和歌山県日高郡由良町門前');
ok($zip->set_number('6491104')->is_valid_number, '和歌山県日高郡由良町江ノ駒');
ok($zip->set_number('6491111')->is_valid_number, '和歌山県日高郡由良町里');
ok($zip->set_number('6491112')->is_valid_number, '和歌山県日高郡由良町網代');
ok($zip->set_number('6491113')->is_valid_number, '和歌山県日高郡由良町阿戸');
ok($zip->set_number('6491121')->is_valid_number, '和歌山県日高郡由良町吹井');
ok($zip->set_number('6491122')->is_valid_number, '和歌山県日高郡由良町神谷');
ok($zip->set_number('6491123')->is_valid_number, '和歌山県日高郡由良町大引');
ok($zip->set_number('6491131')->is_valid_number, '和歌山県日高郡由良町小引');
ok($zip->set_number('6491132')->is_valid_number, '和歌山県日高郡由良町衣奈');
ok($zip->set_number('6491133')->is_valid_number, '和歌山県日高郡由良町三尾川');
ok($zip->set_number('6491134')->is_valid_number, '和歌山県日高郡由良町戸津井');
ok($zip->set_number('6491200')->is_valid_number, '和歌山県日高郡日高町以下に掲載がない場合');
ok($zip->set_number('6491201')->is_valid_number, '和歌山県日高郡日高町原谷');
ok($zip->set_number('6491202')->is_valid_number, '和歌山県日高郡日高町萩原');
ok($zip->set_number('6491203')->is_valid_number, '和歌山県日高郡日高町池田');
ok($zip->set_number('6491211')->is_valid_number, '和歌山県日高郡日高町荊木');
ok($zip->set_number('6491212')->is_valid_number, '和歌山県日高郡日高町小中');
ok($zip->set_number('6491213')->is_valid_number, '和歌山県日高郡日高町高家');
ok($zip->set_number('6491221')->is_valid_number, '和歌山県日高郡日高町志賀');
ok($zip->set_number('6491222')->is_valid_number, '和歌山県日高郡日高町小池');
ok($zip->set_number('6491223')->is_valid_number, '和歌山県日高郡日高町小浦');
ok($zip->set_number('6491224')->is_valid_number, '和歌山県日高郡日高町津久野');
ok($zip->set_number('6491225')->is_valid_number, '和歌山県日高郡日高町方杭');
ok($zip->set_number('6491231')->is_valid_number, '和歌山県日高郡日高町小坂');
ok($zip->set_number('6491232')->is_valid_number, '和歌山県日高郡日高町阿尾');
ok($zip->set_number('6491233')->is_valid_number, '和歌山県日高郡日高町産湯');
ok($zip->set_number('6491234')->is_valid_number, '和歌山県日高郡日高町比井');
ok($zip->set_number('6491300')->is_valid_number, '和歌山県日高郡日高川町以下に掲載がない場合');
ok($zip->set_number('6491311')->is_valid_number, '和歌山県日高郡日高川町平川');
ok($zip->set_number('6491312')->is_valid_number, '和歌山県日高郡日高川町三百瀬');
ok($zip->set_number('6491313')->is_valid_number, '和歌山県日高郡日高川町伊藤川');
ok($zip->set_number('6491314')->is_valid_number, '和歌山県日高郡日高川町早藤');
ok($zip->set_number('6491315')->is_valid_number, '和歌山県日高郡日高川町玄子');
ok($zip->set_number('6491316')->is_valid_number, '和歌山県日高郡日高川町蛇尾');
ok($zip->set_number('6491321')->is_valid_number, '和歌山県日高郡日高川町入野');
ok($zip->set_number('6491322')->is_valid_number, '和歌山県日高郡日高川町若野');
ok($zip->set_number('6491323')->is_valid_number, '和歌山県日高郡日高川町小熊');
ok($zip->set_number('6491324')->is_valid_number, '和歌山県日高郡日高川町土生');
ok($zip->set_number('6491325')->is_valid_number, '和歌山県日高郡日高川町中津川');
ok($zip->set_number('6491331')->is_valid_number, '和歌山県日高郡日高川町鐘巻');
ok($zip->set_number('6491332')->is_valid_number, '和歌山県日高郡日高川町千津川');
ok($zip->set_number('6491341')->is_valid_number, '和歌山県御坊市藤田町藤井');
ok($zip->set_number('6491342')->is_valid_number, '和歌山県御坊市藤田町吉田');
ok($zip->set_number('6491441')->is_valid_number, '和歌山県日高郡日高川町山野');
ok($zip->set_number('6491442')->is_valid_number, '和歌山県日高郡日高川町江川');
ok($zip->set_number('6491443')->is_valid_number, '和歌山県日高郡日高川町和佐');
ok($zip->set_number('6491444')->is_valid_number, '和歌山県日高郡日高川町松瀬');
ok($zip->set_number('6491500')->is_valid_number, '和歌山県日高郡印南町以下に掲載がない場合');
ok($zip->set_number('6491521')->is_valid_number, '和歌山県日高郡印南町美里');
ok($zip->set_number('6491522')->is_valid_number, '和歌山県日高郡印南町古井');
ok($zip->set_number('6491523')->is_valid_number, '和歌山県日高郡印南町樮川');
ok($zip->set_number('6491524')->is_valid_number, '和歌山県日高郡印南町羽六');
ok($zip->set_number('6491525')->is_valid_number, '和歌山県日高郡印南町古屋');
ok($zip->set_number('6491526')->is_valid_number, '和歌山県日高郡印南町宮ノ前');
ok($zip->set_number('6491527')->is_valid_number, '和歌山県日高郡印南町島田');
ok($zip->set_number('6491528')->is_valid_number, '和歌山県日高郡印南町西ノ地');
ok($zip->set_number('6491531')->is_valid_number, '和歌山県日高郡印南町立石');
ok($zip->set_number('6491532')->is_valid_number, '和歌山県日高郡印南町印南原');
ok($zip->set_number('6491533')->is_valid_number, '和歌山県日高郡印南町山口');
ok($zip->set_number('6491534')->is_valid_number, '和歌山県日高郡印南町印南');
ok($zip->set_number('6491535')->is_valid_number, '和歌山県日高郡印南町津井');
ok($zip->set_number('6491536')->is_valid_number, '和歌山県日高郡印南町南谷');
ok($zip->set_number('6491537')->is_valid_number, '和歌山県日高郡印南町明神川');
ok($zip->set_number('6492100')->is_valid_number, '和歌山県西牟婁郡上富田町以下に掲載がない場合');
ok($zip->set_number('6492101')->is_valid_number, '和歌山県西牟婁郡上富田町岡');
ok($zip->set_number('6492102')->is_valid_number, '和歌山県西牟婁郡上富田町岩田');
ok($zip->set_number('6492103')->is_valid_number, '和歌山県西牟婁郡上富田町生馬');
ok($zip->set_number('6492104')->is_valid_number, '和歌山県西牟婁郡上富田町岩崎');
ok($zip->set_number('6492105')->is_valid_number, '和歌山県西牟婁郡上富田町朝来');
ok($zip->set_number('6492106')->is_valid_number, '和歌山県西牟婁郡上富田町南紀の台');
ok($zip->set_number('6492107')->is_valid_number, '和歌山県西牟婁郡上富田町市ノ瀬');
ok($zip->set_number('6492108')->is_valid_number, '和歌山県西牟婁郡上富田町下鮎川');
ok($zip->set_number('6492200')->is_valid_number, '和歌山県西牟婁郡白浜町以下に掲載がない場合');
ok($zip->set_number('6492201')->is_valid_number, '和歌山県西牟婁郡白浜町堅田');
ok($zip->set_number('6492211')->is_valid_number, '和歌山県西牟婁郡白浜町白浜町の次に番地がくる場合');
ok($zip->set_number('6492321')->is_valid_number, '和歌山県西牟婁郡白浜町保呂');
ok($zip->set_number('6492322')->is_valid_number, '和歌山県西牟婁郡白浜町内ノ川');
ok($zip->set_number('6492323')->is_valid_number, '和歌山県西牟婁郡白浜町庄川');
ok($zip->set_number('6492324')->is_valid_number, '和歌山県西牟婁郡白浜町十九渕');
ok($zip->set_number('6492325')->is_valid_number, '和歌山県西牟婁郡白浜町富田');
ok($zip->set_number('6492326')->is_valid_number, '和歌山県西牟婁郡白浜町椿');
ok($zip->set_number('6492331')->is_valid_number, '和歌山県西牟婁郡白浜町平');
ok($zip->set_number('6492332')->is_valid_number, '和歌山県西牟婁郡白浜町栄');
ok($zip->set_number('6492333')->is_valid_number, '和歌山県西牟婁郡白浜町中');
ok($zip->set_number('6492334')->is_valid_number, '和歌山県西牟婁郡白浜町才野');
ok($zip->set_number('6492511')->is_valid_number, '和歌山県西牟婁郡白浜町日置');
ok($zip->set_number('6492521')->is_valid_number, '和歌山県西牟婁郡白浜町大古');
ok($zip->set_number('6492522')->is_valid_number, '和歌山県西牟婁郡白浜町矢田');
ok($zip->set_number('6492523')->is_valid_number, '和歌山県西牟婁郡白浜町田野井');
ok($zip->set_number('6492524')->is_valid_number, '和歌山県西牟婁郡白浜町安宅');
ok($zip->set_number('6492525')->is_valid_number, '和歌山県西牟婁郡白浜町塩野');
ok($zip->set_number('6492531')->is_valid_number, '和歌山県西牟婁郡白浜町口ケ谷');
ok($zip->set_number('6492532')->is_valid_number, '和歌山県西牟婁郡白浜町安居');
ok($zip->set_number('6492533')->is_valid_number, '和歌山県西牟婁郡白浜町中嶋');
ok($zip->set_number('6492534')->is_valid_number, '和歌山県西牟婁郡白浜町寺山');
ok($zip->set_number('6492535')->is_valid_number, '和歌山県西牟婁郡白浜町向平');
ok($zip->set_number('6492536')->is_valid_number, '和歌山県西牟婁郡白浜町久木');
ok($zip->set_number('6492537')->is_valid_number, '和歌山県西牟婁郡白浜町宇津木');
ok($zip->set_number('6492538')->is_valid_number, '和歌山県西牟婁郡白浜町小川');
ok($zip->set_number('6492539')->is_valid_number, '和歌山県西牟婁郡白浜町城');
ok($zip->set_number('6492600')->is_valid_number, '和歌山県西牟婁郡すさみ町以下に掲載がない場合');
ok($zip->set_number('6492601')->is_valid_number, '和歌山県西牟婁郡すさみ町小附');
ok($zip->set_number('6492602')->is_valid_number, '和歌山県西牟婁郡すさみ町大附');
ok($zip->set_number('6492603')->is_valid_number, '和歌山県西牟婁郡すさみ町小河内');
ok($zip->set_number('6492604')->is_valid_number, '和歌山県西牟婁郡すさみ町矢野口');
ok($zip->set_number('6492611')->is_valid_number, '和歌山県西牟婁郡すさみ町和深川');
ok($zip->set_number('6492612')->is_valid_number, '和歌山県西牟婁郡すさみ町口和深');
ok($zip->set_number('6492621')->is_valid_number, '和歌山県西牟婁郡すさみ町周参見');
ok($zip->set_number('6492631')->is_valid_number, '和歌山県西牟婁郡すさみ町太間川');
ok($zip->set_number('6493141')->is_valid_number, '和歌山県西牟婁郡すさみ町見老津');
ok($zip->set_number('6493142')->is_valid_number, '和歌山県西牟婁郡すさみ町江住');
ok($zip->set_number('6493143')->is_valid_number, '和歌山県西牟婁郡すさみ町里野');
ok($zip->set_number('6493151')->is_valid_number, '和歌山県西牟婁郡すさみ町大鎌');
ok($zip->set_number('6493152')->is_valid_number, '和歌山県西牟婁郡すさみ町防己');
ok($zip->set_number('6493153')->is_valid_number, '和歌山県西牟婁郡すさみ町大谷');
ok($zip->set_number('6493161')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本中');
ok($zip->set_number('6493162')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本追川');
ok($zip->set_number('6493163')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本西栗垣内');
ok($zip->set_number('6493164')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本東栗垣内');
ok($zip->set_number('6493165')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本中野');
ok($zip->set_number('6493166')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本西野川');
ok($zip->set_number('6493167')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本平野');
ok($zip->set_number('6493168')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本根倉');
ok($zip->set_number('6493169')->is_valid_number, '和歌山県西牟婁郡すさみ町佐本深谷');
ok($zip->set_number('6493500')->is_valid_number, '和歌山県東牟婁郡串本町以下に掲載がない場合');
ok($zip->set_number('6493501')->is_valid_number, '和歌山県東牟婁郡串本町出雲');
ok($zip->set_number('6493502')->is_valid_number, '和歌山県東牟婁郡串本町潮岬');
ok($zip->set_number('6493503')->is_valid_number, '和歌山県東牟婁郡串本町串本');
ok($zip->set_number('6493510')->is_valid_number, '和歌山県東牟婁郡串本町サンゴ台');
ok($zip->set_number('6493511')->is_valid_number, '和歌山県東牟婁郡串本町鬮野川');
ok($zip->set_number('6493512')->is_valid_number, '和歌山県東牟婁郡串本町二色');
ok($zip->set_number('6493513')->is_valid_number, '和歌山県東牟婁郡串本町高富');
ok($zip->set_number('6493514')->is_valid_number, '和歌山県東牟婁郡串本町有田');
ok($zip->set_number('6493515')->is_valid_number, '和歌山県東牟婁郡串本町田並');
ok($zip->set_number('6493516')->is_valid_number, '和歌山県東牟婁郡串本町田並上');
ok($zip->set_number('6493517')->is_valid_number, '和歌山県東牟婁郡串本町吐生');
ok($zip->set_number('6493518')->is_valid_number, '和歌山県東牟婁郡串本町有田上');
ok($zip->set_number('6493521')->is_valid_number, '和歌山県東牟婁郡串本町江田');
ok($zip->set_number('6493522')->is_valid_number, '和歌山県東牟婁郡串本町田子');
ok($zip->set_number('6493523')->is_valid_number, '和歌山県東牟婁郡串本町和深');
ok($zip->set_number('6493524')->is_valid_number, '和歌山県東牟婁郡串本町里川');
ok($zip->set_number('6493631')->is_valid_number, '和歌山県東牟婁郡串本町樫野');
ok($zip->set_number('6493632')->is_valid_number, '和歌山県東牟婁郡串本町須江');
ok($zip->set_number('6493633')->is_valid_number, '和歌山県東牟婁郡串本町大島');
ok($zip->set_number('6494100')->is_valid_number, '和歌山県東牟婁郡古座川町以下に掲載がない場合');
ok($zip->set_number('6494101')->is_valid_number, '和歌山県東牟婁郡古座川町樫山');
ok($zip->set_number('6494102')->is_valid_number, '和歌山県東牟婁郡古座川町楠');
ok($zip->set_number('6494103')->is_valid_number, '和歌山県東牟婁郡古座川町池野山');
ok($zip->set_number('6494104')->is_valid_number, '和歌山県東牟婁郡古座川町高池');
ok($zip->set_number('6494105')->is_valid_number, '和歌山県東牟婁郡古座川町宇津木');
ok($zip->set_number('6494106')->is_valid_number, '和歌山県東牟婁郡古座川町月野瀬');
ok($zip->set_number('6494111')->is_valid_number, '和歌山県東牟婁郡串本町上田原');
ok($zip->set_number('6494112')->is_valid_number, '和歌山県東牟婁郡串本町田原');
ok($zip->set_number('6494113')->is_valid_number, '和歌山県東牟婁郡串本町津荷');
ok($zip->set_number('6494114')->is_valid_number, '和歌山県東牟婁郡串本町上野山');
ok($zip->set_number('6494115')->is_valid_number, '和歌山県東牟婁郡串本町古座');
ok($zip->set_number('6494116')->is_valid_number, '和歌山県東牟婁郡串本町中湊');
ok($zip->set_number('6494117')->is_valid_number, '和歌山県東牟婁郡串本町佐部');
ok($zip->set_number('6494121')->is_valid_number, '和歌山県東牟婁郡串本町古田');
ok($zip->set_number('6494122')->is_valid_number, '和歌山県東牟婁郡串本町西向');
ok($zip->set_number('6494123')->is_valid_number, '和歌山県東牟婁郡串本町神野川');
ok($zip->set_number('6494124')->is_valid_number, '和歌山県東牟婁郡串本町伊串');
ok($zip->set_number('6494125')->is_valid_number, '和歌山県東牟婁郡串本町姫');
ok($zip->set_number('6494126')->is_valid_number, '和歌山県東牟婁郡串本町姫川');
ok($zip->set_number('6494211')->is_valid_number, '和歌山県東牟婁郡古座川町小森川');
ok($zip->set_number('6494212')->is_valid_number, '和歌山県東牟婁郡古座川町田川');
ok($zip->set_number('6494213')->is_valid_number, '和歌山県東牟婁郡古座川町西赤木');
ok($zip->set_number('6494214')->is_valid_number, '和歌山県東牟婁郡古座川町宇筒井');
ok($zip->set_number('6494215')->is_valid_number, '和歌山県東牟婁郡古座川町大桑');
ok($zip->set_number('6494216')->is_valid_number, '和歌山県東牟婁郡古座川町小川');
ok($zip->set_number('6494217')->is_valid_number, '和歌山県東牟婁郡古座川町山手');
ok($zip->set_number('6494221')->is_valid_number, '和歌山県東牟婁郡古座川町中崎');
ok($zip->set_number('6494222')->is_valid_number, '和歌山県東牟婁郡古座川町直見');
ok($zip->set_number('6494223')->is_valid_number, '和歌山県東牟婁郡古座川町川口');
ok($zip->set_number('6494224')->is_valid_number, '和歌山県東牟婁郡古座川町高瀬');
ok($zip->set_number('6494225')->is_valid_number, '和歌山県東牟婁郡古座川町潤野');
ok($zip->set_number('6494226')->is_valid_number, '和歌山県東牟婁郡古座川町明神');
ok($zip->set_number('6494227')->is_valid_number, '和歌山県東牟婁郡古座川町大柳');
ok($zip->set_number('6494231')->is_valid_number, '和歌山県東牟婁郡古座川町鶴川');
ok($zip->set_number('6494232')->is_valid_number, '和歌山県東牟婁郡古座川町一雨');
ok($zip->set_number('6494233')->is_valid_number, '和歌山県東牟婁郡古座川町立合');
ok($zip->set_number('6494234')->is_valid_number, '和歌山県東牟婁郡古座川町峰');
ok($zip->set_number('6494235')->is_valid_number, '和歌山県東牟婁郡古座川町相瀬');
ok($zip->set_number('6494236')->is_valid_number, '和歌山県東牟婁郡古座川町立合川');
ok($zip->set_number('6494441')->is_valid_number, '和歌山県東牟婁郡古座川町添野川');
ok($zip->set_number('6494442')->is_valid_number, '和歌山県東牟婁郡古座川町佐田');
ok($zip->set_number('6494443')->is_valid_number, '和歌山県東牟婁郡古座川町真砂');
ok($zip->set_number('6494444')->is_valid_number, '和歌山県東牟婁郡古座川町長追');
ok($zip->set_number('6494451')->is_valid_number, '和歌山県東牟婁郡古座川町大川');
ok($zip->set_number('6494452')->is_valid_number, '和歌山県東牟婁郡古座川町蔵土');
ok($zip->set_number('6494453')->is_valid_number, '和歌山県東牟婁郡古座川町洞尾');
ok($zip->set_number('6494454')->is_valid_number, '和歌山県東牟婁郡古座川町南平');
ok($zip->set_number('6494455')->is_valid_number, '和歌山県東牟婁郡古座川町三尾川');
ok($zip->set_number('6494561')->is_valid_number, '和歌山県東牟婁郡古座川町西川');
ok($zip->set_number('6494562')->is_valid_number, '和歌山県東牟婁郡古座川町下露');
ok($zip->set_number('6494563')->is_valid_number, '和歌山県東牟婁郡古座川町平井');
ok($zip->set_number('6494564')->is_valid_number, '和歌山県東牟婁郡古座川町松根');
ok($zip->set_number('6494565')->is_valid_number, '和歌山県東牟婁郡古座川町成川');
ok($zip->set_number('6495100')->is_valid_number, '和歌山県東牟婁郡太地町以下に掲載がない場合');
ok($zip->set_number('6495131')->is_valid_number, '和歌山県東牟婁郡那智勝浦町西中野川');
ok($zip->set_number('6495132')->is_valid_number, '和歌山県東牟婁郡那智勝浦町中ノ川');
ok($zip->set_number('6495133')->is_valid_number, '和歌山県東牟婁郡那智勝浦町井鹿');
ok($zip->set_number('6495134')->is_valid_number, '和歌山県東牟婁郡那智勝浦町南大居');
ok($zip->set_number('6495135')->is_valid_number, '和歌山県東牟婁郡那智勝浦町高遠井');
ok($zip->set_number('6495136')->is_valid_number, '和歌山県東牟婁郡那智勝浦町長井');
ok($zip->set_number('6495137')->is_valid_number, '和歌山県東牟婁郡那智勝浦町小匠');
ok($zip->set_number('6495141')->is_valid_number, '和歌山県東牟婁郡那智勝浦町市屋(その他)');
ok($zip->set_number('6495142')->is_valid_number, '和歌山県東牟婁郡那智勝浦町下里');
ok($zip->set_number('6495143')->is_valid_number, '和歌山県東牟婁郡那智勝浦町八尺鏡野');
ok($zip->set_number('6495144')->is_valid_number, '和歌山県東牟婁郡那智勝浦町粉白');
ok($zip->set_number('6495145')->is_valid_number, '和歌山県東牟婁郡那智勝浦町浦神');
ok($zip->set_number('6495146')->is_valid_number, '和歌山県東牟婁郡那智勝浦町中里');
ok($zip->set_number('6495147')->is_valid_number, '和歌山県東牟婁郡那智勝浦町庄');
ok($zip->set_number('6495148')->is_valid_number, '和歌山県東牟婁郡那智勝浦町下和田');
ok($zip->set_number('6495171')->is_valid_number, '和歌山県東牟婁郡太地町太地(その他)');
ok($zip->set_number('6495172')->is_valid_number, '和歌山県東牟婁郡太地町森浦');
ok($zip->set_number('6495300')->is_valid_number, '和歌山県東牟婁郡那智勝浦町以下に掲載がない場合');
ok($zip->set_number('6495301')->is_valid_number, '和歌山県東牟婁郡那智勝浦町那智山');
ok($zip->set_number('6495302')->is_valid_number, '和歌山県東牟婁郡那智勝浦町市野々');
ok($zip->set_number('6495303')->is_valid_number, '和歌山県東牟婁郡那智勝浦町井関');
ok($zip->set_number('6495304')->is_valid_number, '和歌山県東牟婁郡那智勝浦町川関');
ok($zip->set_number('6495311')->is_valid_number, '和歌山県東牟婁郡那智勝浦町高津気');
ok($zip->set_number('6495312')->is_valid_number, '和歌山県東牟婁郡那智勝浦町宇久井');
ok($zip->set_number('6495313')->is_valid_number, '和歌山県東牟婁郡那智勝浦町狗子ノ川');
ok($zip->set_number('6495314')->is_valid_number, '和歌山県東牟婁郡那智勝浦町浜ノ宮');
ok($zip->set_number('6495331')->is_valid_number, '和歌山県東牟婁郡那智勝浦町天満');
ok($zip->set_number('6495332')->is_valid_number, '和歌山県東牟婁郡那智勝浦町朝日');
ok($zip->set_number('6495333')->is_valid_number, '和歌山県東牟婁郡那智勝浦町北浜');
ok($zip->set_number('6495334')->is_valid_number, '和歌山県東牟婁郡那智勝浦町勝浦');
ok($zip->set_number('6495335')->is_valid_number, '和歌山県東牟婁郡那智勝浦町築地');
ok($zip->set_number('6495336')->is_valid_number, '和歌山県東牟婁郡那智勝浦町湯川');
ok($zip->set_number('6495337')->is_valid_number, '和歌山県東牟婁郡那智勝浦町橋ノ川');
ok($zip->set_number('6495338')->is_valid_number, '和歌山県東牟婁郡那智勝浦町二河');
ok($zip->set_number('6495339')->is_valid_number, '和歌山県東牟婁郡那智勝浦町市屋(大浦、1054-9)');
ok($zip->set_number('6495371')->is_valid_number, '和歌山県東牟婁郡太地町太地(3772~3904番地)');
ok($zip->set_number('6495451')->is_valid_number, '和歌山県東牟婁郡那智勝浦町口色川');
ok($zip->set_number('6495452')->is_valid_number, '和歌山県東牟婁郡那智勝浦町小阪');
ok($zip->set_number('6495453')->is_valid_number, '和歌山県東牟婁郡那智勝浦町南平野');
ok($zip->set_number('6495454')->is_valid_number, '和歌山県東牟婁郡那智勝浦町熊瀬川');
ok($zip->set_number('6495461')->is_valid_number, '和歌山県東牟婁郡那智勝浦町大野');
ok($zip->set_number('6495462')->is_valid_number, '和歌山県東牟婁郡那智勝浦町田垣内');
ok($zip->set_number('6495463')->is_valid_number, '和歌山県東牟婁郡那智勝浦町高野');
ok($zip->set_number('6495464')->is_valid_number, '和歌山県東牟婁郡那智勝浦町直柱');
ok($zip->set_number('6495465')->is_valid_number, '和歌山県東牟婁郡那智勝浦町坂足');
ok($zip->set_number('6495466')->is_valid_number, '和歌山県東牟婁郡那智勝浦町樫原');
ok($zip->set_number('6496101')->is_valid_number, '和歌山県紀の川市桃山町善田');
ok($zip->set_number('6496102')->is_valid_number, '和歌山県紀の川市桃山町黒川');
ok($zip->set_number('6496103')->is_valid_number, '和歌山県紀の川市桃山町野田原');
ok($zip->set_number('6496104')->is_valid_number, '和歌山県紀の川市桃山町脇谷');
ok($zip->set_number('6496105')->is_valid_number, '和歌山県紀の川市桃山町大原');
ok($zip->set_number('6496111')->is_valid_number, '和歌山県紀の川市桃山町最上');
ok($zip->set_number('6496112')->is_valid_number, '和歌山県紀の川市桃山町調月');
ok($zip->set_number('6496121')->is_valid_number, '和歌山県紀の川市桃山町段新田');
ok($zip->set_number('6496122')->is_valid_number, '和歌山県紀の川市桃山町元');
ok($zip->set_number('6496123')->is_valid_number, '和歌山県紀の川市桃山町神田');
ok($zip->set_number('6496124')->is_valid_number, '和歌山県紀の川市桃山町市場');
ok($zip->set_number('6496125')->is_valid_number, '和歌山県紀の川市桃山町段');
ok($zip->set_number('6496161')->is_valid_number, '和歌山県紀の川市高野');
ok($zip->set_number('6496162')->is_valid_number, '和歌山県紀の川市竹房(451番地以上)');
ok($zip->set_number('6496200')->is_valid_number, '和歌山県岩出市以下に掲載がない場合');
ok($zip->set_number('6496201')->is_valid_number, '和歌山県岩出市押川');
ok($zip->set_number('6496202')->is_valid_number, '和歌山県岩出市根来');
ok($zip->set_number('6496203')->is_valid_number, '和歌山県岩出市桜台');
ok($zip->set_number('6496204')->is_valid_number, '和歌山県岩出市今中');
ok($zip->set_number('6496205')->is_valid_number, '和歌山県岩出市森');
ok($zip->set_number('6496206')->is_valid_number, '和歌山県岩出市堀口');
ok($zip->set_number('6496207')->is_valid_number, '和歌山県岩出市尼ケ辻');
ok($zip->set_number('6496208')->is_valid_number, '和歌山県岩出市今畑');
ok($zip->set_number('6496211')->is_valid_number, '和歌山県岩出市東坂本');
ok($zip->set_number('6496212')->is_valid_number, '和歌山県岩出市新田広芝');
ok($zip->set_number('6496213')->is_valid_number, '和歌山県岩出市西国分');
ok($zip->set_number('6496214')->is_valid_number, '和歌山県岩出市水栖');
ok($zip->set_number('6496215')->is_valid_number, '和歌山県岩出市中迫');
ok($zip->set_number('6496216')->is_valid_number, '和歌山県岩出市野上野');
ok($zip->set_number('6496217')->is_valid_number, '和歌山県岩出市山田');
ok($zip->set_number('6496218')->is_valid_number, '和歌山県岩出市南大池');
ok($zip->set_number('6496219')->is_valid_number, '和歌山県岩出市北大池');
ok($zip->set_number('6496221')->is_valid_number, '和歌山県岩出市溝川');
ok($zip->set_number('6496222')->is_valid_number, '和歌山県岩出市岡田');
ok($zip->set_number('6496223')->is_valid_number, '和歌山県岩出市高塚');
ok($zip->set_number('6496224')->is_valid_number, '和歌山県岩出市山崎');
ok($zip->set_number('6496225')->is_valid_number, '和歌山県岩出市船戸');
ok($zip->set_number('6496226')->is_valid_number, '和歌山県岩出市宮');
ok($zip->set_number('6496227')->is_valid_number, '和歌山県岩出市清水');
ok($zip->set_number('6496228')->is_valid_number, '和歌山県岩出市大町');
ok($zip->set_number('6496231')->is_valid_number, '和歌山県岩出市川尻');
ok($zip->set_number('6496232')->is_valid_number, '和歌山県岩出市荊本');
ok($zip->set_number('6496233')->is_valid_number, '和歌山県岩出市備前');
ok($zip->set_number('6496234')->is_valid_number, '和歌山県岩出市高瀬');
ok($zip->set_number('6496235')->is_valid_number, '和歌山県岩出市西野');
ok($zip->set_number('6496236')->is_valid_number, '和歌山県岩出市曽屋');
ok($zip->set_number('6496241')->is_valid_number, '和歌山県岩出市波分');
ok($zip->set_number('6496242')->is_valid_number, '和歌山県岩出市赤垣内');
ok($zip->set_number('6496243')->is_valid_number, '和歌山県岩出市金屋');
ok($zip->set_number('6496244')->is_valid_number, '和歌山県岩出市畑毛');
ok($zip->set_number('6496245')->is_valid_number, '和歌山県岩出市中島');
ok($zip->set_number('6496246')->is_valid_number, '和歌山県岩出市吉田');
ok($zip->set_number('6496248')->is_valid_number, '和歌山県岩出市中黒');
ok($zip->set_number('6496248')->is_valid_number, '和歌山県岩出市湯窪');
ok($zip->set_number('6496251')->is_valid_number, '和歌山県岩出市境谷');
ok($zip->set_number('6496252')->is_valid_number, '和歌山県岩出市安上');
ok($zip->set_number('6496253')->is_valid_number, '和歌山県岩出市紀泉台');
ok($zip->set_number('6496254')->is_valid_number, '和歌山県岩出市原');
ok($zip->set_number('6496255')->is_valid_number, '和歌山県岩出市西安上');
ok($zip->set_number('6496256')->is_valid_number, '和歌山県岩出市金池');
ok($zip->set_number('6496257')->is_valid_number, '和歌山県岩出市相谷');
ok($zip->set_number('6496258')->is_valid_number, '和歌山県岩出市山');
ok($zip->set_number('6496261')->is_valid_number, '和歌山県和歌山市小倉');
ok($zip->set_number('6496262')->is_valid_number, '和歌山県和歌山市上三毛');
ok($zip->set_number('6496263')->is_valid_number, '和歌山県和歌山市下三毛');
ok($zip->set_number('6496264')->is_valid_number, '和歌山県和歌山市新庄');
ok($zip->set_number('6496271')->is_valid_number, '和歌山県和歌山市満屋');
ok($zip->set_number('6496272')->is_valid_number, '和歌山県和歌山市大垣内');
ok($zip->set_number('6496273')->is_valid_number, '和歌山県和歌山市東田中');
ok($zip->set_number('6496274')->is_valid_number, '和歌山県和歌山市金谷');
ok($zip->set_number('6496275')->is_valid_number, '和歌山県和歌山市吐前');
ok($zip->set_number('6496301')->is_valid_number, '和歌山県和歌山市滝畑');
ok($zip->set_number('6496302')->is_valid_number, '和歌山県和歌山市湯屋谷');
ok($zip->set_number('6496303')->is_valid_number, '和歌山県和歌山市平岡');
ok($zip->set_number('6496304')->is_valid_number, '和歌山県和歌山市中筋日延');
ok($zip->set_number('6496305')->is_valid_number, '和歌山県和歌山市谷');
ok($zip->set_number('6496306')->is_valid_number, '和歌山県和歌山市上黒谷');
ok($zip->set_number('6496307')->is_valid_number, '和歌山県和歌山市北別所');
ok($zip->set_number('6496308')->is_valid_number, '和歌山県和歌山市落合');
ok($zip->set_number('6496311')->is_valid_number, '和歌山県和歌山市里');
ok($zip->set_number('6496312')->is_valid_number, '和歌山県和歌山市川辺');
ok($zip->set_number('6496313')->is_valid_number, '和歌山県和歌山市楠本');
ok($zip->set_number('6496314')->is_valid_number, '和歌山県和歌山市島');
ok($zip->set_number('6496315')->is_valid_number, '和歌山県和歌山市神波');
ok($zip->set_number('6496316')->is_valid_number, '和歌山県和歌山市上野');
ok($zip->set_number('6496317')->is_valid_number, '和歌山県和歌山市山口西');
ok($zip->set_number('6496318')->is_valid_number, '和歌山県和歌山市藤田');
ok($zip->set_number('6496321')->is_valid_number, '和歌山県和歌山市布施屋');
ok($zip->set_number('6496322')->is_valid_number, '和歌山県和歌山市和佐関戸');
ok($zip->set_number('6496323')->is_valid_number, '和歌山県和歌山市井ノ口');
ok($zip->set_number('6496324')->is_valid_number, '和歌山県和歌山市祢宜');
ok($zip->set_number('6496325')->is_valid_number, '和歌山県和歌山市下和佐');
ok($zip->set_number('6496326')->is_valid_number, '和歌山県和歌山市和佐中');
ok($zip->set_number('6496331')->is_valid_number, '和歌山県和歌山市北野');
ok($zip->set_number('6496332')->is_valid_number, '和歌山県和歌山市宇田森');
ok($zip->set_number('6496333')->is_valid_number, '和歌山県和歌山市永穂');
ok($zip->set_number('6496334')->is_valid_number, '和歌山県和歌山市北');
ok($zip->set_number('6496335')->is_valid_number, '和歌山県和歌山市西田井');
ok($zip->set_number('6496336')->is_valid_number, '和歌山県和歌山市小豆島');
ok($zip->set_number('6496337')->is_valid_number, '和歌山県和歌山市田屋');
ok($zip->set_number('6496338')->is_valid_number, '和歌山県和歌山市府中');
ok($zip->set_number('6496339')->is_valid_number, '和歌山県和歌山市弘西');
ok($zip->set_number('6496400')->is_valid_number, '和歌山県紀の川市以下に掲載がない場合');
ok($zip->set_number('6496401')->is_valid_number, '和歌山県紀の川市重行');
ok($zip->set_number('6496402')->is_valid_number, '和歌山県紀の川市北勢田');
ok($zip->set_number('6496403')->is_valid_number, '和歌山県紀の川市南勢田');
ok($zip->set_number('6496404')->is_valid_number, '和歌山県紀の川市赤尾');
ok($zip->set_number('6496405')->is_valid_number, '和歌山県紀の川市東大井');
ok($zip->set_number('6496406')->is_valid_number, '和歌山県紀の川市北大井');
ok($zip->set_number('6496407')->is_valid_number, '和歌山県紀の川市池田新');
ok($zip->set_number('6496411')->is_valid_number, '和歌山県紀の川市広野');
ok($zip->set_number('6496412')->is_valid_number, '和歌山県紀の川市黒土');
ok($zip->set_number('6496413')->is_valid_number, '和歌山県紀の川市竹房(450番地以下)');
ok($zip->set_number('6496414')->is_valid_number, '和歌山県紀の川市打田');
ok($zip->set_number('6496415')->is_valid_number, '和歌山県紀の川市窪');
ok($zip->set_number('6496416')->is_valid_number, '和歌山県紀の川市上野');
ok($zip->set_number('6496417')->is_valid_number, '和歌山県紀の川市西大井');
ok($zip->set_number('6496418')->is_valid_number, '和歌山県紀の川市久留壁');
ok($zip->set_number('6496421')->is_valid_number, '和歌山県紀の川市田中馬場');
ok($zip->set_number('6496422')->is_valid_number, '和歌山県紀の川市花野');
ok($zip->set_number('6496423')->is_valid_number, '和歌山県紀の川市尾崎');
ok($zip->set_number('6496424')->is_valid_number, '和歌山県紀の川市畑野上');
ok($zip->set_number('6496425')->is_valid_number, '和歌山県紀の川市中井阪');
ok($zip->set_number('6496426')->is_valid_number, '和歌山県紀の川市下井阪');
ok($zip->set_number('6496427')->is_valid_number, '和歌山県紀の川市西井阪');
ok($zip->set_number('6496428')->is_valid_number, '和歌山県紀の川市東国分');
ok($zip->set_number('6496431')->is_valid_number, '和歌山県紀の川市南中');
ok($zip->set_number('6496432')->is_valid_number, '和歌山県紀の川市古和田');
ok($zip->set_number('6496433')->is_valid_number, '和歌山県紀の川市西三谷');
ok($zip->set_number('6496434')->is_valid_number, '和歌山県紀の川市中三谷');
ok($zip->set_number('6496435')->is_valid_number, '和歌山県紀の川市東三谷');
ok($zip->set_number('6496441')->is_valid_number, '和歌山県紀の川市東山田');
ok($zip->set_number('6496442')->is_valid_number, '和歌山県紀の川市神領');
ok($zip->set_number('6496443')->is_valid_number, '和歌山県紀の川市北中');
ok($zip->set_number('6496444')->is_valid_number, '和歌山県紀の川市登尾');
ok($zip->set_number('6496445')->is_valid_number, '和歌山県紀の川市豊田');
ok($zip->set_number('6496446')->is_valid_number, '和歌山県紀の川市枇杷谷');
ok($zip->set_number('6496447')->is_valid_number, '和歌山県紀の川市西山田');
ok($zip->set_number('6496451')->is_valid_number, '和歌山県紀の川市神通');
ok($zip->set_number('6496452')->is_valid_number, '和歌山県紀の川市中畑');
ok($zip->set_number('6496501')->is_valid_number, '和歌山県紀の川市北志野');
ok($zip->set_number('6496502')->is_valid_number, '和歌山県紀の川市北長田');
ok($zip->set_number('6496503')->is_valid_number, '和歌山県紀の川市長田中');
ok($zip->set_number('6496504')->is_valid_number, '和歌山県紀の川市南志野');
ok($zip->set_number('6496511')->is_valid_number, '和歌山県紀の川市猪垣');
ok($zip->set_number('6496512')->is_valid_number, '和歌山県紀の川市東毛');
ok($zip->set_number('6496513')->is_valid_number, '和歌山県紀の川市中津川');
ok($zip->set_number('6496514')->is_valid_number, '和歌山県紀の川市藤井');
ok($zip->set_number('6496521')->is_valid_number, '和歌山県紀の川市馬宿');
ok($zip->set_number('6496522')->is_valid_number, '和歌山県紀の川市上丹生谷');
ok($zip->set_number('6496523')->is_valid_number, '和歌山県紀の川市下丹生谷');
ok($zip->set_number('6496524')->is_valid_number, '和歌山県紀の川市西川原');
ok($zip->set_number('6496525')->is_valid_number, '和歌山県紀の川市野上');
ok($zip->set_number('6496526')->is_valid_number, '和歌山県紀の川市東川原');
ok($zip->set_number('6496531')->is_valid_number, '和歌山県紀の川市粉河');
ok($zip->set_number('6496532')->is_valid_number, '和歌山県紀の川市中山');
ok($zip->set_number('6496541')->is_valid_number, '和歌山県紀の川市井田');
ok($zip->set_number('6496542')->is_valid_number, '和歌山県紀の川市東野');
ok($zip->set_number('6496551')->is_valid_number, '和歌山県紀の川市上田井');
ok($zip->set_number('6496552')->is_valid_number, '和歌山県紀の川市嶋');
ok($zip->set_number('6496553')->is_valid_number, '和歌山県紀の川市深田');
ok($zip->set_number('6496554')->is_valid_number, '和歌山県紀の川市別所');
ok($zip->set_number('6496555')->is_valid_number, '和歌山県紀の川市松井');
ok($zip->set_number('6496561')->is_valid_number, '和歌山県紀の川市荒見');
ok($zip->set_number('6496562')->is_valid_number, '和歌山県紀の川市遠方');
ok($zip->set_number('6496563')->is_valid_number, '和歌山県紀の川市風市');
ok($zip->set_number('6496564')->is_valid_number, '和歌山県紀の川市勝神');
ok($zip->set_number('6496565')->is_valid_number, '和歌山県紀の川市杉原');
ok($zip->set_number('6496571')->is_valid_number, '和歌山県紀の川市上鞆渕');
ok($zip->set_number('6496572')->is_valid_number, '和歌山県紀の川市下鞆渕');
ok($zip->set_number('6496573')->is_valid_number, '和歌山県紀の川市中鞆渕');
ok($zip->set_number('6496601')->is_valid_number, '和歌山県紀の川市名手上');
ok($zip->set_number('6496602')->is_valid_number, '和歌山県紀の川市平野');
ok($zip->set_number('6496603')->is_valid_number, '和歌山県紀の川市名手下');
ok($zip->set_number('6496604')->is_valid_number, '和歌山県紀の川市西野山');
ok($zip->set_number('6496605')->is_valid_number, '和歌山県紀の川市江川中');
ok($zip->set_number('6496606')->is_valid_number, '和歌山県紀の川市切畑');
ok($zip->set_number('6496611')->is_valid_number, '和歌山県紀の川市穴伏');
ok($zip->set_number('6496612')->is_valid_number, '和歌山県紀の川市北涌');
ok($zip->set_number('6496613')->is_valid_number, '和歌山県紀の川市横谷');
ok($zip->set_number('6496614')->is_valid_number, '和歌山県紀の川市赤沼田');
ok($zip->set_number('6496615')->is_valid_number, '和歌山県紀の川市麻生津中');
ok($zip->set_number('6496616')->is_valid_number, '和歌山県紀の川市西脇');
ok($zip->set_number('6496621')->is_valid_number, '和歌山県紀の川市名手西野');
ok($zip->set_number('6496622')->is_valid_number, '和歌山県紀の川市後田');
ok($zip->set_number('6496623')->is_valid_number, '和歌山県紀の川市藤崎');
ok($zip->set_number('6496624')->is_valid_number, '和歌山県紀の川市王子');
ok($zip->set_number('6496631')->is_valid_number, '和歌山県紀の川市名手市場');
ok($zip->set_number('6497100')->is_valid_number, '和歌山県伊都郡かつらぎ町以下に掲載がない場合');
ok($zip->set_number('6497101')->is_valid_number, '和歌山県伊都郡かつらぎ町東谷');
ok($zip->set_number('6497102')->is_valid_number, '和歌山県伊都郡かつらぎ町滝');
ok($zip->set_number('6497103')->is_valid_number, '和歌山県伊都郡かつらぎ町広口');
ok($zip->set_number('6497104')->is_valid_number, '和歌山県伊都郡かつらぎ町平');
ok($zip->set_number('6497111')->is_valid_number, '和歌山県伊都郡かつらぎ町大畑');
ok($zip->set_number('6497112')->is_valid_number, '和歌山県伊都郡かつらぎ町中飯降');
ok($zip->set_number('6497113')->is_valid_number, '和歌山県伊都郡かつらぎ町妙寺');
ok($zip->set_number('6497114')->is_valid_number, '和歌山県伊都郡かつらぎ町西飯降');
ok($zip->set_number('6497115')->is_valid_number, '和歌山県伊都郡かつらぎ町短野');
ok($zip->set_number('6497121')->is_valid_number, '和歌山県伊都郡かつらぎ町丁ノ町');
ok($zip->set_number('6497122')->is_valid_number, '和歌山県伊都郡かつらぎ町新田');
ok($zip->set_number('6497123')->is_valid_number, '和歌山県伊都郡かつらぎ町柏木');
ok($zip->set_number('6497131')->is_valid_number, '和歌山県伊都郡かつらぎ町山崎');
ok($zip->set_number('6497132')->is_valid_number, '和歌山県伊都郡かつらぎ町教良寺');
ok($zip->set_number('6497133')->is_valid_number, '和歌山県伊都郡かつらぎ町三谷');
ok($zip->set_number('6497134')->is_valid_number, '和歌山県伊都郡かつらぎ町宮本');
ok($zip->set_number('6497135')->is_valid_number, '和歌山県伊都郡かつらぎ町平沼田');
ok($zip->set_number('6497136')->is_valid_number, '和歌山県伊都郡かつらぎ町寺尾');
ok($zip->set_number('6497137')->is_valid_number, '和歌山県伊都郡かつらぎ町兄井');
ok($zip->set_number('6497141')->is_valid_number, '和歌山県伊都郡かつらぎ町上天野');
ok($zip->set_number('6497142')->is_valid_number, '和歌山県伊都郡かつらぎ町下天野');
ok($zip->set_number('6497143')->is_valid_number, '和歌山県伊都郡かつらぎ町神田');
ok($zip->set_number('6497144')->is_valid_number, '和歌山県伊都郡かつらぎ町志賀');
ok($zip->set_number('6497145')->is_valid_number, '和歌山県伊都郡かつらぎ町日高');
ok($zip->set_number('6497146')->is_valid_number, '和歌山県伊都郡かつらぎ町星山');
ok($zip->set_number('6497151')->is_valid_number, '和歌山県伊都郡かつらぎ町東渋田');
ok($zip->set_number('6497152')->is_valid_number, '和歌山県伊都郡かつらぎ町星川');
ok($zip->set_number('6497153')->is_valid_number, '和歌山県伊都郡かつらぎ町御所');
ok($zip->set_number('6497154')->is_valid_number, '和歌山県伊都郡かつらぎ町西渋田');
ok($zip->set_number('6497155')->is_valid_number, '和歌山県伊都郡かつらぎ町島');
ok($zip->set_number('6497161')->is_valid_number, '和歌山県伊都郡かつらぎ町笠田東');
ok($zip->set_number('6497162')->is_valid_number, '和歌山県伊都郡かつらぎ町笠田中');
ok($zip->set_number('6497163')->is_valid_number, '和歌山県伊都郡かつらぎ町萩原');
ok($zip->set_number('6497164')->is_valid_number, '和歌山県伊都郡かつらぎ町窪');
ok($zip->set_number('6497165')->is_valid_number, '和歌山県伊都郡かつらぎ町背ノ山');
ok($zip->set_number('6497166')->is_valid_number, '和歌山県伊都郡かつらぎ町高田');
ok($zip->set_number('6497167')->is_valid_number, '和歌山県伊都郡かつらぎ町移');
ok($zip->set_number('6497171')->is_valid_number, '和歌山県伊都郡かつらぎ町大薮');
ok($zip->set_number('6497172')->is_valid_number, '和歌山県伊都郡かつらぎ町蛭子');
ok($zip->set_number('6497173')->is_valid_number, '和歌山県伊都郡かつらぎ町大谷');
ok($zip->set_number('6497174')->is_valid_number, '和歌山県伊都郡かつらぎ町佐野');
ok($zip->set_number('6497175')->is_valid_number, '和歌山県伊都郡かつらぎ町広浦');
ok($zip->set_number('6497201')->is_valid_number, '和歌山県橋本市高野口町応其');
ok($zip->set_number('6497202')->is_valid_number, '和歌山県橋本市高野口町伏原');
ok($zip->set_number('6497203')->is_valid_number, '和歌山県橋本市高野口町名古曽');
ok($zip->set_number('6497204')->is_valid_number, '和歌山県橋本市高野口町小田');
ok($zip->set_number('6497205')->is_valid_number, '和歌山県橋本市高野口町名倉');
ok($zip->set_number('6497206')->is_valid_number, '和歌山県橋本市高野口町向島');
ok($zip->set_number('6497207')->is_valid_number, '和歌山県橋本市高野口町大野');
ok($zip->set_number('6497211')->is_valid_number, '和歌山県橋本市高野口町下中');
ok($zip->set_number('6497212')->is_valid_number, '和歌山県橋本市高野口町上中');
ok($zip->set_number('6497213')->is_valid_number, '和歌山県橋本市高野口町嵯峨谷');
ok($zip->set_number('6497214')->is_valid_number, '和歌山県橋本市高野口町竹尾');
ok($zip->set_number('6497215')->is_valid_number, '和歌山県橋本市高野口町九重');
ok($zip->set_number('6497216')->is_valid_number, '和歌山県橋本市高野口町田原');
ok($zip->set_number('6500000')->is_valid_number, '兵庫県神戸市中央区以下に掲載がない場合');
ok($zip->set_number('6500000')->is_valid_number, '兵庫県神戸市西区以下に掲載がない場合');
ok($zip->set_number('6500001')->is_valid_number, '兵庫県神戸市中央区加納町');
ok($zip->set_number('6500002')->is_valid_number, '兵庫県神戸市中央区北野町');
ok($zip->set_number('6500003')->is_valid_number, '兵庫県神戸市中央区山本通');
ok($zip->set_number('6500004')->is_valid_number, '兵庫県神戸市中央区中山手通');
ok($zip->set_number('6500005')->is_valid_number, '兵庫県神戸市中央区再度筋町');
ok($zip->set_number('6500006')->is_valid_number, '兵庫県神戸市中央区諏訪山町');
ok($zip->set_number('6500007')->is_valid_number, '兵庫県神戸市中央区神戸港地方');
ok($zip->set_number('6500011')->is_valid_number, '兵庫県神戸市中央区下山手通');
ok($zip->set_number('6500012')->is_valid_number, '兵庫県神戸市中央区北長狭通');
ok($zip->set_number('6500013')->is_valid_number, '兵庫県神戸市中央区花隈町');
ok($zip->set_number('6500014')->is_valid_number, '兵庫県神戸市中央区元町高架通');
ok($zip->set_number('6500015')->is_valid_number, '兵庫県神戸市中央区多聞通');
ok($zip->set_number('6500016')->is_valid_number, '兵庫県神戸市中央区橘通');
ok($zip->set_number('6500017')->is_valid_number, '兵庫県神戸市中央区楠町');
ok($zip->set_number('6500021')->is_valid_number, '兵庫県神戸市中央区三宮町');
ok($zip->set_number('6500022')->is_valid_number, '兵庫県神戸市中央区元町通');
ok($zip->set_number('6500023')->is_valid_number, '兵庫県神戸市中央区栄町通');
ok($zip->set_number('6500024')->is_valid_number, '兵庫県神戸市中央区海岸通');
ok($zip->set_number('6500025')->is_valid_number, '兵庫県神戸市中央区相生町');
ok($zip->set_number('6500026')->is_valid_number, '兵庫県神戸市中央区古湊通');
ok($zip->set_number('6500027')->is_valid_number, '兵庫県神戸市中央区中町通');
ok($zip->set_number('6500031')->is_valid_number, '兵庫県神戸市中央区東町');
ok($zip->set_number('6500032')->is_valid_number, '兵庫県神戸市中央区伊藤町');
ok($zip->set_number('6500033')->is_valid_number, '兵庫県神戸市中央区江戸町');
ok($zip->set_number('6500034')->is_valid_number, '兵庫県神戸市中央区京町');
ok($zip->set_number('6500035')->is_valid_number, '兵庫県神戸市中央区浪花町');
ok($zip->set_number('6500036')->is_valid_number, '兵庫県神戸市中央区播磨町');
ok($zip->set_number('6500037')->is_valid_number, '兵庫県神戸市中央区明石町');
ok($zip->set_number('6500038')->is_valid_number, '兵庫県神戸市中央区西町');
ok($zip->set_number('6500039')->is_valid_number, '兵庫県神戸市中央区前町');
ok($zip->set_number('6500041')->is_valid_number, '兵庫県神戸市中央区新港町');
ok($zip->set_number('6500042')->is_valid_number, '兵庫県神戸市中央区波止場町');
ok($zip->set_number('6500043')->is_valid_number, '兵庫県神戸市中央区弁天町');
ok($zip->set_number('6500044')->is_valid_number, '兵庫県神戸市中央区東川崎町');
ok($zip->set_number('6500045')->is_valid_number, '兵庫県神戸市中央区港島');
ok($zip->set_number('6500046')->is_valid_number, '兵庫県神戸市中央区港島中町');
ok($zip->set_number('6500047')->is_valid_number, '兵庫県神戸市中央区港島南町');
ok($zip->set_number('6500048')->is_valid_number, '兵庫県神戸市中央区神戸空港');
ok($zip->set_number('6510051')->is_valid_number, '兵庫県神戸市中央区神仙寺通');
ok($zip->set_number('6510052')->is_valid_number, '兵庫県神戸市中央区中島通');
ok($zip->set_number('6510053')->is_valid_number, '兵庫県神戸市中央区籠池通');
ok($zip->set_number('6510054')->is_valid_number, '兵庫県神戸市中央区野崎通');
ok($zip->set_number('6510055')->is_valid_number, '兵庫県神戸市中央区熊内橋通');
ok($zip->set_number('6510056')->is_valid_number, '兵庫県神戸市中央区熊内町');
ok($zip->set_number('6510057')->is_valid_number, '兵庫県神戸市中央区中尾町');
ok($zip->set_number('6510058')->is_valid_number, '兵庫県神戸市中央区葺合町');
ok($zip->set_number('6510061')->is_valid_number, '兵庫県神戸市中央区上筒井通');
ok($zip->set_number('6510062')->is_valid_number, '兵庫県神戸市中央区坂口通');
ok($zip->set_number('6510063')->is_valid_number, '兵庫県神戸市中央区宮本通');
ok($zip->set_number('6510064')->is_valid_number, '兵庫県神戸市中央区大日通');
ok($zip->set_number('6510065')->is_valid_number, '兵庫県神戸市中央区割塚通');
ok($zip->set_number('6510066')->is_valid_number, '兵庫県神戸市中央区国香通');
ok($zip->set_number('6510067')->is_valid_number, '兵庫県神戸市中央区神若通');
ok($zip->set_number('6510068')->is_valid_number, '兵庫県神戸市中央区旗塚通');
ok($zip->set_number('6510071')->is_valid_number, '兵庫県神戸市中央区筒井町');
ok($zip->set_number('6510072')->is_valid_number, '兵庫県神戸市中央区脇浜町');
ok($zip->set_number('6510073')->is_valid_number, '兵庫県神戸市中央区脇浜海岸通');
ok($zip->set_number('6510074')->is_valid_number, '兵庫県神戸市中央区南本町通');
ok($zip->set_number('6510075')->is_valid_number, '兵庫県神戸市中央区北本町通');
ok($zip->set_number('6510076')->is_valid_number, '兵庫県神戸市中央区吾妻通');
ok($zip->set_number('6510077')->is_valid_number, '兵庫県神戸市中央区日暮通');
ok($zip->set_number('6510078')->is_valid_number, '兵庫県神戸市中央区八雲通');
ok($zip->set_number('6510079')->is_valid_number, '兵庫県神戸市中央区東雲通');
ok($zip->set_number('6510081')->is_valid_number, '兵庫県神戸市中央区真砂通');
ok($zip->set_number('6510082')->is_valid_number, '兵庫県神戸市中央区小野浜町');
ok($zip->set_number('6510083')->is_valid_number, '兵庫県神戸市中央区浜辺通');
ok($zip->set_number('6510084')->is_valid_number, '兵庫県神戸市中央区磯辺通');
ok($zip->set_number('6510085')->is_valid_number, '兵庫県神戸市中央区八幡通');
ok($zip->set_number('6510086')->is_valid_number, '兵庫県神戸市中央区磯上通');
ok($zip->set_number('6510087')->is_valid_number, '兵庫県神戸市中央区御幸通');
ok($zip->set_number('6510088')->is_valid_number, '兵庫県神戸市中央区小野柄通');
ok($zip->set_number('6510091')->is_valid_number, '兵庫県神戸市中央区若菜通');
ok($zip->set_number('6510092')->is_valid_number, '兵庫県神戸市中央区生田町');
ok($zip->set_number('6510093')->is_valid_number, '兵庫県神戸市中央区二宮町');
ok($zip->set_number('6510094')->is_valid_number, '兵庫県神戸市中央区琴ノ緒町');
ok($zip->set_number('6510095')->is_valid_number, '兵庫県神戸市中央区旭通');
ok($zip->set_number('6510096')->is_valid_number, '兵庫県神戸市中央区雲井通');
ok($zip->set_number('6510097')->is_valid_number, '兵庫県神戸市中央区布引町');
ok($zip->set_number('6511100')->is_valid_number, '兵庫県神戸市北区以下に掲載がない場合');
ok($zip->set_number('6511101')->is_valid_number, '兵庫県神戸市北区山田町小部');
ok($zip->set_number('6511102')->is_valid_number, '兵庫県神戸市北区山田町下谷上(大上谷、修法ケ原、中一里山「9番地の4、12番地を除く」、');
ok($zip->set_number('6511102')->is_valid_number, '兵庫県神戸市北区長尾山、再度公園)');
ok($zip->set_number('6511103')->is_valid_number, '兵庫県神戸市北区中里町');
ok($zip->set_number('6511104')->is_valid_number, '兵庫県神戸市北区山田町藍那');
ok($zip->set_number('6511105')->is_valid_number, '兵庫県神戸市北区山田町小河');
ok($zip->set_number('6511106')->is_valid_number, '兵庫県神戸市北区しあわせの村');
ok($zip->set_number('6511111')->is_valid_number, '兵庫県神戸市北区鈴蘭台北町');
ok($zip->set_number('6511112')->is_valid_number, '兵庫県神戸市北区鈴蘭台東町');
ok($zip->set_number('6511113')->is_valid_number, '兵庫県神戸市北区鈴蘭台南町');
ok($zip->set_number('6511114')->is_valid_number, '兵庫県神戸市北区鈴蘭台西町');
ok($zip->set_number('6511121')->is_valid_number, '兵庫県神戸市北区星和台');
ok($zip->set_number('6511122')->is_valid_number, '兵庫県神戸市北区君影町');
ok($zip->set_number('6511123')->is_valid_number, '兵庫県神戸市北区ひよどり台');
ok($zip->set_number('6511124')->is_valid_number, '兵庫県神戸市北区ひよどり北町');
ok($zip->set_number('6511125')->is_valid_number, '兵庫県神戸市北区ひよどり台南町');
ok($zip->set_number('6511131')->is_valid_number, '兵庫県神戸市北区北五葉');
ok($zip->set_number('6511132')->is_valid_number, '兵庫県神戸市北区南五葉');
ok($zip->set_number('6511133')->is_valid_number, '兵庫県神戸市北区鳴子');
ok($zip->set_number('6511141')->is_valid_number, '兵庫県神戸市北区泉台');
ok($zip->set_number('6511142')->is_valid_number, '兵庫県神戸市北区甲栄台');
ok($zip->set_number('6511143')->is_valid_number, '兵庫県神戸市北区若葉台');
ok($zip->set_number('6511144')->is_valid_number, '兵庫県神戸市北区大脇台');
ok($zip->set_number('6511145')->is_valid_number, '兵庫県神戸市北区惣山町');
ok($zip->set_number('6511146')->is_valid_number, '兵庫県神戸市北区杉尾台');
ok($zip->set_number('6511147')->is_valid_number, '兵庫県神戸市北区松宮台');
ok($zip->set_number('6511201')->is_valid_number, '兵庫県神戸市北区西大池');
ok($zip->set_number('6511202')->is_valid_number, '兵庫県神戸市北区花山中尾台');
ok($zip->set_number('6511203')->is_valid_number, '兵庫県神戸市北区幸陽町');
ok($zip->set_number('6511204')->is_valid_number, '兵庫県神戸市北区花山東町');
ok($zip->set_number('6511205')->is_valid_number, '兵庫県神戸市北区花山台');
ok($zip->set_number('6511206')->is_valid_number, '兵庫県神戸市北区大池見山台');
ok($zip->set_number('6511211')->is_valid_number, '兵庫県神戸市北区小倉台');
ok($zip->set_number('6511212')->is_valid_number, '兵庫県神戸市北区筑紫が丘');
ok($zip->set_number('6511213')->is_valid_number, '兵庫県神戸市北区広陵町');
ok($zip->set_number('6511214')->is_valid_number, '兵庫県神戸市北区桜森町');
ok($zip->set_number('6511221')->is_valid_number, '兵庫県神戸市北区緑町');
ok($zip->set_number('6511222')->is_valid_number, '兵庫県神戸市北区大原');
ok($zip->set_number('6511223')->is_valid_number, '兵庫県神戸市北区桂木');
ok($zip->set_number('6511231')->is_valid_number, '兵庫県神戸市北区青葉台');
ok($zip->set_number('6511232')->is_valid_number, '兵庫県神戸市北区松が枝町');
ok($zip->set_number('6511233')->is_valid_number, '兵庫県神戸市北区日の峰');
ok($zip->set_number('6511241')->is_valid_number, '兵庫県神戸市北区山田町大池');
ok($zip->set_number('6511242')->is_valid_number, '兵庫県神戸市北区山田町上谷上');
ok($zip->set_number('6511243')->is_valid_number, '兵庫県神戸市北区山田町下谷上(その他)');
ok($zip->set_number('6511244')->is_valid_number, '兵庫県神戸市北区谷上南町');
ok($zip->set_number('6511245')->is_valid_number, '兵庫県神戸市北区谷上東町');
ok($zip->set_number('6511246')->is_valid_number, '兵庫県神戸市北区谷上西町');
ok($zip->set_number('6511251')->is_valid_number, '兵庫県神戸市北区山田町与左衛門新田');
ok($zip->set_number('6511252')->is_valid_number, '兵庫県神戸市北区山田町原野');
ok($zip->set_number('6511253')->is_valid_number, '兵庫県神戸市北区山田町中');
ok($zip->set_number('6511254')->is_valid_number, '兵庫県神戸市北区山田町福地');
ok($zip->set_number('6511255')->is_valid_number, '兵庫県神戸市北区柏尾台');
ok($zip->set_number('6511261')->is_valid_number, '兵庫県神戸市北区山田町坂本');
ok($zip->set_number('6511262')->is_valid_number, '兵庫県神戸市北区山田町東下');
ok($zip->set_number('6511263')->is_valid_number, '兵庫県神戸市北区山田町西下');
ok($zip->set_number('6511264')->is_valid_number, '兵庫県神戸市北区山田町衝原');
ok($zip->set_number('6511301')->is_valid_number, '兵庫県神戸市北区藤原台北町');
ok($zip->set_number('6511302')->is_valid_number, '兵庫県神戸市北区藤原台中町');
ok($zip->set_number('6511303')->is_valid_number, '兵庫県神戸市北区藤原台南町');
ok($zip->set_number('6511304')->is_valid_number, '兵庫県神戸市北区京地');
ok($zip->set_number('6511305')->is_valid_number, '兵庫県神戸市北区西山');
ok($zip->set_number('6511306')->is_valid_number, '兵庫県神戸市北区菖蒲が丘');
ok($zip->set_number('6511311')->is_valid_number, '兵庫県神戸市北区有野町二郎');
ok($zip->set_number('6511312')->is_valid_number, '兵庫県神戸市北区有野町有野');
ok($zip->set_number('6511313')->is_valid_number, '兵庫県神戸市北区有野中町');
ok($zip->set_number('6511321')->is_valid_number, '兵庫県神戸市北区有野台');
ok($zip->set_number('6511322')->is_valid_number, '兵庫県神戸市北区東有野台');
ok($zip->set_number('6511331')->is_valid_number, '兵庫県神戸市北区有野町唐櫃');
ok($zip->set_number('6511332')->is_valid_number, '兵庫県神戸市北区唐櫃台');
ok($zip->set_number('6511333')->is_valid_number, '兵庫県神戸市北区東大池');
ok($zip->set_number('6511334')->is_valid_number, '兵庫県神戸市北区唐櫃六甲台');
ok($zip->set_number('6511341')->is_valid_number, '兵庫県神戸市北区八多町深谷');
ok($zip->set_number('6511342')->is_valid_number, '兵庫県神戸市北区八多町柳谷');
ok($zip->set_number('6511343')->is_valid_number, '兵庫県神戸市北区八多町附物');
ok($zip->set_number('6511344')->is_valid_number, '兵庫県神戸市北区八多町屏風');
ok($zip->set_number('6511345')->is_valid_number, '兵庫県神戸市北区八多町西畑');
ok($zip->set_number('6511351')->is_valid_number, '兵庫県神戸市北区八多町中');
ok($zip->set_number('6511352')->is_valid_number, '兵庫県神戸市北区八多町下小名田');
ok($zip->set_number('6511353')->is_valid_number, '兵庫県神戸市北区八多町吉尾');
ok($zip->set_number('6511354')->is_valid_number, '兵庫県神戸市北区八多町上小名田');
ok($zip->set_number('6511401')->is_valid_number, '兵庫県神戸市北区有馬町');
ok($zip->set_number('6511411')->is_valid_number, '兵庫県西宮市山口町名来');
ok($zip->set_number('6511412')->is_valid_number, '兵庫県西宮市山口町下山口');
ok($zip->set_number('6511413')->is_valid_number, '兵庫県西宮市北六甲台');
ok($zip->set_number('6511421')->is_valid_number, '兵庫県西宮市山口町上山口');
ok($zip->set_number('6511422')->is_valid_number, '兵庫県西宮市山口町金仙寺');
ok($zip->set_number('6511423')->is_valid_number, '兵庫県西宮市山口町船坂');
ok($zip->set_number('6511424')->is_valid_number, '兵庫県西宮市山口町香花園');
ok($zip->set_number('6511431')->is_valid_number, '兵庫県西宮市山口町阪神流通センター');
ok($zip->set_number('6511432')->is_valid_number, '兵庫県西宮市すみれ台');
ok($zip->set_number('6511433')->is_valid_number, '兵庫県西宮市山口町中野');
ok($zip->set_number('6511501')->is_valid_number, '兵庫県神戸市北区道場町道場');
ok($zip->set_number('6511502')->is_valid_number, '兵庫県神戸市北区道場町塩田');
ok($zip->set_number('6511503')->is_valid_number, '兵庫県神戸市北区道場町生野(その他)');
ok($zip->set_number('6511504')->is_valid_number, '兵庫県神戸市北区道場町平田');
ok($zip->set_number('6511505')->is_valid_number, '兵庫県神戸市北区道場町日下部');
ok($zip->set_number('6511511')->is_valid_number, '兵庫県神戸市北区長尾町宅原');
ok($zip->set_number('6511512')->is_valid_number, '兵庫県神戸市北区長尾町上津');
ok($zip->set_number('6511513')->is_valid_number, '兵庫県神戸市北区鹿の子台北町');
ok($zip->set_number('6511514')->is_valid_number, '兵庫県神戸市北区鹿の子台南町');
ok($zip->set_number('6511515')->is_valid_number, '兵庫県神戸市北区上津台');
ok($zip->set_number('6511516')->is_valid_number, '兵庫県神戸市北区赤松台');
ok($zip->set_number('6511521')->is_valid_number, '兵庫県神戸市北区大沢町市原');
ok($zip->set_number('6511522')->is_valid_number, '兵庫県神戸市北区大沢町上大沢');
ok($zip->set_number('6511523')->is_valid_number, '兵庫県神戸市北区大沢町神付');
ok($zip->set_number('6511524')->is_valid_number, '兵庫県神戸市北区大沢町中大沢');
ok($zip->set_number('6511525')->is_valid_number, '兵庫県神戸市北区大沢町日西原');
ok($zip->set_number('6511526')->is_valid_number, '兵庫県神戸市北区大沢町簾');
ok($zip->set_number('6511601')->is_valid_number, '兵庫県神戸市北区淡河町北僧尾');
ok($zip->set_number('6511602')->is_valid_number, '兵庫県神戸市北区淡河町南僧尾');
ok($zip->set_number('6511603')->is_valid_number, '兵庫県神戸市北区淡河町淡河');
ok($zip->set_number('6511604')->is_valid_number, '兵庫県神戸市北区淡河町勝雄');
ok($zip->set_number('6511611')->is_valid_number, '兵庫県神戸市北区淡河町中山');
ok($zip->set_number('6511612')->is_valid_number, '兵庫県神戸市北区淡河町東畑');
ok($zip->set_number('6511613')->is_valid_number, '兵庫県神戸市北区淡河町行原');
ok($zip->set_number('6511614')->is_valid_number, '兵庫県神戸市北区淡河町木津');
ok($zip->set_number('6511615')->is_valid_number, '兵庫県神戸市北区淡河町萩原');
ok($zip->set_number('6511616')->is_valid_number, '兵庫県神戸市北区淡河町北畑');
ok($zip->set_number('6511621')->is_valid_number, '兵庫県神戸市北区淡河町神影');
ok($zip->set_number('6511622')->is_valid_number, '兵庫県神戸市北区淡河町神田');
ok($zip->set_number('6511623')->is_valid_number, '兵庫県神戸市北区淡河町野瀬');
ok($zip->set_number('6512101')->is_valid_number, '兵庫県神戸市西区伊川谷町布施畑');
ok($zip->set_number('6512102')->is_valid_number, '兵庫県神戸市西区学園東町');
ok($zip->set_number('6512103')->is_valid_number, '兵庫県神戸市西区学園西町');
ok($zip->set_number('6512104')->is_valid_number, '兵庫県神戸市西区伊川谷町長坂');
ok($zip->set_number('6512105')->is_valid_number, '兵庫県神戸市西区伊川谷町上脇');
ok($zip->set_number('6512106')->is_valid_number, '兵庫県神戸市西区伊川谷町井吹');
ok($zip->set_number('6512107')->is_valid_number, '兵庫県神戸市西区伊川谷町小寺');
ok($zip->set_number('6512108')->is_valid_number, '兵庫県神戸市西区伊川谷町前開');
ok($zip->set_number('6512109')->is_valid_number, '兵庫県神戸市西区前開南町');
ok($zip->set_number('6512111')->is_valid_number, '兵庫県神戸市西区池上');
ok($zip->set_number('6512112')->is_valid_number, '兵庫県神戸市西区大津和');
ok($zip->set_number('6512113')->is_valid_number, '兵庫県神戸市西区伊川谷町有瀬');
ok($zip->set_number('6512114')->is_valid_number, '兵庫県神戸市西区今寺');
ok($zip->set_number('6512115')->is_valid_number, '兵庫県神戸市西区伊川谷町別府');
ok($zip->set_number('6512116')->is_valid_number, '兵庫県神戸市西区南別府');
ok($zip->set_number('6512117')->is_valid_number, '兵庫県神戸市西区北別府');
ok($zip->set_number('6512120')->is_valid_number, '兵庫県神戸市西区和井取');
ok($zip->set_number('6512121')->is_valid_number, '兵庫県神戸市西区玉津町水谷');
ok($zip->set_number('6512121')->is_valid_number, '兵庫県神戸市西区水谷');
ok($zip->set_number('6512122')->is_valid_number, '兵庫県神戸市西区玉津町高津橋');
ok($zip->set_number('6512123')->is_valid_number, '兵庫県神戸市西区天王山');
ok($zip->set_number('6512124')->is_valid_number, '兵庫県神戸市西区伊川谷町潤和');
ok($zip->set_number('6512125')->is_valid_number, '兵庫県神戸市西区玉津町新方');
ok($zip->set_number('6512126')->is_valid_number, '兵庫県神戸市西区玉津町上池');
ok($zip->set_number('6512127')->is_valid_number, '兵庫県神戸市西区玉津町西河原');
ok($zip->set_number('6512128')->is_valid_number, '兵庫県神戸市西区玉津町今津');
ok($zip->set_number('6512129')->is_valid_number, '兵庫県神戸市西区白水');
ok($zip->set_number('6512131')->is_valid_number, '兵庫県神戸市西区持子');
ok($zip->set_number('6512132')->is_valid_number, '兵庫県神戸市西区森友');
ok($zip->set_number('6512133')->is_valid_number, '兵庫県神戸市西区枝吉');
ok($zip->set_number('6512134')->is_valid_number, '兵庫県神戸市西区曙町');
ok($zip->set_number('6512135')->is_valid_number, '兵庫県神戸市西区王塚台');
ok($zip->set_number('6512136')->is_valid_number, '兵庫県神戸市西区中野');
ok($zip->set_number('6512137')->is_valid_number, '兵庫県神戸市西区玉津町出合');
ok($zip->set_number('6512138')->is_valid_number, '兵庫県神戸市西区玉津町吉田');
ok($zip->set_number('6512141')->is_valid_number, '兵庫県神戸市西区天が岡');
ok($zip->set_number('6512142')->is_valid_number, '兵庫県神戸市西区玉津町二ツ屋');
ok($zip->set_number('6512142')->is_valid_number, '兵庫県神戸市西区二ツ屋');
ok($zip->set_number('6512143')->is_valid_number, '兵庫県神戸市西区玉津町丸塚');
ok($zip->set_number('6512143')->is_valid_number, '兵庫県神戸市西区丸塚');
ok($zip->set_number('6512144')->is_valid_number, '兵庫県神戸市西区小山');
ok($zip->set_number('6512144')->is_valid_number, '兵庫県神戸市西区玉津町小山');
ok($zip->set_number('6512145')->is_valid_number, '兵庫県神戸市西区玉津町居住');
ok($zip->set_number('6512146')->is_valid_number, '兵庫県神戸市西区宮下');
ok($zip->set_number('6512147')->is_valid_number, '兵庫県神戸市西区玉津町田中');
ok($zip->set_number('6512148')->is_valid_number, '兵庫県神戸市西区長畑町');
ok($zip->set_number('6512201')->is_valid_number, '兵庫県神戸市西区高雄台');
ok($zip->set_number('6512202')->is_valid_number, '兵庫県神戸市西区押部谷町西盛');
ok($zip->set_number('6512203')->is_valid_number, '兵庫県神戸市西区押部谷町近江');
ok($zip->set_number('6512204')->is_valid_number, '兵庫県神戸市西区押部谷町高和');
ok($zip->set_number('6512205')->is_valid_number, '兵庫県神戸市西区押部谷町養田');
ok($zip->set_number('6512206')->is_valid_number, '兵庫県神戸市西区押部谷町和田');
ok($zip->set_number('6512207')->is_valid_number, '兵庫県神戸市西区押部谷町細田');
ok($zip->set_number('6512211')->is_valid_number, '兵庫県神戸市西区押部谷町栄');
ok($zip->set_number('6512212')->is_valid_number, '兵庫県神戸市西区押部谷町押部');
ok($zip->set_number('6512213')->is_valid_number, '兵庫県神戸市西区押部谷町福住');
ok($zip->set_number('6512214')->is_valid_number, '兵庫県神戸市西区富士見が丘');
ok($zip->set_number('6512215')->is_valid_number, '兵庫県神戸市西区北山台');
ok($zip->set_number('6512216')->is_valid_number, '兵庫県神戸市西区美穂が丘');
ok($zip->set_number('6512217')->is_valid_number, '兵庫県神戸市西区月が丘');
ok($zip->set_number('6512221')->is_valid_number, '兵庫県神戸市西区押部谷町木幡');
ok($zip->set_number('6512222')->is_valid_number, '兵庫県神戸市西区押部谷町木津');
ok($zip->set_number('6512223')->is_valid_number, '兵庫県神戸市西区押部谷町木見');
ok($zip->set_number('6512224')->is_valid_number, '兵庫県神戸市西区秋葉台');
ok($zip->set_number('6512225')->is_valid_number, '兵庫県神戸市西区桜が丘東町');
ok($zip->set_number('6512226')->is_valid_number, '兵庫県神戸市西区桜が丘中町');
ok($zip->set_number('6512227')->is_valid_number, '兵庫県神戸市西区桜が丘西町');
ok($zip->set_number('6512228')->is_valid_number, '兵庫県神戸市西区見津が丘');
ok($zip->set_number('6512231')->is_valid_number, '兵庫県神戸市西区櫨谷町寺谷');
ok($zip->set_number('6512232')->is_valid_number, '兵庫県神戸市西区櫨谷町友清');
ok($zip->set_number('6512233')->is_valid_number, '兵庫県神戸市西区櫨谷町福谷');
ok($zip->set_number('6512234')->is_valid_number, '兵庫県神戸市西区櫨谷町池谷');
ok($zip->set_number('6512235')->is_valid_number, '兵庫県神戸市西区櫨谷町長谷');
ok($zip->set_number('6512236')->is_valid_number, '兵庫県神戸市西区櫨谷町栃木');
ok($zip->set_number('6512237')->is_valid_number, '兵庫県神戸市西区櫨谷町谷口');
ok($zip->set_number('6512238')->is_valid_number, '兵庫県神戸市西区櫨谷町菅野');
ok($zip->set_number('6512239')->is_valid_number, '兵庫県神戸市西区櫨谷町松本');
ok($zip->set_number('6512241')->is_valid_number, '兵庫県神戸市西区室谷');
ok($zip->set_number('6512242')->is_valid_number, '兵庫県神戸市西区井吹台東町');
ok($zip->set_number('6512243')->is_valid_number, '兵庫県神戸市西区井吹台西町');
ok($zip->set_number('6512244')->is_valid_number, '兵庫県神戸市西区井吹台北町');
ok($zip->set_number('6512251')->is_valid_number, '兵庫県神戸市西区平野町下村');
ok($zip->set_number('6512252')->is_valid_number, '兵庫県神戸市西区平野町福中');
ok($zip->set_number('6512253')->is_valid_number, '兵庫県神戸市西区平野町向井');
ok($zip->set_number('6512254')->is_valid_number, '兵庫県神戸市西区平野町芝崎');
ok($zip->set_number('6512255')->is_valid_number, '兵庫県神戸市西区平野町慶明');
ok($zip->set_number('6512256')->is_valid_number, '兵庫県神戸市西区平野町大野');
ok($zip->set_number('6512257')->is_valid_number, '兵庫県神戸市西区平野町中津');
ok($zip->set_number('6512261')->is_valid_number, '兵庫県神戸市西区平野町堅田');
ok($zip->set_number('6512262')->is_valid_number, '兵庫県神戸市西区平野町繁田');
ok($zip->set_number('6512263')->is_valid_number, '兵庫県神戸市西区平野町常本');
ok($zip->set_number('6512264')->is_valid_number, '兵庫県神戸市西区平野町大畑');
ok($zip->set_number('6512265')->is_valid_number, '兵庫県神戸市西区平野町宮前');
ok($zip->set_number('6512266')->is_valid_number, '兵庫県神戸市西区平野町印路');
ok($zip->set_number('6512267')->is_valid_number, '兵庫県神戸市西区平野町西戸田');
ok($zip->set_number('6512268')->is_valid_number, '兵庫県神戸市西区平野町黒田');
ok($zip->set_number('6512271')->is_valid_number, '兵庫県神戸市西区高塚台');
ok($zip->set_number('6512272')->is_valid_number, '兵庫県神戸市西区狩場台');
ok($zip->set_number('6512273')->is_valid_number, '兵庫県神戸市西区糀台');
ok($zip->set_number('6512274')->is_valid_number, '兵庫県神戸市西区竹の台');
ok($zip->set_number('6512275')->is_valid_number, '兵庫県神戸市西区樫野台');
ok($zip->set_number('6512276')->is_valid_number, '兵庫県神戸市西区春日台');
ok($zip->set_number('6512277')->is_valid_number, '兵庫県神戸市西区美賀多台');
ok($zip->set_number('6512301')->is_valid_number, '兵庫県神戸市西区神出町勝成');
ok($zip->set_number('6512302')->is_valid_number, '兵庫県神戸市西区神出町古神');
ok($zip->set_number('6512303')->is_valid_number, '兵庫県神戸市西区神出町五百蔵');
ok($zip->set_number('6512304')->is_valid_number, '兵庫県神戸市西区神出町小束野');
ok($zip->set_number('6512311')->is_valid_number, '兵庫県神戸市西区神出町東');
ok($zip->set_number('6512312')->is_valid_number, '兵庫県神戸市西区神出町南');
ok($zip->set_number('6512313')->is_valid_number, '兵庫県神戸市西区神出町田井');
ok($zip->set_number('6512321')->is_valid_number, '兵庫県神戸市西区神出町宝勢');
ok($zip->set_number('6512331')->is_valid_number, '兵庫県神戸市西区神出町広谷');
ok($zip->set_number('6512332')->is_valid_number, '兵庫県神戸市西区神出町北');
ok($zip->set_number('6512333')->is_valid_number, '兵庫県神戸市西区神出町池田');
ok($zip->set_number('6512334')->is_valid_number, '兵庫県神戸市西区神出町紫合');
ok($zip->set_number('6512401')->is_valid_number, '兵庫県神戸市西区岩岡町岩岡');
ok($zip->set_number('6512402')->is_valid_number, '兵庫県神戸市西区岩岡町印路');
ok($zip->set_number('6512403')->is_valid_number, '兵庫県神戸市西区岩岡町西脇');
ok($zip->set_number('6512404')->is_valid_number, '兵庫県神戸市西区岩岡町古郷');
ok($zip->set_number('6512405')->is_valid_number, '兵庫県神戸市西区岩岡町野中');
ok($zip->set_number('6512411')->is_valid_number, '兵庫県神戸市西区上新地');
ok($zip->set_number('6512412')->is_valid_number, '兵庫県神戸市西区竜が岡');
ok($zip->set_number('6512413')->is_valid_number, '兵庫県神戸市西区福吉台');
ok($zip->set_number('6512414')->is_valid_number, '兵庫県神戸市西区大沢');
ok($zip->set_number('6520000')->is_valid_number, '兵庫県神戸市兵庫区以下に掲載がない場合');
ok($zip->set_number('6520001')->is_valid_number, '兵庫県神戸市兵庫区烏原町');
ok($zip->set_number('6520002')->is_valid_number, '兵庫県神戸市兵庫区平野町');
ok($zip->set_number('6520003')->is_valid_number, '兵庫県神戸市兵庫区梅元町');
ok($zip->set_number('6520004')->is_valid_number, '兵庫県神戸市兵庫区楠谷町');
ok($zip->set_number('6520005')->is_valid_number, '兵庫県神戸市兵庫区矢部町');
ok($zip->set_number('6520006')->is_valid_number, '兵庫県神戸市兵庫区神田町');
ok($zip->set_number('6520007')->is_valid_number, '兵庫県神戸市兵庫区五宮町');
ok($zip->set_number('6520008')->is_valid_number, '兵庫県神戸市兵庫区上祇園町');
ok($zip->set_number('6520011')->is_valid_number, '兵庫県神戸市兵庫区山王町');
ok($zip->set_number('6520012')->is_valid_number, '兵庫県神戸市兵庫区湊山町');
ok($zip->set_number('6520013')->is_valid_number, '兵庫県神戸市兵庫区上三条町');
ok($zip->set_number('6520014')->is_valid_number, '兵庫県神戸市兵庫区下三条町');
ok($zip->set_number('6520015')->is_valid_number, '兵庫県神戸市兵庫区下祇園町');
ok($zip->set_number('6520016')->is_valid_number, '兵庫県神戸市兵庫区馬場町');
ok($zip->set_number('6520021')->is_valid_number, '兵庫県神戸市兵庫区天王町');
ok($zip->set_number('6520022')->is_valid_number, '兵庫県神戸市兵庫区千鳥町');
ok($zip->set_number('6520023')->is_valid_number, '兵庫県神戸市兵庫区都由乃町');
ok($zip->set_number('6520031')->is_valid_number, '兵庫県神戸市兵庫区雪御所町');
ok($zip->set_number('6520032')->is_valid_number, '兵庫県神戸市兵庫区荒田町');
ok($zip->set_number('6520033')->is_valid_number, '兵庫県神戸市兵庫区西上橘通');
ok($zip->set_number('6520034')->is_valid_number, '兵庫県神戸市兵庫区西橘通');
ok($zip->set_number('6520035')->is_valid_number, '兵庫県神戸市兵庫区西多聞通');
ok($zip->set_number('6520036')->is_valid_number, '兵庫県神戸市兵庫区福原町');
ok($zip->set_number('6520041')->is_valid_number, '兵庫県神戸市兵庫区湊川町');
ok($zip->set_number('6520042')->is_valid_number, '兵庫県神戸市兵庫区東山町');
ok($zip->set_number('6520043')->is_valid_number, '兵庫県神戸市兵庫区会下山町');
ok($zip->set_number('6520044')->is_valid_number, '兵庫県神戸市兵庫区大井通');
ok($zip->set_number('6520045')->is_valid_number, '兵庫県神戸市兵庫区松本通');
ok($zip->set_number('6520046')->is_valid_number, '兵庫県神戸市兵庫区上沢通');
ok($zip->set_number('6520047')->is_valid_number, '兵庫県神戸市兵庫区下沢通');
ok($zip->set_number('6520051')->is_valid_number, '兵庫県神戸市兵庫区里山町');
ok($zip->set_number('6520052')->is_valid_number, '兵庫県神戸市兵庫区鵯越筋');
ok($zip->set_number('6520053')->is_valid_number, '兵庫県神戸市兵庫区北山町');
ok($zip->set_number('6520054')->is_valid_number, '兵庫県神戸市兵庫区氷室町');
ok($zip->set_number('6520055')->is_valid_number, '兵庫県神戸市兵庫区小山町');
ok($zip->set_number('6520056')->is_valid_number, '兵庫県神戸市兵庫区滝山町');
ok($zip->set_number('6520057')->is_valid_number, '兵庫県神戸市兵庫区鵯越町');
ok($zip->set_number('6520058')->is_valid_number, '兵庫県神戸市兵庫区菊水町');
ok($zip->set_number('6520061')->is_valid_number, '兵庫県神戸市兵庫区石井町');
ok($zip->set_number('6520062')->is_valid_number, '兵庫県神戸市兵庫区大同町');
ok($zip->set_number('6520063')->is_valid_number, '兵庫県神戸市兵庫区夢野町');
ok($zip->set_number('6520064')->is_valid_number, '兵庫県神戸市兵庫区熊野町');
ok($zip->set_number('6520065')->is_valid_number, '兵庫県神戸市兵庫区清水町');
ok($zip->set_number('6520071')->is_valid_number, '兵庫県神戸市北区山田町下谷上(菊水山、高座川向、中一里山「9番地の4、12番地」、');
ok($zip->set_number('6520071')->is_valid_number, '兵庫県神戸市北区念仏堂、ひよどり越)');
ok($zip->set_number('6520801')->is_valid_number, '兵庫県神戸市兵庫区中道通');
ok($zip->set_number('6520802')->is_valid_number, '兵庫県神戸市兵庫区水木通');
ok($zip->set_number('6520803')->is_valid_number, '兵庫県神戸市兵庫区大開通');
ok($zip->set_number('6520804')->is_valid_number, '兵庫県神戸市兵庫区塚本通');
ok($zip->set_number('6520805')->is_valid_number, '兵庫県神戸市兵庫区羽坂通');
ok($zip->set_number('6520806')->is_valid_number, '兵庫県神戸市兵庫区西柳原町');
ok($zip->set_number('6520807')->is_valid_number, '兵庫県神戸市兵庫区浜崎通');
ok($zip->set_number('6520811')->is_valid_number, '兵庫県神戸市兵庫区新開地');
ok($zip->set_number('6520812')->is_valid_number, '兵庫県神戸市兵庫区湊町');
ok($zip->set_number('6520813')->is_valid_number, '兵庫県神戸市兵庫区兵庫町');
ok($zip->set_number('6520814')->is_valid_number, '兵庫県神戸市兵庫区門口町');
ok($zip->set_number('6520815')->is_valid_number, '兵庫県神戸市兵庫区三川口町');
ok($zip->set_number('6520816')->is_valid_number, '兵庫県神戸市兵庫区永沢町');
ok($zip->set_number('6520821')->is_valid_number, '兵庫県神戸市兵庫区佐比江町');
ok($zip->set_number('6520822')->is_valid_number, '兵庫県神戸市兵庫区西出町');
ok($zip->set_number('6520823')->is_valid_number, '兵庫県神戸市兵庫区東出町');
ok($zip->set_number('6520831')->is_valid_number, '兵庫県神戸市兵庫区七宮町');
ok($zip->set_number('6520832')->is_valid_number, '兵庫県神戸市兵庫区鍛冶屋町');
ok($zip->set_number('6520833')->is_valid_number, '兵庫県神戸市兵庫区島上町');
ok($zip->set_number('6520834')->is_valid_number, '兵庫県神戸市兵庫区本町');
ok($zip->set_number('6520835')->is_valid_number, '兵庫県神戸市兵庫区西仲町');
ok($zip->set_number('6520836')->is_valid_number, '兵庫県神戸市兵庫区神明町');
ok($zip->set_number('6520837')->is_valid_number, '兵庫県神戸市兵庫区北逆瀬川町');
ok($zip->set_number('6520841')->is_valid_number, '兵庫県神戸市兵庫区南仲町');
ok($zip->set_number('6520842')->is_valid_number, '兵庫県神戸市兵庫区磯之町');
ok($zip->set_number('6520843')->is_valid_number, '兵庫県神戸市兵庫区船大工町');
ok($zip->set_number('6520844')->is_valid_number, '兵庫県神戸市兵庫区中之島');
ok($zip->set_number('6520845')->is_valid_number, '兵庫県神戸市兵庫区築地町');
ok($zip->set_number('6520846')->is_valid_number, '兵庫県神戸市兵庫区出在家町');
ok($zip->set_number('6520847')->is_valid_number, '兵庫県神戸市兵庫区切戸町');
ok($zip->set_number('6520851')->is_valid_number, '兵庫県神戸市兵庫区材木町');
ok($zip->set_number('6520852')->is_valid_number, '兵庫県神戸市兵庫区御崎本町');
ok($zip->set_number('6520853')->is_valid_number, '兵庫県神戸市兵庫区今出在家町');
ok($zip->set_number('6520854')->is_valid_number, '兵庫県神戸市兵庫区和田崎町');
ok($zip->set_number('6520855')->is_valid_number, '兵庫県神戸市兵庫区御崎町');
ok($zip->set_number('6520861')->is_valid_number, '兵庫県神戸市兵庫区三石通');
ok($zip->set_number('6520862')->is_valid_number, '兵庫県神戸市兵庫区上庄通');
ok($zip->set_number('6520863')->is_valid_number, '兵庫県神戸市兵庫区和田宮通');
ok($zip->set_number('6520864')->is_valid_number, '兵庫県神戸市兵庫区笠松通');
ok($zip->set_number('6520865')->is_valid_number, '兵庫県神戸市兵庫区小松通');
ok($zip->set_number('6520866')->is_valid_number, '兵庫県神戸市兵庫区遠矢浜町');
ok($zip->set_number('6520871')->is_valid_number, '兵庫県神戸市兵庫区浜山通');
ok($zip->set_number('6520872')->is_valid_number, '兵庫県神戸市兵庫区吉田町');
ok($zip->set_number('6520873')->is_valid_number, '兵庫県神戸市兵庫区金平町');
ok($zip->set_number('6520874')->is_valid_number, '兵庫県神戸市兵庫区高松町');
ok($zip->set_number('6520875')->is_valid_number, '兵庫県神戸市兵庫区浜中町');
ok($zip->set_number('6520881')->is_valid_number, '兵庫県神戸市兵庫区松原通');
ok($zip->set_number('6520882')->is_valid_number, '兵庫県神戸市兵庫区芦原通');
ok($zip->set_number('6520883')->is_valid_number, '兵庫県神戸市兵庫区明和通');
ok($zip->set_number('6520884')->is_valid_number, '兵庫県神戸市兵庫区和田山通');
ok($zip->set_number('6520885')->is_valid_number, '兵庫県神戸市兵庫区御所通');
ok($zip->set_number('6520891')->is_valid_number, '兵庫県神戸市兵庫区西宮内町');
ok($zip->set_number('6520892')->is_valid_number, '兵庫県神戸市兵庫区東柳原町');
ok($zip->set_number('6520893')->is_valid_number, '兵庫県神戸市兵庫区南逆瀬川町');
ok($zip->set_number('6520894')->is_valid_number, '兵庫県神戸市兵庫区入江通');
ok($zip->set_number('6520895')->is_valid_number, '兵庫県神戸市兵庫区小河通');
ok($zip->set_number('6520896')->is_valid_number, '兵庫県神戸市兵庫区須佐野通');
ok($zip->set_number('6520897')->is_valid_number, '兵庫県神戸市兵庫区駅南通');
ok($zip->set_number('6520898')->is_valid_number, '兵庫県神戸市兵庫区駅前通');
ok($zip->set_number('6530000')->is_valid_number, '兵庫県神戸市長田区以下に掲載がない場合');
ok($zip->set_number('6530001')->is_valid_number, '兵庫県神戸市長田区七番町');
ok($zip->set_number('6530002')->is_valid_number, '兵庫県神戸市長田区六番町');
ok($zip->set_number('6530003')->is_valid_number, '兵庫県神戸市長田区五番町');
ok($zip->set_number('6530004')->is_valid_number, '兵庫県神戸市長田区四番町');
ok($zip->set_number('6530011')->is_valid_number, '兵庫県神戸市長田区三番町');
ok($zip->set_number('6530012')->is_valid_number, '兵庫県神戸市長田区二番町');
ok($zip->set_number('6530013')->is_valid_number, '兵庫県神戸市長田区一番町');
ok($zip->set_number('6530014')->is_valid_number, '兵庫県神戸市長田区御蔵通');
ok($zip->set_number('6530015')->is_valid_number, '兵庫県神戸市長田区菅原通');
ok($zip->set_number('6530016')->is_valid_number, '兵庫県神戸市長田区北町');
ok($zip->set_number('6530021')->is_valid_number, '兵庫県神戸市長田区梅ケ香町');
ok($zip->set_number('6530022')->is_valid_number, '兵庫県神戸市長田区東尻池町');
ok($zip->set_number('6530023')->is_valid_number, '兵庫県神戸市長田区東尻池新町');
ok($zip->set_number('6530024')->is_valid_number, '兵庫県神戸市長田区浜添通');
ok($zip->set_number('6530025')->is_valid_number, '兵庫県神戸市長田区真野町');
ok($zip->set_number('6530031')->is_valid_number, '兵庫県神戸市長田区西尻池町');
ok($zip->set_number('6530032')->is_valid_number, '兵庫県神戸市長田区苅藻通');
ok($zip->set_number('6530033')->is_valid_number, '兵庫県神戸市長田区苅藻島町');
ok($zip->set_number('6530034')->is_valid_number, '兵庫県神戸市長田区駒栄町');
ok($zip->set_number('6530035')->is_valid_number, '兵庫県神戸市長田区庄田町');
ok($zip->set_number('6530036')->is_valid_number, '兵庫県神戸市長田区腕塚町');
ok($zip->set_number('6530037')->is_valid_number, '兵庫県神戸市長田区大橋町');
ok($zip->set_number('6530038')->is_valid_number, '兵庫県神戸市長田区若松町');
ok($zip->set_number('6530039')->is_valid_number, '兵庫県神戸市長田区日吉町');
ok($zip->set_number('6530041')->is_valid_number, '兵庫県神戸市長田区久保町');
ok($zip->set_number('6530042')->is_valid_number, '兵庫県神戸市長田区二葉町');
ok($zip->set_number('6530043')->is_valid_number, '兵庫県神戸市長田区駒ケ林町');
ok($zip->set_number('6530044')->is_valid_number, '兵庫県神戸市長田区南駒栄町');
ok($zip->set_number('6530045')->is_valid_number, '兵庫県神戸市長田区駒ケ林南町');
ok($zip->set_number('6530051')->is_valid_number, '兵庫県神戸市長田区野田町');
ok($zip->set_number('6530052')->is_valid_number, '兵庫県神戸市長田区海運町');
ok($zip->set_number('6530053')->is_valid_number, '兵庫県神戸市長田区本庄町');
ok($zip->set_number('6530054')->is_valid_number, '兵庫県神戸市長田区長楽町');
ok($zip->set_number('6530055')->is_valid_number, '兵庫県神戸市長田区浪松町');
ok($zip->set_number('6530801')->is_valid_number, '兵庫県神戸市長田区房王寺町');
ok($zip->set_number('6530802')->is_valid_number, '兵庫県神戸市長田区重池町');
ok($zip->set_number('6530803')->is_valid_number, '兵庫県神戸市長田区前原町');
ok($zip->set_number('6530804')->is_valid_number, '兵庫県神戸市長田区寺池町');
ok($zip->set_number('6530805')->is_valid_number, '兵庫県神戸市長田区片山町');
ok($zip->set_number('6530806')->is_valid_number, '兵庫県神戸市長田区大丸町');
ok($zip->set_number('6530811')->is_valid_number, '兵庫県神戸市長田区大塚町');
ok($zip->set_number('6530812')->is_valid_number, '兵庫県神戸市長田区長田町');
ok($zip->set_number('6530813')->is_valid_number, '兵庫県神戸市長田区宮川町');
ok($zip->set_number('6530814')->is_valid_number, '兵庫県神戸市長田区池田広町');
ok($zip->set_number('6530821')->is_valid_number, '兵庫県神戸市長田区池田谷町');
ok($zip->set_number('6530822')->is_valid_number, '兵庫県神戸市長田区池田寺町');
ok($zip->set_number('6530823')->is_valid_number, '兵庫県神戸市長田区池田経町');
ok($zip->set_number('6530824')->is_valid_number, '兵庫県神戸市長田区池田上町');
ok($zip->set_number('6530825')->is_valid_number, '兵庫県神戸市長田区池田新町');
ok($zip->set_number('6530826')->is_valid_number, '兵庫県神戸市長田区池田塩町');
ok($zip->set_number('6530827')->is_valid_number, '兵庫県神戸市長田区上池田');
ok($zip->set_number('6530831')->is_valid_number, '兵庫県神戸市長田区蓮宮通');
ok($zip->set_number('6530832')->is_valid_number, '兵庫県神戸市長田区御船通');
ok($zip->set_number('6530833')->is_valid_number, '兵庫県神戸市長田区大道通');
ok($zip->set_number('6530834')->is_valid_number, '兵庫県神戸市長田区川西通');
ok($zip->set_number('6530835')->is_valid_number, '兵庫県神戸市長田区細田町');
ok($zip->set_number('6530836')->is_valid_number, '兵庫県神戸市長田区神楽町');
ok($zip->set_number('6530837')->is_valid_number, '兵庫県神戸市長田区蓮池町');
ok($zip->set_number('6530838')->is_valid_number, '兵庫県神戸市長田区大谷町');
ok($zip->set_number('6530841')->is_valid_number, '兵庫県神戸市長田区松野通');
ok($zip->set_number('6530842')->is_valid_number, '兵庫県神戸市長田区水笠通');
ok($zip->set_number('6530843')->is_valid_number, '兵庫県神戸市長田区御屋敷通');
ok($zip->set_number('6530844')->is_valid_number, '兵庫県神戸市長田区西代通');
ok($zip->set_number('6530845')->is_valid_number, '兵庫県神戸市長田区戸崎通');
ok($zip->set_number('6530851')->is_valid_number, '兵庫県神戸市長田区五位ノ池町');
ok($zip->set_number('6530852')->is_valid_number, '兵庫県神戸市長田区山下町');
ok($zip->set_number('6530853')->is_valid_number, '兵庫県神戸市長田区庄山町');
ok($zip->set_number('6530854')->is_valid_number, '兵庫県神戸市長田区平和台町');
ok($zip->set_number('6530855')->is_valid_number, '兵庫県神戸市長田区長尾町');
ok($zip->set_number('6530856')->is_valid_number, '兵庫県神戸市長田区高取山町');
ok($zip->set_number('6530861')->is_valid_number, '兵庫県神戸市長田区林山町');
ok($zip->set_number('6530862')->is_valid_number, '兵庫県神戸市長田区西山町');
ok($zip->set_number('6530863')->is_valid_number, '兵庫県神戸市長田区宮丘町');
ok($zip->set_number('6530864')->is_valid_number, '兵庫県神戸市長田区池田惣町');
ok($zip->set_number('6530865')->is_valid_number, '兵庫県神戸市長田区池田宮町');
ok($zip->set_number('6530866')->is_valid_number, '兵庫県神戸市長田区長者町');
ok($zip->set_number('6530867')->is_valid_number, '兵庫県神戸市長田区高東町');
ok($zip->set_number('6530871')->is_valid_number, '兵庫県神戸市長田区鶯町');
ok($zip->set_number('6530872')->is_valid_number, '兵庫県神戸市長田区大日丘町');
ok($zip->set_number('6530873')->is_valid_number, '兵庫県神戸市長田区萩乃町');
ok($zip->set_number('6530874')->is_valid_number, '兵庫県神戸市長田区西丸山町');
ok($zip->set_number('6530875')->is_valid_number, '兵庫県神戸市長田区丸山町');
ok($zip->set_number('6530876')->is_valid_number, '兵庫県神戸市長田区花山町');
ok($zip->set_number('6530877')->is_valid_number, '兵庫県神戸市長田区鹿松町');
ok($zip->set_number('6530878')->is_valid_number, '兵庫県神戸市長田区一里山町');
ok($zip->set_number('6530879')->is_valid_number, '兵庫県神戸市長田区雲雀ケ丘');
ok($zip->set_number('6530881')->is_valid_number, '兵庫県神戸市長田区滝谷町');
ok($zip->set_number('6530882')->is_valid_number, '兵庫県神戸市長田区長田天神町');
ok($zip->set_number('6530883')->is_valid_number, '兵庫県神戸市長田区名倉町');
ok($zip->set_number('6530884')->is_valid_number, '兵庫県神戸市長田区明泉寺町');
ok($zip->set_number('6530885')->is_valid_number, '兵庫県神戸市長田区堀切町');
ok($zip->set_number('6530886')->is_valid_number, '兵庫県神戸市長田区東丸山町');
ok($zip->set_number('6530887')->is_valid_number, '兵庫県神戸市長田区檜川町');
ok($zip->set_number('6530888')->is_valid_number, '兵庫県神戸市長田区源平町');
ok($zip->set_number('6540000')->is_valid_number, '兵庫県神戸市須磨区以下に掲載がない場合');
ok($zip->set_number('6540001')->is_valid_number, '兵庫県神戸市須磨区禅昌寺町');
ok($zip->set_number('6540002')->is_valid_number, '兵庫県神戸市須磨区明神町');
ok($zip->set_number('6540003')->is_valid_number, '兵庫県神戸市須磨区神撫町');
ok($zip->set_number('6540004')->is_valid_number, '兵庫県神戸市須磨区永楽町');
ok($zip->set_number('6540005')->is_valid_number, '兵庫県神戸市須磨区川上町');
ok($zip->set_number('6540006')->is_valid_number, '兵庫県神戸市須磨区養老町');
ok($zip->set_number('6540007')->is_valid_number, '兵庫県神戸市須磨区宝田町');
ok($zip->set_number('6540008')->is_valid_number, '兵庫県神戸市須磨区菊池町');
ok($zip->set_number('6540009')->is_valid_number, '兵庫県神戸市須磨区板宿町');
ok($zip->set_number('6540011')->is_valid_number, '兵庫県神戸市須磨区前池町');
ok($zip->set_number('6540012')->is_valid_number, '兵庫県神戸市須磨区飛松町');
ok($zip->set_number('6540013')->is_valid_number, '兵庫県神戸市須磨区大手町');
ok($zip->set_number('6540014')->is_valid_number, '兵庫県神戸市須磨区若木町');
ok($zip->set_number('6540015')->is_valid_number, '兵庫県神戸市須磨区奥山畑町');
ok($zip->set_number('6540016')->is_valid_number, '兵庫県神戸市須磨区上細沢町');
ok($zip->set_number('6540017')->is_valid_number, '兵庫県神戸市須磨区大手');
ok($zip->set_number('6540018')->is_valid_number, '兵庫県神戸市須磨区東須磨');
ok($zip->set_number('6540021')->is_valid_number, '兵庫県神戸市須磨区平田町');
ok($zip->set_number('6540022')->is_valid_number, '兵庫県神戸市須磨区大黒町');
ok($zip->set_number('6540023')->is_valid_number, '兵庫県神戸市須磨区戎町');
ok($zip->set_number('6540024')->is_valid_number, '兵庫県神戸市須磨区大田町');
ok($zip->set_number('6540025')->is_valid_number, '兵庫県神戸市須磨区寺田町');
ok($zip->set_number('6540026')->is_valid_number, '兵庫県神戸市須磨区大池町');
ok($zip->set_number('6540027')->is_valid_number, '兵庫県神戸市須磨区千歳町');
ok($zip->set_number('6540028')->is_valid_number, '兵庫県神戸市須磨区常盤町');
ok($zip->set_number('6540031')->is_valid_number, '兵庫県神戸市須磨区権現町');
ok($zip->set_number('6540032')->is_valid_number, '兵庫県神戸市須磨区堀池町');
ok($zip->set_number('6540033')->is_valid_number, '兵庫県神戸市須磨区東町');
ok($zip->set_number('6540034')->is_valid_number, '兵庫県神戸市須磨区戸政町');
ok($zip->set_number('6540035')->is_valid_number, '兵庫県神戸市須磨区中島町');
ok($zip->set_number('6540036')->is_valid_number, '兵庫県神戸市須磨区南町');
ok($zip->set_number('6540037')->is_valid_number, '兵庫県神戸市須磨区行平町');
ok($zip->set_number('6540038')->is_valid_number, '兵庫県神戸市須磨区青葉町');
ok($zip->set_number('6540039')->is_valid_number, '兵庫県神戸市須磨区鷹取町');
ok($zip->set_number('6540041')->is_valid_number, '兵庫県神戸市須磨区古川町');
ok($zip->set_number('6540042')->is_valid_number, '兵庫県神戸市須磨区小寺町');
ok($zip->set_number('6540043')->is_valid_number, '兵庫県神戸市須磨区外浜町');
ok($zip->set_number('6540044')->is_valid_number, '兵庫県神戸市須磨区稲葉町');
ok($zip->set_number('6540045')->is_valid_number, '兵庫県神戸市須磨区松風町');
ok($zip->set_number('6540046')->is_valid_number, '兵庫県神戸市須磨区村雨町');
ok($zip->set_number('6540047')->is_valid_number, '兵庫県神戸市須磨区磯馴町');
ok($zip->set_number('6540048')->is_valid_number, '兵庫県神戸市須磨区衣掛町');
ok($zip->set_number('6540049')->is_valid_number, '兵庫県神戸市須磨区若宮町');
ok($zip->set_number('6540051')->is_valid_number, '兵庫県神戸市須磨区月見山本町');
ok($zip->set_number('6540052')->is_valid_number, '兵庫県神戸市須磨区行幸町');
ok($zip->set_number('6540053')->is_valid_number, '兵庫県神戸市須磨区天神町');
ok($zip->set_number('6540054')->is_valid_number, '兵庫県神戸市須磨区須磨本町');
ok($zip->set_number('6540055')->is_valid_number, '兵庫県神戸市須磨区須磨浦通');
ok($zip->set_number('6540061')->is_valid_number, '兵庫県神戸市須磨区高尾台');
ok($zip->set_number('6540062')->is_valid_number, '兵庫県神戸市須磨区水野町');
ok($zip->set_number('6540063')->is_valid_number, '兵庫県神戸市須磨区月見山町');
ok($zip->set_number('6540064')->is_valid_number, '兵庫県神戸市須磨区北町');
ok($zip->set_number('6540065')->is_valid_number, '兵庫県神戸市須磨区離宮前町');
ok($zip->set_number('6540066')->is_valid_number, '兵庫県神戸市須磨区桜木町');
ok($zip->set_number('6540067')->is_valid_number, '兵庫県神戸市須磨区離宮西町');
ok($zip->set_number('6540068')->is_valid_number, '兵庫県神戸市須磨区西須磨');
ok($zip->set_number('6540071')->is_valid_number, '兵庫県神戸市須磨区須磨寺町');
ok($zip->set_number('6540072')->is_valid_number, '兵庫県神戸市須磨区千守町');
ok($zip->set_number('6540073')->is_valid_number, '兵庫県神戸市須磨区関守町');
ok($zip->set_number('6540074')->is_valid_number, '兵庫県神戸市須磨区高倉町');
ok($zip->set_number('6540075')->is_valid_number, '兵庫県神戸市須磨区潮見台町');
ok($zip->set_number('6540076')->is_valid_number, '兵庫県神戸市須磨区一ノ谷町');
ok($zip->set_number('6540081')->is_valid_number, '兵庫県神戸市須磨区高倉台');
ok($zip->set_number('6540101')->is_valid_number, '兵庫県神戸市須磨区白川');
ok($zip->set_number('6540102')->is_valid_number, '兵庫県神戸市須磨区東白川台');
ok($zip->set_number('6540103')->is_valid_number, '兵庫県神戸市須磨区白川台');
ok($zip->set_number('6540111')->is_valid_number, '兵庫県神戸市須磨区車');
ok($zip->set_number('6540112')->is_valid_number, '兵庫県神戸市須磨区若草町');
ok($zip->set_number('6540113')->is_valid_number, '兵庫県神戸市須磨区緑が丘');
ok($zip->set_number('6540114')->is_valid_number, '兵庫県神戸市須磨区桜の杜');
ok($zip->set_number('6540121')->is_valid_number, '兵庫県神戸市須磨区妙法寺');
ok($zip->set_number('6540122')->is_valid_number, '兵庫県神戸市須磨区道正台');
ok($zip->set_number('6540123')->is_valid_number, '兵庫県神戸市須磨区清水台');
ok($zip->set_number('6540131')->is_valid_number, '兵庫県神戸市須磨区横尾');
ok($zip->set_number('6540132')->is_valid_number, '兵庫県神戸市須磨区多井畑南町');
ok($zip->set_number('6540133')->is_valid_number, '兵庫県神戸市須磨区多井畑');
ok($zip->set_number('6540134')->is_valid_number, '兵庫県神戸市須磨区多井畑東町');
ok($zip->set_number('6540141')->is_valid_number, '兵庫県神戸市須磨区竜が台');
ok($zip->set_number('6540142')->is_valid_number, '兵庫県神戸市須磨区友が丘');
ok($zip->set_number('6540143')->is_valid_number, '兵庫県神戸市須磨区菅の台');
ok($zip->set_number('6540151')->is_valid_number, '兵庫県神戸市須磨区北落合');
ok($zip->set_number('6540152')->is_valid_number, '兵庫県神戸市須磨区東落合');
ok($zip->set_number('6540153')->is_valid_number, '兵庫県神戸市須磨区南落合');
ok($zip->set_number('6540154')->is_valid_number, '兵庫県神戸市須磨区中落合');
ok($zip->set_number('6540155')->is_valid_number, '兵庫県神戸市須磨区西落合');
ok($zip->set_number('6540161')->is_valid_number, '兵庫県神戸市須磨区弥栄台');
ok($zip->set_number('6540162')->is_valid_number, '兵庫県神戸市須磨区神の谷');
ok($zip->set_number('6540163')->is_valid_number, '兵庫県神戸市須磨区緑台');
ok($zip->set_number('6550000')->is_valid_number, '兵庫県神戸市垂水区以下に掲載がない場合');
ok($zip->set_number('6550001')->is_valid_number, '兵庫県神戸市垂水区多聞町');
ok($zip->set_number('6550002')->is_valid_number, '兵庫県神戸市垂水区小束山');
ok($zip->set_number('6550003')->is_valid_number, '兵庫県神戸市垂水区小束山本町');
ok($zip->set_number('6550004')->is_valid_number, '兵庫県神戸市垂水区学が丘');
ok($zip->set_number('6550005')->is_valid_number, '兵庫県神戸市垂水区潮見が丘');
ok($zip->set_number('6550006')->is_valid_number, '兵庫県神戸市垂水区本多聞');
ok($zip->set_number('6550007')->is_valid_number, '兵庫県神戸市垂水区多聞台');
ok($zip->set_number('6550008')->is_valid_number, '兵庫県神戸市垂水区小束台');
ok($zip->set_number('6550009')->is_valid_number, '兵庫県神戸市垂水区小束山手');
ok($zip->set_number('6550011')->is_valid_number, '兵庫県神戸市垂水区千鳥が丘');
ok($zip->set_number('6550012')->is_valid_number, '兵庫県神戸市垂水区向陽');
ok($zip->set_number('6550013')->is_valid_number, '兵庫県神戸市垂水区福田');
ok($zip->set_number('6550014')->is_valid_number, '兵庫県神戸市垂水区大町');
ok($zip->set_number('6550015')->is_valid_number, '兵庫県神戸市垂水区野田通');
ok($zip->set_number('6550016')->is_valid_number, '兵庫県神戸市垂水区高丸');
ok($zip->set_number('6550017')->is_valid_number, '兵庫県神戸市垂水区上高丸');
ok($zip->set_number('6550018')->is_valid_number, '兵庫県神戸市垂水区千代が丘');
ok($zip->set_number('6550021')->is_valid_number, '兵庫県神戸市垂水区馬場通');
ok($zip->set_number('6550022')->is_valid_number, '兵庫県神戸市垂水区瑞穂通');
ok($zip->set_number('6550023')->is_valid_number, '兵庫県神戸市垂水区清水通');
ok($zip->set_number('6550024')->is_valid_number, '兵庫県神戸市垂水区御霊町');
ok($zip->set_number('6550025')->is_valid_number, '兵庫県神戸市垂水区瑞ケ丘');
ok($zip->set_number('6550026')->is_valid_number, '兵庫県神戸市垂水区陸ノ町');
ok($zip->set_number('6550027')->is_valid_number, '兵庫県神戸市垂水区神田町');
ok($zip->set_number('6550028')->is_valid_number, '兵庫県神戸市垂水区宮本町');
ok($zip->set_number('6550029')->is_valid_number, '兵庫県神戸市垂水区天ノ下町');
ok($zip->set_number('6550031')->is_valid_number, '兵庫県神戸市垂水区清水が丘');
ok($zip->set_number('6550032')->is_valid_number, '兵庫県神戸市垂水区星が丘');
ok($zip->set_number('6550033')->is_valid_number, '兵庫県神戸市垂水区旭が丘');
ok($zip->set_number('6550034')->is_valid_number, '兵庫県神戸市垂水区仲田');
ok($zip->set_number('6550035')->is_valid_number, '兵庫県神戸市垂水区五色山');
ok($zip->set_number('6550036')->is_valid_number, '兵庫県神戸市垂水区海岸通');
ok($zip->set_number('6550037')->is_valid_number, '兵庫県神戸市垂水区歌敷山');
ok($zip->set_number('6550038')->is_valid_number, '兵庫県神戸市垂水区星陵台');
ok($zip->set_number('6550039')->is_valid_number, '兵庫県神戸市垂水区霞ケ丘');
ok($zip->set_number('6550041')->is_valid_number, '兵庫県神戸市垂水区神陵台');
ok($zip->set_number('6550042')->is_valid_number, '兵庫県神戸市垂水区西脇');
ok($zip->set_number('6550043')->is_valid_number, '兵庫県神戸市垂水区南多聞台');
ok($zip->set_number('6550044')->is_valid_number, '兵庫県神戸市垂水区舞子坂');
ok($zip->set_number('6550045')->is_valid_number, '兵庫県神戸市垂水区北舞子');
ok($zip->set_number('6550046')->is_valid_number, '兵庫県神戸市垂水区舞子台');
ok($zip->set_number('6550047')->is_valid_number, '兵庫県神戸市垂水区東舞子町');
ok($zip->set_number('6550048')->is_valid_number, '兵庫県神戸市垂水区西舞子');
ok($zip->set_number('6550049')->is_valid_number, '兵庫県神戸市垂水区狩口台');
ok($zip->set_number('6550051')->is_valid_number, '兵庫県神戸市垂水区舞多聞西');
ok($zip->set_number('6550052')->is_valid_number, '兵庫県神戸市垂水区舞多聞東');
ok($zip->set_number('6550061')->is_valid_number, '兵庫県神戸市垂水区小束台東');
ok($zip->set_number('6550851')->is_valid_number, '兵庫県神戸市垂水区神和台');
ok($zip->set_number('6550852')->is_valid_number, '兵庫県神戸市垂水区名谷町');
ok($zip->set_number('6550853')->is_valid_number, '兵庫県神戸市垂水区つつじが丘');
ok($zip->set_number('6550854')->is_valid_number, '兵庫県神戸市垂水区桃山台');
ok($zip->set_number('6550855')->is_valid_number, '兵庫県神戸市垂水区みずき台');
ok($zip->set_number('6550861')->is_valid_number, '兵庫県神戸市垂水区下畑町');
ok($zip->set_number('6550862')->is_valid_number, '兵庫県神戸市垂水区朝谷町');
ok($zip->set_number('6550863')->is_valid_number, '兵庫県神戸市垂水区塩屋北町');
ok($zip->set_number('6550864')->is_valid_number, '兵庫県神戸市垂水区塩屋台');
ok($zip->set_number('6550865')->is_valid_number, '兵庫県神戸市垂水区清玄町');
ok($zip->set_number('6550871')->is_valid_number, '兵庫県神戸市垂水区松風台');
ok($zip->set_number('6550872')->is_valid_number, '兵庫県神戸市垂水区塩屋町');
ok($zip->set_number('6550873')->is_valid_number, '兵庫県神戸市垂水区青山台');
ok($zip->set_number('6550874')->is_valid_number, '兵庫県神戸市垂水区美山台');
ok($zip->set_number('6550881')->is_valid_number, '兵庫県神戸市垂水区東垂水町');
ok($zip->set_number('6550882')->is_valid_number, '兵庫県神戸市垂水区乙木');
ok($zip->set_number('6550883')->is_valid_number, '兵庫県神戸市垂水区王居殿');
ok($zip->set_number('6550884')->is_valid_number, '兵庫県神戸市垂水区城が山');
ok($zip->set_number('6550885')->is_valid_number, '兵庫県神戸市垂水区泉が丘');
ok($zip->set_number('6550886')->is_valid_number, '兵庫県神戸市垂水区東垂水');
ok($zip->set_number('6550891')->is_valid_number, '兵庫県神戸市垂水区山手');
ok($zip->set_number('6550892')->is_valid_number, '兵庫県神戸市垂水区平磯');
ok($zip->set_number('6550893')->is_valid_number, '兵庫県神戸市垂水区日向');
ok($zip->set_number('6550894')->is_valid_number, '兵庫県神戸市垂水区川原');
ok($zip->set_number('6550895')->is_valid_number, '兵庫県神戸市垂水区坂上');
ok($zip->set_number('6550896')->is_valid_number, '兵庫県神戸市垂水区中道');
ok($zip->set_number('6560000')->is_valid_number, '兵庫県洲本市以下に掲載がない場合');
ok($zip->set_number('6560001')->is_valid_number, '兵庫県洲本市中川原町厚浜');
ok($zip->set_number('6560002')->is_valid_number, '兵庫県洲本市中川原町中川原');
ok($zip->set_number('6560003')->is_valid_number, '兵庫県洲本市中川原町三木田');
ok($zip->set_number('6560004')->is_valid_number, '兵庫県洲本市中川原町安坂');
ok($zip->set_number('6560005')->is_valid_number, '兵庫県洲本市中川原町市原');
ok($zip->set_number('6560006')->is_valid_number, '兵庫県洲本市中川原町二ツ石');
ok($zip->set_number('6560011')->is_valid_number, '兵庫県洲本市炬口');
ok($zip->set_number('6560012')->is_valid_number, '兵庫県洲本市宇山');
ok($zip->set_number('6560013')->is_valid_number, '兵庫県洲本市下加茂');
ok($zip->set_number('6560014')->is_valid_number, '兵庫県洲本市桑間');
ok($zip->set_number('6560015')->is_valid_number, '兵庫県洲本市上加茂');
ok($zip->set_number('6560016')->is_valid_number, '兵庫県洲本市下内膳');
ok($zip->set_number('6560017')->is_valid_number, '兵庫県洲本市上内膳');
ok($zip->set_number('6560018')->is_valid_number, '兵庫県洲本市奥畑');
ok($zip->set_number('6560021')->is_valid_number, '兵庫県洲本市塩屋');
ok($zip->set_number('6560022')->is_valid_number, '兵庫県洲本市海岸通');
ok($zip->set_number('6560023')->is_valid_number, '兵庫県洲本市小路谷');
ok($zip->set_number('6560024')->is_valid_number, '兵庫県洲本市山手');
ok($zip->set_number('6560025')->is_valid_number, '兵庫県洲本市本町');
ok($zip->set_number('6560026')->is_valid_number, '兵庫県洲本市栄町');
ok($zip->set_number('6560027')->is_valid_number, '兵庫県洲本市港');
ok($zip->set_number('6560031')->is_valid_number, '兵庫県洲本市千草');
ok($zip->set_number('6560041')->is_valid_number, '兵庫県洲本市新村');
ok($zip->set_number('6560042')->is_valid_number, '兵庫県洲本市池内');
ok($zip->set_number('6560043')->is_valid_number, '兵庫県洲本市池田');
ok($zip->set_number('6560044')->is_valid_number, '兵庫県洲本市前平');
ok($zip->set_number('6560045')->is_valid_number, '兵庫県洲本市木戸');
ok($zip->set_number('6560046')->is_valid_number, '兵庫県洲本市金屋');
ok($zip->set_number('6560051')->is_valid_number, '兵庫県洲本市物部');
ok($zip->set_number('6560052')->is_valid_number, '兵庫県洲本市津田');
ok($zip->set_number('6560053')->is_valid_number, '兵庫県洲本市上物部');
ok($zip->set_number('6560054')->is_valid_number, '兵庫県洲本市宇原');
ok($zip->set_number('6560055')->is_valid_number, '兵庫県洲本市大野');
ok($zip->set_number('6560101')->is_valid_number, '兵庫県洲本市納');
ok($zip->set_number('6560111')->is_valid_number, '兵庫県洲本市鮎屋');
ok($zip->set_number('6560121')->is_valid_number, '兵庫県南あわじ市山添');
ok($zip->set_number('6560122')->is_valid_number, '兵庫県南あわじ市広田広田');
ok($zip->set_number('6560131')->is_valid_number, '兵庫県南あわじ市広田中筋');
ok($zip->set_number('6560141')->is_valid_number, '兵庫県南あわじ市中条広田');
ok($zip->set_number('6560142')->is_valid_number, '兵庫県南あわじ市中条徳原');
ok($zip->set_number('6560143')->is_valid_number, '兵庫県南あわじ市中条中筋');
ok($zip->set_number('6560151')->is_valid_number, '兵庫県南あわじ市倭文安住寺');
ok($zip->set_number('6560152')->is_valid_number, '兵庫県南あわじ市倭文長田');
ok($zip->set_number('6560153')->is_valid_number, '兵庫県南あわじ市倭文庄田');
ok($zip->set_number('6560154')->is_valid_number, '兵庫県南あわじ市倭文神道');
ok($zip->set_number('6560161')->is_valid_number, '兵庫県南あわじ市倭文土井');
ok($zip->set_number('6560301')->is_valid_number, '兵庫県南あわじ市松帆北方');
ok($zip->set_number('6560302')->is_valid_number, '兵庫県南あわじ市松帆塩浜');
ok($zip->set_number('6560303')->is_valid_number, '兵庫県南あわじ市松帆江尻');
ok($zip->set_number('6560304')->is_valid_number, '兵庫県南あわじ市松帆古津路');
ok($zip->set_number('6560305')->is_valid_number, '兵庫県南あわじ市松帆北浜');
ok($zip->set_number('6560306')->is_valid_number, '兵庫県南あわじ市松帆慶野');
ok($zip->set_number('6560307')->is_valid_number, '兵庫県南あわじ市松帆檪田');
ok($zip->set_number('6560308')->is_valid_number, '兵庫県南あわじ市松帆宝明寺');
ok($zip->set_number('6560311')->is_valid_number, '兵庫県南あわじ市松帆戒旦寺');
ok($zip->set_number('6560312')->is_valid_number, '兵庫県南あわじ市松帆脇田');
ok($zip->set_number('6560313')->is_valid_number, '兵庫県南あわじ市松帆志知川');
ok($zip->set_number('6560314')->is_valid_number, '兵庫県南あわじ市松帆西路');
ok($zip->set_number('6560315')->is_valid_number, '兵庫県南あわじ市松帆高屋');
ok($zip->set_number('6560321')->is_valid_number, '兵庫県南あわじ市志知');
ok($zip->set_number('6560322')->is_valid_number, '兵庫県南あわじ市志知鈩');
ok($zip->set_number('6560323')->is_valid_number, '兵庫県南あわじ市志知飯山寺');
ok($zip->set_number('6560324')->is_valid_number, '兵庫県南あわじ市志知口');
ok($zip->set_number('6560325')->is_valid_number, '兵庫県南あわじ市志知奥');
ok($zip->set_number('6560326')->is_valid_number, '兵庫県南あわじ市志知南');
ok($zip->set_number('6560327')->is_valid_number, '兵庫県南あわじ市志知北');
ok($zip->set_number('6560328')->is_valid_number, '兵庫県南あわじ市桜花の郷');
ok($zip->set_number('6560331')->is_valid_number, '兵庫県南あわじ市湊里');
ok($zip->set_number('6560332')->is_valid_number, '兵庫県南あわじ市湊');
ok($zip->set_number('6560341')->is_valid_number, '兵庫県南あわじ市津井');
ok($zip->set_number('6560400')->is_valid_number, '兵庫県南あわじ市以下に掲載がない場合');
ok($zip->set_number('6560411')->is_valid_number, '兵庫県南あわじ市倭文高');
ok($zip->set_number('6560412')->is_valid_number, '兵庫県南あわじ市倭文委文');
ok($zip->set_number('6560413')->is_valid_number, '兵庫県南あわじ市倭文流');
ok($zip->set_number('6560421')->is_valid_number, '兵庫県南あわじ市榎列山所');
ok($zip->set_number('6560422')->is_valid_number, '兵庫県南あわじ市榎列上幡多');
ok($zip->set_number('6560423')->is_valid_number, '兵庫県南あわじ市榎列下幡多');
ok($zip->set_number('6560424')->is_valid_number, '兵庫県南あわじ市榎列西川');
ok($zip->set_number('6560425')->is_valid_number, '兵庫県南あわじ市榎列小榎列');
ok($zip->set_number('6560426')->is_valid_number, '兵庫県南あわじ市榎列大榎列');
ok($zip->set_number('6560427')->is_valid_number, '兵庫県南あわじ市榎列松田');
ok($zip->set_number('6560428')->is_valid_number, '兵庫県南あわじ市榎列掃守');
ok($zip->set_number('6560431')->is_valid_number, '兵庫県南あわじ市八木野原');
ok($zip->set_number('6560432')->is_valid_number, '兵庫県南あわじ市八木徳野');
ok($zip->set_number('6560433')->is_valid_number, '兵庫県南あわじ市八木鳥井');
ok($zip->set_number('6560434')->is_valid_number, '兵庫県南あわじ市八木国分');
ok($zip->set_number('6560435')->is_valid_number, '兵庫県南あわじ市八木立石');
ok($zip->set_number('6560436')->is_valid_number, '兵庫県南あわじ市八木新庄');
ok($zip->set_number('6560441')->is_valid_number, '兵庫県南あわじ市八木入田');
ok($zip->set_number('6560442')->is_valid_number, '兵庫県南あわじ市八木養宜中');
ok($zip->set_number('6560443')->is_valid_number, '兵庫県南あわじ市八木養宜上');
ok($zip->set_number('6560444')->is_valid_number, '兵庫県南あわじ市八木大久保');
ok($zip->set_number('6560445')->is_valid_number, '兵庫県南あわじ市八木馬回');
ok($zip->set_number('6560446')->is_valid_number, '兵庫県南あわじ市八木寺内');
ok($zip->set_number('6560451')->is_valid_number, '兵庫県南あわじ市神代社家');
ok($zip->set_number('6560452')->is_valid_number, '兵庫県南あわじ市神代浦壁');
ok($zip->set_number('6560453')->is_valid_number, '兵庫県南あわじ市神代黒道');
ok($zip->set_number('6560454')->is_valid_number, '兵庫県南あわじ市神代喜来');
ok($zip->set_number('6560455')->is_valid_number, '兵庫県南あわじ市神代國衙');
ok($zip->set_number('6560456')->is_valid_number, '兵庫県南あわじ市神代地頭方');
ok($zip->set_number('6560457')->is_valid_number, '兵庫県南あわじ市神代富田');
ok($zip->set_number('6560461')->is_valid_number, '兵庫県南あわじ市市円行寺');
ok($zip->set_number('6560462')->is_valid_number, '兵庫県南あわじ市市青木');
ok($zip->set_number('6560471')->is_valid_number, '兵庫県南あわじ市市十一ケ所');
ok($zip->set_number('6560472')->is_valid_number, '兵庫県南あわじ市市善光寺');
ok($zip->set_number('6560473')->is_valid_number, '兵庫県南あわじ市市小井');
ok($zip->set_number('6560474')->is_valid_number, '兵庫県南あわじ市市市');
ok($zip->set_number('6560475')->is_valid_number, '兵庫県南あわじ市市三條');
ok($zip->set_number('6560476')->is_valid_number, '兵庫県南あわじ市市新');
ok($zip->set_number('6560477')->is_valid_number, '兵庫県南あわじ市市徳長');
ok($zip->set_number('6560478')->is_valid_number, '兵庫県南あわじ市市福永');
ok($zip->set_number('6560481')->is_valid_number, '兵庫県南あわじ市志知松本');
ok($zip->set_number('6560482')->is_valid_number, '兵庫県南あわじ市志知難波');
ok($zip->set_number('6560483')->is_valid_number, '兵庫県南あわじ市志知中島');
ok($zip->set_number('6560484')->is_valid_number, '兵庫県南あわじ市志知佐礼尾');
ok($zip->set_number('6560501')->is_valid_number, '兵庫県南あわじ市福良甲');
ok($zip->set_number('6560502')->is_valid_number, '兵庫県南あわじ市福良乙');
ok($zip->set_number('6560503')->is_valid_number, '兵庫県南あわじ市福良丙');
ok($zip->set_number('6560511')->is_valid_number, '兵庫県南あわじ市賀集八幡');
ok($zip->set_number('6560512')->is_valid_number, '兵庫県南あわじ市賀集立川瀬');
ok($zip->set_number('6560513')->is_valid_number, '兵庫県南あわじ市賀集野田');
ok($zip->set_number('6560514')->is_valid_number, '兵庫県南あわじ市賀集(賀集)');
ok($zip->set_number('6560515')->is_valid_number, '兵庫県南あわじ市賀集鍛治屋');
ok($zip->set_number('6560516')->is_valid_number, '兵庫県南あわじ市賀集福井');
ok($zip->set_number('6560517')->is_valid_number, '兵庫県南あわじ市賀集内ケ原');
ok($zip->set_number('6560517')->is_valid_number, '兵庫県南あわじ市賀集生子');
ok($zip->set_number('6560517')->is_valid_number, '兵庫県南あわじ市賀集長原');
ok($zip->set_number('6560518')->is_valid_number, '兵庫県南あわじ市賀集牛内');
ok($zip->set_number('6560521')->is_valid_number, '兵庫県南あわじ市潮美台');
ok($zip->set_number('6560531')->is_valid_number, '兵庫県南あわじ市北阿万伊賀野');
ok($zip->set_number('6560532')->is_valid_number, '兵庫県南あわじ市北阿万稲田南');
ok($zip->set_number('6560533')->is_valid_number, '兵庫県南あわじ市北阿万新田(北、中)');
ok($zip->set_number('6560534')->is_valid_number, '兵庫県南あわじ市北阿万筒井');
ok($zip->set_number('6560541')->is_valid_number, '兵庫県南あわじ市阿万上町');
ok($zip->set_number('6560542')->is_valid_number, '兵庫県南あわじ市阿万吹上町');
ok($zip->set_number('6560543')->is_valid_number, '兵庫県南あわじ市阿万塩屋町');
ok($zip->set_number('6560544')->is_valid_number, '兵庫県南あわじ市阿万下町');
ok($zip->set_number('6560545')->is_valid_number, '兵庫県南あわじ市阿万西町');
ok($zip->set_number('6560546')->is_valid_number, '兵庫県南あわじ市阿万東町');
ok($zip->set_number('6560551')->is_valid_number, '兵庫県南あわじ市灘');
ok($zip->set_number('6560651')->is_valid_number, '兵庫県南あわじ市伊加利');
ok($zip->set_number('6560661')->is_valid_number, '兵庫県南あわじ市阿那賀');
ok($zip->set_number('6560662')->is_valid_number, '兵庫県南あわじ市阿那賀志知川');
ok($zip->set_number('6560663')->is_valid_number, '兵庫県南あわじ市阿那賀西路');
ok($zip->set_number('6560961')->is_valid_number, '兵庫県南あわじ市沼島');
ok($zip->set_number('6561301')->is_valid_number, '兵庫県洲本市五色町都志');
ok($zip->set_number('6561302')->is_valid_number, '兵庫県洲本市五色町都志米山');
ok($zip->set_number('6561303')->is_valid_number, '兵庫県洲本市五色町都志大宮');
ok($zip->set_number('6561304')->is_valid_number, '兵庫県洲本市五色町都志万歳');
ok($zip->set_number('6561311')->is_valid_number, '兵庫県洲本市五色町鮎原葛尾');
ok($zip->set_number('6561312')->is_valid_number, '兵庫県洲本市五色町鮎原吉田');
ok($zip->set_number('6561313')->is_valid_number, '兵庫県洲本市五色町鮎原西');
ok($zip->set_number('6561314')->is_valid_number, '兵庫県洲本市五色町鮎原鮎の郷');
ok($zip->set_number('6561315')->is_valid_number, '兵庫県洲本市五色町鮎原宇谷');
ok($zip->set_number('6561316')->is_valid_number, '兵庫県洲本市五色町鮎原栢野');
ok($zip->set_number('6561317')->is_valid_number, '兵庫県洲本市五色町鮎原小山田');
ok($zip->set_number('6561318')->is_valid_number, '兵庫県洲本市五色町鮎原神陽');
ok($zip->set_number('6561321')->is_valid_number, '兵庫県洲本市五色町鮎原中邑');
ok($zip->set_number('6561322')->is_valid_number, '兵庫県洲本市五色町鮎原上');
ok($zip->set_number('6561323')->is_valid_number, '兵庫県洲本市五色町鮎原塔下');
ok($zip->set_number('6561324')->is_valid_number, '兵庫県洲本市五色町鮎原三野畑');
ok($zip->set_number('6561325')->is_valid_number, '兵庫県洲本市五色町鮎原南谷');
ok($zip->set_number('6561326')->is_valid_number, '兵庫県洲本市五色町鮎原下');
ok($zip->set_number('6561327')->is_valid_number, '兵庫県洲本市五色町鮎原田処');
ok($zip->set_number('6561331')->is_valid_number, '兵庫県洲本市五色町都志大日');
ok($zip->set_number('6561332')->is_valid_number, '兵庫県洲本市五色町広石北');
ok($zip->set_number('6561333')->is_valid_number, '兵庫県洲本市五色町広石上');
ok($zip->set_number('6561334')->is_valid_number, '兵庫県洲本市五色町広石中');
ok($zip->set_number('6561335')->is_valid_number, '兵庫県洲本市五色町広石下');
ok($zip->set_number('6561336')->is_valid_number, '兵庫県洲本市五色町上堺');
ok($zip->set_number('6561337')->is_valid_number, '兵庫県洲本市五色町下堺');
ok($zip->set_number('6561341')->is_valid_number, '兵庫県洲本市五色町都志角川');
ok($zip->set_number('6561342')->is_valid_number, '兵庫県洲本市五色町鳥飼上');
ok($zip->set_number('6561343')->is_valid_number, '兵庫県洲本市五色町鳥飼中');
ok($zip->set_number('6561344')->is_valid_number, '兵庫県洲本市五色町鳥飼浦');
ok($zip->set_number('6561501')->is_valid_number, '兵庫県淡路市尾崎');
ok($zip->set_number('6561502')->is_valid_number, '兵庫県淡路市新村');
ok($zip->set_number('6561503')->is_valid_number, '兵庫県淡路市遠田');
ok($zip->set_number('6561511')->is_valid_number, '兵庫県淡路市郡家');
ok($zip->set_number('6561512')->is_valid_number, '兵庫県淡路市北山');
ok($zip->set_number('6561521')->is_valid_number, '兵庫県淡路市多賀');
ok($zip->set_number('6561522')->is_valid_number, '兵庫県淡路市下河合');
ok($zip->set_number('6561523')->is_valid_number, '兵庫県淡路市上河合');
ok($zip->set_number('6561524')->is_valid_number, '兵庫県淡路市竹谷');
ok($zip->set_number('6561525')->is_valid_number, '兵庫県淡路市井手');
ok($zip->set_number('6561526')->is_valid_number, '兵庫県淡路市中村');
ok($zip->set_number('6561531')->is_valid_number, '兵庫県淡路市江井');
ok($zip->set_number('6561541')->is_valid_number, '兵庫県淡路市柳沢');
ok($zip->set_number('6561551')->is_valid_number, '兵庫県淡路市高山');
ok($zip->set_number('6561552')->is_valid_number, '兵庫県淡路市入野');
ok($zip->set_number('6561553')->is_valid_number, '兵庫県淡路市山田');
ok($zip->set_number('6561554')->is_valid_number, '兵庫県淡路市深草');
ok($zip->set_number('6561555')->is_valid_number, '兵庫県淡路市南');
ok($zip->set_number('6561556')->is_valid_number, '兵庫県淡路市草香');
ok($zip->set_number('6561557')->is_valid_number, '兵庫県淡路市明神');
ok($zip->set_number('6561558')->is_valid_number, '兵庫県淡路市草香北');
ok($zip->set_number('6561601')->is_valid_number, '兵庫県淡路市黒谷');
ok($zip->set_number('6561602')->is_valid_number, '兵庫県淡路市育波');
ok($zip->set_number('6561603')->is_valid_number, '兵庫県淡路市生田大坪');
ok($zip->set_number('6561604')->is_valid_number, '兵庫県淡路市生田畑');
ok($zip->set_number('6561605')->is_valid_number, '兵庫県淡路市生田田尻');
ok($zip->set_number('6561606')->is_valid_number, '兵庫県淡路市室津');
ok($zip->set_number('6561711')->is_valid_number, '兵庫県淡路市富島');
ok($zip->set_number('6561712')->is_valid_number, '兵庫県淡路市石田');
ok($zip->set_number('6561721')->is_valid_number, '兵庫県淡路市野島蟇浦');
ok($zip->set_number('6561722')->is_valid_number, '兵庫県淡路市野島轟木');
ok($zip->set_number('6561723')->is_valid_number, '兵庫県淡路市野島大川');
ok($zip->set_number('6561724')->is_valid_number, '兵庫県淡路市野島平林');
ok($zip->set_number('6561725')->is_valid_number, '兵庫県淡路市野島江崎(その他)');
ok($zip->set_number('6561726')->is_valid_number, '兵庫県淡路市野島常盤');
ok($zip->set_number('6561727')->is_valid_number, '兵庫県淡路市野島貴船');
ok($zip->set_number('6561731')->is_valid_number, '兵庫県淡路市仁井');
ok($zip->set_number('6561732')->is_valid_number, '兵庫県淡路市小田');
ok($zip->set_number('6561733')->is_valid_number, '兵庫県淡路市長畠');
ok($zip->set_number('6561734')->is_valid_number, '兵庫県淡路市舟木');
ok($zip->set_number('6561735')->is_valid_number, '兵庫県淡路市久野々');
ok($zip->set_number('6561736')->is_valid_number, '兵庫県淡路市小倉');
ok($zip->set_number('6561741')->is_valid_number, '兵庫県淡路市浅野南');
ok($zip->set_number('6561742')->is_valid_number, '兵庫県淡路市浅野神田');
ok($zip->set_number('6561743')->is_valid_number, '兵庫県淡路市斗ノ内');
ok($zip->set_number('6562100')->is_valid_number, '兵庫県淡路市以下に掲載がない場合');
ok($zip->set_number('6562121')->is_valid_number, '兵庫県洲本市安乎町平安浦');
ok($zip->set_number('6562122')->is_valid_number, '兵庫県洲本市安乎町中田');
ok($zip->set_number('6562123')->is_valid_number, '兵庫県洲本市安乎町古宮');
ok($zip->set_number('6562124')->is_valid_number, '兵庫県洲本市安乎町北谷');
ok($zip->set_number('6562125')->is_valid_number, '兵庫県洲本市安乎町山田原');
ok($zip->set_number('6562126')->is_valid_number, '兵庫県洲本市安乎町宮野原');
ok($zip->set_number('6562131')->is_valid_number, '兵庫県淡路市志筑');
ok($zip->set_number('6562132')->is_valid_number, '兵庫県淡路市志筑新島');
ok($zip->set_number('6562133')->is_valid_number, '兵庫県淡路市志筑新浜');
ok($zip->set_number('6562141')->is_valid_number, '兵庫県淡路市塩尾');
ok($zip->set_number('6562142')->is_valid_number, '兵庫県淡路市塩田新島');
ok($zip->set_number('6562143')->is_valid_number, '兵庫県淡路市里');
ok($zip->set_number('6562144')->is_valid_number, '兵庫県淡路市下司');
ok($zip->set_number('6562151')->is_valid_number, '兵庫県淡路市大町畑');
ok($zip->set_number('6562152')->is_valid_number, '兵庫県淡路市木曽上');
ok($zip->set_number('6562153')->is_valid_number, '兵庫県淡路市木曽上畑');
ok($zip->set_number('6562154')->is_valid_number, '兵庫県淡路市木曽下');
ok($zip->set_number('6562155')->is_valid_number, '兵庫県淡路市大町上');
ok($zip->set_number('6562156')->is_valid_number, '兵庫県淡路市大町下');
ok($zip->set_number('6562161')->is_valid_number, '兵庫県淡路市池ノ内');
ok($zip->set_number('6562162')->is_valid_number, '兵庫県淡路市王子');
ok($zip->set_number('6562163')->is_valid_number, '兵庫県淡路市中田');
ok($zip->set_number('6562211')->is_valid_number, '兵庫県淡路市興隆寺');
ok($zip->set_number('6562212')->is_valid_number, '兵庫県淡路市佐野');
ok($zip->set_number('6562213')->is_valid_number, '兵庫県淡路市佐野新島');
ok($zip->set_number('6562214')->is_valid_number, '兵庫県淡路市津名の郷');
ok($zip->set_number('6562221')->is_valid_number, '兵庫県淡路市長沢');
ok($zip->set_number('6562222')->is_valid_number, '兵庫県淡路市野田尾');
ok($zip->set_number('6562223')->is_valid_number, '兵庫県淡路市生穂');
ok($zip->set_number('6562224')->is_valid_number, '兵庫県淡路市大谷');
ok($zip->set_number('6562225')->is_valid_number, '兵庫県淡路市生穂新島');
ok($zip->set_number('6562301')->is_valid_number, '兵庫県淡路市楠本');
ok($zip->set_number('6562302')->is_valid_number, '兵庫県淡路市大磯');
ok($zip->set_number('6562303')->is_valid_number, '兵庫県淡路市小磯');
ok($zip->set_number('6562304')->is_valid_number, '兵庫県淡路市浜');
ok($zip->set_number('6562305')->is_valid_number, '兵庫県淡路市浦');
ok($zip->set_number('6562306')->is_valid_number, '兵庫県淡路市夢舞台');
ok($zip->set_number('6562307')->is_valid_number, '兵庫県淡路市南鵜崎');
ok($zip->set_number('6562311')->is_valid_number, '兵庫県淡路市久留麻');
ok($zip->set_number('6562321')->is_valid_number, '兵庫県淡路市中持');
ok($zip->set_number('6562322')->is_valid_number, '兵庫県淡路市白山');
ok($zip->set_number('6562323')->is_valid_number, '兵庫県淡路市河内');
ok($zip->set_number('6562331')->is_valid_number, '兵庫県淡路市仮屋');
ok($zip->set_number('6562332')->is_valid_number, '兵庫県淡路市谷');
ok($zip->set_number('6562333')->is_valid_number, '兵庫県淡路市下田');
ok($zip->set_number('6562334')->is_valid_number, '兵庫県淡路市釜口');
ok($zip->set_number('6562401')->is_valid_number, '兵庫県淡路市岩屋');
ok($zip->set_number('6562451')->is_valid_number, '兵庫県淡路市野島江崎(13、14番地、10番地の2、5)');
ok($zip->set_number('6562531')->is_valid_number, '兵庫県洲本市相川組');
ok($zip->set_number('6562532')->is_valid_number, '兵庫県洲本市中津川組');
ok($zip->set_number('6562533')->is_valid_number, '兵庫県洲本市畑田組');
ok($zip->set_number('6562541')->is_valid_number, '兵庫県洲本市由良');
ok($zip->set_number('6562542')->is_valid_number, '兵庫県洲本市由良町内田');
ok($zip->set_number('6562543')->is_valid_number, '兵庫県洲本市由良町由良');
ok($zip->set_number('6570000')->is_valid_number, '兵庫県神戸市灘区以下に掲載がない場合');
ok($zip->set_number('6570001')->is_valid_number, '兵庫県神戸市灘区高羽');
ok($zip->set_number('6570002')->is_valid_number, '兵庫県神戸市灘区篠原(その他)');
ok($zip->set_number('6570011')->is_valid_number, '兵庫県神戸市灘区鶴甲');
ok($zip->set_number('6570012')->is_valid_number, '兵庫県神戸市灘区一王山町');
ok($zip->set_number('6570013')->is_valid_number, '兵庫県神戸市灘区六甲台町');
ok($zip->set_number('6570014')->is_valid_number, '兵庫県神戸市灘区大土平町');
ok($zip->set_number('6570015')->is_valid_number, '兵庫県神戸市灘区篠原伯母野山町');
ok($zip->set_number('6570016')->is_valid_number, '兵庫県神戸市灘区篠原台');
ok($zip->set_number('6570017')->is_valid_number, '兵庫県神戸市灘区大月台');
ok($zip->set_number('6570018')->is_valid_number, '兵庫県神戸市灘区水車新田');
ok($zip->set_number('6570021')->is_valid_number, '兵庫県神戸市灘区桜ケ丘町');
ok($zip->set_number('6570022')->is_valid_number, '兵庫県神戸市灘区土山町');
ok($zip->set_number('6570023')->is_valid_number, '兵庫県神戸市灘区高羽町');
ok($zip->set_number('6570024')->is_valid_number, '兵庫県神戸市灘区楠丘町');
ok($zip->set_number('6570025')->is_valid_number, '兵庫県神戸市灘区高徳町');
ok($zip->set_number('6570026')->is_valid_number, '兵庫県神戸市灘区弓木町');
ok($zip->set_number('6570027')->is_valid_number, '兵庫県神戸市灘区永手町');
ok($zip->set_number('6570028')->is_valid_number, '兵庫県神戸市灘区森後町');
ok($zip->set_number('6570029')->is_valid_number, '兵庫県神戸市灘区日尾町');
ok($zip->set_number('6570031')->is_valid_number, '兵庫県神戸市灘区大和町');
ok($zip->set_number('6570032')->is_valid_number, '兵庫県神戸市灘区中郷町');
ok($zip->set_number('6570033')->is_valid_number, '兵庫県神戸市灘区徳井町');
ok($zip->set_number('6570034')->is_valid_number, '兵庫県神戸市灘区記田町');
ok($zip->set_number('6570035')->is_valid_number, '兵庫県神戸市灘区友田町');
ok($zip->set_number('6570036')->is_valid_number, '兵庫県神戸市灘区桜口町');
ok($zip->set_number('6570037')->is_valid_number, '兵庫県神戸市灘区備後町');
ok($zip->set_number('6570038')->is_valid_number, '兵庫県神戸市灘区深田町');
ok($zip->set_number('6570041')->is_valid_number, '兵庫県神戸市灘区琵琶町');
ok($zip->set_number('6570042')->is_valid_number, '兵庫県神戸市灘区烏帽子町');
ok($zip->set_number('6570043')->is_valid_number, '兵庫県神戸市灘区大石東町');
ok($zip->set_number('6570044')->is_valid_number, '兵庫県神戸市灘区鹿ノ下通');
ok($zip->set_number('6570045')->is_valid_number, '兵庫県神戸市灘区下河原通');
ok($zip->set_number('6570051')->is_valid_number, '兵庫県神戸市灘区八幡町');
ok($zip->set_number('6570052')->is_valid_number, '兵庫県神戸市灘区神前町');
ok($zip->set_number('6570053')->is_valid_number, '兵庫県神戸市灘区六甲町');
ok($zip->set_number('6570054')->is_valid_number, '兵庫県神戸市灘区稗原町');
ok($zip->set_number('6570055')->is_valid_number, '兵庫県神戸市灘区上河原通');
ok($zip->set_number('6570056')->is_valid_number, '兵庫県神戸市灘区千旦通');
ok($zip->set_number('6570057')->is_valid_number, '兵庫県神戸市灘区神ノ木通');
ok($zip->set_number('6570058')->is_valid_number, '兵庫県神戸市灘区将軍通');
ok($zip->set_number('6570059')->is_valid_number, '兵庫県神戸市灘区篠原南町');
ok($zip->set_number('6570061')->is_valid_number, '兵庫県神戸市灘区赤松町');
ok($zip->set_number('6570062')->is_valid_number, '兵庫県神戸市灘区寺口町');
ok($zip->set_number('6570063')->is_valid_number, '兵庫県神戸市灘区曾和町');
ok($zip->set_number('6570064')->is_valid_number, '兵庫県神戸市灘区山田町');
ok($zip->set_number('6570065')->is_valid_number, '兵庫県神戸市灘区宮山町');
ok($zip->set_number('6570066')->is_valid_number, '兵庫県神戸市灘区篠原中町');
ok($zip->set_number('6570067')->is_valid_number, '兵庫県神戸市灘区篠原本町');
ok($zip->set_number('6570068')->is_valid_number, '兵庫県神戸市灘区篠原北町');
ok($zip->set_number('6570101')->is_valid_number, '兵庫県神戸市灘区六甲山町');
ok($zip->set_number('6570102')->is_valid_number, '兵庫県神戸市灘区畑原(ノタ山)');
ok($zip->set_number('6570103')->is_valid_number, '兵庫県神戸市灘区上野(小ヤバ三ノ休原)');
ok($zip->set_number('6570104')->is_valid_number, '兵庫県神戸市灘区摩耶山');
ok($zip->set_number('6570105')->is_valid_number, '兵庫県神戸市灘区摩耶山町');
ok($zip->set_number('6570111')->is_valid_number, '兵庫県神戸市東灘区本山町森(748-1番地)');
ok($zip->set_number('6570801')->is_valid_number, '兵庫県神戸市灘区五毛');
ok($zip->set_number('6570802')->is_valid_number, '兵庫県神戸市灘区原田');
ok($zip->set_number('6570803')->is_valid_number, '兵庫県神戸市灘区岩屋');
ok($zip->set_number('6570804')->is_valid_number, '兵庫県神戸市灘区城の下通');
ok($zip->set_number('6570805')->is_valid_number, '兵庫県神戸市灘区青谷町');
ok($zip->set_number('6570811')->is_valid_number, '兵庫県神戸市灘区長峰台');
ok($zip->set_number('6570812')->is_valid_number, '兵庫県神戸市灘区箕岡通');
ok($zip->set_number('6570813')->is_valid_number, '兵庫県神戸市灘区高尾通');
ok($zip->set_number('6570814')->is_valid_number, '兵庫県神戸市灘区五毛通');
ok($zip->set_number('6570815')->is_valid_number, '兵庫県神戸市灘区薬師通');
ok($zip->set_number('6570816')->is_valid_number, '兵庫県神戸市灘区国玉通');
ok($zip->set_number('6570817')->is_valid_number, '兵庫県神戸市灘区上野通');
ok($zip->set_number('6570821')->is_valid_number, '兵庫県神戸市灘区赤坂通');
ok($zip->set_number('6570822')->is_valid_number, '兵庫県神戸市灘区畑原通');
ok($zip->set_number('6570823')->is_valid_number, '兵庫県神戸市灘区天城通');
ok($zip->set_number('6570824')->is_valid_number, '兵庫県神戸市灘区福住通');
ok($zip->set_number('6570825')->is_valid_number, '兵庫県神戸市灘区中原通');
ok($zip->set_number('6570826')->is_valid_number, '兵庫県神戸市灘区倉石通');
ok($zip->set_number('6570831')->is_valid_number, '兵庫県神戸市灘区水道筋');
ok($zip->set_number('6570832')->is_valid_number, '兵庫県神戸市灘区岸地通');
ok($zip->set_number('6570833')->is_valid_number, '兵庫県神戸市灘区大内通');
ok($zip->set_number('6570834')->is_valid_number, '兵庫県神戸市灘区泉通');
ok($zip->set_number('6570835')->is_valid_number, '兵庫県神戸市灘区灘北通');
ok($zip->set_number('6570836')->is_valid_number, '兵庫県神戸市灘区城内通');
ok($zip->set_number('6570837')->is_valid_number, '兵庫県神戸市灘区原田通');
ok($zip->set_number('6570838')->is_valid_number, '兵庫県神戸市灘区王子町');
ok($zip->set_number('6570841')->is_valid_number, '兵庫県神戸市灘区灘南通');
ok($zip->set_number('6570842')->is_valid_number, '兵庫県神戸市灘区船寺通');
ok($zip->set_number('6570843')->is_valid_number, '兵庫県神戸市灘区大石北町');
ok($zip->set_number('6570844')->is_valid_number, '兵庫県神戸市灘区都通');
ok($zip->set_number('6570845')->is_valid_number, '兵庫県神戸市灘区岩屋中町');
ok($zip->set_number('6570846')->is_valid_number, '兵庫県神戸市灘区岩屋北町');
ok($zip->set_number('6570851')->is_valid_number, '兵庫県神戸市灘区味泥町');
ok($zip->set_number('6570852')->is_valid_number, '兵庫県神戸市灘区大石南町');
ok($zip->set_number('6570853')->is_valid_number, '兵庫県神戸市灘区灘浜町');
ok($zip->set_number('6570854')->is_valid_number, '兵庫県神戸市灘区摩耶埠頭');
ok($zip->set_number('6570855')->is_valid_number, '兵庫県神戸市灘区摩耶海岸通');
ok($zip->set_number('6570856')->is_valid_number, '兵庫県神戸市灘区岩屋南町');
ok($zip->set_number('6570861')->is_valid_number, '兵庫県神戸市灘区新在家北町');
ok($zip->set_number('6570862')->is_valid_number, '兵庫県神戸市灘区浜田町');
ok($zip->set_number('6570863')->is_valid_number, '兵庫県神戸市灘区灘浜東町');
ok($zip->set_number('6570864')->is_valid_number, '兵庫県神戸市灘区新在家南町');
ok($zip->set_number('6580000')->is_valid_number, '兵庫県神戸市東灘区以下に掲載がない場合');
ok($zip->set_number('6580001')->is_valid_number, '兵庫県神戸市東灘区森北町');
ok($zip->set_number('6580002')->is_valid_number, '兵庫県神戸市東灘区甲南台');
ok($zip->set_number('6580003')->is_valid_number, '兵庫県神戸市東灘区本山北町');
ok($zip->set_number('6580004')->is_valid_number, '兵庫県神戸市東灘区本山町田辺');
ok($zip->set_number('6580005')->is_valid_number, '兵庫県神戸市東灘区本山町北畑');
ok($zip->set_number('6580011')->is_valid_number, '兵庫県神戸市東灘区森南町');
ok($zip->set_number('6580012')->is_valid_number, '兵庫県神戸市東灘区本庄町');
ok($zip->set_number('6580013')->is_valid_number, '兵庫県神戸市東灘区深江北町');
ok($zip->set_number('6580014')->is_valid_number, '兵庫県神戸市東灘区北青木');
ok($zip->set_number('6580015')->is_valid_number, '兵庫県神戸市東灘区本山南町');
ok($zip->set_number('6580016')->is_valid_number, '兵庫県神戸市東灘区本山中町');
ok($zip->set_number('6580021')->is_valid_number, '兵庫県神戸市東灘区深江本町');
ok($zip->set_number('6580022')->is_valid_number, '兵庫県神戸市東灘区深江南町');
ok($zip->set_number('6580023')->is_valid_number, '兵庫県神戸市東灘区深江浜町');
ok($zip->set_number('6580024')->is_valid_number, '兵庫県神戸市東灘区魚崎浜町');
ok($zip->set_number('6580025')->is_valid_number, '兵庫県神戸市東灘区魚崎南町');
ok($zip->set_number('6580026')->is_valid_number, '兵庫県神戸市東灘区魚崎西町');
ok($zip->set_number('6580027')->is_valid_number, '兵庫県神戸市東灘区青木');
ok($zip->set_number('6580031')->is_valid_number, '兵庫県神戸市東灘区向洋町東');
ok($zip->set_number('6580032')->is_valid_number, '兵庫県神戸市東灘区向洋町中');
ok($zip->set_number('6580033')->is_valid_number, '兵庫県神戸市東灘区向洋町西');
ok($zip->set_number('6580041')->is_valid_number, '兵庫県神戸市東灘区住吉南町');
ok($zip->set_number('6580042')->is_valid_number, '兵庫県神戸市東灘区住吉浜町');
ok($zip->set_number('6580043')->is_valid_number, '兵庫県神戸市東灘区御影浜町');
ok($zip->set_number('6580044')->is_valid_number, '兵庫県神戸市東灘区御影塚町');
ok($zip->set_number('6580045')->is_valid_number, '兵庫県神戸市東灘区御影石町');
ok($zip->set_number('6580046')->is_valid_number, '兵庫県神戸市東灘区御影本町');
ok($zip->set_number('6580047')->is_valid_number, '兵庫県神戸市東灘区御影');
ok($zip->set_number('6580048')->is_valid_number, '兵庫県神戸市東灘区御影郡家');
ok($zip->set_number('6580051')->is_valid_number, '兵庫県神戸市東灘区住吉本町');
ok($zip->set_number('6580052')->is_valid_number, '兵庫県神戸市東灘区住吉東町');
ok($zip->set_number('6580053')->is_valid_number, '兵庫県神戸市東灘区住吉宮町');
ok($zip->set_number('6580054')->is_valid_number, '兵庫県神戸市東灘区御影中町');
ok($zip->set_number('6580061')->is_valid_number, '兵庫県神戸市東灘区本山町田中');
ok($zip->set_number('6580062')->is_valid_number, '兵庫県神戸市東灘区住吉台');
ok($zip->set_number('6580063')->is_valid_number, '兵庫県神戸市東灘区住吉山手');
ok($zip->set_number('6580064')->is_valid_number, '兵庫県神戸市東灘区鴨子ケ原');
ok($zip->set_number('6580065')->is_valid_number, '兵庫県神戸市東灘区御影山手');
ok($zip->set_number('6580066')->is_valid_number, '兵庫県神戸市東灘区渦森台');
ok($zip->set_number('6580071')->is_valid_number, '兵庫県神戸市東灘区本山町岡本');
ok($zip->set_number('6580072')->is_valid_number, '兵庫県神戸市東灘区岡本');
ok($zip->set_number('6580073')->is_valid_number, '兵庫県神戸市東灘区西岡本');
ok($zip->set_number('6580081')->is_valid_number, '兵庫県神戸市東灘区田中町');
ok($zip->set_number('6580082')->is_valid_number, '兵庫県神戸市東灘区魚崎北町');
ok($zip->set_number('6580083')->is_valid_number, '兵庫県神戸市東灘区魚崎中町');
ok($zip->set_number('6580084')->is_valid_number, '兵庫県神戸市東灘区甲南町');
ok($zip->set_number('6590000')->is_valid_number, '兵庫県芦屋市以下に掲載がない場合');
ok($zip->set_number('6590001')->is_valid_number, '兵庫県芦屋市剣谷');
ok($zip->set_number('6590002')->is_valid_number, '兵庫県芦屋市奥山');
ok($zip->set_number('6590003')->is_valid_number, '兵庫県芦屋市奥池町');
ok($zip->set_number('6590004')->is_valid_number, '兵庫県芦屋市奥池南町');
ok($zip->set_number('6590011')->is_valid_number, '兵庫県芦屋市六麓荘町');
ok($zip->set_number('6590012')->is_valid_number, '兵庫県芦屋市朝日ケ丘町');
ok($zip->set_number('6590013')->is_valid_number, '兵庫県芦屋市岩園町');
ok($zip->set_number('6590014')->is_valid_number, '兵庫県芦屋市翠ケ丘町');
ok($zip->set_number('6590015')->is_valid_number, '兵庫県芦屋市楠町');
ok($zip->set_number('6590016')->is_valid_number, '兵庫県芦屋市親王塚町');
ok($zip->set_number('6590021')->is_valid_number, '兵庫県芦屋市春日町');
ok($zip->set_number('6590022')->is_valid_number, '兵庫県芦屋市打出町');
ok($zip->set_number('6590023')->is_valid_number, '兵庫県芦屋市大東町');
ok($zip->set_number('6590024')->is_valid_number, '兵庫県芦屋市南宮町');
ok($zip->set_number('6590025')->is_valid_number, '兵庫県芦屋市浜町');
ok($zip->set_number('6590026')->is_valid_number, '兵庫県芦屋市西蔵町');
ok($zip->set_number('6590027')->is_valid_number, '兵庫県芦屋市若宮町');
ok($zip->set_number('6590028')->is_valid_number, '兵庫県芦屋市打出小槌町');
ok($zip->set_number('6590031')->is_valid_number, '兵庫県芦屋市新浜町');
ok($zip->set_number('6590032')->is_valid_number, '兵庫県芦屋市浜風町');
ok($zip->set_number('6590033')->is_valid_number, '兵庫県芦屋市高浜町');
ok($zip->set_number('6590034')->is_valid_number, '兵庫県芦屋市陽光町');
ok($zip->set_number('6590035')->is_valid_number, '兵庫県芦屋市海洋町');
ok($zip->set_number('6590036')->is_valid_number, '兵庫県芦屋市涼風町');
ok($zip->set_number('6590037')->is_valid_number, '兵庫県芦屋市南浜町');
ok($zip->set_number('6590041')->is_valid_number, '兵庫県芦屋市若葉町');
ok($zip->set_number('6590042')->is_valid_number, '兵庫県芦屋市緑町');
ok($zip->set_number('6590043')->is_valid_number, '兵庫県芦屋市潮見町');
ok($zip->set_number('6590051')->is_valid_number, '兵庫県芦屋市呉川町');
ok($zip->set_number('6590052')->is_valid_number, '兵庫県芦屋市伊勢町');
ok($zip->set_number('6590053')->is_valid_number, '兵庫県芦屋市松浜町');
ok($zip->set_number('6590054')->is_valid_number, '兵庫県芦屋市浜芦屋町');
ok($zip->set_number('6590055')->is_valid_number, '兵庫県芦屋市竹園町');
ok($zip->set_number('6590061')->is_valid_number, '兵庫県芦屋市上宮川町');
ok($zip->set_number('6590062')->is_valid_number, '兵庫県芦屋市宮塚町');
ok($zip->set_number('6590063')->is_valid_number, '兵庫県芦屋市宮川町');
ok($zip->set_number('6590064')->is_valid_number, '兵庫県芦屋市精道町');
ok($zip->set_number('6590065')->is_valid_number, '兵庫県芦屋市公光町');
ok($zip->set_number('6590066')->is_valid_number, '兵庫県芦屋市大桝町');
ok($zip->set_number('6590067')->is_valid_number, '兵庫県芦屋市茶屋之町');
ok($zip->set_number('6590068')->is_valid_number, '兵庫県芦屋市業平町');
ok($zip->set_number('6590071')->is_valid_number, '兵庫県芦屋市前田町');
ok($zip->set_number('6590072')->is_valid_number, '兵庫県芦屋市川西町');
ok($zip->set_number('6590073')->is_valid_number, '兵庫県芦屋市平田北町');
ok($zip->set_number('6590074')->is_valid_number, '兵庫県芦屋市平田町');
ok($zip->set_number('6590075')->is_valid_number, '兵庫県芦屋市津知町');
ok($zip->set_number('6590076')->is_valid_number, '兵庫県芦屋市清水町');
ok($zip->set_number('6590081')->is_valid_number, '兵庫県芦屋市城山');
ok($zip->set_number('6590082')->is_valid_number, '兵庫県芦屋市山芦屋町');
ok($zip->set_number('6590083')->is_valid_number, '兵庫県芦屋市西山町');
ok($zip->set_number('6590084')->is_valid_number, '兵庫県芦屋市月若町');
ok($zip->set_number('6590085')->is_valid_number, '兵庫県芦屋市西芦屋町');
ok($zip->set_number('6590086')->is_valid_number, '兵庫県芦屋市三条南町');
ok($zip->set_number('6590087')->is_valid_number, '兵庫県芦屋市三条町');
ok($zip->set_number('6590091')->is_valid_number, '兵庫県芦屋市東山町');
ok($zip->set_number('6590092')->is_valid_number, '兵庫県芦屋市大原町');
ok($zip->set_number('6590093')->is_valid_number, '兵庫県芦屋市船戸町');
ok($zip->set_number('6590094')->is_valid_number, '兵庫県芦屋市松ノ内町');
ok($zip->set_number('6590095')->is_valid_number, '兵庫県芦屋市東芦屋町');
ok($zip->set_number('6590096')->is_valid_number, '兵庫県芦屋市山手町');
ok($zip->set_number('6600000')->is_valid_number, '兵庫県尼崎市以下に掲載がない場合');
ok($zip->set_number('6600051')->is_valid_number, '兵庫県尼崎市東七松町');
ok($zip->set_number('6600052')->is_valid_number, '兵庫県尼崎市七松町');
ok($zip->set_number('6600053')->is_valid_number, '兵庫県尼崎市南七松町');
ok($zip->set_number('6600054')->is_valid_number, '兵庫県尼崎市西立花町');
ok($zip->set_number('6600055')->is_valid_number, '兵庫県尼崎市稲葉元町');
ok($zip->set_number('6600061')->is_valid_number, '兵庫県尼崎市蓬川荘園');
ok($zip->set_number('6600062')->is_valid_number, '兵庫県尼崎市浜田町');
ok($zip->set_number('6600063')->is_valid_number, '兵庫県尼崎市大庄北');
ok($zip->set_number('6600064')->is_valid_number, '兵庫県尼崎市稲葉荘');
ok($zip->set_number('6600071')->is_valid_number, '兵庫県尼崎市崇徳院');
ok($zip->set_number('6600072')->is_valid_number, '兵庫県尼崎市大庄川田町');
ok($zip->set_number('6600073')->is_valid_number, '兵庫県尼崎市菜切山町');
ok($zip->set_number('6600074')->is_valid_number, '兵庫県尼崎市琴浦町');
ok($zip->set_number('6600075')->is_valid_number, '兵庫県尼崎市大庄中通');
ok($zip->set_number('6600076')->is_valid_number, '兵庫県尼崎市大島');
ok($zip->set_number('6600077')->is_valid_number, '兵庫県尼崎市大庄西町');
ok($zip->set_number('6600081')->is_valid_number, '兵庫県尼崎市蓬川町');
ok($zip->set_number('6600082')->is_valid_number, '兵庫県尼崎市水明町');
ok($zip->set_number('6600083')->is_valid_number, '兵庫県尼崎市道意町');
ok($zip->set_number('6600084')->is_valid_number, '兵庫県尼崎市武庫川町');
ok($zip->set_number('6600085')->is_valid_number, '兵庫県尼崎市元浜町');
ok($zip->set_number('6600086')->is_valid_number, '兵庫県尼崎市丸島町');
ok($zip->set_number('6600087')->is_valid_number, '兵庫県尼崎市平左衛門町');
ok($zip->set_number('6600091')->is_valid_number, '兵庫県尼崎市中浜町');
ok($zip->set_number('6600092')->is_valid_number, '兵庫県尼崎市鶴町');
ok($zip->set_number('6600093')->is_valid_number, '兵庫県尼崎市西海岸町');
ok($zip->set_number('6600094')->is_valid_number, '兵庫県尼崎市末広町');
ok($zip->set_number('6600095')->is_valid_number, '兵庫県尼崎市大浜町');
ok($zip->set_number('6600096')->is_valid_number, '兵庫県尼崎市扇町');
ok($zip->set_number('6600801')->is_valid_number, '兵庫県尼崎市長洲東通');
ok($zip->set_number('6600802')->is_valid_number, '兵庫県尼崎市長洲中通');
ok($zip->set_number('6600803')->is_valid_number, '兵庫県尼崎市長洲本通');
ok($zip->set_number('6600804')->is_valid_number, '兵庫県尼崎市北大物町');
ok($zip->set_number('6600805')->is_valid_number, '兵庫県尼崎市西長洲町');
ok($zip->set_number('6600806')->is_valid_number, '兵庫県尼崎市金楽寺町');
ok($zip->set_number('6600807')->is_valid_number, '兵庫県尼崎市長洲西通');
ok($zip->set_number('6600808')->is_valid_number, '兵庫県尼崎市潮江(1丁目1番、5丁目1番)');
ok($zip->set_number('6600811')->is_valid_number, '兵庫県尼崎市常光寺');
ok($zip->set_number('6600812')->is_valid_number, '兵庫県尼崎市今福');
ok($zip->set_number('6600813')->is_valid_number, '兵庫県尼崎市杭瀬寺島');
ok($zip->set_number('6600814')->is_valid_number, '兵庫県尼崎市杭瀬本町');
ok($zip->set_number('6600815')->is_valid_number, '兵庫県尼崎市杭瀬北新町');
ok($zip->set_number('6600821')->is_valid_number, '兵庫県尼崎市梶ケ島');
ok($zip->set_number('6600822')->is_valid_number, '兵庫県尼崎市杭瀬南新町');
ok($zip->set_number('6600823')->is_valid_number, '兵庫県尼崎市大物町');
ok($zip->set_number('6600824')->is_valid_number, '兵庫県尼崎市東本町');
ok($zip->set_number('6600825')->is_valid_number, '兵庫県尼崎市南城内');
ok($zip->set_number('6600826')->is_valid_number, '兵庫県尼崎市北城内');
ok($zip->set_number('6600827')->is_valid_number, '兵庫県尼崎市西大物町');
ok($zip->set_number('6600828')->is_valid_number, '兵庫県尼崎市東大物町');
ok($zip->set_number('6600831')->is_valid_number, '兵庫県尼崎市東松島町');
ok($zip->set_number('6600832')->is_valid_number, '兵庫県尼崎市東初島町');
ok($zip->set_number('6600833')->is_valid_number, '兵庫県尼崎市南初島町');
ok($zip->set_number('6600834')->is_valid_number, '兵庫県尼崎市北初島町');
ok($zip->set_number('6600835')->is_valid_number, '兵庫県尼崎市東向島東之町');
ok($zip->set_number('6600837')->is_valid_number, '兵庫県尼崎市西松島町');
ok($zip->set_number('6600841')->is_valid_number, '兵庫県尼崎市東高洲町');
ok($zip->set_number('6600842')->is_valid_number, '兵庫県尼崎市大高洲町');
ok($zip->set_number('6600843')->is_valid_number, '兵庫県尼崎市東海岸町');
ok($zip->set_number('6600844')->is_valid_number, '兵庫県尼崎市東浜町');
ok($zip->set_number('6600845')->is_valid_number, '兵庫県尼崎市西高洲町');
ok($zip->set_number('6600846')->is_valid_number, '兵庫県尼崎市船出');
ok($zip->set_number('6600851')->is_valid_number, '兵庫県尼崎市中在家町');
ok($zip->set_number('6600856')->is_valid_number, '兵庫県尼崎市東向島西之町');
ok($zip->set_number('6600857')->is_valid_number, '兵庫県尼崎市西向島町');
ok($zip->set_number('6600858')->is_valid_number, '兵庫県尼崎市築地');
ok($zip->set_number('6600861')->is_valid_number, '兵庫県尼崎市御園町');
ok($zip->set_number('6600862')->is_valid_number, '兵庫県尼崎市開明町');
ok($zip->set_number('6600863')->is_valid_number, '兵庫県尼崎市西本町北通');
ok($zip->set_number('6600864')->is_valid_number, '兵庫県尼崎市東桜木町');
ok($zip->set_number('6600865')->is_valid_number, '兵庫県尼崎市西桜木町');
ok($zip->set_number('6600866')->is_valid_number, '兵庫県尼崎市汐町');
ok($zip->set_number('6600867')->is_valid_number, '兵庫県尼崎市寺町');
ok($zip->set_number('6600868')->is_valid_number, '兵庫県尼崎市西御園町');
ok($zip->set_number('6600871')->is_valid_number, '兵庫県尼崎市建家町');
ok($zip->set_number('6600872')->is_valid_number, '兵庫県尼崎市玄番北之町');
ok($zip->set_number('6600873')->is_valid_number, '兵庫県尼崎市玄番南之町');
ok($zip->set_number('6600874')->is_valid_number, '兵庫県尼崎市西本町');
ok($zip->set_number('6600875')->is_valid_number, '兵庫県尼崎市南竹谷町');
ok($zip->set_number('6600876')->is_valid_number, '兵庫県尼崎市竹谷町');
ok($zip->set_number('6600877')->is_valid_number, '兵庫県尼崎市宮内町');
ok($zip->set_number('6600878')->is_valid_number, '兵庫県尼崎市北竹谷町');
ok($zip->set_number('6600881')->is_valid_number, '兵庫県尼崎市昭和通');
ok($zip->set_number('6600882')->is_valid_number, '兵庫県尼崎市昭和南通');
ok($zip->set_number('6600883')->is_valid_number, '兵庫県尼崎市神田北通');
ok($zip->set_number('6600884')->is_valid_number, '兵庫県尼崎市神田中通');
ok($zip->set_number('6600885')->is_valid_number, '兵庫県尼崎市神田南通');
ok($zip->set_number('6600891')->is_valid_number, '兵庫県尼崎市扶桑町');
ok($zip->set_number('6600892')->is_valid_number, '兵庫県尼崎市東難波町');
ok($zip->set_number('6600893')->is_valid_number, '兵庫県尼崎市西難波町');
ok($zip->set_number('6610001')->is_valid_number, '兵庫県尼崎市塚口本町');
ok($zip->set_number('6610002')->is_valid_number, '兵庫県尼崎市塚口町');
ok($zip->set_number('6610003')->is_valid_number, '兵庫県尼崎市富松町');
ok($zip->set_number('6610011')->is_valid_number, '兵庫県尼崎市東塚口町');
ok($zip->set_number('6610012')->is_valid_number, '兵庫県尼崎市南塚口町');
ok($zip->set_number('6610013')->is_valid_number, '兵庫県尼崎市栗山町');
ok($zip->set_number('6610014')->is_valid_number, '兵庫県尼崎市上ノ島町');
ok($zip->set_number('6610021')->is_valid_number, '兵庫県尼崎市名神町');
ok($zip->set_number('6610022')->is_valid_number, '兵庫県尼崎市尾浜町');
ok($zip->set_number('6610023')->is_valid_number, '兵庫県尼崎市大西町');
ok($zip->set_number('6610024')->is_valid_number, '兵庫県尼崎市三反田町');
ok($zip->set_number('6610025')->is_valid_number, '兵庫県尼崎市立花町');
ok($zip->set_number('6610026')->is_valid_number, '兵庫県尼崎市水堂町');
ok($zip->set_number('6610031')->is_valid_number, '兵庫県尼崎市武庫之荘本町');
ok($zip->set_number('6610032')->is_valid_number, '兵庫県尼崎市武庫之荘東');
ok($zip->set_number('6610033')->is_valid_number, '兵庫県尼崎市南武庫之荘');
ok($zip->set_number('6610034')->is_valid_number, '兵庫県尼崎市武庫之荘西');
ok($zip->set_number('6610035')->is_valid_number, '兵庫県尼崎市武庫之荘');
ok($zip->set_number('6610041')->is_valid_number, '兵庫県尼崎市武庫の里');
ok($zip->set_number('6610042')->is_valid_number, '兵庫県尼崎市常吉');
ok($zip->set_number('6610043')->is_valid_number, '兵庫県尼崎市武庫元町');
ok($zip->set_number('6610044')->is_valid_number, '兵庫県尼崎市武庫町');
ok($zip->set_number('6610045')->is_valid_number, '兵庫県尼崎市武庫豊町');
ok($zip->set_number('6610046')->is_valid_number, '兵庫県尼崎市常松');
ok($zip->set_number('6610047')->is_valid_number, '兵庫県尼崎市西昆陽');
ok($zip->set_number('6610951')->is_valid_number, '兵庫県尼崎市田能');
ok($zip->set_number('6610952')->is_valid_number, '兵庫県尼崎市椎堂');
ok($zip->set_number('6610953')->is_valid_number, '兵庫県尼崎市東園田町');
ok($zip->set_number('6610961')->is_valid_number, '兵庫県尼崎市戸ノ内町');
ok($zip->set_number('6610962')->is_valid_number, '兵庫県尼崎市額田町');
ok($zip->set_number('6610963')->is_valid_number, '兵庫県尼崎市高田町');
ok($zip->set_number('6610964')->is_valid_number, '兵庫県尼崎市神崎町');
ok($zip->set_number('6610965')->is_valid_number, '兵庫県尼崎市次屋');
ok($zip->set_number('6610966')->is_valid_number, '兵庫県尼崎市西川');
ok($zip->set_number('6610967')->is_valid_number, '兵庫県尼崎市浜');
ok($zip->set_number('6610970')->is_valid_number, '兵庫県尼崎市弥生ケ丘町');
ok($zip->set_number('6610971')->is_valid_number, '兵庫県尼崎市瓦宮');
ok($zip->set_number('6610972')->is_valid_number, '兵庫県尼崎市小中島');
ok($zip->set_number('6610973')->is_valid_number, '兵庫県尼崎市善法寺町');
ok($zip->set_number('6610974')->is_valid_number, '兵庫県尼崎市若王寺');
ok($zip->set_number('6610975')->is_valid_number, '兵庫県尼崎市下坂部');
ok($zip->set_number('6610976')->is_valid_number, '兵庫県尼崎市潮江(その他)');
ok($zip->set_number('6610977')->is_valid_number, '兵庫県尼崎市久々知');
ok($zip->set_number('6610978')->is_valid_number, '兵庫県尼崎市久々知西町');
ok($zip->set_number('6610979')->is_valid_number, '兵庫県尼崎市上坂部');
ok($zip->set_number('6610981')->is_valid_number, '兵庫県尼崎市猪名寺');
ok($zip->set_number('6610982')->is_valid_number, '兵庫県尼崎市食満');
ok($zip->set_number('6610983')->is_valid_number, '兵庫県尼崎市口田中');
ok($zip->set_number('6610984')->is_valid_number, '兵庫県尼崎市御園');
ok($zip->set_number('6610985')->is_valid_number, '兵庫県尼崎市南清水');
ok($zip->set_number('6620000')->is_valid_number, '兵庫県西宮市以下に掲載がない場合');
ok($zip->set_number('6620001')->is_valid_number, '兵庫県西宮市甲山町');
ok($zip->set_number('6620002')->is_valid_number, '兵庫県西宮市鷲林寺南町');
ok($zip->set_number('6620003')->is_valid_number, '兵庫県西宮市鷲林寺町');
ok($zip->set_number('6620004')->is_valid_number, '兵庫県西宮市鷲林寺');
ok($zip->set_number('6620005')->is_valid_number, '兵庫県西宮市湯元町');
ok($zip->set_number('6620006')->is_valid_number, '兵庫県西宮市越水社家郷山');
ok($zip->set_number('6620011')->is_valid_number, '兵庫県西宮市甲陽園目神山町');
ok($zip->set_number('6620012')->is_valid_number, '兵庫県西宮市甲陽園東山町');
ok($zip->set_number('6620013')->is_valid_number, '兵庫県西宮市新甲陽町');
ok($zip->set_number('6620014')->is_valid_number, '兵庫県西宮市甲陽園日之出町');
ok($zip->set_number('6620015')->is_valid_number, '兵庫県西宮市甲陽園本庄町');
ok($zip->set_number('6620016')->is_valid_number, '兵庫県西宮市甲陽園若江町');
ok($zip->set_number('6620017')->is_valid_number, '兵庫県西宮市甲陽園西山町');
ok($zip->set_number('6620018')->is_valid_number, '兵庫県西宮市甲陽園山王町');
ok($zip->set_number('6620021')->is_valid_number, '兵庫県西宮市神原');
ok($zip->set_number('6620022')->is_valid_number, '兵庫県西宮市奥畑');
ok($zip->set_number('6620023')->is_valid_number, '兵庫県西宮市城山');
ok($zip->set_number('6620024')->is_valid_number, '兵庫県西宮市名次町');
ok($zip->set_number('6620025')->is_valid_number, '兵庫県西宮市北名次町');
ok($zip->set_number('6620026')->is_valid_number, '兵庫県西宮市獅子ケ口町');
ok($zip->set_number('6620027')->is_valid_number, '兵庫県西宮市神園町');
ok($zip->set_number('6620031')->is_valid_number, '兵庫県西宮市満池谷町');
ok($zip->set_number('6620032')->is_valid_number, '兵庫県西宮市桜谷町');
ok($zip->set_number('6620033')->is_valid_number, '兵庫県西宮市清水町');
ok($zip->set_number('6620034')->is_valid_number, '兵庫県西宮市西田町');
ok($zip->set_number('6620035')->is_valid_number, '兵庫県西宮市若松町');
ok($zip->set_number('6620036')->is_valid_number, '兵庫県西宮市大井手町');
ok($zip->set_number('6620037')->is_valid_number, '兵庫県西宮市結善町');
ok($zip->set_number('6620038')->is_valid_number, '兵庫県西宮市南郷町');
ok($zip->set_number('6620041')->is_valid_number, '兵庫県西宮市末広町');
ok($zip->set_number('6620042')->is_valid_number, '兵庫県西宮市分銅町');
ok($zip->set_number('6620043')->is_valid_number, '兵庫県西宮市常磐町');
ok($zip->set_number('6620044')->is_valid_number, '兵庫県西宮市平松町');
ok($zip->set_number('6620045')->is_valid_number, '兵庫県西宮市安井町');
ok($zip->set_number('6620046')->is_valid_number, '兵庫県西宮市千歳町');
ok($zip->set_number('6620047')->is_valid_number, '兵庫県西宮市寿町');
ok($zip->set_number('6620051')->is_valid_number, '兵庫県西宮市羽衣町');
ok($zip->set_number('6620052')->is_valid_number, '兵庫県西宮市霞町');
ok($zip->set_number('6620053')->is_valid_number, '兵庫県西宮市松園町');
ok($zip->set_number('6620054')->is_valid_number, '兵庫県西宮市大谷町');
ok($zip->set_number('6620061')->is_valid_number, '兵庫県西宮市松ケ丘町');
ok($zip->set_number('6620062')->is_valid_number, '兵庫県西宮市木津山町');
ok($zip->set_number('6620063')->is_valid_number, '兵庫県西宮市相生町');
ok($zip->set_number('6620064')->is_valid_number, '兵庫県西宮市雲井町');
ok($zip->set_number('6620065')->is_valid_number, '兵庫県西宮市殿山町');
ok($zip->set_number('6620066')->is_valid_number, '兵庫県西宮市高塚町');
ok($zip->set_number('6620067')->is_valid_number, '兵庫県西宮市深谷町');
ok($zip->set_number('6620071')->is_valid_number, '兵庫県西宮市桜町');
ok($zip->set_number('6620072')->is_valid_number, '兵庫県西宮市豊楽町');
ok($zip->set_number('6620073')->is_valid_number, '兵庫県西宮市松風町');
ok($zip->set_number('6620074')->is_valid_number, '兵庫県西宮市石刎町');
ok($zip->set_number('6620075')->is_valid_number, '兵庫県西宮市南越木岩町');
ok($zip->set_number('6620076')->is_valid_number, '兵庫県西宮市松生町');
ok($zip->set_number('6620077')->is_valid_number, '兵庫県西宮市久出ケ谷町');
ok($zip->set_number('6620078')->is_valid_number, '兵庫県西宮市菊谷町');
ok($zip->set_number('6620081')->is_valid_number, '兵庫県西宮市苦楽園三番町');
ok($zip->set_number('6620082')->is_valid_number, '兵庫県西宮市苦楽園二番町');
ok($zip->set_number('6620083')->is_valid_number, '兵庫県西宮市苦楽園一番町');
ok($zip->set_number('6620084')->is_valid_number, '兵庫県西宮市樋之池町');
ok($zip->set_number('6620085')->is_valid_number, '兵庫県西宮市老松町');
ok($zip->set_number('6620086')->is_valid_number, '兵庫県西宮市苦楽園六番町');
ok($zip->set_number('6620087')->is_valid_number, '兵庫県西宮市苦楽園五番町');
ok($zip->set_number('6620088')->is_valid_number, '兵庫県西宮市苦楽園四番町');
ok($zip->set_number('6620091')->is_valid_number, '兵庫県西宮市北山町');
ok($zip->set_number('6620092')->is_valid_number, '兵庫県西宮市甑岩町');
ok($zip->set_number('6620093')->is_valid_number, '兵庫県西宮市西平町');
ok($zip->set_number('6620094')->is_valid_number, '兵庫県西宮市毘沙門町');
ok($zip->set_number('6620095')->is_valid_number, '兵庫県西宮市美作町');
ok($zip->set_number('6620096')->is_valid_number, '兵庫県西宮市角石町');
ok($zip->set_number('6620097')->is_valid_number, '兵庫県西宮市柏堂町');
ok($zip->set_number('6620098')->is_valid_number, '兵庫県西宮市柏堂西町');
ok($zip->set_number('6620099')->is_valid_number, '兵庫県西宮市剣谷町');
ok($zip->set_number('6620811')->is_valid_number, '兵庫県西宮市仁川町');
ok($zip->set_number('6620812')->is_valid_number, '兵庫県西宮市甲東園');
ok($zip->set_number('6620813')->is_valid_number, '兵庫県西宮市上甲東園');
ok($zip->set_number('6620814')->is_valid_number, '兵庫県西宮市仁川五ケ山町');
ok($zip->set_number('6620815')->is_valid_number, '兵庫県西宮市仁川百合野町');
ok($zip->set_number('6620822')->is_valid_number, '兵庫県西宮市松籟荘');
ok($zip->set_number('6620823')->is_valid_number, '兵庫県西宮市神呪町');
ok($zip->set_number('6620824')->is_valid_number, '兵庫県西宮市門戸東町');
ok($zip->set_number('6620825')->is_valid_number, '兵庫県西宮市門戸荘');
ok($zip->set_number('6620826')->is_valid_number, '兵庫県西宮市門戸岡田町');
ok($zip->set_number('6620827')->is_valid_number, '兵庫県西宮市岡田山');
ok($zip->set_number('6620828')->is_valid_number, '兵庫県西宮市門戸西町');
ok($zip->set_number('6620831')->is_valid_number, '兵庫県西宮市丸橋町');
ok($zip->set_number('6620832')->is_valid_number, '兵庫県西宮市甲風園');
ok($zip->set_number('6620833')->is_valid_number, '兵庫県西宮市北昭和町');
ok($zip->set_number('6620834')->is_valid_number, '兵庫県西宮市南昭和町');
ok($zip->set_number('6620835')->is_valid_number, '兵庫県西宮市平木町');
ok($zip->set_number('6620836')->is_valid_number, '兵庫県西宮市大畑町');
ok($zip->set_number('6620837')->is_valid_number, '兵庫県西宮市広田町');
ok($zip->set_number('6620838')->is_valid_number, '兵庫県西宮市能登町');
ok($zip->set_number('6620841')->is_valid_number, '兵庫県西宮市両度町');
ok($zip->set_number('6620842')->is_valid_number, '兵庫県西宮市芦原町');
ok($zip->set_number('6620843')->is_valid_number, '兵庫県西宮市神祇官町');
ok($zip->set_number('6620844')->is_valid_number, '兵庫県西宮市西福町');
ok($zip->set_number('6620845')->is_valid_number, '兵庫県西宮市神明町');
ok($zip->set_number('6620846')->is_valid_number, '兵庫県西宮市森下町');
ok($zip->set_number('6620851')->is_valid_number, '兵庫県西宮市中須佐町');
ok($zip->set_number('6620852')->is_valid_number, '兵庫県西宮市中殿町');
ok($zip->set_number('6620853')->is_valid_number, '兵庫県西宮市津田町');
ok($zip->set_number('6620854')->is_valid_number, '兵庫県西宮市櫨塚町');
ok($zip->set_number('6620855')->is_valid_number, '兵庫県西宮市江上町');
ok($zip->set_number('6620856')->is_valid_number, '兵庫県西宮市城ケ堀町');
ok($zip->set_number('6620857')->is_valid_number, '兵庫県西宮市中前田町');
ok($zip->set_number('6620861')->is_valid_number, '兵庫県西宮市河原町');
ok($zip->set_number('6620862')->is_valid_number, '兵庫県西宮市青木町');
ok($zip->set_number('6620863')->is_valid_number, '兵庫県西宮市室川町');
ok($zip->set_number('6620864')->is_valid_number, '兵庫県西宮市越水町');
ok($zip->set_number('6620865')->is_valid_number, '兵庫県西宮市神垣町');
ok($zip->set_number('6620866')->is_valid_number, '兵庫県西宮市柳本町');
ok($zip->set_number('6620867')->is_valid_number, '兵庫県西宮市大社町');
ok($zip->set_number('6620868')->is_valid_number, '兵庫県西宮市中屋町');
ok($zip->set_number('6620871')->is_valid_number, '兵庫県西宮市愛宕山');
ok($zip->set_number('6620872')->is_valid_number, '兵庫県西宮市高座町');
ok($zip->set_number('6620873')->is_valid_number, '兵庫県西宮市一ケ谷町');
ok($zip->set_number('6620874')->is_valid_number, '兵庫県西宮市六軒町');
ok($zip->set_number('6620875')->is_valid_number, '兵庫県西宮市五月ケ丘');
ok($zip->set_number('6620881')->is_valid_number, '兵庫県西宮市上ケ原七番町');
ok($zip->set_number('6620882')->is_valid_number, '兵庫県西宮市上ケ原八番町');
ok($zip->set_number('6620883')->is_valid_number, '兵庫県西宮市上ケ原九番町');
ok($zip->set_number('6620884')->is_valid_number, '兵庫県西宮市上ケ原十番町');
ok($zip->set_number('6620885')->is_valid_number, '兵庫県西宮市上ケ原山手町');
ok($zip->set_number('6620886')->is_valid_number, '兵庫県西宮市上ケ原山田町');
ok($zip->set_number('6620891')->is_valid_number, '兵庫県西宮市上ケ原一番町');
ok($zip->set_number('6620892')->is_valid_number, '兵庫県西宮市上ケ原二番町');
ok($zip->set_number('6620893')->is_valid_number, '兵庫県西宮市上ケ原三番町');
ok($zip->set_number('6620894')->is_valid_number, '兵庫県西宮市上ケ原四番町');
ok($zip->set_number('6620895')->is_valid_number, '兵庫県西宮市上ケ原五番町');
ok($zip->set_number('6620896')->is_valid_number, '兵庫県西宮市上ケ原六番町');
ok($zip->set_number('6620911')->is_valid_number, '兵庫県西宮市池田町');
ok($zip->set_number('6620912')->is_valid_number, '兵庫県西宮市松原町');
ok($zip->set_number('6620913')->is_valid_number, '兵庫県西宮市染殿町');
ok($zip->set_number('6620914')->is_valid_number, '兵庫県西宮市本町');
ok($zip->set_number('6620915')->is_valid_number, '兵庫県西宮市馬場町');
ok($zip->set_number('6620916')->is_valid_number, '兵庫県西宮市戸田町');
ok($zip->set_number('6620917')->is_valid_number, '兵庫県西宮市与古道町');
ok($zip->set_number('6620918')->is_valid_number, '兵庫県西宮市六湛寺町');
ok($zip->set_number('6620921')->is_valid_number, '兵庫県西宮市用海町');
ok($zip->set_number('6620922')->is_valid_number, '兵庫県西宮市東町');
ok($zip->set_number('6620923')->is_valid_number, '兵庫県西宮市浜松原町');
ok($zip->set_number('6620924')->is_valid_number, '兵庫県西宮市東浜町');
ok($zip->set_number('6620925')->is_valid_number, '兵庫県西宮市朝凪町');
ok($zip->set_number('6620926')->is_valid_number, '兵庫県西宮市鞍掛町');
ok($zip->set_number('6620927')->is_valid_number, '兵庫県西宮市久保町');
ok($zip->set_number('6620928')->is_valid_number, '兵庫県西宮市石在町');
ok($zip->set_number('6620931')->is_valid_number, '兵庫県西宮市前浜町');
ok($zip->set_number('6620932')->is_valid_number, '兵庫県西宮市泉町');
ok($zip->set_number('6620933')->is_valid_number, '兵庫県西宮市西波止町');
ok($zip->set_number('6620934')->is_valid_number, '兵庫県西宮市西宮浜');
ok($zip->set_number('6620941')->is_valid_number, '兵庫県西宮市浜脇町');
ok($zip->set_number('6620942')->is_valid_number, '兵庫県西宮市浜町');
ok($zip->set_number('6620943')->is_valid_number, '兵庫県西宮市建石町');
ok($zip->set_number('6620944')->is_valid_number, '兵庫県西宮市川添町');
ok($zip->set_number('6620945')->is_valid_number, '兵庫県西宮市川東町');
ok($zip->set_number('6620946')->is_valid_number, '兵庫県西宮市荒戎町');
ok($zip->set_number('6620947')->is_valid_number, '兵庫県西宮市宮前町');
ok($zip->set_number('6620951')->is_valid_number, '兵庫県西宮市川西町');
ok($zip->set_number('6620952')->is_valid_number, '兵庫県西宮市中浜町');
ok($zip->set_number('6620953')->is_valid_number, '兵庫県西宮市堀切町');
ok($zip->set_number('6620954')->is_valid_number, '兵庫県西宮市上葭原町');
ok($zip->set_number('6620955')->is_valid_number, '兵庫県西宮市中葭原町');
ok($zip->set_number('6620956')->is_valid_number, '兵庫県西宮市下葭原町');
ok($zip->set_number('6620957')->is_valid_number, '兵庫県西宮市大浜町');
ok($zip->set_number('6620961')->is_valid_number, '兵庫県西宮市御茶家所町');
ok($zip->set_number('6620962')->is_valid_number, '兵庫県西宮市松下町');
ok($zip->set_number('6620963')->is_valid_number, '兵庫県西宮市屋敷町');
ok($zip->set_number('6620964')->is_valid_number, '兵庫県西宮市弓場町');
ok($zip->set_number('6620965')->is_valid_number, '兵庫県西宮市郷免町');
ok($zip->set_number('6620971')->is_valid_number, '兵庫県西宮市和上町');
ok($zip->set_number('6620972')->is_valid_number, '兵庫県西宮市今在家町');
ok($zip->set_number('6620973')->is_valid_number, '兵庫県西宮市田中町');
ok($zip->set_number('6620974')->is_valid_number, '兵庫県西宮市社家町');
ok($zip->set_number('6620975')->is_valid_number, '兵庫県西宮市市庭町');
ok($zip->set_number('6620976')->is_valid_number, '兵庫県西宮市宮西町');
ok($zip->set_number('6620977')->is_valid_number, '兵庫県西宮市神楽町');
ok($zip->set_number('6620978')->is_valid_number, '兵庫県西宮市産所町');
ok($zip->set_number('6638001')->is_valid_number, '兵庫県西宮市田近野町');
ok($zip->set_number('6638002')->is_valid_number, '兵庫県西宮市一里山町');
ok($zip->set_number('6638003')->is_valid_number, '兵庫県西宮市上大市');
ok($zip->set_number('6638004')->is_valid_number, '兵庫県西宮市下大市東町');
ok($zip->set_number('6638005')->is_valid_number, '兵庫県西宮市下大市西町');
ok($zip->set_number('6638006')->is_valid_number, '兵庫県西宮市段上町');
ok($zip->set_number('6638011')->is_valid_number, '兵庫県西宮市樋ノ口町');
ok($zip->set_number('6638012')->is_valid_number, '兵庫県西宮市堤町');
ok($zip->set_number('6638013')->is_valid_number, '兵庫県西宮市門前町');
ok($zip->set_number('6638014')->is_valid_number, '兵庫県西宮市林田町');
ok($zip->set_number('6638015')->is_valid_number, '兵庫県西宮市野間町');
ok($zip->set_number('6638016')->is_valid_number, '兵庫県西宮市若山町');
ok($zip->set_number('6638017')->is_valid_number, '兵庫県西宮市大島町');
ok($zip->set_number('6638021')->is_valid_number, '兵庫県西宮市上之町');
ok($zip->set_number('6638022')->is_valid_number, '兵庫県西宮市日野町');
ok($zip->set_number('6638023')->is_valid_number, '兵庫県西宮市大森町');
ok($zip->set_number('6638024')->is_valid_number, '兵庫県西宮市薬師町');
ok($zip->set_number('6638025')->is_valid_number, '兵庫県西宮市荒木町');
ok($zip->set_number('6638031')->is_valid_number, '兵庫県西宮市伏原町');
ok($zip->set_number('6638032')->is_valid_number, '兵庫県西宮市高木西町');
ok($zip->set_number('6638033')->is_valid_number, '兵庫県西宮市高木東町');
ok($zip->set_number('6638034')->is_valid_number, '兵庫県西宮市長田町');
ok($zip->set_number('6638035')->is_valid_number, '兵庫県西宮市北口町');
ok($zip->set_number('6638101')->is_valid_number, '兵庫県西宮市松山町');
ok($zip->set_number('6638102')->is_valid_number, '兵庫県西宮市松並町');
ok($zip->set_number('6638103')->is_valid_number, '兵庫県西宮市熊野町');
ok($zip->set_number('6638104')->is_valid_number, '兵庫県西宮市天道町');
ok($zip->set_number('6638105')->is_valid_number, '兵庫県西宮市中島町');
ok($zip->set_number('6638106')->is_valid_number, '兵庫県西宮市大屋町');
ok($zip->set_number('6638107')->is_valid_number, '兵庫県西宮市瓦林町');
ok($zip->set_number('6638111')->is_valid_number, '兵庫県西宮市二見町');
ok($zip->set_number('6638112')->is_valid_number, '兵庫県西宮市甲子園口北町');
ok($zip->set_number('6638113')->is_valid_number, '兵庫県西宮市甲子園口');
ok($zip->set_number('6638114')->is_valid_number, '兵庫県西宮市上甲子園');
ok($zip->set_number('6638121')->is_valid_number, '兵庫県西宮市戸崎町');
ok($zip->set_number('6638122')->is_valid_number, '兵庫県西宮市小曽根町');
ok($zip->set_number('6638123')->is_valid_number, '兵庫県西宮市小松東町');
ok($zip->set_number('6638124')->is_valid_number, '兵庫県西宮市小松南町');
ok($zip->set_number('6638125')->is_valid_number, '兵庫県西宮市小松西町');
ok($zip->set_number('6638126')->is_valid_number, '兵庫県西宮市小松北町');
ok($zip->set_number('6638127')->is_valid_number, '兵庫県西宮市小松町');
ok($zip->set_number('6638131')->is_valid_number, '兵庫県西宮市武庫川町');
ok($zip->set_number('6638132')->is_valid_number, '兵庫県西宮市東鳴尾町');
ok($zip->set_number('6638133')->is_valid_number, '兵庫県西宮市上田東町');
ok($zip->set_number('6638134')->is_valid_number, '兵庫県西宮市上田中町');
ok($zip->set_number('6638135')->is_valid_number, '兵庫県西宮市上田西町');
ok($zip->set_number('6638136')->is_valid_number, '兵庫県西宮市笠屋町');
ok($zip->set_number('6638137')->is_valid_number, '兵庫県西宮市池開町');
ok($zip->set_number('6638141')->is_valid_number, '兵庫県西宮市高須町');
ok($zip->set_number('6638142')->is_valid_number, '兵庫県西宮市鳴尾浜');
ok($zip->set_number('6638143')->is_valid_number, '兵庫県西宮市枝川町');
ok($zip->set_number('6638151')->is_valid_number, '兵庫県西宮市甲子園洲鳥町');
ok($zip->set_number('6638152')->is_valid_number, '兵庫県西宮市甲子園町');
ok($zip->set_number('6638153')->is_valid_number, '兵庫県西宮市南甲子園');
ok($zip->set_number('6638154')->is_valid_number, '兵庫県西宮市浜甲子園');
ok($zip->set_number('6638155')->is_valid_number, '兵庫県西宮市甲子園浜');
ok($zip->set_number('6638156')->is_valid_number, '兵庫県西宮市甲子園網引町');
ok($zip->set_number('6638161')->is_valid_number, '兵庫県西宮市甲子園春風町');
ok($zip->set_number('6638162')->is_valid_number, '兵庫県西宮市甲子園砂田町');
ok($zip->set_number('6638163')->is_valid_number, '兵庫県西宮市甲子園三保町');
ok($zip->set_number('6638164')->is_valid_number, '兵庫県西宮市甲子園六石町');
ok($zip->set_number('6638165')->is_valid_number, '兵庫県西宮市甲子園浦風町');
ok($zip->set_number('6638166')->is_valid_number, '兵庫県西宮市甲子園高潮町');
ok($zip->set_number('6638167')->is_valid_number, '兵庫県西宮市甲子園浜田町');
ok($zip->set_number('6638171')->is_valid_number, '兵庫県西宮市甲子園一番町');
ok($zip->set_number('6638172')->is_valid_number, '兵庫県西宮市甲子園二番町');
ok($zip->set_number('6638173')->is_valid_number, '兵庫県西宮市甲子園三番町');
ok($zip->set_number('6638174')->is_valid_number, '兵庫県西宮市甲子園四番町');
ok($zip->set_number('6638175')->is_valid_number, '兵庫県西宮市甲子園五番町');
ok($zip->set_number('6638176')->is_valid_number, '兵庫県西宮市甲子園六番町');
ok($zip->set_number('6638177')->is_valid_number, '兵庫県西宮市甲子園七番町');
ok($zip->set_number('6638178')->is_valid_number, '兵庫県西宮市甲子園八番町');
ok($zip->set_number('6638179')->is_valid_number, '兵庫県西宮市甲子園九番町');
ok($zip->set_number('6638181')->is_valid_number, '兵庫県西宮市若草町');
ok($zip->set_number('6638182')->is_valid_number, '兵庫県西宮市学文殿町');
ok($zip->set_number('6638183')->is_valid_number, '兵庫県西宮市里中町');
ok($zip->set_number('6638184')->is_valid_number, '兵庫県西宮市鳴尾町');
ok($zip->set_number('6638185')->is_valid_number, '兵庫県西宮市古川町');
ok($zip->set_number('6638186')->is_valid_number, '兵庫県西宮市上鳴尾町');
ok($zip->set_number('6638187')->is_valid_number, '兵庫県西宮市花園町');
ok($zip->set_number('6638201')->is_valid_number, '兵庫県西宮市田代町');
ok($zip->set_number('6638202')->is_valid_number, '兵庫県西宮市高畑町');
ok($zip->set_number('6638203')->is_valid_number, '兵庫県西宮市深津町');
ok($zip->set_number('6638204')->is_valid_number, '兵庫県西宮市高松町');
ok($zip->set_number('6638211')->is_valid_number, '兵庫県西宮市今津山中町');
ok($zip->set_number('6638212')->is_valid_number, '兵庫県西宮市今津野田町');
ok($zip->set_number('6638213')->is_valid_number, '兵庫県西宮市今津上野町');
ok($zip->set_number('6638214')->is_valid_number, '兵庫県西宮市今津曙町');
ok($zip->set_number('6638215')->is_valid_number, '兵庫県西宮市今津水波町');
ok($zip->set_number('6638221')->is_valid_number, '兵庫県西宮市今津大東町');
ok($zip->set_number('6638222')->is_valid_number, '兵庫県西宮市今津久寿川町');
ok($zip->set_number('6638223')->is_valid_number, '兵庫県西宮市今津巽町');
ok($zip->set_number('6638224')->is_valid_number, '兵庫県西宮市今津真砂町');
ok($zip->set_number('6638225')->is_valid_number, '兵庫県西宮市今津西浜町');
ok($zip->set_number('6638226')->is_valid_number, '兵庫県西宮市今津港町');
ok($zip->set_number('6638227')->is_valid_number, '兵庫県西宮市今津出在家町');
ok($zip->set_number('6638228')->is_valid_number, '兵庫県西宮市今津二葉町');
ok($zip->set_number('6638229')->is_valid_number, '兵庫県西宮市今津社前町');
ok($zip->set_number('6638231')->is_valid_number, '兵庫県西宮市津門西口町');
ok($zip->set_number('6638232')->is_valid_number, '兵庫県西宮市津門宝津町');
ok($zip->set_number('6638233')->is_valid_number, '兵庫県西宮市津門川町');
ok($zip->set_number('6638234')->is_valid_number, '兵庫県西宮市津門住江町');
ok($zip->set_number('6638241')->is_valid_number, '兵庫県西宮市津門大塚町');
ok($zip->set_number('6638242')->is_valid_number, '兵庫県西宮市津門飯田町');
ok($zip->set_number('6638243')->is_valid_number, '兵庫県西宮市津門大箇町');
ok($zip->set_number('6638244')->is_valid_number, '兵庫県西宮市津門綾羽町');
ok($zip->set_number('6638245')->is_valid_number, '兵庫県西宮市津門呉羽町');
ok($zip->set_number('6638246')->is_valid_number, '兵庫県西宮市津門仁辺町');
ok($zip->set_number('6638247')->is_valid_number, '兵庫県西宮市津門稲荷町');
ok($zip->set_number('6640000')->is_valid_number, '兵庫県伊丹市以下に掲載がない場合');
ok($zip->set_number('6640001')->is_valid_number, '兵庫県伊丹市荒牧');
ok($zip->set_number('6640002')->is_valid_number, '兵庫県伊丹市荻野');
ok($zip->set_number('6640003')->is_valid_number, '兵庫県伊丹市大野');
ok($zip->set_number('6640004')->is_valid_number, '兵庫県伊丹市東野');
ok($zip->set_number('6640005')->is_valid_number, '兵庫県伊丹市瑞原');
ok($zip->set_number('6640006')->is_valid_number, '兵庫県伊丹市鴻池');
ok($zip->set_number('6640007')->is_valid_number, '兵庫県伊丹市北野');
ok($zip->set_number('6640008')->is_valid_number, '兵庫県伊丹市荒牧南');
ok($zip->set_number('6640011')->is_valid_number, '兵庫県伊丹市鋳物師');
ok($zip->set_number('6640012')->is_valid_number, '兵庫県伊丹市緑ケ丘');
ok($zip->set_number('6640013')->is_valid_number, '兵庫県伊丹市瑞穂町');
ok($zip->set_number('6640014')->is_valid_number, '兵庫県伊丹市広畑');
ok($zip->set_number('6640015')->is_valid_number, '兵庫県伊丹市昆陽池');
ok($zip->set_number('6640016')->is_valid_number, '兵庫県伊丹市昆陽北');
ok($zip->set_number('6640017')->is_valid_number, '兵庫県伊丹市瑞ケ丘');
ok($zip->set_number('6640020')->is_valid_number, '兵庫県伊丹市寺本東');
ok($zip->set_number('6640022')->is_valid_number, '兵庫県伊丹市中野東');
ok($zip->set_number('6640023')->is_valid_number, '兵庫県伊丹市中野西');
ok($zip->set_number('6640024')->is_valid_number, '兵庫県伊丹市松ケ丘');
ok($zip->set_number('6640025')->is_valid_number, '兵庫県伊丹市奥畑');
ok($zip->set_number('6640026')->is_valid_number, '兵庫県伊丹市寺本');
ok($zip->set_number('6640027')->is_valid_number, '兵庫県伊丹市池尻');
ok($zip->set_number('6640028')->is_valid_number, '兵庫県伊丹市西野');
ok($zip->set_number('6640029')->is_valid_number, '兵庫県伊丹市中野北');
ok($zip->set_number('6640031')->is_valid_number, '兵庫県伊丹市荻野西');
ok($zip->set_number('6640831')->is_valid_number, '兵庫県伊丹市北伊丹');
ok($zip->set_number('6640832')->is_valid_number, '兵庫県伊丹市下河原');
ok($zip->set_number('6640833')->is_valid_number, '兵庫県伊丹市小阪田(都賀元)');
ok($zip->set_number('6640834')->is_valid_number, '兵庫県伊丹市西桑津');
ok($zip->set_number('6640835')->is_valid_number, '兵庫県伊丹市東桑津');
ok($zip->set_number('6640836')->is_valid_number, '兵庫県伊丹市北本町');
ok($zip->set_number('6640837')->is_valid_number, '兵庫県伊丹市北河原');
ok($zip->set_number('6640838')->is_valid_number, '兵庫県伊丹市中村');
ok($zip->set_number('6640839')->is_valid_number, '兵庫県伊丹市桑津');
ok($zip->set_number('6640842')->is_valid_number, '兵庫県伊丹市森本');
ok($zip->set_number('6640843')->is_valid_number, '兵庫県伊丹市岩屋');
ok($zip->set_number('6640844')->is_valid_number, '兵庫県伊丹市口酒井');
ok($zip->set_number('6640845')->is_valid_number, '兵庫県伊丹市東有岡');
ok($zip->set_number('6640846')->is_valid_number, '兵庫県伊丹市伊丹');
ok($zip->set_number('6640847')->is_valid_number, '兵庫県伊丹市藤ノ木');
ok($zip->set_number('6640851')->is_valid_number, '兵庫県伊丹市中央');
ok($zip->set_number('6640852')->is_valid_number, '兵庫県伊丹市南本町');
ok($zip->set_number('6640853')->is_valid_number, '兵庫県伊丹市平松');
ok($zip->set_number('6640854')->is_valid_number, '兵庫県伊丹市南町');
ok($zip->set_number('6640855')->is_valid_number, '兵庫県伊丹市御願塚');
ok($zip->set_number('6640856')->is_valid_number, '兵庫県伊丹市梅ノ木');
ok($zip->set_number('6640857')->is_valid_number, '兵庫県伊丹市行基町');
ok($zip->set_number('6640858')->is_valid_number, '兵庫県伊丹市西台');
ok($zip->set_number('6640861')->is_valid_number, '兵庫県伊丹市稲野町');
ok($zip->set_number('6640862')->is_valid_number, '兵庫県伊丹市若菱町');
ok($zip->set_number('6640863')->is_valid_number, '兵庫県伊丹市柏木町');
ok($zip->set_number('6640864')->is_valid_number, '兵庫県伊丹市安堂寺町');
ok($zip->set_number('6640865')->is_valid_number, '兵庫県伊丹市南野');
ok($zip->set_number('6640871')->is_valid_number, '兵庫県伊丹市堀池');
ok($zip->set_number('6640872')->is_valid_number, '兵庫県伊丹市車塚');
ok($zip->set_number('6640873')->is_valid_number, '兵庫県伊丹市野間');
ok($zip->set_number('6640874')->is_valid_number, '兵庫県伊丹市山田');
ok($zip->set_number('6640875')->is_valid_number, '兵庫県伊丹市野間北');
ok($zip->set_number('6640881')->is_valid_number, '兵庫県伊丹市昆陽');
ok($zip->set_number('6640882')->is_valid_number, '兵庫県伊丹市鈴原町');
ok($zip->set_number('6640883')->is_valid_number, '兵庫県伊丹市南鈴原');
ok($zip->set_number('6640884')->is_valid_number, '兵庫県伊丹市美鈴町');
ok($zip->set_number('6640885')->is_valid_number, '兵庫県伊丹市昆陽泉町');
ok($zip->set_number('6640886')->is_valid_number, '兵庫県伊丹市昆陽東');
ok($zip->set_number('6640887')->is_valid_number, '兵庫県伊丹市南野北');
ok($zip->set_number('6640888')->is_valid_number, '兵庫県伊丹市昆陽南');
ok($zip->set_number('6640891')->is_valid_number, '兵庫県伊丹市北園');
ok($zip->set_number('6640892')->is_valid_number, '兵庫県伊丹市高台');
ok($zip->set_number('6640893')->is_valid_number, '兵庫県伊丹市春日丘');
ok($zip->set_number('6640894')->is_valid_number, '兵庫県伊丹市清水');
ok($zip->set_number('6640895')->is_valid_number, '兵庫県伊丹市宮ノ前');
ok($zip->set_number('6640896')->is_valid_number, '兵庫県伊丹市船原');
ok($zip->set_number('6640897')->is_valid_number, '兵庫県伊丹市桜ケ丘');
ok($zip->set_number('6640898')->is_valid_number, '兵庫県伊丹市千僧');
ok($zip->set_number('6640899')->is_valid_number, '兵庫県伊丹市大鹿');
ok($zip->set_number('6650000')->is_valid_number, '兵庫県宝塚市以下に掲載がない場合');
ok($zip->set_number('6650001')->is_valid_number, '兵庫県宝塚市長寿ガ丘');
ok($zip->set_number('6650002')->is_valid_number, '兵庫県宝塚市月見山');
ok($zip->set_number('6650003')->is_valid_number, '兵庫県宝塚市湯本町');
ok($zip->set_number('6650004')->is_valid_number, '兵庫県宝塚市梅野町');
ok($zip->set_number('6650005')->is_valid_number, '兵庫県宝塚市武庫山');
ok($zip->set_number('6650006')->is_valid_number, '兵庫県宝塚市紅葉ガ丘');
ok($zip->set_number('6650007')->is_valid_number, '兵庫県宝塚市伊孑志(武庫山)');
ok($zip->set_number('6650011')->is_valid_number, '兵庫県宝塚市南口');
ok($zip->set_number('6650012')->is_valid_number, '兵庫県宝塚市寿楽荘');
ok($zip->set_number('6650013')->is_valid_number, '兵庫県宝塚市宝梅');
ok($zip->set_number('6650014')->is_valid_number, '兵庫県宝塚市青葉台');
ok($zip->set_number('6650015')->is_valid_number, '兵庫県宝塚市光ガ丘');
ok($zip->set_number('6650016')->is_valid_number, '兵庫県宝塚市宝松苑');
ok($zip->set_number('6650017')->is_valid_number, '兵庫県宝塚市小林西山');
ok($zip->set_number('6650021')->is_valid_number, '兵庫県宝塚市中州');
ok($zip->set_number('6650022')->is_valid_number, '兵庫県宝塚市野上');
ok($zip->set_number('6650023')->is_valid_number, '兵庫県宝塚市蔵人');
ok($zip->set_number('6650024')->is_valid_number, '兵庫県宝塚市逆瀬台');
ok($zip->set_number('6650025')->is_valid_number, '兵庫県宝塚市ゆずり葉台');
ok($zip->set_number('6650031')->is_valid_number, '兵庫県宝塚市末広町');
ok($zip->set_number('6650032')->is_valid_number, '兵庫県宝塚市東洋町');
ok($zip->set_number('6650033')->is_valid_number, '兵庫県宝塚市伊孑志');
ok($zip->set_number('6650034')->is_valid_number, '兵庫県宝塚市小林');
ok($zip->set_number('6650035')->is_valid_number, '兵庫県宝塚市逆瀬川');
ok($zip->set_number('6650041')->is_valid_number, '兵庫県宝塚市御所の前町');
ok($zip->set_number('6650042')->is_valid_number, '兵庫県宝塚市美幸町');
ok($zip->set_number('6650043')->is_valid_number, '兵庫県宝塚市高松町');
ok($zip->set_number('6650044')->is_valid_number, '兵庫県宝塚市末成町');
ok($zip->set_number('6650045')->is_valid_number, '兵庫県宝塚市光明町');
ok($zip->set_number('6650046')->is_valid_number, '兵庫県宝塚市福井町');
ok($zip->set_number('6650047')->is_valid_number, '兵庫県宝塚市亀井町');
ok($zip->set_number('6650051')->is_valid_number, '兵庫県宝塚市高司');
ok($zip->set_number('6650052')->is_valid_number, '兵庫県宝塚市新明和町');
ok($zip->set_number('6650053')->is_valid_number, '兵庫県宝塚市駒の町');
ok($zip->set_number('6650054')->is_valid_number, '兵庫県宝塚市鹿塩');
ok($zip->set_number('6650055')->is_valid_number, '兵庫県宝塚市大成町');
ok($zip->set_number('6650056')->is_valid_number, '兵庫県宝塚市中野町');
ok($zip->set_number('6650057')->is_valid_number, '兵庫県宝塚市大吹町');
ok($zip->set_number('6650061')->is_valid_number, '兵庫県宝塚市仁川北');
ok($zip->set_number('6650062')->is_valid_number, '兵庫県宝塚市仁川高台');
ok($zip->set_number('6650063')->is_valid_number, '兵庫県宝塚市仁川高丸');
ok($zip->set_number('6650064')->is_valid_number, '兵庫県宝塚市仁川うぐいす台');
ok($zip->set_number('6650065')->is_valid_number, '兵庫県宝塚市仁川旭ガ丘');
ok($zip->set_number('6650066')->is_valid_number, '兵庫県宝塚市仁川団地');
ok($zip->set_number('6650067')->is_valid_number, '兵庫県宝塚市仁川月見ガ丘');
ok($zip->set_number('6650068')->is_valid_number, '兵庫県宝塚市仁川清風台');
ok($zip->set_number('6650071')->is_valid_number, '兵庫県宝塚市社町');
ok($zip->set_number('6650072')->is_valid_number, '兵庫県宝塚市千種');
ok($zip->set_number('6650073')->is_valid_number, '兵庫県宝塚市塔の町');
ok($zip->set_number('6650074')->is_valid_number, '兵庫県宝塚市仁川台');
ok($zip->set_number('6650075')->is_valid_number, '兵庫県宝塚市仁川宮西町');
ok($zip->set_number('6650076')->is_valid_number, '兵庫県宝塚市谷口町');
ok($zip->set_number('6650801')->is_valid_number, '兵庫県宝塚市花屋敷松ガ丘');
ok($zip->set_number('6650802')->is_valid_number, '兵庫県宝塚市花屋敷荘園');
ok($zip->set_number('6650803')->is_valid_number, '兵庫県宝塚市花屋敷つつじガ丘');
ok($zip->set_number('6650804')->is_valid_number, '兵庫県宝塚市雲雀丘山手');
ok($zip->set_number('6650805')->is_valid_number, '兵庫県宝塚市雲雀丘');
ok($zip->set_number('6650806')->is_valid_number, '兵庫県宝塚市ふじガ丘');
ok($zip->set_number('6650807')->is_valid_number, '兵庫県宝塚市長尾台');
ok($zip->set_number('6650808')->is_valid_number, '兵庫県宝塚市切畑(長尾山「その他」)');
ok($zip->set_number('6650811')->is_valid_number, '兵庫県宝塚市南ひばりガ丘');
ok($zip->set_number('6650812')->is_valid_number, '兵庫県宝塚市口谷東');
ok($zip->set_number('6650813')->is_valid_number, '兵庫県宝塚市口谷西');
ok($zip->set_number('6650814')->is_valid_number, '兵庫県宝塚市山本野里');
ok($zip->set_number('6650815')->is_valid_number, '兵庫県宝塚市山本丸橋');
ok($zip->set_number('6650816')->is_valid_number, '兵庫県宝塚市平井');
ok($zip->set_number('6650817')->is_valid_number, '兵庫県宝塚市平井山荘');
ok($zip->set_number('6650821')->is_valid_number, '兵庫県宝塚市安倉北');
ok($zip->set_number('6650822')->is_valid_number, '兵庫県宝塚市安倉中');
ok($zip->set_number('6650823')->is_valid_number, '兵庫県宝塚市安倉南');
ok($zip->set_number('6650824')->is_valid_number, '兵庫県宝塚市金井町');
ok($zip->set_number('6650825')->is_valid_number, '兵庫県宝塚市安倉西');
ok($zip->set_number('6650826')->is_valid_number, '兵庫県宝塚市弥生町');
ok($zip->set_number('6650827')->is_valid_number, '兵庫県宝塚市小浜');
ok($zip->set_number('6650831')->is_valid_number, '兵庫県宝塚市米谷');
ok($zip->set_number('6650832')->is_valid_number, '兵庫県宝塚市向月町');
ok($zip->set_number('6650833')->is_valid_number, '兵庫県宝塚市鶴の荘');
ok($zip->set_number('6650834')->is_valid_number, '兵庫県宝塚市美座');
ok($zip->set_number('6650835')->is_valid_number, '兵庫県宝塚市旭町');
ok($zip->set_number('6650836')->is_valid_number, '兵庫県宝塚市清荒神');
ok($zip->set_number('6650837')->is_valid_number, '兵庫県宝塚市米谷清');
ok($zip->set_number('6650841')->is_valid_number, '兵庫県宝塚市御殿山');
ok($zip->set_number('6650842')->is_valid_number, '兵庫県宝塚市川面');
ok($zip->set_number('6650843')->is_valid_number, '兵庫県宝塚市宮の町');
ok($zip->set_number('6650844')->is_valid_number, '兵庫県宝塚市武庫川町');
ok($zip->set_number('6650845')->is_valid_number, '兵庫県宝塚市栄町');
ok($zip->set_number('6650846')->is_valid_number, '兵庫県宝塚市桜ガ丘');
ok($zip->set_number('6650847')->is_valid_number, '兵庫県宝塚市すみれガ丘');
ok($zip->set_number('6650848')->is_valid_number, '兵庫県宝塚市川面(長尾山)');
ok($zip->set_number('6650851')->is_valid_number, '兵庫県宝塚市泉ガ丘');
ok($zip->set_number('6650852')->is_valid_number, '兵庫県宝塚市売布');
ok($zip->set_number('6650853')->is_valid_number, '兵庫県宝塚市売布ガ丘');
ok($zip->set_number('6650854')->is_valid_number, '兵庫県宝塚市売布山手町');
ok($zip->set_number('6650855')->is_valid_number, '兵庫県宝塚市売布きよしガ丘');
ok($zip->set_number('6650856')->is_valid_number, '兵庫県宝塚市売布自由ガ丘');
ok($zip->set_number('6650861')->is_valid_number, '兵庫県宝塚市中山寺');
ok($zip->set_number('6650862')->is_valid_number, '兵庫県宝塚市今里町');
ok($zip->set_number('6650863')->is_valid_number, '兵庫県宝塚市三笠町');
ok($zip->set_number('6650864')->is_valid_number, '兵庫県宝塚市泉町');
ok($zip->set_number('6650865')->is_valid_number, '兵庫県宝塚市寿町');
ok($zip->set_number('6650866')->is_valid_number, '兵庫県宝塚市星の荘');
ok($zip->set_number('6650867')->is_valid_number, '兵庫県宝塚市売布東の町');
ok($zip->set_number('6650868')->is_valid_number, '兵庫県宝塚市中山荘園');
ok($zip->set_number('6650871')->is_valid_number, '兵庫県宝塚市中山五月台');
ok($zip->set_number('6650872')->is_valid_number, '兵庫県宝塚市中筋(平井)');
ok($zip->set_number('6650873')->is_valid_number, '兵庫県宝塚市長尾町');
ok($zip->set_number('6650874')->is_valid_number, '兵庫県宝塚市中筋');
ok($zip->set_number('6650875')->is_valid_number, '兵庫県宝塚市中筋山手');
ok($zip->set_number('6650876')->is_valid_number, '兵庫県宝塚市中山台');
ok($zip->set_number('6650877')->is_valid_number, '兵庫県宝塚市中山桜台');
ok($zip->set_number('6650881')->is_valid_number, '兵庫県宝塚市山本東');
ok($zip->set_number('6650882')->is_valid_number, '兵庫県宝塚市山本南');
ok($zip->set_number('6650883')->is_valid_number, '兵庫県宝塚市山本中');
ok($zip->set_number('6650884')->is_valid_number, '兵庫県宝塚市山本西');
ok($zip->set_number('6650885')->is_valid_number, '兵庫県宝塚市山本台');
ok($zip->set_number('6650886')->is_valid_number, '兵庫県宝塚市山手台西');
ok($zip->set_number('6650887')->is_valid_number, '兵庫県宝塚市山手台東');
ok($zip->set_number('6650891')->is_valid_number, '兵庫県川西市満願寺町');
ok($zip->set_number('6660000')->is_valid_number, '兵庫県川西市以下に掲載がない場合');
ok($zip->set_number('6660001')->is_valid_number, '兵庫県川西市鴬の森町');
ok($zip->set_number('6660002')->is_valid_number, '兵庫県川西市滝山町');
ok($zip->set_number('6660003')->is_valid_number, '兵庫県川西市丸の内町');
ok($zip->set_number('6660004')->is_valid_number, '兵庫県川西市萩原');
ok($zip->set_number('6660005')->is_valid_number, '兵庫県川西市萩原台東');
ok($zip->set_number('6660006')->is_valid_number, '兵庫県川西市萩原台西(1、2丁目、3丁目1番~282番)');
ok($zip->set_number('6660007')->is_valid_number, '兵庫県川西市鴬が丘');
ok($zip->set_number('6660011')->is_valid_number, '兵庫県川西市出在家町');
ok($zip->set_number('6660012')->is_valid_number, '兵庫県川西市絹延町');
ok($zip->set_number('6660013')->is_valid_number, '兵庫県川西市美園町');
ok($zip->set_number('6660014')->is_valid_number, '兵庫県川西市小戸');
ok($zip->set_number('6660015')->is_valid_number, '兵庫県川西市小花');
ok($zip->set_number('6660016')->is_valid_number, '兵庫県川西市中央町');
ok($zip->set_number('6660017')->is_valid_number, '兵庫県川西市火打');
ok($zip->set_number('6660021')->is_valid_number, '兵庫県川西市栄根');
ok($zip->set_number('6660022')->is_valid_number, '兵庫県川西市下加茂');
ok($zip->set_number('6660023')->is_valid_number, '兵庫県川西市東久代');
ok($zip->set_number('6660024')->is_valid_number, '兵庫県川西市久代');
ok($zip->set_number('6660025')->is_valid_number, '兵庫県川西市加茂');
ok($zip->set_number('6660026')->is_valid_number, '兵庫県川西市南花屋敷');
ok($zip->set_number('6660031')->is_valid_number, '兵庫県川西市霞ケ丘');
ok($zip->set_number('6660032')->is_valid_number, '兵庫県川西市日高町');
ok($zip->set_number('6660033')->is_valid_number, '兵庫県川西市栄町');
ok($zip->set_number('6660034')->is_valid_number, '兵庫県川西市寺畑');
ok($zip->set_number('6660035')->is_valid_number, '兵庫県川西市花屋敷');
ok($zip->set_number('6660036')->is_valid_number, '兵庫県川西市花屋敷山手町');
ok($zip->set_number('6660037')->is_valid_number, '兵庫県川西市松が丘町');
ok($zip->set_number('6660101')->is_valid_number, '兵庫県川西市黒川');
ok($zip->set_number('6660102')->is_valid_number, '兵庫県川西市横路');
ok($zip->set_number('6660103')->is_valid_number, '兵庫県川西市国崎');
ok($zip->set_number('6660104')->is_valid_number, '兵庫県川西市笹部');
ok($zip->set_number('6660105')->is_valid_number, '兵庫県川西市見野');
ok($zip->set_number('6660106')->is_valid_number, '兵庫県川西市山下町');
ok($zip->set_number('6660107')->is_valid_number, '兵庫県川西市下財町');
ok($zip->set_number('6660111')->is_valid_number, '兵庫県川西市大和東');
ok($zip->set_number('6660112')->is_valid_number, '兵庫県川西市大和西');
ok($zip->set_number('6660113')->is_valid_number, '兵庫県川西市長尾町');
ok($zip->set_number('6660114')->is_valid_number, '兵庫県川西市東畦野山手');
ok($zip->set_number('6660115')->is_valid_number, '兵庫県川西市向陽台');
ok($zip->set_number('6660116')->is_valid_number, '兵庫県川西市水明台');
ok($zip->set_number('6660117')->is_valid_number, '兵庫県川西市東畦野');
ok($zip->set_number('6660121')->is_valid_number, '兵庫県川西市平野');
ok($zip->set_number('6660122')->is_valid_number, '兵庫県川西市東多田');
ok($zip->set_number('6660123')->is_valid_number, '兵庫県川西市鼓が滝');
ok($zip->set_number('6660124')->is_valid_number, '兵庫県川西市多田桜木');
ok($zip->set_number('6660125')->is_valid_number, '兵庫県川西市新田');
ok($zip->set_number('6660126')->is_valid_number, '兵庫県川西市多田院');
ok($zip->set_number('6660127')->is_valid_number, '兵庫県川西市多田院多田所町');
ok($zip->set_number('6660128')->is_valid_number, '兵庫県川西市多田院西');
ok($zip->set_number('6660129')->is_valid_number, '兵庫県川西市緑台');
ok($zip->set_number('6660131')->is_valid_number, '兵庫県川西市矢問');
ok($zip->set_number('6660132')->is_valid_number, '兵庫県川西市矢問東町');
ok($zip->set_number('6660133')->is_valid_number, '兵庫県川西市鴬台');
ok($zip->set_number('6660134')->is_valid_number, '兵庫県川西市萩原台西(3丁目283番以上)');
ok($zip->set_number('6660135')->is_valid_number, '兵庫県川西市錦松台');
ok($zip->set_number('6660136')->is_valid_number, '兵庫県川西市南野坂');
ok($zip->set_number('6660137')->is_valid_number, '兵庫県川西市湯山台');
ok($zip->set_number('6660138')->is_valid_number, '兵庫県川西市西多田');
ok($zip->set_number('6660141')->is_valid_number, '兵庫県川西市虫生');
ok($zip->set_number('6660142')->is_valid_number, '兵庫県川西市清和台東');
ok($zip->set_number('6660143')->is_valid_number, '兵庫県川西市清和台西');
ok($zip->set_number('6660144')->is_valid_number, '兵庫県川西市柳谷');
ok($zip->set_number('6660145')->is_valid_number, '兵庫県川西市けやき坂');
ok($zip->set_number('6660146')->is_valid_number, '兵庫県川西市芋生');
ok($zip->set_number('6660147')->is_valid_number, '兵庫県川西市若宮');
ok($zip->set_number('6660148')->is_valid_number, '兵庫県川西市赤松');
ok($zip->set_number('6660151')->is_valid_number, '兵庫県川西市美山台');
ok($zip->set_number('6660152')->is_valid_number, '兵庫県川西市丸山台');
ok($zip->set_number('6660153')->is_valid_number, '兵庫県川西市一庫');
ok($zip->set_number('6660154')->is_valid_number, '兵庫県川西市山原');
ok($zip->set_number('6660155')->is_valid_number, '兵庫県川西市西畦野');
ok($zip->set_number('6660156')->is_valid_number, '兵庫県川西市石道');
ok($zip->set_number('6660157')->is_valid_number, '兵庫県川西市緑が丘');
ok($zip->set_number('6660158')->is_valid_number, '兵庫県川西市清流台');
ok($zip->set_number('6660161')->is_valid_number, '兵庫県宝塚市切畑(長尾山19-14)');
ok($zip->set_number('6660162')->is_valid_number, '兵庫県宝塚市花屋敷緑ガ丘');
ok($zip->set_number('6660200')->is_valid_number, '兵庫県川辺郡猪名川町以下に掲載がない場合');
ok($zip->set_number('6660201')->is_valid_number, '兵庫県川辺郡猪名川町杉生');
ok($zip->set_number('6660202')->is_valid_number, '兵庫県川辺郡猪名川町鎌倉');
ok($zip->set_number('6660203')->is_valid_number, '兵庫県川辺郡猪名川町西畑');
ok($zip->set_number('6660204')->is_valid_number, '兵庫県川辺郡猪名川町柏原');
ok($zip->set_number('6660211')->is_valid_number, '兵庫県川辺郡猪名川町仁頂寺');
ok($zip->set_number('6660212')->is_valid_number, '兵庫県川辺郡猪名川町旭ケ丘');
ok($zip->set_number('6660213')->is_valid_number, '兵庫県川辺郡猪名川町清水東');
ok($zip->set_number('6660214')->is_valid_number, '兵庫県川辺郡猪名川町清水');
ok($zip->set_number('6660215')->is_valid_number, '兵庫県川辺郡猪名川町島');
ok($zip->set_number('6660221')->is_valid_number, '兵庫県川辺郡猪名川町杤原');
ok($zip->set_number('6660222')->is_valid_number, '兵庫県川辺郡猪名川町槻並');
ok($zip->set_number('6660223')->is_valid_number, '兵庫県川辺郡猪名川町木間生');
ok($zip->set_number('6660224')->is_valid_number, '兵庫県川辺郡猪名川町万善');
ok($zip->set_number('6660225')->is_valid_number, '兵庫県川辺郡猪名川町木津');
ok($zip->set_number('6660226')->is_valid_number, '兵庫県川辺郡猪名川町林田');
ok($zip->set_number('6660227')->is_valid_number, '兵庫県川辺郡猪名川町笹尾');
ok($zip->set_number('6660231')->is_valid_number, '兵庫県川辺郡猪名川町上阿古谷');
ok($zip->set_number('6660232')->is_valid_number, '兵庫県川辺郡猪名川町民田');
ok($zip->set_number('6660233')->is_valid_number, '兵庫県川辺郡猪名川町紫合');
ok($zip->set_number('6660234')->is_valid_number, '兵庫県川辺郡猪名川町北野');
ok($zip->set_number('6660235')->is_valid_number, '兵庫県川辺郡猪名川町南田原');
ok($zip->set_number('6660236')->is_valid_number, '兵庫県川辺郡猪名川町北田原');
ok($zip->set_number('6660237')->is_valid_number, '兵庫県川辺郡猪名川町下阿古谷');
ok($zip->set_number('6660238')->is_valid_number, '兵庫県川辺郡猪名川町荘苑');
ok($zip->set_number('6660241')->is_valid_number, '兵庫県川辺郡猪名川町内馬場');
ok($zip->set_number('6660242')->is_valid_number, '兵庫県川辺郡猪名川町原');
ok($zip->set_number('6660243')->is_valid_number, '兵庫県川辺郡猪名川町柏梨田');
ok($zip->set_number('6660244')->is_valid_number, '兵庫県川辺郡猪名川町上野');
ok($zip->set_number('6660245')->is_valid_number, '兵庫県川辺郡猪名川町つつじが丘');
ok($zip->set_number('6660246')->is_valid_number, '兵庫県川辺郡猪名川町猪名川台');
ok($zip->set_number('6660251')->is_valid_number, '兵庫県川辺郡猪名川町若葉');
ok($zip->set_number('6660252')->is_valid_number, '兵庫県川辺郡猪名川町広根');
ok($zip->set_number('6660253')->is_valid_number, '兵庫県川辺郡猪名川町差組');
ok($zip->set_number('6660254')->is_valid_number, '兵庫県川辺郡猪名川町肝川');
ok($zip->set_number('6660255')->is_valid_number, '兵庫県川辺郡猪名川町猪渕');
ok($zip->set_number('6660256')->is_valid_number, '兵庫県川辺郡猪名川町銀山');
ok($zip->set_number('6660257')->is_valid_number, '兵庫県川辺郡猪名川町白金');
ok($zip->set_number('6660261')->is_valid_number, '兵庫県川辺郡猪名川町松尾台');
ok($zip->set_number('6660262')->is_valid_number, '兵庫県川辺郡猪名川町伏見台');
ok($zip->set_number('6670000')->is_valid_number, '兵庫県養父市以下に掲載がない場合');
ok($zip->set_number('6670001')->is_valid_number, '兵庫県養父市八鹿町青山');
ok($zip->set_number('6670002')->is_valid_number, '兵庫県養父市八鹿町三谷');
ok($zip->set_number('6670003')->is_valid_number, '兵庫県養父市八鹿町宿南');
ok($zip->set_number('6670004')->is_valid_number, '兵庫県養父市八鹿町上小田');
ok($zip->set_number('6670005')->is_valid_number, '兵庫県養父市八鹿町下小田');
ok($zip->set_number('6670011')->is_valid_number, '兵庫県養父市八鹿町浅間');
ok($zip->set_number('6670012')->is_valid_number, '兵庫県養父市八鹿町伊佐');
ok($zip->set_number('6670013')->is_valid_number, '兵庫県養父市八鹿町坂本');
ok($zip->set_number('6670014')->is_valid_number, '兵庫県養父市八鹿町岩崎');
ok($zip->set_number('6670015')->is_valid_number, '兵庫県養父市八鹿町大江');
ok($zip->set_number('6670016')->is_valid_number, '兵庫県養父市八鹿町舞狂');
ok($zip->set_number('6670021')->is_valid_number, '兵庫県養父市八鹿町八鹿');
ok($zip->set_number('6670022')->is_valid_number, '兵庫県養父市八鹿町下網場');
ok($zip->set_number('6670023')->is_valid_number, '兵庫県養父市八鹿町上網場');
ok($zip->set_number('6670024')->is_valid_number, '兵庫県養父市八鹿町朝倉');
ok($zip->set_number('6670031')->is_valid_number, '兵庫県養父市八鹿町九鹿');
ok($zip->set_number('6670032')->is_valid_number, '兵庫県養父市八鹿町小山');
ok($zip->set_number('6670041')->is_valid_number, '兵庫県養父市八鹿町八木');
ok($zip->set_number('6670042')->is_valid_number, '兵庫県養父市八鹿町今滝寺');
ok($zip->set_number('6670043')->is_valid_number, '兵庫県養父市八鹿町高柳');
ok($zip->set_number('6670044')->is_valid_number, '兵庫県養父市八鹿町国木');
ok($zip->set_number('6670045')->is_valid_number, '兵庫県養父市八鹿町米里');
ok($zip->set_number('6670051')->is_valid_number, '兵庫県養父市八鹿町石原');
ok($zip->set_number('6670052')->is_valid_number, '兵庫県養父市八鹿町日畑');
ok($zip->set_number('6670053')->is_valid_number, '兵庫県養父市八鹿町小佐');
ok($zip->set_number('6670101')->is_valid_number, '兵庫県養父市広谷');
ok($zip->set_number('6670102')->is_valid_number, '兵庫県養父市十二所');
ok($zip->set_number('6670103')->is_valid_number, '兵庫県養父市浅野');
ok($zip->set_number('6670104')->is_valid_number, '兵庫県養父市伊豆');
ok($zip->set_number('6670105')->is_valid_number, '兵庫県養父市左近山');
ok($zip->set_number('6670106')->is_valid_number, '兵庫県養父市玉見');
ok($zip->set_number('6670107')->is_valid_number, '兵庫県養父市新津');
ok($zip->set_number('6670111')->is_valid_number, '兵庫県養父市大薮');
ok($zip->set_number('6670112')->is_valid_number, '兵庫県養父市養父市場');
ok($zip->set_number('6670113')->is_valid_number, '兵庫県養父市薮崎');
ok($zip->set_number('6670114')->is_valid_number, '兵庫県養父市小城');
ok($zip->set_number('6670115')->is_valid_number, '兵庫県養父市上箇');
ok($zip->set_number('6670121')->is_valid_number, '兵庫県養父市奥米地');
ok($zip->set_number('6670122')->is_valid_number, '兵庫県養父市中米地');
ok($zip->set_number('6670123')->is_valid_number, '兵庫県養父市鉄屋米地');
ok($zip->set_number('6670124')->is_valid_number, '兵庫県養父市口米地');
ok($zip->set_number('6670125')->is_valid_number, '兵庫県養父市大塚');
ok($zip->set_number('6670126')->is_valid_number, '兵庫県養父市堀畑');
ok($zip->set_number('6670131')->is_valid_number, '兵庫県養父市上野');
ok($zip->set_number('6670132')->is_valid_number, '兵庫県養父市稲津');
ok($zip->set_number('6670133')->is_valid_number, '兵庫県養父市畑');
ok($zip->set_number('6670134')->is_valid_number, '兵庫県養父市大坪');
ok($zip->set_number('6670135')->is_valid_number, '兵庫県養父市船谷');
ok($zip->set_number('6670136')->is_valid_number, '兵庫県養父市三谷');
ok($zip->set_number('6670141')->is_valid_number, '兵庫県養父市森');
ok($zip->set_number('6670142')->is_valid_number, '兵庫県養父市建屋');
ok($zip->set_number('6670143')->is_valid_number, '兵庫県養父市能座');
ok($zip->set_number('6670144')->is_valid_number, '兵庫県養父市餅耕地');
ok($zip->set_number('6670145')->is_valid_number, '兵庫県養父市長野');
ok($zip->set_number('6670301')->is_valid_number, '兵庫県養父市大屋町上山');
ok($zip->set_number('6670302')->is_valid_number, '兵庫県養父市大屋町樽見');
ok($zip->set_number('6670303')->is_valid_number, '兵庫県養父市大屋町おうみ');
ok($zip->set_number('6670304')->is_valid_number, '兵庫県養父市大屋町中');
ok($zip->set_number('6670304')->is_valid_number, '兵庫県養父市大屋町由良');
ok($zip->set_number('6670305')->is_valid_number, '兵庫県養父市大屋町夏梅');
ok($zip->set_number('6670306')->is_valid_number, '兵庫県養父市大屋町宮垣');
ok($zip->set_number('6670311')->is_valid_number, '兵庫県養父市大屋町大屋市場');
ok($zip->set_number('6670312')->is_valid_number, '兵庫県養父市大屋町山路');
ok($zip->set_number('6670313')->is_valid_number, '兵庫県養父市大屋町笠谷');
ok($zip->set_number('6670314')->is_valid_number, '兵庫県養父市大屋町大杉');
ok($zip->set_number('6670315')->is_valid_number, '兵庫県養父市大屋町加保');
ok($zip->set_number('6670321')->is_valid_number, '兵庫県養父市大屋町蔵垣');
ok($zip->set_number('6670322')->is_valid_number, '兵庫県養父市大屋町筏');
ok($zip->set_number('6670323')->is_valid_number, '兵庫県養父市大屋町若杉');
ok($zip->set_number('6670324')->is_valid_number, '兵庫県養父市大屋町横行');
ok($zip->set_number('6670325')->is_valid_number, '兵庫県養父市大屋町栗ノ下');
ok($zip->set_number('6670325')->is_valid_number, '兵庫県養父市大屋町中間');
ok($zip->set_number('6670431')->is_valid_number, '兵庫県養父市大屋町糸原');
ok($zip->set_number('6670432')->is_valid_number, '兵庫県養父市大屋町宮本');
ok($zip->set_number('6670433')->is_valid_number, '兵庫県養父市大屋町門野');
ok($zip->set_number('6670434')->is_valid_number, '兵庫県養父市大屋町須西');
ok($zip->set_number('6670435')->is_valid_number, '兵庫県養父市大屋町和田');
ok($zip->set_number('6670436')->is_valid_number, '兵庫県養父市大屋町明延');
ok($zip->set_number('6671101')->is_valid_number, '兵庫県養父市三宅');
ok($zip->set_number('6671102')->is_valid_number, '兵庫県養父市大谷');
ok($zip->set_number('6671103')->is_valid_number, '兵庫県養父市万久里');
ok($zip->set_number('6671104')->is_valid_number, '兵庫県養父市尾崎');
ok($zip->set_number('6671105')->is_valid_number, '兵庫県養父市関宮');
ok($zip->set_number('6671111')->is_valid_number, '兵庫県養父市吉井');
ok($zip->set_number('6671112')->is_valid_number, '兵庫県養父市出合');
ok($zip->set_number('6671113')->is_valid_number, '兵庫県養父市川原場');
ok($zip->set_number('6671114')->is_valid_number, '兵庫県養父市小路頃');
ok($zip->set_number('6671115')->is_valid_number, '兵庫県養父市葛畑');
ok($zip->set_number('6671116')->is_valid_number, '兵庫県養父市中瀬');
ok($zip->set_number('6671117')->is_valid_number, '兵庫県養父市轟');
ok($zip->set_number('6671118')->is_valid_number, '兵庫県養父市安井');
ok($zip->set_number('6671119')->is_valid_number, '兵庫県養父市鵜縄');
ok($zip->set_number('6671121')->is_valid_number, '兵庫県養父市外野');
ok($zip->set_number('6671122')->is_valid_number, '兵庫県養父市草出');
ok($zip->set_number('6671123')->is_valid_number, '兵庫県養父市梨ケ原');
ok($zip->set_number('6671124')->is_valid_number, '兵庫県養父市丹戸');
ok($zip->set_number('6671125')->is_valid_number, '兵庫県養父市奈良尾');
ok($zip->set_number('6671126')->is_valid_number, '兵庫県養父市福定');
ok($zip->set_number('6671127')->is_valid_number, '兵庫県養父市大久保');
ok($zip->set_number('6671128')->is_valid_number, '兵庫県養父市別宮');
ok($zip->set_number('6671301')->is_valid_number, '兵庫県美方郡香美町村岡区境');
ok($zip->set_number('6671302')->is_valid_number, '兵庫県美方郡香美町村岡区山田');
ok($zip->set_number('6671303')->is_valid_number, '兵庫県美方郡香美町村岡区小城');
ok($zip->set_number('6671304')->is_valid_number, '兵庫県美方郡香美町村岡区和佐父');
ok($zip->set_number('6671311')->is_valid_number, '兵庫県美方郡香美町村岡区村岡');
ok($zip->set_number('6671312')->is_valid_number, '兵庫県美方郡香美町村岡区相田');
ok($zip->set_number('6671313')->is_valid_number, '兵庫県美方郡香美町村岡区神坂');
ok($zip->set_number('6671314')->is_valid_number, '兵庫県美方郡香美町村岡区萩山');
ok($zip->set_number('6671315')->is_valid_number, '兵庫県美方郡香美町村岡区板仕野');
ok($zip->set_number('6671316')->is_valid_number, '兵庫県美方郡香美町村岡区鹿田');
ok($zip->set_number('6671317')->is_valid_number, '兵庫県美方郡香美町村岡区用野');
ok($zip->set_number('6671321')->is_valid_number, '兵庫県美方郡香美町村岡区大糠');
ok($zip->set_number('6671322')->is_valid_number, '兵庫県美方郡香美町村岡区寺河内');
ok($zip->set_number('6671323')->is_valid_number, '兵庫県美方郡香美町村岡区耀山');
ok($zip->set_number('6671324')->is_valid_number, '兵庫県美方郡香美町村岡区市原');
ok($zip->set_number('6671325')->is_valid_number, '兵庫県美方郡香美町村岡区高井');
ok($zip->set_number('6671326')->is_valid_number, '兵庫県美方郡香美町村岡区光陽');
ok($zip->set_number('6671331')->is_valid_number, '兵庫県美方郡香美町村岡区作山');
ok($zip->set_number('6671332')->is_valid_number, '兵庫県美方郡香美町村岡区八井谷');
ok($zip->set_number('6671333')->is_valid_number, '兵庫県美方郡香美町村岡区大野');
ok($zip->set_number('6671334')->is_valid_number, '兵庫県美方郡香美町村岡区福岡');
ok($zip->set_number('6671335')->is_valid_number, '兵庫県美方郡香美町村岡区黒田');
ok($zip->set_number('6671336')->is_valid_number, '兵庫県美方郡香美町村岡区宿');
ok($zip->set_number('6671337')->is_valid_number, '兵庫県美方郡香美町村岡区日影');
ok($zip->set_number('6671341')->is_valid_number, '兵庫県美方郡香美町村岡区森脇');
ok($zip->set_number('6671342')->is_valid_number, '兵庫県美方郡香美町村岡区口大谷');
ok($zip->set_number('6671343')->is_valid_number, '兵庫県美方郡香美町村岡区中大谷');
ok($zip->set_number('6671344')->is_valid_number, '兵庫県美方郡香美町村岡区大笹');
ok($zip->set_number('6671345')->is_valid_number, '兵庫県美方郡香美町村岡区高坂');
ok($zip->set_number('6671346')->is_valid_number, '兵庫県美方郡香美町村岡区池ケ平');
ok($zip->set_number('6671347')->is_valid_number, '兵庫県美方郡香美町村岡区和池');
ok($zip->set_number('6671351')->is_valid_number, '兵庫県美方郡香美町村岡区丸味');
ok($zip->set_number('6671352')->is_valid_number, '兵庫県美方郡香美町村岡区長板');
ok($zip->set_number('6671353')->is_valid_number, '兵庫県美方郡香美町村岡区熊波');
ok($zip->set_number('6671354')->is_valid_number, '兵庫県美方郡香美町村岡区柤岡');
ok($zip->set_number('6671361')->is_valid_number, '兵庫県美方郡香美町村岡区長瀬');
ok($zip->set_number('6671362')->is_valid_number, '兵庫県美方郡香美町村岡区原');
ok($zip->set_number('6671363')->is_valid_number, '兵庫県美方郡香美町村岡区味取');
ok($zip->set_number('6671364')->is_valid_number, '兵庫県美方郡香美町村岡区長須');
ok($zip->set_number('6671365')->is_valid_number, '兵庫県美方郡香美町村岡区高津');
ok($zip->set_number('6671366')->is_valid_number, '兵庫県美方郡香美町村岡区川会');
ok($zip->set_number('6671367')->is_valid_number, '兵庫県美方郡香美町村岡区和田');
ok($zip->set_number('6671368')->is_valid_number, '兵庫県美方郡香美町村岡区入江');
ok($zip->set_number('6671501')->is_valid_number, '兵庫県美方郡香美町小代区久須部');
ok($zip->set_number('6671502')->is_valid_number, '兵庫県美方郡香美町小代区城山');
ok($zip->set_number('6671503')->is_valid_number, '兵庫県美方郡香美町小代区大谷');
ok($zip->set_number('6671511')->is_valid_number, '兵庫県美方郡香美町小代区神水');
ok($zip->set_number('6671512')->is_valid_number, '兵庫県美方郡香美町小代区石寺');
ok($zip->set_number('6671513')->is_valid_number, '兵庫県美方郡香美町小代区広井');
ok($zip->set_number('6671514')->is_valid_number, '兵庫県美方郡香美町小代区神場');
ok($zip->set_number('6671515')->is_valid_number, '兵庫県美方郡香美町小代区水間');
ok($zip->set_number('6671521')->is_valid_number, '兵庫県美方郡香美町小代区野間谷');
ok($zip->set_number('6671522')->is_valid_number, '兵庫県美方郡香美町小代区実山');
ok($zip->set_number('6671523')->is_valid_number, '兵庫県美方郡香美町小代区平野');
ok($zip->set_number('6671531')->is_valid_number, '兵庫県美方郡香美町小代区茅野');
ok($zip->set_number('6671532')->is_valid_number, '兵庫県美方郡香美町小代区新屋');
ok($zip->set_number('6671533')->is_valid_number, '兵庫県美方郡香美町小代区秋岡');
ok($zip->set_number('6671541')->is_valid_number, '兵庫県美方郡香美町小代区佐坊');
ok($zip->set_number('6671542')->is_valid_number, '兵庫県美方郡香美町小代区鍛治屋');
ok($zip->set_number('6671543')->is_valid_number, '兵庫県美方郡香美町小代区忠宮');
ok($zip->set_number('6671544')->is_valid_number, '兵庫県美方郡香美町小代区貫田');
ok($zip->set_number('6671545')->is_valid_number, '兵庫県美方郡香美町小代区東垣');
ok($zip->set_number('6680000')->is_valid_number, '兵庫県豊岡市以下に掲載がない場合');
ok($zip->set_number('6680001')->is_valid_number, '兵庫県豊岡市伊賀谷');
ok($zip->set_number('6680002')->is_valid_number, '兵庫県豊岡市岩熊');
ok($zip->set_number('6680003')->is_valid_number, '兵庫県豊岡市江野');
ok($zip->set_number('6680004')->is_valid_number, '兵庫県豊岡市新堂');
ok($zip->set_number('6680005')->is_valid_number, '兵庫県豊岡市滝');
ok($zip->set_number('6680006')->is_valid_number, '兵庫県豊岡市森津');
ok($zip->set_number('6680011')->is_valid_number, '兵庫県豊岡市上陰');
ok($zip->set_number('6680012')->is_valid_number, '兵庫県豊岡市下陰');
ok($zip->set_number('6680013')->is_valid_number, '兵庫県豊岡市中陰');
ok($zip->set_number('6680014')->is_valid_number, '兵庫県豊岡市野田');
ok($zip->set_number('6680015')->is_valid_number, '兵庫県豊岡市一日市');
ok($zip->set_number('6680016')->is_valid_number, '兵庫県豊岡市宮島');
ok($zip->set_number('6680021')->is_valid_number, '兵庫県豊岡市泉町');
ok($zip->set_number('6680022')->is_valid_number, '兵庫県豊岡市小田井町');
ok($zip->set_number('6680023')->is_valid_number, '兵庫県豊岡市加広町');
ok($zip->set_number('6680024')->is_valid_number, '兵庫県豊岡市寿町');
ok($zip->set_number('6680025')->is_valid_number, '兵庫県豊岡市幸町');
ok($zip->set_number('6680026')->is_valid_number, '兵庫県豊岡市元町');
ok($zip->set_number('6680027')->is_valid_number, '兵庫県豊岡市若松町');
ok($zip->set_number('6680031')->is_valid_number, '兵庫県豊岡市大手町');
ok($zip->set_number('6680032')->is_valid_number, '兵庫県豊岡市千代田町');
ok($zip->set_number('6680033')->is_valid_number, '兵庫県豊岡市中央町');
ok($zip->set_number('6680041')->is_valid_number, '兵庫県豊岡市大磯町');
ok($zip->set_number('6680042')->is_valid_number, '兵庫県豊岡市京町');
ok($zip->set_number('6680043')->is_valid_number, '兵庫県豊岡市桜町');
ok($zip->set_number('6680044')->is_valid_number, '兵庫県豊岡市山王町');
ok($zip->set_number('6680045')->is_valid_number, '兵庫県豊岡市城南町');
ok($zip->set_number('6680046')->is_valid_number, '兵庫県豊岡市立野町');
ok($zip->set_number('6680047')->is_valid_number, '兵庫県豊岡市三坂町');
ok($zip->set_number('6680051')->is_valid_number, '兵庫県豊岡市九日市上町');
ok($zip->set_number('6680052')->is_valid_number, '兵庫県豊岡市九日市下町');
ok($zip->set_number('6680053')->is_valid_number, '兵庫県豊岡市九日市中町');
ok($zip->set_number('6680054')->is_valid_number, '兵庫県豊岡市塩津町');
ok($zip->set_number('6680055')->is_valid_number, '兵庫県豊岡市昭和町');
ok($zip->set_number('6680056')->is_valid_number, '兵庫県豊岡市妙楽寺');
ok($zip->set_number('6680057')->is_valid_number, '兵庫県豊岡市弥栄町');
ok($zip->set_number('6680061')->is_valid_number, '兵庫県豊岡市上佐野');
ok($zip->set_number('6680062')->is_valid_number, '兵庫県豊岡市佐野');
ok($zip->set_number('6680063')->is_valid_number, '兵庫県豊岡市正法寺');
ok($zip->set_number('6680064')->is_valid_number, '兵庫県豊岡市高屋');
ok($zip->set_number('6680065')->is_valid_number, '兵庫県豊岡市戸牧');
ok($zip->set_number('6680071')->is_valid_number, '兵庫県豊岡市内町');
ok($zip->set_number('6680072')->is_valid_number, '兵庫県豊岡市大谷');
ok($zip->set_number('6680073')->is_valid_number, '兵庫県豊岡市辻');
ok($zip->set_number('6680074')->is_valid_number, '兵庫県豊岡市野垣');
ok($zip->set_number('6680075')->is_valid_number, '兵庫県豊岡市福成寺');
ok($zip->set_number('6680076')->is_valid_number, '兵庫県豊岡市船谷');
ok($zip->set_number('6680077')->is_valid_number, '兵庫県豊岡市目坂');
ok($zip->set_number('6680078')->is_valid_number, '兵庫県豊岡市吉井');
ok($zip->set_number('6680081')->is_valid_number, '兵庫県豊岡市岩井');
ok($zip->set_number('6680082')->is_valid_number, '兵庫県豊岡市庄');
ok($zip->set_number('6680083')->is_valid_number, '兵庫県豊岡市栃江');
ok($zip->set_number('6680084')->is_valid_number, '兵庫県豊岡市福田');
ok($zip->set_number('6680085')->is_valid_number, '兵庫県豊岡市宮井');
ok($zip->set_number('6680201')->is_valid_number, '兵庫県豊岡市出石町奥小野');
ok($zip->set_number('6680202')->is_valid_number, '兵庫県豊岡市出石町口小野');
ok($zip->set_number('6680203')->is_valid_number, '兵庫県豊岡市出石町袴狭');
ok($zip->set_number('6680204')->is_valid_number, '兵庫県豊岡市出石町宮内');
ok($zip->set_number('6680205')->is_valid_number, '兵庫県豊岡市出石町嶋');
ok($zip->set_number('6680206')->is_valid_number, '兵庫県豊岡市出石町福居');
ok($zip->set_number('6680207')->is_valid_number, '兵庫県豊岡市出石町伊豆');
ok($zip->set_number('6680208')->is_valid_number, '兵庫県豊岡市出石町安良');
ok($zip->set_number('6680209')->is_valid_number, '兵庫県豊岡市出石町田多地');
ok($zip->set_number('6680211')->is_valid_number, '兵庫県豊岡市出石町下谷');
ok($zip->set_number('6680212')->is_valid_number, '兵庫県豊岡市出石町谷山');
ok($zip->set_number('6680213')->is_valid_number, '兵庫県豊岡市出石町伊木');
ok($zip->set_number('6680214')->is_valid_number, '兵庫県豊岡市出石町内町');
ok($zip->set_number('6680215')->is_valid_number, '兵庫県豊岡市出石町魚屋');
ok($zip->set_number('6680216')->is_valid_number, '兵庫県豊岡市出石町材木');
ok($zip->set_number('6680217')->is_valid_number, '兵庫県豊岡市出石町東條');
ok($zip->set_number('6680218')->is_valid_number, '兵庫県豊岡市出石町入佐');
ok($zip->set_number('6680221')->is_valid_number, '兵庫県豊岡市出石町町分');
ok($zip->set_number('6680222')->is_valid_number, '兵庫県豊岡市出石町寺町');
ok($zip->set_number('6680223')->is_valid_number, '兵庫県豊岡市出石町鉄砲');
ok($zip->set_number('6680224')->is_valid_number, '兵庫県豊岡市出石町本町');
ok($zip->set_number('6680225')->is_valid_number, '兵庫県豊岡市出石町八木');
ok($zip->set_number('6680231')->is_valid_number, '兵庫県豊岡市出石町川原');
ok($zip->set_number('6680232')->is_valid_number, '兵庫県豊岡市出石町宵田');
ok($zip->set_number('6680233')->is_valid_number, '兵庫県豊岡市出石町田結庄');
ok($zip->set_number('6680234')->is_valid_number, '兵庫県豊岡市出石町柳');
ok($zip->set_number('6680235')->is_valid_number, '兵庫県豊岡市出石町鍛冶屋');
ok($zip->set_number('6680236')->is_valid_number, '兵庫県豊岡市出石町松枝');
ok($zip->set_number('6680237')->is_valid_number, '兵庫県豊岡市出石町馬場');
ok($zip->set_number('6680238')->is_valid_number, '兵庫県豊岡市出石町弘原');
ok($zip->set_number('6680241')->is_valid_number, '兵庫県豊岡市出石町寺坂');
ok($zip->set_number('6680242')->is_valid_number, '兵庫県豊岡市出石町桐野');
ok($zip->set_number('6680243')->is_valid_number, '兵庫県豊岡市出石町中野');
ok($zip->set_number('6680244')->is_valid_number, '兵庫県豊岡市出石町上野');
ok($zip->set_number('6680245')->is_valid_number, '兵庫県豊岡市出石町百合');
ok($zip->set_number('6680246')->is_valid_number, '兵庫県豊岡市出石町日野辺');
ok($zip->set_number('6680251')->is_valid_number, '兵庫県豊岡市出石町奥山');
ok($zip->set_number('6680252')->is_valid_number, '兵庫県豊岡市出石町和屋');
ok($zip->set_number('6680253')->is_valid_number, '兵庫県豊岡市出石町榎見');
ok($zip->set_number('6680254')->is_valid_number, '兵庫県豊岡市出石町中村');
ok($zip->set_number('6680255')->is_valid_number, '兵庫県豊岡市出石町上村');
ok($zip->set_number('6680256')->is_valid_number, '兵庫県豊岡市出石町小人');
ok($zip->set_number('6680257')->is_valid_number, '兵庫県豊岡市出石町坪口');
ok($zip->set_number('6680261')->is_valid_number, '兵庫県豊岡市出石町荒木');
ok($zip->set_number('6680262')->is_valid_number, '兵庫県豊岡市出石町細見');
ok($zip->set_number('6680263')->is_valid_number, '兵庫県豊岡市出石町福住');
ok($zip->set_number('6680264')->is_valid_number, '兵庫県豊岡市出石町暮坂');
ok($zip->set_number('6680265')->is_valid_number, '兵庫県豊岡市出石町福見');
ok($zip->set_number('6680266')->is_valid_number, '兵庫県豊岡市出石町平田');
ok($zip->set_number('6680271')->is_valid_number, '兵庫県豊岡市出石町大谷');
ok($zip->set_number('6680272')->is_valid_number, '兵庫県豊岡市出石町鳥居');
ok($zip->set_number('6680273')->is_valid_number, '兵庫県豊岡市出石町坪井');
ok($zip->set_number('6680274')->is_valid_number, '兵庫県豊岡市出石町水上');
ok($zip->set_number('6680275')->is_valid_number, '兵庫県豊岡市出石町長砂');
ok($zip->set_number('6680276')->is_valid_number, '兵庫県豊岡市出石町森井');
ok($zip->set_number('6680277')->is_valid_number, '兵庫県豊岡市出石町丸中');
ok($zip->set_number('6680278')->is_valid_number, '兵庫県豊岡市出石町三木');
ok($zip->set_number('6680279')->is_valid_number, '兵庫県豊岡市出石町片間');
ok($zip->set_number('6680301')->is_valid_number, '兵庫県豊岡市但東町奥矢根');
ok($zip->set_number('6680302')->is_valid_number, '兵庫県豊岡市但東町矢根');
ok($zip->set_number('6680303')->is_valid_number, '兵庫県豊岡市但東町畑');
ok($zip->set_number('6680304')->is_valid_number, '兵庫県豊岡市但東町水石');
ok($zip->set_number('6680311')->is_valid_number, '兵庫県豊岡市但東町出合');
ok($zip->set_number('6680312')->is_valid_number, '兵庫県豊岡市但東町南尾');
ok($zip->set_number('6680313')->is_valid_number, '兵庫県豊岡市但東町出合市場');
ok($zip->set_number('6680314')->is_valid_number, '兵庫県豊岡市但東町日殿');
ok($zip->set_number('6680315')->is_valid_number, '兵庫県豊岡市但東町河本');
ok($zip->set_number('6680316')->is_valid_number, '兵庫県豊岡市但東町天谷');
ok($zip->set_number('6680317')->is_valid_number, '兵庫県豊岡市但東町西谷');
ok($zip->set_number('6680321')->is_valid_number, '兵庫県豊岡市但東町唐川');
ok($zip->set_number('6680322')->is_valid_number, '兵庫県豊岡市但東町三原');
ok($zip->set_number('6680323')->is_valid_number, '兵庫県豊岡市但東町小谷');
ok($zip->set_number('6680324')->is_valid_number, '兵庫県豊岡市但東町相田');
ok($zip->set_number('6680325')->is_valid_number, '兵庫県豊岡市但東町佐々木');
ok($zip->set_number('6680331')->is_valid_number, '兵庫県豊岡市但東町木村');
ok($zip->set_number('6680332')->is_valid_number, '兵庫県豊岡市但東町西野々');
ok($zip->set_number('6680333')->is_valid_number, '兵庫県豊岡市但東町高龍寺');
ok($zip->set_number('6680334')->is_valid_number, '兵庫県豊岡市但東町坂野');
ok($zip->set_number('6680335')->is_valid_number, '兵庫県豊岡市但東町太田');
ok($zip->set_number('6680336')->is_valid_number, '兵庫県豊岡市但東町日向');
ok($zip->set_number('6680337')->is_valid_number, '兵庫県豊岡市但東町東里');
ok($zip->set_number('6680341')->is_valid_number, '兵庫県豊岡市但東町口藤');
ok($zip->set_number('6680342')->is_valid_number, '兵庫県豊岡市但東町中藤');
ok($zip->set_number('6680343')->is_valid_number, '兵庫県豊岡市但東町奥藤');
ok($zip->set_number('6680344')->is_valid_number, '兵庫県豊岡市但東町虫生');
ok($zip->set_number('6680345')->is_valid_number, '兵庫県豊岡市但東町中山');
ok($zip->set_number('6680351')->is_valid_number, '兵庫県豊岡市但東町畑山');
ok($zip->set_number('6680352')->is_valid_number, '兵庫県豊岡市但東町赤花');
ok($zip->set_number('6680353')->is_valid_number, '兵庫県豊岡市但東町奥赤');
ok($zip->set_number('6680354')->is_valid_number, '兵庫県豊岡市但東町坂津');
ok($zip->set_number('6680361')->is_valid_number, '兵庫県豊岡市但東町正法寺');
ok($zip->set_number('6680362')->is_valid_number, '兵庫県豊岡市但東町平田');
ok($zip->set_number('6680363')->is_valid_number, '兵庫県豊岡市但東町栗尾');
ok($zip->set_number('6680364')->is_valid_number, '兵庫県豊岡市但東町佐田');
ok($zip->set_number('6680371')->is_valid_number, '兵庫県豊岡市但東町薬王寺');
ok($zip->set_number('6680372')->is_valid_number, '兵庫県豊岡市但東町大河内');
ok($zip->set_number('6680373')->is_valid_number, '兵庫県豊岡市但東町久畑');
ok($zip->set_number('6680374')->is_valid_number, '兵庫県豊岡市但東町後');
ok($zip->set_number('6680375')->is_valid_number, '兵庫県豊岡市但東町東中');
ok($zip->set_number('6680376')->is_valid_number, '兵庫県豊岡市但東町小坂');
ok($zip->set_number('6680801')->is_valid_number, '兵庫県豊岡市赤石');
ok($zip->set_number('6680802')->is_valid_number, '兵庫県豊岡市金剛寺');
ok($zip->set_number('6680803')->is_valid_number, '兵庫県豊岡市下鶴井');
ok($zip->set_number('6680804')->is_valid_number, '兵庫県豊岡市野上');
ok($zip->set_number('6680805')->is_valid_number, '兵庫県豊岡市船町');
ok($zip->set_number('6680806')->is_valid_number, '兵庫県豊岡市森');
ok($zip->set_number('6680807')->is_valid_number, '兵庫県豊岡市山本');
ok($zip->set_number('6680811')->is_valid_number, '兵庫県豊岡市鎌田');
ok($zip->set_number('6680812')->is_valid_number, '兵庫県豊岡市栄町');
ok($zip->set_number('6680813')->is_valid_number, '兵庫県豊岡市下宮');
ok($zip->set_number('6680814')->is_valid_number, '兵庫県豊岡市祥雲寺');
ok($zip->set_number('6680815')->is_valid_number, '兵庫県豊岡市日撫');
ok($zip->set_number('6680816')->is_valid_number, '兵庫県豊岡市法花寺');
ok($zip->set_number('6680817')->is_valid_number, '兵庫県豊岡市六地蔵');
ok($zip->set_number('6680821')->is_valid_number, '兵庫県豊岡市市場');
ok($zip->set_number('6680822')->is_valid_number, '兵庫県豊岡市奥野');
ok($zip->set_number('6680823')->is_valid_number, '兵庫県豊岡市三宅');
ok($zip->set_number('6680824')->is_valid_number, '兵庫県豊岡市森尾');
ok($zip->set_number('6680831')->is_valid_number, '兵庫県豊岡市神美台');
ok($zip->set_number('6680832')->is_valid_number, '兵庫県豊岡市倉見');
ok($zip->set_number('6680833')->is_valid_number, '兵庫県豊岡市立石');
ok($zip->set_number('6680834')->is_valid_number, '兵庫県豊岡市長谷');
ok($zip->set_number('6680841')->is_valid_number, '兵庫県豊岡市加陽');
ok($zip->set_number('6680842')->is_valid_number, '兵庫県豊岡市中郷');
ok($zip->set_number('6680843')->is_valid_number, '兵庫県豊岡市引野');
ok($zip->set_number('6680844')->is_valid_number, '兵庫県豊岡市土渕');
ok($zip->set_number('6680851')->is_valid_number, '兵庫県豊岡市今森');
ok($zip->set_number('6680852')->is_valid_number, '兵庫県豊岡市江本');
ok($zip->set_number('6680853')->is_valid_number, '兵庫県豊岡市清冷寺');
ok($zip->set_number('6680854')->is_valid_number, '兵庫県豊岡市八社宮');
ok($zip->set_number('6680855')->is_valid_number, '兵庫県豊岡市伏');
ok($zip->set_number('6680861')->is_valid_number, '兵庫県豊岡市大篠岡');
ok($zip->set_number('6680862')->is_valid_number, '兵庫県豊岡市香住');
ok($zip->set_number('6680863')->is_valid_number, '兵庫県豊岡市上鉢山');
ok($zip->set_number('6680864')->is_valid_number, '兵庫県豊岡市木内');
ok($zip->set_number('6680865')->is_valid_number, '兵庫県豊岡市下鉢山');
ok($zip->set_number('6680866')->is_valid_number, '兵庫県豊岡市駄坂');
ok($zip->set_number('6680871')->is_valid_number, '兵庫県豊岡市梶原');
ok($zip->set_number('6680872')->is_valid_number, '兵庫県豊岡市河谷');
ok($zip->set_number('6680873')->is_valid_number, '兵庫県豊岡市庄境');
ok($zip->set_number('6680874')->is_valid_number, '兵庫県豊岡市中谷');
ok($zip->set_number('6680875')->is_valid_number, '兵庫県豊岡市百合地');
ok($zip->set_number('6691101')->is_valid_number, '兵庫県西宮市塩瀬町生瀬');
ok($zip->set_number('6691102')->is_valid_number, '兵庫県西宮市生瀬町');
ok($zip->set_number('6691103')->is_valid_number, '兵庫県西宮市生瀬東町');
ok($zip->set_number('6691104')->is_valid_number, '兵庫県西宮市生瀬武庫川町');
ok($zip->set_number('6691111')->is_valid_number, '兵庫県西宮市生瀬高台');
ok($zip->set_number('6691112')->is_valid_number, '兵庫県西宮市宝生ケ丘');
ok($zip->set_number('6691121')->is_valid_number, '兵庫県西宮市花の峯');
ok($zip->set_number('6691122')->is_valid_number, '兵庫県西宮市青葉台');
ok($zip->set_number('6691131')->is_valid_number, '兵庫県西宮市清瀬台');
ok($zip->set_number('6691132')->is_valid_number, '兵庫県西宮市名塩南台');
ok($zip->set_number('6691133')->is_valid_number, '兵庫県西宮市東山台');
ok($zip->set_number('6691134')->is_valid_number, '兵庫県西宮市名塩新町');
ok($zip->set_number('6691135')->is_valid_number, '兵庫県西宮市国見台');
ok($zip->set_number('6691136')->is_valid_number, '兵庫県西宮市名塩木之元');
ok($zip->set_number('6691141')->is_valid_number, '兵庫県西宮市塩瀬町名塩(その他)');
ok($zip->set_number('6691142')->is_valid_number, '兵庫県西宮市名塩山荘');
ok($zip->set_number('6691143')->is_valid_number, '兵庫県西宮市名塩ガーデン');
ok($zip->set_number('6691144')->is_valid_number, '兵庫県西宮市名塩茶園町');
ok($zip->set_number('6691145')->is_valid_number, '兵庫県西宮市名塩平成台');
ok($zip->set_number('6691146')->is_valid_number, '兵庫県西宮市名塩さくら台');
ok($zip->set_number('6691147')->is_valid_number, '兵庫県西宮市名塩');
ok($zip->set_number('6691148')->is_valid_number, '兵庫県西宮市名塩東久保');
ok($zip->set_number('6691149')->is_valid_number, '兵庫県西宮市名塩赤坂');
ok($zip->set_number('6691161')->is_valid_number, '兵庫県神戸市北区道場町生野(1172番地)');
ok($zip->set_number('6691162')->is_valid_number, '兵庫県西宮市名塩美山');
ok($zip->set_number('6691201')->is_valid_number, '兵庫県宝塚市香合新田');
ok($zip->set_number('6691202')->is_valid_number, '兵庫県宝塚市上佐曽利');
ok($zip->set_number('6691203')->is_valid_number, '兵庫県宝塚市下佐曽利');
ok($zip->set_number('6691204')->is_valid_number, '兵庫県宝塚市長谷');
ok($zip->set_number('6691205')->is_valid_number, '兵庫県宝塚市芝辻新田');
ok($zip->set_number('6691211')->is_valid_number, '兵庫県宝塚市大原野');
ok($zip->set_number('6691221')->is_valid_number, '兵庫県宝塚市波豆');
ok($zip->set_number('6691222')->is_valid_number, '兵庫県宝塚市境野');
ok($zip->set_number('6691231')->is_valid_number, '兵庫県宝塚市玉瀬');
ok($zip->set_number('6691241')->is_valid_number, '兵庫県宝塚市切畑(長尾山19-64)');
ok($zip->set_number('6691241')->is_valid_number, '兵庫県宝塚市切畑(その他)');
ok($zip->set_number('6691251')->is_valid_number, '兵庫県西宮市塩瀬町名塩(4205-1、5205、5313-20、5313-33、');
ok($zip->set_number('6691251')->is_valid_number, '兵庫県西宮市5313-35番地)');
ok($zip->set_number('6691300')->is_valid_number, '兵庫県三田市以下に掲載がない場合');
ok($zip->set_number('6691301')->is_valid_number, '兵庫県三田市上青野');
ok($zip->set_number('6691302')->is_valid_number, '兵庫県三田市下青野');
ok($zip->set_number('6691303')->is_valid_number, '兵庫県三田市末');
ok($zip->set_number('6691304')->is_valid_number, '兵庫県三田市北浦');
ok($zip->set_number('6691311')->is_valid_number, '兵庫県三田市加茂');
ok($zip->set_number('6691312')->is_valid_number, '兵庫県三田市東野上');
ok($zip->set_number('6691313')->is_valid_number, '兵庫県三田市福島');
ok($zip->set_number('6691314')->is_valid_number, '兵庫県三田市西野上');
ok($zip->set_number('6691315')->is_valid_number, '兵庫県三田市下井沢');
ok($zip->set_number('6691316')->is_valid_number, '兵庫県三田市上井沢');
ok($zip->set_number('6691317')->is_valid_number, '兵庫県三田市宮脇');
ok($zip->set_number('6691321')->is_valid_number, '兵庫県三田市けやき台');
ok($zip->set_number('6691322')->is_valid_number, '兵庫県三田市すずかけ台');
ok($zip->set_number('6691323')->is_valid_number, '兵庫県三田市あかしあ台');
ok($zip->set_number('6691324')->is_valid_number, '兵庫県三田市ゆりのき台');
ok($zip->set_number('6691325')->is_valid_number, '兵庫県三田市さくら坂');
ok($zip->set_number('6691330')->is_valid_number, '兵庫県三田市学園上ケ原');
ok($zip->set_number('6691331')->is_valid_number, '兵庫県三田市広野');
ok($zip->set_number('6691332')->is_valid_number, '兵庫県三田市広沢');
ok($zip->set_number('6691333')->is_valid_number, '兵庫県三田市下内神');
ok($zip->set_number('6691334')->is_valid_number, '兵庫県三田市中内神');
ok($zip->set_number('6691335')->is_valid_number, '兵庫県三田市沢谷');
ok($zip->set_number('6691336')->is_valid_number, '兵庫県三田市馬渡');
ok($zip->set_number('6691337')->is_valid_number, '兵庫県三田市学園');
ok($zip->set_number('6691338')->is_valid_number, '兵庫県三田市上内神');
ok($zip->set_number('6691339')->is_valid_number, '兵庫県三田市テクノパーク');
ok($zip->set_number('6691341')->is_valid_number, '兵庫県三田市西相野');
ok($zip->set_number('6691342')->is_valid_number, '兵庫県三田市四ツ辻');
ok($zip->set_number('6691343')->is_valid_number, '兵庫県三田市洞');
ok($zip->set_number('6691344')->is_valid_number, '兵庫県三田市溝口');
ok($zip->set_number('6691345')->is_valid_number, '兵庫県三田市下相野');
ok($zip->set_number('6691346')->is_valid_number, '兵庫県三田市上相野');
ok($zip->set_number('6691347')->is_valid_number, '兵庫県三田市つつじが丘南');
ok($zip->set_number('6691348')->is_valid_number, '兵庫県三田市つつじが丘北');
ok($zip->set_number('6691349')->is_valid_number, '兵庫県三田市大川瀬');
ok($zip->set_number('6691351')->is_valid_number, '兵庫県三田市上本庄');
ok($zip->set_number('6691352')->is_valid_number, '兵庫県三田市須磨田');
ok($zip->set_number('6691353')->is_valid_number, '兵庫県三田市東山');
ok($zip->set_number('6691354')->is_valid_number, '兵庫県三田市大畑');
ok($zip->set_number('6691355')->is_valid_number, '兵庫県三田市長坂');
ok($zip->set_number('6691356')->is_valid_number, '兵庫県三田市井ノ草');
ok($zip->set_number('6691357')->is_valid_number, '兵庫県三田市東本庄');
ok($zip->set_number('6691358')->is_valid_number, '兵庫県三田市藍本');
ok($zip->set_number('6691401')->is_valid_number, '兵庫県三田市小柿');
ok($zip->set_number('6691402')->is_valid_number, '兵庫県三田市末吉');
ok($zip->set_number('6691403')->is_valid_number, '兵庫県三田市川原');
ok($zip->set_number('6691404')->is_valid_number, '兵庫県三田市十倉');
ok($zip->set_number('6691405')->is_valid_number, '兵庫県三田市酒井');
ok($zip->set_number('6691406')->is_valid_number, '兵庫県三田市田中');
ok($zip->set_number('6691407')->is_valid_number, '兵庫県三田市布木');
ok($zip->set_number('6691411')->is_valid_number, '兵庫県三田市波豆川');
ok($zip->set_number('6691412')->is_valid_number, '兵庫県三田市木器');
ok($zip->set_number('6691413')->is_valid_number, '兵庫県三田市下槻瀬');
ok($zip->set_number('6691414')->is_valid_number, '兵庫県三田市市之瀬');
ok($zip->set_number('6691415')->is_valid_number, '兵庫県三田市上槻瀬');
ok($zip->set_number('6691416')->is_valid_number, '兵庫県三田市下里');
ok($zip->set_number('6691417')->is_valid_number, '兵庫県三田市鈴鹿');
ok($zip->set_number('6691501')->is_valid_number, '兵庫県三田市母子');
ok($zip->set_number('6691502')->is_valid_number, '兵庫県三田市永沢寺');
ok($zip->set_number('6691503')->is_valid_number, '兵庫県三田市乙原');
ok($zip->set_number('6691504')->is_valid_number, '兵庫県三田市小野');
ok($zip->set_number('6691505')->is_valid_number, '兵庫県三田市尼寺');
ok($zip->set_number('6691506')->is_valid_number, '兵庫県三田市志手原');
ok($zip->set_number('6691507')->is_valid_number, '兵庫県三田市香下');
ok($zip->set_number('6691511')->is_valid_number, '兵庫県三田市山田');
ok($zip->set_number('6691512')->is_valid_number, '兵庫県三田市高次');
ok($zip->set_number('6691513')->is_valid_number, '兵庫県三田市三輪');
ok($zip->set_number('6691514')->is_valid_number, '兵庫県三田市川除');
ok($zip->set_number('6691515')->is_valid_number, '兵庫県三田市大原');
ok($zip->set_number('6691516')->is_valid_number, '兵庫県三田市友が丘');
ok($zip->set_number('6691517')->is_valid_number, '兵庫県三田市成谷');
ok($zip->set_number('6691521')->is_valid_number, '兵庫県三田市桑原');
ok($zip->set_number('6691522')->is_valid_number, '兵庫県三田市下田中');
ok($zip->set_number('6691523')->is_valid_number, '兵庫県三田市寺村町');
ok($zip->set_number('6691524')->is_valid_number, '兵庫県三田市八景町');
ok($zip->set_number('6691525')->is_valid_number, '兵庫県三田市対中町');
ok($zip->set_number('6691526')->is_valid_number, '兵庫県三田市相生町');
ok($zip->set_number('6691527')->is_valid_number, '兵庫県三田市中町');
ok($zip->set_number('6691528')->is_valid_number, '兵庫県三田市駅前町');
ok($zip->set_number('6691529')->is_valid_number, '兵庫県三田市中央町');
ok($zip->set_number('6691531')->is_valid_number, '兵庫県三田市天神');
ok($zip->set_number('6691532')->is_valid_number, '兵庫県三田市屋敷町');
ok($zip->set_number('6691533')->is_valid_number, '兵庫県三田市三田町');
ok($zip->set_number('6691534')->is_valid_number, '兵庫県三田市横山町');
ok($zip->set_number('6691535')->is_valid_number, '兵庫県三田市南が丘');
ok($zip->set_number('6691536')->is_valid_number, '兵庫県三田市三田市の次に番地がくる場合');
ok($zip->set_number('6691537')->is_valid_number, '兵庫県三田市西山');
ok($zip->set_number('6691541')->is_valid_number, '兵庫県三田市貴志');
ok($zip->set_number('6691542')->is_valid_number, '兵庫県三田市上深田');
ok($zip->set_number('6691543')->is_valid_number, '兵庫県三田市下深田');
ok($zip->set_number('6691544')->is_valid_number, '兵庫県三田市武庫が丘');
ok($zip->set_number('6691545')->is_valid_number, '兵庫県三田市狭間が丘');
ok($zip->set_number('6691546')->is_valid_number, '兵庫県三田市弥生が丘');
ok($zip->set_number('6691547')->is_valid_number, '兵庫県三田市富士が丘');
ok($zip->set_number('6691548')->is_valid_number, '兵庫県三田市池尻');
ok($zip->set_number('6692101')->is_valid_number, '兵庫県丹波篠山市初田');
ok($zip->set_number('6692102')->is_valid_number, '兵庫県丹波篠山市南矢代');
ok($zip->set_number('6692103')->is_valid_number, '兵庫県丹波篠山市波賀野');
ok($zip->set_number('6692104')->is_valid_number, '兵庫県丹波篠山市矢代新');
ok($zip->set_number('6692105')->is_valid_number, '兵庫県丹波篠山市犬飼');
ok($zip->set_number('6692106')->is_valid_number, '兵庫県丹波篠山市牛ケ瀬');
ok($zip->set_number('6692111')->is_valid_number, '兵庫県丹波篠山市当野');
ok($zip->set_number('6692112')->is_valid_number, '兵庫県丹波篠山市古森');
ok($zip->set_number('6692113')->is_valid_number, '兵庫県丹波篠山市草野');
ok($zip->set_number('6692114')->is_valid_number, '兵庫県丹波篠山市油井');
ok($zip->set_number('6692121')->is_valid_number, '兵庫県丹波篠山市見内');
ok($zip->set_number('6692122')->is_valid_number, '兵庫県丹波篠山市波賀野新田');
ok($zip->set_number('6692123')->is_valid_number, '兵庫県丹波篠山市古市');
ok($zip->set_number('6692124')->is_valid_number, '兵庫県丹波篠山市不来坂');
ok($zip->set_number('6692125')->is_valid_number, '兵庫県丹波篠山市住山');
ok($zip->set_number('6692131')->is_valid_number, '兵庫県丹波篠山市今田町辰巳');
ok($zip->set_number('6692132')->is_valid_number, '兵庫県丹波篠山市今田町上小野原');
ok($zip->set_number('6692133')->is_valid_number, '兵庫県丹波篠山市今田町下小野原');
ok($zip->set_number('6692134')->is_valid_number, '兵庫県丹波篠山市今田町休場');
ok($zip->set_number('6692135')->is_valid_number, '兵庫県丹波篠山市今田町上立杭');
ok($zip->set_number('6692141')->is_valid_number, '兵庫県丹波篠山市今田町下立杭');
ok($zip->set_number('6692142')->is_valid_number, '兵庫県丹波篠山市今田町東庄');
ok($zip->set_number('6692143')->is_valid_number, '兵庫県丹波篠山市今田町釜屋');
ok($zip->set_number('6692144')->is_valid_number, '兵庫県丹波篠山市今田町間新田');
ok($zip->set_number('6692145')->is_valid_number, '兵庫県丹波篠山市今田町木津');
ok($zip->set_number('6692151')->is_valid_number, '兵庫県丹波篠山市今田町今田');
ok($zip->set_number('6692152')->is_valid_number, '兵庫県丹波篠山市今田町荻野分');
ok($zip->set_number('6692153')->is_valid_number, '兵庫県丹波篠山市今田町今田新田');
ok($zip->set_number('6692154')->is_valid_number, '兵庫県丹波篠山市今田町市原');
ok($zip->set_number('6692155')->is_valid_number, '兵庫県丹波篠山市今田町芦原新田');
ok($zip->set_number('6692156')->is_valid_number, '兵庫県丹波篠山市今田町佐曽良新田');
ok($zip->set_number('6692161')->is_valid_number, '兵庫県丹波篠山市今田町四斗谷');
ok($zip->set_number('6692162')->is_valid_number, '兵庫県丹波篠山市今田町黒石');
ok($zip->set_number('6692163')->is_valid_number, '兵庫県丹波篠山市今田町本荘');
ok($zip->set_number('6692201')->is_valid_number, '兵庫県丹波篠山市東古佐');
ok($zip->set_number('6692202')->is_valid_number, '兵庫県丹波篠山市東吹');
ok($zip->set_number('6692203')->is_valid_number, '兵庫県丹波篠山市吹新');
ok($zip->set_number('6692204')->is_valid_number, '兵庫県丹波篠山市杉');
ok($zip->set_number('6692205')->is_valid_number, '兵庫県丹波篠山市網掛');
ok($zip->set_number('6692206')->is_valid_number, '兵庫県丹波篠山市西吹');
ok($zip->set_number('6692211')->is_valid_number, '兵庫県丹波篠山市大沢新');
ok($zip->set_number('6692212')->is_valid_number, '兵庫県丹波篠山市大沢');
ok($zip->set_number('6692213')->is_valid_number, '兵庫県丹波篠山市中野');
ok($zip->set_number('6692214')->is_valid_number, '兵庫県丹波篠山市味間新');
ok($zip->set_number('6692221')->is_valid_number, '兵庫県丹波篠山市西古佐');
ok($zip->set_number('6692222')->is_valid_number, '兵庫県丹波篠山市味間南');
ok($zip->set_number('6692223')->is_valid_number, '兵庫県丹波篠山市味間奥');
ok($zip->set_number('6692224')->is_valid_number, '兵庫県丹波篠山市味間北');
ok($zip->set_number('6692231')->is_valid_number, '兵庫県丹波篠山市住吉台');
ok($zip->set_number('6692300')->is_valid_number, '兵庫県丹波篠山市以下に掲載がない場合');
ok($zip->set_number('6692301')->is_valid_number, '兵庫県丹波篠山市火打岩');
ok($zip->set_number('6692302')->is_valid_number, '兵庫県丹波篠山市奥畑');
ok($zip->set_number('6692303')->is_valid_number, '兵庫県丹波篠山市瀬利');
ok($zip->set_number('6692304')->is_valid_number, '兵庫県丹波篠山市今谷');
ok($zip->set_number('6692305')->is_valid_number, '兵庫県丹波篠山市畑宮');
ok($zip->set_number('6692306')->is_valid_number, '兵庫県丹波篠山市大上');
ok($zip->set_number('6692307')->is_valid_number, '兵庫県丹波篠山市般若寺');
ok($zip->set_number('6692308')->is_valid_number, '兵庫県丹波篠山市和田');
ok($zip->set_number('6692309')->is_valid_number, '兵庫県丹波篠山市大渕');
ok($zip->set_number('6692311')->is_valid_number, '兵庫県丹波篠山市新荘');
ok($zip->set_number('6692312')->is_valid_number, '兵庫県丹波篠山市菅');
ok($zip->set_number('6692313')->is_valid_number, '兵庫県丹波篠山市野間');
ok($zip->set_number('6692314')->is_valid_number, '兵庫県丹波篠山市東沢田');
ok($zip->set_number('6692315')->is_valid_number, '兵庫県丹波篠山市筋山');
ok($zip->set_number('6692316')->is_valid_number, '兵庫県丹波篠山市前沢田');
ok($zip->set_number('6692317')->is_valid_number, '兵庫県丹波篠山市北沢田');
ok($zip->set_number('6692318')->is_valid_number, '兵庫県丹波篠山市大熊');
ok($zip->set_number('6692321')->is_valid_number, '兵庫県丹波篠山市黒岡');
ok($zip->set_number('6692322')->is_valid_number, '兵庫県丹波篠山市呉服町');
ok($zip->set_number('6692323')->is_valid_number, '兵庫県丹波篠山市立町');
ok($zip->set_number('6692324')->is_valid_number, '兵庫県丹波篠山市東新町');
ok($zip->set_number('6692325')->is_valid_number, '兵庫県丹波篠山市河原町');
ok($zip->set_number('6692326')->is_valid_number, '兵庫県丹波篠山市小川町');
ok($zip->set_number('6692331')->is_valid_number, '兵庫県丹波篠山市二階町');
ok($zip->set_number('6692332')->is_valid_number, '兵庫県丹波篠山市北新町');
ok($zip->set_number('6692333')->is_valid_number, '兵庫県丹波篠山市南新町');
ok($zip->set_number('6692334')->is_valid_number, '兵庫県丹波篠山市西新町');
ok($zip->set_number('6692335')->is_valid_number, '兵庫県丹波篠山市乾新町');
ok($zip->set_number('6692336')->is_valid_number, '兵庫県丹波篠山市魚屋町');
ok($zip->set_number('6692337')->is_valid_number, '兵庫県丹波篠山市山内町');
ok($zip->set_number('6692341')->is_valid_number, '兵庫県丹波篠山市郡家');
ok($zip->set_number('6692342')->is_valid_number, '兵庫県丹波篠山市西町');
ok($zip->set_number('6692343')->is_valid_number, '兵庫県丹波篠山市風深');
ok($zip->set_number('6692344')->is_valid_number, '兵庫県丹波篠山市吹上');
ok($zip->set_number('6692345')->is_valid_number, '兵庫県丹波篠山市東岡屋');
ok($zip->set_number('6692346')->is_valid_number, '兵庫県丹波篠山市西岡屋');
ok($zip->set_number('6692351')->is_valid_number, '兵庫県丹波篠山市東浜谷');
ok($zip->set_number('6692352')->is_valid_number, '兵庫県丹波篠山市西浜谷');
ok($zip->set_number('6692353')->is_valid_number, '兵庫県丹波篠山市野尻');
ok($zip->set_number('6692354')->is_valid_number, '兵庫県丹波篠山市有居');
ok($zip->set_number('6692355')->is_valid_number, '兵庫県丹波篠山市大野');
ok($zip->set_number('6692356')->is_valid_number, '兵庫県丹波篠山市矢代');
ok($zip->set_number('6692357')->is_valid_number, '兵庫県丹波篠山市今福');
ok($zip->set_number('6692361')->is_valid_number, '兵庫県丹波篠山市丸山');
ok($zip->set_number('6692362')->is_valid_number, '兵庫県丹波篠山市知足');
ok($zip->set_number('6692363')->is_valid_number, '兵庫県丹波篠山市大谷');
ok($zip->set_number('6692364')->is_valid_number, '兵庫県丹波篠山市鷲尾');
ok($zip->set_number('6692365')->is_valid_number, '兵庫県丹波篠山市佐倉');
ok($zip->set_number('6692366')->is_valid_number, '兵庫県丹波篠山市寺内');
ok($zip->set_number('6692367')->is_valid_number, '兵庫県丹波篠山市熊谷');
ok($zip->set_number('6692368')->is_valid_number, '兵庫県丹波篠山市藤岡口');
ok($zip->set_number('6692369')->is_valid_number, '兵庫県丹波篠山市藤岡奥');
ok($zip->set_number('6692401')->is_valid_number, '兵庫県丹波篠山市奥県守');
ok($zip->set_number('6692402')->is_valid_number, '兵庫県丹波篠山市県守');
ok($zip->set_number('6692403')->is_valid_number, '兵庫県丹波篠山市東本荘');
ok($zip->set_number('6692404')->is_valid_number, '兵庫県丹波篠山市西本荘');
ok($zip->set_number('6692405')->is_valid_number, '兵庫県丹波篠山市佐貫谷');
ok($zip->set_number('6692406')->is_valid_number, '兵庫県丹波篠山市泉');
ok($zip->set_number('6692407')->is_valid_number, '兵庫県丹波篠山市倉谷');
ok($zip->set_number('6692408')->is_valid_number, '兵庫県丹波篠山市春日江');
ok($zip->set_number('6692411')->is_valid_number, '兵庫県丹波篠山市辻');
ok($zip->set_number('6692412')->is_valid_number, '兵庫県丹波篠山市小中');
ok($zip->set_number('6692413')->is_valid_number, '兵庫県丹波篠山市畑市');
ok($zip->set_number('6692414')->is_valid_number, '兵庫県丹波篠山市宮ノ前');
ok($zip->set_number('6692415')->is_valid_number, '兵庫県丹波篠山市上宿');
ok($zip->set_number('6692416')->is_valid_number, '兵庫県丹波篠山市井ノ上');
ok($zip->set_number('6692417')->is_valid_number, '兵庫県丹波篠山市北島');
ok($zip->set_number('6692418')->is_valid_number, '兵庫県丹波篠山市畑井');
ok($zip->set_number('6692421')->is_valid_number, '兵庫県丹波篠山市後川新田');
ok($zip->set_number('6692422')->is_valid_number, '兵庫県丹波篠山市後川上');
ok($zip->set_number('6692423')->is_valid_number, '兵庫県丹波篠山市後川中');
ok($zip->set_number('6692424')->is_valid_number, '兵庫県丹波篠山市後川下');
ok($zip->set_number('6692425')->is_valid_number, '兵庫県丹波篠山市後川奥');
ok($zip->set_number('6692431')->is_valid_number, '兵庫県丹波篠山市八上下');
ok($zip->set_number('6692432')->is_valid_number, '兵庫県丹波篠山市八上内');
ok($zip->set_number('6692433')->is_valid_number, '兵庫県丹波篠山市西八上');
ok($zip->set_number('6692434')->is_valid_number, '兵庫県丹波篠山市殿町');
ok($zip->set_number('6692435')->is_valid_number, '兵庫県丹波篠山市小多田');
ok($zip->set_number('6692436')->is_valid_number, '兵庫県丹波篠山市池上');
ok($zip->set_number('6692437')->is_valid_number, '兵庫県丹波篠山市糯ケ坪');
ok($zip->set_number('6692438')->is_valid_number, '兵庫県丹波篠山市京町');
ok($zip->set_number('6692439')->is_valid_number, '兵庫県丹波篠山市渋谷');
ok($zip->set_number('6692441')->is_valid_number, '兵庫県丹波篠山市日置');
ok($zip->set_number('6692442')->is_valid_number, '兵庫県丹波篠山市曽地口');
ok($zip->set_number('6692443')->is_valid_number, '兵庫県丹波篠山市曽地中');
ok($zip->set_number('6692444')->is_valid_number, '兵庫県丹波篠山市曽地奥');
ok($zip->set_number('6692445')->is_valid_number, '兵庫県丹波篠山市野々垣');
ok($zip->set_number('6692446')->is_valid_number, '兵庫県丹波篠山市八上上');
ok($zip->set_number('6692447')->is_valid_number, '兵庫県丹波篠山市西荘');
ok($zip->set_number('6692451')->is_valid_number, '兵庫県丹波篠山市北');
ok($zip->set_number('6692452')->is_valid_number, '兵庫県丹波篠山市野中');
ok($zip->set_number('6692453')->is_valid_number, '兵庫県丹波篠山市谷山');
ok($zip->set_number('6692454')->is_valid_number, '兵庫県丹波篠山市岩崎');
ok($zip->set_number('6692455')->is_valid_number, '兵庫県丹波篠山市宇土');
ok($zip->set_number('6692461')->is_valid_number, '兵庫県丹波篠山市小枕');
ok($zip->set_number('6692462')->is_valid_number, '兵庫県丹波篠山市真南条上');
ok($zip->set_number('6692463')->is_valid_number, '兵庫県丹波篠山市真南条中');
ok($zip->set_number('6692464')->is_valid_number, '兵庫県丹波篠山市真南条下');
ok($zip->set_number('6692465')->is_valid_number, '兵庫県丹波篠山市栗栖野');
ok($zip->set_number('6692501')->is_valid_number, '兵庫県丹波篠山市奥原山');
ok($zip->set_number('6692502')->is_valid_number, '兵庫県丹波篠山市中原山');
ok($zip->set_number('6692503')->is_valid_number, '兵庫県丹波篠山市下原山');
ok($zip->set_number('6692504')->is_valid_number, '兵庫県丹波篠山市西野々');
ok($zip->set_number('6692505')->is_valid_number, '兵庫県丹波篠山市安口');
ok($zip->set_number('6692511')->is_valid_number, '兵庫県丹波篠山市本明谷');
ok($zip->set_number('6692512')->is_valid_number, '兵庫県丹波篠山市川原');
ok($zip->set_number('6692513')->is_valid_number, '兵庫県丹波篠山市福住');
ok($zip->set_number('6692521')->is_valid_number, '兵庫県丹波篠山市二之坪');
ok($zip->set_number('6692522')->is_valid_number, '兵庫県丹波篠山市小野奥谷');
ok($zip->set_number('6692523')->is_valid_number, '兵庫県丹波篠山市小野新');
ok($zip->set_number('6692524')->is_valid_number, '兵庫県丹波篠山市箱谷');
ok($zip->set_number('6692525')->is_valid_number, '兵庫県丹波篠山市栃梨');
ok($zip->set_number('6692526')->is_valid_number, '兵庫県丹波篠山市向井');
ok($zip->set_number('6692527')->is_valid_number, '兵庫県丹波篠山市松ケ鼻');
ok($zip->set_number('6692531')->is_valid_number, '兵庫県丹波篠山市垂水');
ok($zip->set_number('6692532')->is_valid_number, '兵庫県丹波篠山市小立');
ok($zip->set_number('6692533')->is_valid_number, '兵庫県丹波篠山市山田');
ok($zip->set_number('6692534')->is_valid_number, '兵庫県丹波篠山市上筱見');
ok($zip->set_number('6692535')->is_valid_number, '兵庫県丹波篠山市下筱見');
ok($zip->set_number('6692541')->is_valid_number, '兵庫県丹波篠山市井串');
ok($zip->set_number('6692542')->is_valid_number, '兵庫県丹波篠山市細工所');
ok($zip->set_number('6692543')->is_valid_number, '兵庫県丹波篠山市塩岡');
ok($zip->set_number('6692544')->is_valid_number, '兵庫県丹波篠山市草ノ上');
ok($zip->set_number('6692545')->is_valid_number, '兵庫県丹波篠山市小田中');
ok($zip->set_number('6692551')->is_valid_number, '兵庫県丹波篠山市安田');
ok($zip->set_number('6692552')->is_valid_number, '兵庫県丹波篠山市藤之木');
ok($zip->set_number('6692553')->is_valid_number, '兵庫県丹波篠山市幡路');
ok($zip->set_number('6692554')->is_valid_number, '兵庫県丹波篠山市貝田');
ok($zip->set_number('6692601')->is_valid_number, '兵庫県丹波篠山市中');
ok($zip->set_number('6692602')->is_valid_number, '兵庫県丹波篠山市三熊');
ok($zip->set_number('6692603')->is_valid_number, '兵庫県丹波篠山市福井');
ok($zip->set_number('6692604')->is_valid_number, '兵庫県丹波篠山市小原');
ok($zip->set_number('6692605')->is_valid_number, '兵庫県丹波篠山市藤坂');
ok($zip->set_number('6692611')->is_valid_number, '兵庫県丹波篠山市大藤');
ok($zip->set_number('6692612')->is_valid_number, '兵庫県丹波篠山市立金');
ok($zip->set_number('6692613')->is_valid_number, '兵庫県丹波篠山市市野々');
ok($zip->set_number('6692614')->is_valid_number, '兵庫県丹波篠山市小倉');
ok($zip->set_number('6692615')->is_valid_number, '兵庫県丹波篠山市宮代');
ok($zip->set_number('6692616')->is_valid_number, '兵庫県丹波篠山市奥山');
ok($zip->set_number('6692701')->is_valid_number, '兵庫県丹波篠山市川阪');
ok($zip->set_number('6692702')->is_valid_number, '兵庫県丹波篠山市本郷');
ok($zip->set_number('6692703')->is_valid_number, '兵庫県丹波篠山市桑原');
ok($zip->set_number('6692704')->is_valid_number, '兵庫県丹波篠山市遠方');
ok($zip->set_number('6692711')->is_valid_number, '兵庫県丹波篠山市栗柄');
ok($zip->set_number('6692712')->is_valid_number, '兵庫県丹波篠山市坂本');
ok($zip->set_number('6692713')->is_valid_number, '兵庫県丹波篠山市倉本');
ok($zip->set_number('6692714')->is_valid_number, '兵庫県丹波篠山市垣屋');
ok($zip->set_number('6692715')->is_valid_number, '兵庫県丹波篠山市打坂');
ok($zip->set_number('6692716')->is_valid_number, '兵庫県丹波篠山市乗竹');
ok($zip->set_number('6692717')->is_valid_number, '兵庫県丹波篠山市高坂');
ok($zip->set_number('6692718')->is_valid_number, '兵庫県丹波篠山市市山');
ok($zip->set_number('6692721')->is_valid_number, '兵庫県丹波篠山市西谷');
ok($zip->set_number('6692722')->is_valid_number, '兵庫県丹波篠山市河内台');
ok($zip->set_number('6692723')->is_valid_number, '兵庫県丹波篠山市口阪本');
ok($zip->set_number('6692724')->is_valid_number, '兵庫県丹波篠山市川北');
ok($zip->set_number('6692725')->is_valid_number, '兵庫県丹波篠山市川北新田');
ok($zip->set_number('6692726')->is_valid_number, '兵庫県丹波篠山市黒田');
ok($zip->set_number('6692727')->is_valid_number, '兵庫県丹波篠山市高屋');
ok($zip->set_number('6692728')->is_valid_number, '兵庫県丹波篠山市西阪本');
ok($zip->set_number('6692731')->is_valid_number, '兵庫県丹波篠山市小坂');
ok($zip->set_number('6692732')->is_valid_number, '兵庫県丹波篠山市上板井');
ok($zip->set_number('6692733')->is_valid_number, '兵庫県丹波篠山市下板井');
ok($zip->set_number('6692734')->is_valid_number, '兵庫県丹波篠山市宮田');
ok($zip->set_number('6692735')->is_valid_number, '兵庫県丹波篠山市川西');
ok($zip->set_number('6692736')->is_valid_number, '兵庫県丹波篠山市西木之部');
ok($zip->set_number('6692737')->is_valid_number, '兵庫県丹波篠山市東木之部');
ok($zip->set_number('6692801')->is_valid_number, '兵庫県丹波篠山市追入');
ok($zip->set_number('6692802')->is_valid_number, '兵庫県丹波篠山市大山宮');
ok($zip->set_number('6692803')->is_valid_number, '兵庫県丹波篠山市大山上');
ok($zip->set_number('6692804')->is_valid_number, '兵庫県丹波篠山市荒子新田');
ok($zip->set_number('6692805')->is_valid_number, '兵庫県丹波篠山市園田分');
ok($zip->set_number('6692811')->is_valid_number, '兵庫県丹波篠山市石住');
ok($zip->set_number('6692812')->is_valid_number, '兵庫県丹波篠山市高倉');
ok($zip->set_number('6692813')->is_valid_number, '兵庫県丹波篠山市一印谷');
ok($zip->set_number('6692814')->is_valid_number, '兵庫県丹波篠山市長安寺');
ok($zip->set_number('6692815')->is_valid_number, '兵庫県丹波篠山市町ノ田');
ok($zip->set_number('6692821')->is_valid_number, '兵庫県丹波篠山市東河地');
ok($zip->set_number('6692822')->is_valid_number, '兵庫県丹波篠山市明野');
ok($zip->set_number('6692823')->is_valid_number, '兵庫県丹波篠山市大山下');
ok($zip->set_number('6692824')->is_valid_number, '兵庫県丹波篠山市北野');
ok($zip->set_number('6692825')->is_valid_number, '兵庫県丹波篠山市北野新田');
ok($zip->set_number('6692826')->is_valid_number, '兵庫県丹波篠山市徳永');
ok($zip->set_number('6692827')->is_valid_number, '兵庫県丹波篠山市大山新');
ok($zip->set_number('6693101')->is_valid_number, '兵庫県丹波市山南町上滝');
ok($zip->set_number('6693102')->is_valid_number, '兵庫県丹波市山南町下滝');
ok($zip->set_number('6693103')->is_valid_number, '兵庫県丹波市山南町篠場');
ok($zip->set_number('6693104')->is_valid_number, '兵庫県丹波市山南町畑内');
ok($zip->set_number('6693105')->is_valid_number, '兵庫県丹波市山南町北太田');
ok($zip->set_number('6693111')->is_valid_number, '兵庫県丹波市山南町阿草');
ok($zip->set_number('6693112')->is_valid_number, '兵庫県丹波市山南町青田');
ok($zip->set_number('6693113')->is_valid_number, '兵庫県丹波市山南町太田');
ok($zip->set_number('6693121')->is_valid_number, '兵庫県丹波市山南町奥野々');
ok($zip->set_number('6693122')->is_valid_number, '兵庫県丹波市山南町玉巻');
ok($zip->set_number('6693123')->is_valid_number, '兵庫県丹波市山南町大河');
ok($zip->set_number('6693124')->is_valid_number, '兵庫県丹波市山南町大谷');
ok($zip->set_number('6693125')->is_valid_number, '兵庫県丹波市山南町池谷');
ok($zip->set_number('6693126')->is_valid_number, '兵庫県丹波市山南町長野');
ok($zip->set_number('6693127')->is_valid_number, '兵庫県丹波市山南町岡本');
ok($zip->set_number('6693128')->is_valid_number, '兵庫県丹波市山南町金屋');
ok($zip->set_number('6693131')->is_valid_number, '兵庫県丹波市山南町谷川');
ok($zip->set_number('6693132')->is_valid_number, '兵庫県丹波市山南町山崎');
ok($zip->set_number('6693141')->is_valid_number, '兵庫県丹波市山南町岩屋');
ok($zip->set_number('6693142')->is_valid_number, '兵庫県丹波市山南町村森');
ok($zip->set_number('6693143')->is_valid_number, '兵庫県丹波市山南町井原');
ok($zip->set_number('6693144')->is_valid_number, '兵庫県丹波市山南町奥');
ok($zip->set_number('6693145')->is_valid_number, '兵庫県丹波市山南町野坂');
ok($zip->set_number('6693146')->is_valid_number, '兵庫県丹波市山南町南中');
ok($zip->set_number('6693147')->is_valid_number, '兵庫県丹波市山南町子茂田');
ok($zip->set_number('6693148')->is_valid_number, '兵庫県丹波市山南町きらら通');
ok($zip->set_number('6693151')->is_valid_number, '兵庫県丹波市山南町草部');
ok($zip->set_number('6693152')->is_valid_number, '兵庫県丹波市山南町北和田');
ok($zip->set_number('6693153')->is_valid_number, '兵庫県丹波市山南町前川');
ok($zip->set_number('6693154')->is_valid_number, '兵庫県丹波市山南町梶');
ok($zip->set_number('6693155')->is_valid_number, '兵庫県丹波市山南町小新屋');
ok($zip->set_number('6693156')->is_valid_number, '兵庫県丹波市山南町金倉');
ok($zip->set_number('6693157')->is_valid_number, '兵庫県丹波市山南町和田');
ok($zip->set_number('6693158')->is_valid_number, '兵庫県丹波市山南町応地');
ok($zip->set_number('6693159')->is_valid_number, '兵庫県丹波市山南町美和');
ok($zip->set_number('6693161')->is_valid_number, '兵庫県丹波市山南町五ケ野');
ok($zip->set_number('6693162')->is_valid_number, '兵庫県丹波市山南町坂尻');
ok($zip->set_number('6693163')->is_valid_number, '兵庫県丹波市山南町山本');
ok($zip->set_number('6693164')->is_valid_number, '兵庫県丹波市山南町若林');
ok($zip->set_number('6693165')->is_valid_number, '兵庫県丹波市山南町富田');
ok($zip->set_number('6693166')->is_valid_number, '兵庫県丹波市山南町小野尻');
ok($zip->set_number('6693167')->is_valid_number, '兵庫県丹波市山南町小畑');
ok($zip->set_number('6693168')->is_valid_number, '兵庫県丹波市山南町西谷');
ok($zip->set_number('6693300')->is_valid_number, '兵庫県丹波市以下に掲載がない場合');
ok($zip->set_number('6693301')->is_valid_number, '兵庫県丹波市柏原町南多田');
ok($zip->set_number('6693302')->is_valid_number, '兵庫県丹波市柏原町東奥');
ok($zip->set_number('6693303')->is_valid_number, '兵庫県丹波市柏原町見長');
ok($zip->set_number('6693304')->is_valid_number, '兵庫県丹波市柏原町上小倉');
ok($zip->set_number('6693305')->is_valid_number, '兵庫県丹波市柏原町下小倉');
ok($zip->set_number('6693306')->is_valid_number, '兵庫県丹波市柏原町北中');
ok($zip->set_number('6693307')->is_valid_number, '兵庫県丹波市柏原町石戸');
ok($zip->set_number('6693308')->is_valid_number, '兵庫県丹波市柏原町小南');
ok($zip->set_number('6693309')->is_valid_number, '兵庫県丹波市柏原町柏原');
ok($zip->set_number('6693311')->is_valid_number, '兵庫県丹波市柏原町母坪');
ok($zip->set_number('6693312')->is_valid_number, '兵庫県丹波市柏原町田路');
ok($zip->set_number('6693313')->is_valid_number, '兵庫県丹波市柏原町北山');
ok($zip->set_number('6693314')->is_valid_number, '兵庫県丹波市柏原町挙田');
ok($zip->set_number('6693315')->is_valid_number, '兵庫県丹波市柏原町大新屋');
ok($zip->set_number('6693316')->is_valid_number, '兵庫県丹波市柏原町鴨野');
ok($zip->set_number('6693401')->is_valid_number, '兵庫県丹波市春日町山田');
ok($zip->set_number('6693402')->is_valid_number, '兵庫県丹波市春日町新才');
ok($zip->set_number('6693403')->is_valid_number, '兵庫県丹波市春日町長王');
ok($zip->set_number('6693404')->is_valid_number, '兵庫県丹波市春日町牛河内');
ok($zip->set_number('6693411')->is_valid_number, '兵庫県丹波市春日町朝日');
ok($zip->set_number('6693412')->is_valid_number, '兵庫県丹波市春日町園部');
ok($zip->set_number('6693413')->is_valid_number, '兵庫県丹波市春日町石才');
ok($zip->set_number('6693414')->is_valid_number, '兵庫県丹波市春日町歌道谷');
ok($zip->set_number('6693415')->is_valid_number, '兵庫県丹波市春日町坂');
ok($zip->set_number('6693416')->is_valid_number, '兵庫県丹波市春日町野山');
ok($zip->set_number('6693461')->is_valid_number, '兵庫県丹波市氷上町市辺');
ok($zip->set_number('6693462')->is_valid_number, '兵庫県丹波市氷上町大崎');
ok($zip->set_number('6693463')->is_valid_number, '兵庫県丹波市氷上町北野');
ok($zip->set_number('6693464')->is_valid_number, '兵庫県丹波市氷上町石生');
ok($zip->set_number('6693465')->is_valid_number, '兵庫県丹波市氷上町横田');
ok($zip->set_number('6693466')->is_valid_number, '兵庫県丹波市氷上町稲継');
ok($zip->set_number('6693467')->is_valid_number, '兵庫県丹波市氷上町本郷');
ok($zip->set_number('6693571')->is_valid_number, '兵庫県丹波市氷上町新郷');
ok($zip->set_number('6693572')->is_valid_number, '兵庫県丹波市氷上町谷村');
ok($zip->set_number('6693573')->is_valid_number, '兵庫県丹波市氷上町油利');
ok($zip->set_number('6693574')->is_valid_number, '兵庫県丹波市氷上町朝阪');
ok($zip->set_number('6693575')->is_valid_number, '兵庫県丹波市氷上町小野');
ok($zip->set_number('6693581')->is_valid_number, '兵庫県丹波市氷上町稲畑');
ok($zip->set_number('6693582')->is_valid_number, '兵庫県丹波市氷上町佐野');
ok($zip->set_number('6693583')->is_valid_number, '兵庫県丹波市氷上町福田');
ok($zip->set_number('6693601')->is_valid_number, '兵庫県丹波市氷上町成松');
ok($zip->set_number('6693602')->is_valid_number, '兵庫県丹波市氷上町常楽');
ok($zip->set_number('6693603')->is_valid_number, '兵庫県丹波市氷上町西中');
ok($zip->set_number('6693604')->is_valid_number, '兵庫県丹波市氷上町犬岡');
ok($zip->set_number('6693605')->is_valid_number, '兵庫県丹波市氷上町黒田');
ok($zip->set_number('6693606')->is_valid_number, '兵庫県丹波市氷上町上成松');
ok($zip->set_number('6693611')->is_valid_number, '兵庫県丹波市氷上町柿柴');
ok($zip->set_number('6693612')->is_valid_number, '兵庫県丹波市氷上町長野');
ok($zip->set_number('6693613')->is_valid_number, '兵庫県丹波市氷上町上新庄');
ok($zip->set_number('6693614')->is_valid_number, '兵庫県丹波市氷上町下新庄');
ok($zip->set_number('6693621')->is_valid_number, '兵庫県丹波市氷上町大谷');
ok($zip->set_number('6693622')->is_valid_number, '兵庫県丹波市氷上町三原');
ok($zip->set_number('6693623')->is_valid_number, '兵庫県丹波市氷上町中野');
ok($zip->set_number('6693624')->is_valid_number, '兵庫県丹波市氷上町三方');
ok($zip->set_number('6693625')->is_valid_number, '兵庫県丹波市氷上町中');
ok($zip->set_number('6693626')->is_valid_number, '兵庫県丹波市氷上町清住');
ok($zip->set_number('6693631')->is_valid_number, '兵庫県丹波市氷上町賀茂');
ok($zip->set_number('6693632')->is_valid_number, '兵庫県丹波市氷上町井中');
ok($zip->set_number('6693633')->is_valid_number, '兵庫県丹波市氷上町御油');
ok($zip->set_number('6693634')->is_valid_number, '兵庫県丹波市氷上町沼');
ok($zip->set_number('6693641')->is_valid_number, '兵庫県丹波市氷上町絹山');
ok($zip->set_number('6693642')->is_valid_number, '兵庫県丹波市氷上町香良');
ok($zip->set_number('6693643')->is_valid_number, '兵庫県丹波市氷上町伊佐口');
ok($zip->set_number('6693644')->is_valid_number, '兵庫県丹波市氷上町日比宇');
ok($zip->set_number('6693645')->is_valid_number, '兵庫県丹波市氷上町鴨内');
ok($zip->set_number('6693646')->is_valid_number, '兵庫県丹波市氷上町小谷');
ok($zip->set_number('6693651')->is_valid_number, '兵庫県丹波市氷上町氷上');
ok($zip->set_number('6693652')->is_valid_number, '兵庫県丹波市氷上町桟敷');
ok($zip->set_number('6693653')->is_valid_number, '兵庫県丹波市氷上町北油良');
ok($zip->set_number('6693654')->is_valid_number, '兵庫県丹波市氷上町南油良');
ok($zip->set_number('6693801')->is_valid_number, '兵庫県丹波市青垣町東芦田');
ok($zip->set_number('6693802')->is_valid_number, '兵庫県丹波市青垣町栗住野');
ok($zip->set_number('6693803')->is_valid_number, '兵庫県丹波市青垣町西芦田');
ok($zip->set_number('6693804')->is_valid_number, '兵庫県丹波市青垣町田井縄');
ok($zip->set_number('6693811')->is_valid_number, '兵庫県丹波市青垣町佐治');
ok($zip->set_number('6693812')->is_valid_number, '兵庫県丹波市青垣町小倉');
ok($zip->set_number('6693821')->is_valid_number, '兵庫県丹波市青垣町桧倉');
ok($zip->set_number('6693822')->is_valid_number, '兵庫県丹波市青垣町大名草');
ok($zip->set_number('6693823')->is_valid_number, '兵庫県丹波市青垣町大稗');
ok($zip->set_number('6693824')->is_valid_number, '兵庫県丹波市青垣町小稗');
ok($zip->set_number('6693825')->is_valid_number, '兵庫県丹波市青垣町惣持');
ok($zip->set_number('6693826')->is_valid_number, '兵庫県丹波市青垣町文室');
ok($zip->set_number('6693827')->is_valid_number, '兵庫県丹波市青垣町稲土');
ok($zip->set_number('6693831')->is_valid_number, '兵庫県丹波市青垣町市原');
ok($zip->set_number('6693832')->is_valid_number, '兵庫県丹波市青垣町遠阪');
ok($zip->set_number('6693833')->is_valid_number, '兵庫県丹波市青垣町山垣');
ok($zip->set_number('6693834')->is_valid_number, '兵庫県丹波市青垣町中佐治');
ok($zip->set_number('6693841')->is_valid_number, '兵庫県丹波市青垣町口塩久');
ok($zip->set_number('6693842')->is_valid_number, '兵庫県丹波市青垣町沢野');
ok($zip->set_number('6693843')->is_valid_number, '兵庫県丹波市青垣町奥塩久');
ok($zip->set_number('6694121')->is_valid_number, '兵庫県丹波市春日町池尾');
ok($zip->set_number('6694122')->is_valid_number, '兵庫県丹波市春日町小多利');
ok($zip->set_number('6694123')->is_valid_number, '兵庫県丹波市春日町多利');
ok($zip->set_number('6694124')->is_valid_number, '兵庫県丹波市春日町野上野');
ok($zip->set_number('6694125')->is_valid_number, '兵庫県丹波市春日町多田');
ok($zip->set_number('6694131')->is_valid_number, '兵庫県丹波市春日町七日市');
ok($zip->set_number('6694132')->is_valid_number, '兵庫県丹波市春日町野村');
ok($zip->set_number('6694133')->is_valid_number, '兵庫県丹波市春日町平松');
ok($zip->set_number('6694134')->is_valid_number, '兵庫県丹波市春日町古河');
ok($zip->set_number('6694135')->is_valid_number, '兵庫県丹波市春日町稲塚');
ok($zip->set_number('6694141')->is_valid_number, '兵庫県丹波市春日町黒井');
ok($zip->set_number('6694251')->is_valid_number, '兵庫県丹波市春日町上三井庄');
ok($zip->set_number('6694252')->is_valid_number, '兵庫県丹波市春日町下三井庄');
ok($zip->set_number('6694253')->is_valid_number, '兵庫県丹波市春日町鹿場');
ok($zip->set_number('6694261')->is_valid_number, '兵庫県丹波市春日町野瀬');
ok($zip->set_number('6694262')->is_valid_number, '兵庫県丹波市春日町栢野');
ok($zip->set_number('6694263')->is_valid_number, '兵庫県丹波市春日町広瀬');
ok($zip->set_number('6694264')->is_valid_number, '兵庫県丹波市春日町松森');
ok($zip->set_number('6694265')->is_valid_number, '兵庫県丹波市春日町中山');
ok($zip->set_number('6694271')->is_valid_number, '兵庫県丹波市春日町柚津');
ok($zip->set_number('6694272')->is_valid_number, '兵庫県丹波市春日町東中');
ok($zip->set_number('6694273')->is_valid_number, '兵庫県丹波市春日町国領');
ok($zip->set_number('6694274')->is_valid_number, '兵庫県丹波市春日町棚原');
ok($zip->set_number('6694301')->is_valid_number, '兵庫県丹波市市島町下竹田');
ok($zip->set_number('6694302')->is_valid_number, '兵庫県丹波市市島町中竹田');
ok($zip->set_number('6694311')->is_valid_number, '兵庫県丹波市市島町戸平');
ok($zip->set_number('6694312')->is_valid_number, '兵庫県丹波市市島町北奥');
ok($zip->set_number('6694313')->is_valid_number, '兵庫県丹波市市島町多利');
ok($zip->set_number('6694314')->is_valid_number, '兵庫県丹波市市島町南');
ok($zip->set_number('6694315')->is_valid_number, '兵庫県丹波市市島町喜多');
ok($zip->set_number('6694316')->is_valid_number, '兵庫県丹波市市島町岩戸');
ok($zip->set_number('6694317')->is_valid_number, '兵庫県丹波市市島町上牧');
ok($zip->set_number('6694321')->is_valid_number, '兵庫県丹波市市島町上垣');
ok($zip->set_number('6694322')->is_valid_number, '兵庫県丹波市市島町上田');
ok($zip->set_number('6694323')->is_valid_number, '兵庫県丹波市市島町梶原');
ok($zip->set_number('6694324')->is_valid_number, '兵庫県丹波市市島町市島');
ok($zip->set_number('6694325')->is_valid_number, '兵庫県丹波市市島町北岡本');
ok($zip->set_number('6694331')->is_valid_number, '兵庫県丹波市市島町東勅使');
ok($zip->set_number('6694332')->is_valid_number, '兵庫県丹波市市島町勅使');
ok($zip->set_number('6694333')->is_valid_number, '兵庫県丹波市市島町戸坂');
ok($zip->set_number('6694334')->is_valid_number, '兵庫県丹波市市島町白毫寺');
ok($zip->set_number('6694335')->is_valid_number, '兵庫県丹波市市島町与戸');
ok($zip->set_number('6694336')->is_valid_number, '兵庫県丹波市市島町乙河内');
ok($zip->set_number('6694337')->is_valid_number, '兵庫県丹波市市島町酒梨');
ok($zip->set_number('6694341')->is_valid_number, '兵庫県丹波市市島町上竹田');
ok($zip->set_number('6694342')->is_valid_number, '兵庫県丹波市市島町矢代');
ok($zip->set_number('6694343')->is_valid_number, '兵庫県丹波市市島町下鴨阪');
ok($zip->set_number('6694344')->is_valid_number, '兵庫県丹波市市島町上鴨阪');
ok($zip->set_number('6694345')->is_valid_number, '兵庫県丹波市市島町徳尾');
ok($zip->set_number('6695101')->is_valid_number, '兵庫県朝来市山東町滝田');
ok($zip->set_number('6695102')->is_valid_number, '兵庫県朝来市山東町大垣');
ok($zip->set_number('6695103')->is_valid_number, '兵庫県朝来市山東町矢名瀬町');
ok($zip->set_number('6695104')->is_valid_number, '兵庫県朝来市山東町末歳');
ok($zip->set_number('6695111')->is_valid_number, '兵庫県朝来市山東町新堂');
ok($zip->set_number('6695112')->is_valid_number, '兵庫県朝来市山東町大内');
ok($zip->set_number('6695113')->is_valid_number, '兵庫県朝来市山東町塩田');
ok($zip->set_number('6695114')->is_valid_number, '兵庫県朝来市山東町野間');
ok($zip->set_number('6695115')->is_valid_number, '兵庫県朝来市山東町金浦');
ok($zip->set_number('6695121')->is_valid_number, '兵庫県朝来市山東町和賀');
ok($zip->set_number('6695122')->is_valid_number, '兵庫県朝来市山東町早田');
ok($zip->set_number('6695123')->is_valid_number, '兵庫県朝来市山東町一品');
ok($zip->set_number('6695124')->is_valid_number, '兵庫県朝来市山東町柴');
ok($zip->set_number('6695125')->is_valid_number, '兵庫県朝来市山東町粟鹿');
ok($zip->set_number('6695131')->is_valid_number, '兵庫県朝来市山東町柊木');
ok($zip->set_number('6695132')->is_valid_number, '兵庫県朝来市山東町溝黒');
ok($zip->set_number('6695133')->is_valid_number, '兵庫県朝来市山東町喜多垣');
ok($zip->set_number('6695134')->is_valid_number, '兵庫県朝来市山東町迫間');
ok($zip->set_number('6695135')->is_valid_number, '兵庫県朝来市山東町森');
ok($zip->set_number('6695136')->is_valid_number, '兵庫県朝来市山東町与布土');
ok($zip->set_number('6695141')->is_valid_number, '兵庫県朝来市山東町三保');
ok($zip->set_number('6695142')->is_valid_number, '兵庫県朝来市山東町越田');
ok($zip->set_number('6695143')->is_valid_number, '兵庫県朝来市山東町柿坪');
ok($zip->set_number('6695151')->is_valid_number, '兵庫県朝来市山東町小谷');
ok($zip->set_number('6695152')->is_valid_number, '兵庫県朝来市山東町楽音寺');
ok($zip->set_number('6695153')->is_valid_number, '兵庫県朝来市山東町大月');
ok($zip->set_number('6695200')->is_valid_number, '兵庫県朝来市以下に掲載がない場合');
ok($zip->set_number('6695201')->is_valid_number, '兵庫県朝来市和田山町和田山');
ok($zip->set_number('6695202')->is_valid_number, '兵庫県朝来市和田山町東谷');
ok($zip->set_number('6695203')->is_valid_number, '兵庫県朝来市和田山町寺谷');
ok($zip->set_number('6695204')->is_valid_number, '兵庫県朝来市和田山町駅北');
ok($zip->set_number('6695211')->is_valid_number, '兵庫県朝来市和田山町平野');
ok($zip->set_number('6695212')->is_valid_number, '兵庫県朝来市和田山町柳原');
ok($zip->set_number('6695213')->is_valid_number, '兵庫県朝来市和田山町玉置');
ok($zip->set_number('6695214')->is_valid_number, '兵庫県朝来市和田山町桑原');
ok($zip->set_number('6695215')->is_valid_number, '兵庫県朝来市和田山町枚田岡');
ok($zip->set_number('6695216')->is_valid_number, '兵庫県朝来市和田山町弥生が丘');
ok($zip->set_number('6695220')->is_valid_number, '兵庫県朝来市和田山町白井');
ok($zip->set_number('6695221')->is_valid_number, '兵庫県朝来市和田山町秋葉台');
ok($zip->set_number('6695222')->is_valid_number, '兵庫県朝来市和田山町万葉台');
ok($zip->set_number('6695223')->is_valid_number, '兵庫県朝来市和田山町室尾');
ok($zip->set_number('6695224')->is_valid_number, '兵庫県朝来市和田山町岡田');
ok($zip->set_number('6695225')->is_valid_number, '兵庫県朝来市和田山町野村');
ok($zip->set_number('6695226')->is_valid_number, '兵庫県朝来市和田山町中');
ok($zip->set_number('6695227')->is_valid_number, '兵庫県朝来市和田山町東和田');
ok($zip->set_number('6695228')->is_valid_number, '兵庫県朝来市和田山町久田和');
ok($zip->set_number('6695229')->is_valid_number, '兵庫県朝来市和田山町宮');
ok($zip->set_number('6695231')->is_valid_number, '兵庫県朝来市和田山町林垣');
ok($zip->set_number('6695232')->is_valid_number, '兵庫県朝来市和田山町寺内');
ok($zip->set_number('6695233')->is_valid_number, '兵庫県朝来市和田山町高生田');
ok($zip->set_number('6695234')->is_valid_number, '兵庫県朝来市和田山町市場');
ok($zip->set_number('6695235')->is_valid_number, '兵庫県朝来市和田山町和田');
ok($zip->set_number('6695236')->is_valid_number, '兵庫県朝来市和田山町内海');
ok($zip->set_number('6695237')->is_valid_number, '兵庫県朝来市和田山町竹ノ内');
ok($zip->set_number('6695238')->is_valid_number, '兵庫県朝来市和田山町朝日');
ok($zip->set_number('6695241')->is_valid_number, '兵庫県朝来市和田山町土田');
ok($zip->set_number('6695242')->is_valid_number, '兵庫県朝来市和田山町宮田');
ok($zip->set_number('6695243')->is_valid_number, '兵庫県朝来市和田山町高田');
ok($zip->set_number('6695244')->is_valid_number, '兵庫県朝来市和田山町宮内');
ok($zip->set_number('6695245')->is_valid_number, '兵庫県朝来市和田山町法道寺');
ok($zip->set_number('6695246')->is_valid_number, '兵庫県朝来市和田山町岡');
ok($zip->set_number('6695251')->is_valid_number, '兵庫県朝来市和田山町栄町');
ok($zip->set_number('6695252')->is_valid_number, '兵庫県朝来市和田山町竹田');
ok($zip->set_number('6695253')->is_valid_number, '兵庫県朝来市和田山町久世田');
ok($zip->set_number('6695254')->is_valid_number, '兵庫県朝来市和田山町安井');
ok($zip->set_number('6695255')->is_valid_number, '兵庫県朝来市和田山町殿');
ok($zip->set_number('6695256')->is_valid_number, '兵庫県朝来市和田山町三波');
ok($zip->set_number('6695257')->is_valid_number, '兵庫県朝来市和田山町藤和');
ok($zip->set_number('6695258')->is_valid_number, '兵庫県朝来市和田山町城南台');
ok($zip->set_number('6695261')->is_valid_number, '兵庫県朝来市和田山町枚田');
ok($zip->set_number('6695262')->is_valid_number, '兵庫県朝来市和田山町市御堂');
ok($zip->set_number('6695263')->is_valid_number, '兵庫県朝来市和田山町久留引');
ok($zip->set_number('6695264')->is_valid_number, '兵庫県朝来市和田山町加都');
ok($zip->set_number('6695265')->is_valid_number, '兵庫県朝来市和田山町筒江');
ok($zip->set_number('6695266')->is_valid_number, '兵庫県朝来市和田山町比治');
ok($zip->set_number('6695267')->is_valid_number, '兵庫県朝来市和田山町法興寺');
ok($zip->set_number('6695268')->is_valid_number, '兵庫県朝来市和田山町立ノ原');
ok($zip->set_number('6695301')->is_valid_number, '兵庫県豊岡市日高町江原');
ok($zip->set_number('6695302')->is_valid_number, '兵庫県豊岡市日高町岩中');
ok($zip->set_number('6695303')->is_valid_number, '兵庫県豊岡市日高町東構');
ok($zip->set_number('6695304')->is_valid_number, '兵庫県豊岡市日高町宵田');
ok($zip->set_number('6695305')->is_valid_number, '兵庫県豊岡市日高町祢布');
ok($zip->set_number('6695306')->is_valid_number, '兵庫県豊岡市日高町水上');
ok($zip->set_number('6695307')->is_valid_number, '兵庫県豊岡市日高町松岡');
ok($zip->set_number('6695311')->is_valid_number, '兵庫県豊岡市日高町日置');
ok($zip->set_number('6695312')->is_valid_number, '兵庫県豊岡市日高町日高');
ok($zip->set_number('6695313')->is_valid_number, '兵庫県豊岡市日高町鶴岡');
ok($zip->set_number('6695314')->is_valid_number, '兵庫県豊岡市日高町赤崎');
ok($zip->set_number('6695315')->is_valid_number, '兵庫県豊岡市日高町浅倉');
ok($zip->set_number('6695321')->is_valid_number, '兵庫県豊岡市日高町土居');
ok($zip->set_number('6695322')->is_valid_number, '兵庫県豊岡市日高町府市場');
ok($zip->set_number('6695323')->is_valid_number, '兵庫県豊岡市日高町府中新');
ok($zip->set_number('6695324')->is_valid_number, '兵庫県豊岡市日高町上郷');
ok($zip->set_number('6695325')->is_valid_number, '兵庫県豊岡市日高町堀');
ok($zip->set_number('6695326')->is_valid_number, '兵庫県豊岡市日高町池上');
ok($zip->set_number('6695327')->is_valid_number, '兵庫県豊岡市日高町野々庄');
ok($zip->set_number('6695328')->is_valid_number, '兵庫県豊岡市日高町西芝');
ok($zip->set_number('6695328')->is_valid_number, '兵庫県豊岡市日高町東芝');
ok($zip->set_number('6695331')->is_valid_number, '兵庫県豊岡市日高町上石');
ok($zip->set_number('6695332')->is_valid_number, '兵庫県豊岡市日高町竹貫');
ok($zip->set_number('6695333')->is_valid_number, '兵庫県豊岡市日高町藤井');
ok($zip->set_number('6695334')->is_valid_number, '兵庫県豊岡市日高町山本');
ok($zip->set_number('6695335')->is_valid_number, '兵庫県豊岡市日高町奈佐路');
ok($zip->set_number('6695336')->is_valid_number, '兵庫県豊岡市日高町谷');
ok($zip->set_number('6695337')->is_valid_number, '兵庫県豊岡市日高町中');
ok($zip->set_number('6695338')->is_valid_number, '兵庫県豊岡市日高町猪爪');
ok($zip->set_number('6695339')->is_valid_number, '兵庫県豊岡市日高町大岡');
ok($zip->set_number('6695339')->is_valid_number, '兵庫県豊岡市日高町河江');
ok($zip->set_number('6695339')->is_valid_number, '兵庫県豊岡市日高町小河江');
ok($zip->set_number('6695339')->is_valid_number, '兵庫県豊岡市日高町八代');
ok($zip->set_number('6695341')->is_valid_number, '兵庫県豊岡市日高町国分寺');
ok($zip->set_number('6695342')->is_valid_number, '兵庫県豊岡市日高町久斗');
ok($zip->set_number('6695343')->is_valid_number, '兵庫県豊岡市日高町道場');
ok($zip->set_number('6695344')->is_valid_number, '兵庫県豊岡市日高町夏栗');
ok($zip->set_number('6695345')->is_valid_number, '兵庫県豊岡市日高町久田谷');
ok($zip->set_number('6695346')->is_valid_number, '兵庫県豊岡市日高町伊府');
ok($zip->set_number('6695351')->is_valid_number, '兵庫県豊岡市日高町佐田');
ok($zip->set_number('6695352')->is_valid_number, '兵庫県豊岡市日高町知見');
ok($zip->set_number('6695353')->is_valid_number, '兵庫県豊岡市日高町森山');
ok($zip->set_number('6695354')->is_valid_number, '兵庫県豊岡市日高町観音寺');
ok($zip->set_number('6695355')->is_valid_number, '兵庫県豊岡市日高町篠垣');
ok($zip->set_number('6695356')->is_valid_number, '兵庫県豊岡市日高町荒川');
ok($zip->set_number('6695357')->is_valid_number, '兵庫県豊岡市日高町猪子垣');
ok($zip->set_number('6695357')->is_valid_number, '兵庫県豊岡市日高町田ノ口');
ok($zip->set_number('6695358')->is_valid_number, '兵庫県豊岡市日高町殿');
ok($zip->set_number('6695358')->is_valid_number, '兵庫県豊岡市日高町広井');
ok($zip->set_number('6695359')->is_valid_number, '兵庫県豊岡市日高町羽尻');
ok($zip->set_number('6695361')->is_valid_number, '兵庫県豊岡市日高町栗山');
ok($zip->set_number('6695362')->is_valid_number, '兵庫県豊岡市日高町芝');
ok($zip->set_number('6695363')->is_valid_number, '兵庫県豊岡市日高町野');
ok($zip->set_number('6695364')->is_valid_number, '兵庫県豊岡市日高町庄境');
ok($zip->set_number('6695365')->is_valid_number, '兵庫県豊岡市日高町十戸');
ok($zip->set_number('6695366')->is_valid_number, '兵庫県豊岡市日高町頃垣');
ok($zip->set_number('6695367')->is_valid_number, '兵庫県豊岡市日高町石井');
ok($zip->set_number('6695368')->is_valid_number, '兵庫県豊岡市日高町山宮');
ok($zip->set_number('6695369')->is_valid_number, '兵庫県豊岡市日高町栃本');
ok($zip->set_number('6695371')->is_valid_number, '兵庫県豊岡市日高町太田');
ok($zip->set_number('6695372')->is_valid_number, '兵庫県豊岡市日高町栗栖野');
ok($zip->set_number('6695373')->is_valid_number, '兵庫県豊岡市日高町東河内');
ok($zip->set_number('6695374')->is_valid_number, '兵庫県豊岡市日高町水口');
ok($zip->set_number('6695375')->is_valid_number, '兵庫県豊岡市日高町稲葉');
ok($zip->set_number('6695376')->is_valid_number, '兵庫県豊岡市日高町万劫');
ok($zip->set_number('6695377')->is_valid_number, '兵庫県豊岡市日高町山田');
ok($zip->set_number('6695378')->is_valid_number, '兵庫県豊岡市日高町万場');
ok($zip->set_number('6695379')->is_valid_number, '兵庫県豊岡市日高町名色');
ok($zip->set_number('6696101')->is_valid_number, '兵庫県豊岡市城崎町湯島');
ok($zip->set_number('6696102')->is_valid_number, '兵庫県豊岡市城崎町桃島');
ok($zip->set_number('6696103')->is_valid_number, '兵庫県豊岡市城崎町今津');
ok($zip->set_number('6696111')->is_valid_number, '兵庫県豊岡市城崎町楽々浦');
ok($zip->set_number('6696112')->is_valid_number, '兵庫県豊岡市城崎町飯谷');
ok($zip->set_number('6696113')->is_valid_number, '兵庫県豊岡市城崎町結');
ok($zip->set_number('6696114')->is_valid_number, '兵庫県豊岡市城崎町戸島');
ok($zip->set_number('6696115')->is_valid_number, '兵庫県豊岡市城崎町来日');
ok($zip->set_number('6696116')->is_valid_number, '兵庫県豊岡市城崎町上山');
ok($zip->set_number('6696121')->is_valid_number, '兵庫県豊岡市津居山');
ok($zip->set_number('6696122')->is_valid_number, '兵庫県豊岡市瀬戸');
ok($zip->set_number('6696123')->is_valid_number, '兵庫県豊岡市小島');
ok($zip->set_number('6696124')->is_valid_number, '兵庫県豊岡市気比');
ok($zip->set_number('6696125')->is_valid_number, '兵庫県豊岡市田結');
ok($zip->set_number('6696126')->is_valid_number, '兵庫県豊岡市三原');
ok($zip->set_number('6696127')->is_valid_number, '兵庫県豊岡市畑上');
ok($zip->set_number('6696201')->is_valid_number, '兵庫県豊岡市竹野町竹野');
ok($zip->set_number('6696202')->is_valid_number, '兵庫県豊岡市竹野町宇日');
ok($zip->set_number('6696203')->is_valid_number, '兵庫県豊岡市竹野町田久日');
ok($zip->set_number('6696211')->is_valid_number, '兵庫県豊岡市竹野町和田');
ok($zip->set_number('6696212')->is_valid_number, '兵庫県豊岡市竹野町松本');
ok($zip->set_number('6696213')->is_valid_number, '兵庫県豊岡市竹野町羽入');
ok($zip->set_number('6696214')->is_valid_number, '兵庫県豊岡市竹野町阿金谷');
ok($zip->set_number('6696215')->is_valid_number, '兵庫県豊岡市竹野町草飼');
ok($zip->set_number('6696216')->is_valid_number, '兵庫県豊岡市竹野町切浜');
ok($zip->set_number('6696217')->is_valid_number, '兵庫県豊岡市竹野町浜須井');
ok($zip->set_number('6696218')->is_valid_number, '兵庫県豊岡市竹野町奥須井');
ok($zip->set_number('6696221')->is_valid_number, '兵庫県豊岡市竹野町須谷');
ok($zip->set_number('6696222')->is_valid_number, '兵庫県豊岡市竹野町小丸');
ok($zip->set_number('6696223')->is_valid_number, '兵庫県豊岡市竹野町芦谷');
ok($zip->set_number('6696224')->is_valid_number, '兵庫県豊岡市竹野町鬼神谷');
ok($zip->set_number('6696225')->is_valid_number, '兵庫県豊岡市竹野町轟');
ok($zip->set_number('6696226')->is_valid_number, '兵庫県豊岡市竹野町下塚');
ok($zip->set_number('6696227')->is_valid_number, '兵庫県豊岡市竹野町林');
ok($zip->set_number('6696228')->is_valid_number, '兵庫県豊岡市竹野町東大谷');
ok($zip->set_number('6696229')->is_valid_number, '兵庫県豊岡市竹野町金原');
ok($zip->set_number('6696331')->is_valid_number, '兵庫県豊岡市竹野町坊岡');
ok($zip->set_number('6696332')->is_valid_number, '兵庫県豊岡市竹野町森本');
ok($zip->set_number('6696333')->is_valid_number, '兵庫県豊岡市竹野町御又');
ok($zip->set_number('6696334')->is_valid_number, '兵庫県豊岡市竹野町河内');
ok($zip->set_number('6696335')->is_valid_number, '兵庫県豊岡市竹野町門谷');
ok($zip->set_number('6696341')->is_valid_number, '兵庫県豊岡市竹野町小城');
ok($zip->set_number('6696342')->is_valid_number, '兵庫県豊岡市竹野町二連原');
ok($zip->set_number('6696343')->is_valid_number, '兵庫県豊岡市竹野町段');
ok($zip->set_number('6696344')->is_valid_number, '兵庫県豊岡市竹野町椒');
ok($zip->set_number('6696351')->is_valid_number, '兵庫県豊岡市竹野町須野谷');
ok($zip->set_number('6696352')->is_valid_number, '兵庫県豊岡市竹野町大森');
ok($zip->set_number('6696353')->is_valid_number, '兵庫県豊岡市竹野町桑野本');
ok($zip->set_number('6696354')->is_valid_number, '兵庫県豊岡市竹野町川南谷');
ok($zip->set_number('6696355')->is_valid_number, '兵庫県豊岡市竹野町三原');
ok($zip->set_number('6696401')->is_valid_number, '兵庫県美方郡香美町香住区無南垣');
ok($zip->set_number('6696402')->is_valid_number, '兵庫県美方郡香美町香住区訓谷');
ok($zip->set_number('6696403')->is_valid_number, '兵庫県美方郡香美町香住区安木');
ok($zip->set_number('6696404')->is_valid_number, '兵庫県美方郡香美町香住区相谷');
ok($zip->set_number('6696411')->is_valid_number, '兵庫県美方郡香美町香住区九斗');
ok($zip->set_number('6696412')->is_valid_number, '兵庫県美方郡香美町香住区米地');
ok($zip->set_number('6696413')->is_valid_number, '兵庫県美方郡香美町香住区下岡');
ok($zip->set_number('6696414')->is_valid_number, '兵庫県美方郡香美町香住区上岡');
ok($zip->set_number('6696415')->is_valid_number, '兵庫県美方郡香美町香住区西下岡');
ok($zip->set_number('6696416')->is_valid_number, '兵庫県美方郡香美町香住区丹生地');
ok($zip->set_number('6696421')->is_valid_number, '兵庫県美方郡香美町香住区本見塚');
ok($zip->set_number('6696422')->is_valid_number, '兵庫県美方郡香美町香住区土生');
ok($zip->set_number('6696423')->is_valid_number, '兵庫県美方郡香美町香住区畑');
ok($zip->set_number('6696424')->is_valid_number, '兵庫県美方郡香美町香住区隼人');
ok($zip->set_number('6696425')->is_valid_number, '兵庫県美方郡香美町香住区大梶');
ok($zip->set_number('6696426')->is_valid_number, '兵庫県美方郡香美町香住区三川');
ok($zip->set_number('6696431')->is_valid_number, '兵庫県美方郡香美町香住区浦上');
ok($zip->set_number('6696432')->is_valid_number, '兵庫県美方郡香美町香住区上計');
ok($zip->set_number('6696433')->is_valid_number, '兵庫県美方郡香美町香住区沖浦');
ok($zip->set_number('6696500')->is_valid_number, '兵庫県美方郡香美町以下に掲載がない場合');
ok($zip->set_number('6696541')->is_valid_number, '兵庫県美方郡香美町香住区境');
ok($zip->set_number('6696542')->is_valid_number, '兵庫県美方郡香美町香住区一日市');
ok($zip->set_number('6696543')->is_valid_number, '兵庫県美方郡香美町香住区若松');
ok($zip->set_number('6696544')->is_valid_number, '兵庫県美方郡香美町香住区香住');
ok($zip->set_number('6696545')->is_valid_number, '兵庫県美方郡香美町香住区森');
ok($zip->set_number('6696546')->is_valid_number, '兵庫県美方郡香美町香住区七日市');
ok($zip->set_number('6696547')->is_valid_number, '兵庫県美方郡香美町香住区山手');
ok($zip->set_number('6696551')->is_valid_number, '兵庫県美方郡香美町香住区守柄');
ok($zip->set_number('6696552')->is_valid_number, '兵庫県美方郡香美町香住区加鹿野');
ok($zip->set_number('6696553')->is_valid_number, '兵庫県美方郡香美町香住区三谷');
ok($zip->set_number('6696554')->is_valid_number, '兵庫県美方郡香美町香住区大谷');
ok($zip->set_number('6696555')->is_valid_number, '兵庫県美方郡香美町香住区大野');
ok($zip->set_number('6696556')->is_valid_number, '兵庫県美方郡香美町香住区中野');
ok($zip->set_number('6696557')->is_valid_number, '兵庫県美方郡香美町香住区藤');
ok($zip->set_number('6696558')->is_valid_number, '兵庫県美方郡香美町香住区八原');
ok($zip->set_number('6696559')->is_valid_number, '兵庫県美方郡香美町香住区小原');
ok($zip->set_number('6696561')->is_valid_number, '兵庫県美方郡香美町香住区間室');
ok($zip->set_number('6696562')->is_valid_number, '兵庫県美方郡香美町香住区油良');
ok($zip->set_number('6696563')->is_valid_number, '兵庫県美方郡香美町香住区矢田');
ok($zip->set_number('6696564')->is_valid_number, '兵庫県美方郡香美町香住区下浜');
ok($zip->set_number('6696671')->is_valid_number, '兵庫県美方郡香美町香住区余部');
ok($zip->set_number('6696672')->is_valid_number, '兵庫県美方郡香美町香住区鎧');
ok($zip->set_number('6696700')->is_valid_number, '兵庫県美方郡新温泉町以下に掲載がない場合');
ok($zip->set_number('6696701')->is_valid_number, '兵庫県美方郡新温泉町芦屋');
ok($zip->set_number('6696702')->is_valid_number, '兵庫県美方郡新温泉町浜坂');
ok($zip->set_number('6696711')->is_valid_number, '兵庫県美方郡新温泉町清富');
ok($zip->set_number('6696712')->is_valid_number, '兵庫県美方郡新温泉町指杭');
ok($zip->set_number('6696713')->is_valid_number, '兵庫県美方郡新温泉町田井');
ok($zip->set_number('6696714')->is_valid_number, '兵庫県美方郡新温泉町赤崎');
ok($zip->set_number('6696715')->is_valid_number, '兵庫県美方郡新温泉町三尾');
ok($zip->set_number('6696716')->is_valid_number, '兵庫県美方郡新温泉町和田');
ok($zip->set_number('6696721')->is_valid_number, '兵庫県美方郡新温泉町久谷');
ok($zip->set_number('6696722')->is_valid_number, '兵庫県美方郡新温泉町高末');
ok($zip->set_number('6696723')->is_valid_number, '兵庫県美方郡新温泉町正法庵');
ok($zip->set_number('6696724')->is_valid_number, '兵庫県美方郡新温泉町辺地');
ok($zip->set_number('6696725')->is_valid_number, '兵庫県美方郡新温泉町藤尾');
ok($zip->set_number('6696726')->is_valid_number, '兵庫県美方郡新温泉町境');
ok($zip->set_number('6696727')->is_valid_number, '兵庫県美方郡新温泉町久斗山');
ok($zip->set_number('6696728')->is_valid_number, '兵庫県美方郡新温泉町対田');
ok($zip->set_number('6696731')->is_valid_number, '兵庫県美方郡新温泉町二日市');
ok($zip->set_number('6696732')->is_valid_number, '兵庫県美方郡新温泉町福富');
ok($zip->set_number('6696741')->is_valid_number, '兵庫県美方郡新温泉町七釜');
ok($zip->set_number('6696742')->is_valid_number, '兵庫県美方郡新温泉町新市');
ok($zip->set_number('6696743')->is_valid_number, '兵庫県美方郡新温泉町古市');
ok($zip->set_number('6696744')->is_valid_number, '兵庫県美方郡新温泉町用土');
ok($zip->set_number('6696745')->is_valid_number, '兵庫県美方郡新温泉町栃谷');
ok($zip->set_number('6696746')->is_valid_number, '兵庫県美方郡新温泉町戸田');
ok($zip->set_number('6696747')->is_valid_number, '兵庫県美方郡新温泉町三谷');
ok($zip->set_number('6696751')->is_valid_number, '兵庫県美方郡新温泉町居組');
ok($zip->set_number('6696752')->is_valid_number, '兵庫県美方郡新温泉町釜屋');
ok($zip->set_number('6696753')->is_valid_number, '兵庫県美方郡新温泉町諸寄');
ok($zip->set_number('6696761')->is_valid_number, '兵庫県美方郡新温泉町竹田(後山、細見谷)');
ok($zip->set_number('6696801')->is_valid_number, '兵庫県美方郡新温泉町井土');
ok($zip->set_number('6696802')->is_valid_number, '兵庫県美方郡新温泉町金屋');
ok($zip->set_number('6696803')->is_valid_number, '兵庫県美方郡新温泉町今岡');
ok($zip->set_number('6696804')->is_valid_number, '兵庫県美方郡新温泉町熊谷');
ok($zip->set_number('6696805')->is_valid_number, '兵庫県美方郡新温泉町伊角');
ok($zip->set_number('6696806')->is_valid_number, '兵庫県美方郡新温泉町桧尾');
ok($zip->set_number('6696807')->is_valid_number, '兵庫県美方郡新温泉町春来');
ok($zip->set_number('6696808')->is_valid_number, '兵庫県美方郡新温泉町歌長');
ok($zip->set_number('6696811')->is_valid_number, '兵庫県美方郡新温泉町多子');
ok($zip->set_number('6696812')->is_valid_number, '兵庫県美方郡新温泉町切畑');
ok($zip->set_number('6696813')->is_valid_number, '兵庫県美方郡新温泉町丹土');
ok($zip->set_number('6696814')->is_valid_number, '兵庫県美方郡新温泉町中辻');
ok($zip->set_number('6696815')->is_valid_number, '兵庫県美方郡新温泉町桐岡');
ok($zip->set_number('6696821')->is_valid_number, '兵庫県美方郡新温泉町湯');
ok($zip->set_number('6696822')->is_valid_number, '兵庫県美方郡新温泉町細田');
ok($zip->set_number('6696831')->is_valid_number, '兵庫県美方郡新温泉町竹田(その他)');
ok($zip->set_number('6696832')->is_valid_number, '兵庫県美方郡新温泉町飯野');
ok($zip->set_number('6696833')->is_valid_number, '兵庫県美方郡新温泉町塩山');
ok($zip->set_number('6696941')->is_valid_number, '兵庫県美方郡新温泉町千原');
ok($zip->set_number('6696942')->is_valid_number, '兵庫県美方郡新温泉町鐘尾');
ok($zip->set_number('6696943')->is_valid_number, '兵庫県美方郡新温泉町千谷');
ok($zip->set_number('6696944')->is_valid_number, '兵庫県美方郡新温泉町宮脇');
ok($zip->set_number('6696945')->is_valid_number, '兵庫県美方郡新温泉町内山');
ok($zip->set_number('6696946')->is_valid_number, '兵庫県美方郡新温泉町越坂');
ok($zip->set_number('6696951')->is_valid_number, '兵庫県美方郡新温泉町前');
ok($zip->set_number('6696952')->is_valid_number, '兵庫県美方郡新温泉町海上');
ok($zip->set_number('6696953')->is_valid_number, '兵庫県美方郡新温泉町石橋');
ok($zip->set_number('6696954')->is_valid_number, '兵庫県美方郡新温泉町岸田');
ok($zip->set_number('6700000')->is_valid_number, '兵庫県姫路市以下に掲載がない場合');
ok($zip->set_number('6700001')->is_valid_number, '兵庫県姫路市河間町');
ok($zip->set_number('6700002')->is_valid_number, '兵庫県姫路市鍛冶町');
ok($zip->set_number('6700003')->is_valid_number, '兵庫県姫路市米屋町');
ok($zip->set_number('6700004')->is_valid_number, '兵庫県姫路市福本町');
ok($zip->set_number('6700005')->is_valid_number, '兵庫県姫路市金屋町');
ok($zip->set_number('6700006')->is_valid_number, '兵庫県姫路市八木町');
ok($zip->set_number('6700007')->is_valid_number, '兵庫県姫路市生野町');
ok($zip->set_number('6700008')->is_valid_number, '兵庫県姫路市橋之町');
ok($zip->set_number('6700009')->is_valid_number, '兵庫県姫路市鍵町');
ok($zip->set_number('6700011')->is_valid_number, '兵庫県姫路市坊主町');
ok($zip->set_number('6700012')->is_valid_number, '兵庫県姫路市本町');
ok($zip->set_number('6700013')->is_valid_number, '兵庫県姫路市竹田町');
ok($zip->set_number('6700014')->is_valid_number, '兵庫県姫路市堺町');
ok($zip->set_number('6700015')->is_valid_number, '兵庫県姫路市総社本町');
ok($zip->set_number('6700016')->is_valid_number, '兵庫県姫路市坂元町');
ok($zip->set_number('6700017')->is_valid_number, '兵庫県姫路市福中町');
ok($zip->set_number('6700021')->is_valid_number, '兵庫県姫路市山野井町');
ok($zip->set_number('6700022')->is_valid_number, '兵庫県姫路市小利木町');
ok($zip->set_number('6700023')->is_valid_number, '兵庫県姫路市柳町');
ok($zip->set_number('6700024')->is_valid_number, '兵庫県姫路市鷹匠町');
ok($zip->set_number('6700025')->is_valid_number, '兵庫県姫路市材木町');
ok($zip->set_number('6700026')->is_valid_number, '兵庫県姫路市岡町');
ok($zip->set_number('6700027')->is_valid_number, '兵庫県姫路市景福寺前');
ok($zip->set_number('6700028')->is_valid_number, '兵庫県姫路市岩端町');
ok($zip->set_number('6700029')->is_valid_number, '兵庫県姫路市嵐山町');
ok($zip->set_number('6700031')->is_valid_number, '兵庫県姫路市吉田町');
ok($zip->set_number('6700032')->is_valid_number, '兵庫県姫路市龍野町');
ok($zip->set_number('6700033')->is_valid_number, '兵庫県姫路市西新町');
ok($zip->set_number('6700034')->is_valid_number, '兵庫県姫路市船丘町');
ok($zip->set_number('6700035')->is_valid_number, '兵庫県姫路市琴岡町');
ok($zip->set_number('6700036')->is_valid_number, '兵庫県姫路市山畑新田');
ok($zip->set_number('6700037')->is_valid_number, '兵庫県姫路市柿山伏');
ok($zip->set_number('6700038')->is_valid_number, '兵庫県姫路市農人町');
ok($zip->set_number('6700041')->is_valid_number, '兵庫県姫路市上片町');
ok($zip->set_number('6700042')->is_valid_number, '兵庫県姫路市米田町');
ok($zip->set_number('6700043')->is_valid_number, '兵庫県姫路市小姓町');
ok($zip->set_number('6700044')->is_valid_number, '兵庫県姫路市地内町');
ok($zip->set_number('6700045')->is_valid_number, '兵庫県姫路市片田町');
ok($zip->set_number('6700046')->is_valid_number, '兵庫県姫路市東雲町');
ok($zip->set_number('6700047')->is_valid_number, '兵庫県姫路市花影町');
ok($zip->set_number('6700048')->is_valid_number, '兵庫県姫路市船橋町');
ok($zip->set_number('6700049')->is_valid_number, '兵庫県姫路市元町');
ok($zip->set_number('6700051')->is_valid_number, '兵庫県姫路市名古山町');
ok($zip->set_number('6700052')->is_valid_number, '兵庫県姫路市今宿');
ok($zip->set_number('6700053')->is_valid_number, '兵庫県姫路市南車崎');
ok($zip->set_number('6700054')->is_valid_number, '兵庫県姫路市南今宿');
ok($zip->set_number('6700055')->is_valid_number, '兵庫県姫路市神子岡前');
ok($zip->set_number('6700056')->is_valid_number, '兵庫県姫路市東今宿');
ok($zip->set_number('6700057')->is_valid_number, '兵庫県姫路市北今宿');
ok($zip->set_number('6700058')->is_valid_number, '兵庫県姫路市車崎');
ok($zip->set_number('6700061')->is_valid_number, '兵庫県姫路市西今宿');
ok($zip->set_number('6700062')->is_valid_number, '兵庫県姫路市高岡新町');
ok($zip->set_number('6700063')->is_valid_number, '兵庫県姫路市下手野');
ok($zip->set_number('6700064')->is_valid_number, '兵庫県姫路市東夢前台');
ok($zip->set_number('6700065')->is_valid_number, '兵庫県姫路市上手野');
ok($zip->set_number('6700066')->is_valid_number, '兵庫県姫路市藤ケ台');
ok($zip->set_number('6700071')->is_valid_number, '兵庫県姫路市御立北');
ok($zip->set_number('6700072')->is_valid_number, '兵庫県姫路市御立東');
ok($zip->set_number('6700073')->is_valid_number, '兵庫県姫路市御立中');
ok($zip->set_number('6700074')->is_valid_number, '兵庫県姫路市御立西');
ok($zip->set_number('6700075')->is_valid_number, '兵庫県姫路市北夢前台(その他)');
ok($zip->set_number('6700081')->is_valid_number, '兵庫県姫路市田寺東');
ok($zip->set_number('6700082')->is_valid_number, '兵庫県姫路市田寺山手町');
ok($zip->set_number('6700083')->is_valid_number, '兵庫県姫路市辻井');
ok($zip->set_number('6700084')->is_valid_number, '兵庫県姫路市東辻井');
ok($zip->set_number('6700085')->is_valid_number, '兵庫県姫路市山吹');
ok($zip->set_number('6700086')->is_valid_number, '兵庫県姫路市田寺');
ok($zip->set_number('6700091')->is_valid_number, '兵庫県姫路市北新在家');
ok($zip->set_number('6700092')->is_valid_number, '兵庫県姫路市新在家本町');
ok($zip->set_number('6700093')->is_valid_number, '兵庫県姫路市南新在家');
ok($zip->set_number('6700094')->is_valid_number, '兵庫県姫路市新在家中の町');
ok($zip->set_number('6700095')->is_valid_number, '兵庫県姫路市新在家');
ok($zip->set_number('6700096')->is_valid_number, '兵庫県姫路市西新在家');
ok($zip->set_number('6700801')->is_valid_number, '兵庫県姫路市仁豊野');
ok($zip->set_number('6700802')->is_valid_number, '兵庫県姫路市砥堀');
ok($zip->set_number('6700803')->is_valid_number, '兵庫県姫路市城見台');
ok($zip->set_number('6700804')->is_valid_number, '兵庫県姫路市保城');
ok($zip->set_number('6700805')->is_valid_number, '兵庫県姫路市西中島');
ok($zip->set_number('6700806')->is_valid_number, '兵庫県姫路市増位新町');
ok($zip->set_number('6700807')->is_valid_number, '兵庫県姫路市増位本町');
ok($zip->set_number('6700808')->is_valid_number, '兵庫県姫路市白国');
ok($zip->set_number('6700811')->is_valid_number, '兵庫県姫路市野里');
ok($zip->set_number('6700812')->is_valid_number, '兵庫県姫路市睦町');
ok($zip->set_number('6700813')->is_valid_number, '兵庫県姫路市野里慶雲寺前町');
ok($zip->set_number('6700814')->is_valid_number, '兵庫県姫路市野里上野町');
ok($zip->set_number('6700815')->is_valid_number, '兵庫県姫路市野里大和町');
ok($zip->set_number('6700816')->is_valid_number, '兵庫県姫路市威徳寺町');
ok($zip->set_number('6700817')->is_valid_number, '兵庫県姫路市梅ケ枝町');
ok($zip->set_number('6700821')->is_valid_number, '兵庫県姫路市東郷町');
ok($zip->set_number('6700822')->is_valid_number, '兵庫県姫路市市川台');
ok($zip->set_number('6700823')->is_valid_number, '兵庫県姫路市宮上町');
ok($zip->set_number('6700824')->is_valid_number, '兵庫県姫路市京町');
ok($zip->set_number('6700825')->is_valid_number, '兵庫県姫路市市川橋通');
ok($zip->set_number('6700826')->is_valid_number, '兵庫県姫路市楠町');
ok($zip->set_number('6700827')->is_valid_number, '兵庫県姫路市丸尾町');
ok($zip->set_number('6700831')->is_valid_number, '兵庫県姫路市城見町');
ok($zip->set_number('6700832')->is_valid_number, '兵庫県姫路市双葉町');
ok($zip->set_number('6700833')->is_valid_number, '兵庫県姫路市大善町');
ok($zip->set_number('6700834')->is_valid_number, '兵庫県姫路市神和町');
ok($zip->set_number('6700835')->is_valid_number, '兵庫県姫路市幸町');
ok($zip->set_number('6700836')->is_valid_number, '兵庫県姫路市神屋町');
ok($zip->set_number('6700837')->is_valid_number, '兵庫県姫路市宮西町');
ok($zip->set_number('6700841')->is_valid_number, '兵庫県姫路市城東町');
ok($zip->set_number('6700842')->is_valid_number, '兵庫県姫路市城東町毘沙門');
ok($zip->set_number('6700843')->is_valid_number, '兵庫県姫路市城東町清水');
ok($zip->set_number('6700844')->is_valid_number, '兵庫県姫路市城東町野田');
ok($zip->set_number('6700845')->is_valid_number, '兵庫県姫路市城東町京口台');
ok($zip->set_number('6700846')->is_valid_number, '兵庫県姫路市天神町');
ok($zip->set_number('6700847')->is_valid_number, '兵庫県姫路市城東町中河原');
ok($zip->set_number('6700848')->is_valid_number, '兵庫県姫路市城東町竹之門');
ok($zip->set_number('6700849')->is_valid_number, '兵庫県姫路市城東町五軒屋');
ok($zip->set_number('6700851')->is_valid_number, '兵庫県姫路市京口町');
ok($zip->set_number('6700852')->is_valid_number, '兵庫県姫路市国府寺町');
ok($zip->set_number('6700853')->is_valid_number, '兵庫県姫路市大黒壱丁町');
ok($zip->set_number('6700854')->is_valid_number, '兵庫県姫路市五軒邸');
ok($zip->set_number('6700855')->is_valid_number, '兵庫県姫路市福居町');
ok($zip->set_number('6700856')->is_valid_number, '兵庫県姫路市同心町');
ok($zip->set_number('6700857')->is_valid_number, '兵庫県姫路市五郎右衛門邸');
ok($zip->set_number('6700861')->is_valid_number, '兵庫県姫路市野里東町');
ok($zip->set_number('6700862')->is_valid_number, '兵庫県姫路市野里新町');
ok($zip->set_number('6700863')->is_valid_number, '兵庫県姫路市野里東同心町');
ok($zip->set_number('6700864')->is_valid_number, '兵庫県姫路市野里中町');
ok($zip->set_number('6700865')->is_valid_number, '兵庫県姫路市野里月丘町');
ok($zip->set_number('6700866')->is_valid_number, '兵庫県姫路市野里堀留町');
ok($zip->set_number('6700867')->is_valid_number, '兵庫県姫路市野里寺町');
ok($zip->set_number('6700868')->is_valid_number, '兵庫県姫路市大野町');
ok($zip->set_number('6700871')->is_valid_number, '兵庫県姫路市伊伝居');
ok($zip->set_number('6700872')->is_valid_number, '兵庫県姫路市八代');
ok($zip->set_number('6700873')->is_valid_number, '兵庫県姫路市八代東光寺町');
ok($zip->set_number('6700874')->is_valid_number, '兵庫県姫路市八代本町');
ok($zip->set_number('6700875')->is_valid_number, '兵庫県姫路市南八代町');
ok($zip->set_number('6700876')->is_valid_number, '兵庫県姫路市西八代町');
ok($zip->set_number('6700877')->is_valid_number, '兵庫県姫路市北八代');
ok($zip->set_number('6700881')->is_valid_number, '兵庫県姫路市峰南町');
ok($zip->set_number('6700882')->is_valid_number, '兵庫県姫路市広峰');
ok($zip->set_number('6700883')->is_valid_number, '兵庫県姫路市城北新町');
ok($zip->set_number('6700884')->is_valid_number, '兵庫県姫路市城北本町');
ok($zip->set_number('6700885')->is_valid_number, '兵庫県姫路市八代宮前町');
ok($zip->set_number('6700886')->is_valid_number, '兵庫県姫路市八代緑ケ丘町');
ok($zip->set_number('6700887')->is_valid_number, '兵庫県姫路市北平野南の町');
ok($zip->set_number('6700891')->is_valid_number, '兵庫県姫路市広嶺山');
ok($zip->set_number('6700892')->is_valid_number, '兵庫県姫路市北平野奥垣内');
ok($zip->set_number('6700893')->is_valid_number, '兵庫県姫路市北平野');
ok($zip->set_number('6700894')->is_valid_number, '兵庫県姫路市梅ケ谷町');
ok($zip->set_number('6700895')->is_valid_number, '兵庫県姫路市北平野台町');
ok($zip->set_number('6700896')->is_valid_number, '兵庫県姫路市上大野');
ok($zip->set_number('6700897')->is_valid_number, '兵庫県姫路市西大寿台');
ok($zip->set_number('6700898')->is_valid_number, '兵庫県姫路市大寿台');
ok($zip->set_number('6700901')->is_valid_number, '兵庫県姫路市西二階町');
ok($zip->set_number('6700902')->is_valid_number, '兵庫県姫路市白銀町');
ok($zip->set_number('6700903')->is_valid_number, '兵庫県姫路市立町');
ok($zip->set_number('6700904')->is_valid_number, '兵庫県姫路市塩町');
ok($zip->set_number('6700905')->is_valid_number, '兵庫県姫路市魚町');
ok($zip->set_number('6700906')->is_valid_number, '兵庫県姫路市博労町');
ok($zip->set_number('6700911')->is_valid_number, '兵庫県姫路市十二所前町');
ok($zip->set_number('6700912')->is_valid_number, '兵庫県姫路市南町');
ok($zip->set_number('6700913')->is_valid_number, '兵庫県姫路市西駅前町');
ok($zip->set_number('6700914')->is_valid_number, '兵庫県姫路市豆腐町');
ok($zip->set_number('6700915')->is_valid_number, '兵庫県姫路市高尾町');
ok($zip->set_number('6700916')->is_valid_number, '兵庫県姫路市久保町');
ok($zip->set_number('6700917')->is_valid_number, '兵庫県姫路市忍町');
ok($zip->set_number('6700921')->is_valid_number, '兵庫県姫路市綿町');
ok($zip->set_number('6700922')->is_valid_number, '兵庫県姫路市二階町');
ok($zip->set_number('6700923')->is_valid_number, '兵庫県姫路市呉服町');
ok($zip->set_number('6700924')->is_valid_number, '兵庫県姫路市紺屋町');
ok($zip->set_number('6700925')->is_valid_number, '兵庫県姫路市亀井町');
ok($zip->set_number('6700926')->is_valid_number, '兵庫県姫路市東駅前町');
ok($zip->set_number('6700927')->is_valid_number, '兵庫県姫路市駅前町');
ok($zip->set_number('6700931')->is_valid_number, '兵庫県姫路市坂田町');
ok($zip->set_number('6700932')->is_valid_number, '兵庫県姫路市下寺町');
ok($zip->set_number('6700933')->is_valid_number, '兵庫県姫路市平野町');
ok($zip->set_number('6700934')->is_valid_number, '兵庫県姫路市朝日町');
ok($zip->set_number('6700935')->is_valid_number, '兵庫県姫路市北条口');
ok($zip->set_number('6700936')->is_valid_number, '兵庫県姫路市古二階町');
ok($zip->set_number('6700937')->is_valid_number, '兵庫県姫路市元塩町');
ok($zip->set_number('6700940')->is_valid_number, '兵庫県姫路市三左衛門堀西の町');
ok($zip->set_number('6700941')->is_valid_number, '兵庫県姫路市若菜町');
ok($zip->set_number('6700942')->is_valid_number, '兵庫県姫路市日出町');
ok($zip->set_number('6700943')->is_valid_number, '兵庫県姫路市市之郷');
ok($zip->set_number('6700943')->is_valid_number, '兵庫県姫路市市之郷町');
ok($zip->set_number('6700944')->is_valid_number, '兵庫県姫路市阿保');
ok($zip->set_number('6700945')->is_valid_number, '兵庫県姫路市北条梅原町');
ok($zip->set_number('6700946')->is_valid_number, '兵庫県姫路市北条永良町');
ok($zip->set_number('6700947')->is_valid_number, '兵庫県姫路市北条');
ok($zip->set_number('6700948')->is_valid_number, '兵庫県姫路市北条宮の町');
ok($zip->set_number('6700949')->is_valid_number, '兵庫県姫路市三左衛門堀東の町');
ok($zip->set_number('6700951')->is_valid_number, '兵庫県姫路市庄田');
ok($zip->set_number('6700952')->is_valid_number, '兵庫県姫路市南条');
ok($zip->set_number('6700953')->is_valid_number, '兵庫県姫路市三条町(1丁目)');
ok($zip->set_number('6700954')->is_valid_number, '兵庫県姫路市栗山町');
ok($zip->set_number('6700955')->is_valid_number, '兵庫県姫路市安田');
ok($zip->set_number('6700961')->is_valid_number, '兵庫県姫路市南畝町');
ok($zip->set_number('6700962')->is_valid_number, '兵庫県姫路市南駅前町');
ok($zip->set_number('6700964')->is_valid_number, '兵庫県姫路市豊沢町');
ok($zip->set_number('6700965')->is_valid_number, '兵庫県姫路市東延末');
ok($zip->set_number('6700966')->is_valid_number, '兵庫県姫路市延末');
ok($zip->set_number('6700971')->is_valid_number, '兵庫県姫路市西延末');
ok($zip->set_number('6700972')->is_valid_number, '兵庫県姫路市手柄');
ok($zip->set_number('6700973')->is_valid_number, '兵庫県姫路市亀山');
ok($zip->set_number('6700974')->is_valid_number, '兵庫県姫路市飯田');
ok($zip->set_number('6700975')->is_valid_number, '兵庫県姫路市中地南町');
ok($zip->set_number('6700976')->is_valid_number, '兵庫県姫路市中地');
ok($zip->set_number('6700981')->is_valid_number, '兵庫県姫路市西庄');
ok($zip->set_number('6700982')->is_valid_number, '兵庫県姫路市岡田');
ok($zip->set_number('6700983')->is_valid_number, '兵庫県姫路市井ノ口');
ok($zip->set_number('6700984')->is_valid_number, '兵庫県姫路市町坪');
ok($zip->set_number('6700985')->is_valid_number, '兵庫県姫路市玉手');
ok($zip->set_number('6700986')->is_valid_number, '兵庫県姫路市苫編');
ok($zip->set_number('6700987')->is_valid_number, '兵庫県姫路市苫編南');
ok($zip->set_number('6700989')->is_valid_number, '兵庫県姫路市町坪南町');
ok($zip->set_number('6700991')->is_valid_number, '兵庫県姫路市神田町');
ok($zip->set_number('6700992')->is_valid_number, '兵庫県姫路市福沢町');
ok($zip->set_number('6700993')->is_valid_number, '兵庫県姫路市千代田町');
ok($zip->set_number('6700994')->is_valid_number, '兵庫県姫路市定元町');
ok($zip->set_number('6700995')->is_valid_number, '兵庫県姫路市土山東の町');
ok($zip->set_number('6700996')->is_valid_number, '兵庫県姫路市土山');
ok($zip->set_number('6710101')->is_valid_number, '兵庫県姫路市大塩町');
ok($zip->set_number('6710102')->is_valid_number, '兵庫県姫路市大塩町汐咲');
ok($zip->set_number('6710103')->is_valid_number, '兵庫県姫路市大塩町宮前');
ok($zip->set_number('6710111')->is_valid_number, '兵庫県姫路市的形町的形');
ok($zip->set_number('6710112')->is_valid_number, '兵庫県姫路市的形町福泊');
ok($zip->set_number('6710121')->is_valid_number, '兵庫県高砂市北浜町牛谷');
ok($zip->set_number('6710122')->is_valid_number, '兵庫県高砂市北浜町北脇');
ok($zip->set_number('6710123')->is_valid_number, '兵庫県高砂市北浜町西浜');
ok($zip->set_number('6710201')->is_valid_number, '兵庫県姫路市飾東町小原新');
ok($zip->set_number('6710202')->is_valid_number, '兵庫県姫路市飾東町北野');
ok($zip->set_number('6710203')->is_valid_number, '兵庫県姫路市飾東町大釜');
ok($zip->set_number('6710204')->is_valid_number, '兵庫県姫路市飾東町大釜新');
ok($zip->set_number('6710205')->is_valid_number, '兵庫県姫路市飾東町清住');
ok($zip->set_number('6710207')->is_valid_number, '兵庫県姫路市飾東町山崎');
ok($zip->set_number('6710208')->is_valid_number, '兵庫県姫路市飾東町八重畑');
ok($zip->set_number('6710209')->is_valid_number, '兵庫県姫路市飾東町小原');
ok($zip->set_number('6710211')->is_valid_number, '兵庫県姫路市飾東町塩崎');
ok($zip->set_number('6710212')->is_valid_number, '兵庫県姫路市飾東町北山');
ok($zip->set_number('6710214')->is_valid_number, '兵庫県姫路市飾東町唐端新');
ok($zip->set_number('6710215')->is_valid_number, '兵庫県姫路市飾東町夕陽ケ丘');
ok($zip->set_number('6710216')->is_valid_number, '兵庫県姫路市飾東町志吹');
ok($zip->set_number('6710217')->is_valid_number, '兵庫県姫路市飾東町佐良和');
ok($zip->set_number('6710218')->is_valid_number, '兵庫県姫路市飾東町庄');
ok($zip->set_number('6710219')->is_valid_number, '兵庫県姫路市飾東町豊国');
ok($zip->set_number('6710221')->is_valid_number, '兵庫県姫路市別所町別所');
ok($zip->set_number('6710222')->is_valid_number, '兵庫県姫路市別所町小林');
ok($zip->set_number('6710223')->is_valid_number, '兵庫県姫路市別所町北宿');
ok($zip->set_number('6710224')->is_valid_number, '兵庫県姫路市別所町佐土');
ok($zip->set_number('6710225')->is_valid_number, '兵庫県姫路市別所町家具町');
ok($zip->set_number('6710226')->is_valid_number, '兵庫県姫路市別所町佐土新');
ok($zip->set_number('6710231')->is_valid_number, '兵庫県姫路市御国野町深志野');
ok($zip->set_number('6710232')->is_valid_number, '兵庫県姫路市御国野町御着');
ok($zip->set_number('6710233')->is_valid_number, '兵庫県姫路市御国野町西御着');
ok($zip->set_number('6710234')->is_valid_number, '兵庫県姫路市御国野町国分寺');
ok($zip->set_number('6710241')->is_valid_number, '兵庫県姫路市四郷町上鈴');
ok($zip->set_number('6710242')->is_valid_number, '兵庫県姫路市四郷町中鈴');
ok($zip->set_number('6710243')->is_valid_number, '兵庫県姫路市四郷町本郷');
ok($zip->set_number('6710244')->is_valid_number, '兵庫県姫路市四郷町見野');
ok($zip->set_number('6710245')->is_valid_number, '兵庫県姫路市四郷町明田');
ok($zip->set_number('6710246')->is_valid_number, '兵庫県姫路市四郷町坂元');
ok($zip->set_number('6710247')->is_valid_number, '兵庫県姫路市四郷町東阿保');
ok($zip->set_number('6710248')->is_valid_number, '兵庫県姫路市四郷町山脇');
ok($zip->set_number('6710251')->is_valid_number, '兵庫県姫路市花田町上原田');
ok($zip->set_number('6710252')->is_valid_number, '兵庫県姫路市花田町加納原田');
ok($zip->set_number('6710253')->is_valid_number, '兵庫県姫路市花田町一本松');
ok($zip->set_number('6710254')->is_valid_number, '兵庫県姫路市花田町勅旨');
ok($zip->set_number('6710255')->is_valid_number, '兵庫県姫路市花田町小川');
ok($zip->set_number('6710256')->is_valid_number, '兵庫県姫路市花田町高木');
ok($zip->set_number('6711101')->is_valid_number, '兵庫県姫路市広畑区東夢前台');
ok($zip->set_number('6711102')->is_valid_number, '兵庫県姫路市広畑区蒲田');
ok($zip->set_number('6711103')->is_valid_number, '兵庫県姫路市広畑区西夢前台');
ok($zip->set_number('6711104')->is_valid_number, '兵庫県姫路市広畑区才');
ok($zip->set_number('6711105')->is_valid_number, '兵庫県姫路市広畑区則直');
ok($zip->set_number('6711106')->is_valid_number, '兵庫県姫路市広畑区京見町');
ok($zip->set_number('6711107')->is_valid_number, '兵庫県姫路市広畑区西蒲田');
ok($zip->set_number('6711108')->is_valid_number, '兵庫県姫路市広畑区城山町');
ok($zip->set_number('6711111')->is_valid_number, '兵庫県姫路市広畑区北河原町');
ok($zip->set_number('6711112')->is_valid_number, '兵庫県姫路市広畑区北野町');
ok($zip->set_number('6711113')->is_valid_number, '兵庫県姫路市広畑区清水町');
ok($zip->set_number('6711114')->is_valid_number, '兵庫県姫路市広畑区本町');
ok($zip->set_number('6711115')->is_valid_number, '兵庫県姫路市広畑区末広町');
ok($zip->set_number('6711116')->is_valid_number, '兵庫県姫路市広畑区正門通');
ok($zip->set_number('6711121')->is_valid_number, '兵庫県姫路市広畑区東新町');
ok($zip->set_number('6711122')->is_valid_number, '兵庫県姫路市広畑区夢前町');
ok($zip->set_number('6711123')->is_valid_number, '兵庫県姫路市広畑区富士町');
ok($zip->set_number('6711124')->is_valid_number, '兵庫県姫路市広畑区鶴町');
ok($zip->set_number('6711125')->is_valid_number, '兵庫県姫路市広畑区長町');
ok($zip->set_number('6711131')->is_valid_number, '兵庫県姫路市大津区天神町');
ok($zip->set_number('6711132')->is_valid_number, '兵庫県姫路市大津区勘兵衛町');
ok($zip->set_number('6711133')->is_valid_number, '兵庫県姫路市大津区吉美');
ok($zip->set_number('6711134')->is_valid_number, '兵庫県姫路市大津区真砂町');
ok($zip->set_number('6711135')->is_valid_number, '兵庫県姫路市大津区新町');
ok($zip->set_number('6711136')->is_valid_number, '兵庫県姫路市大津区恵美酒町');
ok($zip->set_number('6711141')->is_valid_number, '兵庫県姫路市大津区西土井');
ok($zip->set_number('6711142')->is_valid_number, '兵庫県姫路市大津区北天満町');
ok($zip->set_number('6711143')->is_valid_number, '兵庫県姫路市大津区天満');
ok($zip->set_number('6711144')->is_valid_number, '兵庫県姫路市大津区長松');
ok($zip->set_number('6711145')->is_valid_number, '兵庫県姫路市大津区平松');
ok($zip->set_number('6711146')->is_valid_number, '兵庫県姫路市大津区大津町');
ok($zip->set_number('6711151')->is_valid_number, '兵庫県姫路市広畑区早瀬町');
ok($zip->set_number('6711152')->is_valid_number, '兵庫県姫路市広畑区小松町');
ok($zip->set_number('6711153')->is_valid_number, '兵庫県姫路市広畑区高浜町');
ok($zip->set_number('6711154')->is_valid_number, '兵庫県姫路市広畑区吾妻町');
ok($zip->set_number('6711155')->is_valid_number, '兵庫県姫路市広畑区大町');
ok($zip->set_number('6711156')->is_valid_number, '兵庫県姫路市広畑区小坂');
ok($zip->set_number('6711201')->is_valid_number, '兵庫県姫路市勝原区下太田');
ok($zip->set_number('6711202')->is_valid_number, '兵庫県姫路市勝原区勝山町');
ok($zip->set_number('6711203')->is_valid_number, '兵庫県姫路市勝原区丁');
ok($zip->set_number('6711204')->is_valid_number, '兵庫県姫路市勝原区朝日谷');
ok($zip->set_number('6711205')->is_valid_number, '兵庫県姫路市勝原区大谷');
ok($zip->set_number('6711211')->is_valid_number, '兵庫県姫路市勝原区熊見');
ok($zip->set_number('6711212')->is_valid_number, '兵庫県姫路市勝原区勝原町');
ok($zip->set_number('6711213')->is_valid_number, '兵庫県姫路市勝原区宮田');
ok($zip->set_number('6711214')->is_valid_number, '兵庫県姫路市勝原区山戸');
ok($zip->set_number('6711221')->is_valid_number, '兵庫県姫路市網干区田井');
ok($zip->set_number('6711222')->is_valid_number, '兵庫県姫路市網干区宮内');
ok($zip->set_number('6711223')->is_valid_number, '兵庫県姫路市網干区坂上');
ok($zip->set_number('6711224')->is_valid_number, '兵庫県姫路市網干区津市場');
ok($zip->set_number('6711225')->is_valid_number, '兵庫県姫路市網干区福井');
ok($zip->set_number('6711226')->is_valid_number, '兵庫県姫路市網干区高田');
ok($zip->set_number('6711227')->is_valid_number, '兵庫県姫路市網干区和久');
ok($zip->set_number('6711228')->is_valid_number, '兵庫県姫路市網干区坂出');
ok($zip->set_number('6711231')->is_valid_number, '兵庫県姫路市網干区大江島');
ok($zip->set_number('6711232')->is_valid_number, '兵庫県姫路市網干区大江島寺前町');
ok($zip->set_number('6711233')->is_valid_number, '兵庫県姫路市網干区大江島古川町');
ok($zip->set_number('6711234')->is_valid_number, '兵庫県姫路市網干区新在家');
ok($zip->set_number('6711235')->is_valid_number, '兵庫県姫路市網干区北新在家');
ok($zip->set_number('6711236')->is_valid_number, '兵庫県姫路市網干区網干浜');
ok($zip->set_number('6711241')->is_valid_number, '兵庫県姫路市網干区興浜');
ok($zip->set_number('6711242')->is_valid_number, '兵庫県姫路市網干区浜田');
ok($zip->set_number('6711251')->is_valid_number, '兵庫県姫路市網干区垣内北町');
ok($zip->set_number('6711252')->is_valid_number, '兵庫県姫路市網干区垣内東町');
ok($zip->set_number('6711253')->is_valid_number, '兵庫県姫路市網干区垣内中町');
ok($zip->set_number('6711254')->is_valid_number, '兵庫県姫路市網干区余子浜');
ok($zip->set_number('6711255')->is_valid_number, '兵庫県姫路市網干区垣内南町');
ok($zip->set_number('6711256')->is_valid_number, '兵庫県姫路市網干区垣内西町');
ok($zip->set_number('6711257')->is_valid_number, '兵庫県姫路市網干区垣内本町');
ok($zip->set_number('6711261')->is_valid_number, '兵庫県姫路市余部区下余部');
ok($zip->set_number('6711262')->is_valid_number, '兵庫県姫路市余部区上余部');
ok($zip->set_number('6711263')->is_valid_number, '兵庫県姫路市余部区上川原');
ok($zip->set_number('6711301')->is_valid_number, '兵庫県たつの市御津町黒崎');
ok($zip->set_number('6711311')->is_valid_number, '兵庫県たつの市御津町中島');
ok($zip->set_number('6711312')->is_valid_number, '兵庫県たつの市御津町碇岩');
ok($zip->set_number('6711321')->is_valid_number, '兵庫県たつの市御津町苅屋');
ok($zip->set_number('6711331')->is_valid_number, '兵庫県たつの市御津町岩見');
ok($zip->set_number('6711332')->is_valid_number, '兵庫県たつの市御津町室津');
ok($zip->set_number('6711341')->is_valid_number, '兵庫県たつの市御津町釜屋');
ok($zip->set_number('6711342')->is_valid_number, '兵庫県たつの市御津町朝臣');
ok($zip->set_number('6711500')->is_valid_number, '兵庫県揖保郡太子町以下に掲載がない場合');
ok($zip->set_number('6711501')->is_valid_number, '兵庫県揖保郡太子町山田');
ok($zip->set_number('6711502')->is_valid_number, '兵庫県揖保郡太子町原');
ok($zip->set_number('6711503')->is_valid_number, '兵庫県揖保郡太子町天満山');
ok($zip->set_number('6711504')->is_valid_number, '兵庫県揖保郡太子町黒岡');
ok($zip->set_number('6711511')->is_valid_number, '兵庫県揖保郡太子町太田');
ok($zip->set_number('6711521')->is_valid_number, '兵庫県揖保郡太子町東出');
ok($zip->set_number('6711522')->is_valid_number, '兵庫県揖保郡太子町矢田部');
ok($zip->set_number('6711523')->is_valid_number, '兵庫県揖保郡太子町東南');
ok($zip->set_number('6711524')->is_valid_number, '兵庫県揖保郡太子町東保');
ok($zip->set_number('6711531')->is_valid_number, '兵庫県揖保郡太子町立岡');
ok($zip->set_number('6711532')->is_valid_number, '兵庫県揖保郡太子町糸井');
ok($zip->set_number('6711533')->is_valid_number, '兵庫県揖保郡太子町竹広');
ok($zip->set_number('6711534')->is_valid_number, '兵庫県揖保郡太子町福地');
ok($zip->set_number('6711535')->is_valid_number, '兵庫県揖保郡太子町蓮常寺');
ok($zip->set_number('6711541')->is_valid_number, '兵庫県揖保郡太子町塚森');
ok($zip->set_number('6711542')->is_valid_number, '兵庫県揖保郡太子町米田');
ok($zip->set_number('6711543')->is_valid_number, '兵庫県揖保郡太子町沖代');
ok($zip->set_number('6711544')->is_valid_number, '兵庫県揖保郡太子町吉福');
ok($zip->set_number('6711545')->is_valid_number, '兵庫県揖保郡太子町岩見構');
ok($zip->set_number('6711551')->is_valid_number, '兵庫県揖保郡太子町馬場');
ok($zip->set_number('6711552')->is_valid_number, '兵庫県揖保郡太子町下阿曽');
ok($zip->set_number('6711553')->is_valid_number, '兵庫県揖保郡太子町老原');
ok($zip->set_number('6711554')->is_valid_number, '兵庫県揖保郡太子町船代');
ok($zip->set_number('6711555')->is_valid_number, '兵庫県揖保郡太子町宮本');
ok($zip->set_number('6711556')->is_valid_number, '兵庫県揖保郡太子町常全');
ok($zip->set_number('6711557')->is_valid_number, '兵庫県揖保郡太子町阿曽');
ok($zip->set_number('6711561')->is_valid_number, '兵庫県揖保郡太子町鵤');
ok($zip->set_number('6711571')->is_valid_number, '兵庫県揖保郡太子町広坂');
ok($zip->set_number('6711572')->is_valid_number, '兵庫県揖保郡太子町王子');
ok($zip->set_number('6711573')->is_valid_number, '兵庫県揖保郡太子町上太田');
ok($zip->set_number('6711574')->is_valid_number, '兵庫県揖保郡太子町松ケ下');
ok($zip->set_number('6711575')->is_valid_number, '兵庫県揖保郡太子町佐用岡');
ok($zip->set_number('6711576')->is_valid_number, '兵庫県揖保郡太子町松尾');
ok($zip->set_number('6711601')->is_valid_number, '兵庫県たつの市揖保川町半田');
ok($zip->set_number('6711602')->is_valid_number, '兵庫県たつの市揖保川町野田');
ok($zip->set_number('6711603')->is_valid_number, '兵庫県たつの市揖保川町養久');
ok($zip->set_number('6711611')->is_valid_number, '兵庫県たつの市揖保川町新在家');
ok($zip->set_number('6711612')->is_valid_number, '兵庫県たつの市揖保川町本條');
ok($zip->set_number('6711613')->is_valid_number, '兵庫県たつの市揖保川町二塚');
ok($zip->set_number('6711621')->is_valid_number, '兵庫県たつの市揖保川町正條');
ok($zip->set_number('6711631')->is_valid_number, '兵庫県たつの市揖保川町山津屋');
ok($zip->set_number('6711632')->is_valid_number, '兵庫県たつの市揖保川町黍田');
ok($zip->set_number('6711641')->is_valid_number, '兵庫県たつの市揖保川町原');
ok($zip->set_number('6711642')->is_valid_number, '兵庫県たつの市揖保川町大門');
ok($zip->set_number('6711643')->is_valid_number, '兵庫県たつの市揖保川町神戸北山');
ok($zip->set_number('6711651')->is_valid_number, '兵庫県たつの市揖保川町片島');
ok($zip->set_number('6711661')->is_valid_number, '兵庫県たつの市揖保川町袋尻');
ok($zip->set_number('6711662')->is_valid_number, '兵庫県たつの市揖保川町市場');
ok($zip->set_number('6711663')->is_valid_number, '兵庫県たつの市揖保川町浦部');
ok($zip->set_number('6711664')->is_valid_number, '兵庫県たつの市揖保川町金剛山');
ok($zip->set_number('6711665')->is_valid_number, '兵庫県たつの市揖保川町馬場');
ok($zip->set_number('6712101')->is_valid_number, '兵庫県姫路市夢前町山之内');
ok($zip->set_number('6712102')->is_valid_number, '兵庫県姫路市夢前町新庄');
ok($zip->set_number('6712103')->is_valid_number, '兵庫県姫路市夢前町前之庄');
ok($zip->set_number('6712105')->is_valid_number, '兵庫県姫路市夢前町神種');
ok($zip->set_number('6712106')->is_valid_number, '兵庫県姫路市夢前町莇野');
ok($zip->set_number('6712111')->is_valid_number, '兵庫県姫路市夢前町杉之内');
ok($zip->set_number('6712112')->is_valid_number, '兵庫県姫路市夢前町塩田');
ok($zip->set_number('6712113')->is_valid_number, '兵庫県姫路市夢前町古知之庄');
ok($zip->set_number('6712114')->is_valid_number, '兵庫県姫路市夢前町糸田');
ok($zip->set_number('6712115')->is_valid_number, '兵庫県姫路市夢前町又坂');
ok($zip->set_number('6712116')->is_valid_number, '兵庫県姫路市夢前町寺');
ok($zip->set_number('6712117')->is_valid_number, '兵庫県姫路市夢前町高長');
ok($zip->set_number('6712121')->is_valid_number, '兵庫県姫路市夢前町宮置');
ok($zip->set_number('6712122')->is_valid_number, '兵庫県姫路市夢前町置本');
ok($zip->set_number('6712123')->is_valid_number, '兵庫県姫路市夢前町山冨');
ok($zip->set_number('6712124')->is_valid_number, '兵庫県姫路市夢前町玉田');
ok($zip->set_number('6712131')->is_valid_number, '兵庫県姫路市夢前町戸倉');
ok($zip->set_number('6712132')->is_valid_number, '兵庫県姫路市夢前町古瀬畑');
ok($zip->set_number('6712133')->is_valid_number, '兵庫県姫路市夢前町芦田');
ok($zip->set_number('6712134')->is_valid_number, '兵庫県姫路市夢前町菅生澗');
ok($zip->set_number('6712135')->is_valid_number, '兵庫県姫路市夢前町塚本');
ok($zip->set_number('6712136')->is_valid_number, '兵庫県姫路市夢前町護持');
ok($zip->set_number('6712137')->is_valid_number, '兵庫県姫路市夢前町野畑');
ok($zip->set_number('6712201')->is_valid_number, '兵庫県姫路市書写');
ok($zip->set_number('6712202')->is_valid_number, '兵庫県姫路市北夢前台(1丁目1~77番地)');
ok($zip->set_number('6712203')->is_valid_number, '兵庫県姫路市書写台');
ok($zip->set_number('6712211')->is_valid_number, '兵庫県姫路市田井台');
ok($zip->set_number('6712212')->is_valid_number, '兵庫県姫路市川西');
ok($zip->set_number('6712213')->is_valid_number, '兵庫県姫路市川西台');
ok($zip->set_number('6712214')->is_valid_number, '兵庫県姫路市西夢前台');
ok($zip->set_number('6712215')->is_valid_number, '兵庫県姫路市飾西台');
ok($zip->set_number('6712216')->is_valid_number, '兵庫県姫路市飾西');
ok($zip->set_number('6712217')->is_valid_number, '兵庫県姫路市町田');
ok($zip->set_number('6712221')->is_valid_number, '兵庫県姫路市青山北');
ok($zip->set_number('6712222')->is_valid_number, '兵庫県姫路市青山');
ok($zip->set_number('6712223')->is_valid_number, '兵庫県姫路市青山南');
ok($zip->set_number('6712224')->is_valid_number, '兵庫県姫路市青山西');
ok($zip->set_number('6712231')->is_valid_number, '兵庫県姫路市石倉');
ok($zip->set_number('6712232')->is_valid_number, '兵庫県姫路市相野');
ok($zip->set_number('6712233')->is_valid_number, '兵庫県姫路市太市中');
ok($zip->set_number('6712234')->is_valid_number, '兵庫県姫路市西脇');
ok($zip->set_number('6712241')->is_valid_number, '兵庫県姫路市刀出');
ok($zip->set_number('6712242')->is_valid_number, '兵庫県姫路市六角');
ok($zip->set_number('6712243')->is_valid_number, '兵庫県姫路市菅生台');
ok($zip->set_number('6712244')->is_valid_number, '兵庫県姫路市実法寺');
ok($zip->set_number('6712245')->is_valid_number, '兵庫県姫路市白鳥台');
ok($zip->set_number('6712246')->is_valid_number, '兵庫県姫路市打越');
ok($zip->set_number('6712247')->is_valid_number, '兵庫県姫路市緑台');
ok($zip->set_number('6712401')->is_valid_number, '兵庫県姫路市安富町安志');
ok($zip->set_number('6712411')->is_valid_number, '兵庫県姫路市安富町三森');
ok($zip->set_number('6712412')->is_valid_number, '兵庫県姫路市安富町名坂');
ok($zip->set_number('6712413')->is_valid_number, '兵庫県姫路市安富町末広');
ok($zip->set_number('6712414')->is_valid_number, '兵庫県姫路市安富町杤原');
ok($zip->set_number('6712415')->is_valid_number, '兵庫県姫路市安富町皆河');
ok($zip->set_number('6712416')->is_valid_number, '兵庫県姫路市安富町関');
ok($zip->set_number('6712421')->is_valid_number, '兵庫県姫路市安富町長野');
ok($zip->set_number('6712422')->is_valid_number, '兵庫県姫路市安富町塩野');
ok($zip->set_number('6712423')->is_valid_number, '兵庫県姫路市安富町狭戸');
ok($zip->set_number('6712424')->is_valid_number, '兵庫県姫路市安富町瀬川');
ok($zip->set_number('6712425')->is_valid_number, '兵庫県姫路市安富町三坂');
ok($zip->set_number('6712426')->is_valid_number, '兵庫県姫路市安富町植木野');
ok($zip->set_number('6712500')->is_valid_number, '兵庫県宍粟市以下に掲載がない場合');
ok($zip->set_number('6712501')->is_valid_number, '兵庫県宍粟市山崎町上ノ');
ok($zip->set_number('6712502')->is_valid_number, '兵庫県宍粟市山崎町中野');
ok($zip->set_number('6712503')->is_valid_number, '兵庫県宍粟市山崎町大谷');
ok($zip->set_number('6712504')->is_valid_number, '兵庫県宍粟市山崎町東下野');
ok($zip->set_number('6712505')->is_valid_number, '兵庫県宍粟市山崎町片山');
ok($zip->set_number('6712506')->is_valid_number, '兵庫県宍粟市山崎町宇野');
ok($zip->set_number('6712507')->is_valid_number, '兵庫県宍粟市山崎町下牧谷');
ok($zip->set_number('6712508')->is_valid_number, '兵庫県宍粟市山崎町上牧谷');
ok($zip->set_number('6712511')->is_valid_number, '兵庫県宍粟市山崎町清野');
ok($zip->set_number('6712512')->is_valid_number, '兵庫県宍粟市山崎町与位');
ok($zip->set_number('6712513')->is_valid_number, '兵庫県宍粟市山崎町梯');
ok($zip->set_number('6712514')->is_valid_number, '兵庫県宍粟市山崎町田井');
ok($zip->set_number('6712515')->is_valid_number, '兵庫県宍粟市山崎町五十波');
ok($zip->set_number('6712516')->is_valid_number, '兵庫県宍粟市山崎町三津');
ok($zip->set_number('6712517')->is_valid_number, '兵庫県宍粟市山崎町生谷');
ok($zip->set_number('6712518')->is_valid_number, '兵庫県宍粟市山崎町横須');
ok($zip->set_number('6712519')->is_valid_number, '兵庫県宍粟市山崎町下町');
ok($zip->set_number('6712521')->is_valid_number, '兵庫県宍粟市山崎町木ノ谷');
ok($zip->set_number('6712522')->is_valid_number, '兵庫県宍粟市山崎町杉ケ瀬');
ok($zip->set_number('6712523')->is_valid_number, '兵庫県宍粟市山崎町母栖');
ok($zip->set_number('6712524')->is_valid_number, '兵庫県宍粟市山崎町三谷');
ok($zip->set_number('6712525')->is_valid_number, '兵庫県宍粟市山崎町神谷');
ok($zip->set_number('6712526')->is_valid_number, '兵庫県宍粟市山崎町矢原');
ok($zip->set_number('6712527')->is_valid_number, '兵庫県宍粟市山崎町岸田');
ok($zip->set_number('6712528')->is_valid_number, '兵庫県宍粟市山崎町野々上');
ok($zip->set_number('6712531')->is_valid_number, '兵庫県宍粟市山崎町中');
ok($zip->set_number('6712532')->is_valid_number, '兵庫県宍粟市山崎町高所');
ok($zip->set_number('6712533')->is_valid_number, '兵庫県宍粟市山崎町須賀沢');
ok($zip->set_number('6712534')->is_valid_number, '兵庫県宍粟市山崎町川戸');
ok($zip->set_number('6712535')->is_valid_number, '兵庫県宍粟市山崎町宇原');
ok($zip->set_number('6712536')->is_valid_number, '兵庫県宍粟市山崎町下宇原');
ok($zip->set_number('6712541')->is_valid_number, '兵庫県宍粟市山崎町下広瀬');
ok($zip->set_number('6712542')->is_valid_number, '兵庫県宍粟市山崎町船元');
ok($zip->set_number('6712543')->is_valid_number, '兵庫県宍粟市山崎町野');
ok($zip->set_number('6712544')->is_valid_number, '兵庫県宍粟市山崎町千本屋');
ok($zip->set_number('6712545')->is_valid_number, '兵庫県宍粟市山崎町中井');
ok($zip->set_number('6712551')->is_valid_number, '兵庫県宍粟市山崎町春安');
ok($zip->set_number('6712552')->is_valid_number, '兵庫県宍粟市山崎町段');
ok($zip->set_number('6712553')->is_valid_number, '兵庫県宍粟市山崎町鶴木');
ok($zip->set_number('6712554')->is_valid_number, '兵庫県宍粟市山崎町御名');
ok($zip->set_number('6712555')->is_valid_number, '兵庫県宍粟市山崎町金谷');
ok($zip->set_number('6712556')->is_valid_number, '兵庫県宍粟市山崎町下比地');
ok($zip->set_number('6712557')->is_valid_number, '兵庫県宍粟市山崎町中比地');
ok($zip->set_number('6712558')->is_valid_number, '兵庫県宍粟市山崎町上比地');
ok($zip->set_number('6712560')->is_valid_number, '兵庫県宍粟市山崎町塩山');
ok($zip->set_number('6712561')->is_valid_number, '兵庫県宍粟市山崎町小茅野');
ok($zip->set_number('6712562')->is_valid_number, '兵庫県宍粟市山崎町大沢');
ok($zip->set_number('6712563')->is_valid_number, '兵庫県宍粟市山崎町塩田');
ok($zip->set_number('6712564')->is_valid_number, '兵庫県宍粟市山崎町青木');
ok($zip->set_number('6712565')->is_valid_number, '兵庫県宍粟市山崎町高下');
ok($zip->set_number('6712566')->is_valid_number, '兵庫県宍粟市山崎町市場');
ok($zip->set_number('6712567')->is_valid_number, '兵庫県宍粟市山崎町木谷');
ok($zip->set_number('6712568')->is_valid_number, '兵庫県宍粟市山崎町葛根');
ok($zip->set_number('6712569')->is_valid_number, '兵庫県宍粟市山崎町土万');
ok($zip->set_number('6712570')->is_valid_number, '兵庫県宍粟市山崎町加生');
ok($zip->set_number('6712571')->is_valid_number, '兵庫県宍粟市山崎町上寺');
ok($zip->set_number('6712572')->is_valid_number, '兵庫県宍粟市山崎町庄能');
ok($zip->set_number('6712573')->is_valid_number, '兵庫県宍粟市山崎町今宿');
ok($zip->set_number('6712574')->is_valid_number, '兵庫県宍粟市山崎町中広瀬');
ok($zip->set_number('6712575')->is_valid_number, '兵庫県宍粟市山崎町山田');
ok($zip->set_number('6712576')->is_valid_number, '兵庫県宍粟市山崎町鹿沢');
ok($zip->set_number('6712577')->is_valid_number, '兵庫県宍粟市山崎町山崎');
ok($zip->set_number('6712578')->is_valid_number, '兵庫県宍粟市山崎町元山崎');
ok($zip->set_number('6712579')->is_valid_number, '兵庫県宍粟市山崎町門前');
ok($zip->set_number('6713201')->is_valid_number, '兵庫県宍粟市千種町千草');
ok($zip->set_number('6713202')->is_valid_number, '兵庫県宍粟市千種町黒土');
ok($zip->set_number('6713211')->is_valid_number, '兵庫県宍粟市千種町岩野辺');
ok($zip->set_number('6713212')->is_valid_number, '兵庫県宍粟市千種町鷹巣');
ok($zip->set_number('6713221')->is_valid_number, '兵庫県宍粟市千種町西山');
ok($zip->set_number('6713222')->is_valid_number, '兵庫県宍粟市千種町奥西山');
ok($zip->set_number('6713223')->is_valid_number, '兵庫県宍粟市千種町室');
ok($zip->set_number('6713224')->is_valid_number, '兵庫県宍粟市千種町七野');
ok($zip->set_number('6713225')->is_valid_number, '兵庫県宍粟市千種町下河野');
ok($zip->set_number('6713231')->is_valid_number, '兵庫県宍粟市千種町河呂');
ok($zip->set_number('6713232')->is_valid_number, '兵庫県宍粟市千種町河内');
ok($zip->set_number('6713233')->is_valid_number, '兵庫県宍粟市千種町西河内');
ok($zip->set_number('6714101')->is_valid_number, '兵庫県宍粟市一宮町倉床');
ok($zip->set_number('6714102')->is_valid_number, '兵庫県宍粟市一宮町横山');
ok($zip->set_number('6714103')->is_valid_number, '兵庫県宍粟市一宮町黒原');
ok($zip->set_number('6714104')->is_valid_number, '兵庫県宍粟市一宮町井内');
ok($zip->set_number('6714105')->is_valid_number, '兵庫県宍粟市一宮町上岸田');
ok($zip->set_number('6714106')->is_valid_number, '兵庫県宍粟市一宮町百千家満');
ok($zip->set_number('6714107')->is_valid_number, '兵庫県宍粟市一宮町草木');
ok($zip->set_number('6714108')->is_valid_number, '兵庫県宍粟市一宮町千町');
ok($zip->set_number('6714111')->is_valid_number, '兵庫県宍粟市一宮町公文');
ok($zip->set_number('6714112')->is_valid_number, '兵庫県宍粟市一宮町森添');
ok($zip->set_number('6714113')->is_valid_number, '兵庫県宍粟市一宮町三方町');
ok($zip->set_number('6714114')->is_valid_number, '兵庫県宍粟市一宮町福野');
ok($zip->set_number('6714115')->is_valid_number, '兵庫県宍粟市一宮町河原田');
ok($zip->set_number('6714121')->is_valid_number, '兵庫県宍粟市一宮町福中');
ok($zip->set_number('6714122')->is_valid_number, '兵庫県宍粟市一宮町福知');
ok($zip->set_number('6714123')->is_valid_number, '兵庫県宍粟市一宮町生栖');
ok($zip->set_number('6714124')->is_valid_number, '兵庫県宍粟市一宮町深河谷');
ok($zip->set_number('6714125')->is_valid_number, '兵庫県宍粟市一宮町西深');
ok($zip->set_number('6714131')->is_valid_number, '兵庫県宍粟市一宮町安積');
ok($zip->set_number('6714132')->is_valid_number, '兵庫県宍粟市一宮町東市場');
ok($zip->set_number('6714133')->is_valid_number, '兵庫県宍粟市一宮町須行名');
ok($zip->set_number('6714134')->is_valid_number, '兵庫県宍粟市一宮町伊和');
ok($zip->set_number('6714135')->is_valid_number, '兵庫県宍粟市一宮町安黒');
ok($zip->set_number('6714136')->is_valid_number, '兵庫県宍粟市一宮町嶋田');
ok($zip->set_number('6714137')->is_valid_number, '兵庫県宍粟市一宮町閏賀');
ok($zip->set_number('6714138')->is_valid_number, '兵庫県宍粟市一宮町西安積');
ok($zip->set_number('6714139')->is_valid_number, '兵庫県宍粟市一宮町杉田');
ok($zip->set_number('6714141')->is_valid_number, '兵庫県宍粟市一宮町東河内');
ok($zip->set_number('6714142')->is_valid_number, '兵庫県宍粟市一宮町能倉');
ok($zip->set_number('6714143')->is_valid_number, '兵庫県宍粟市一宮町上野田');
ok($zip->set_number('6714144')->is_valid_number, '兵庫県宍粟市一宮町下野田');
ok($zip->set_number('6714201')->is_valid_number, '兵庫県宍粟市波賀町戸倉');
ok($zip->set_number('6714202')->is_valid_number, '兵庫県宍粟市波賀町道谷');
ok($zip->set_number('6714203')->is_valid_number, '兵庫県宍粟市波賀町鹿伏');
ok($zip->set_number('6714204')->is_valid_number, '兵庫県宍粟市波賀町引原');
ok($zip->set_number('6714211')->is_valid_number, '兵庫県宍粟市波賀町音水');
ok($zip->set_number('6714212')->is_valid_number, '兵庫県宍粟市波賀町日ノ原');
ok($zip->set_number('6714213')->is_valid_number, '兵庫県宍粟市波賀町原');
ok($zip->set_number('6714214')->is_valid_number, '兵庫県宍粟市波賀町野尻');
ok($zip->set_number('6714215')->is_valid_number, '兵庫県宍粟市波賀町飯見');
ok($zip->set_number('6714216')->is_valid_number, '兵庫県宍粟市波賀町皆木');
ok($zip->set_number('6714221')->is_valid_number, '兵庫県宍粟市波賀町上野');
ok($zip->set_number('6714231')->is_valid_number, '兵庫県宍粟市波賀町有賀');
ok($zip->set_number('6714232')->is_valid_number, '兵庫県宍粟市波賀町斉木');
ok($zip->set_number('6714241')->is_valid_number, '兵庫県宍粟市波賀町安賀');
ok($zip->set_number('6714242')->is_valid_number, '兵庫県宍粟市波賀町今市');
ok($zip->set_number('6714243')->is_valid_number, '兵庫県宍粟市波賀町小野');
ok($zip->set_number('6714244')->is_valid_number, '兵庫県宍粟市波賀町谷');
ok($zip->set_number('6714245')->is_valid_number, '兵庫県宍粟市波賀町日見谷');
ok($zip->set_number('6720101')->is_valid_number, '兵庫県姫路市家島町真浦');
ok($zip->set_number('6720102')->is_valid_number, '兵庫県姫路市家島町宮');
ok($zip->set_number('6720103')->is_valid_number, '兵庫県姫路市家島町坊勢');
ok($zip->set_number('6728001')->is_valid_number, '兵庫県姫路市兼田');
ok($zip->set_number('6728002')->is_valid_number, '兵庫県姫路市北原');
ok($zip->set_number('6728003')->is_valid_number, '兵庫県姫路市奥山');
ok($zip->set_number('6728004')->is_valid_number, '兵庫県姫路市継');
ok($zip->set_number('6728011')->is_valid_number, '兵庫県姫路市白浜町神田');
ok($zip->set_number('6728012')->is_valid_number, '兵庫県姫路市白浜町寺家');
ok($zip->set_number('6728013')->is_valid_number, '兵庫県姫路市白浜町宇佐崎北');
ok($zip->set_number('6728014')->is_valid_number, '兵庫県姫路市東山');
ok($zip->set_number('6728015')->is_valid_number, '兵庫県姫路市八家');
ok($zip->set_number('6728016')->is_valid_number, '兵庫県姫路市木場');
ok($zip->set_number('6728017')->is_valid_number, '兵庫県姫路市木場十八反町');
ok($zip->set_number('6728018')->is_valid_number, '兵庫県姫路市木場前中町');
ok($zip->set_number('6728019')->is_valid_number, '兵庫県姫路市木場前七反町');
ok($zip->set_number('6728021')->is_valid_number, '兵庫県姫路市白浜町宇佐崎中');
ok($zip->set_number('6728022')->is_valid_number, '兵庫県姫路市白浜町宇佐崎南');
ok($zip->set_number('6728023')->is_valid_number, '兵庫県姫路市白浜町');
ok($zip->set_number('6728024')->is_valid_number, '兵庫県姫路市白浜町灘浜');
ok($zip->set_number('6728025')->is_valid_number, '兵庫県姫路市飾磨区堀川町');
ok($zip->set_number('6728030')->is_valid_number, '兵庫県姫路市飾磨区阿成植木');
ok($zip->set_number('6728031')->is_valid_number, '兵庫県姫路市飾磨区妻鹿');
ok($zip->set_number('6728032')->is_valid_number, '兵庫県姫路市飾磨区妻鹿東海町');
ok($zip->set_number('6728033')->is_valid_number, '兵庫県姫路市飾磨区妻鹿日田町');
ok($zip->set_number('6728034')->is_valid_number, '兵庫県姫路市飾磨区妻鹿常盤町');
ok($zip->set_number('6728035')->is_valid_number, '兵庫県姫路市飾磨区中島');
ok($zip->set_number('6728036')->is_valid_number, '兵庫県姫路市飾磨区三和町');
ok($zip->set_number('6728037')->is_valid_number, '兵庫県姫路市飾磨区阿成');
ok($zip->set_number('6728038')->is_valid_number, '兵庫県姫路市飾磨区阿成鹿古');
ok($zip->set_number('6728039')->is_valid_number, '兵庫県姫路市飾磨区阿成渡場');
ok($zip->set_number('6728040')->is_valid_number, '兵庫県姫路市飾磨区野田町');
ok($zip->set_number('6728041')->is_valid_number, '兵庫県姫路市三条町(2丁目)');
ok($zip->set_number('6728043')->is_valid_number, '兵庫県姫路市飾磨区上野田');
ok($zip->set_number('6728044')->is_valid_number, '兵庫県姫路市飾磨区下野田');
ok($zip->set_number('6728045')->is_valid_number, '兵庫県姫路市飾磨区中野田');
ok($zip->set_number('6728046')->is_valid_number, '兵庫県姫路市飾磨区都倉');
ok($zip->set_number('6728047')->is_valid_number, '兵庫県姫路市飾磨区亀山');
ok($zip->set_number('6728048')->is_valid_number, '兵庫県姫路市飾磨区三宅');
ok($zip->set_number('6728049')->is_valid_number, '兵庫県姫路市佃町');
ok($zip->set_number('6728051')->is_valid_number, '兵庫県姫路市飾磨区清水');
ok($zip->set_number('6728052')->is_valid_number, '兵庫県姫路市飾磨区玉地');
ok($zip->set_number('6728053')->is_valid_number, '兵庫県姫路市飾磨区栄町');
ok($zip->set_number('6728054')->is_valid_number, '兵庫県姫路市飾磨区東堀');
ok($zip->set_number('6728055')->is_valid_number, '兵庫県姫路市飾磨区宮');
ok($zip->set_number('6728056')->is_valid_number, '兵庫県姫路市飾磨区御幸');
ok($zip->set_number('6728057')->is_valid_number, '兵庫県姫路市飾磨区恵美酒');
ok($zip->set_number('6728058')->is_valid_number, '兵庫県姫路市飾磨区阿成中垣内');
ok($zip->set_number('6728059')->is_valid_number, '兵庫県姫路市飾磨区阿成下垣内');
ok($zip->set_number('6728061')->is_valid_number, '兵庫県姫路市飾磨区天神');
ok($zip->set_number('6728062')->is_valid_number, '兵庫県姫路市飾磨区大浜');
ok($zip->set_number('6728063')->is_valid_number, '兵庫県姫路市飾磨区須加');
ok($zip->set_number('6728064')->is_valid_number, '兵庫県姫路市飾磨区細江');
ok($zip->set_number('6728069')->is_valid_number, '兵庫県姫路市飾磨区加茂南');
ok($zip->set_number('6728070')->is_valid_number, '兵庫県姫路市飾磨区加茂東');
ok($zip->set_number('6728071')->is_valid_number, '兵庫県姫路市飾磨区構');
ok($zip->set_number('6728072')->is_valid_number, '兵庫県姫路市飾磨区蓼野町');
ok($zip->set_number('6728073')->is_valid_number, '兵庫県姫路市飾磨区加茂北');
ok($zip->set_number('6728074')->is_valid_number, '兵庫県姫路市飾磨区加茂');
ok($zip->set_number('6728075')->is_valid_number, '兵庫県姫路市飾磨区思案橋');
ok($zip->set_number('6728076')->is_valid_number, '兵庫県姫路市飾磨区入船町');
ok($zip->set_number('6728077')->is_valid_number, '兵庫県姫路市飾磨区粕谷新町');
ok($zip->set_number('6728078')->is_valid_number, '兵庫県姫路市飾磨区英賀');
ok($zip->set_number('6728079')->is_valid_number, '兵庫県姫路市飾磨区今在家');
ok($zip->set_number('6728080')->is_valid_number, '兵庫県姫路市飾磨区英賀宮町');
ok($zip->set_number('6728081')->is_valid_number, '兵庫県姫路市飾磨区高町');
ok($zip->set_number('6728082')->is_valid_number, '兵庫県姫路市飾磨区付城');
ok($zip->set_number('6728083')->is_valid_number, '兵庫県姫路市飾磨区城南町');
ok($zip->set_number('6728084')->is_valid_number, '兵庫県姫路市飾磨区英賀清水町');
ok($zip->set_number('6728085')->is_valid_number, '兵庫県姫路市飾磨区中浜町');
ok($zip->set_number('6728086')->is_valid_number, '兵庫県姫路市飾磨区西浜町');
ok($zip->set_number('6728087')->is_valid_number, '兵庫県姫路市飾磨区英賀東町');
ok($zip->set_number('6728088')->is_valid_number, '兵庫県姫路市飾磨区英賀西町');
ok($zip->set_number('6728089')->is_valid_number, '兵庫県姫路市飾磨区英賀宮台');
ok($zip->set_number('6728090')->is_valid_number, '兵庫県姫路市飾磨区今在家北');
ok($zip->set_number('6728091')->is_valid_number, '兵庫県姫路市飾磨区英賀保駅前町');
ok($zip->set_number('6728092')->is_valid_number, '兵庫県姫路市飾磨区英賀春日町');
ok($zip->set_number('6728093')->is_valid_number, '兵庫県姫路市飾磨区矢倉町');
ok($zip->set_number('6728094')->is_valid_number, '兵庫県姫路市飾磨区鎌倉町');
ok($zip->set_number('6728095')->is_valid_number, '兵庫県姫路市飾磨区若宮町');
ok($zip->set_number('6728096')->is_valid_number, '兵庫県姫路市飾磨区山崎台');
ok($zip->set_number('6728097')->is_valid_number, '兵庫県姫路市飾磨区山崎');
ok($zip->set_number('6728098')->is_valid_number, '兵庫県姫路市飾磨区富士見ケ丘町');
ok($zip->set_number('6730000')->is_valid_number, '兵庫県明石市以下に掲載がない場合');
ok($zip->set_number('6730001')->is_valid_number, '兵庫県明石市明南町');
ok($zip->set_number('6730002')->is_valid_number, '兵庫県明石市旭が丘');
ok($zip->set_number('6730003')->is_valid_number, '兵庫県明石市鳥羽');
ok($zip->set_number('6730004')->is_valid_number, '兵庫県明石市鳥羽弁財天');
ok($zip->set_number('6730005')->is_valid_number, '兵庫県明石市小久保');
ok($zip->set_number('6730006')->is_valid_number, '兵庫県明石市鳥羽二本松');
ok($zip->set_number('6730007')->is_valid_number, '兵庫県明石市鳥羽西鳥羽');
ok($zip->set_number('6730008')->is_valid_number, '兵庫県明石市沢野');
ok($zip->set_number('6730009')->is_valid_number, '兵庫県明石市西明石東町');
ok($zip->set_number('6730011')->is_valid_number, '兵庫県明石市西明石町');
ok($zip->set_number('6730012')->is_valid_number, '兵庫県明石市和坂');
ok($zip->set_number('6730012')->is_valid_number, '兵庫県明石市和坂');
ok($zip->set_number('6730013')->is_valid_number, '兵庫県明石市和坂稲荷町');
ok($zip->set_number('6730014')->is_valid_number, '兵庫県明石市川崎町');
ok($zip->set_number('6730015')->is_valid_number, '兵庫県明石市花園町');
ok($zip->set_number('6730016')->is_valid_number, '兵庫県明石市松の内');
ok($zip->set_number('6730017')->is_valid_number, '兵庫県明石市野々上');
ok($zip->set_number('6730018')->is_valid_number, '兵庫県明石市西明石北町');
ok($zip->set_number('6730019')->is_valid_number, '兵庫県明石市沢野南町');
ok($zip->set_number('6730021')->is_valid_number, '兵庫県明石市北王子町');
ok($zip->set_number('6730022')->is_valid_number, '兵庫県明石市王子');
ok($zip->set_number('6730023')->is_valid_number, '兵庫県明石市西新町');
ok($zip->set_number('6730024')->is_valid_number, '兵庫県明石市南王子町');
ok($zip->set_number('6730025')->is_valid_number, '兵庫県明石市田町');
ok($zip->set_number('6730026')->is_valid_number, '兵庫県明石市船上町');
ok($zip->set_number('6730027')->is_valid_number, '兵庫県明石市新明町');
ok($zip->set_number('6730028')->is_valid_number, '兵庫県明石市硯町');
ok($zip->set_number('6730029')->is_valid_number, '兵庫県明石市大道町');
ok($zip->set_number('6730031')->is_valid_number, '兵庫県明石市宮の上');
ok($zip->set_number('6730032')->is_valid_number, '兵庫県明石市立石');
ok($zip->set_number('6730033')->is_valid_number, '兵庫県明石市林崎町');
ok($zip->set_number('6730034')->is_valid_number, '兵庫県明石市林');
ok($zip->set_number('6730035')->is_valid_number, '兵庫県明石市南貴崎町');
ok($zip->set_number('6730036')->is_valid_number, '兵庫県明石市松江');
ok($zip->set_number('6730037')->is_valid_number, '兵庫県明石市貴崎');
ok($zip->set_number('6730038')->is_valid_number, '兵庫県明石市別所町');
ok($zip->set_number('6730041')->is_valid_number, '兵庫県明石市西明石南町');
ok($zip->set_number('6730042')->is_valid_number, '兵庫県明石市東藤江');
ok($zip->set_number('6730043')->is_valid_number, '兵庫県明石市藤江(川添)');
ok($zip->set_number('6730044')->is_valid_number, '兵庫県明石市藤江');
ok($zip->set_number('6730045')->is_valid_number, '兵庫県明石市藤江(若林)');
ok($zip->set_number('6730046')->is_valid_number, '兵庫県明石市藤が丘');
ok($zip->set_number('6730047')->is_valid_number, '兵庫県明石市藤江(中谷町)');
ok($zip->set_number('6730048')->is_valid_number, '兵庫県明石市藤江(中谷山)');
ok($zip->set_number('6730049')->is_valid_number, '兵庫県明石市西明石西町');
ok($zip->set_number('6730400')->is_valid_number, '兵庫県三木市以下に掲載がない場合');
ok($zip->set_number('6730401')->is_valid_number, '兵庫県三木市跡部');
ok($zip->set_number('6730402')->is_valid_number, '兵庫県三木市加佐');
ok($zip->set_number('6730403')->is_valid_number, '兵庫県三木市末広');
ok($zip->set_number('6730404')->is_valid_number, '兵庫県三木市大村');
ok($zip->set_number('6730405')->is_valid_number, '兵庫県三木市平田');
ok($zip->set_number('6730411')->is_valid_number, '兵庫県三木市久留美');
ok($zip->set_number('6730412')->is_valid_number, '兵庫県三木市岩宮');
ok($zip->set_number('6730413')->is_valid_number, '兵庫県三木市大塚');
ok($zip->set_number('6730414')->is_valid_number, '兵庫県三木市芝町');
ok($zip->set_number('6730415')->is_valid_number, '兵庫県三木市府内');
ok($zip->set_number('6730416')->is_valid_number, '兵庫県三木市府内町');
ok($zip->set_number('6730421')->is_valid_number, '兵庫県三木市平井');
ok($zip->set_number('6730422')->is_valid_number, '兵庫県三木市与呂木');
ok($zip->set_number('6730423')->is_valid_number, '兵庫県三木市宿原');
ok($zip->set_number('6730424')->is_valid_number, '兵庫県三木市自由が丘本町');
ok($zip->set_number('6730425')->is_valid_number, '兵庫県三木市君が峰町');
ok($zip->set_number('6730431')->is_valid_number, '兵庫県三木市本町');
ok($zip->set_number('6730432')->is_valid_number, '兵庫県三木市上の丸町');
ok($zip->set_number('6730433')->is_valid_number, '兵庫県三木市福井');
ok($zip->set_number('6730434')->is_valid_number, '兵庫県三木市別所町小林');
ok($zip->set_number('6730435')->is_valid_number, '兵庫県三木市別所町高木');
ok($zip->set_number('6730436')->is_valid_number, '兵庫県三木市さつき台');
ok($zip->set_number('6730441')->is_valid_number, '兵庫県三木市別所町朝日ケ丘');
ok($zip->set_number('6730442')->is_valid_number, '兵庫県三木市別所町興治');
ok($zip->set_number('6730443')->is_valid_number, '兵庫県三木市別所町巴');
ok($zip->set_number('6730444')->is_valid_number, '兵庫県三木市別所町東這田');
ok($zip->set_number('6730445')->is_valid_number, '兵庫県三木市別所町西這田');
ok($zip->set_number('6730446')->is_valid_number, '兵庫県三木市別所町花尻');
ok($zip->set_number('6730451')->is_valid_number, '兵庫県三木市別所町近藤');
ok($zip->set_number('6730452')->is_valid_number, '兵庫県三木市別所町石野');
ok($zip->set_number('6730453')->is_valid_number, '兵庫県三木市別所町下石野');
ok($zip->set_number('6730454')->is_valid_number, '兵庫県三木市別所町正法寺');
ok($zip->set_number('6730455')->is_valid_number, '兵庫県三木市別所町和田');
ok($zip->set_number('6730456')->is_valid_number, '兵庫県三木市鳥町');
ok($zip->set_number('6730501')->is_valid_number, '兵庫県三木市志染町吉田');
ok($zip->set_number('6730502')->is_valid_number, '兵庫県三木市志染町安福田');
ok($zip->set_number('6730503')->is_valid_number, '兵庫県三木市志染町窟屋');
ok($zip->set_number('6730504')->is_valid_number, '兵庫県三木市志染町高男寺');
ok($zip->set_number('6730505')->is_valid_number, '兵庫県三木市志染町細目');
ok($zip->set_number('6730506')->is_valid_number, '兵庫県三木市志染町四合谷');
ok($zip->set_number('6730511')->is_valid_number, '兵庫県三木市志染町志染中');
ok($zip->set_number('6730512')->is_valid_number, '兵庫県三木市志染町井上');
ok($zip->set_number('6730513')->is_valid_number, '兵庫県三木市志染町大谷');
ok($zip->set_number('6730514')->is_valid_number, '兵庫県三木市志染町戸田');
ok($zip->set_number('6730515')->is_valid_number, '兵庫県三木市志染町三津田');
ok($zip->set_number('6730516')->is_valid_number, '兵庫県三木市志染町御坂');
ok($zip->set_number('6730521')->is_valid_number, '兵庫県三木市志染町青山');
ok($zip->set_number('6730531')->is_valid_number, '兵庫県三木市緑が丘町西');
ok($zip->set_number('6730532')->is_valid_number, '兵庫県三木市緑が丘町中');
ok($zip->set_number('6730533')->is_valid_number, '兵庫県三木市緑が丘町東');
ok($zip->set_number('6730534')->is_valid_number, '兵庫県三木市緑が丘町本町');
ok($zip->set_number('6730541')->is_valid_number, '兵庫県三木市志染町広野');
ok($zip->set_number('6730551')->is_valid_number, '兵庫県三木市志染町西自由が丘');
ok($zip->set_number('6730552')->is_valid_number, '兵庫県三木市志染町中自由が丘');
ok($zip->set_number('6730553')->is_valid_number, '兵庫県三木市志染町東自由が丘');
ok($zip->set_number('6730701')->is_valid_number, '兵庫県三木市細川町瑞穂');
ok($zip->set_number('6730702')->is_valid_number, '兵庫県三木市細川町中里');
ok($zip->set_number('6730703')->is_valid_number, '兵庫県三木市細川町垂穂');
ok($zip->set_number('6730704')->is_valid_number, '兵庫県三木市細川町増田');
ok($zip->set_number('6730711')->is_valid_number, '兵庫県三木市細川町金屋');
ok($zip->set_number('6730712')->is_valid_number, '兵庫県三木市細川町桃津');
ok($zip->set_number('6730713')->is_valid_number, '兵庫県三木市細川町豊地');
ok($zip->set_number('6730714')->is_valid_number, '兵庫県三木市細川町細川中');
ok($zip->set_number('6730715')->is_valid_number, '兵庫県三木市細川町西');
ok($zip->set_number('6730721')->is_valid_number, '兵庫県三木市細川町高篠');
ok($zip->set_number('6730722')->is_valid_number, '兵庫県三木市細川町脇川');
ok($zip->set_number('6730723')->is_valid_number, '兵庫県三木市加佐草荷野');
ok($zip->set_number('6730724')->is_valid_number, '兵庫県三木市細川町高畑');
ok($zip->set_number('6730731')->is_valid_number, '兵庫県三木市口吉川町東中');
ok($zip->set_number('6730732')->is_valid_number, '兵庫県三木市口吉川町馬場');
ok($zip->set_number('6730733')->is_valid_number, '兵庫県三木市口吉川町東');
ok($zip->set_number('6730734')->is_valid_number, '兵庫県三木市口吉川町蓮花寺');
ok($zip->set_number('6730735')->is_valid_number, '兵庫県三木市口吉川町西中');
ok($zip->set_number('6730736')->is_valid_number, '兵庫県三木市口吉川町桃坂');
ok($zip->set_number('6730741')->is_valid_number, '兵庫県三木市口吉川町殿畑');
ok($zip->set_number('6730742')->is_valid_number, '兵庫県三木市口吉川町保木');
ok($zip->set_number('6730743')->is_valid_number, '兵庫県三木市口吉川町桾原');
ok($zip->set_number('6730751')->is_valid_number, '兵庫県三木市口吉川町里脇');
ok($zip->set_number('6730752')->is_valid_number, '兵庫県三木市口吉川町吉祥寺');
ok($zip->set_number('6730753')->is_valid_number, '兵庫県三木市口吉川町槇');
ok($zip->set_number('6730754')->is_valid_number, '兵庫県三木市口吉川町善祥寺');
ok($zip->set_number('6730755')->is_valid_number, '兵庫県三木市口吉川町大島');
ok($zip->set_number('6730756')->is_valid_number, '兵庫県三木市口吉川町南畑');
ok($zip->set_number('6730757')->is_valid_number, '兵庫県三木市口吉川町笹原');
ok($zip->set_number('6730758')->is_valid_number, '兵庫県三木市口吉川町久次');
ok($zip->set_number('6730841')->is_valid_number, '兵庫県明石市太寺天王町');
ok($zip->set_number('6730842')->is_valid_number, '兵庫県明石市荷山町');
ok($zip->set_number('6730843')->is_valid_number, '兵庫県明石市太寺大野町');
ok($zip->set_number('6730844')->is_valid_number, '兵庫県明石市東野町');
ok($zip->set_number('6730845')->is_valid_number, '兵庫県明石市太寺');
ok($zip->set_number('6730846')->is_valid_number, '兵庫県明石市上ノ丸');
ok($zip->set_number('6730847')->is_valid_number, '兵庫県明石市明石公園');
ok($zip->set_number('6730848')->is_valid_number, '兵庫県明石市鷹匠町');
ok($zip->set_number('6730849')->is_valid_number, '兵庫県明石市茶園場町');
ok($zip->set_number('6730851')->is_valid_number, '兵庫県明石市朝霧北町');
ok($zip->set_number('6730852')->is_valid_number, '兵庫県明石市朝霧台');
ok($zip->set_number('6730853')->is_valid_number, '兵庫県明石市朝霧山手町');
ok($zip->set_number('6730854')->is_valid_number, '兵庫県明石市東朝霧丘');
ok($zip->set_number('6730855')->is_valid_number, '兵庫県明石市中朝霧丘');
ok($zip->set_number('6730856')->is_valid_number, '兵庫県明石市西朝霧丘');
ok($zip->set_number('6730857')->is_valid_number, '兵庫県明石市北朝霧丘');
ok($zip->set_number('6730860')->is_valid_number, '兵庫県明石市朝霧東町');
ok($zip->set_number('6730861')->is_valid_number, '兵庫県明石市松が丘北町');
ok($zip->set_number('6730862')->is_valid_number, '兵庫県明石市松が丘');
ok($zip->set_number('6730866')->is_valid_number, '兵庫県明石市朝霧町');
ok($zip->set_number('6730867')->is_valid_number, '兵庫県明石市大蔵谷奥');
ok($zip->set_number('6730868')->is_valid_number, '兵庫県明石市東山町');
ok($zip->set_number('6730870')->is_valid_number, '兵庫県明石市朝霧南町');
ok($zip->set_number('6730871')->is_valid_number, '兵庫県明石市大蔵八幡町');
ok($zip->set_number('6730872')->is_valid_number, '兵庫県明石市大蔵町');
ok($zip->set_number('6730873')->is_valid_number, '兵庫県明石市大蔵中町');
ok($zip->set_number('6730874')->is_valid_number, '兵庫県明石市大蔵本町');
ok($zip->set_number('6730875')->is_valid_number, '兵庫県明石市大蔵天神町');
ok($zip->set_number('6730876')->is_valid_number, '兵庫県明石市東人丸町');
ok($zip->set_number('6730877')->is_valid_number, '兵庫県明石市人丸町');
ok($zip->set_number('6730878')->is_valid_number, '兵庫県明石市山下町');
ok($zip->set_number('6730879')->is_valid_number, '兵庫県明石市大蔵海岸通');
ok($zip->set_number('6730881')->is_valid_number, '兵庫県明石市天文町');
ok($zip->set_number('6730882')->is_valid_number, '兵庫県明石市相生町');
ok($zip->set_number('6730883')->is_valid_number, '兵庫県明石市中崎');
ok($zip->set_number('6730884')->is_valid_number, '兵庫県明石市鍛治屋町');
ok($zip->set_number('6730885')->is_valid_number, '兵庫県明石市桜町');
ok($zip->set_number('6730886')->is_valid_number, '兵庫県明石市東仲ノ町');
ok($zip->set_number('6730891')->is_valid_number, '兵庫県明石市大明石町');
ok($zip->set_number('6730892')->is_valid_number, '兵庫県明石市本町');
ok($zip->set_number('6730893')->is_valid_number, '兵庫県明石市材木町');
ok($zip->set_number('6730894')->is_valid_number, '兵庫県明石市港町');
ok($zip->set_number('6730895')->is_valid_number, '兵庫県明石市岬町');
ok($zip->set_number('6730896')->is_valid_number, '兵庫県明石市日富美町');
ok($zip->set_number('6730897')->is_valid_number, '兵庫県明石市大観町');
ok($zip->set_number('6730898')->is_valid_number, '兵庫県明石市樽屋町');
ok($zip->set_number('6731101')->is_valid_number, '兵庫県三木市吉川町新田');
ok($zip->set_number('6731102')->is_valid_number, '兵庫県三木市吉川町冨岡');
ok($zip->set_number('6731103')->is_valid_number, '兵庫県三木市吉川町前田');
ok($zip->set_number('6731104')->is_valid_number, '兵庫県三木市吉川町上中');
ok($zip->set_number('6731105')->is_valid_number, '兵庫県三木市吉川町古川');
ok($zip->set_number('6731106')->is_valid_number, '兵庫県三木市吉川町実楽');
ok($zip->set_number('6731107')->is_valid_number, '兵庫県三木市吉川町有安');
ok($zip->set_number('6731108')->is_valid_number, '兵庫県三木市吉川町古市');
ok($zip->set_number('6731111')->is_valid_number, '兵庫県三木市吉川町上荒川');
ok($zip->set_number('6731112')->is_valid_number, '兵庫県三木市吉川町畑枝');
ok($zip->set_number('6731113')->is_valid_number, '兵庫県三木市吉川町福井');
ok($zip->set_number('6731114')->is_valid_number, '兵庫県三木市吉川町吉安');
ok($zip->set_number('6731115')->is_valid_number, '兵庫県三木市吉川町大沢');
ok($zip->set_number('6731116')->is_valid_number, '兵庫県三木市吉川町大畑');
ok($zip->set_number('6731117')->is_valid_number, '兵庫県三木市吉川町みなぎ台');
ok($zip->set_number('6731118')->is_valid_number, '兵庫県三木市吉川町貸潮');
ok($zip->set_number('6731119')->is_valid_number, '兵庫県三木市吉川町鍛治屋');
ok($zip->set_number('6731121')->is_valid_number, '兵庫県三木市吉川町米田');
ok($zip->set_number('6731122')->is_valid_number, '兵庫県三木市吉川町西奥');
ok($zip->set_number('6731123')->is_valid_number, '兵庫県三木市吉川町湯谷');
ok($zip->set_number('6731124')->is_valid_number, '兵庫県三木市吉川町法光寺');
ok($zip->set_number('6731125')->is_valid_number, '兵庫県三木市吉川町田谷');
ok($zip->set_number('6731126')->is_valid_number, '兵庫県三木市吉川町上松');
ok($zip->set_number('6731127')->is_valid_number, '兵庫県三木市吉川町長谷');
ok($zip->set_number('6731128')->is_valid_number, '兵庫県三木市吉川町山上');
ok($zip->set_number('6731129')->is_valid_number, '兵庫県三木市吉川町渡瀬');
ok($zip->set_number('6731231')->is_valid_number, '兵庫県三木市吉川町稲田');
ok($zip->set_number('6731232')->is_valid_number, '兵庫県三木市吉川町金会');
ok($zip->set_number('6731233')->is_valid_number, '兵庫県三木市吉川町毘沙門');
ok($zip->set_number('6731234')->is_valid_number, '兵庫県三木市吉川町福吉');
ok($zip->set_number('6731235')->is_valid_number, '兵庫県三木市吉川町市野瀬');
ok($zip->set_number('6731236')->is_valid_number, '兵庫県三木市吉川町東田');
ok($zip->set_number('6731241')->is_valid_number, '兵庫県三木市吉川町楠原');
ok($zip->set_number('6731242')->is_valid_number, '兵庫県三木市吉川町奥谷');
ok($zip->set_number('6731243')->is_valid_number, '兵庫県三木市吉川町豊岡');
ok($zip->set_number('6731244')->is_valid_number, '兵庫県三木市吉川町水上');
ok($zip->set_number('6731301')->is_valid_number, '兵庫県加東市黒谷');
ok($zip->set_number('6731302')->is_valid_number, '兵庫県加東市秋津');
ok($zip->set_number('6731303')->is_valid_number, '兵庫県加東市少分谷');
ok($zip->set_number('6731304')->is_valid_number, '兵庫県加東市長貞');
ok($zip->set_number('6731311')->is_valid_number, '兵庫県加東市天神');
ok($zip->set_number('6731312')->is_valid_number, '兵庫県加東市掎鹿谷');
ok($zip->set_number('6731313')->is_valid_number, '兵庫県加東市永福');
ok($zip->set_number('6731314')->is_valid_number, '兵庫県加東市横谷');
ok($zip->set_number('6731321')->is_valid_number, '兵庫県加東市岩屋');
ok($zip->set_number('6731322')->is_valid_number, '兵庫県加東市森');
ok($zip->set_number('6731323')->is_valid_number, '兵庫県加東市岡本');
ok($zip->set_number('6731324')->is_valid_number, '兵庫県加東市新定');
ok($zip->set_number('6731325')->is_valid_number, '兵庫県加東市大畑');
ok($zip->set_number('6731331')->is_valid_number, '兵庫県加東市森尾');
ok($zip->set_number('6731332')->is_valid_number, '兵庫県加東市栄枝');
ok($zip->set_number('6731333')->is_valid_number, '兵庫県加東市小沢');
ok($zip->set_number('6731334')->is_valid_number, '兵庫県加東市吉井');
ok($zip->set_number('6731335')->is_valid_number, '兵庫県加東市藪');
ok($zip->set_number('6731336')->is_valid_number, '兵庫県加東市東垂水');
ok($zip->set_number('6731337')->is_valid_number, '兵庫県加東市松沢');
ok($zip->set_number('6731338')->is_valid_number, '兵庫県加東市厚利');
ok($zip->set_number('6731341')->is_valid_number, '兵庫県加東市南山');
ok($zip->set_number('6731400')->is_valid_number, '兵庫県加東市以下に掲載がない場合');
ok($zip->set_number('6731401')->is_valid_number, '兵庫県加東市上鴨川');
ok($zip->set_number('6731402')->is_valid_number, '兵庫県加東市平木');
ok($zip->set_number('6731403')->is_valid_number, '兵庫県加東市下鴨川');
ok($zip->set_number('6731404')->is_valid_number, '兵庫県加東市馬瀬');
ok($zip->set_number('6731411')->is_valid_number, '兵庫県加東市畑');
ok($zip->set_number('6731412')->is_valid_number, '兵庫県加東市廻渕');
ok($zip->set_number('6731413')->is_valid_number, '兵庫県加東市池之内');
ok($zip->set_number('6731414')->is_valid_number, '兵庫県加東市上久米');
ok($zip->set_number('6731415')->is_valid_number, '兵庫県加東市下久米');
ok($zip->set_number('6731416')->is_valid_number, '兵庫県加東市久米');
ok($zip->set_number('6731421')->is_valid_number, '兵庫県加東市山国');
ok($zip->set_number('6731422')->is_valid_number, '兵庫県加東市屋度');
ok($zip->set_number('6731423')->is_valid_number, '兵庫県加東市東古瀬');
ok($zip->set_number('6731424')->is_valid_number, '兵庫県加東市中古瀬');
ok($zip->set_number('6731425')->is_valid_number, '兵庫県加東市西古瀬');
ok($zip->set_number('6731431')->is_valid_number, '兵庫県加東市社');
ok($zip->set_number('6731432')->is_valid_number, '兵庫県加東市ひろのが丘');
ok($zip->set_number('6731433')->is_valid_number, '兵庫県加東市松尾');
ok($zip->set_number('6731434')->is_valid_number, '兵庫県加東市東実');
ok($zip->set_number('6731441')->is_valid_number, '兵庫県加東市田中');
ok($zip->set_number('6731442')->is_valid_number, '兵庫県加東市出水');
ok($zip->set_number('6731443')->is_valid_number, '兵庫県加東市福吉');
ok($zip->set_number('6731444')->is_valid_number, '兵庫県加東市沢部');
ok($zip->set_number('6731445')->is_valid_number, '兵庫県加東市大門');
ok($zip->set_number('6731446')->is_valid_number, '兵庫県加東市上田');
ok($zip->set_number('6731447')->is_valid_number, '兵庫県加東市佐保');
ok($zip->set_number('6731451')->is_valid_number, '兵庫県加東市家原');
ok($zip->set_number('6731452')->is_valid_number, '兵庫県加東市鳥居');
ok($zip->set_number('6731453')->is_valid_number, '兵庫県加東市貝原');
ok($zip->set_number('6731454')->is_valid_number, '兵庫県加東市野村');
ok($zip->set_number('6731455')->is_valid_number, '兵庫県加東市西垂水');
ok($zip->set_number('6731456')->is_valid_number, '兵庫県加東市窪田');
ok($zip->set_number('6731461')->is_valid_number, '兵庫県加東市木梨');
ok($zip->set_number('6731462')->is_valid_number, '兵庫県加東市藤田');
ok($zip->set_number('6731463')->is_valid_number, '兵庫県加東市梶原');
ok($zip->set_number('6731464')->is_valid_number, '兵庫県加東市上中');
ok($zip->set_number('6731465')->is_valid_number, '兵庫県加東市喜田');
ok($zip->set_number('6731471')->is_valid_number, '兵庫県加東市山口');
ok($zip->set_number('6731472')->is_valid_number, '兵庫県加東市上三草');
ok($zip->set_number('6731473')->is_valid_number, '兵庫県加東市下三草');
ok($zip->set_number('6731474')->is_valid_number, '兵庫県加東市牧野');
ok($zip->set_number('6731475')->is_valid_number, '兵庫県加東市吉馬');
ok($zip->set_number('6740050')->is_valid_number, '兵庫県明石市大久保町松陰山手');
ok($zip->set_number('6740051')->is_valid_number, '兵庫県明石市大久保町大窪');
ok($zip->set_number('6740052')->is_valid_number, '兵庫県明石市大久保町松陰新田');
ok($zip->set_number('6740053')->is_valid_number, '兵庫県明石市大久保町松陰');
ok($zip->set_number('6740054')->is_valid_number, '兵庫県明石市大久保町西脇');
ok($zip->set_number('6740055')->is_valid_number, '兵庫県明石市大久保町緑が丘');
ok($zip->set_number('6740056')->is_valid_number, '兵庫県明石市大久保町山手台');
ok($zip->set_number('6740057')->is_valid_number, '兵庫県明石市大久保町高丘');
ok($zip->set_number('6740058')->is_valid_number, '兵庫県明石市大久保町駅前');
ok($zip->set_number('6740059')->is_valid_number, '兵庫県明石市大久保町茜');
ok($zip->set_number('6740061')->is_valid_number, '兵庫県明石市大久保町森田');
ok($zip->set_number('6740062')->is_valid_number, '兵庫県明石市大久保町谷八木');
ok($zip->set_number('6740063')->is_valid_number, '兵庫県明石市大久保町八木');
ok($zip->set_number('6740064')->is_valid_number, '兵庫県明石市大久保町江井島');
ok($zip->set_number('6740065')->is_valid_number, '兵庫県明石市大久保町西島');
ok($zip->set_number('6740066')->is_valid_number, '兵庫県明石市大久保町福田');
ok($zip->set_number('6740067')->is_valid_number, '兵庫県明石市大久保町大久保町');
ok($zip->set_number('6740068')->is_valid_number, '兵庫県明石市大久保町ゆりのき通');
ok($zip->set_number('6740069')->is_valid_number, '兵庫県明石市大久保町わかば');
ok($zip->set_number('6740071')->is_valid_number, '兵庫県明石市魚住町金ケ崎');
ok($zip->set_number('6740072')->is_valid_number, '兵庫県明石市魚住町長坂寺');
ok($zip->set_number('6740073')->is_valid_number, '兵庫県明石市魚住町鴨池');
ok($zip->set_number('6740074')->is_valid_number, '兵庫県明石市魚住町清水');
ok($zip->set_number('6740081')->is_valid_number, '兵庫県明石市魚住町錦が丘');
ok($zip->set_number('6740082')->is_valid_number, '兵庫県明石市魚住町中尾');
ok($zip->set_number('6740083')->is_valid_number, '兵庫県明石市魚住町住吉');
ok($zip->set_number('6740084')->is_valid_number, '兵庫県明石市魚住町西岡');
ok($zip->set_number('6740091')->is_valid_number, '兵庫県明石市二見町福里');
ok($zip->set_number('6740092')->is_valid_number, '兵庫県明石市二見町東二見');
ok($zip->set_number('6740093')->is_valid_number, '兵庫県明石市二見町南二見');
ok($zip->set_number('6740094')->is_valid_number, '兵庫県明石市二見町西二見');
ok($zip->set_number('6740095')->is_valid_number, '兵庫県明石市二見町西二見駅前');
ok($zip->set_number('6750000')->is_valid_number, '兵庫県加古川市以下に掲載がない場合');
ok($zip->set_number('6750000')->is_valid_number, '兵庫県加西市以下に掲載がない場合');
ok($zip->set_number('6750001')->is_valid_number, '兵庫県加古川市西条山手');
ok($zip->set_number('6750002')->is_valid_number, '兵庫県加古川市山手');
ok($zip->set_number('6750003')->is_valid_number, '兵庫県加古川市神野町神野');
ok($zip->set_number('6750004')->is_valid_number, '兵庫県加古川市神野町福留');
ok($zip->set_number('6750005')->is_valid_number, '兵庫県加古川市神野町石守');
ok($zip->set_number('6750006')->is_valid_number, '兵庫県加古川市神野町日岡苑');
ok($zip->set_number('6750007')->is_valid_number, '兵庫県加古川市神野町西之山');
ok($zip->set_number('6750008')->is_valid_number, '兵庫県加古川市新神野');
ok($zip->set_number('6750009')->is_valid_number, '兵庫県加古川市神野町西条');
ok($zip->set_number('6750010')->is_valid_number, '兵庫県加古川市野口町坂元北');
ok($zip->set_number('6750011')->is_valid_number, '兵庫県加古川市野口町北野');
ok($zip->set_number('6750012')->is_valid_number, '兵庫県加古川市野口町野口');
ok($zip->set_number('6750013')->is_valid_number, '兵庫県加古川市野口町二屋');
ok($zip->set_number('6750014')->is_valid_number, '兵庫県加古川市野口町古大内');
ok($zip->set_number('6750015')->is_valid_number, '兵庫県加古川市野口町坂井');
ok($zip->set_number('6750016')->is_valid_number, '兵庫県加古川市野口町長砂');
ok($zip->set_number('6750017')->is_valid_number, '兵庫県加古川市野口町良野');
ok($zip->set_number('6750018')->is_valid_number, '兵庫県加古川市野口町坂元');
ok($zip->set_number('6750019')->is_valid_number, '兵庫県加古川市野口町水足');
ok($zip->set_number('6750021')->is_valid_number, '兵庫県加古川市尾上町安田');
ok($zip->set_number('6750022')->is_valid_number, '兵庫県加古川市尾上町口里');
ok($zip->set_number('6750023')->is_valid_number, '兵庫県加古川市尾上町池田');
ok($zip->set_number('6750024')->is_valid_number, '兵庫県加古川市尾上町長田');
ok($zip->set_number('6750025')->is_valid_number, '兵庫県加古川市尾上町養田');
ok($zip->set_number('6750026')->is_valid_number, '兵庫県加古川市尾上町旭');
ok($zip->set_number('6750027')->is_valid_number, '兵庫県加古川市尾上町今福');
ok($zip->set_number('6750031')->is_valid_number, '兵庫県加古川市加古川町北在家');
ok($zip->set_number('6750032')->is_valid_number, '兵庫県加古川市加古川町備後');
ok($zip->set_number('6750033')->is_valid_number, '兵庫県加古川市加古川町南備後');
ok($zip->set_number('6750034')->is_valid_number, '兵庫県加古川市加古川町稲屋');
ok($zip->set_number('6750035')->is_valid_number, '兵庫県加古川市加古川町友沢');
ok($zip->set_number('6750036')->is_valid_number, '兵庫県加古川市加古川町西河原');
ok($zip->set_number('6750037')->is_valid_number, '兵庫県加古川市加古川町本町');
ok($zip->set_number('6750038')->is_valid_number, '兵庫県加古川市加古川町木村');
ok($zip->set_number('6750039')->is_valid_number, '兵庫県加古川市加古川町粟津');
ok($zip->set_number('6750041')->is_valid_number, '兵庫県加古川市西神吉町宮前');
ok($zip->set_number('6750042')->is_valid_number, '兵庫県加古川市西神吉町西村');
ok($zip->set_number('6750043')->is_valid_number, '兵庫県加古川市西神吉町中西');
ok($zip->set_number('6750044')->is_valid_number, '兵庫県加古川市西神吉町大国');
ok($zip->set_number('6750045')->is_valid_number, '兵庫県加古川市西神吉町岸');
ok($zip->set_number('6750046')->is_valid_number, '兵庫県加古川市西神吉町辻');
ok($zip->set_number('6750047')->is_valid_number, '兵庫県加古川市西神吉町鼎');
ok($zip->set_number('6750051')->is_valid_number, '兵庫県加古川市東神吉町升田');
ok($zip->set_number('6750052')->is_valid_number, '兵庫県加古川市東神吉町出河原');
ok($zip->set_number('6750053')->is_valid_number, '兵庫県加古川市米田町船頭');
ok($zip->set_number('6750054')->is_valid_number, '兵庫県加古川市米田町平津');
ok($zip->set_number('6750055')->is_valid_number, '兵庫県加古川市東神吉町西井ノ口');
ok($zip->set_number('6750056')->is_valid_number, '兵庫県加古川市東神吉町砂部');
ok($zip->set_number('6750057')->is_valid_number, '兵庫県加古川市東神吉町神吉');
ok($zip->set_number('6750058')->is_valid_number, '兵庫県加古川市東神吉町天下原');
ok($zip->set_number('6750061')->is_valid_number, '兵庫県加古川市加古川町大野');
ok($zip->set_number('6750062')->is_valid_number, '兵庫県加古川市加古川町美乃利');
ok($zip->set_number('6750063')->is_valid_number, '兵庫県加古川市加古川町平野');
ok($zip->set_number('6750064')->is_valid_number, '兵庫県加古川市加古川町溝之口');
ok($zip->set_number('6750065')->is_valid_number, '兵庫県加古川市加古川町篠原町');
ok($zip->set_number('6750066')->is_valid_number, '兵庫県加古川市加古川町寺家町');
ok($zip->set_number('6750067')->is_valid_number, '兵庫県加古川市加古川町河原');
ok($zip->set_number('6750068')->is_valid_number, '兵庫県加古川市加古川町中津');
ok($zip->set_number('6750100')->is_valid_number, '兵庫県加古郡播磨町以下に掲載がない場合');
ok($zip->set_number('6750101')->is_valid_number, '兵庫県加古川市平岡町新在家');
ok($zip->set_number('6750102')->is_valid_number, '兵庫県加古川市平岡町西谷');
ok($zip->set_number('6750103')->is_valid_number, '兵庫県加古川市平岡町高畑');
ok($zip->set_number('6750104')->is_valid_number, '兵庫県加古川市平岡町土山');
ok($zip->set_number('6750105')->is_valid_number, '兵庫県加古川市平岡町つつじ野');
ok($zip->set_number('6750111')->is_valid_number, '兵庫県加古川市平岡町二俣');
ok($zip->set_number('6750112')->is_valid_number, '兵庫県加古川市平岡町山之上');
ok($zip->set_number('6750113')->is_valid_number, '兵庫県加古川市平岡町中野');
ok($zip->set_number('6750114')->is_valid_number, '兵庫県加古川市平岡町八反田');
ok($zip->set_number('6750115')->is_valid_number, '兵庫県加古川市平岡町一色');
ok($zip->set_number('6750116')->is_valid_number, '兵庫県加古川市平岡町一色東');
ok($zip->set_number('6750117')->is_valid_number, '兵庫県加古川市平岡町一色西');
ok($zip->set_number('6750121')->is_valid_number, '兵庫県加古川市別府町新野辺北町');
ok($zip->set_number('6750122')->is_valid_number, '兵庫県加古川市別府町別府');
ok($zip->set_number('6750123')->is_valid_number, '兵庫県加古川市別府町朝日町');
ok($zip->set_number('6750124')->is_valid_number, '兵庫県加古川市別府町緑町');
ok($zip->set_number('6750125')->is_valid_number, '兵庫県加古川市別府町西脇');
ok($zip->set_number('6750126')->is_valid_number, '兵庫県加古川市別府町本町');
ok($zip->set_number('6750127')->is_valid_number, '兵庫県加古川市別府町石町');
ok($zip->set_number('6750128')->is_valid_number, '兵庫県加古川市別府町中島町');
ok($zip->set_number('6750131')->is_valid_number, '兵庫県加古川市別府町新野辺');
ok($zip->set_number('6750132')->is_valid_number, '兵庫県加古川市別府町宮田町');
ok($zip->set_number('6750133')->is_valid_number, '兵庫県加古川市別府町西町');
ok($zip->set_number('6750134')->is_valid_number, '兵庫県加古川市別府町元町');
ok($zip->set_number('6750135')->is_valid_number, '兵庫県加古川市別府町東町');
ok($zip->set_number('6750136')->is_valid_number, '兵庫県加古川市別府町港町');
ok($zip->set_number('6750137')->is_valid_number, '兵庫県加古川市金沢町');
ok($zip->set_number('6750141')->is_valid_number, '兵庫県加古郡播磨町野添城');
ok($zip->set_number('6750142')->is_valid_number, '兵庫県加古郡播磨町大中');
ok($zip->set_number('6750143')->is_valid_number, '兵庫県加古郡播磨町宮北');
ok($zip->set_number('6750144')->is_valid_number, '兵庫県加古郡播磨町北本荘');
ok($zip->set_number('6750145')->is_valid_number, '兵庫県加古郡播磨町宮西');
ok($zip->set_number('6750146')->is_valid_number, '兵庫県加古郡播磨町古田');
ok($zip->set_number('6750147')->is_valid_number, '兵庫県加古郡播磨町南大中');
ok($zip->set_number('6750148')->is_valid_number, '兵庫県加古郡播磨町北古田');
ok($zip->set_number('6750150')->is_valid_number, '兵庫県加古郡播磨町南野添');
ok($zip->set_number('6750151')->is_valid_number, '兵庫県加古郡播磨町野添');
ok($zip->set_number('6750154')->is_valid_number, '兵庫県加古郡播磨町本荘');
ok($zip->set_number('6750155')->is_valid_number, '兵庫県加古郡播磨町新島');
ok($zip->set_number('6750156')->is_valid_number, '兵庫県加古郡播磨町東本荘');
ok($zip->set_number('6750157')->is_valid_number, '兵庫県加古郡播磨町上野添');
ok($zip->set_number('6750158')->is_valid_number, '兵庫県加古郡播磨町北野添');
ok($zip->set_number('6750159')->is_valid_number, '兵庫県加古郡播磨町東野添');
ok($zip->set_number('6750160')->is_valid_number, '兵庫県加古郡播磨町西野添');
ok($zip->set_number('6750162')->is_valid_number, '兵庫県加古郡播磨町二子');
ok($zip->set_number('6750163')->is_valid_number, '兵庫県加古郡播磨町古宮');
ok($zip->set_number('6750164')->is_valid_number, '兵庫県加古郡播磨町東新島');
ok($zip->set_number('6750301')->is_valid_number, '兵庫県加古川市志方町大澤');
ok($zip->set_number('6750302')->is_valid_number, '兵庫県加古川市志方町野尻');
ok($zip->set_number('6750303')->is_valid_number, '兵庫県加古川市志方町細工所');
ok($zip->set_number('6750304')->is_valid_number, '兵庫県加古川市志方町高畑');
ok($zip->set_number('6750305')->is_valid_number, '兵庫県加古川市志方町大宗');
ok($zip->set_number('6750306')->is_valid_number, '兵庫県加古川市志方町東中');
ok($zip->set_number('6750311')->is_valid_number, '兵庫県加古川市志方町岡');
ok($zip->set_number('6750312')->is_valid_number, '兵庫県加古川市志方町広尾');
ok($zip->set_number('6750313')->is_valid_number, '兵庫県加古川市志方町投松');
ok($zip->set_number('6750314')->is_valid_number, '兵庫県加古川市志方町上冨木');
ok($zip->set_number('6750321')->is_valid_number, '兵庫県加古川市志方町志方町');
ok($zip->set_number('6750331')->is_valid_number, '兵庫県加古川市志方町西牧');
ok($zip->set_number('6750332')->is_valid_number, '兵庫県加古川市志方町横大路');
ok($zip->set_number('6750333')->is_valid_number, '兵庫県加古川市志方町西山');
ok($zip->set_number('6750334')->is_valid_number, '兵庫県加古川市志方町成井');
ok($zip->set_number('6750335')->is_valid_number, '兵庫県加古川市志方町原');
ok($zip->set_number('6750336')->is_valid_number, '兵庫県加古川市志方町山中');
ok($zip->set_number('6750341')->is_valid_number, '兵庫県加古川市志方町畑');
ok($zip->set_number('6750342')->is_valid_number, '兵庫県加古川市志方町雑郷');
ok($zip->set_number('6750343')->is_valid_number, '兵庫県加古川市志方町行常');
ok($zip->set_number('6750344')->is_valid_number, '兵庫県加古川市志方町東飯坂');
ok($zip->set_number('6750345')->is_valid_number, '兵庫県加古川市志方町西飯坂');
ok($zip->set_number('6750346')->is_valid_number, '兵庫県加古川市志方町西中');
ok($zip->set_number('6750347')->is_valid_number, '兵庫県加古川市志方町永室');
ok($zip->set_number('6751100')->is_valid_number, '兵庫県加古郡稲美町以下に掲載がない場合');
ok($zip->set_number('6751101')->is_valid_number, '兵庫県加古郡稲美町下草谷');
ok($zip->set_number('6751102')->is_valid_number, '兵庫県加古郡稲美町草谷');
ok($zip->set_number('6751103')->is_valid_number, '兵庫県加古郡稲美町野谷');
ok($zip->set_number('6751104')->is_valid_number, '兵庫県加古郡稲美町野寺');
ok($zip->set_number('6751105')->is_valid_number, '兵庫県加古郡稲美町加古');
ok($zip->set_number('6751111')->is_valid_number, '兵庫県加古郡稲美町印南');
ok($zip->set_number('6751112')->is_valid_number, '兵庫県加古郡稲美町六分一');
ok($zip->set_number('6751113')->is_valid_number, '兵庫県加古郡稲美町岡');
ok($zip->set_number('6751114')->is_valid_number, '兵庫県加古郡稲美町国安');
ok($zip->set_number('6751115')->is_valid_number, '兵庫県加古郡稲美町国岡');
ok($zip->set_number('6751116')->is_valid_number, '兵庫県加古郡稲美町蛸草');
ok($zip->set_number('6751121')->is_valid_number, '兵庫県加古郡稲美町北山');
ok($zip->set_number('6751122')->is_valid_number, '兵庫県加古郡稲美町中村');
ok($zip->set_number('6751123')->is_valid_number, '兵庫県加古郡稲美町国北');
ok($zip->set_number('6751124')->is_valid_number, '兵庫県加古郡稲美町森安');
ok($zip->set_number('6751125')->is_valid_number, '兵庫県加古郡稲美町和田');
ok($zip->set_number('6751126')->is_valid_number, '兵庫県加古郡稲美町幸竹');
ok($zip->set_number('6751127')->is_valid_number, '兵庫県加古郡稲美町中一色');
ok($zip->set_number('6751201')->is_valid_number, '兵庫県加古川市八幡町宗佐');
ok($zip->set_number('6751202')->is_valid_number, '兵庫県加古川市八幡町野村');
ok($zip->set_number('6751203')->is_valid_number, '兵庫県加古川市八幡町下村');
ok($zip->set_number('6751204')->is_valid_number, '兵庫県加古川市八幡町上西条');
ok($zip->set_number('6751205')->is_valid_number, '兵庫県加古川市八幡町中西条');
ok($zip->set_number('6751206')->is_valid_number, '兵庫県加古川市八幡町船町');
ok($zip->set_number('6751211')->is_valid_number, '兵庫県加古川市上荘町白沢');
ok($zip->set_number('6751212')->is_valid_number, '兵庫県加古川市上荘町井ノ口');
ok($zip->set_number('6751213')->is_valid_number, '兵庫県加古川市上荘町国包');
ok($zip->set_number('6751214')->is_valid_number, '兵庫県加古川市上荘町見土呂');
ok($zip->set_number('6751215')->is_valid_number, '兵庫県加古川市上荘町都台');
ok($zip->set_number('6751216')->is_valid_number, '兵庫県加古川市上荘町都染');
ok($zip->set_number('6751217')->is_valid_number, '兵庫県加古川市上荘町薬栗');
ok($zip->set_number('6751218')->is_valid_number, '兵庫県加古川市上荘町小野');
ok($zip->set_number('6751221')->is_valid_number, '兵庫県加古川市平荘町山角');
ok($zip->set_number('6751222')->is_valid_number, '兵庫県加古川市平荘町神木');
ok($zip->set_number('6751223')->is_valid_number, '兵庫県加古川市平荘町新中山');
ok($zip->set_number('6751224')->is_valid_number, '兵庫県加古川市平荘町上原');
ok($zip->set_number('6751225')->is_valid_number, '兵庫県加古川市平荘町中山');
ok($zip->set_number('6751226')->is_valid_number, '兵庫県加古川市平荘町磐');
ok($zip->set_number('6751231')->is_valid_number, '兵庫県加古川市平荘町養老');
ok($zip->set_number('6751232')->is_valid_number, '兵庫県加古川市平荘町里');
ok($zip->set_number('6751233')->is_valid_number, '兵庫県加古川市平荘町池尻');
ok($zip->set_number('6751234')->is_valid_number, '兵庫県加古川市平荘町西山');
ok($zip->set_number('6751235')->is_valid_number, '兵庫県加古川市平荘町小畑');
ok($zip->set_number('6751236')->is_valid_number, '兵庫県加古川市平荘町一本松');
ok($zip->set_number('6751300')->is_valid_number, '兵庫県小野市以下に掲載がない場合');
ok($zip->set_number('6751301')->is_valid_number, '兵庫県小野市小田町');
ok($zip->set_number('6751302')->is_valid_number, '兵庫県小野市曽根町');
ok($zip->set_number('6751303')->is_valid_number, '兵庫県小野市池田町');
ok($zip->set_number('6751304')->is_valid_number, '兵庫県小野市中谷町');
ok($zip->set_number('6751305')->is_valid_number, '兵庫県小野市脇本町');
ok($zip->set_number('6751306')->is_valid_number, '兵庫県小野市船木町');
ok($zip->set_number('6751307')->is_valid_number, '兵庫県小野市菅田町');
ok($zip->set_number('6751308')->is_valid_number, '兵庫県小野市中番町');
ok($zip->set_number('6751309')->is_valid_number, '兵庫県小野市福住町');
ok($zip->set_number('6751311')->is_valid_number, '兵庫県小野市万勝寺町');
ok($zip->set_number('6751312')->is_valid_number, '兵庫県小野市栄町');
ok($zip->set_number('6751313')->is_valid_number, '兵庫県小野市大開町');
ok($zip->set_number('6751314')->is_valid_number, '兵庫県小野市長尾町');
ok($zip->set_number('6751315')->is_valid_number, '兵庫県小野市日吉町');
ok($zip->set_number('6751316')->is_valid_number, '兵庫県小野市天神町');
ok($zip->set_number('6751317')->is_valid_number, '兵庫県小野市浄谷町');
ok($zip->set_number('6751318')->is_valid_number, '兵庫県小野市北丘町');
ok($zip->set_number('6751321')->is_valid_number, '兵庫県小野市山田町');
ok($zip->set_number('6751322')->is_valid_number, '兵庫県小野市匠台');
ok($zip->set_number('6751323')->is_valid_number, '兵庫県小野市榊町');
ok($zip->set_number('6751324')->is_valid_number, '兵庫県小野市育ケ丘町');
ok($zip->set_number('6751325')->is_valid_number, '兵庫県小野市樫山町');
ok($zip->set_number('6751326')->is_valid_number, '兵庫県小野市池尻町');
ok($zip->set_number('6751327')->is_valid_number, '兵庫県小野市市場町');
ok($zip->set_number('6751328')->is_valid_number, '兵庫県小野市二葉町');
ok($zip->set_number('6751331')->is_valid_number, '兵庫県小野市神明町');
ok($zip->set_number('6751332')->is_valid_number, '兵庫県小野市中町');
ok($zip->set_number('6751333')->is_valid_number, '兵庫県小野市垂井町');
ok($zip->set_number('6751334')->is_valid_number, '兵庫県小野市大島町');
ok($zip->set_number('6751335')->is_valid_number, '兵庫県小野市片山町');
ok($zip->set_number('6751336')->is_valid_number, '兵庫県小野市下大部町');
ok($zip->set_number('6751337')->is_valid_number, '兵庫県小野市久茂町');
ok($zip->set_number('6751338')->is_valid_number, '兵庫県小野市田園町');
ok($zip->set_number('6751341')->is_valid_number, '兵庫県小野市西脇町');
ok($zip->set_number('6751342')->is_valid_number, '兵庫県小野市阿形町');
ok($zip->set_number('6751343')->is_valid_number, '兵庫県小野市来住町');
ok($zip->set_number('6751344')->is_valid_number, '兵庫県小野市下来住町');
ok($zip->set_number('6751345')->is_valid_number, '兵庫県小野市黍田町');
ok($zip->set_number('6751346')->is_valid_number, '兵庫県小野市福甸町');
ok($zip->set_number('6751350')->is_valid_number, '兵庫県小野市南青野町');
ok($zip->set_number('6751351')->is_valid_number, '兵庫県小野市桜台');
ok($zip->set_number('6751352')->is_valid_number, '兵庫県小野市青野ケ原町');
ok($zip->set_number('6751352')->is_valid_number, '兵庫県小野市西山町');
ok($zip->set_number('6751352')->is_valid_number, '兵庫県小野市復井町');
ok($zip->set_number('6751353')->is_valid_number, '兵庫県小野市河合中町');
ok($zip->set_number('6751354')->is_valid_number, '兵庫県小野市河合西町');
ok($zip->set_number('6751355')->is_valid_number, '兵庫県小野市新部町');
ok($zip->set_number('6751356')->is_valid_number, '兵庫県小野市旭町');
ok($zip->set_number('6751357')->is_valid_number, '兵庫県小野市三和町');
ok($zip->set_number('6751358')->is_valid_number, '兵庫県小野市粟生町');
ok($zip->set_number('6751359')->is_valid_number, '兵庫県小野市昭和町');
ok($zip->set_number('6751360')->is_valid_number, '兵庫県小野市喜多町');
ok($zip->set_number('6751361')->is_valid_number, '兵庫県小野市住吉町');
ok($zip->set_number('6751362')->is_valid_number, '兵庫県小野市久保木町');
ok($zip->set_number('6751362')->is_valid_number, '兵庫県小野市高山町');
ok($zip->set_number('6751363')->is_valid_number, '兵庫県小野市古川町');
ok($zip->set_number('6751364')->is_valid_number, '兵庫県小野市鹿野町');
ok($zip->set_number('6751365')->is_valid_number, '兵庫県小野市広渡町');
ok($zip->set_number('6751366')->is_valid_number, '兵庫県小野市中島町');
ok($zip->set_number('6751367')->is_valid_number, '兵庫県小野市敷地町');
ok($zip->set_number('6751368')->is_valid_number, '兵庫県小野市住永町');
ok($zip->set_number('6751369')->is_valid_number, '兵庫県小野市高田町');
ok($zip->set_number('6751371')->is_valid_number, '兵庫県小野市黒川町');
ok($zip->set_number('6751372')->is_valid_number, '兵庫県小野市本町(その他)');
ok($zip->set_number('6751373')->is_valid_number, '兵庫県小野市東本町');
ok($zip->set_number('6751374')->is_valid_number, '兵庫県小野市本町(1丁目)');
ok($zip->set_number('6751375')->is_valid_number, '兵庫県小野市西本町');
ok($zip->set_number('6751376')->is_valid_number, '兵庫県小野市丸山町');
ok($zip->set_number('6751377')->is_valid_number, '兵庫県小野市葉多町');
ok($zip->set_number('6751378')->is_valid_number, '兵庫県小野市王子町');
ok($zip->set_number('6751378')->is_valid_number, '兵庫県小野市上新町');
ok($zip->set_number('6751379')->is_valid_number, '兵庫県小野市上本町');
ok($zip->set_number('6752101')->is_valid_number, '兵庫県加西市繁昌町');
ok($zip->set_number('6752102')->is_valid_number, '兵庫県加西市中野町');
ok($zip->set_number('6752103')->is_valid_number, '兵庫県加西市鶉野町');
ok($zip->set_number('6752104')->is_valid_number, '兵庫県加西市上宮木町');
ok($zip->set_number('6752105')->is_valid_number, '兵庫県加西市下宮木町');
ok($zip->set_number('6752111')->is_valid_number, '兵庫県加西市桑原田町');
ok($zip->set_number('6752112')->is_valid_number, '兵庫県加西市栄町');
ok($zip->set_number('6752113')->is_valid_number, '兵庫県加西市網引町');
ok($zip->set_number('6752114')->is_valid_number, '兵庫県加西市田原町');
ok($zip->set_number('6752201')->is_valid_number, '兵庫県加西市琵琶甲町');
ok($zip->set_number('6752202')->is_valid_number, '兵庫県加西市野条町');
ok($zip->set_number('6752203')->is_valid_number, '兵庫県加西市牛居町');
ok($zip->set_number('6752204')->is_valid_number, '兵庫県加西市新生町');
ok($zip->set_number('6752211')->is_valid_number, '兵庫県加西市野田町');
ok($zip->set_number('6752212')->is_valid_number, '兵庫県加西市東笠原町');
ok($zip->set_number('6752213')->is_valid_number, '兵庫県加西市西笠原町');
ok($zip->set_number('6752221')->is_valid_number, '兵庫県加西市倉谷町');
ok($zip->set_number('6752222')->is_valid_number, '兵庫県加西市坂本町');
ok($zip->set_number('6752223')->is_valid_number, '兵庫県加西市三口町');
ok($zip->set_number('6752231')->is_valid_number, '兵庫県加西市王子町');
ok($zip->set_number('6752232')->is_valid_number, '兵庫県加西市戸田井町');
ok($zip->set_number('6752233')->is_valid_number, '兵庫県加西市両月町');
ok($zip->set_number('6752234')->is_valid_number, '兵庫県加西市大村町');
ok($zip->set_number('6752241')->is_valid_number, '兵庫県加西市段下町');
ok($zip->set_number('6752242')->is_valid_number, '兵庫県加西市尾崎町');
ok($zip->set_number('6752243')->is_valid_number, '兵庫県加西市中西町');
ok($zip->set_number('6752301')->is_valid_number, '兵庫県加西市北条町小谷');
ok($zip->set_number('6752302')->is_valid_number, '兵庫県加西市北条町栗田');
ok($zip->set_number('6752303')->is_valid_number, '兵庫県加西市北条町古坂');
ok($zip->set_number('6752311')->is_valid_number, '兵庫県加西市北条町横尾');
ok($zip->set_number('6752312')->is_valid_number, '兵庫県加西市北条町北条');
ok($zip->set_number('6752313')->is_valid_number, '兵庫県加西市北条町黒駒');
ok($zip->set_number('6752321')->is_valid_number, '兵庫県加西市北条町東高室');
ok($zip->set_number('6752322')->is_valid_number, '兵庫県加西市北条町西高室');
ok($zip->set_number('6752323')->is_valid_number, '兵庫県加西市北条町西南');
ok($zip->set_number('6752324')->is_valid_number, '兵庫県加西市北条町東南');
ok($zip->set_number('6752331')->is_valid_number, '兵庫県加西市東横田町');
ok($zip->set_number('6752332')->is_valid_number, '兵庫県加西市鎮岩町');
ok($zip->set_number('6752333')->is_valid_number, '兵庫県加西市岸呂町');
ok($zip->set_number('6752334')->is_valid_number, '兵庫県加西市福住町');
ok($zip->set_number('6752335')->is_valid_number, '兵庫県加西市西横田町');
ok($zip->set_number('6752336')->is_valid_number, '兵庫県加西市坂元町');
ok($zip->set_number('6752337')->is_valid_number, '兵庫県加西市市村町');
ok($zip->set_number('6752341')->is_valid_number, '兵庫県加西市東長町');
ok($zip->set_number('6752342')->is_valid_number, '兵庫県加西市西長町');
ok($zip->set_number('6752343')->is_valid_number, '兵庫県加西市中山町');
ok($zip->set_number('6752344')->is_valid_number, '兵庫県加西市大柳町');
ok($zip->set_number('6752345')->is_valid_number, '兵庫県加西市西剣坂町');
ok($zip->set_number('6752346')->is_valid_number, '兵庫県加西市東剣坂町');
ok($zip->set_number('6752351')->is_valid_number, '兵庫県加西市福居町');
ok($zip->set_number('6752352')->is_valid_number, '兵庫県加西市谷口町');
ok($zip->set_number('6752353')->is_valid_number, '兵庫県加西市吉野町');
ok($zip->set_number('6752354')->is_valid_number, '兵庫県加西市山下町');
ok($zip->set_number('6752361')->is_valid_number, '兵庫県加西市谷町');
ok($zip->set_number('6752362')->is_valid_number, '兵庫県加西市西上野町');
ok($zip->set_number('6752363')->is_valid_number, '兵庫県加西市吸谷町');
ok($zip->set_number('6752364')->is_valid_number, '兵庫県加西市窪田町');
ok($zip->set_number('6752365')->is_valid_number, '兵庫県加西市畑町');
ok($zip->set_number('6752366')->is_valid_number, '兵庫県加西市西谷町');
ok($zip->set_number('6752401')->is_valid_number, '兵庫県加西市国正町');
ok($zip->set_number('6752402')->is_valid_number, '兵庫県加西市田谷町');
ok($zip->set_number('6752403')->is_valid_number, '兵庫県加西市小印南町');
ok($zip->set_number('6752404')->is_valid_number, '兵庫県加西市油谷町');
ok($zip->set_number('6752411')->is_valid_number, '兵庫県加西市大工町');
ok($zip->set_number('6752412')->is_valid_number, '兵庫県加西市鍛治屋町');
ok($zip->set_number('6752413')->is_valid_number, '兵庫県加西市青野町');
ok($zip->set_number('6752414')->is_valid_number, '兵庫県加西市馬渡谷町');
ok($zip->set_number('6752421')->is_valid_number, '兵庫県加西市河内町');
ok($zip->set_number('6752422')->is_valid_number, '兵庫県加西市山田町');
ok($zip->set_number('6752423')->is_valid_number, '兵庫県加西市和泉町');
ok($zip->set_number('6752424')->is_valid_number, '兵庫県加西市野上町');
ok($zip->set_number('6752425')->is_valid_number, '兵庫県加西市池上町');
ok($zip->set_number('6752426')->is_valid_number, '兵庫県加西市西野々町');
ok($zip->set_number('6752431')->is_valid_number, '兵庫県加西市島町');
ok($zip->set_number('6752432')->is_valid_number, '兵庫県加西市満久町');
ok($zip->set_number('6752433')->is_valid_number, '兵庫県加西市北町');
ok($zip->set_number('6752434')->is_valid_number, '兵庫県加西市上野町');
ok($zip->set_number('6752441')->is_valid_number, '兵庫県加西市越水町');
ok($zip->set_number('6752442')->is_valid_number, '兵庫県加西市中富町');
ok($zip->set_number('6752443')->is_valid_number, '兵庫県加西市笹倉町');
ok($zip->set_number('6752444')->is_valid_number, '兵庫県加西市鴨谷町');
ok($zip->set_number('6752445')->is_valid_number, '兵庫県加西市殿原町');
ok($zip->set_number('6752451')->is_valid_number, '兵庫県加西市上万願寺町');
ok($zip->set_number('6752452')->is_valid_number, '兵庫県加西市下万願寺町');
ok($zip->set_number('6752453')->is_valid_number, '兵庫県加西市上道山町');
ok($zip->set_number('6752454')->is_valid_number, '兵庫県加西市下道山町');
ok($zip->set_number('6752455')->is_valid_number, '兵庫県加西市大内町');
ok($zip->set_number('6752456')->is_valid_number, '兵庫県加西市若井町');
ok($zip->set_number('6752461')->is_valid_number, '兵庫県加西市佐谷町');
ok($zip->set_number('6752462')->is_valid_number, '兵庫県加西市別所町');
ok($zip->set_number('6752463')->is_valid_number, '兵庫県加西市広原町');
ok($zip->set_number('6752464')->is_valid_number, '兵庫県加西市下芥田町');
ok($zip->set_number('6752465')->is_valid_number, '兵庫県加西市上芥田町');
ok($zip->set_number('6760000')->is_valid_number, '兵庫県高砂市以下に掲載がない場合');
ok($zip->set_number('6760001')->is_valid_number, '兵庫県高砂市中島');
ok($zip->set_number('6760002')->is_valid_number, '兵庫県高砂市末広町');
ok($zip->set_number('6760003')->is_valid_number, '兵庫県高砂市今市');
ok($zip->set_number('6760004')->is_valid_number, '兵庫県高砂市荒井町千鳥');
ok($zip->set_number('6760005')->is_valid_number, '兵庫県高砂市荒井町御旅');
ok($zip->set_number('6760006')->is_valid_number, '兵庫県高砂市荒井町南栄町');
ok($zip->set_number('6760007')->is_valid_number, '兵庫県高砂市荒井町中町');
ok($zip->set_number('6760008')->is_valid_number, '兵庫県高砂市荒井町新浜');
ok($zip->set_number('6760011')->is_valid_number, '兵庫県高砂市荒井町小松原');
ok($zip->set_number('6760012')->is_valid_number, '兵庫県高砂市荒井町中新町');
ok($zip->set_number('6760013')->is_valid_number, '兵庫県高砂市荒井町蓮池');
ok($zip->set_number('6760014')->is_valid_number, '兵庫県高砂市荒井町日之出町');
ok($zip->set_number('6760015')->is_valid_number, '兵庫県高砂市荒井町紙町');
ok($zip->set_number('6760016')->is_valid_number, '兵庫県高砂市荒井町扇町');
ok($zip->set_number('6760017')->is_valid_number, '兵庫県高砂市荒井町東本町');
ok($zip->set_number('6760018')->is_valid_number, '兵庫県高砂市荒井町若宮町');
ok($zip->set_number('6760019')->is_valid_number, '兵庫県高砂市緑丘');
ok($zip->set_number('6760021')->is_valid_number, '兵庫県高砂市高砂町朝日町');
ok($zip->set_number('6760022')->is_valid_number, '兵庫県高砂市高砂町浜田町');
ok($zip->set_number('6760023')->is_valid_number, '兵庫県高砂市高砂町松波町');
ok($zip->set_number('6760024')->is_valid_number, '兵庫県高砂市高砂町木曽町');
ok($zip->set_number('6760025')->is_valid_number, '兵庫県高砂市西畑');
ok($zip->set_number('6760026')->is_valid_number, '兵庫県高砂市高砂町沖浜町');
ok($zip->set_number('6760027')->is_valid_number, '兵庫県高砂市高砂町宮前町');
ok($zip->set_number('6760028')->is_valid_number, '兵庫県高砂市高砂町相生町');
ok($zip->set_number('6760031')->is_valid_number, '兵庫県高砂市高砂町向島町');
ok($zip->set_number('6760032')->is_valid_number, '兵庫県高砂市高砂町東浜町');
ok($zip->set_number('6760033')->is_valid_number, '兵庫県高砂市高砂町材木町');
ok($zip->set_number('6760034')->is_valid_number, '兵庫県高砂市高砂町船頭町');
ok($zip->set_number('6760035')->is_valid_number, '兵庫県高砂市高砂町清水町');
ok($zip->set_number('6760036')->is_valid_number, '兵庫県高砂市高砂町高瀬町');
ok($zip->set_number('6760037')->is_valid_number, '兵庫県高砂市高砂町藍屋町');
ok($zip->set_number('6760038')->is_valid_number, '兵庫県高砂市高砂町栄町');
ok($zip->set_number('6760041')->is_valid_number, '兵庫県高砂市高砂町今津町');
ok($zip->set_number('6760042')->is_valid_number, '兵庫県高砂市高砂町南浜町');
ok($zip->set_number('6760043')->is_valid_number, '兵庫県高砂市高砂町東宮町');
ok($zip->set_number('6760044')->is_valid_number, '兵庫県高砂市高砂町南材木町');
ok($zip->set_number('6760045')->is_valid_number, '兵庫県高砂市高砂町戎町');
ok($zip->set_number('6760046')->is_valid_number, '兵庫県高砂市高砂町西宮町');
ok($zip->set_number('6760047')->is_valid_number, '兵庫県高砂市高砂町南本町');
ok($zip->set_number('6760048')->is_valid_number, '兵庫県高砂市高砂町猟師町');
ok($zip->set_number('6760049')->is_valid_number, '兵庫県高砂市高砂町田町');
ok($zip->set_number('6760051')->is_valid_number, '兵庫県高砂市高砂町横町');
ok($zip->set_number('6760052')->is_valid_number, '兵庫県高砂市高砂町南渡海町');
ok($zip->set_number('6760053')->is_valid_number, '兵庫県高砂市高砂町魚町');
ok($zip->set_number('6760054')->is_valid_number, '兵庫県高砂市高砂町狩網町');
ok($zip->set_number('6760055')->is_valid_number, '兵庫県高砂市高砂町釣船町');
ok($zip->set_number('6760056')->is_valid_number, '兵庫県高砂市高砂町大工町');
ok($zip->set_number('6760061')->is_valid_number, '兵庫県高砂市高砂町農人町');
ok($zip->set_number('6760062')->is_valid_number, '兵庫県高砂市高砂町北渡海町');
ok($zip->set_number('6760063')->is_valid_number, '兵庫県高砂市高砂町次郎助町');
ok($zip->set_number('6760064')->is_valid_number, '兵庫県高砂市高砂町北本町');
ok($zip->set_number('6760065')->is_valid_number, '兵庫県高砂市高砂町細工町');
ok($zip->set_number('6760066')->is_valid_number, '兵庫県高砂市高砂町鍵町');
ok($zip->set_number('6760067')->is_valid_number, '兵庫県高砂市高砂町東農人町');
ok($zip->set_number('6760068')->is_valid_number, '兵庫県高砂市高砂町鍛冶屋町');
ok($zip->set_number('6760071')->is_valid_number, '兵庫県高砂市伊保東');
ok($zip->set_number('6760072')->is_valid_number, '兵庫県高砂市伊保港町');
ok($zip->set_number('6760073')->is_valid_number, '兵庫県高砂市高須');
ok($zip->set_number('6760074')->is_valid_number, '兵庫県高砂市梅井');
ok($zip->set_number('6760075')->is_valid_number, '兵庫県高砂市伊保崎南');
ok($zip->set_number('6760076')->is_valid_number, '兵庫県高砂市伊保崎');
ok($zip->set_number('6760077')->is_valid_number, '兵庫県高砂市松陽');
ok($zip->set_number('6760078')->is_valid_number, '兵庫県高砂市伊保');
ok($zip->set_number('6760081')->is_valid_number, '兵庫県高砂市伊保町中筋');
ok($zip->set_number('6760082')->is_valid_number, '兵庫県高砂市曽根町');
ok($zip->set_number('6760801')->is_valid_number, '兵庫県高砂市米田町米田新');
ok($zip->set_number('6760802')->is_valid_number, '兵庫県高砂市米田町古新');
ok($zip->set_number('6760803')->is_valid_number, '兵庫県高砂市百合丘');
ok($zip->set_number('6760804')->is_valid_number, '兵庫県高砂市美保里');
ok($zip->set_number('6760805')->is_valid_number, '兵庫県高砂市米田町米田');
ok($zip->set_number('6760806')->is_valid_number, '兵庫県高砂市米田町塩市');
ok($zip->set_number('6760807')->is_valid_number, '兵庫県高砂市米田町島');
ok($zip->set_number('6760808')->is_valid_number, '兵庫県高砂市神爪');
ok($zip->set_number('6760809')->is_valid_number, '兵庫県高砂市米田団地');
ok($zip->set_number('6760811')->is_valid_number, '兵庫県高砂市竜山');
ok($zip->set_number('6760812')->is_valid_number, '兵庫県高砂市中筋');
ok($zip->set_number('6760813')->is_valid_number, '兵庫県高砂市時光寺町');
ok($zip->set_number('6760814')->is_valid_number, '兵庫県高砂市春日野町');
ok($zip->set_number('6760815')->is_valid_number, '兵庫県高砂市阿弥陀(丁目)');
ok($zip->set_number('6760816')->is_valid_number, '兵庫県高砂市金ケ田町');
ok($zip->set_number('6760821')->is_valid_number, '兵庫県高砂市阿弥陀町長尾');
ok($zip->set_number('6760822')->is_valid_number, '兵庫県高砂市阿弥陀町魚橋');
ok($zip->set_number('6760823')->is_valid_number, '兵庫県高砂市阿弥陀町生石');
ok($zip->set_number('6760824')->is_valid_number, '兵庫県高砂市阿弥陀町南池');
ok($zip->set_number('6760825')->is_valid_number, '兵庫県高砂市阿弥陀町北池');
ok($zip->set_number('6760826')->is_valid_number, '兵庫県高砂市阿弥陀町北山');
ok($zip->set_number('6760827')->is_valid_number, '兵庫県高砂市阿弥陀町阿弥陀(番地)');
ok($zip->set_number('6760828')->is_valid_number, '兵庫県高砂市阿弥陀町地徳');
ok($zip->set_number('6770000')->is_valid_number, '兵庫県西脇市以下に掲載がない場合');
ok($zip->set_number('6770001')->is_valid_number, '兵庫県西脇市大木町');
ok($zip->set_number('6770002')->is_valid_number, '兵庫県西脇市前島町');
ok($zip->set_number('6770003')->is_valid_number, '兵庫県西脇市西田町');
ok($zip->set_number('6770004')->is_valid_number, '兵庫県西脇市市原町');
ok($zip->set_number('6770005')->is_valid_number, '兵庫県西脇市野中町');
ok($zip->set_number('6770006')->is_valid_number, '兵庫県西脇市羽安町');
ok($zip->set_number('6770011')->is_valid_number, '兵庫県西脇市富吉上町');
ok($zip->set_number('6770012')->is_valid_number, '兵庫県西脇市富吉南町');
ok($zip->set_number('6770013')->is_valid_number, '兵庫県西脇市日野町');
ok($zip->set_number('6770014')->is_valid_number, '兵庫県西脇市郷瀬町');
ok($zip->set_number('6770015')->is_valid_number, '兵庫県西脇市西脇');
ok($zip->set_number('6770016')->is_valid_number, '兵庫県西脇市高田井町');
ok($zip->set_number('6770017')->is_valid_number, '兵庫県西脇市小坂町');
ok($zip->set_number('6770018')->is_valid_number, '兵庫県西脇市富田町');
ok($zip->set_number('6770021')->is_valid_number, '兵庫県西脇市蒲江');
ok($zip->set_number('6770022')->is_valid_number, '兵庫県西脇市寺内');
ok($zip->set_number('6770023')->is_valid_number, '兵庫県西脇市西嶋');
ok($zip->set_number('6770024')->is_valid_number, '兵庫県西脇市嶋');
ok($zip->set_number('6770025')->is_valid_number, '兵庫県西脇市大野');
ok($zip->set_number('6770026')->is_valid_number, '兵庫県西脇市坂本');
ok($zip->set_number('6770031')->is_valid_number, '兵庫県西脇市住吉町');
ok($zip->set_number('6770032')->is_valid_number, '兵庫県西脇市中畑町');
ok($zip->set_number('6770033')->is_valid_number, '兵庫県西脇市鹿野町');
ok($zip->set_number('6770034')->is_valid_number, '兵庫県西脇市塚口町');
ok($zip->set_number('6770035')->is_valid_number, '兵庫県西脇市上戸田');
ok($zip->set_number('6770036')->is_valid_number, '兵庫県西脇市津万');
ok($zip->set_number('6770037')->is_valid_number, '兵庫県西脇市比延町');
ok($zip->set_number('6770038')->is_valid_number, '兵庫県西脇市大垣内');
ok($zip->set_number('6770039')->is_valid_number, '兵庫県西脇市上比延町');
ok($zip->set_number('6770041')->is_valid_number, '兵庫県西脇市高嶋町');
ok($zip->set_number('6770042')->is_valid_number, '兵庫県西脇市堀町');
ok($zip->set_number('6770043')->is_valid_number, '兵庫県西脇市下戸田');
ok($zip->set_number('6770044')->is_valid_number, '兵庫県西脇市上野');
ok($zip->set_number('6770051')->is_valid_number, '兵庫県西脇市谷町');
ok($zip->set_number('6770052')->is_valid_number, '兵庫県西脇市和田町');
ok($zip->set_number('6770053')->is_valid_number, '兵庫県西脇市和布町');
ok($zip->set_number('6770054')->is_valid_number, '兵庫県西脇市野村町');
ok($zip->set_number('6770055')->is_valid_number, '兵庫県西脇市高松町');
ok($zip->set_number('6770056')->is_valid_number, '兵庫県西脇市板波町');
ok($zip->set_number('6770057')->is_valid_number, '兵庫県西脇市野村町茜が丘');
ok($zip->set_number('6770061')->is_valid_number, '兵庫県西脇市合山町');
ok($zip->set_number('6770062')->is_valid_number, '兵庫県西脇市出会町');
ok($zip->set_number('6770063')->is_valid_number, '兵庫県西脇市平野町');
ok($zip->set_number('6770064')->is_valid_number, '兵庫県西脇市八坂町');
ok($zip->set_number('6770065')->is_valid_number, '兵庫県西脇市岡崎町');
ok($zip->set_number('6770066')->is_valid_number, '兵庫県西脇市水尾町');
ok($zip->set_number('6770067')->is_valid_number, '兵庫県西脇市明楽寺町');
ok($zip->set_number('6770068')->is_valid_number, '兵庫県西脇市落方町');
ok($zip->set_number('6770069')->is_valid_number, '兵庫県西脇市上王子町');
ok($zip->set_number('6770101')->is_valid_number, '兵庫県多可郡多可町八千代区大屋');
ok($zip->set_number('6770102')->is_valid_number, '兵庫県多可郡多可町八千代区坂本');
ok($zip->set_number('6770103')->is_valid_number, '兵庫県多可郡多可町八千代区中村');
ok($zip->set_number('6770104')->is_valid_number, '兵庫県多可郡多可町八千代区横屋');
ok($zip->set_number('6770105')->is_valid_number, '兵庫県多可郡多可町八千代区下村');
ok($zip->set_number('6770111')->is_valid_number, '兵庫県多可郡多可町八千代区門田');
ok($zip->set_number('6770112')->is_valid_number, '兵庫県多可郡多可町八千代区赤坂');
ok($zip->set_number('6770113')->is_valid_number, '兵庫県多可郡多可町八千代区俵田');
ok($zip->set_number('6770114')->is_valid_number, '兵庫県多可郡多可町八千代区仕出原');
ok($zip->set_number('6770121')->is_valid_number, '兵庫県多可郡多可町八千代区中野間');
ok($zip->set_number('6770122')->is_valid_number, '兵庫県多可郡多可町八千代区下野間');
ok($zip->set_number('6770131')->is_valid_number, '兵庫県多可郡多可町八千代区下三原');
ok($zip->set_number('6770132')->is_valid_number, '兵庫県多可郡多可町八千代区大和');
ok($zip->set_number('6780000')->is_valid_number, '兵庫県相生市以下に掲載がない場合');
ok($zip->set_number('6780001')->is_valid_number, '兵庫県相生市山手');
ok($zip->set_number('6780002')->is_valid_number, '兵庫県相生市汐見台');
ok($zip->set_number('6780003')->is_valid_number, '兵庫県相生市陸');
ok($zip->set_number('6780004')->is_valid_number, '兵庫県相生市池之内');
ok($zip->set_number('6780005')->is_valid_number, '兵庫県相生市大石町');
ok($zip->set_number('6780006')->is_valid_number, '兵庫県相生市本郷町');
ok($zip->set_number('6780007')->is_valid_number, '兵庫県相生市陸本町');
ok($zip->set_number('6780008')->is_valid_number, '兵庫県相生市栄町');
ok($zip->set_number('6780011')->is_valid_number, '兵庫県相生市那波野');
ok($zip->set_number('6780012')->is_valid_number, '兵庫県相生市古池');
ok($zip->set_number('6780021')->is_valid_number, '兵庫県相生市赤坂');
ok($zip->set_number('6780022')->is_valid_number, '兵庫県相生市垣内町');
ok($zip->set_number('6780023')->is_valid_number, '兵庫県相生市向陽台');
ok($zip->set_number('6780024')->is_valid_number, '兵庫県相生市双葉');
ok($zip->set_number('6780025')->is_valid_number, '兵庫県相生市古池本町');
ok($zip->set_number('6780031')->is_valid_number, '兵庫県相生市旭');
ok($zip->set_number('6780041')->is_valid_number, '兵庫県相生市相生(その他)');
ok($zip->set_number('6780042')->is_valid_number, '兵庫県相生市川原町');
ok($zip->set_number('6780043')->is_valid_number, '兵庫県相生市大谷町');
ok($zip->set_number('6780044')->is_valid_number, '兵庫県相生市野瀬');
ok($zip->set_number('6780051')->is_valid_number, '兵庫県相生市那波大浜町');
ok($zip->set_number('6780052')->is_valid_number, '兵庫県相生市大島町');
ok($zip->set_number('6780053')->is_valid_number, '兵庫県相生市那波南本町');
ok($zip->set_number('6780054')->is_valid_number, '兵庫県相生市那波西本町');
ok($zip->set_number('6780055')->is_valid_number, '兵庫県相生市那波本町');
ok($zip->set_number('6780056')->is_valid_number, '兵庫県相生市那波東本町');
ok($zip->set_number('6780061')->is_valid_number, '兵庫県相生市桜ケ丘町');
ok($zip->set_number('6780062')->is_valid_number, '兵庫県相生市千尋町');
ok($zip->set_number('6780063')->is_valid_number, '兵庫県相生市佐方');
ok($zip->set_number('6780064')->is_valid_number, '兵庫県相生市青葉台');
ok($zip->set_number('6780065')->is_valid_number, '兵庫県相生市西谷町');
ok($zip->set_number('6780066')->is_valid_number, '兵庫県相生市山崎町');
ok($zip->set_number('6780067')->is_valid_number, '兵庫県相生市那波');
ok($zip->set_number('6780071')->is_valid_number, '兵庫県相生市緑ケ丘');
ok($zip->set_number('6780072')->is_valid_number, '兵庫県相生市竜泉町');
ok($zip->set_number('6780073')->is_valid_number, '兵庫県相生市菅原町');
ok($zip->set_number('6780074')->is_valid_number, '兵庫県相生市ひかりが丘');
ok($zip->set_number('6780081')->is_valid_number, '兵庫県相生市若狭野町雨内');
ok($zip->set_number('6780081')->is_valid_number, '兵庫県相生市若狭野町入野');
ok($zip->set_number('6780081')->is_valid_number, '兵庫県相生市若狭野町上松');
ok($zip->set_number('6780081')->is_valid_number, '兵庫県相生市若狭野町東後明');
ok($zip->set_number('6780081')->is_valid_number, '兵庫県相生市若狭野町西後明');
ok($zip->set_number('6780081')->is_valid_number, '兵庫県相生市若狭野町若狭野');
ok($zip->set_number('6780082')->is_valid_number, '兵庫県相生市若狭野町下土井');
ok($zip->set_number('6780082')->is_valid_number, '兵庫県相生市若狭野町寺田');
ok($zip->set_number('6780082')->is_valid_number, '兵庫県相生市若狭野町出');
ok($zip->set_number('6780082')->is_valid_number, '兵庫県相生市若狭野町野々');
ok($zip->set_number('6780082')->is_valid_number, '兵庫県相生市若狭野町八洞');
ok($zip->set_number('6780082')->is_valid_number, '兵庫県相生市若狭野町福井');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町瓜生');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町金坂');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町釜出');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町上');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町榊');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町菅谷');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町中野');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町能下');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町二木');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町真広');
ok($zip->set_number('6780091')->is_valid_number, '兵庫県相生市矢野町森');
ok($zip->set_number('6780092')->is_valid_number, '兵庫県相生市矢野町小河');
ok($zip->set_number('6780092')->is_valid_number, '兵庫県相生市矢野町上土井');
ok($zip->set_number('6780092')->is_valid_number, '兵庫県相生市矢野町下田');
ok($zip->set_number('6780141')->is_valid_number, '兵庫県相生市相生(5133番地2~5187番地、5316番地1~5316番地167)');
ok($zip->set_number('6780161')->is_valid_number, '兵庫県赤穂市中山');
ok($zip->set_number('6780162')->is_valid_number, '兵庫県赤穂市周世');
ok($zip->set_number('6780163')->is_valid_number, '兵庫県赤穂市高雄');
ok($zip->set_number('6780164')->is_valid_number, '兵庫県赤穂市目坂');
ok($zip->set_number('6780165')->is_valid_number, '兵庫県赤穂市木津');
ok($zip->set_number('6780166')->is_valid_number, '兵庫県赤穂市真殿');
ok($zip->set_number('6780171')->is_valid_number, '兵庫県赤穂市高野');
ok($zip->set_number('6780172')->is_valid_number, '兵庫県赤穂市坂越');
ok($zip->set_number('6780173')->is_valid_number, '兵庫県赤穂市浜市');
ok($zip->set_number('6780174')->is_valid_number, '兵庫県赤穂市砂子');
ok($zip->set_number('6780175')->is_valid_number, '兵庫県赤穂市北野中');
ok($zip->set_number('6780176')->is_valid_number, '兵庫県赤穂市南野中');
ok($zip->set_number('6780200')->is_valid_number, '兵庫県赤穂市以下に掲載がない場合');
ok($zip->set_number('6780201')->is_valid_number, '兵庫県赤穂市塩屋');
ok($zip->set_number('6780202')->is_valid_number, '兵庫県赤穂市山手町');
ok($zip->set_number('6780203')->is_valid_number, '兵庫県赤穂市元町');
ok($zip->set_number('6780204')->is_valid_number, '兵庫県赤穂市寿町');
ok($zip->set_number('6780205')->is_valid_number, '兵庫県赤穂市大町');
ok($zip->set_number('6780206')->is_valid_number, '兵庫県赤穂市宮前町');
ok($zip->set_number('6780207')->is_valid_number, '兵庫県赤穂市西浜北町');
ok($zip->set_number('6780208')->is_valid_number, '兵庫県赤穂市西浜町');
ok($zip->set_number('6780211')->is_valid_number, '兵庫県赤穂市南宮町');
ok($zip->set_number('6780212')->is_valid_number, '兵庫県赤穂市清水町');
ok($zip->set_number('6780213')->is_valid_number, '兵庫県赤穂市元塩町');
ok($zip->set_number('6780214')->is_valid_number, '兵庫県赤穂市朝日町');
ok($zip->set_number('6780215')->is_valid_number, '兵庫県赤穂市御崎');
ok($zip->set_number('6780216')->is_valid_number, '兵庫県赤穂市正保橋町');
ok($zip->set_number('6780217')->is_valid_number, '兵庫県赤穂市本水尾町');
ok($zip->set_number('6780221')->is_valid_number, '兵庫県赤穂市尾崎');
ok($zip->set_number('6780222')->is_valid_number, '兵庫県赤穂市東浜町');
ok($zip->set_number('6780223')->is_valid_number, '兵庫県赤穂市元禄橋町');
ok($zip->set_number('6780224')->is_valid_number, '兵庫県赤穂市元沖町');
ok($zip->set_number('6780225')->is_valid_number, '兵庫県赤穂市海浜町');
ok($zip->set_number('6780226')->is_valid_number, '兵庫県赤穂市さつき町');
ok($zip->set_number('6780227')->is_valid_number, '兵庫県赤穂市中浜町');
ok($zip->set_number('6780228')->is_valid_number, '兵庫県赤穂市松原町');
ok($zip->set_number('6780229')->is_valid_number, '兵庫県赤穂市大橋町');
ok($zip->set_number('6780231')->is_valid_number, '兵庫県赤穂市細野町');
ok($zip->set_number('6780232')->is_valid_number, '兵庫県赤穂市中広');
ok($zip->set_number('6780233')->is_valid_number, '兵庫県赤穂市加里屋中洲');
ok($zip->set_number('6780234')->is_valid_number, '兵庫県赤穂市加里屋南');
ok($zip->set_number('6780235')->is_valid_number, '兵庫県赤穂市上仮屋');
ok($zip->set_number('6780236')->is_valid_number, '兵庫県赤穂市上仮屋南');
ok($zip->set_number('6780237')->is_valid_number, '兵庫県赤穂市上仮屋北');
ok($zip->set_number('6780238')->is_valid_number, '兵庫県赤穂市農神町');
ok($zip->set_number('6780239')->is_valid_number, '兵庫県赤穂市加里屋');
ok($zip->set_number('6780241')->is_valid_number, '兵庫県赤穂市惣門町');
ok($zip->set_number('6780242')->is_valid_number, '兵庫県赤穂市長池町');
ok($zip->set_number('6780243')->is_valid_number, '兵庫県赤穂市若草町');
ok($zip->set_number('6780244')->is_valid_number, '兵庫県赤穂市城西町');
ok($zip->set_number('6780245')->is_valid_number, '兵庫県赤穂市三樋町');
ok($zip->set_number('6780246')->is_valid_number, '兵庫県赤穂市六百目町');
ok($zip->set_number('6780247')->is_valid_number, '兵庫県赤穂市平成町');
ok($zip->set_number('6780248')->is_valid_number, '兵庫県赤穂市板屋町');
ok($zip->set_number('6780249')->is_valid_number, '兵庫県赤穂市片浜町');
ok($zip->set_number('6780250')->is_valid_number, '兵庫県赤穂市磯浜町');
ok($zip->set_number('6780251')->is_valid_number, '兵庫県赤穂市西有年(湯の内)');
ok($zip->set_number('6780252')->is_valid_number, '兵庫県赤穂市大津');
ok($zip->set_number('6780253')->is_valid_number, '兵庫県赤穂市木生谷');
ok($zip->set_number('6780254')->is_valid_number, '兵庫県赤穂市折方');
ok($zip->set_number('6780255')->is_valid_number, '兵庫県赤穂市新田');
ok($zip->set_number('6780256')->is_valid_number, '兵庫県赤穂市鷆和');
ok($zip->set_number('6780257')->is_valid_number, '兵庫県赤穂市福浦');
ok($zip->set_number('6780258')->is_valid_number, '兵庫県赤穂市古浜町');
ok($zip->set_number('6780259')->is_valid_number, '兵庫県赤穂市黒崎町');
ok($zip->set_number('6781181')->is_valid_number, '兵庫県赤穂市有年楢原');
ok($zip->set_number('6781182')->is_valid_number, '兵庫県赤穂市有年原');
ok($zip->set_number('6781183')->is_valid_number, '兵庫県赤穂市有年牟礼');
ok($zip->set_number('6781184')->is_valid_number, '兵庫県赤穂市有年横尾');
ok($zip->set_number('6781185')->is_valid_number, '兵庫県赤穂市東有年');
ok($zip->set_number('6781186')->is_valid_number, '兵庫県赤穂市西有年(その他)');
ok($zip->set_number('6781200')->is_valid_number, '兵庫県赤穂郡上郡町以下に掲載がない場合');
ok($zip->set_number('6781201')->is_valid_number, '兵庫県赤穂郡上郡町金出地');
ok($zip->set_number('6781202')->is_valid_number, '兵庫県赤穂郡上郡町野桑');
ok($zip->set_number('6781203')->is_valid_number, '兵庫県赤穂郡上郡町尾長谷');
ok($zip->set_number('6781204')->is_valid_number, '兵庫県赤穂郡上郡町大冨');
ok($zip->set_number('6781205')->is_valid_number, '兵庫県赤穂郡上郡町光都');
ok($zip->set_number('6781211')->is_valid_number, '兵庫県赤穂郡上郡町小野豆');
ok($zip->set_number('6781212')->is_valid_number, '兵庫県赤穂郡上郡町佐用谷');
ok($zip->set_number('6781213')->is_valid_number, '兵庫県赤穂郡上郡町宇野山');
ok($zip->set_number('6781214')->is_valid_number, '兵庫県赤穂郡上郡町休治');
ok($zip->set_number('6781215')->is_valid_number, '兵庫県赤穂郡上郡町正福寺');
ok($zip->set_number('6781216')->is_valid_number, '兵庫県赤穂郡上郡町中野');
ok($zip->set_number('6781217')->is_valid_number, '兵庫県赤穂郡上郡町宿');
ok($zip->set_number('6781218')->is_valid_number, '兵庫県赤穂郡上郡町宇治山');
ok($zip->set_number('6781219')->is_valid_number, '兵庫県赤穂郡上郡町奥');
ok($zip->set_number('6781221')->is_valid_number, '兵庫県赤穂郡上郡町神明寺');
ok($zip->set_number('6781222')->is_valid_number, '兵庫県赤穂郡上郡町西野山');
ok($zip->set_number('6781223')->is_valid_number, '兵庫県赤穂郡上郡町釜島');
ok($zip->set_number('6781224')->is_valid_number, '兵庫県赤穂郡上郡町與井新');
ok($zip->set_number('6781225')->is_valid_number, '兵庫県赤穂郡上郡町與井');
ok($zip->set_number('6781226')->is_valid_number, '兵庫県赤穂郡上郡町高田台');
ok($zip->set_number('6781231')->is_valid_number, '兵庫県赤穂郡上郡町上郡');
ok($zip->set_number('6781232')->is_valid_number, '兵庫県赤穂郡上郡町竹万');
ok($zip->set_number('6781233')->is_valid_number, '兵庫県赤穂郡上郡町大持');
ok($zip->set_number('6781234')->is_valid_number, '兵庫県赤穂郡上郡町駅前');
ok($zip->set_number('6781241')->is_valid_number, '兵庫県赤穂郡上郡町山野里');
ok($zip->set_number('6781242')->is_valid_number, '兵庫県赤穂郡上郡町栗原');
ok($zip->set_number('6781243')->is_valid_number, '兵庫県赤穂郡上郡町落地');
ok($zip->set_number('6781244')->is_valid_number, '兵庫県赤穂郡上郡町梨ケ原');
ok($zip->set_number('6781251')->is_valid_number, '兵庫県赤穂郡上郡町井上');
ok($zip->set_number('6781252')->is_valid_number, '兵庫県赤穂郡上郡町船坂');
ok($zip->set_number('6781253')->is_valid_number, '兵庫県赤穂郡上郡町別名');
ok($zip->set_number('6781254')->is_valid_number, '兵庫県赤穂郡上郡町高山');
ok($zip->set_number('6781255')->is_valid_number, '兵庫県赤穂郡上郡町行頭');
ok($zip->set_number('6781256')->is_valid_number, '兵庫県赤穂郡上郡町八保');
ok($zip->set_number('6781261')->is_valid_number, '兵庫県赤穂郡上郡町旭日');
ok($zip->set_number('6781262')->is_valid_number, '兵庫県赤穂郡上郡町岩木');
ok($zip->set_number('6781271')->is_valid_number, '兵庫県赤穂郡上郡町楠');
ok($zip->set_number('6781272')->is_valid_number, '兵庫県赤穂郡上郡町細野');
ok($zip->set_number('6781273')->is_valid_number, '兵庫県赤穂郡上郡町赤松');
ok($zip->set_number('6781274')->is_valid_number, '兵庫県赤穂郡上郡町柏野');
ok($zip->set_number('6781275')->is_valid_number, '兵庫県赤穂郡上郡町大枝');
ok($zip->set_number('6781276')->is_valid_number, '兵庫県赤穂郡上郡町大枝新');
ok($zip->set_number('6781277')->is_valid_number, '兵庫県赤穂郡上郡町苔縄');
ok($zip->set_number('6781278')->is_valid_number, '兵庫県赤穂郡上郡町河野原');
ok($zip->set_number('6790101')->is_valid_number, '兵庫県加西市都染町');
ok($zip->set_number('6790102')->is_valid_number, '兵庫県加西市青野原町');
ok($zip->set_number('6790103')->is_valid_number, '兵庫県加西市別府町');
ok($zip->set_number('6790104')->is_valid_number, '兵庫県加西市常吉町');
ok($zip->set_number('6790105')->is_valid_number, '兵庫県加西市朝妻町');
ok($zip->set_number('6790106')->is_valid_number, '兵庫県加西市豊倉町');
ok($zip->set_number('6790107')->is_valid_number, '兵庫県加西市玉野町');
ok($zip->set_number('6790108')->is_valid_number, '兵庫県加西市山枝町');
ok($zip->set_number('6790109')->is_valid_number, '兵庫県加西市玉丘町');
ok($zip->set_number('6790201')->is_valid_number, '兵庫県加東市曽我');
ok($zip->set_number('6790202')->is_valid_number, '兵庫県加東市多井田');
ok($zip->set_number('6790203')->is_valid_number, '兵庫県加東市稲尾');
ok($zip->set_number('6790204')->is_valid_number, '兵庫県加東市新町');
ok($zip->set_number('6790205')->is_valid_number, '兵庫県加東市北野');
ok($zip->set_number('6790206')->is_valid_number, '兵庫県加東市穂積');
ok($zip->set_number('6790207')->is_valid_number, '兵庫県加東市滝野団地');
ok($zip->set_number('6790211')->is_valid_number, '兵庫県加東市上滝野');
ok($zip->set_number('6790212')->is_valid_number, '兵庫県加東市下滝野');
ok($zip->set_number('6790213')->is_valid_number, '兵庫県加東市光明寺');
ok($zip->set_number('6790221')->is_valid_number, '兵庫県加東市河高');
ok($zip->set_number('6790222')->is_valid_number, '兵庫県加東市高岡');
ok($zip->set_number('6790223')->is_valid_number, '兵庫県加東市桜台');
ok($zip->set_number('6790301')->is_valid_number, '兵庫県西脇市黒田庄町小苗');
ok($zip->set_number('6790302')->is_valid_number, '兵庫県西脇市黒田庄町黒田');
ok($zip->set_number('6790303')->is_valid_number, '兵庫県西脇市黒田庄町前坂');
ok($zip->set_number('6790304')->is_valid_number, '兵庫県西脇市黒田庄町船町');
ok($zip->set_number('6790311')->is_valid_number, '兵庫県西脇市黒田庄町喜多');
ok($zip->set_number('6790312')->is_valid_number, '兵庫県西脇市黒田庄町門柳');
ok($zip->set_number('6790313')->is_valid_number, '兵庫県西脇市黒田庄町岡');
ok($zip->set_number('6790314')->is_valid_number, '兵庫県西脇市黒田庄町福地');
ok($zip->set_number('6790315')->is_valid_number, '兵庫県西脇市黒田庄町津万井');
ok($zip->set_number('6790316')->is_valid_number, '兵庫県西脇市黒田庄町大門');
ok($zip->set_number('6790321')->is_valid_number, '兵庫県西脇市黒田庄町田高');
ok($zip->set_number('6790322')->is_valid_number, '兵庫県西脇市黒田庄町石原');
ok($zip->set_number('6790323')->is_valid_number, '兵庫県西脇市黒田庄町西澤');
ok($zip->set_number('6790324')->is_valid_number, '兵庫県西脇市黒田庄町大伏');
ok($zip->set_number('6791100')->is_valid_number, '兵庫県多可郡多可町以下に掲載がない場合');
ok($zip->set_number('6791101')->is_valid_number, '兵庫県多可郡多可町中区門前');
ok($zip->set_number('6791102')->is_valid_number, '兵庫県多可郡多可町中区安楽田');
ok($zip->set_number('6791103')->is_valid_number, '兵庫県多可郡多可町中区牧野');
ok($zip->set_number('6791104')->is_valid_number, '兵庫県多可郡多可町中区田野口');
ok($zip->set_number('6791105')->is_valid_number, '兵庫県多可郡多可町中区東山');
ok($zip->set_number('6791106')->is_valid_number, '兵庫県多可郡多可町中区高岸');
ok($zip->set_number('6791107')->is_valid_number, '兵庫県多可郡多可町中区奥中');
ok($zip->set_number('6791107')->is_valid_number, '兵庫県多可郡多可町中区徳畑');
ok($zip->set_number('6791111')->is_valid_number, '兵庫県多可郡多可町中区鍛冶屋');
ok($zip->set_number('6791112')->is_valid_number, '兵庫県多可郡多可町中区間子');
ok($zip->set_number('6791113')->is_valid_number, '兵庫県多可郡多可町中区中村町');
ok($zip->set_number('6791114')->is_valid_number, '兵庫県多可郡多可町中区岸上');
ok($zip->set_number('6791115')->is_valid_number, '兵庫県多可郡多可町中区天田');
ok($zip->set_number('6791121')->is_valid_number, '兵庫県多可郡多可町中区東安田');
ok($zip->set_number('6791122')->is_valid_number, '兵庫県多可郡多可町中区中安田');
ok($zip->set_number('6791123')->is_valid_number, '兵庫県多可郡多可町中区西安田');
ok($zip->set_number('6791124')->is_valid_number, '兵庫県多可郡多可町中区森本');
ok($zip->set_number('6791131')->is_valid_number, '兵庫県多可郡多可町中区曽我井');
ok($zip->set_number('6791132')->is_valid_number, '兵庫県多可郡多可町中区坂本');
ok($zip->set_number('6791133')->is_valid_number, '兵庫県多可郡多可町中区糀屋');
ok($zip->set_number('6791134')->is_valid_number, '兵庫県多可郡多可町中区茂利');
ok($zip->set_number('6791135')->is_valid_number, '兵庫県多可郡多可町中区安坂');
ok($zip->set_number('6791201')->is_valid_number, '兵庫県多可郡多可町加美区豊部');
ok($zip->set_number('6791202')->is_valid_number, '兵庫県多可郡多可町加美区熊野部');
ok($zip->set_number('6791203')->is_valid_number, '兵庫県多可郡多可町加美区多田');
ok($zip->set_number('6791204')->is_valid_number, '兵庫県多可郡多可町加美区棚釜');
ok($zip->set_number('6791205')->is_valid_number, '兵庫県多可郡多可町加美区岩座神');
ok($zip->set_number('6791211')->is_valid_number, '兵庫県多可郡多可町加美区寺内');
ok($zip->set_number('6791212')->is_valid_number, '兵庫県多可郡多可町加美区西脇');
ok($zip->set_number('6791213')->is_valid_number, '兵庫県多可郡多可町加美区山野部');
ok($zip->set_number('6791214')->is_valid_number, '兵庫県多可郡多可町加美区的場');
ok($zip->set_number('6791215')->is_valid_number, '兵庫県多可郡多可町加美区奥荒田');
ok($zip->set_number('6791321')->is_valid_number, '兵庫県多可郡多可町加美区山寄上');
ok($zip->set_number('6791322')->is_valid_number, '兵庫県多可郡多可町加美区鳥羽');
ok($zip->set_number('6791323')->is_valid_number, '兵庫県多可郡多可町加美区清水');
ok($zip->set_number('6791324')->is_valid_number, '兵庫県多可郡多可町加美区轟');
ok($zip->set_number('6791325')->is_valid_number, '兵庫県多可郡多可町加美区山口');
ok($zip->set_number('6791326')->is_valid_number, '兵庫県多可郡多可町加美区西山');
ok($zip->set_number('6791327')->is_valid_number, '兵庫県多可郡多可町加美区市原');
ok($zip->set_number('6791331')->is_valid_number, '兵庫県多可郡多可町加美区丹治');
ok($zip->set_number('6791332')->is_valid_number, '兵庫県多可郡多可町加美区大袋');
ok($zip->set_number('6791333')->is_valid_number, '兵庫県多可郡多可町加美区三谷');
ok($zip->set_number('6791334')->is_valid_number, '兵庫県多可郡多可町加美区箸荷');
ok($zip->set_number('6791335')->is_valid_number, '兵庫県多可郡多可町加美区門村');
ok($zip->set_number('6791336')->is_valid_number, '兵庫県多可郡多可町加美区杉原');
ok($zip->set_number('6791337')->is_valid_number, '兵庫県多可郡多可町加美区奥豊部');
ok($zip->set_number('6791338')->is_valid_number, '兵庫県多可郡多可町加美区観音寺');
ok($zip->set_number('6792101')->is_valid_number, '兵庫県姫路市船津町');
ok($zip->set_number('6792111')->is_valid_number, '兵庫県姫路市山田町多田');
ok($zip->set_number('6792112')->is_valid_number, '兵庫県姫路市山田町北山田');
ok($zip->set_number('6792113')->is_valid_number, '兵庫県姫路市山田町南山田');
ok($zip->set_number('6792114')->is_valid_number, '兵庫県姫路市山田町牧野');
ok($zip->set_number('6792115')->is_valid_number, '兵庫県姫路市山田町西山田');
ok($zip->set_number('6792121')->is_valid_number, '兵庫県姫路市豊富町神谷');
ok($zip->set_number('6792122')->is_valid_number, '兵庫県姫路市豊富町御蔭');
ok($zip->set_number('6792123')->is_valid_number, '兵庫県姫路市豊富町豊富');
ok($zip->set_number('6792124')->is_valid_number, '兵庫県姫路市豊富町甲丘');
ok($zip->set_number('6792131')->is_valid_number, '兵庫県姫路市香寺町犬飼');
ok($zip->set_number('6792132')->is_valid_number, '兵庫県姫路市香寺町須加院');
ok($zip->set_number('6792141')->is_valid_number, '兵庫県姫路市香寺町岩部');
ok($zip->set_number('6792142')->is_valid_number, '兵庫県姫路市香寺町広瀬');
ok($zip->set_number('6792143')->is_valid_number, '兵庫県姫路市香寺町中仁野');
ok($zip->set_number('6792144')->is_valid_number, '兵庫県姫路市香寺町中屋');
ok($zip->set_number('6792151')->is_valid_number, '兵庫県姫路市香寺町香呂');
ok($zip->set_number('6792152')->is_valid_number, '兵庫県姫路市香寺町行重');
ok($zip->set_number('6792153')->is_valid_number, '兵庫県姫路市香寺町田野');
ok($zip->set_number('6792154')->is_valid_number, '兵庫県姫路市香寺町相坂');
ok($zip->set_number('6792155')->is_valid_number, '兵庫県姫路市香寺町矢田部');
ok($zip->set_number('6792161')->is_valid_number, '兵庫県姫路市香寺町溝口');
ok($zip->set_number('6792162')->is_valid_number, '兵庫県姫路市香寺町野田');
ok($zip->set_number('6792163')->is_valid_number, '兵庫県姫路市香寺町土師');
ok($zip->set_number('6792164')->is_valid_number, '兵庫県姫路市香寺町中寺');
ok($zip->set_number('6792165')->is_valid_number, '兵庫県姫路市香寺町恒屋');
ok($zip->set_number('6792166')->is_valid_number, '兵庫県姫路市香寺町中村');
ok($zip->set_number('6792167')->is_valid_number, '兵庫県姫路市香寺町久畑');
ok($zip->set_number('6792200')->is_valid_number, '兵庫県神崎郡福崎町以下に掲載がない場合');
ok($zip->set_number('6792201')->is_valid_number, '兵庫県神崎郡福崎町大貫');
ok($zip->set_number('6792202')->is_valid_number, '兵庫県神崎郡福崎町八千種');
ok($zip->set_number('6792203')->is_valid_number, '兵庫県神崎郡福崎町南田原');
ok($zip->set_number('6792204')->is_valid_number, '兵庫県神崎郡福崎町西田原');
ok($zip->set_number('6792205')->is_valid_number, '兵庫県神崎郡福崎町東田原');
ok($zip->set_number('6792211')->is_valid_number, '兵庫県神崎郡福崎町山崎');
ok($zip->set_number('6792212')->is_valid_number, '兵庫県神崎郡福崎町福田');
ok($zip->set_number('6792213')->is_valid_number, '兵庫県神崎郡福崎町馬田');
ok($zip->set_number('6792214')->is_valid_number, '兵庫県神崎郡福崎町福崎新');
ok($zip->set_number('6792215')->is_valid_number, '兵庫県神崎郡福崎町西治');
ok($zip->set_number('6792216')->is_valid_number, '兵庫県神崎郡福崎町高橋');
ok($zip->set_number('6792217')->is_valid_number, '兵庫県神崎郡福崎町高岡');
ok($zip->set_number('6792218')->is_valid_number, '兵庫県神崎郡福崎町田口');
ok($zip->set_number('6792300')->is_valid_number, '兵庫県神崎郡市川町以下に掲載がない場合');
ok($zip->set_number('6792301')->is_valid_number, '兵庫県神崎郡市川町上牛尾');
ok($zip->set_number('6792302')->is_valid_number, '兵庫県神崎郡市川町下牛尾');
ok($zip->set_number('6792303')->is_valid_number, '兵庫県神崎郡市川町上瀬加');
ok($zip->set_number('6792304')->is_valid_number, '兵庫県神崎郡市川町下瀬加');
ok($zip->set_number('6792311')->is_valid_number, '兵庫県神崎郡市川町上田中');
ok($zip->set_number('6792312')->is_valid_number, '兵庫県神崎郡市川町保喜');
ok($zip->set_number('6792313')->is_valid_number, '兵庫県神崎郡市川町西田中');
ok($zip->set_number('6792314')->is_valid_number, '兵庫県神崎郡市川町北田中');
ok($zip->set_number('6792315')->is_valid_number, '兵庫県神崎郡市川町西川辺');
ok($zip->set_number('6792316')->is_valid_number, '兵庫県神崎郡市川町東川辺');
ok($zip->set_number('6792317')->is_valid_number, '兵庫県神崎郡市川町浅野');
ok($zip->set_number('6792318')->is_valid_number, '兵庫県神崎郡市川町小畑');
ok($zip->set_number('6792321')->is_valid_number, '兵庫県神崎郡市川町千原');
ok($zip->set_number('6792322')->is_valid_number, '兵庫県神崎郡市川町小谷');
ok($zip->set_number('6792323')->is_valid_number, '兵庫県神崎郡市川町甘地');
ok($zip->set_number('6792324')->is_valid_number, '兵庫県神崎郡市川町坂戸');
ok($zip->set_number('6792325')->is_valid_number, '兵庫県神崎郡市川町奥');
ok($zip->set_number('6792326')->is_valid_number, '兵庫県神崎郡市川町谷');
ok($zip->set_number('6792327')->is_valid_number, '兵庫県神崎郡市川町近平');
ok($zip->set_number('6792331')->is_valid_number, '兵庫県神崎郡市川町小室');
ok($zip->set_number('6792332')->is_valid_number, '兵庫県神崎郡市川町田中');
ok($zip->set_number('6792333')->is_valid_number, '兵庫県神崎郡市川町神崎');
ok($zip->set_number('6792334')->is_valid_number, '兵庫県神崎郡市川町鶴居');
ok($zip->set_number('6792335')->is_valid_number, '兵庫県神崎郡市川町美佐');
ok($zip->set_number('6792336')->is_valid_number, '兵庫県神崎郡市川町沢');
ok($zip->set_number('6792337')->is_valid_number, '兵庫県神崎郡市川町屋形');
ok($zip->set_number('6792401')->is_valid_number, '兵庫県神崎郡神河町新田');
ok($zip->set_number('6792402')->is_valid_number, '兵庫県神崎郡神河町作畑');
ok($zip->set_number('6792403')->is_valid_number, '兵庫県神崎郡神河町大畑');
ok($zip->set_number('6792404')->is_valid_number, '兵庫県神崎郡神河町越知');
ok($zip->set_number('6792405')->is_valid_number, '兵庫県神崎郡神河町岩屋');
ok($zip->set_number('6792411')->is_valid_number, '兵庫県神崎郡神河町根宇野');
ok($zip->set_number('6792412')->is_valid_number, '兵庫県神崎郡神河町山田');
ok($zip->set_number('6792413')->is_valid_number, '兵庫県神崎郡神河町中村');
ok($zip->set_number('6792414')->is_valid_number, '兵庫県神崎郡神河町粟賀町');
ok($zip->set_number('6792415')->is_valid_number, '兵庫県神崎郡神河町福本');
ok($zip->set_number('6792421')->is_valid_number, '兵庫県神崎郡神河町加納');
ok($zip->set_number('6792422')->is_valid_number, '兵庫県神崎郡神河町貝野');
ok($zip->set_number('6792423')->is_valid_number, '兵庫県神崎郡神河町寺野');
ok($zip->set_number('6792424')->is_valid_number, '兵庫県神崎郡神河町柏尾');
ok($zip->set_number('6792425')->is_valid_number, '兵庫県神崎郡神河町東柏尾');
ok($zip->set_number('6792431')->is_valid_number, '兵庫県神崎郡神河町猪篠');
ok($zip->set_number('6792432')->is_valid_number, '兵庫県神崎郡神河町大山');
ok($zip->set_number('6792433')->is_valid_number, '兵庫県神崎郡神河町杉');
ok($zip->set_number('6792434')->is_valid_number, '兵庫県神崎郡神河町吉冨');
ok($zip->set_number('6793100')->is_valid_number, '兵庫県神崎郡神河町以下に掲載がない場合');
ok($zip->set_number('6793101')->is_valid_number, '兵庫県神崎郡神河町渕');
ok($zip->set_number('6793102')->is_valid_number, '兵庫県神崎郡神河町栗');
ok($zip->set_number('6793103')->is_valid_number, '兵庫県神崎郡神河町長谷');
ok($zip->set_number('6793104')->is_valid_number, '兵庫県神崎郡神河町川上');
ok($zip->set_number('6793111')->is_valid_number, '兵庫県神崎郡神河町大河');
ok($zip->set_number('6793112')->is_valid_number, '兵庫県神崎郡神河町鍛治');
ok($zip->set_number('6793113')->is_valid_number, '兵庫県神崎郡神河町野村');
ok($zip->set_number('6793114')->is_valid_number, '兵庫県神崎郡神河町新野');
ok($zip->set_number('6793115')->is_valid_number, '兵庫県神崎郡神河町比延');
ok($zip->set_number('6793116')->is_valid_number, '兵庫県神崎郡神河町寺前');
ok($zip->set_number('6793121')->is_valid_number, '兵庫県神崎郡神河町上岩');
ok($zip->set_number('6793122')->is_valid_number, '兵庫県神崎郡神河町高朝田');
ok($zip->set_number('6793123')->is_valid_number, '兵庫県神崎郡神河町宮野');
ok($zip->set_number('6793124')->is_valid_number, '兵庫県神崎郡神河町南小田');
ok($zip->set_number('6793125')->is_valid_number, '兵庫県神崎郡神河町上小田');
ok($zip->set_number('6793301')->is_valid_number, '兵庫県朝来市生野町口銀谷');
ok($zip->set_number('6793302')->is_valid_number, '兵庫県朝来市生野町円山');
ok($zip->set_number('6793311')->is_valid_number, '兵庫県朝来市生野町真弓');
ok($zip->set_number('6793321')->is_valid_number, '兵庫県朝来市生野町新町');
ok($zip->set_number('6793322')->is_valid_number, '兵庫県朝来市生野町奥銀谷');
ok($zip->set_number('6793323')->is_valid_number, '兵庫県朝来市生野町竹原野');
ok($zip->set_number('6793324')->is_valid_number, '兵庫県朝来市生野町小野');
ok($zip->set_number('6793325')->is_valid_number, '兵庫県朝来市生野町猪野々');
ok($zip->set_number('6793326')->is_valid_number, '兵庫県朝来市生野町白口');
ok($zip->set_number('6793331')->is_valid_number, '兵庫県朝来市生野町栃原');
ok($zip->set_number('6793332')->is_valid_number, '兵庫県朝来市生野町川尻');
ok($zip->set_number('6793341')->is_valid_number, '兵庫県朝来市生野町黒川');
ok($zip->set_number('6793401')->is_valid_number, '兵庫県朝来市物部');
ok($zip->set_number('6793402')->is_valid_number, '兵庫県朝来市桑市');
ok($zip->set_number('6793403')->is_valid_number, '兵庫県朝来市立脇');
ok($zip->set_number('6793411')->is_valid_number, '兵庫県朝来市沢');
ok($zip->set_number('6793412')->is_valid_number, '兵庫県朝来市山内');
ok($zip->set_number('6793413')->is_valid_number, '兵庫県朝来市納座');
ok($zip->set_number('6793414')->is_valid_number, '兵庫県朝来市川上');
ok($zip->set_number('6793421')->is_valid_number, '兵庫県朝来市伊由市場');
ok($zip->set_number('6793422')->is_valid_number, '兵庫県朝来市石田');
ok($zip->set_number('6793423')->is_valid_number, '兵庫県朝来市多々良木');
ok($zip->set_number('6793424')->is_valid_number, '兵庫県朝来市立野');
ok($zip->set_number('6793431')->is_valid_number, '兵庫県朝来市新井');
ok($zip->set_number('6793432')->is_valid_number, '兵庫県朝来市山口');
ok($zip->set_number('6793433')->is_valid_number, '兵庫県朝来市岩津');
ok($zip->set_number('6793441')->is_valid_number, '兵庫県朝来市羽渕');
ok($zip->set_number('6793442')->is_valid_number, '兵庫県朝来市田路');
ok($zip->set_number('6793451')->is_valid_number, '兵庫県朝来市上八代');
ok($zip->set_number('6793452')->is_valid_number, '兵庫県朝来市八代');
ok($zip->set_number('6793453')->is_valid_number, '兵庫県朝来市佐嚢');
ok($zip->set_number('6794001')->is_valid_number, '兵庫県たつの市揖西町新宮');
ok($zip->set_number('6794002')->is_valid_number, '兵庫県たつの市揖西町中垣内');
ok($zip->set_number('6794003')->is_valid_number, '兵庫県たつの市揖西町小神');
ok($zip->set_number('6794004')->is_valid_number, '兵庫県たつの市揖西町清水新');
ok($zip->set_number('6794005')->is_valid_number, '兵庫県たつの市揖西町清水');
ok($zip->set_number('6794006')->is_valid_number, '兵庫県たつの市揖西町田井');
ok($zip->set_number('6794007')->is_valid_number, '兵庫県たつの市揖西町構');
ok($zip->set_number('6794008')->is_valid_number, '兵庫県たつの市揖西町芦原台');
ok($zip->set_number('6794011')->is_valid_number, '兵庫県たつの市揖西町佐江');
ok($zip->set_number('6794012')->is_valid_number, '兵庫県たつの市揖西町前地');
ok($zip->set_number('6794013')->is_valid_number, '兵庫県たつの市揖西町北山');
ok($zip->set_number('6794014')->is_valid_number, '兵庫県たつの市揖西町竹万');
ok($zip->set_number('6794015')->is_valid_number, '兵庫県たつの市揖西町龍子');
ok($zip->set_number('6794016')->is_valid_number, '兵庫県たつの市揖西町南山');
ok($zip->set_number('6794017')->is_valid_number, '兵庫県たつの市揖西町土師');
ok($zip->set_number('6794021')->is_valid_number, '兵庫県たつの市揖西町小犬丸');
ok($zip->set_number('6794022')->is_valid_number, '兵庫県たつの市揖西町北沢');
ok($zip->set_number('6794023')->is_valid_number, '兵庫県たつの市揖西町住吉');
ok($zip->set_number('6794024')->is_valid_number, '兵庫県たつの市揖西町尾崎');
ok($zip->set_number('6794025')->is_valid_number, '兵庫県たつの市揖西町小畑');
ok($zip->set_number('6794026')->is_valid_number, '兵庫県たつの市揖西町竹原');
ok($zip->set_number('6794027')->is_valid_number, '兵庫県たつの市揖西町長尾');
ok($zip->set_number('6794100')->is_valid_number, '兵庫県たつの市以下に掲載がない場合');
ok($zip->set_number('6794101')->is_valid_number, '兵庫県たつの市神岡町奥村');
ok($zip->set_number('6794102')->is_valid_number, '兵庫県たつの市神岡町北横内');
ok($zip->set_number('6794103')->is_valid_number, '兵庫県たつの市神岡町上横内');
ok($zip->set_number('6794104')->is_valid_number, '兵庫県たつの市神岡町筒井');
ok($zip->set_number('6794105')->is_valid_number, '兵庫県たつの市神岡町西鳥井');
ok($zip->set_number('6794106')->is_valid_number, '兵庫県たつの市神岡町横内');
ok($zip->set_number('6794107')->is_valid_number, '兵庫県たつの市神岡町西横内');
ok($zip->set_number('6794108')->is_valid_number, '兵庫県たつの市神岡町大住寺');
ok($zip->set_number('6794109')->is_valid_number, '兵庫県たつの市神岡町東觜崎');
ok($zip->set_number('6794111')->is_valid_number, '兵庫県たつの市神岡町野部');
ok($zip->set_number('6794112')->is_valid_number, '兵庫県たつの市神岡町追分');
ok($zip->set_number('6794113')->is_valid_number, '兵庫県たつの市神岡町田中');
ok($zip->set_number('6794114')->is_valid_number, '兵庫県たつの市神岡町寄井');
ok($zip->set_number('6794115')->is_valid_number, '兵庫県たつの市神岡町入野');
ok($zip->set_number('6794116')->is_valid_number, '兵庫県たつの市神岡町沢田');
ok($zip->set_number('6794121')->is_valid_number, '兵庫県たつの市龍野町島田');
ok($zip->set_number('6794122')->is_valid_number, '兵庫県たつの市龍野町日飼');
ok($zip->set_number('6794123')->is_valid_number, '兵庫県たつの市龍野町片山');
ok($zip->set_number('6794124')->is_valid_number, '兵庫県たつの市龍野町中井');
ok($zip->set_number('6794125')->is_valid_number, '兵庫県たつの市龍野町末政');
ok($zip->set_number('6794126')->is_valid_number, '兵庫県たつの市龍野町中村');
ok($zip->set_number('6794127')->is_valid_number, '兵庫県たつの市龍野町宮脇');
ok($zip->set_number('6794128')->is_valid_number, '兵庫県たつの市龍野町小宅北');
ok($zip->set_number('6794129')->is_valid_number, '兵庫県たつの市龍野町堂本');
ok($zip->set_number('6794130')->is_valid_number, '兵庫県たつの市誉田町長真');
ok($zip->set_number('6794131')->is_valid_number, '兵庫県たつの市誉田町内山');
ok($zip->set_number('6794132')->is_valid_number, '兵庫県たつの市誉田町福田');
ok($zip->set_number('6794133')->is_valid_number, '兵庫県たつの市誉田町誉');
ok($zip->set_number('6794134')->is_valid_number, '兵庫県たつの市誉田町広山');
ok($zip->set_number('6794135')->is_valid_number, '兵庫県たつの市誉田町高駄');
ok($zip->set_number('6794136')->is_valid_number, '兵庫県たつの市誉田町井上');
ok($zip->set_number('6794137')->is_valid_number, '兵庫県たつの市誉田町片吹');
ok($zip->set_number('6794138')->is_valid_number, '兵庫県たつの市誉田町下沖');
ok($zip->set_number('6794139')->is_valid_number, '兵庫県たつの市誉田町上沖');
ok($zip->set_number('6794141')->is_valid_number, '兵庫県たつの市揖保町栄');
ok($zip->set_number('6794142')->is_valid_number, '兵庫県たつの市揖保町松原');
ok($zip->set_number('6794143')->is_valid_number, '兵庫県たつの市揖保町東用');
ok($zip->set_number('6794144')->is_valid_number, '兵庫県たつの市揖保町真砂');
ok($zip->set_number('6794145')->is_valid_number, '兵庫県たつの市揖保町萩原');
ok($zip->set_number('6794146')->is_valid_number, '兵庫県たつの市揖保町今市');
ok($zip->set_number('6794151')->is_valid_number, '兵庫県たつの市揖保町山下');
ok($zip->set_number('6794152')->is_valid_number, '兵庫県たつの市揖保町中臣');
ok($zip->set_number('6794153')->is_valid_number, '兵庫県たつの市揖保町門前');
ok($zip->set_number('6794154')->is_valid_number, '兵庫県たつの市揖保町西構');
ok($zip->set_number('6794155')->is_valid_number, '兵庫県たつの市揖保町揖保中');
ok($zip->set_number('6794156')->is_valid_number, '兵庫県たつの市揖保町揖保上');
ok($zip->set_number('6794161')->is_valid_number, '兵庫県たつの市龍野町日山');
ok($zip->set_number('6794162')->is_valid_number, '兵庫県たつの市龍野町下霞城');
ok($zip->set_number('6794163')->is_valid_number, '兵庫県たつの市龍野町福の神');
ok($zip->set_number('6794164')->is_valid_number, '兵庫県たつの市龍野町立町');
ok($zip->set_number('6794165')->is_valid_number, '兵庫県たつの市龍野町本町');
ok($zip->set_number('6794166')->is_valid_number, '兵庫県たつの市龍野町川原町');
ok($zip->set_number('6794167')->is_valid_number, '兵庫県たつの市龍野町富永');
ok($zip->set_number('6794168')->is_valid_number, '兵庫県たつの市龍野町四箇');
ok($zip->set_number('6794169')->is_valid_number, '兵庫県たつの市龍野町大道');
ok($zip->set_number('6794170')->is_valid_number, '兵庫県たつの市龍野町中霞城');
ok($zip->set_number('6794171')->is_valid_number, '兵庫県たつの市龍野町北龍野');
ok($zip->set_number('6794172')->is_valid_number, '兵庫県たつの市龍野町上川原');
ok($zip->set_number('6794173')->is_valid_number, '兵庫県たつの市龍野町門の外');
ok($zip->set_number('6794174')->is_valid_number, '兵庫県たつの市龍野町柳原');
ok($zip->set_number('6794175')->is_valid_number, '兵庫県たつの市龍野町旭町');
ok($zip->set_number('6794176')->is_valid_number, '兵庫県たつの市龍野町水神町');
ok($zip->set_number('6794177')->is_valid_number, '兵庫県たつの市龍野町下川原');
ok($zip->set_number('6794178')->is_valid_number, '兵庫県たつの市龍野町大手');
ok($zip->set_number('6794179')->is_valid_number, '兵庫県たつの市龍野町上霞城');
ok($zip->set_number('6794201')->is_valid_number, '兵庫県姫路市林田町久保');
ok($zip->set_number('6794202')->is_valid_number, '兵庫県姫路市林田町下構');
ok($zip->set_number('6794203')->is_valid_number, '兵庫県姫路市林田町中構');
ok($zip->set_number('6794204')->is_valid_number, '兵庫県姫路市林田町上構');
ok($zip->set_number('6794205')->is_valid_number, '兵庫県姫路市林田町新町');
ok($zip->set_number('6794206')->is_valid_number, '兵庫県姫路市林田町林田');
ok($zip->set_number('6794211')->is_valid_number, '兵庫県姫路市林田町六九谷');
ok($zip->set_number('6794212')->is_valid_number, '兵庫県姫路市林田町松山');
ok($zip->set_number('6794213')->is_valid_number, '兵庫県姫路市林田町山田');
ok($zip->set_number('6794214')->is_valid_number, '兵庫県姫路市林田町中山下');
ok($zip->set_number('6794215')->is_valid_number, '兵庫県姫路市林田町八幡');
ok($zip->set_number('6794221')->is_valid_number, '兵庫県姫路市林田町林谷');
ok($zip->set_number('6794222')->is_valid_number, '兵庫県姫路市林田町口佐見');
ok($zip->set_number('6794223')->is_valid_number, '兵庫県姫路市林田町奥佐見');
ok($zip->set_number('6794231')->is_valid_number, '兵庫県姫路市林田町大堤');
ok($zip->set_number('6794232')->is_valid_number, '兵庫県姫路市林田町上伊勢');
ok($zip->set_number('6794233')->is_valid_number, '兵庫県姫路市林田町下伊勢');
ok($zip->set_number('6794301')->is_valid_number, '兵庫県たつの市新宮町篠首');
ok($zip->set_number('6794302')->is_valid_number, '兵庫県たつの市新宮町香山');
ok($zip->set_number('6794303')->is_valid_number, '兵庫県たつの市新宮町上笹');
ok($zip->set_number('6794304')->is_valid_number, '兵庫県たつの市新宮町下笹');
ok($zip->set_number('6794305')->is_valid_number, '兵庫県たつの市新宮町吉島');
ok($zip->set_number('6794311')->is_valid_number, '兵庫県たつの市新宮町宮内');
ok($zip->set_number('6794312')->is_valid_number, '兵庫県たつの市新宮町下野');
ok($zip->set_number('6794313')->is_valid_number, '兵庫県たつの市新宮町新宮');
ok($zip->set_number('6794314')->is_valid_number, '兵庫県たつの市新宮町曽我井');
ok($zip->set_number('6794315')->is_valid_number, '兵庫県たつの市新宮町井野原');
ok($zip->set_number('6794316')->is_valid_number, '兵庫県たつの市新宮町芝田');
ok($zip->set_number('6794321')->is_valid_number, '兵庫県たつの市新宮町段之上');
ok($zip->set_number('6794322')->is_valid_number, '兵庫県たつの市新宮町仙正');
ok($zip->set_number('6794323')->is_valid_number, '兵庫県たつの市新宮町北村');
ok($zip->set_number('6794324')->is_valid_number, '兵庫県たつの市新宮町觜崎');
ok($zip->set_number('6794325')->is_valid_number, '兵庫県たつの市新宮町佐野');
ok($zip->set_number('6794326')->is_valid_number, '兵庫県たつの市新宮町船渡');
ok($zip->set_number('6794327')->is_valid_number, '兵庫県たつの市新宮町中野庄');
ok($zip->set_number('6794331')->is_valid_number, '兵庫県たつの市新宮町市野保');
ok($zip->set_number('6794332')->is_valid_number, '兵庫県たつの市新宮町馬立');
ok($zip->set_number('6794333')->is_valid_number, '兵庫県たつの市新宮町下野田');
ok($zip->set_number('6794341')->is_valid_number, '兵庫県たつの市新宮町能地');
ok($zip->set_number('6794342')->is_valid_number, '兵庫県たつの市新宮町平野');
ok($zip->set_number('6794343')->is_valid_number, '兵庫県たつの市新宮町大屋');
ok($zip->set_number('6794344')->is_valid_number, '兵庫県たつの市新宮町善定');
ok($zip->set_number('6794345')->is_valid_number, '兵庫県たつの市新宮町福栖');
ok($zip->set_number('6794346')->is_valid_number, '兵庫県たつの市新宮町千本');
ok($zip->set_number('6795131')->is_valid_number, '兵庫県佐用郡佐用町上本郷');
ok($zip->set_number('6795132')->is_valid_number, '兵庫県佐用郡佐用町下本郷');
ok($zip->set_number('6795133')->is_valid_number, '兵庫県佐用郡佐用町三日月');
ok($zip->set_number('6795134')->is_valid_number, '兵庫県佐用郡佐用町乃井野');
ok($zip->set_number('6795135')->is_valid_number, '兵庫県佐用郡佐用町春哉');
ok($zip->set_number('6795136')->is_valid_number, '兵庫県佐用郡佐用町志文');
ok($zip->set_number('6795137')->is_valid_number, '兵庫県佐用郡佐用町真宗');
ok($zip->set_number('6795141')->is_valid_number, '兵庫県佐用郡佐用町廣山');
ok($zip->set_number('6795142')->is_valid_number, '兵庫県佐用郡佐用町弦谷');
ok($zip->set_number('6795143')->is_valid_number, '兵庫県佐用郡佐用町三原');
ok($zip->set_number('6795144')->is_valid_number, '兵庫県佐用郡佐用町三ツ尾');
ok($zip->set_number('6795145')->is_valid_number, '兵庫県佐用郡佐用町大畑');
ok($zip->set_number('6795146')->is_valid_number, '兵庫県佐用郡佐用町大下り');
ok($zip->set_number('6795147')->is_valid_number, '兵庫県佐用郡佐用町末廣');
ok($zip->set_number('6795148')->is_valid_number, '兵庫県佐用郡佐用町光都');
ok($zip->set_number('6795151')->is_valid_number, '兵庫県たつの市新宮町奥小屋');
ok($zip->set_number('6795152')->is_valid_number, '兵庫県たつの市新宮町牧');
ok($zip->set_number('6795153')->is_valid_number, '兵庫県たつの市新宮町時重');
ok($zip->set_number('6795154')->is_valid_number, '兵庫県たつの市新宮町鍛冶屋');
ok($zip->set_number('6795155')->is_valid_number, '兵庫県たつの市新宮町栗町');
ok($zip->set_number('6795161')->is_valid_number, '兵庫県たつの市新宮町下莇原');
ok($zip->set_number('6795162')->is_valid_number, '兵庫県たつの市新宮町上莇原');
ok($zip->set_number('6795163')->is_valid_number, '兵庫県たつの市新宮町角亀');
ok($zip->set_number('6795164')->is_valid_number, '兵庫県たつの市新宮町二柏野');
ok($zip->set_number('6795165')->is_valid_number, '兵庫県たつの市新宮町光都');
ok($zip->set_number('6795201')->is_valid_number, '兵庫県佐用郡佐用町多賀');
ok($zip->set_number('6795202')->is_valid_number, '兵庫県佐用郡佐用町中島');
ok($zip->set_number('6795203')->is_valid_number, '兵庫県佐用郡佐用町米田');
ok($zip->set_number('6795204')->is_valid_number, '兵庫県佐用郡佐用町小山');
ok($zip->set_number('6795205')->is_valid_number, '兵庫県佐用郡佐用町安川');
ok($zip->set_number('6795206')->is_valid_number, '兵庫県佐用郡佐用町土井');
ok($zip->set_number('6795207')->is_valid_number, '兵庫県佐用郡佐用町宝蔵寺');
ok($zip->set_number('6795211')->is_valid_number, '兵庫県佐用郡佐用町下徳久');
ok($zip->set_number('6795212')->is_valid_number, '兵庫県佐用郡佐用町林崎');
ok($zip->set_number('6795213')->is_valid_number, '兵庫県佐用郡佐用町東徳久');
ok($zip->set_number('6795214')->is_valid_number, '兵庫県佐用郡佐用町西徳久');
ok($zip->set_number('6795215')->is_valid_number, '兵庫県佐用郡佐用町平松');
ok($zip->set_number('6795221')->is_valid_number, '兵庫県佐用郡佐用町漆野');
ok($zip->set_number('6795222')->is_valid_number, '兵庫県佐用郡佐用町西下野');
ok($zip->set_number('6795223')->is_valid_number, '兵庫県佐用郡佐用町下三河');
ok($zip->set_number('6795224')->is_valid_number, '兵庫県佐用郡佐用町中三河');
ok($zip->set_number('6795225')->is_valid_number, '兵庫県佐用郡佐用町上三河');
ok($zip->set_number('6795226')->is_valid_number, '兵庫県佐用郡佐用町河崎');
ok($zip->set_number('6795227')->is_valid_number, '兵庫県佐用郡佐用町船越');
ok($zip->set_number('6795300')->is_valid_number, '兵庫県佐用郡佐用町以下に掲載がない場合');
ok($zip->set_number('6795301')->is_valid_number, '兵庫県佐用郡佐用町佐用');
ok($zip->set_number('6795302')->is_valid_number, '兵庫県佐用郡佐用町山脇');
ok($zip->set_number('6795303')->is_valid_number, '兵庫県佐用郡佐用町真盛');
ok($zip->set_number('6795304')->is_valid_number, '兵庫県佐用郡佐用町山田');
ok($zip->set_number('6795305')->is_valid_number, '兵庫県佐用郡佐用町長尾');
ok($zip->set_number('6795306')->is_valid_number, '兵庫県佐用郡佐用町本位田');
ok($zip->set_number('6795307')->is_valid_number, '兵庫県佐用郡佐用町円応寺');
ok($zip->set_number('6795311')->is_valid_number, '兵庫県佐用郡佐用町福沢');
ok($zip->set_number('6795312')->is_valid_number, '兵庫県佐用郡佐用町仁方');
ok($zip->set_number('6795313')->is_valid_number, '兵庫県佐用郡佐用町西河内');
ok($zip->set_number('6795314')->is_valid_number, '兵庫県佐用郡佐用町大木谷');
ok($zip->set_number('6795315')->is_valid_number, '兵庫県佐用郡佐用町淀');
ok($zip->set_number('6795316')->is_valid_number, '兵庫県佐用郡佐用町豊福');
ok($zip->set_number('6795317')->is_valid_number, '兵庫県佐用郡佐用町末包');
ok($zip->set_number('6795318')->is_valid_number, '兵庫県佐用郡佐用町東中山');
ok($zip->set_number('6795319')->is_valid_number, '兵庫県佐用郡佐用町大畠');
ok($zip->set_number('6795321')->is_valid_number, '兵庫県佐用郡佐用町下石井');
ok($zip->set_number('6795322')->is_valid_number, '兵庫県佐用郡佐用町上石井');
ok($zip->set_number('6795323')->is_valid_number, '兵庫県佐用郡佐用町若州');
ok($zip->set_number('6795324')->is_valid_number, '兵庫県佐用郡佐用町奥海');
ok($zip->set_number('6795325')->is_valid_number, '兵庫県佐用郡佐用町水根');
ok($zip->set_number('6795331')->is_valid_number, '兵庫県佐用郡佐用町平福');
ok($zip->set_number('6795332')->is_valid_number, '兵庫県佐用郡佐用町延吉');
ok($zip->set_number('6795333')->is_valid_number, '兵庫県佐用郡佐用町庵');
ok($zip->set_number('6795334')->is_valid_number, '兵庫県佐用郡佐用町桑野');
ok($zip->set_number('6795335')->is_valid_number, '兵庫県佐用郡佐用町海内');
ok($zip->set_number('6795341')->is_valid_number, '兵庫県佐用郡佐用町横坂');
ok($zip->set_number('6795342')->is_valid_number, '兵庫県佐用郡佐用町宗行');
ok($zip->set_number('6795343')->is_valid_number, '兵庫県佐用郡佐用町口長谷');
ok($zip->set_number('6795344')->is_valid_number, '兵庫県佐用郡佐用町奥長谷');
ok($zip->set_number('6795345')->is_valid_number, '兵庫県佐用郡佐用町奥金近');
ok($zip->set_number('6795346')->is_valid_number, '兵庫県佐用郡佐用町口金近');
ok($zip->set_number('6795501')->is_valid_number, '兵庫県佐用郡佐用町桜山');
ok($zip->set_number('6795502')->is_valid_number, '兵庫県佐用郡佐用町才金');
ok($zip->set_number('6795503')->is_valid_number, '兵庫県佐用郡佐用町本郷');
ok($zip->set_number('6795504')->is_valid_number, '兵庫県佐用郡佐用町大垣内');
ok($zip->set_number('6795505')->is_valid_number, '兵庫県佐用郡佐用町皆田');
ok($zip->set_number('6795511')->is_valid_number, '兵庫県佐用郡佐用町福中');
ok($zip->set_number('6795512')->is_valid_number, '兵庫県佐用郡佐用町南中山');
ok($zip->set_number('6795513')->is_valid_number, '兵庫県佐用郡佐用町金屋');
ok($zip->set_number('6795514')->is_valid_number, '兵庫県佐用郡佐用町福吉');
ok($zip->set_number('6795521')->is_valid_number, '兵庫県佐用郡佐用町早瀬');
ok($zip->set_number('6795522')->is_valid_number, '兵庫県佐用郡佐用町仁位');
ok($zip->set_number('6795523')->is_valid_number, '兵庫県佐用郡佐用町上月');
ok($zip->set_number('6795524')->is_valid_number, '兵庫県佐用郡佐用町寄延');
ok($zip->set_number('6795525')->is_valid_number, '兵庫県佐用郡佐用町目高');
ok($zip->set_number('6795531')->is_valid_number, '兵庫県佐用郡佐用町宇根');
ok($zip->set_number('6795532')->is_valid_number, '兵庫県佐用郡佐用町須安');
ok($zip->set_number('6795533')->is_valid_number, '兵庫県佐用郡佐用町力万');
ok($zip->set_number('6795534')->is_valid_number, '兵庫県佐用郡佐用町西大畠');
ok($zip->set_number('6795535')->is_valid_number, '兵庫県佐用郡佐用町小日山');
ok($zip->set_number('6795641')->is_valid_number, '兵庫県佐用郡佐用町久崎');
ok($zip->set_number('6795642')->is_valid_number, '兵庫県佐用郡佐用町円光寺');
ok($zip->set_number('6795643')->is_valid_number, '兵庫県佐用郡佐用町下秋里');
ok($zip->set_number('6795644')->is_valid_number, '兵庫県佐用郡佐用町上秋里');
ok($zip->set_number('6795645')->is_valid_number, '兵庫県佐用郡佐用町西新宿');
ok($zip->set_number('6795646')->is_valid_number, '兵庫県佐用郡佐用町大日山');
ok($zip->set_number('6795651')->is_valid_number, '兵庫県佐用郡佐用町櫛田');
ok($zip->set_number('6795652')->is_valid_number, '兵庫県佐用郡佐用町家内');
ok($zip->set_number('6795653')->is_valid_number, '兵庫県佐用郡佐用町小赤松');
ok($zip->set_number('6795654')->is_valid_number, '兵庫県佐用郡佐用町大酒');
ok($zip->set_number('6800000')->is_valid_number, '鳥取県鳥取市以下に掲載がない場合');
ok($zip->set_number('6800001')->is_valid_number, '鳥取県鳥取市浜坂');
ok($zip->set_number('6800002')->is_valid_number, '鳥取県鳥取市浜坂東');
ok($zip->set_number('6800003')->is_valid_number, '鳥取県鳥取市覚寺');
ok($zip->set_number('6800004')->is_valid_number, '鳥取県鳥取市北園');
ok($zip->set_number('6800005')->is_valid_number, '鳥取県鳥取市円護寺');
ok($zip->set_number('6800006')->is_valid_number, '鳥取県鳥取市丸山町');
ok($zip->set_number('6800007')->is_valid_number, '鳥取県鳥取市湯所町');
ok($zip->set_number('6800008')->is_valid_number, '鳥取県鳥取市山城町');
ok($zip->set_number('6800011')->is_valid_number, '鳥取県鳥取市東町');
ok($zip->set_number('6800012')->is_valid_number, '鳥取県鳥取市栗谷町');
ok($zip->set_number('6800013')->is_valid_number, '鳥取県鳥取市江崎町');
ok($zip->set_number('6800014')->is_valid_number, '鳥取県鳥取市馬場町');
ok($zip->set_number('6800015')->is_valid_number, '鳥取県鳥取市上町');
ok($zip->set_number('6800016')->is_valid_number, '鳥取県鳥取市中町');
ok($zip->set_number('6800017')->is_valid_number, '鳥取県鳥取市尚徳町');
ok($zip->set_number('6800021')->is_valid_number, '鳥取県鳥取市材木町');
ok($zip->set_number('6800022')->is_valid_number, '鳥取県鳥取市西町');
ok($zip->set_number('6800023')->is_valid_number, '鳥取県鳥取市片原');
ok($zip->set_number('6800024')->is_valid_number, '鳥取県鳥取市玄好町');
ok($zip->set_number('6800031')->is_valid_number, '鳥取県鳥取市本町');
ok($zip->set_number('6800032')->is_valid_number, '鳥取県鳥取市茶町');
ok($zip->set_number('6800033')->is_valid_number, '鳥取県鳥取市二階町');
ok($zip->set_number('6800034')->is_valid_number, '鳥取県鳥取市元魚町');
ok($zip->set_number('6800035')->is_valid_number, '鳥取県鳥取市新町');
ok($zip->set_number('6800036')->is_valid_number, '鳥取県鳥取市川端');
ok($zip->set_number('6800037')->is_valid_number, '鳥取県鳥取市元町');
ok($zip->set_number('6800041')->is_valid_number, '鳥取県鳥取市掛出町');
ok($zip->set_number('6800042')->is_valid_number, '鳥取県鳥取市庖丁人町');
ok($zip->set_number('6800043')->is_valid_number, '鳥取県鳥取市大榎町');
ok($zip->set_number('6800044')->is_valid_number, '鳥取県鳥取市御弓町');
ok($zip->set_number('6800045')->is_valid_number, '鳥取県鳥取市大工町頭');
ok($zip->set_number('6800046')->is_valid_number, '鳥取県鳥取市元大工町');
ok($zip->set_number('6800047')->is_valid_number, '鳥取県鳥取市上魚町');
ok($zip->set_number('6800051')->is_valid_number, '鳥取県鳥取市若桜町');
ok($zip->set_number('6800052')->is_valid_number, '鳥取県鳥取市鍛冶町');
ok($zip->set_number('6800053')->is_valid_number, '鳥取県鳥取市寺町');
ok($zip->set_number('6800054')->is_valid_number, '鳥取県鳥取市桶屋町');
ok($zip->set_number('6800055')->is_valid_number, '鳥取県鳥取市戎町');
ok($zip->set_number('6800056')->is_valid_number, '鳥取県鳥取市職人町');
ok($zip->set_number('6800061')->is_valid_number, '鳥取県鳥取市立川町');
ok($zip->set_number('6800062')->is_valid_number, '鳥取県鳥取市吉方町');
ok($zip->set_number('6800071')->is_valid_number, '鳥取県鳥取市百谷');
ok($zip->set_number('6800072')->is_valid_number, '鳥取県鳥取市滝山');
ok($zip->set_number('6800073')->is_valid_number, '鳥取県鳥取市小西谷');
ok($zip->set_number('6800074')->is_valid_number, '鳥取県鳥取市卯垣');
ok($zip->set_number('6800081')->is_valid_number, '鳥取県鳥取市岩倉');
ok($zip->set_number('6800131')->is_valid_number, '鳥取県鳥取市国府町高岡');
ok($zip->set_number('6800132')->is_valid_number, '鳥取県鳥取市国府町神垣');
ok($zip->set_number('6800133')->is_valid_number, '鳥取県鳥取市国府町山根');
ok($zip->set_number('6800134')->is_valid_number, '鳥取県鳥取市国府町清水');
ok($zip->set_number('6800135')->is_valid_number, '鳥取県鳥取市国府町谷');
ok($zip->set_number('6800136')->is_valid_number, '鳥取県鳥取市国府町糸谷');
ok($zip->set_number('6800141')->is_valid_number, '鳥取県鳥取市国府町美歎');
ok($zip->set_number('6800142')->is_valid_number, '鳥取県鳥取市国府町麻生');
ok($zip->set_number('6800143')->is_valid_number, '鳥取県鳥取市国府町玉鉾');
ok($zip->set_number('6800144')->is_valid_number, '鳥取県鳥取市国府町岡益');
ok($zip->set_number('6800145')->is_valid_number, '鳥取県鳥取市国府町広西');
ok($zip->set_number('6800146')->is_valid_number, '鳥取県鳥取市国府町町屋');
ok($zip->set_number('6800151')->is_valid_number, '鳥取県鳥取市国府町宮下');
ok($zip->set_number('6800152')->is_valid_number, '鳥取県鳥取市国府町庁');
ok($zip->set_number('6800153')->is_valid_number, '鳥取県鳥取市国府町法花寺');
ok($zip->set_number('6800154')->is_valid_number, '鳥取県鳥取市国府町三代寺');
ok($zip->set_number('6800155')->is_valid_number, '鳥取県鳥取市国府町国分寺');
ok($zip->set_number('6800156')->is_valid_number, '鳥取県鳥取市国府町中郷');
ok($zip->set_number('6800201')->is_valid_number, '鳥取県鳥取市国府町雨滝');
ok($zip->set_number('6800202')->is_valid_number, '鳥取県鳥取市国府町石井谷');
ok($zip->set_number('6800203')->is_valid_number, '鳥取県鳥取市国府町大石');
ok($zip->set_number('6800204')->is_valid_number, '鳥取県鳥取市国府町楠城');
ok($zip->set_number('6800205')->is_valid_number, '鳥取県鳥取市国府町拾石');
ok($zip->set_number('6800206')->is_valid_number, '鳥取県鳥取市国府町栃本');
ok($zip->set_number('6800207')->is_valid_number, '鳥取県鳥取市国府町下木原');
ok($zip->set_number('6800208')->is_valid_number, '鳥取県鳥取市国府町木原');
ok($zip->set_number('6800211')->is_valid_number, '鳥取県鳥取市国府町菅野');
ok($zip->set_number('6800212')->is_valid_number, '鳥取県鳥取市国府町上地');
ok($zip->set_number('6800213')->is_valid_number, '鳥取県鳥取市国府町上上地');
ok($zip->set_number('6800214')->is_valid_number, '鳥取県鳥取市国府町上荒舟');
ok($zip->set_number('6800215')->is_valid_number, '鳥取県鳥取市国府町山崎');
ok($zip->set_number('6800216')->is_valid_number, '鳥取県鳥取市国府町荒舟');
ok($zip->set_number('6800221')->is_valid_number, '鳥取県鳥取市国府町神護');
ok($zip->set_number('6800222')->is_valid_number, '鳥取県鳥取市国府町殿');
ok($zip->set_number('6800223')->is_valid_number, '鳥取県鳥取市国府町中河原');
ok($zip->set_number('6800224')->is_valid_number, '鳥取県鳥取市国府町松尾');
ok($zip->set_number('6800225')->is_valid_number, '鳥取県鳥取市国府町吉野');
ok($zip->set_number('6800226')->is_valid_number, '鳥取県鳥取市国府町新井');
ok($zip->set_number('6800301')->is_valid_number, '鳥取県八頭郡八頭町姫路');
ok($zip->set_number('6800302')->is_valid_number, '鳥取県八頭郡八頭町明辺');
ok($zip->set_number('6800303')->is_valid_number, '鳥取県八頭郡八頭町落岩');
ok($zip->set_number('6800304')->is_valid_number, '鳥取県八頭郡八頭町山志谷');
ok($zip->set_number('6800305')->is_valid_number, '鳥取県八頭郡八頭町麻生');
ok($zip->set_number('6800306')->is_valid_number, '鳥取県八頭郡八頭町野町');
ok($zip->set_number('6800307')->is_valid_number, '鳥取県八頭郡八頭町福地');
ok($zip->set_number('6800311')->is_valid_number, '鳥取県八頭郡八頭町市場');
ok($zip->set_number('6800312')->is_valid_number, '鳥取県八頭郡八頭町覚王寺');
ok($zip->set_number('6800313')->is_valid_number, '鳥取県八頭郡八頭町上津黒');
ok($zip->set_number('6800314')->is_valid_number, '鳥取県八頭郡八頭町下津黒');
ok($zip->set_number('6800315')->is_valid_number, '鳥取県八頭郡八頭町別府');
ok($zip->set_number('6800316')->is_valid_number, '鳥取県八頭郡八頭町篠波');
ok($zip->set_number('6800400')->is_valid_number, '鳥取県八頭郡八頭町以下に掲載がない場合');
ok($zip->set_number('6800401')->is_valid_number, '鳥取県八頭郡八頭町上野');
ok($zip->set_number('6800402')->is_valid_number, '鳥取県八頭郡八頭町隼福');
ok($zip->set_number('6800403')->is_valid_number, '鳥取県八頭郡八頭町福井');
ok($zip->set_number('6800404')->is_valid_number, '鳥取県八頭郡八頭町見槻中');
ok($zip->set_number('6800405')->is_valid_number, '鳥取県八頭郡八頭町隼郡家');
ok($zip->set_number('6800406')->is_valid_number, '鳥取県八頭郡八頭町見槻');
ok($zip->set_number('6800407')->is_valid_number, '鳥取県八頭郡八頭町志子部');
ok($zip->set_number('6800408')->is_valid_number, '鳥取県八頭郡八頭町西谷');
ok($zip->set_number('6800411')->is_valid_number, '鳥取県八頭郡八頭町船岡殿');
ok($zip->set_number('6800412')->is_valid_number, '鳥取県八頭郡八頭町水口');
ok($zip->set_number('6800413')->is_valid_number, '鳥取県八頭郡八頭町塩上');
ok($zip->set_number('6800414')->is_valid_number, '鳥取県八頭郡八頭町橋本');
ok($zip->set_number('6800415')->is_valid_number, '鳥取県八頭郡八頭町下野');
ok($zip->set_number('6800416')->is_valid_number, '鳥取県八頭郡八頭町大江');
ok($zip->set_number('6800421')->is_valid_number, '鳥取県八頭郡八頭町下門尾');
ok($zip->set_number('6800422')->is_valid_number, '鳥取県八頭郡八頭町門尾');
ok($zip->set_number('6800423')->is_valid_number, '鳥取県八頭郡八頭町堀越');
ok($zip->set_number('6800424')->is_valid_number, '鳥取県八頭郡八頭町稲荷');
ok($zip->set_number('6800425')->is_valid_number, '鳥取県八頭郡八頭町井古');
ok($zip->set_number('6800426')->is_valid_number, '鳥取県八頭郡八頭町下坂');
ok($zip->set_number('6800427')->is_valid_number, '鳥取県八頭郡八頭町奥谷');
ok($zip->set_number('6800431')->is_valid_number, '鳥取県八頭郡八頭町下峰寺');
ok($zip->set_number('6800432')->is_valid_number, '鳥取県八頭郡八頭町上峰寺');
ok($zip->set_number('6800433')->is_valid_number, '鳥取県八頭郡八頭町山上');
ok($zip->set_number('6800434')->is_valid_number, '鳥取県八頭郡八頭町延命寺');
ok($zip->set_number('6800435')->is_valid_number, '鳥取県八頭郡八頭町大坪');
ok($zip->set_number('6800436')->is_valid_number, '鳥取県八頭郡八頭町山路');
ok($zip->set_number('6800437')->is_valid_number, '鳥取県八頭郡八頭町花原');
ok($zip->set_number('6800438')->is_valid_number, '鳥取県八頭郡八頭町山田');
ok($zip->set_number('6800441')->is_valid_number, '鳥取県八頭郡八頭町西御門');
ok($zip->set_number('6800442')->is_valid_number, '鳥取県八頭郡八頭町市谷');
ok($zip->set_number('6800443')->is_valid_number, '鳥取県八頭郡八頭町郡家殿');
ok($zip->set_number('6800444')->is_valid_number, '鳥取県八頭郡八頭町花');
ok($zip->set_number('6800445')->is_valid_number, '鳥取県八頭郡八頭町大門');
ok($zip->set_number('6800451')->is_valid_number, '鳥取県八頭郡八頭町久能寺');
ok($zip->set_number('6800452')->is_valid_number, '鳥取県八頭郡八頭町池田');
ok($zip->set_number('6800453')->is_valid_number, '鳥取県八頭郡八頭町万代寺');
ok($zip->set_number('6800454')->is_valid_number, '鳥取県八頭郡八頭町石田百井');
ok($zip->set_number('6800455')->is_valid_number, '鳥取県八頭郡八頭町土師百井');
ok($zip->set_number('6800456')->is_valid_number, '鳥取県八頭郡八頭町米岡');
ok($zip->set_number('6800457')->is_valid_number, '鳥取県八頭郡八頭町国中');
ok($zip->set_number('6800461')->is_valid_number, '鳥取県八頭郡八頭町郡家');
ok($zip->set_number('6800462')->is_valid_number, '鳥取県八頭郡八頭町福本');
ok($zip->set_number('6800463')->is_valid_number, '鳥取県八頭郡八頭町宮谷');
ok($zip->set_number('6800471')->is_valid_number, '鳥取県八頭郡八頭町船岡');
ok($zip->set_number('6800472')->is_valid_number, '鳥取県八頭郡八頭町下濃');
ok($zip->set_number('6800473')->is_valid_number, '鳥取県八頭郡八頭町坂田');
ok($zip->set_number('6800474')->is_valid_number, '鳥取県八頭郡八頭町破岩');
ok($zip->set_number('6800521')->is_valid_number, '鳥取県八頭郡八頭町安井宿');
ok($zip->set_number('6800522')->is_valid_number, '鳥取県八頭郡八頭町新興寺');
ok($zip->set_number('6800523')->is_valid_number, '鳥取県八頭郡八頭町小別府');
ok($zip->set_number('6800524')->is_valid_number, '鳥取県八頭郡八頭町茂田');
ok($zip->set_number('6800525')->is_valid_number, '鳥取県八頭郡八頭町横田');
ok($zip->set_number('6800526')->is_valid_number, '鳥取県八頭郡八頭町日下部');
ok($zip->set_number('6800527')->is_valid_number, '鳥取県八頭郡八頭町桜ヶ丘');
ok($zip->set_number('6800531')->is_valid_number, '鳥取県八頭郡八頭町才代');
ok($zip->set_number('6800532')->is_valid_number, '鳥取県八頭郡八頭町東');
ok($zip->set_number('6800533')->is_valid_number, '鳥取県八頭郡八頭町皆原');
ok($zip->set_number('6800534')->is_valid_number, '鳥取県八頭郡八頭町鍛冶屋');
ok($zip->set_number('6800535')->is_valid_number, '鳥取県八頭郡八頭町三山口');
ok($zip->set_number('6800536')->is_valid_number, '鳥取県八頭郡八頭町三浦');
ok($zip->set_number('6800537')->is_valid_number, '鳥取県八頭郡八頭町岩淵');
ok($zip->set_number('6800541')->is_valid_number, '鳥取県八頭郡八頭町清徳');
ok($zip->set_number('6800542')->is_valid_number, '鳥取県八頭郡八頭町茂谷');
ok($zip->set_number('6800543')->is_valid_number, '鳥取県八頭郡八頭町奥野');
ok($zip->set_number('6800544')->is_valid_number, '鳥取県八頭郡八頭町佐崎');
ok($zip->set_number('6800545')->is_valid_number, '鳥取県八頭郡八頭町柿原');
ok($zip->set_number('6800601')->is_valid_number, '鳥取県八頭郡八頭町北山');
ok($zip->set_number('6800602')->is_valid_number, '鳥取県八頭郡八頭町用呂');
ok($zip->set_number('6800603')->is_valid_number, '鳥取県八頭郡八頭町日田');
ok($zip->set_number('6800604')->is_valid_number, '鳥取県八頭郡八頭町南');
ok($zip->set_number('6800605')->is_valid_number, '鳥取県八頭郡八頭町島');
ok($zip->set_number('6800606')->is_valid_number, '鳥取県八頭郡八頭町重枝');
ok($zip->set_number('6800607')->is_valid_number, '鳥取県八頭郡八頭町徳丸');
ok($zip->set_number('6800611')->is_valid_number, '鳥取県八頭郡八頭町富枝');
ok($zip->set_number('6800612')->is_valid_number, '鳥取県八頭郡八頭町志谷');
ok($zip->set_number('6800613')->is_valid_number, '鳥取県八頭郡八頭町稗谷');
ok($zip->set_number('6800614')->is_valid_number, '鳥取県八頭郡八頭町中');
ok($zip->set_number('6800700')->is_valid_number, '鳥取県八頭郡若桜町以下に掲載がない場合');
ok($zip->set_number('6800701')->is_valid_number, '鳥取県八頭郡若桜町若桜');
ok($zip->set_number('6800711')->is_valid_number, '鳥取県八頭郡若桜町三倉');
ok($zip->set_number('6800712')->is_valid_number, '鳥取県八頭郡若桜町高野');
ok($zip->set_number('6800713')->is_valid_number, '鳥取県八頭郡若桜町赤松');
ok($zip->set_number('6800714')->is_valid_number, '鳥取県八頭郡若桜町来見野');
ok($zip->set_number('6800715')->is_valid_number, '鳥取県八頭郡若桜町諸鹿');
ok($zip->set_number('6800721')->is_valid_number, '鳥取県八頭郡若桜町屋堂羅');
ok($zip->set_number('6800722')->is_valid_number, '鳥取県八頭郡若桜町浅井');
ok($zip->set_number('6800723')->is_valid_number, '鳥取県八頭郡若桜町香田');
ok($zip->set_number('6800724')->is_valid_number, '鳥取県八頭郡若桜町長砂');
ok($zip->set_number('6800725')->is_valid_number, '鳥取県八頭郡若桜町湯原');
ok($zip->set_number('6800726')->is_valid_number, '鳥取県八頭郡若桜町淵見');
ok($zip->set_number('6800727')->is_valid_number, '鳥取県八頭郡若桜町茗荷谷');
ok($zip->set_number('6800728')->is_valid_number, '鳥取県八頭郡若桜町つく米');
ok($zip->set_number('6800731')->is_valid_number, '鳥取県八頭郡若桜町岩屋堂');
ok($zip->set_number('6800732')->is_valid_number, '鳥取県八頭郡若桜町中原');
ok($zip->set_number('6800733')->is_valid_number, '鳥取県八頭郡若桜町大野');
ok($zip->set_number('6800734')->is_valid_number, '鳥取県八頭郡若桜町小船');
ok($zip->set_number('6800735')->is_valid_number, '鳥取県八頭郡若桜町落折');
ok($zip->set_number('6800741')->is_valid_number, '鳥取県八頭郡若桜町大炊');
ok($zip->set_number('6800742')->is_valid_number, '鳥取県八頭郡若桜町岸野');
ok($zip->set_number('6800743')->is_valid_number, '鳥取県八頭郡若桜町糸白見');
ok($zip->set_number('6800744')->is_valid_number, '鳥取県八頭郡若桜町根安');
ok($zip->set_number('6800745')->is_valid_number, '鳥取県八頭郡若桜町須澄');
ok($zip->set_number('6800746')->is_valid_number, '鳥取県八頭郡若桜町吉川');
ok($zip->set_number('6800801')->is_valid_number, '鳥取県鳥取市松並町');
ok($zip->set_number('6800802')->is_valid_number, '鳥取県鳥取市青葉町');
ok($zip->set_number('6800803')->is_valid_number, '鳥取県鳥取市田園町');
ok($zip->set_number('6800804')->is_valid_number, '鳥取県鳥取市田島');
ok($zip->set_number('6800805')->is_valid_number, '鳥取県鳥取市相生町');
ok($zip->set_number('6800806')->is_valid_number, '鳥取県鳥取市薬師町');
ok($zip->set_number('6800811')->is_valid_number, '鳥取県鳥取市西品治');
ok($zip->set_number('6800812')->is_valid_number, '鳥取県鳥取市新品治町');
ok($zip->set_number('6800813')->is_valid_number, '鳥取県鳥取市寿町');
ok($zip->set_number('6800814')->is_valid_number, '鳥取県鳥取市南町');
ok($zip->set_number('6800821')->is_valid_number, '鳥取県鳥取市瓦町');
ok($zip->set_number('6800822')->is_valid_number, '鳥取県鳥取市今町');
ok($zip->set_number('6800823')->is_valid_number, '鳥取県鳥取市幸町');
ok($zip->set_number('6800824')->is_valid_number, '鳥取県鳥取市行徳');
ok($zip->set_number('6800831')->is_valid_number, '鳥取県鳥取市栄町');
ok($zip->set_number('6800832')->is_valid_number, '鳥取県鳥取市弥生町');
ok($zip->set_number('6800833')->is_valid_number, '鳥取県鳥取市末広温泉町');
ok($zip->set_number('6800834')->is_valid_number, '鳥取県鳥取市永楽温泉町');
ok($zip->set_number('6800835')->is_valid_number, '鳥取県鳥取市東品治町');
ok($zip->set_number('6800841')->is_valid_number, '鳥取県鳥取市吉方温泉');
ok($zip->set_number('6800842')->is_valid_number, '鳥取県鳥取市吉方');
ok($zip->set_number('6800843')->is_valid_number, '鳥取県鳥取市南吉方');
ok($zip->set_number('6800844')->is_valid_number, '鳥取県鳥取市興南町');
ok($zip->set_number('6800845')->is_valid_number, '鳥取県鳥取市富安');
ok($zip->set_number('6800846')->is_valid_number, '鳥取県鳥取市扇町');
ok($zip->set_number('6800847')->is_valid_number, '鳥取県鳥取市天神町');
ok($zip->set_number('6800851')->is_valid_number, '鳥取県鳥取市大杙');
ok($zip->set_number('6800852')->is_valid_number, '鳥取県鳥取市東今在家');
ok($zip->set_number('6800853')->is_valid_number, '鳥取県鳥取市桜谷');
ok($zip->set_number('6800854')->is_valid_number, '鳥取県鳥取市正蓮寺');
ok($zip->set_number('6800855')->is_valid_number, '鳥取県鳥取市面影');
ok($zip->set_number('6800861')->is_valid_number, '鳥取県鳥取市新');
ok($zip->set_number('6800862')->is_valid_number, '鳥取県鳥取市雲山');
ok($zip->set_number('6800863')->is_valid_number, '鳥取県鳥取市大覚寺');
ok($zip->set_number('6800864')->is_valid_number, '鳥取県鳥取市吉成');
ok($zip->set_number('6800865')->is_valid_number, '鳥取県鳥取市古市');
ok($zip->set_number('6800871')->is_valid_number, '鳥取県鳥取市吉成南町');
ok($zip->set_number('6800872')->is_valid_number, '鳥取県鳥取市宮長');
ok($zip->set_number('6800873')->is_valid_number, '鳥取県鳥取市的場');
ok($zip->set_number('6800874')->is_valid_number, '鳥取県鳥取市叶');
ok($zip->set_number('6800875')->is_valid_number, '鳥取県鳥取市数津');
ok($zip->set_number('6800901')->is_valid_number, '鳥取県鳥取市江津');
ok($zip->set_number('6800902')->is_valid_number, '鳥取県鳥取市秋里');
ok($zip->set_number('6800903')->is_valid_number, '鳥取県鳥取市南隈');
ok($zip->set_number('6800904')->is_valid_number, '鳥取県鳥取市晩稲');
ok($zip->set_number('6800905')->is_valid_number, '鳥取県鳥取市賀露町');
ok($zip->set_number('6800906')->is_valid_number, '鳥取県鳥取市港町');
ok($zip->set_number('6800907')->is_valid_number, '鳥取県鳥取市賀露町北');
ok($zip->set_number('6800908')->is_valid_number, '鳥取県鳥取市賀露町西');
ok($zip->set_number('6800909')->is_valid_number, '鳥取県鳥取市賀露町南');
ok($zip->set_number('6800911')->is_valid_number, '鳥取県鳥取市千代水');
ok($zip->set_number('6800912')->is_valid_number, '鳥取県鳥取市商栄町');
ok($zip->set_number('6800913')->is_valid_number, '鳥取県鳥取市安長');
ok($zip->set_number('6800914')->is_valid_number, '鳥取県鳥取市南安長');
ok($zip->set_number('6800915')->is_valid_number, '鳥取県鳥取市緑ケ丘');
ok($zip->set_number('6800921')->is_valid_number, '鳥取県鳥取市古海');
ok($zip->set_number('6800922')->is_valid_number, '鳥取県鳥取市菖蒲');
ok($zip->set_number('6800923')->is_valid_number, '鳥取県鳥取市服部');
ok($zip->set_number('6800924')->is_valid_number, '鳥取県鳥取市野寺');
ok($zip->set_number('6800931')->is_valid_number, '鳥取県鳥取市岩吉');
ok($zip->set_number('6800932')->is_valid_number, '鳥取県鳥取市五反田町');
ok($zip->set_number('6800933')->is_valid_number, '鳥取県鳥取市徳吉');
ok($zip->set_number('6800934')->is_valid_number, '鳥取県鳥取市徳尾');
ok($zip->set_number('6800935')->is_valid_number, '鳥取県鳥取市里仁');
ok($zip->set_number('6800941')->is_valid_number, '鳥取県鳥取市湖山町北');
ok($zip->set_number('6800942')->is_valid_number, '鳥取県鳥取市湖山町東');
ok($zip->set_number('6800943')->is_valid_number, '鳥取県鳥取市足山');
ok($zip->set_number('6800944')->is_valid_number, '鳥取県鳥取市布勢');
ok($zip->set_number('6800945')->is_valid_number, '鳥取県鳥取市湖山町南');
ok($zip->set_number('6800946')->is_valid_number, '鳥取県鳥取市湖山町');
ok($zip->set_number('6800947')->is_valid_number, '鳥取県鳥取市湖山町西');
ok($zip->set_number('6801131')->is_valid_number, '鳥取県鳥取市馬場');
ok($zip->set_number('6801132')->is_valid_number, '鳥取県鳥取市国安');
ok($zip->set_number('6801133')->is_valid_number, '鳥取県鳥取市源太');
ok($zip->set_number('6801141')->is_valid_number, '鳥取県鳥取市蔵田');
ok($zip->set_number('6801142')->is_valid_number, '鳥取県鳥取市橋本');
ok($zip->set_number('6801143')->is_valid_number, '鳥取県鳥取市八坂');
ok($zip->set_number('6801144')->is_valid_number, '鳥取県鳥取市円通寺');
ok($zip->set_number('6801145')->is_valid_number, '鳥取県鳥取市西円通寺');
ok($zip->set_number('6801146')->is_valid_number, '鳥取県鳥取市赤子田');
ok($zip->set_number('6801151')->is_valid_number, '鳥取県鳥取市倭文');
ok($zip->set_number('6801152')->is_valid_number, '鳥取県鳥取市玉津');
ok($zip->set_number('6801153')->is_valid_number, '鳥取県鳥取市長谷');
ok($zip->set_number('6801154')->is_valid_number, '鳥取県鳥取市下砂見');
ok($zip->set_number('6801155')->is_valid_number, '鳥取県鳥取市中砂見');
ok($zip->set_number('6801156')->is_valid_number, '鳥取県鳥取市上砂見');
ok($zip->set_number('6801157')->is_valid_number, '鳥取県鳥取市岩坪');
ok($zip->set_number('6801161')->is_valid_number, '鳥取県鳥取市向国安');
ok($zip->set_number('6801162')->is_valid_number, '鳥取県鳥取市竹生');
ok($zip->set_number('6801163')->is_valid_number, '鳥取県鳥取市横枕');
ok($zip->set_number('6801164')->is_valid_number, '鳥取県鳥取市猪子');
ok($zip->set_number('6801165')->is_valid_number, '鳥取県鳥取市下味野');
ok($zip->set_number('6801166')->is_valid_number, '鳥取県鳥取市朝月');
ok($zip->set_number('6801167')->is_valid_number, '鳥取県鳥取市上味野');
ok($zip->set_number('6801171')->is_valid_number, '鳥取県鳥取市本高');
ok($zip->set_number('6801172')->is_valid_number, '鳥取県鳥取市北村');
ok($zip->set_number('6801173')->is_valid_number, '鳥取県鳥取市西今在家');
ok($zip->set_number('6801174')->is_valid_number, '鳥取県鳥取市篠坂');
ok($zip->set_number('6801175')->is_valid_number, '鳥取県鳥取市中村');
ok($zip->set_number('6801176')->is_valid_number, '鳥取県鳥取市有富');
ok($zip->set_number('6801177')->is_valid_number, '鳥取県鳥取市高路');
ok($zip->set_number('6801201')->is_valid_number, '鳥取県鳥取市河原町袋河原');
ok($zip->set_number('6801202')->is_valid_number, '鳥取県鳥取市河原町布袋');
ok($zip->set_number('6801203')->is_valid_number, '鳥取県鳥取市河原町稲常');
ok($zip->set_number('6801204')->is_valid_number, '鳥取県鳥取市河原町片山');
ok($zip->set_number('6801205')->is_valid_number, '鳥取県鳥取市河原町今在家');
ok($zip->set_number('6801206')->is_valid_number, '鳥取県鳥取市河原町三谷');
ok($zip->set_number('6801207')->is_valid_number, '鳥取県鳥取市河原町郷原');
ok($zip->set_number('6801208')->is_valid_number, '鳥取県鳥取市河原町鮎ケ丘');
ok($zip->set_number('6801209')->is_valid_number, '鳥取県鳥取市河原町西円通寺');
ok($zip->set_number('6801211')->is_valid_number, '鳥取県鳥取市河原町山手');
ok($zip->set_number('6801212')->is_valid_number, '鳥取県鳥取市河原町徳吉');
ok($zip->set_number('6801213')->is_valid_number, '鳥取県鳥取市河原町高福');
ok($zip->set_number('6801214')->is_valid_number, '鳥取県鳥取市河原町八日市');
ok($zip->set_number('6801215')->is_valid_number, '鳥取県鳥取市河原町和奈見');
ok($zip->set_number('6801216')->is_valid_number, '鳥取県鳥取市河原町釜口');
ok($zip->set_number('6801221')->is_valid_number, '鳥取県鳥取市河原町渡一木');
ok($zip->set_number('6801222')->is_valid_number, '鳥取県鳥取市河原町曳田');
ok($zip->set_number('6801223')->is_valid_number, '鳥取県鳥取市河原町天神原');
ok($zip->set_number('6801224')->is_valid_number, '鳥取県鳥取市河原町中井');
ok($zip->set_number('6801225')->is_valid_number, '鳥取県鳥取市河原町牛戸');
ok($zip->set_number('6801231')->is_valid_number, '鳥取県鳥取市河原町湯谷');
ok($zip->set_number('6801232')->is_valid_number, '鳥取県鳥取市河原町小畑');
ok($zip->set_number('6801233')->is_valid_number, '鳥取県鳥取市河原町弓河内');
ok($zip->set_number('6801234')->is_valid_number, '鳥取県鳥取市河原町北村');
ok($zip->set_number('6801241')->is_valid_number, '鳥取県鳥取市河原町長瀬');
ok($zip->set_number('6801242')->is_valid_number, '鳥取県鳥取市河原町谷一木');
ok($zip->set_number('6801243')->is_valid_number, '鳥取県鳥取市河原町佐貫');
ok($zip->set_number('6801244')->is_valid_number, '鳥取県鳥取市河原町水根');
ok($zip->set_number('6801245')->is_valid_number, '鳥取県鳥取市河原町小倉');
ok($zip->set_number('6801246')->is_valid_number, '鳥取県鳥取市河原町山上');
ok($zip->set_number('6801251')->is_valid_number, '鳥取県鳥取市河原町河原');
ok($zip->set_number('6801252')->is_valid_number, '鳥取県鳥取市河原町本鹿');
ok($zip->set_number('6801253')->is_valid_number, '鳥取県鳥取市河原町小河内');
ok($zip->set_number('6801254')->is_valid_number, '鳥取県鳥取市河原町神馬');
ok($zip->set_number('6801411')->is_valid_number, '鳥取県鳥取市嶋');
ok($zip->set_number('6801412')->is_valid_number, '鳥取県鳥取市宮谷');
ok($zip->set_number('6801413')->is_valid_number, '鳥取県鳥取市野坂');
ok($zip->set_number('6801414')->is_valid_number, '鳥取県鳥取市下段');
ok($zip->set_number('6801415')->is_valid_number, '鳥取県鳥取市大塚');
ok($zip->set_number('6801416')->is_valid_number, '鳥取県鳥取市高住');
ok($zip->set_number('6801417')->is_valid_number, '鳥取県鳥取市桂見');
ok($zip->set_number('6801418')->is_valid_number, '鳥取県鳥取市大桷');
ok($zip->set_number('6801421')->is_valid_number, '鳥取県鳥取市上段');
ok($zip->set_number('6801422')->is_valid_number, '鳥取県鳥取市上原');
ok($zip->set_number('6801423')->is_valid_number, '鳥取県鳥取市松上');
ok($zip->set_number('6801424')->is_valid_number, '鳥取県鳥取市槇原');
ok($zip->set_number('6801425')->is_valid_number, '鳥取県鳥取市河内');
ok($zip->set_number('6801426')->is_valid_number, '鳥取県鳥取市細見');
ok($zip->set_number('6801427')->is_valid_number, '鳥取県鳥取市尾崎');
ok($zip->set_number('6801428')->is_valid_number, '鳥取県鳥取市三山口');
ok($zip->set_number('6801431')->is_valid_number, '鳥取県鳥取市妙徳寺');
ok($zip->set_number('6801432')->is_valid_number, '鳥取県鳥取市双六原');
ok($zip->set_number('6801433')->is_valid_number, '鳥取県鳥取市矢矯');
ok($zip->set_number('6801434')->is_valid_number, '鳥取県鳥取市洞谷');
ok($zip->set_number('6801435')->is_valid_number, '鳥取県鳥取市瀬田蔵');
ok($zip->set_number('6801436')->is_valid_number, '鳥取県鳥取市長柄');
ok($zip->set_number('6801437')->is_valid_number, '鳥取県鳥取市大畑');
ok($zip->set_number('6801438')->is_valid_number, '鳥取県鳥取市福井');
ok($zip->set_number('6801439')->is_valid_number, '鳥取県鳥取市金沢');
ok($zip->set_number('6801441')->is_valid_number, '鳥取県鳥取市良田');
ok($zip->set_number('6801442')->is_valid_number, '鳥取県鳥取市吉岡温泉町');
ok($zip->set_number('6801443')->is_valid_number, '鳥取県鳥取市六反田');
ok($zip->set_number('6801444')->is_valid_number, '鳥取県鳥取市松原');
ok($zip->set_number('6808021')->is_valid_number, '鳥取県鳥取市福部町久志羅(上野)');
ok($zip->set_number('6808022')->is_valid_number, '鳥取県鳥取市福部町左近(上野)');
ok($zip->set_number('6808062')->is_valid_number, '鳥取県鳥取市国府町稲葉丘');
ok($zip->set_number('6808063')->is_valid_number, '鳥取県鳥取市国府町奥谷');
ok($zip->set_number('6808064')->is_valid_number, '鳥取県鳥取市国府町分上');
ok($zip->set_number('6808065')->is_valid_number, '鳥取県鳥取市国府町新町');
ok($zip->set_number('6808066')->is_valid_number, '鳥取県鳥取市国府町新通り');
ok($zip->set_number('6810000')->is_valid_number, '鳥取県岩美郡岩美町以下に掲載がない場合');
ok($zip->set_number('6810001')->is_valid_number, '鳥取県岩美郡岩美町牧谷');
ok($zip->set_number('6810002')->is_valid_number, '鳥取県岩美郡岩美町相谷');
ok($zip->set_number('6810003')->is_valid_number, '鳥取県岩美郡岩美町浦富');
ok($zip->set_number('6810011')->is_valid_number, '鳥取県岩美郡岩美町陸上');
ok($zip->set_number('6810012')->is_valid_number, '鳥取県岩美郡岩美町田河内');
ok($zip->set_number('6810013')->is_valid_number, '鳥取県岩美郡岩美町小羽尾');
ok($zip->set_number('6810014')->is_valid_number, '鳥取県岩美郡岩美町大羽尾');
ok($zip->set_number('6810021')->is_valid_number, '鳥取県岩美郡岩美町長谷');
ok($zip->set_number('6810022')->is_valid_number, '鳥取県岩美郡岩美町白地');
ok($zip->set_number('6810023')->is_valid_number, '鳥取県岩美郡岩美町真名');
ok($zip->set_number('6810024')->is_valid_number, '鳥取県岩美郡岩美町岩井');
ok($zip->set_number('6810025')->is_valid_number, '鳥取県岩美郡岩美町宇治');
ok($zip->set_number('6810031')->is_valid_number, '鳥取県岩美郡岩美町蒲生');
ok($zip->set_number('6810032')->is_valid_number, '鳥取県岩美郡岩美町洗井');
ok($zip->set_number('6810033')->is_valid_number, '鳥取県岩美郡岩美町鳥越');
ok($zip->set_number('6810034')->is_valid_number, '鳥取県岩美郡岩美町銀山');
ok($zip->set_number('6810035')->is_valid_number, '鳥取県岩美郡岩美町馬場');
ok($zip->set_number('6810036')->is_valid_number, '鳥取県岩美郡岩美町相山');
ok($zip->set_number('6810041')->is_valid_number, '鳥取県岩美郡岩美町黒谷');
ok($zip->set_number('6810042')->is_valid_number, '鳥取県岩美郡岩美町小田');
ok($zip->set_number('6810043')->is_valid_number, '鳥取県岩美郡岩美町大坂');
ok($zip->set_number('6810044')->is_valid_number, '鳥取県岩美郡岩美町外邑');
ok($zip->set_number('6810045')->is_valid_number, '鳥取県岩美郡岩美町唐川');
ok($zip->set_number('6810046')->is_valid_number, '鳥取県岩美郡岩美町延興寺');
ok($zip->set_number('6810047')->is_valid_number, '鳥取県岩美郡岩美町池谷');
ok($zip->set_number('6810051')->is_valid_number, '鳥取県岩美郡岩美町河崎');
ok($zip->set_number('6810052')->is_valid_number, '鳥取県岩美郡岩美町岩常');
ok($zip->set_number('6810053')->is_valid_number, '鳥取県岩美郡岩美町高住');
ok($zip->set_number('6810054')->is_valid_number, '鳥取県岩美郡岩美町院内');
ok($zip->set_number('6810055')->is_valid_number, '鳥取県岩美郡岩美町荒金');
ok($zip->set_number('6810056')->is_valid_number, '鳥取県岩美郡岩美町長郷');
ok($zip->set_number('6810061')->is_valid_number, '鳥取県岩美郡岩美町高山');
ok($zip->set_number('6810062')->is_valid_number, '鳥取県岩美郡岩美町恩志');
ok($zip->set_number('6810063')->is_valid_number, '鳥取県岩美郡岩美町太田');
ok($zip->set_number('6810064')->is_valid_number, '鳥取県岩美郡岩美町本庄');
ok($zip->set_number('6810065')->is_valid_number, '鳥取県岩美郡岩美町新井');
ok($zip->set_number('6810071')->is_valid_number, '鳥取県岩美郡岩美町田後');
ok($zip->set_number('6810072')->is_valid_number, '鳥取県岩美郡岩美町岩本');
ok($zip->set_number('6810073')->is_valid_number, '鳥取県岩美郡岩美町大谷');
ok($zip->set_number('6810074')->is_valid_number, '鳥取県岩美郡岩美町網代');
ok($zip->set_number('6820000')->is_valid_number, '鳥取県倉吉市以下に掲載がない場合');
ok($zip->set_number('6820001')->is_valid_number, '鳥取県倉吉市穴窪');
ok($zip->set_number('6820002')->is_valid_number, '鳥取県倉吉市中江');
ok($zip->set_number('6820003')->is_valid_number, '鳥取県倉吉市新田');
ok($zip->set_number('6820004')->is_valid_number, '鳥取県倉吉市古川沢');
ok($zip->set_number('6820005')->is_valid_number, '鳥取県倉吉市下古川');
ok($zip->set_number('6820006')->is_valid_number, '鳥取県倉吉市井手畑');
ok($zip->set_number('6820011')->is_valid_number, '鳥取県倉吉市大塚');
ok($zip->set_number('6820012')->is_valid_number, '鳥取県倉吉市清谷');
ok($zip->set_number('6820013')->is_valid_number, '鳥取県倉吉市福庭');
ok($zip->set_number('6820014')->is_valid_number, '鳥取県倉吉市海田東町');
ok($zip->set_number('6820015')->is_valid_number, '鳥取県倉吉市海田南町');
ok($zip->set_number('6820016')->is_valid_number, '鳥取県倉吉市海田西町');
ok($zip->set_number('6820017')->is_valid_number, '鳥取県倉吉市清谷町');
ok($zip->set_number('6820018')->is_valid_number, '鳥取県倉吉市福庭町');
ok($zip->set_number('6820021')->is_valid_number, '鳥取県倉吉市上井');
ok($zip->set_number('6820022')->is_valid_number, '鳥取県倉吉市上井町');
ok($zip->set_number('6820023')->is_valid_number, '鳥取県倉吉市山根');
ok($zip->set_number('6820024')->is_valid_number, '鳥取県倉吉市伊木');
ok($zip->set_number('6820025')->is_valid_number, '鳥取県倉吉市八屋');
ok($zip->set_number('6820031')->is_valid_number, '鳥取県倉吉市下余戸');
ok($zip->set_number('6820032')->is_valid_number, '鳥取県倉吉市上余戸');
ok($zip->set_number('6820033')->is_valid_number, '鳥取県倉吉市栗尾');
ok($zip->set_number('6820034')->is_valid_number, '鳥取県倉吉市大原');
ok($zip->set_number('6820035')->is_valid_number, '鳥取県倉吉市広栄町');
ok($zip->set_number('6820036')->is_valid_number, '鳥取県倉吉市虹ケ丘町');
ok($zip->set_number('6820041')->is_valid_number, '鳥取県倉吉市河北町');
ok($zip->set_number('6820042')->is_valid_number, '鳥取県倉吉市大平町');
ok($zip->set_number('6820043')->is_valid_number, '鳥取県倉吉市天神町');
ok($zip->set_number('6820044')->is_valid_number, '鳥取県倉吉市小田');
ok($zip->set_number('6820045')->is_valid_number, '鳥取県倉吉市小田東');
ok($zip->set_number('6820100')->is_valid_number, '鳥取県東伯郡三朝町以下に掲載がない場合');
ok($zip->set_number('6820121')->is_valid_number, '鳥取県東伯郡三朝町大瀬');
ok($zip->set_number('6820122')->is_valid_number, '鳥取県東伯郡三朝町山田');
ok($zip->set_number('6820123')->is_valid_number, '鳥取県東伯郡三朝町恋谷');
ok($zip->set_number('6820123')->is_valid_number, '鳥取県東伯郡三朝町三朝');
ok($zip->set_number('6820124')->is_valid_number, '鳥取県東伯郡三朝町砂原');
ok($zip->set_number('6820125')->is_valid_number, '鳥取県東伯郡三朝町徳本');
ok($zip->set_number('6820125')->is_valid_number, '鳥取県東伯郡三朝町横手');
ok($zip->set_number('6820131')->is_valid_number, '鳥取県東伯郡三朝町俵原');
ok($zip->set_number('6820132')->is_valid_number, '鳥取県東伯郡三朝町三徳');
ok($zip->set_number('6820133')->is_valid_number, '鳥取県東伯郡三朝町桜ケ丘');
ok($zip->set_number('6820133')->is_valid_number, '鳥取県東伯郡三朝町吉田');
ok($zip->set_number('6820134')->is_valid_number, '鳥取県東伯郡三朝町余戸');
ok($zip->set_number('6820135')->is_valid_number, '鳥取県東伯郡三朝町片柴');
ok($zip->set_number('6820136')->is_valid_number, '鳥取県東伯郡三朝町坂本');
ok($zip->set_number('6820141')->is_valid_number, '鳥取県東伯郡三朝町中津');
ok($zip->set_number('6820142')->is_valid_number, '鳥取県東伯郡三朝町神倉');
ok($zip->set_number('6820143')->is_valid_number, '鳥取県東伯郡三朝町東小鹿');
ok($zip->set_number('6820144')->is_valid_number, '鳥取県東伯郡三朝町西小鹿');
ok($zip->set_number('6820145')->is_valid_number, '鳥取県東伯郡三朝町西尾');
ok($zip->set_number('6820146')->is_valid_number, '鳥取県東伯郡三朝町高橋');
ok($zip->set_number('6820151')->is_valid_number, '鳥取県東伯郡三朝町今泉');
ok($zip->set_number('6820151')->is_valid_number, '鳥取県東伯郡三朝町若宮');
ok($zip->set_number('6820152')->is_valid_number, '鳥取県東伯郡三朝町本泉');
ok($zip->set_number('6820153')->is_valid_number, '鳥取県東伯郡三朝町天神');
ok($zip->set_number('6820153')->is_valid_number, '鳥取県東伯郡三朝町森');
ok($zip->set_number('6820154')->is_valid_number, '鳥取県東伯郡三朝町鎌田');
ok($zip->set_number('6820155')->is_valid_number, '鳥取県東伯郡三朝町吉尾');
ok($zip->set_number('6820156')->is_valid_number, '鳥取県東伯郡三朝町下谷');
ok($zip->set_number('6820157')->is_valid_number, '鳥取県東伯郡三朝町小河内');
ok($zip->set_number('6820158')->is_valid_number, '鳥取県東伯郡三朝町笏賀');
ok($zip->set_number('6820159')->is_valid_number, '鳥取県東伯郡三朝町福田');
ok($zip->set_number('6820161')->is_valid_number, '鳥取県東伯郡三朝町柿谷');
ok($zip->set_number('6820162')->is_valid_number, '鳥取県東伯郡三朝町鉛山');
ok($zip->set_number('6820163')->is_valid_number, '鳥取県東伯郡三朝町福吉');
ok($zip->set_number('6820171')->is_valid_number, '鳥取県東伯郡三朝町湯谷');
ok($zip->set_number('6820172')->is_valid_number, '鳥取県東伯郡三朝町赤松');
ok($zip->set_number('6820173')->is_valid_number, '鳥取県東伯郡三朝町恩地');
ok($zip->set_number('6820176')->is_valid_number, '鳥取県東伯郡三朝町助谷');
ok($zip->set_number('6820177')->is_valid_number, '鳥取県東伯郡三朝町大柿');
ok($zip->set_number('6820178')->is_valid_number, '鳥取県東伯郡三朝町牧');
ok($zip->set_number('6820301')->is_valid_number, '鳥取県東伯郡三朝町木地山');
ok($zip->set_number('6820302')->is_valid_number, '鳥取県東伯郡三朝町加谷');
ok($zip->set_number('6820303')->is_valid_number, '鳥取県東伯郡三朝町穴鴨');
ok($zip->set_number('6820311')->is_valid_number, '鳥取県東伯郡三朝町福山');
ok($zip->set_number('6820312')->is_valid_number, '鳥取県東伯郡三朝町下西谷');
ok($zip->set_number('6820313')->is_valid_number, '鳥取県東伯郡三朝町上西谷');
ok($zip->set_number('6820314')->is_valid_number, '鳥取県東伯郡三朝町田代');
ok($zip->set_number('6820315')->is_valid_number, '鳥取県東伯郡三朝町大谷');
ok($zip->set_number('6820316')->is_valid_number, '鳥取県東伯郡三朝町下畑');
ok($zip->set_number('6820317')->is_valid_number, '鳥取県東伯郡三朝町福本');
ok($zip->set_number('6820374')->is_valid_number, '鳥取県東伯郡三朝町曹源寺');
ok($zip->set_number('6820375')->is_valid_number, '鳥取県東伯郡三朝町久原');
ok($zip->set_number('6820401')->is_valid_number, '鳥取県倉吉市関金町安歩');
ok($zip->set_number('6820402')->is_valid_number, '鳥取県倉吉市関金町大鳥居');
ok($zip->set_number('6820403')->is_valid_number, '鳥取県倉吉市関金町松河原');
ok($zip->set_number('6820404')->is_valid_number, '鳥取県倉吉市関金町泰久寺');
ok($zip->set_number('6820411')->is_valid_number, '鳥取県倉吉市関金町関金宿');
ok($zip->set_number('6820412')->is_valid_number, '鳥取県倉吉市関金町山口');
ok($zip->set_number('6820413')->is_valid_number, '鳥取県倉吉市関金町郡家');
ok($zip->set_number('6820421')->is_valid_number, '鳥取県倉吉市関金町今西');
ok($zip->set_number('6820422')->is_valid_number, '鳥取県倉吉市関金町堀');
ok($zip->set_number('6820423')->is_valid_number, '鳥取県倉吉市関金町明高');
ok($zip->set_number('6820431')->is_valid_number, '鳥取県倉吉市関金町米富');
ok($zip->set_number('6820432')->is_valid_number, '鳥取県倉吉市関金町福原');
ok($zip->set_number('6820433')->is_valid_number, '鳥取県倉吉市関金町小泉');
ok($zip->set_number('6820434')->is_valid_number, '鳥取県倉吉市関金町野添');
ok($zip->set_number('6820601')->is_valid_number, '鳥取県倉吉市下米積');
ok($zip->set_number('6820602')->is_valid_number, '鳥取県倉吉市上米積');
ok($zip->set_number('6820603')->is_valid_number, '鳥取県倉吉市三江');
ok($zip->set_number('6820604')->is_valid_number, '鳥取県倉吉市福本');
ok($zip->set_number('6820605')->is_valid_number, '鳥取県倉吉市福富');
ok($zip->set_number('6820606')->is_valid_number, '鳥取県倉吉市沢谷');
ok($zip->set_number('6820607')->is_valid_number, '鳥取県倉吉市尾田');
ok($zip->set_number('6820611')->is_valid_number, '鳥取県倉吉市杉野');
ok($zip->set_number('6820612')->is_valid_number, '鳥取県倉吉市中野');
ok($zip->set_number('6820613')->is_valid_number, '鳥取県倉吉市志津');
ok($zip->set_number('6820615')->is_valid_number, '鳥取県倉吉市森');
ok($zip->set_number('6820621')->is_valid_number, '鳥取県倉吉市忰谷');
ok($zip->set_number('6820622')->is_valid_number, '鳥取県倉吉市長谷');
ok($zip->set_number('6820623')->is_valid_number, '鳥取県倉吉市大河内');
ok($zip->set_number('6820624')->is_valid_number, '鳥取県倉吉市般若');
ok($zip->set_number('6820625')->is_valid_number, '鳥取県倉吉市椋波');
ok($zip->set_number('6820626')->is_valid_number, '鳥取県倉吉市立見');
ok($zip->set_number('6820631')->is_valid_number, '鳥取県倉吉市上大立');
ok($zip->set_number('6820632')->is_valid_number, '鳥取県倉吉市大立');
ok($zip->set_number('6820633')->is_valid_number, '鳥取県倉吉市河来見');
ok($zip->set_number('6820634')->is_valid_number, '鳥取県倉吉市桜');
ok($zip->set_number('6820635')->is_valid_number, '鳥取県倉吉市服部');
ok($zip->set_number('6820641')->is_valid_number, '鳥取県倉吉市今在家');
ok($zip->set_number('6820642')->is_valid_number, '鳥取県倉吉市上福田');
ok($zip->set_number('6820643')->is_valid_number, '鳥取県倉吉市下福田');
ok($zip->set_number('6820644')->is_valid_number, '鳥取県倉吉市福積');
ok($zip->set_number('6820645')->is_valid_number, '鳥取県倉吉市岡');
ok($zip->set_number('6820700')->is_valid_number, '鳥取県東伯郡湯梨浜町以下に掲載がない場合');
ok($zip->set_number('6820701')->is_valid_number, '鳥取県東伯郡湯梨浜町宇野');
ok($zip->set_number('6820702')->is_valid_number, '鳥取県東伯郡湯梨浜町橋津');
ok($zip->set_number('6820703')->is_valid_number, '鳥取県東伯郡湯梨浜町上橋津');
ok($zip->set_number('6820704')->is_valid_number, '鳥取県東伯郡湯梨浜町南谷');
ok($zip->set_number('6820711')->is_valid_number, '鳥取県東伯郡湯梨浜町下浅津');
ok($zip->set_number('6820712')->is_valid_number, '鳥取県東伯郡湯梨浜町上浅津');
ok($zip->set_number('6820713')->is_valid_number, '鳥取県東伯郡湯梨浜町光吉');
ok($zip->set_number('6820714')->is_valid_number, '鳥取県東伯郡湯梨浜町赤池');
ok($zip->set_number('6820715')->is_valid_number, '鳥取県東伯郡湯梨浜町はわい温泉');
ok($zip->set_number('6820721')->is_valid_number, '鳥取県東伯郡湯梨浜町田後');
ok($zip->set_number('6820722')->is_valid_number, '鳥取県東伯郡湯梨浜町はわい長瀬');
ok($zip->set_number('6820723')->is_valid_number, '鳥取県東伯郡湯梨浜町久留');
ok($zip->set_number('6820724')->is_valid_number, '鳥取県東伯郡湯梨浜町水下');
ok($zip->set_number('6820801')->is_valid_number, '鳥取県倉吉市巌城');
ok($zip->set_number('6820802')->is_valid_number, '鳥取県倉吉市東巌城町');
ok($zip->set_number('6820803')->is_valid_number, '鳥取県倉吉市見日町');
ok($zip->set_number('6820804')->is_valid_number, '鳥取県倉吉市東昭和町');
ok($zip->set_number('6820805')->is_valid_number, '鳥取県倉吉市南昭和町');
ok($zip->set_number('6820806')->is_valid_number, '鳥取県倉吉市昭和町');
ok($zip->set_number('6820807')->is_valid_number, '鳥取県倉吉市幸町');
ok($zip->set_number('6820811')->is_valid_number, '鳥取県倉吉市上灘町');
ok($zip->set_number('6820812')->is_valid_number, '鳥取県倉吉市下田中町');
ok($zip->set_number('6820813')->is_valid_number, '鳥取県倉吉市円谷町');
ok($zip->set_number('6820814')->is_valid_number, '鳥取県倉吉市米田町');
ok($zip->set_number('6820815')->is_valid_number, '鳥取県倉吉市新陽町');
ok($zip->set_number('6820816')->is_valid_number, '鳥取県倉吉市駄経寺町');
ok($zip->set_number('6820817')->is_valid_number, '鳥取県倉吉市住吉町');
ok($zip->set_number('6820821')->is_valid_number, '鳥取県倉吉市魚町');
ok($zip->set_number('6820822')->is_valid_number, '鳥取県倉吉市葵町');
ok($zip->set_number('6820823')->is_valid_number, '鳥取県倉吉市東町');
ok($zip->set_number('6820824')->is_valid_number, '鳥取県倉吉市仲ノ町');
ok($zip->set_number('6820825')->is_valid_number, '鳥取県倉吉市西仲町');
ok($zip->set_number('6820826')->is_valid_number, '鳥取県倉吉市東仲町');
ok($zip->set_number('6820831')->is_valid_number, '鳥取県倉吉市八幡町');
ok($zip->set_number('6820832')->is_valid_number, '鳥取県倉吉市富海');
ok($zip->set_number('6820833')->is_valid_number, '鳥取県倉吉市東鴨新町');
ok($zip->set_number('6820834')->is_valid_number, '鳥取県倉吉市東鴨');
ok($zip->set_number('6820835')->is_valid_number, '鳥取県倉吉市長坂町');
ok($zip->set_number('6820836')->is_valid_number, '鳥取県倉吉市長坂新町');
ok($zip->set_number('6820837')->is_valid_number, '鳥取県倉吉市下大江');
ok($zip->set_number('6820841')->is_valid_number, '鳥取県倉吉市大宮');
ok($zip->set_number('6820842')->is_valid_number, '鳥取県倉吉市岩倉');
ok($zip->set_number('6820843')->is_valid_number, '鳥取県倉吉市菅原');
ok($zip->set_number('6820844')->is_valid_number, '鳥取県倉吉市広瀬');
ok($zip->set_number('6820845')->is_valid_number, '鳥取県倉吉市耳');
ok($zip->set_number('6820846')->is_valid_number, '鳥取県倉吉市鴨河内');
ok($zip->set_number('6820847')->is_valid_number, '鳥取県倉吉市福山');
ok($zip->set_number('6820851')->is_valid_number, '鳥取県倉吉市西倉吉町');
ok($zip->set_number('6820852')->is_valid_number, '鳥取県倉吉市丸山町');
ok($zip->set_number('6820853')->is_valid_number, '鳥取県倉吉市余戸谷町');
ok($zip->set_number('6820854')->is_valid_number, '鳥取県倉吉市みどり町');
ok($zip->set_number('6820855')->is_valid_number, '鳥取県倉吉市生田');
ok($zip->set_number('6820856')->is_valid_number, '鳥取県倉吉市中河原');
ok($zip->set_number('6820857')->is_valid_number, '鳥取県倉吉市北野');
ok($zip->set_number('6820861')->is_valid_number, '鳥取県倉吉市新町');
ok($zip->set_number('6820862')->is_valid_number, '鳥取県倉吉市西町');
ok($zip->set_number('6820863')->is_valid_number, '鳥取県倉吉市瀬崎町');
ok($zip->set_number('6820864')->is_valid_number, '鳥取県倉吉市鍛冶町');
ok($zip->set_number('6820865')->is_valid_number, '鳥取県倉吉市越中町');
ok($zip->set_number('6820866')->is_valid_number, '鳥取県倉吉市広瀬町');
ok($zip->set_number('6820867')->is_valid_number, '鳥取県倉吉市越殿町');
ok($zip->set_number('6820871')->is_valid_number, '鳥取県倉吉市旭田町');
ok($zip->set_number('6820872')->is_valid_number, '鳥取県倉吉市福吉町');
ok($zip->set_number('6820873')->is_valid_number, '鳥取県倉吉市東岩倉町');
ok($zip->set_number('6820874')->is_valid_number, '鳥取県倉吉市西岩倉町');
ok($zip->set_number('6820875')->is_valid_number, '鳥取県倉吉市金森町');
ok($zip->set_number('6820881')->is_valid_number, '鳥取県倉吉市宮川町');
ok($zip->set_number('6820882')->is_valid_number, '鳥取県倉吉市湊町');
ok($zip->set_number('6820883')->is_valid_number, '鳥取県倉吉市荒神町');
ok($zip->set_number('6820884')->is_valid_number, '鳥取県倉吉市研屋町');
ok($zip->set_number('6820885')->is_valid_number, '鳥取県倉吉市堺町');
ok($zip->set_number('6820886')->is_valid_number, '鳥取県倉吉市大正町');
ok($zip->set_number('6820887')->is_valid_number, '鳥取県倉吉市明治町');
ok($zip->set_number('6820901')->is_valid_number, '鳥取県倉吉市穴沢');
ok($zip->set_number('6820902')->is_valid_number, '鳥取県倉吉市上神');
ok($zip->set_number('6820903')->is_valid_number, '鳥取県倉吉市北面');
ok($zip->set_number('6820904')->is_valid_number, '鳥取県倉吉市尾原');
ok($zip->set_number('6820905')->is_valid_number, '鳥取県倉吉市別所');
ok($zip->set_number('6820911')->is_valid_number, '鳥取県倉吉市寺谷');
ok($zip->set_number('6820912')->is_valid_number, '鳥取県倉吉市和田');
ok($zip->set_number('6820913')->is_valid_number, '鳥取県倉吉市和田東町');
ok($zip->set_number('6820914')->is_valid_number, '鳥取県倉吉市馬場町');
ok($zip->set_number('6820915')->is_valid_number, '鳥取県倉吉市不入岡');
ok($zip->set_number('6820921')->is_valid_number, '鳥取県倉吉市西福守町');
ok($zip->set_number('6820922')->is_valid_number, '鳥取県倉吉市福守町');
ok($zip->set_number('6820923')->is_valid_number, '鳥取県倉吉市鴨川町');
ok($zip->set_number('6820924')->is_valid_number, '鳥取県倉吉市河原町');
ok($zip->set_number('6820925')->is_valid_number, '鳥取県倉吉市秋喜');
ok($zip->set_number('6820926')->is_valid_number, '鳥取県倉吉市秋喜西町');
ok($zip->set_number('6820931')->is_valid_number, '鳥取県倉吉市小鴨');
ok($zip->set_number('6820932')->is_valid_number, '鳥取県倉吉市蔵内');
ok($zip->set_number('6820933')->is_valid_number, '鳥取県倉吉市石塚');
ok($zip->set_number('6820934')->is_valid_number, '鳥取県倉吉市上古川');
ok($zip->set_number('6820941')->is_valid_number, '鳥取県倉吉市大谷');
ok($zip->set_number('6820942')->is_valid_number, '鳥取県倉吉市国府');
ok($zip->set_number('6820943')->is_valid_number, '鳥取県倉吉市国分寺');
ok($zip->set_number('6820944')->is_valid_number, '鳥取県倉吉市福光');
ok($zip->set_number('6820945')->is_valid_number, '鳥取県倉吉市黒見');
ok($zip->set_number('6820946')->is_valid_number, '鳥取県倉吉市横田');
ok($zip->set_number('6820947')->is_valid_number, '鳥取県倉吉市大沢');
ok($zip->set_number('6820948')->is_valid_number, '鳥取県倉吉市大谷茶屋');
ok($zip->set_number('6820951')->is_valid_number, '鳥取県倉吉市津原');
ok($zip->set_number('6820952')->is_valid_number, '鳥取県倉吉市鋤');
ok($zip->set_number('6820953')->is_valid_number, '鳥取県倉吉市半坂');
ok($zip->set_number('6820954')->is_valid_number, '鳥取県倉吉市谷');
ok($zip->set_number('6830000')->is_valid_number, '鳥取県米子市以下に掲載がない場合');
ok($zip->set_number('6830001')->is_valid_number, '鳥取県米子市皆生温泉');
ok($zip->set_number('6830002')->is_valid_number, '鳥取県米子市皆生新田');
ok($zip->set_number('6830003')->is_valid_number, '鳥取県米子市皆生');
ok($zip->set_number('6830004')->is_valid_number, '鳥取県米子市上福原');
ok($zip->set_number('6830005')->is_valid_number, '鳥取県米子市中島');
ok($zip->set_number('6830006')->is_valid_number, '鳥取県米子市車尾');
ok($zip->set_number('6830007')->is_valid_number, '鳥取県米子市観音寺');
ok($zip->set_number('6830008')->is_valid_number, '鳥取県米子市車尾南');
ok($zip->set_number('6830009')->is_valid_number, '鳥取県米子市観音寺新町');
ok($zip->set_number('6830011')->is_valid_number, '鳥取県米子市福市');
ok($zip->set_number('6830012')->is_valid_number, '鳥取県米子市八幡');
ok($zip->set_number('6830013')->is_valid_number, '鳥取県米子市諏訪');
ok($zip->set_number('6830014')->is_valid_number, '鳥取県米子市永江');
ok($zip->set_number('6830015')->is_valid_number, '鳥取県米子市日原');
ok($zip->set_number('6830016')->is_valid_number, '鳥取県米子市奥谷');
ok($zip->set_number('6830017')->is_valid_number, '鳥取県米子市宗像');
ok($zip->set_number('6830021')->is_valid_number, '鳥取県米子市石井');
ok($zip->set_number('6830022')->is_valid_number, '鳥取県米子市奈喜良');
ok($zip->set_number('6830023')->is_valid_number, '鳥取県米子市橋本');
ok($zip->set_number('6830024')->is_valid_number, '鳥取県米子市吉谷');
ok($zip->set_number('6830025')->is_valid_number, '鳥取県米子市古市');
ok($zip->set_number('6830026')->is_valid_number, '鳥取県米子市新山');
ok($zip->set_number('6830027')->is_valid_number, '鳥取県米子市陰田町');
ok($zip->set_number('6830031')->is_valid_number, '鳥取県米子市東山町');
ok($zip->set_number('6830032')->is_valid_number, '鳥取県米子市陽田町');
ok($zip->set_number('6830033')->is_valid_number, '鳥取県米子市長砂町');
ok($zip->set_number('6830034')->is_valid_number, '鳥取県米子市美吉');
ok($zip->set_number('6830035')->is_valid_number, '鳥取県米子市目久美町');
ok($zip->set_number('6830036')->is_valid_number, '鳥取県米子市弥生町');
ok($zip->set_number('6830037')->is_valid_number, '鳥取県米子市昭和町');
ok($zip->set_number('6830041')->is_valid_number, '鳥取県米子市茶町');
ok($zip->set_number('6830042')->is_valid_number, '鳥取県米子市塩町');
ok($zip->set_number('6830043')->is_valid_number, '鳥取県米子市末広町');
ok($zip->set_number('6830044')->is_valid_number, '鳥取県米子市大工町');
ok($zip->set_number('6830045')->is_valid_number, '鳥取県米子市大谷町');
ok($zip->set_number('6830046')->is_valid_number, '鳥取県米子市愛宕町');
ok($zip->set_number('6830047')->is_valid_number, '鳥取県米子市祇園町');
ok($zip->set_number('6830051')->is_valid_number, '鳥取県米子市勝田町');
ok($zip->set_number('6830052')->is_valid_number, '鳥取県米子市博労町');
ok($zip->set_number('6830053')->is_valid_number, '鳥取県米子市明治町');
ok($zip->set_number('6830054')->is_valid_number, '鳥取県米子市糀町');
ok($zip->set_number('6830055')->is_valid_number, '鳥取県米子市冨士見町');
ok($zip->set_number('6830061')->is_valid_number, '鳥取県米子市四日市町');
ok($zip->set_number('6830062')->is_valid_number, '鳥取県米子市紺屋町');
ok($zip->set_number('6830063')->is_valid_number, '鳥取県米子市法勝寺町');
ok($zip->set_number('6830064')->is_valid_number, '鳥取県米子市道笑町');
ok($zip->set_number('6830065')->is_valid_number, '鳥取県米子市万能町');
ok($zip->set_number('6830066')->is_valid_number, '鳥取県米子市日野町');
ok($zip->set_number('6830067')->is_valid_number, '鳥取県米子市東町');
ok($zip->set_number('6830101')->is_valid_number, '鳥取県米子市大篠津町');
ok($zip->set_number('6830102')->is_valid_number, '鳥取県米子市和田町');
ok($zip->set_number('6830103')->is_valid_number, '鳥取県米子市富益町');
ok($zip->set_number('6830104')->is_valid_number, '鳥取県米子市大崎');
ok($zip->set_number('6830105')->is_valid_number, '鳥取県米子市葭津');
ok($zip->set_number('6830201')->is_valid_number, '鳥取県西伯郡南部町天万');
ok($zip->set_number('6830202')->is_valid_number, '鳥取県西伯郡南部町寺内');
ok($zip->set_number('6830203')->is_valid_number, '鳥取県西伯郡南部町三崎');
ok($zip->set_number('6830204')->is_valid_number, '鳥取県西伯郡南部町福里');
ok($zip->set_number('6830211')->is_valid_number, '鳥取県西伯郡南部町円山');
ok($zip->set_number('6830212')->is_valid_number, '鳥取県西伯郡南部町諸木');
ok($zip->set_number('6830213')->is_valid_number, '鳥取県西伯郡南部町西原');
ok($zip->set_number('6830214')->is_valid_number, '鳥取県西伯郡南部町田住');
ok($zip->set_number('6830215')->is_valid_number, '鳥取県西伯郡南部町荻名');
ok($zip->set_number('6830216')->is_valid_number, '鳥取県西伯郡南部町朝金');
ok($zip->set_number('6830217')->is_valid_number, '鳥取県西伯郡南部町鶴田');
ok($zip->set_number('6830218')->is_valid_number, '鳥取県西伯郡南部町池野');
ok($zip->set_number('6830221')->is_valid_number, '鳥取県西伯郡南部町宮前');
ok($zip->set_number('6830222')->is_valid_number, '鳥取県西伯郡南部町市山');
ok($zip->set_number('6830223')->is_valid_number, '鳥取県西伯郡南部町井上');
ok($zip->set_number('6830224')->is_valid_number, '鳥取県西伯郡南部町金田');
ok($zip->set_number('6830225')->is_valid_number, '鳥取県西伯郡南部町御内谷');
ok($zip->set_number('6830226')->is_valid_number, '鳥取県西伯郡南部町高姫');
ok($zip->set_number('6830227')->is_valid_number, '鳥取県西伯郡南部町浅井');
ok($zip->set_number('6830251')->is_valid_number, '鳥取県米子市兼久');
ok($zip->set_number('6830252')->is_valid_number, '鳥取県米子市青木');
ok($zip->set_number('6830253')->is_valid_number, '鳥取県米子市下安曇');
ok($zip->set_number('6830254')->is_valid_number, '鳥取県米子市別所');
ok($zip->set_number('6830255')->is_valid_number, '鳥取県米子市上安曇');
ok($zip->set_number('6830256')->is_valid_number, '鳥取県米子市大袋');
ok($zip->set_number('6830257')->is_valid_number, '鳥取県米子市榎原');
ok($zip->set_number('6830300')->is_valid_number, '鳥取県西伯郡南部町以下に掲載がない場合');
ok($zip->set_number('6830301')->is_valid_number, '鳥取県西伯郡南部町東町');
ok($zip->set_number('6830302')->is_valid_number, '鳥取県西伯郡南部町西町');
ok($zip->set_number('6830311')->is_valid_number, '鳥取県西伯郡南部町境');
ok($zip->set_number('6830312')->is_valid_number, '鳥取県西伯郡南部町福成');
ok($zip->set_number('6830321')->is_valid_number, '鳥取県西伯郡南部町清水川');
ok($zip->set_number('6830322')->is_valid_number, '鳥取県西伯郡南部町阿賀');
ok($zip->set_number('6830323')->is_valid_number, '鳥取県西伯郡南部町倭');
ok($zip->set_number('6830331')->is_valid_number, '鳥取県西伯郡南部町掛相');
ok($zip->set_number('6830332')->is_valid_number, '鳥取県西伯郡南部町馬佐良');
ok($zip->set_number('6830333')->is_valid_number, '鳥取県西伯郡南部町八金');
ok($zip->set_number('6830334')->is_valid_number, '鳥取県西伯郡南部町東上');
ok($zip->set_number('6830335')->is_valid_number, '鳥取県西伯郡南部町中');
ok($zip->set_number('6830336')->is_valid_number, '鳥取県西伯郡南部町福頼');
ok($zip->set_number('6830337')->is_valid_number, '鳥取県西伯郡南部町落合');
ok($zip->set_number('6830341')->is_valid_number, '鳥取県西伯郡南部町鴨部');
ok($zip->set_number('6830342')->is_valid_number, '鳥取県西伯郡南部町能竹');
ok($zip->set_number('6830343')->is_valid_number, '鳥取県西伯郡南部町下中谷');
ok($zip->set_number('6830344')->is_valid_number, '鳥取県西伯郡南部町上中谷');
ok($zip->set_number('6830345')->is_valid_number, '鳥取県西伯郡南部町大木屋');
ok($zip->set_number('6830351')->is_valid_number, '鳥取県西伯郡南部町法勝寺');
ok($zip->set_number('6830352')->is_valid_number, '鳥取県西伯郡南部町馬場');
ok($zip->set_number('6830353')->is_valid_number, '鳥取県西伯郡南部町徳長');
ok($zip->set_number('6830354')->is_valid_number, '鳥取県西伯郡南部町武信');
ok($zip->set_number('6830355')->is_valid_number, '鳥取県西伯郡南部町道河内');
ok($zip->set_number('6830356')->is_valid_number, '鳥取県西伯郡南部町伐株');
ok($zip->set_number('6830361')->is_valid_number, '鳥取県西伯郡南部町北方');
ok($zip->set_number('6830362')->is_valid_number, '鳥取県西伯郡南部町原');
ok($zip->set_number('6830363')->is_valid_number, '鳥取県西伯郡南部町西');
ok($zip->set_number('6830364')->is_valid_number, '鳥取県西伯郡南部町絹屋');
ok($zip->set_number('6830365')->is_valid_number, '鳥取県西伯郡南部町鍋倉');
ok($zip->set_number('6830366')->is_valid_number, '鳥取県西伯郡南部町与一谷');
ok($zip->set_number('6830367')->is_valid_number, '鳥取県西伯郡南部町猪小路');
ok($zip->set_number('6830801')->is_valid_number, '鳥取県米子市新開');
ok($zip->set_number('6830802')->is_valid_number, '鳥取県米子市東福原');
ok($zip->set_number('6830803')->is_valid_number, '鳥取県米子市日ノ出町');
ok($zip->set_number('6830804')->is_valid_number, '鳥取県米子市米原');
ok($zip->set_number('6830805')->is_valid_number, '鳥取県米子市西福原');
ok($zip->set_number('6830811')->is_valid_number, '鳥取県米子市錦町');
ok($zip->set_number('6830812')->is_valid_number, '鳥取県米子市角盤町');
ok($zip->set_number('6830813')->is_valid_number, '鳥取県米子市朝日町');
ok($zip->set_number('6830814')->is_valid_number, '鳥取県米子市尾高町');
ok($zip->set_number('6830815')->is_valid_number, '鳥取県米子市東倉吉町');
ok($zip->set_number('6830816')->is_valid_number, '鳥取県米子市西倉吉町');
ok($zip->set_number('6830821')->is_valid_number, '鳥取県米子市天神町');
ok($zip->set_number('6830822')->is_valid_number, '鳥取県米子市中町');
ok($zip->set_number('6830823')->is_valid_number, '鳥取県米子市加茂町');
ok($zip->set_number('6830824')->is_valid_number, '鳥取県米子市久米町');
ok($zip->set_number('6830825')->is_valid_number, '鳥取県米子市錦海町');
ok($zip->set_number('6830826')->is_valid_number, '鳥取県米子市西町');
ok($zip->set_number('6830831')->is_valid_number, '鳥取県米子市寺町');
ok($zip->set_number('6830832')->is_valid_number, '鳥取県米子市立町');
ok($zip->set_number('6830833')->is_valid_number, '鳥取県米子市岩倉町');
ok($zip->set_number('6830834')->is_valid_number, '鳥取県米子市内町');
ok($zip->set_number('6830835')->is_valid_number, '鳥取県米子市灘町');
ok($zip->set_number('6830836')->is_valid_number, '鳥取県米子市花園町');
ok($zip->set_number('6830841')->is_valid_number, '鳥取県米子市上後藤');
ok($zip->set_number('6830842')->is_valid_number, '鳥取県米子市三本松');
ok($zip->set_number('6830843')->is_valid_number, '鳥取県米子市三旗町');
ok($zip->set_number('6830844')->is_valid_number, '鳥取県米子市義方町');
ok($zip->set_number('6830845')->is_valid_number, '鳥取県米子市旗ヶ崎');
ok($zip->set_number('6830846')->is_valid_number, '鳥取県米子市安倍');
ok($zip->set_number('6830851')->is_valid_number, '鳥取県米子市夜見町');
ok($zip->set_number('6830852')->is_valid_number, '鳥取県米子市河崎');
ok($zip->set_number('6830853')->is_valid_number, '鳥取県米子市両三柳');
ok($zip->set_number('6830854')->is_valid_number, '鳥取県米子市彦名町');
ok($zip->set_number('6830855')->is_valid_number, '鳥取県米子市彦名新田');
ok($zip->set_number('6840000')->is_valid_number, '鳥取県境港市以下に掲載がない場合');
ok($zip->set_number('6840001')->is_valid_number, '鳥取県境港市清水町');
ok($zip->set_number('6840002')->is_valid_number, '鳥取県境港市弥生町');
ok($zip->set_number('6840003')->is_valid_number, '鳥取県境港市浜ノ町');
ok($zip->set_number('6840004')->is_valid_number, '鳥取県境港市大正町');
ok($zip->set_number('6840005')->is_valid_number, '鳥取県境港市松ケ枝町');
ok($zip->set_number('6840006')->is_valid_number, '鳥取県境港市栄町');
ok($zip->set_number('6840011')->is_valid_number, '鳥取県境港市相生町');
ok($zip->set_number('6840012')->is_valid_number, '鳥取県境港市中町');
ok($zip->set_number('6840013')->is_valid_number, '鳥取県境港市朝日町');
ok($zip->set_number('6840014')->is_valid_number, '鳥取県境港市入船町');
ok($zip->set_number('6840015')->is_valid_number, '鳥取県境港市東雲町');
ok($zip->set_number('6840016')->is_valid_number, '鳥取県境港市花町');
ok($zip->set_number('6840017')->is_valid_number, '鳥取県境港市岬町');
ok($zip->set_number('6840021')->is_valid_number, '鳥取県境港市馬場崎町');
ok($zip->set_number('6840022')->is_valid_number, '鳥取県境港市明治町');
ok($zip->set_number('6840023')->is_valid_number, '鳥取県境港市京町');
ok($zip->set_number('6840024')->is_valid_number, '鳥取県境港市日ノ出町');
ok($zip->set_number('6840025')->is_valid_number, '鳥取県境港市本町');
ok($zip->set_number('6840026')->is_valid_number, '鳥取県境港市末広町');
ok($zip->set_number('6840027')->is_valid_number, '鳥取県境港市東本町');
ok($zip->set_number('6840031')->is_valid_number, '鳥取県境港市湊町');
ok($zip->set_number('6840032')->is_valid_number, '鳥取県境港市元町');
ok($zip->set_number('6840033')->is_valid_number, '鳥取県境港市上道町');
ok($zip->set_number('6840034')->is_valid_number, '鳥取県境港市昭和町');
ok($zip->set_number('6840041')->is_valid_number, '鳥取県境港市中野町');
ok($zip->set_number('6840042')->is_valid_number, '鳥取県境港市福定町');
ok($zip->set_number('6840043')->is_valid_number, '鳥取県境港市竹内町');
ok($zip->set_number('6840044')->is_valid_number, '鳥取県境港市美保町');
ok($zip->set_number('6840045')->is_valid_number, '鳥取県境港市高松町');
ok($zip->set_number('6840046')->is_valid_number, '鳥取県境港市竹内団地');
ok($zip->set_number('6840051')->is_valid_number, '鳥取県境港市新屋町');
ok($zip->set_number('6840052')->is_valid_number, '鳥取県境港市麦垣町');
ok($zip->set_number('6840053')->is_valid_number, '鳥取県境港市小篠津町');
ok($zip->set_number('6840054')->is_valid_number, '鳥取県境港市財ノ木町');
ok($zip->set_number('6840055')->is_valid_number, '鳥取県境港市佐斐神町');
ok($zip->set_number('6840056')->is_valid_number, '鳥取県境港市幸神町');
ok($zip->set_number('6840061')->is_valid_number, '鳥取県境港市米川町');
ok($zip->set_number('6840062')->is_valid_number, '鳥取県境港市蓮池町');
ok($zip->set_number('6840063')->is_valid_number, '鳥取県境港市誠道町');
ok($zip->set_number('6840064')->is_valid_number, '鳥取県境港市三軒屋町');
ok($zip->set_number('6840065')->is_valid_number, '鳥取県境港市森岡町');
ok($zip->set_number('6840066')->is_valid_number, '鳥取県境港市芝町');
ok($zip->set_number('6840071')->is_valid_number, '鳥取県境港市外江町');
ok($zip->set_number('6840072')->is_valid_number, '鳥取県境港市渡町');
ok($zip->set_number('6840073')->is_valid_number, '鳥取県境港市中海干拓地');
ok($zip->set_number('6840074')->is_valid_number, '鳥取県境港市潮見町');
ok($zip->set_number('6840075')->is_valid_number, '鳥取県境港市西工業団地');
ok($zip->set_number('6840076')->is_valid_number, '鳥取県境港市夕日ケ丘');
ok($zip->set_number('6840100')->is_valid_number, '島根県隠岐郡知夫村以下に掲載がない場合');
ok($zip->set_number('6840101')->is_valid_number, '島根県隠岐郡知夫村大江');
ok($zip->set_number('6840102')->is_valid_number, '島根県隠岐郡知夫村郡');
ok($zip->set_number('6840103')->is_valid_number, '島根県隠岐郡知夫村多沢');
ok($zip->set_number('6840104')->is_valid_number, '島根県隠岐郡知夫村薄毛');
ok($zip->set_number('6840105')->is_valid_number, '島根県隠岐郡知夫村仁夫');
ok($zip->set_number('6840106')->is_valid_number, '島根県隠岐郡知夫村来居');
ok($zip->set_number('6840107')->is_valid_number, '島根県隠岐郡知夫村古海');
ok($zip->set_number('6840211')->is_valid_number, '島根県隠岐郡西ノ島町浦郷');
ok($zip->set_number('6840300')->is_valid_number, '島根県隠岐郡西ノ島町以下に掲載がない場合');
ok($zip->set_number('6840301')->is_valid_number, '島根県隠岐郡西ノ島町宇賀');
ok($zip->set_number('6840302')->is_valid_number, '島根県隠岐郡西ノ島町別府');
ok($zip->set_number('6840303')->is_valid_number, '島根県隠岐郡西ノ島町美田');
ok($zip->set_number('6840400')->is_valid_number, '島根県隠岐郡海士町以下に掲載がない場合');
ok($zip->set_number('6840401')->is_valid_number, '島根県隠岐郡海士町宇受賀');
ok($zip->set_number('6840402')->is_valid_number, '島根県隠岐郡海士町豊田');
ok($zip->set_number('6840403')->is_valid_number, '島根県隠岐郡海士町海士');
ok($zip->set_number('6840404')->is_valid_number, '島根県隠岐郡海士町福井');
ok($zip->set_number('6840411')->is_valid_number, '島根県隠岐郡海士町知々井');
ok($zip->set_number('6840412')->is_valid_number, '島根県隠岐郡海士町御波');
ok($zip->set_number('6840413')->is_valid_number, '島根県隠岐郡海士町崎');
ok($zip->set_number('6850000')->is_valid_number, '島根県隠岐郡隠岐の島町以下に掲載がない場合');
ok($zip->set_number('6850001')->is_valid_number, '島根県隠岐郡隠岐の島町大久');
ok($zip->set_number('6850002')->is_valid_number, '島根県隠岐郡隠岐の島町釜');
ok($zip->set_number('6850003')->is_valid_number, '島根県隠岐郡隠岐の島町犬来');
ok($zip->set_number('6850004')->is_valid_number, '島根県隠岐郡隠岐の島町飯田');
ok($zip->set_number('6850005')->is_valid_number, '島根県隠岐郡隠岐の島町東郷');
ok($zip->set_number('6850006')->is_valid_number, '島根県隠岐郡隠岐の島町有木');
ok($zip->set_number('6850007')->is_valid_number, '島根県隠岐郡隠岐の島町池田');
ok($zip->set_number('6850011')->is_valid_number, '島根県隠岐郡隠岐の島町栄町');
ok($zip->set_number('6850012')->is_valid_number, '島根県隠岐郡隠岐の島町東町');
ok($zip->set_number('6850013')->is_valid_number, '島根県隠岐郡隠岐の島町中町');
ok($zip->set_number('6850014')->is_valid_number, '島根県隠岐郡隠岐の島町西町');
ok($zip->set_number('6850015')->is_valid_number, '島根県隠岐郡隠岐の島町港町');
ok($zip->set_number('6850016')->is_valid_number, '島根県隠岐郡隠岐の島町城北町');
ok($zip->set_number('6850017')->is_valid_number, '島根県隠岐郡隠岐の島町下西');
ok($zip->set_number('6850021')->is_valid_number, '島根県隠岐郡隠岐の島町岬町');
ok($zip->set_number('6850022')->is_valid_number, '島根県隠岐郡隠岐の島町今津');
ok($zip->set_number('6850023')->is_valid_number, '島根県隠岐郡隠岐の島町西田');
ok($zip->set_number('6850024')->is_valid_number, '島根県隠岐郡隠岐の島町加茂');
ok($zip->set_number('6850025')->is_valid_number, '島根県隠岐郡隠岐の島町平');
ok($zip->set_number('6850026')->is_valid_number, '島根県隠岐郡隠岐の島町上西');
ok($zip->set_number('6850027')->is_valid_number, '島根県隠岐郡隠岐の島町原田');
ok($zip->set_number('6850101')->is_valid_number, '島根県隠岐郡隠岐の島町蔵田');
ok($zip->set_number('6850102')->is_valid_number, '島根県隠岐郡隠岐の島町油井');
ok($zip->set_number('6850103')->is_valid_number, '島根県隠岐郡隠岐の島町那久');
ok($zip->set_number('6850104')->is_valid_number, '島根県隠岐郡隠岐の島町都万');
ok($zip->set_number('6850105')->is_valid_number, '島根県隠岐郡隠岐の島町津戸');
ok($zip->set_number('6850106')->is_valid_number, '島根県隠岐郡隠岐の島町蛸木');
ok($zip->set_number('6850301')->is_valid_number, '島根県隠岐郡隠岐の島町北方');
ok($zip->set_number('6850302')->is_valid_number, '島根県隠岐郡隠岐の島町苗代田');
ok($zip->set_number('6850303')->is_valid_number, '島根県隠岐郡隠岐の島町南方');
ok($zip->set_number('6850304')->is_valid_number, '島根県隠岐郡隠岐の島町代');
ok($zip->set_number('6850305')->is_valid_number, '島根県隠岐郡隠岐の島町久見');
ok($zip->set_number('6850306')->is_valid_number, '島根県隠岐郡隠岐の島町伊後(向ケ丘)');
ok($zip->set_number('6850311')->is_valid_number, '島根県隠岐郡隠岐の島町郡');
ok($zip->set_number('6850312')->is_valid_number, '島根県隠岐郡隠岐の島町小路');
ok($zip->set_number('6850313')->is_valid_number, '島根県隠岐郡隠岐の島町那久路');
ok($zip->set_number('6850314')->is_valid_number, '島根県隠岐郡隠岐の島町山田');
ok($zip->set_number('6850411')->is_valid_number, '島根県隠岐郡隠岐の島町飯美');
ok($zip->set_number('6850412')->is_valid_number, '島根県隠岐郡隠岐の島町布施');
ok($zip->set_number('6850413')->is_valid_number, '島根県隠岐郡隠岐の島町卯敷');
ok($zip->set_number('6850431')->is_valid_number, '島根県隠岐郡隠岐の島町伊後(その他)');
ok($zip->set_number('6850432')->is_valid_number, '島根県隠岐郡隠岐の島町西村');
ok($zip->set_number('6850433')->is_valid_number, '島根県隠岐郡隠岐の島町湊');
ok($zip->set_number('6850434')->is_valid_number, '島根県隠岐郡隠岐の島町中村');
ok($zip->set_number('6850435')->is_valid_number, '島根県隠岐郡隠岐の島町元屋');
ok($zip->set_number('6890101')->is_valid_number, '鳥取県鳥取市福部町岩戸');
ok($zip->set_number('6890102')->is_valid_number, '鳥取県鳥取市福部町細川');
ok($zip->set_number('6890103')->is_valid_number, '鳥取県鳥取市福部町高江');
ok($zip->set_number('6890104')->is_valid_number, '鳥取県鳥取市福部町箭溪');
ok($zip->set_number('6890105')->is_valid_number, '鳥取県鳥取市福部町湯山');
ok($zip->set_number('6890106')->is_valid_number, '鳥取県鳥取市福部町海士');
ok($zip->set_number('6890111')->is_valid_number, '鳥取県鳥取市福部町栗谷');
ok($zip->set_number('6890112')->is_valid_number, '鳥取県鳥取市福部町蔵見');
ok($zip->set_number('6890113')->is_valid_number, '鳥取県鳥取市福部町久志羅(その他)');
ok($zip->set_number('6890114')->is_valid_number, '鳥取県鳥取市福部町左近(その他)');
ok($zip->set_number('6890115')->is_valid_number, '鳥取県鳥取市福部町八重原');
ok($zip->set_number('6890116')->is_valid_number, '鳥取県鳥取市福部町中');
ok($zip->set_number('6890117')->is_valid_number, '鳥取県鳥取市福部町南田');
ok($zip->set_number('6890201')->is_valid_number, '鳥取県鳥取市伏野');
ok($zip->set_number('6890202')->is_valid_number, '鳥取県鳥取市美萩野');
ok($zip->set_number('6890203')->is_valid_number, '鳥取県鳥取市三津');
ok($zip->set_number('6890204')->is_valid_number, '鳥取県鳥取市御熊');
ok($zip->set_number('6890205')->is_valid_number, '鳥取県鳥取市内海中');
ok($zip->set_number('6890206')->is_valid_number, '鳥取県鳥取市白兎');
ok($zip->set_number('6890207')->is_valid_number, '鳥取県鳥取市小沢見');
ok($zip->set_number('6890211')->is_valid_number, '鳥取県鳥取市気高町奥沢見');
ok($zip->set_number('6890212')->is_valid_number, '鳥取県鳥取市気高町常松');
ok($zip->set_number('6890213')->is_valid_number, '鳥取県鳥取市気高町下光元');
ok($zip->set_number('6890214')->is_valid_number, '鳥取県鳥取市気高町上光');
ok($zip->set_number('6890215')->is_valid_number, '鳥取県鳥取市気高町冨吉');
ok($zip->set_number('6890216')->is_valid_number, '鳥取県鳥取市気高町宝木');
ok($zip->set_number('6890217')->is_valid_number, '鳥取県鳥取市気高町酒津');
ok($zip->set_number('6890221')->is_valid_number, '鳥取県鳥取市気高町下坂本');
ok($zip->set_number('6890222')->is_valid_number, '鳥取県鳥取市気高町日光');
ok($zip->set_number('6890223')->is_valid_number, '鳥取県鳥取市気高町二本木');
ok($zip->set_number('6890224')->is_valid_number, '鳥取県鳥取市気高町重高');
ok($zip->set_number('6890225')->is_valid_number, '鳥取県鳥取市気高町土居');
ok($zip->set_number('6890226')->is_valid_number, '鳥取県鳥取市気高町宿');
ok($zip->set_number('6890331')->is_valid_number, '鳥取県鳥取市気高町浜村');
ok($zip->set_number('6890332')->is_valid_number, '鳥取県鳥取市気高町勝見');
ok($zip->set_number('6890333')->is_valid_number, '鳥取県鳥取市気高町新町');
ok($zip->set_number('6890334')->is_valid_number, '鳥取県鳥取市気高町北浜');
ok($zip->set_number('6890341')->is_valid_number, '鳥取県鳥取市気高町下石');
ok($zip->set_number('6890342')->is_valid_number, '鳥取県鳥取市気高町殿');
ok($zip->set_number('6890343')->is_valid_number, '鳥取県鳥取市気高町飯里');
ok($zip->set_number('6890344')->is_valid_number, '鳥取県鳥取市気高町上原');
ok($zip->set_number('6890345')->is_valid_number, '鳥取県鳥取市気高町山宮');
ok($zip->set_number('6890351')->is_valid_number, '鳥取県鳥取市気高町八幡');
ok($zip->set_number('6890352')->is_valid_number, '鳥取県鳥取市気高町高江');
ok($zip->set_number('6890353')->is_valid_number, '鳥取県鳥取市気高町郡家');
ok($zip->set_number('6890354')->is_valid_number, '鳥取県鳥取市気高町睦逢');
ok($zip->set_number('6890355')->is_valid_number, '鳥取県鳥取市気高町会下');
ok($zip->set_number('6890356')->is_valid_number, '鳥取県鳥取市気高町下原');
ok($zip->set_number('6890357')->is_valid_number, '鳥取県鳥取市気高町八束水');
ok($zip->set_number('6890401')->is_valid_number, '鳥取県鳥取市鹿野町広木');
ok($zip->set_number('6890402')->is_valid_number, '鳥取県鳥取市鹿野町閉野');
ok($zip->set_number('6890403')->is_valid_number, '鳥取県鳥取市鹿野町末用');
ok($zip->set_number('6890404')->is_valid_number, '鳥取県鳥取市鹿野町水谷');
ok($zip->set_number('6890405')->is_valid_number, '鳥取県鳥取市鹿野町鹿野');
ok($zip->set_number('6890411')->is_valid_number, '鳥取県鳥取市鹿野町鷲峯');
ok($zip->set_number('6890412')->is_valid_number, '鳥取県鳥取市鹿野町河内');
ok($zip->set_number('6890413')->is_valid_number, '鳥取県鳥取市鹿野町小別所');
ok($zip->set_number('6890421')->is_valid_number, '鳥取県鳥取市鹿野町乙亥正');
ok($zip->set_number('6890422')->is_valid_number, '鳥取県鳥取市鹿野町岡木');
ok($zip->set_number('6890423')->is_valid_number, '鳥取県鳥取市鹿野町中園');
ok($zip->set_number('6890424')->is_valid_number, '鳥取県鳥取市鹿野町宮方');
ok($zip->set_number('6890425')->is_valid_number, '鳥取県鳥取市鹿野町今市');
ok($zip->set_number('6890426')->is_valid_number, '鳥取県鳥取市鹿野町寺内');
ok($zip->set_number('6890501')->is_valid_number, '鳥取県鳥取市青谷町青谷');
ok($zip->set_number('6890511')->is_valid_number, '鳥取県鳥取市青谷町善田');
ok($zip->set_number('6890512')->is_valid_number, '鳥取県鳥取市青谷町養郷');
ok($zip->set_number('6890513')->is_valid_number, '鳥取県鳥取市青谷町蔵内');
ok($zip->set_number('6890514')->is_valid_number, '鳥取県鳥取市青谷町山根');
ok($zip->set_number('6890515')->is_valid_number, '鳥取県鳥取市青谷町河原');
ok($zip->set_number('6890516')->is_valid_number, '鳥取県鳥取市青谷町小畑');
ok($zip->set_number('6890517')->is_valid_number, '鳥取県鳥取市青谷町早牛');
ok($zip->set_number('6890518')->is_valid_number, '鳥取県鳥取市青谷町大坪');
ok($zip->set_number('6890519')->is_valid_number, '鳥取県鳥取市青谷町奥崎');
ok($zip->set_number('6890521')->is_valid_number, '鳥取県鳥取市青谷町露谷');
ok($zip->set_number('6890522')->is_valid_number, '鳥取県鳥取市青谷町亀尻');
ok($zip->set_number('6890523')->is_valid_number, '鳥取県鳥取市青谷町山田');
ok($zip->set_number('6890524')->is_valid_number, '鳥取県鳥取市青谷町八葉寺');
ok($zip->set_number('6890525')->is_valid_number, '鳥取県鳥取市青谷町田原谷');
ok($zip->set_number('6890526')->is_valid_number, '鳥取県鳥取市青谷町紙屋');
ok($zip->set_number('6890527')->is_valid_number, '鳥取県鳥取市青谷町楠根');
ok($zip->set_number('6890528')->is_valid_number, '鳥取県鳥取市青谷町澄水');
ok($zip->set_number('6890529')->is_valid_number, '鳥取県鳥取市青谷町桑原');
ok($zip->set_number('6890531')->is_valid_number, '鳥取県鳥取市青谷町鳴滝');
ok($zip->set_number('6890532')->is_valid_number, '鳥取県鳥取市青谷町北河原');
ok($zip->set_number('6890533')->is_valid_number, '鳥取県鳥取市青谷町絹見');
ok($zip->set_number('6890534')->is_valid_number, '鳥取県鳥取市青谷町吉川');
ok($zip->set_number('6890535')->is_valid_number, '鳥取県鳥取市青谷町井手');
ok($zip->set_number('6890536')->is_valid_number, '鳥取県鳥取市青谷町長和瀬');
ok($zip->set_number('6890537')->is_valid_number, '鳥取県鳥取市青谷町栄町');
ok($zip->set_number('6890601')->is_valid_number, '鳥取県東伯郡湯梨浜町泊');
ok($zip->set_number('6890602')->is_valid_number, '鳥取県東伯郡湯梨浜町石脇');
ok($zip->set_number('6890603')->is_valid_number, '鳥取県東伯郡湯梨浜町小浜');
ok($zip->set_number('6890604')->is_valid_number, '鳥取県東伯郡湯梨浜町筒地');
ok($zip->set_number('6890605')->is_valid_number, '鳥取県東伯郡湯梨浜町園');
ok($zip->set_number('6890606')->is_valid_number, '鳥取県東伯郡湯梨浜町原');
ok($zip->set_number('6890607')->is_valid_number, '鳥取県東伯郡湯梨浜町宇谷');
ok($zip->set_number('6890701')->is_valid_number, '鳥取県東伯郡湯梨浜町北福');
ok($zip->set_number('6890702')->is_valid_number, '鳥取県東伯郡湯梨浜町漆原');
ok($zip->set_number('6890703')->is_valid_number, '鳥取県東伯郡湯梨浜町方地');
ok($zip->set_number('6890704')->is_valid_number, '鳥取県東伯郡湯梨浜町白石');
ok($zip->set_number('6890705')->is_valid_number, '鳥取県東伯郡湯梨浜町野方');
ok($zip->set_number('6890706')->is_valid_number, '鳥取県東伯郡湯梨浜町藤津');
ok($zip->set_number('6890707')->is_valid_number, '鳥取県東伯郡湯梨浜町宮内');
ok($zip->set_number('6890711')->is_valid_number, '鳥取県東伯郡湯梨浜町松崎');
ok($zip->set_number('6890712')->is_valid_number, '鳥取県東伯郡湯梨浜町中興寺');
ok($zip->set_number('6890713')->is_valid_number, '鳥取県東伯郡湯梨浜町旭');
ok($zip->set_number('6890714')->is_valid_number, '鳥取県東伯郡湯梨浜町龍島');
ok($zip->set_number('6890715')->is_valid_number, '鳥取県東伯郡湯梨浜町引地');
ok($zip->set_number('6890721')->is_valid_number, '鳥取県東伯郡湯梨浜町麻畑');
ok($zip->set_number('6890722')->is_valid_number, '鳥取県東伯郡湯梨浜町川上');
ok($zip->set_number('6890723')->is_valid_number, '鳥取県東伯郡湯梨浜町高辻');
ok($zip->set_number('6890724')->is_valid_number, '鳥取県東伯郡湯梨浜町方面');
ok($zip->set_number('6890725')->is_valid_number, '鳥取県東伯郡湯梨浜町別所');
ok($zip->set_number('6890726')->is_valid_number, '鳥取県東伯郡湯梨浜町国信');
ok($zip->set_number('6890727')->is_valid_number, '鳥取県東伯郡湯梨浜町田畑');
ok($zip->set_number('6890728')->is_valid_number, '鳥取県東伯郡湯梨浜町久見');
ok($zip->set_number('6890729')->is_valid_number, '鳥取県東伯郡湯梨浜町小鹿谷');
ok($zip->set_number('6890731')->is_valid_number, '鳥取県東伯郡湯梨浜町野花');
ok($zip->set_number('6890732')->is_valid_number, '鳥取県東伯郡湯梨浜町長和田');
ok($zip->set_number('6890733')->is_valid_number, '鳥取県東伯郡湯梨浜町羽衣石');
ok($zip->set_number('6890734')->is_valid_number, '鳥取県東伯郡湯梨浜町埴見');
ok($zip->set_number('6890735')->is_valid_number, '鳥取県東伯郡湯梨浜町佐美');
ok($zip->set_number('6890736')->is_valid_number, '鳥取県東伯郡湯梨浜町門田');
ok($zip->set_number('6890737')->is_valid_number, '鳥取県東伯郡湯梨浜町長江');
ok($zip->set_number('6891101')->is_valid_number, '鳥取県鳥取市杉崎');
ok($zip->set_number('6891102')->is_valid_number, '鳥取県鳥取市津ノ井');
ok($zip->set_number('6891103')->is_valid_number, '鳥取県鳥取市生山');
ok($zip->set_number('6891104')->is_valid_number, '鳥取県鳥取市桂木');
ok($zip->set_number('6891105')->is_valid_number, '鳥取県鳥取市東大路');
ok($zip->set_number('6891106')->is_valid_number, '鳥取県鳥取市中大路');
ok($zip->set_number('6891107')->is_valid_number, '鳥取県鳥取市西大路');
ok($zip->set_number('6891111')->is_valid_number, '鳥取県鳥取市若葉台北');
ok($zip->set_number('6891112')->is_valid_number, '鳥取県鳥取市若葉台南');
ok($zip->set_number('6891113')->is_valid_number, '鳥取県鳥取市祢宜谷');
ok($zip->set_number('6891114')->is_valid_number, '鳥取県鳥取市香取');
ok($zip->set_number('6891115')->is_valid_number, '鳥取県鳥取市紙子谷');
ok($zip->set_number('6891116')->is_valid_number, '鳥取県鳥取市広岡');
ok($zip->set_number('6891117')->is_valid_number, '鳥取県鳥取市海蔵寺');
ok($zip->set_number('6891121')->is_valid_number, '鳥取県鳥取市南栄町');
ok($zip->set_number('6891122')->is_valid_number, '鳥取県鳥取市船木');
ok($zip->set_number('6891123')->is_valid_number, '鳥取県鳥取市久末');
ok($zip->set_number('6891124')->is_valid_number, '鳥取県鳥取市越路');
ok($zip->set_number('6891125')->is_valid_number, '鳥取県鳥取市古郡家');
ok($zip->set_number('6891126')->is_valid_number, '鳥取県鳥取市美和');
ok($zip->set_number('6891201')->is_valid_number, '鳥取県鳥取市用瀬町用瀬');
ok($zip->set_number('6891211')->is_valid_number, '鳥取県鳥取市用瀬町別府');
ok($zip->set_number('6891212')->is_valid_number, '鳥取県鳥取市用瀬町美成');
ok($zip->set_number('6891213')->is_valid_number, '鳥取県鳥取市用瀬町鷹狩');
ok($zip->set_number('6891214')->is_valid_number, '鳥取県鳥取市用瀬町旭ケ丘');
ok($zip->set_number('6891215')->is_valid_number, '鳥取県鳥取市用瀬町赤波');
ok($zip->set_number('6891221')->is_valid_number, '鳥取県鳥取市用瀬町古用瀬');
ok($zip->set_number('6891222')->is_valid_number, '鳥取県鳥取市用瀬町家奥');
ok($zip->set_number('6891223')->is_valid_number, '鳥取県鳥取市用瀬町金屋');
ok($zip->set_number('6891224')->is_valid_number, '鳥取県鳥取市用瀬町樟原');
ok($zip->set_number('6891225')->is_valid_number, '鳥取県鳥取市用瀬町宮原');
ok($zip->set_number('6891226')->is_valid_number, '鳥取県鳥取市用瀬町川中');
ok($zip->set_number('6891227')->is_valid_number, '鳥取県鳥取市用瀬町安蔵');
ok($zip->set_number('6891228')->is_valid_number, '鳥取県鳥取市用瀬町屋住');
ok($zip->set_number('6891229')->is_valid_number, '鳥取県鳥取市用瀬町江波');
ok($zip->set_number('6891301')->is_valid_number, '鳥取県鳥取市佐治町葛谷');
ok($zip->set_number('6891302')->is_valid_number, '鳥取県鳥取市佐治町小原');
ok($zip->set_number('6891303')->is_valid_number, '鳥取県鳥取市佐治町刈地');
ok($zip->set_number('6891304')->is_valid_number, '鳥取県鳥取市佐治町大井');
ok($zip->set_number('6891305')->is_valid_number, '鳥取県鳥取市佐治町森坪');
ok($zip->set_number('6891306')->is_valid_number, '鳥取県鳥取市佐治町古市');
ok($zip->set_number('6891307')->is_valid_number, '鳥取県鳥取市佐治町津無');
ok($zip->set_number('6891311')->is_valid_number, '鳥取県鳥取市佐治町津野');
ok($zip->set_number('6891312')->is_valid_number, '鳥取県鳥取市佐治町高山');
ok($zip->set_number('6891313')->is_valid_number, '鳥取県鳥取市佐治町加瀬木');
ok($zip->set_number('6891314')->is_valid_number, '鳥取県鳥取市佐治町加茂');
ok($zip->set_number('6891315')->is_valid_number, '鳥取県鳥取市佐治町畑');
ok($zip->set_number('6891316')->is_valid_number, '鳥取県鳥取市佐治町福園');
ok($zip->set_number('6891321')->is_valid_number, '鳥取県鳥取市佐治町河本');
ok($zip->set_number('6891322')->is_valid_number, '鳥取県鳥取市佐治町つく谷');
ok($zip->set_number('6891323')->is_valid_number, '鳥取県鳥取市佐治町余戸');
ok($zip->set_number('6891324')->is_valid_number, '鳥取県鳥取市佐治町尾際');
ok($zip->set_number('6891325')->is_valid_number, '鳥取県鳥取市佐治町中');
ok($zip->set_number('6891326')->is_valid_number, '鳥取県鳥取市佐治町栃原');
ok($zip->set_number('6891400')->is_valid_number, '鳥取県八頭郡智頭町以下に掲載がない場合');
ok($zip->set_number('6891401')->is_valid_number, '鳥取県八頭郡智頭町市瀬');
ok($zip->set_number('6891402')->is_valid_number, '鳥取県八頭郡智頭町智頭');
ok($zip->set_number('6891403')->is_valid_number, '鳥取県八頭郡智頭町南方');
ok($zip->set_number('6891404')->is_valid_number, '鳥取県八頭郡智頭町岩神');
ok($zip->set_number('6891411')->is_valid_number, '鳥取県八頭郡智頭町八河谷');
ok($zip->set_number('6891412')->is_valid_number, '鳥取県八頭郡智頭町芦津');
ok($zip->set_number('6891413')->is_valid_number, '鳥取県八頭郡智頭町大呂');
ok($zip->set_number('6891414')->is_valid_number, '鳥取県八頭郡智頭町西野');
ok($zip->set_number('6891415')->is_valid_number, '鳥取県八頭郡智頭町郷原');
ok($zip->set_number('6891416')->is_valid_number, '鳥取県八頭郡智頭町毛谷');
ok($zip->set_number('6891417')->is_valid_number, '鳥取県八頭郡智頭町篠坂');
ok($zip->set_number('6891421')->is_valid_number, '鳥取県八頭郡智頭町大内');
ok($zip->set_number('6891422')->is_valid_number, '鳥取県八頭郡智頭町尾見');
ok($zip->set_number('6891423')->is_valid_number, '鳥取県八頭郡智頭町中原');
ok($zip->set_number('6891424')->is_valid_number, '鳥取県八頭郡智頭町駒帰');
ok($zip->set_number('6891425')->is_valid_number, '鳥取県八頭郡智頭町福原');
ok($zip->set_number('6891426')->is_valid_number, '鳥取県八頭郡智頭町西谷');
ok($zip->set_number('6891431')->is_valid_number, '鳥取県八頭郡智頭町山根');
ok($zip->set_number('6891432')->is_valid_number, '鳥取県八頭郡智頭町穂見');
ok($zip->set_number('6891433')->is_valid_number, '鳥取県八頭郡智頭町埴師');
ok($zip->set_number('6891434')->is_valid_number, '鳥取県八頭郡智頭町三吉');
ok($zip->set_number('6891435')->is_valid_number, '鳥取県八頭郡智頭町横田');
ok($zip->set_number('6891436')->is_valid_number, '鳥取県八頭郡智頭町木原');
ok($zip->set_number('6891437')->is_valid_number, '鳥取県八頭郡智頭町三田');
ok($zip->set_number('6891441')->is_valid_number, '鳥取県八頭郡智頭町慶所');
ok($zip->set_number('6891442')->is_valid_number, '鳥取県八頭郡智頭町大屋');
ok($zip->set_number('6891443')->is_valid_number, '鳥取県八頭郡智頭町真鹿野');
ok($zip->set_number('6891444')->is_valid_number, '鳥取県八頭郡智頭町野原');
ok($zip->set_number('6891445')->is_valid_number, '鳥取県八頭郡智頭町早瀬');
ok($zip->set_number('6891451')->is_valid_number, '鳥取県八頭郡智頭町大背');
ok($zip->set_number('6891452')->is_valid_number, '鳥取県八頭郡智頭町奥本');
ok($zip->set_number('6891453')->is_valid_number, '鳥取県八頭郡智頭町東宇塚');
ok($zip->set_number('6891454')->is_valid_number, '鳥取県八頭郡智頭町河津原');
ok($zip->set_number('6891455')->is_valid_number, '鳥取県八頭郡智頭町西宇塚');
ok($zip->set_number('6891461')->is_valid_number, '鳥取県八頭郡智頭町坂原');
ok($zip->set_number('6891462')->is_valid_number, '鳥取県八頭郡智頭町中田');
ok($zip->set_number('6891463')->is_valid_number, '鳥取県八頭郡智頭町新見');
ok($zip->set_number('6891464')->is_valid_number, '鳥取県八頭郡智頭町口宇波');
ok($zip->set_number('6891465')->is_valid_number, '鳥取県八頭郡智頭町宇波');
ok($zip->set_number('6891466')->is_valid_number, '鳥取県八頭郡智頭町波多');
ok($zip->set_number('6891467')->is_valid_number, '鳥取県八頭郡智頭町口波多');
ok($zip->set_number('6891468')->is_valid_number, '鳥取県八頭郡智頭町惣地');
ok($zip->set_number('6892101')->is_valid_number, '鳥取県東伯郡北栄町江北');
ok($zip->set_number('6892102')->is_valid_number, '鳥取県東伯郡北栄町国坂');
ok($zip->set_number('6892103')->is_valid_number, '鳥取県東伯郡北栄町田井');
ok($zip->set_number('6892104')->is_valid_number, '鳥取県東伯郡北栄町弓原');
ok($zip->set_number('6892105')->is_valid_number, '鳥取県東伯郡北栄町下神');
ok($zip->set_number('6892106')->is_valid_number, '鳥取県東伯郡北栄町松神');
ok($zip->set_number('6892111')->is_valid_number, '鳥取県東伯郡北栄町土下');
ok($zip->set_number('6892112')->is_valid_number, '鳥取県東伯郡北栄町北条島');
ok($zip->set_number('6892113')->is_valid_number, '鳥取県東伯郡北栄町米里');
ok($zip->set_number('6892114')->is_valid_number, '鳥取県東伯郡北栄町北尾');
ok($zip->set_number('6892115')->is_valid_number, '鳥取県東伯郡北栄町曲');
ok($zip->set_number('6892200')->is_valid_number, '鳥取県東伯郡北栄町以下に掲載がない場合');
ok($zip->set_number('6892201')->is_valid_number, '鳥取県東伯郡北栄町西園');
ok($zip->set_number('6892202')->is_valid_number, '鳥取県東伯郡北栄町東園');
ok($zip->set_number('6892203')->is_valid_number, '鳥取県東伯郡北栄町原');
ok($zip->set_number('6892204')->is_valid_number, '鳥取県東伯郡北栄町穂波');
ok($zip->set_number('6892205')->is_valid_number, '鳥取県東伯郡北栄町瀬戸');
ok($zip->set_number('6892206')->is_valid_number, '鳥取県東伯郡北栄町大島');
ok($zip->set_number('6892207')->is_valid_number, '鳥取県東伯郡北栄町西穂波');
ok($zip->set_number('6892208')->is_valid_number, '鳥取県東伯郡北栄町六尾');
ok($zip->set_number('6892211')->is_valid_number, '鳥取県東伯郡北栄町亀谷');
ok($zip->set_number('6892212')->is_valid_number, '鳥取県東伯郡北栄町下種');
ok($zip->set_number('6892213')->is_valid_number, '鳥取県東伯郡北栄町上種');
ok($zip->set_number('6892214')->is_valid_number, '鳥取県東伯郡北栄町東高尾');
ok($zip->set_number('6892215')->is_valid_number, '鳥取県東伯郡北栄町西高尾');
ok($zip->set_number('6892216')->is_valid_number, '鳥取県東伯郡北栄町岩坪');
ok($zip->set_number('6892221')->is_valid_number, '鳥取県東伯郡北栄町由良宿');
ok($zip->set_number('6892223')->is_valid_number, '鳥取県東伯郡北栄町大谷');
ok($zip->set_number('6892224')->is_valid_number, '鳥取県東伯郡北栄町妻波');
ok($zip->set_number('6892300')->is_valid_number, '鳥取県東伯郡琴浦町以下に掲載がない場合');
ok($zip->set_number('6892301')->is_valid_number, '鳥取県東伯郡琴浦町八橋');
ok($zip->set_number('6892302')->is_valid_number, '鳥取県東伯郡琴浦町丸尾');
ok($zip->set_number('6892303')->is_valid_number, '鳥取県東伯郡琴浦町徳万');
ok($zip->set_number('6892304')->is_valid_number, '鳥取県東伯郡琴浦町逢束');
ok($zip->set_number('6892305')->is_valid_number, '鳥取県東伯郡琴浦町槻下');
ok($zip->set_number('6892306')->is_valid_number, '鳥取県東伯郡琴浦町笠見');
ok($zip->set_number('6892311')->is_valid_number, '鳥取県東伯郡琴浦町中尾');
ok($zip->set_number('6892312')->is_valid_number, '鳥取県東伯郡琴浦町金屋');
ok($zip->set_number('6892313')->is_valid_number, '鳥取県東伯郡琴浦町杉下');
ok($zip->set_number('6892314')->is_valid_number, '鳥取県東伯郡琴浦町下大江');
ok($zip->set_number('6892315')->is_valid_number, '鳥取県東伯郡琴浦町上伊勢');
ok($zip->set_number('6892316')->is_valid_number, '鳥取県東伯郡琴浦町下伊勢');
ok($zip->set_number('6892321')->is_valid_number, '鳥取県東伯郡琴浦町森藤');
ok($zip->set_number('6892322')->is_valid_number, '鳥取県東伯郡琴浦町八反田');
ok($zip->set_number('6892323')->is_valid_number, '鳥取県東伯郡琴浦町宮場');
ok($zip->set_number('6892324')->is_valid_number, '鳥取県東伯郡琴浦町矢下');
ok($zip->set_number('6892325')->is_valid_number, '鳥取県東伯郡琴浦町法万');
ok($zip->set_number('6892326')->is_valid_number, '鳥取県東伯郡琴浦町光好');
ok($zip->set_number('6892331')->is_valid_number, '鳥取県東伯郡琴浦町杉地');
ok($zip->set_number('6892332')->is_valid_number, '鳥取県東伯郡琴浦町古長');
ok($zip->set_number('6892333')->is_valid_number, '鳥取県東伯郡琴浦町別宮');
ok($zip->set_number('6892334')->is_valid_number, '鳥取県東伯郡琴浦町三本杉');
ok($zip->set_number('6892335')->is_valid_number, '鳥取県東伯郡琴浦町中津原');
ok($zip->set_number('6892336')->is_valid_number, '鳥取県東伯郡琴浦町野井倉');
ok($zip->set_number('6892341')->is_valid_number, '鳥取県東伯郡琴浦町倉坂');
ok($zip->set_number('6892342')->is_valid_number, '鳥取県東伯郡琴浦町公文');
ok($zip->set_number('6892343')->is_valid_number, '鳥取県東伯郡琴浦町山田');
ok($zip->set_number('6892344')->is_valid_number, '鳥取県東伯郡琴浦町大杉');
ok($zip->set_number('6892345')->is_valid_number, '鳥取県東伯郡琴浦町福永');
ok($zip->set_number('6892346')->is_valid_number, '鳥取県東伯郡琴浦町野田');
ok($zip->set_number('6892351')->is_valid_number, '鳥取県東伯郡琴浦町保');
ok($zip->set_number('6892352')->is_valid_number, '鳥取県東伯郡琴浦町浦安');
ok($zip->set_number('6892353')->is_valid_number, '鳥取県東伯郡琴浦町三保');
ok($zip->set_number('6892354')->is_valid_number, '鳥取県東伯郡琴浦町美好');
ok($zip->set_number('6892355')->is_valid_number, '鳥取県東伯郡琴浦町釛');
ok($zip->set_number('6892356')->is_valid_number, '鳥取県東伯郡琴浦町田越');
ok($zip->set_number('6892501')->is_valid_number, '鳥取県東伯郡琴浦町赤碕');
ok($zip->set_number('6892502')->is_valid_number, '鳥取県東伯郡琴浦町別所');
ok($zip->set_number('6892503')->is_valid_number, '鳥取県東伯郡琴浦町松谷');
ok($zip->set_number('6892511')->is_valid_number, '鳥取県東伯郡琴浦町出上');
ok($zip->set_number('6892512')->is_valid_number, '鳥取県東伯郡琴浦町勝田');
ok($zip->set_number('6892513')->is_valid_number, '鳥取県東伯郡琴浦町西宮');
ok($zip->set_number('6892521')->is_valid_number, '鳥取県東伯郡琴浦町竹内');
ok($zip->set_number('6892522')->is_valid_number, '鳥取県東伯郡琴浦町宮木');
ok($zip->set_number('6892523')->is_valid_number, '鳥取県東伯郡琴浦町高岡');
ok($zip->set_number('6892524')->is_valid_number, '鳥取県東伯郡琴浦町大父');
ok($zip->set_number('6892525')->is_valid_number, '鳥取県東伯郡琴浦町山川');
ok($zip->set_number('6892531')->is_valid_number, '鳥取県東伯郡琴浦町佐崎');
ok($zip->set_number('6892532')->is_valid_number, '鳥取県東伯郡琴浦町太一垣');
ok($zip->set_number('6892533')->is_valid_number, '鳥取県東伯郡琴浦町中村');
ok($zip->set_number('6892534')->is_valid_number, '鳥取県東伯郡琴浦町光');
ok($zip->set_number('6892535')->is_valid_number, '鳥取県東伯郡琴浦町尾張');
ok($zip->set_number('6892541')->is_valid_number, '鳥取県東伯郡琴浦町八幡');
ok($zip->set_number('6892542')->is_valid_number, '鳥取県東伯郡琴浦町湯坂');
ok($zip->set_number('6892543')->is_valid_number, '鳥取県東伯郡琴浦町梅田');
ok($zip->set_number('6892544')->is_valid_number, '鳥取県東伯郡琴浦町箆津');
ok($zip->set_number('6893101')->is_valid_number, '鳥取県西伯郡大山町潮音寺');
ok($zip->set_number('6893102')->is_valid_number, '鳥取県西伯郡大山町石井垣');
ok($zip->set_number('6893103')->is_valid_number, '鳥取県西伯郡大山町樋口');
ok($zip->set_number('6893104')->is_valid_number, '鳥取県西伯郡大山町八重');
ok($zip->set_number('6893105')->is_valid_number, '鳥取県西伯郡大山町束積');
ok($zip->set_number('6893106')->is_valid_number, '鳥取県西伯郡大山町羽田井');
ok($zip->set_number('6893111')->is_valid_number, '鳥取県西伯郡大山町赤坂');
ok($zip->set_number('6893112')->is_valid_number, '鳥取県西伯郡大山町下甲');
ok($zip->set_number('6893113')->is_valid_number, '鳥取県西伯郡大山町御崎');
ok($zip->set_number('6893114')->is_valid_number, '鳥取県西伯郡大山町田中');
ok($zip->set_number('6893115')->is_valid_number, '鳥取県西伯郡大山町栄田');
ok($zip->set_number('6893121')->is_valid_number, '鳥取県西伯郡大山町岡');
ok($zip->set_number('6893122')->is_valid_number, '鳥取県西伯郡大山町塩津');
ok($zip->set_number('6893123')->is_valid_number, '鳥取県西伯郡大山町住吉');
ok($zip->set_number('6893124')->is_valid_number, '鳥取県西伯郡大山町上市');
ok($zip->set_number('6893125')->is_valid_number, '鳥取県西伯郡大山町下市');
ok($zip->set_number('6893132')->is_valid_number, '鳥取県西伯郡大山町松河原');
ok($zip->set_number('6893133')->is_valid_number, '鳥取県西伯郡大山町退休寺');
ok($zip->set_number('6893134')->is_valid_number, '鳥取県西伯郡大山町高橋');
ok($zip->set_number('6893135')->is_valid_number, '鳥取県西伯郡大山町殿河内');
ok($zip->set_number('6893136')->is_valid_number, '鳥取県西伯郡大山町長野');
ok($zip->set_number('6893200')->is_valid_number, '鳥取県西伯郡大山町以下に掲載がない場合');
ok($zip->set_number('6893201')->is_valid_number, '鳥取県西伯郡大山町豊成');
ok($zip->set_number('6893202')->is_valid_number, '鳥取県西伯郡大山町倉谷');
ok($zip->set_number('6893203')->is_valid_number, '鳥取県西伯郡大山町小竹');
ok($zip->set_number('6893204')->is_valid_number, '鳥取県西伯郡大山町東坪');
ok($zip->set_number('6893205')->is_valid_number, '鳥取県西伯郡大山町西坪');
ok($zip->set_number('6893211')->is_valid_number, '鳥取県西伯郡大山町御来屋');
ok($zip->set_number('6893212')->is_valid_number, '鳥取県西伯郡大山町名和');
ok($zip->set_number('6893213')->is_valid_number, '鳥取県西伯郡大山町門前');
ok($zip->set_number('6893214')->is_valid_number, '鳥取県西伯郡大山町加茂');
ok($zip->set_number('6893221')->is_valid_number, '鳥取県西伯郡大山町富長');
ok($zip->set_number('6893222')->is_valid_number, '鳥取県西伯郡大山町古御堂');
ok($zip->set_number('6893223')->is_valid_number, '鳥取県西伯郡大山町茶畑');
ok($zip->set_number('6893224')->is_valid_number, '鳥取県西伯郡大山町高田');
ok($zip->set_number('6893225')->is_valid_number, '鳥取県西伯郡大山町押平');
ok($zip->set_number('6893226')->is_valid_number, '鳥取県西伯郡大山町大塚');
ok($zip->set_number('6893301')->is_valid_number, '鳥取県西伯郡大山町福尾');
ok($zip->set_number('6893302')->is_valid_number, '鳥取県西伯郡大山町上野');
ok($zip->set_number('6893303')->is_valid_number, '鳥取県西伯郡大山町所子');
ok($zip->set_number('6893304')->is_valid_number, '鳥取県西伯郡大山町平木');
ok($zip->set_number('6893305')->is_valid_number, '鳥取県西伯郡大山町神原');
ok($zip->set_number('6893306')->is_valid_number, '鳥取県西伯郡大山町中高');
ok($zip->set_number('6893307')->is_valid_number, '鳥取県西伯郡大山町野田');
ok($zip->set_number('6893308')->is_valid_number, '鳥取県西伯郡大山町清原');
ok($zip->set_number('6893309')->is_valid_number, '鳥取県西伯郡大山町国信');
ok($zip->set_number('6893311')->is_valid_number, '鳥取県西伯郡大山町宮内');
ok($zip->set_number('6893312')->is_valid_number, '鳥取県西伯郡大山町坊領');
ok($zip->set_number('6893313')->is_valid_number, '鳥取県西伯郡大山町佐摩');
ok($zip->set_number('6893314')->is_valid_number, '鳥取県西伯郡大山町今在家');
ok($zip->set_number('6893315')->is_valid_number, '鳥取県西伯郡大山町前');
ok($zip->set_number('6893316')->is_valid_number, '鳥取県西伯郡大山町豊房');
ok($zip->set_number('6893317')->is_valid_number, '鳥取県西伯郡大山町鈑戸');
ok($zip->set_number('6893318')->is_valid_number, '鳥取県西伯郡大山町大山');
ok($zip->set_number('6893319')->is_valid_number, '鳥取県西伯郡大山町赤松');
ok($zip->set_number('6893321')->is_valid_number, '鳥取県西伯郡大山町平');
ok($zip->set_number('6893322')->is_valid_number, '鳥取県西伯郡大山町長田');
ok($zip->set_number('6893323')->is_valid_number, '鳥取県西伯郡大山町荘田');
ok($zip->set_number('6893324')->is_valid_number, '鳥取県西伯郡大山町妻木');
ok($zip->set_number('6893325')->is_valid_number, '鳥取県西伯郡大山町富岡');
ok($zip->set_number('6893326')->is_valid_number, '鳥取県西伯郡大山町安原');
ok($zip->set_number('6893327')->is_valid_number, '鳥取県西伯郡大山町保田');
ok($zip->set_number('6893331')->is_valid_number, '鳥取県西伯郡大山町末吉');
ok($zip->set_number('6893332')->is_valid_number, '鳥取県西伯郡大山町末長');
ok($zip->set_number('6893333')->is_valid_number, '鳥取県西伯郡大山町唐王');
ok($zip->set_number('6893334')->is_valid_number, '鳥取県西伯郡大山町稲光');
ok($zip->set_number('6893335')->is_valid_number, '鳥取県西伯郡大山町上万');
ok($zip->set_number('6893336')->is_valid_number, '鳥取県西伯郡大山町平田');
ok($zip->set_number('6893401')->is_valid_number, '鳥取県米子市淀江町今津');
ok($zip->set_number('6893402')->is_valid_number, '鳥取県米子市淀江町淀江');
ok($zip->set_number('6893403')->is_valid_number, '鳥取県米子市淀江町西原');
ok($zip->set_number('6893411')->is_valid_number, '鳥取県米子市淀江町福岡');
ok($zip->set_number('6893412')->is_valid_number, '鳥取県米子市淀江町稲吉');
ok($zip->set_number('6893413')->is_valid_number, '鳥取県米子市淀江町本宮');
ok($zip->set_number('6893414')->is_valid_number, '鳥取県米子市淀江町西尾原');
ok($zip->set_number('6893415')->is_valid_number, '鳥取県米子市淀江町富繁');
ok($zip->set_number('6893416')->is_valid_number, '鳥取県米子市淀江町福井');
ok($zip->set_number('6893417')->is_valid_number, '鳥取県米子市淀江町中西尾');
ok($zip->set_number('6893418')->is_valid_number, '鳥取県米子市淀江町高井谷');
ok($zip->set_number('6893421')->is_valid_number, '鳥取県米子市淀江町福頼');
ok($zip->set_number('6893422')->is_valid_number, '鳥取県米子市淀江町平岡');
ok($zip->set_number('6893423')->is_valid_number, '鳥取県米子市淀江町小波');
ok($zip->set_number('6893424')->is_valid_number, '鳥取県米子市淀江町中間');
ok($zip->set_number('6893425')->is_valid_number, '鳥取県米子市淀江町佐陀');
ok($zip->set_number('6893500')->is_valid_number, '鳥取県西伯郡日吉津村以下に掲載がない場合');
ok($zip->set_number('6893511')->is_valid_number, '鳥取県米子市下郷');
ok($zip->set_number('6893512')->is_valid_number, '鳥取県米子市泉');
ok($zip->set_number('6893513')->is_valid_number, '鳥取県米子市岡成');
ok($zip->set_number('6893514')->is_valid_number, '鳥取県米子市尾高');
ok($zip->set_number('6893515')->is_valid_number, '鳥取県米子市赤井手');
ok($zip->set_number('6893521')->is_valid_number, '鳥取県米子市河岡');
ok($zip->set_number('6893522')->is_valid_number, '鳥取県米子市日下');
ok($zip->set_number('6893523')->is_valid_number, '鳥取県米子市福万');
ok($zip->set_number('6893524')->is_valid_number, '鳥取県米子市石州府');
ok($zip->set_number('6893531')->is_valid_number, '鳥取県米子市下新印');
ok($zip->set_number('6893532')->is_valid_number, '鳥取県米子市上新印');
ok($zip->set_number('6893533')->is_valid_number, '鳥取県米子市一部');
ok($zip->set_number('6893534')->is_valid_number, '鳥取県米子市水浜');
ok($zip->set_number('6893535')->is_valid_number, '鳥取県米子市東八幡');
ok($zip->set_number('6893536')->is_valid_number, '鳥取県米子市高島');
ok($zip->set_number('6893537')->is_valid_number, '鳥取県米子市古豊千');
ok($zip->set_number('6893541')->is_valid_number, '鳥取県米子市二本木');
ok($zip->set_number('6893542')->is_valid_number, '鳥取県米子市今在家');
ok($zip->set_number('6893543')->is_valid_number, '鳥取県米子市蚊屋');
ok($zip->set_number('6893544')->is_valid_number, '鳥取県米子市浦津');
ok($zip->set_number('6893545')->is_valid_number, '鳥取県米子市吉岡');
ok($zip->set_number('6893546')->is_valid_number, '鳥取県米子市熊党');
ok($zip->set_number('6893547')->is_valid_number, '鳥取県米子市流通町');
ok($zip->set_number('6893551')->is_valid_number, '鳥取県西伯郡日吉津村今吉');
ok($zip->set_number('6893552')->is_valid_number, '鳥取県西伯郡日吉津村富吉');
ok($zip->set_number('6893553')->is_valid_number, '鳥取県西伯郡日吉津村日吉津');
ok($zip->set_number('6894100')->is_valid_number, '鳥取県西伯郡伯耆町以下に掲載がない場合');
ok($zip->set_number('6894101')->is_valid_number, '鳥取県西伯郡伯耆町小林');
ok($zip->set_number('6894102')->is_valid_number, '鳥取県西伯郡伯耆町大原');
ok($zip->set_number('6894103')->is_valid_number, '鳥取県西伯郡伯耆町真野');
ok($zip->set_number('6894104')->is_valid_number, '鳥取県西伯郡伯耆町番原');
ok($zip->set_number('6894105')->is_valid_number, '鳥取県西伯郡伯耆町久古');
ok($zip->set_number('6894106')->is_valid_number, '鳥取県西伯郡伯耆町口別所');
ok($zip->set_number('6894107')->is_valid_number, '鳥取県西伯郡伯耆町須村');
ok($zip->set_number('6894108')->is_valid_number, '鳥取県西伯郡伯耆町丸山');
ok($zip->set_number('6894111')->is_valid_number, '鳥取県西伯郡伯耆町清原');
ok($zip->set_number('6894112')->is_valid_number, '鳥取県西伯郡伯耆町上細見');
ok($zip->set_number('6894113')->is_valid_number, '鳥取県西伯郡伯耆町小野');
ok($zip->set_number('6894114')->is_valid_number, '鳥取県西伯郡伯耆町立岩');
ok($zip->set_number('6894115')->is_valid_number, '鳥取県西伯郡伯耆町小町');
ok($zip->set_number('6894121')->is_valid_number, '鳥取県西伯郡伯耆町大殿');
ok($zip->set_number('6894122')->is_valid_number, '鳥取県西伯郡伯耆町坂長');
ok($zip->set_number('6894123')->is_valid_number, '鳥取県西伯郡伯耆町岩屋谷');
ok($zip->set_number('6894131')->is_valid_number, '鳥取県西伯郡伯耆町吉定');
ok($zip->set_number('6894132')->is_valid_number, '鳥取県西伯郡伯耆町岸本');
ok($zip->set_number('6894133')->is_valid_number, '鳥取県西伯郡伯耆町吉長');
ok($zip->set_number('6894134')->is_valid_number, '鳥取県西伯郡伯耆町遠藤');
ok($zip->set_number('6894135')->is_valid_number, '鳥取県西伯郡伯耆町押口');
ok($zip->set_number('6894136')->is_valid_number, '鳥取県西伯郡伯耆町福岡原');
ok($zip->set_number('6894201')->is_valid_number, '鳥取県西伯郡伯耆町溝口');
ok($zip->set_number('6894202')->is_valid_number, '鳥取県西伯郡伯耆町長山');
ok($zip->set_number('6894203')->is_valid_number, '鳥取県西伯郡伯耆町貴住');
ok($zip->set_number('6894204')->is_valid_number, '鳥取県西伯郡伯耆町谷川');
ok($zip->set_number('6894205')->is_valid_number, '鳥取県西伯郡伯耆町大倉');
ok($zip->set_number('6894206')->is_valid_number, '鳥取県西伯郡伯耆町宮原');
ok($zip->set_number('6894207')->is_valid_number, '鳥取県西伯郡伯耆町宇代');
ok($zip->set_number('6894211')->is_valid_number, '鳥取県西伯郡伯耆町大江');
ok($zip->set_number('6894212')->is_valid_number, '鳥取県西伯郡伯耆町上野');
ok($zip->set_number('6894213')->is_valid_number, '鳥取県西伯郡伯耆町金屋谷');
ok($zip->set_number('6894214')->is_valid_number, '鳥取県西伯郡伯耆町岩立');
ok($zip->set_number('6894215')->is_valid_number, '鳥取県西伯郡伯耆町大内');
ok($zip->set_number('6894216')->is_valid_number, '鳥取県西伯郡伯耆町福兼');
ok($zip->set_number('6894217')->is_valid_number, '鳥取県西伯郡伯耆町添谷');
ok($zip->set_number('6894221')->is_valid_number, '鳥取県西伯郡伯耆町富江');
ok($zip->set_number('6894222')->is_valid_number, '鳥取県西伯郡伯耆町大滝');
ok($zip->set_number('6894223')->is_valid_number, '鳥取県西伯郡伯耆町栃原');
ok($zip->set_number('6894224')->is_valid_number, '鳥取県西伯郡伯耆町根雨原');
ok($zip->set_number('6894225')->is_valid_number, '鳥取県西伯郡伯耆町白水');
ok($zip->set_number('6894226')->is_valid_number, '鳥取県西伯郡伯耆町大坂');
ok($zip->set_number('6894231')->is_valid_number, '鳥取県西伯郡伯耆町船越');
ok($zip->set_number('6894232')->is_valid_number, '鳥取県西伯郡伯耆町福島');
ok($zip->set_number('6894233')->is_valid_number, '鳥取県西伯郡伯耆町二部');
ok($zip->set_number('6894234')->is_valid_number, '鳥取県西伯郡伯耆町畑池');
ok($zip->set_number('6894235')->is_valid_number, '鳥取県西伯郡伯耆町福岡');
ok($zip->set_number('6894236')->is_valid_number, '鳥取県西伯郡伯耆町焼杉');
ok($zip->set_number('6894237')->is_valid_number, '鳥取県西伯郡伯耆町福居');
ok($zip->set_number('6894241')->is_valid_number, '鳥取県西伯郡伯耆町中祖');
ok($zip->set_number('6894242')->is_valid_number, '鳥取県西伯郡伯耆町古市');
ok($zip->set_number('6894243')->is_valid_number, '鳥取県西伯郡伯耆町荘');
ok($zip->set_number('6894244')->is_valid_number, '鳥取県西伯郡伯耆町父原');
ok($zip->set_number('6894245')->is_valid_number, '鳥取県西伯郡伯耆町福吉');
ok($zip->set_number('6894246')->is_valid_number, '鳥取県西伯郡伯耆町三部');
ok($zip->set_number('6894400')->is_valid_number, '鳥取県日野郡江府町以下に掲載がない場合');
ok($zip->set_number('6894401')->is_valid_number, '鳥取県日野郡江府町江尾');
ok($zip->set_number('6894402')->is_valid_number, '鳥取県日野郡江府町小江尾');
ok($zip->set_number('6894403')->is_valid_number, '鳥取県日野郡江府町久連');
ok($zip->set_number('6894411')->is_valid_number, '鳥取県日野郡江府町武庫');
ok($zip->set_number('6894412')->is_valid_number, '鳥取県日野郡江府町下安井');
ok($zip->set_number('6894413')->is_valid_number, '鳥取県日野郡江府町洲河崎');
ok($zip->set_number('6894414')->is_valid_number, '鳥取県日野郡江府町俣野');
ok($zip->set_number('6894421')->is_valid_number, '鳥取県日野郡江府町宮市');
ok($zip->set_number('6894422')->is_valid_number, '鳥取県日野郡江府町杉谷');
ok($zip->set_number('6894423')->is_valid_number, '鳥取県日野郡江府町美用');
ok($zip->set_number('6894424')->is_valid_number, '鳥取県日野郡江府町御机');
ok($zip->set_number('6894425')->is_valid_number, '鳥取県日野郡江府町下蚊屋');
ok($zip->set_number('6894426')->is_valid_number, '鳥取県日野郡江府町助沢');
ok($zip->set_number('6894431')->is_valid_number, '鳥取県日野郡江府町佐川');
ok($zip->set_number('6894432')->is_valid_number, '鳥取県日野郡江府町柿原');
ok($zip->set_number('6894433')->is_valid_number, '鳥取県日野郡江府町吉原');
ok($zip->set_number('6894434')->is_valid_number, '鳥取県日野郡江府町大河原');
ok($zip->set_number('6894435')->is_valid_number, '鳥取県日野郡江府町貝田');
ok($zip->set_number('6894500')->is_valid_number, '鳥取県日野郡日野町以下に掲載がない場合');
ok($zip->set_number('6894501')->is_valid_number, '鳥取県日野郡日野町貝原');
ok($zip->set_number('6894502')->is_valid_number, '鳥取県日野郡日野町三谷');
ok($zip->set_number('6894503')->is_valid_number, '鳥取県日野郡日野町根雨');
ok($zip->set_number('6894504')->is_valid_number, '鳥取県日野郡日野町野田');
ok($zip->set_number('6894505')->is_valid_number, '鳥取県日野郡日野町舟場');
ok($zip->set_number('6894511')->is_valid_number, '鳥取県日野郡日野町高尾');
ok($zip->set_number('6894512')->is_valid_number, '鳥取県日野郡日野町金持');
ok($zip->set_number('6894513')->is_valid_number, '鳥取県日野郡日野町板井原');
ok($zip->set_number('6894514')->is_valid_number, '鳥取県日野郡日野町三土');
ok($zip->set_number('6894515')->is_valid_number, '鳥取県日野郡日野町秋縄');
ok($zip->set_number('6894516')->is_valid_number, '鳥取県日野郡日野町門谷');
ok($zip->set_number('6894517')->is_valid_number, '鳥取県日野郡日野町濁谷');
ok($zip->set_number('6894521')->is_valid_number, '鳥取県日野郡日野町津地');
ok($zip->set_number('6894522')->is_valid_number, '鳥取県日野郡日野町本郷');
ok($zip->set_number('6894523')->is_valid_number, '鳥取県日野郡日野町榎市');
ok($zip->set_number('6894524')->is_valid_number, '鳥取県日野郡日野町別所');
ok($zip->set_number('6894525')->is_valid_number, '鳥取県日野郡日野町小原');
ok($zip->set_number('6894526')->is_valid_number, '鳥取県日野郡日野町下榎');
ok($zip->set_number('6894527')->is_valid_number, '鳥取県日野郡日野町安原');
ok($zip->set_number('6895131')->is_valid_number, '鳥取県日野郡日野町黒坂');
ok($zip->set_number('6895132')->is_valid_number, '鳥取県日野郡日野町久住');
ok($zip->set_number('6895133')->is_valid_number, '鳥取県日野郡日野町下黒坂');
ok($zip->set_number('6895134')->is_valid_number, '鳥取県日野郡日野町下菅');
ok($zip->set_number('6895135')->is_valid_number, '鳥取県日野郡日野町中菅');
ok($zip->set_number('6895136')->is_valid_number, '鳥取県日野郡日野町小河内');
ok($zip->set_number('6895137')->is_valid_number, '鳥取県日野郡日野町上菅');
ok($zip->set_number('6895137')->is_valid_number, '鳥取県日野郡日野町福長');
ok($zip->set_number('6895200')->is_valid_number, '鳥取県日野郡日南町以下に掲載がない場合');
ok($zip->set_number('6895211')->is_valid_number, '鳥取県日野郡日南町生山');
ok($zip->set_number('6895212')->is_valid_number, '鳥取県日野郡日南町霞');
ok($zip->set_number('6895213')->is_valid_number, '鳥取県日野郡日南町丸山');
ok($zip->set_number('6895214')->is_valid_number, '鳥取県日野郡日南町三栄');
ok($zip->set_number('6895215')->is_valid_number, '鳥取県日野郡日南町矢戸');
ok($zip->set_number('6895216')->is_valid_number, '鳥取県日野郡日南町宮内');
ok($zip->set_number('6895221')->is_valid_number, '鳥取県日野郡日南町河上');
ok($zip->set_number('6895222')->is_valid_number, '鳥取県日野郡日南町萩原');
ok($zip->set_number('6895223')->is_valid_number, '鳥取県日野郡日南町上萩山');
ok($zip->set_number('6895224')->is_valid_number, '鳥取県日野郡日南町多里');
ok($zip->set_number('6895225')->is_valid_number, '鳥取県日野郡日南町新屋');
ok($zip->set_number('6895226')->is_valid_number, '鳥取県日野郡日南町湯河');
ok($zip->set_number('6895531')->is_valid_number, '鳥取県日野郡日南町印賀');
ok($zip->set_number('6895532')->is_valid_number, '鳥取県日野郡日南町菅沢');
ok($zip->set_number('6895533')->is_valid_number, '鳥取県日野郡日南町宝谷');
ok($zip->set_number('6895534')->is_valid_number, '鳥取県日野郡日南町折渡');
ok($zip->set_number('6895541')->is_valid_number, '鳥取県日野郡日南町佐木谷');
ok($zip->set_number('6895542')->is_valid_number, '鳥取県日野郡日南町福万来');
ok($zip->set_number('6895543')->is_valid_number, '鳥取県日野郡日南町笠木');
ok($zip->set_number('6895544')->is_valid_number, '鳥取県日野郡日南町茶屋');
ok($zip->set_number('6895545')->is_valid_number, '鳥取県日野郡日南町福寿実');
ok($zip->set_number('6895551')->is_valid_number, '鳥取県日野郡日南町阿毘縁');
ok($zip->set_number('6895552')->is_valid_number, '鳥取県日野郡日南町下阿毘縁');
ok($zip->set_number('6895661')->is_valid_number, '鳥取県日野郡日南町花口');
ok($zip->set_number('6895662')->is_valid_number, '鳥取県日野郡日南町神戸上');
ok($zip->set_number('6895663')->is_valid_number, '鳥取県日野郡日南町上石見');
ok($zip->set_number('6895664')->is_valid_number, '鳥取県日野郡日南町中石見');
ok($zip->set_number('6895665')->is_valid_number, '鳥取県日野郡日南町下石見');
ok($zip->set_number('6895666')->is_valid_number, '鳥取県日野郡日南町三吉');
ok($zip->set_number('6895671')->is_valid_number, '鳥取県日野郡日南町福塚');
ok($zip->set_number('6895672')->is_valid_number, '鳥取県日野郡日南町神福');
ok($zip->set_number('6895673')->is_valid_number, '鳥取県日野郡日南町豊栄');
ok($zip->set_number('6900000')->is_valid_number, '島根県松江市以下に掲載がない場合');
ok($zip->set_number('6900001')->is_valid_number, '島根県松江市東朝日町');
ok($zip->set_number('6900002')->is_valid_number, '島根県松江市大正町');
ok($zip->set_number('6900003')->is_valid_number, '島根県松江市朝日町');
ok($zip->set_number('6900004')->is_valid_number, '島根県松江市八軒屋町');
ok($zip->set_number('6900005')->is_valid_number, '島根県松江市和多見町');
ok($zip->set_number('6900006')->is_valid_number, '島根県松江市伊勢宮町');
ok($zip->set_number('6900007')->is_valid_number, '島根県松江市御手船場町');
ok($zip->set_number('6900011')->is_valid_number, '島根県松江市東津田町');
ok($zip->set_number('6900012')->is_valid_number, '島根県松江市古志原');
ok($zip->set_number('6900013')->is_valid_number, '島根県松江市古志原町');
ok($zip->set_number('6900014')->is_valid_number, '島根県松江市八雲台');
ok($zip->set_number('6900015')->is_valid_number, '島根県松江市上乃木');
ok($zip->set_number('6900017')->is_valid_number, '島根県松江市西津田');
ok($zip->set_number('6900021')->is_valid_number, '島根県松江市矢田町');
ok($zip->set_number('6900022')->is_valid_number, '島根県松江市青葉台');
ok($zip->set_number('6900023')->is_valid_number, '島根県松江市竹矢町');
ok($zip->set_number('6900024')->is_valid_number, '島根県松江市馬潟町');
ok($zip->set_number('6900025')->is_valid_number, '島根県松江市八幡町');
ok($zip->set_number('6900026')->is_valid_number, '島根県松江市富士見町');
ok($zip->set_number('6900027')->is_valid_number, '島根県松江市意宇町');
ok($zip->set_number('6900031')->is_valid_number, '島根県松江市山代町');
ok($zip->set_number('6900032')->is_valid_number, '島根県松江市大草町');
ok($zip->set_number('6900033')->is_valid_number, '島根県松江市大庭町');
ok($zip->set_number('6900034')->is_valid_number, '島根県松江市一の谷町');
ok($zip->set_number('6900035')->is_valid_number, '島根県松江市佐草町');
ok($zip->set_number('6900036')->is_valid_number, '島根県松江市東忌部町');
ok($zip->set_number('6900037')->is_valid_number, '島根県松江市西忌部町');
ok($zip->set_number('6900038')->is_valid_number, '島根県松江市平成町');
ok($zip->set_number('6900041')->is_valid_number, '島根県松江市幸町');
ok($zip->set_number('6900042')->is_valid_number, '島根県松江市栄町');
ok($zip->set_number('6900043')->is_valid_number, '島根県松江市松尾町');
ok($zip->set_number('6900044')->is_valid_number, '島根県松江市浜乃木');
ok($zip->set_number('6900045')->is_valid_number, '島根県松江市乃白町');
ok($zip->set_number('6900046')->is_valid_number, '島根県松江市乃木福富町');
ok($zip->set_number('6900047')->is_valid_number, '島根県松江市嫁島町');
ok($zip->set_number('6900048')->is_valid_number, '島根県松江市西嫁島');
ok($zip->set_number('6900049')->is_valid_number, '島根県松江市袖師町');
ok($zip->set_number('6900051')->is_valid_number, '島根県松江市横浜町');
ok($zip->set_number('6900052')->is_valid_number, '島根県松江市竪町');
ok($zip->set_number('6900053')->is_valid_number, '島根県松江市本郷町');
ok($zip->set_number('6900054')->is_valid_number, '島根県松江市新雑賀町');
ok($zip->set_number('6900055')->is_valid_number, '島根県松江市津田町');
ok($zip->set_number('6900056')->is_valid_number, '島根県松江市雑賀町');
ok($zip->set_number('6900057')->is_valid_number, '島根県松江市新町');
ok($zip->set_number('6900058')->is_valid_number, '島根県松江市田和山町');
ok($zip->set_number('6900061')->is_valid_number, '島根県松江市白瀉本町');
ok($zip->set_number('6900062')->is_valid_number, '島根県松江市魚町');
ok($zip->set_number('6900063')->is_valid_number, '島根県松江市寺町');
ok($zip->set_number('6900064')->is_valid_number, '島根県松江市天神町');
ok($zip->set_number('6900065')->is_valid_number, '島根県松江市灘町');
ok($zip->set_number('6900121')->is_valid_number, '島根県松江市古志町');
ok($zip->set_number('6900122')->is_valid_number, '島根県松江市西浜佐陀町');
ok($zip->set_number('6900131')->is_valid_number, '島根県松江市打出町');
ok($zip->set_number('6900132')->is_valid_number, '島根県松江市西長江町');
ok($zip->set_number('6900133')->is_valid_number, '島根県松江市東長江町');
ok($zip->set_number('6900141')->is_valid_number, '島根県松江市荘成町');
ok($zip->set_number('6900142')->is_valid_number, '島根県松江市西谷町');
ok($zip->set_number('6900151')->is_valid_number, '島根県松江市古曽志町');
ok($zip->set_number('6900261')->is_valid_number, '島根県松江市秋鹿町');
ok($zip->set_number('6900262')->is_valid_number, '島根県松江市岡本町');
ok($zip->set_number('6900263')->is_valid_number, '島根県松江市大垣町');
ok($zip->set_number('6900264')->is_valid_number, '島根県松江市大野町');
ok($zip->set_number('6900265')->is_valid_number, '島根県松江市上大野町');
ok($zip->set_number('6900266')->is_valid_number, '島根県松江市魚瀬町');
ok($zip->set_number('6900321')->is_valid_number, '島根県松江市鹿島町武代');
ok($zip->set_number('6900322')->is_valid_number, '島根県松江市鹿島町恵曇');
ok($zip->set_number('6900323')->is_valid_number, '島根県松江市鹿島町手結');
ok($zip->set_number('6900324')->is_valid_number, '島根県松江市鹿島町片句');
ok($zip->set_number('6900331')->is_valid_number, '島根県松江市鹿島町佐陀宮内');
ok($zip->set_number('6900332')->is_valid_number, '島根県松江市鹿島町佐陀本郷');
ok($zip->set_number('6900333')->is_valid_number, '島根県松江市鹿島町古浦');
ok($zip->set_number('6900401')->is_valid_number, '島根県松江市島根町加賀');
ok($zip->set_number('6900402')->is_valid_number, '島根県松江市島根町大芦');
ok($zip->set_number('6900411')->is_valid_number, '島根県松江市鹿島町御津');
ok($zip->set_number('6900801')->is_valid_number, '島根県松江市鹿島町上講武');
ok($zip->set_number('6900802')->is_valid_number, '島根県松江市鹿島町南講武');
ok($zip->set_number('6900803')->is_valid_number, '島根県松江市鹿島町名分');
ok($zip->set_number('6900804')->is_valid_number, '島根県松江市鹿島町北講武');
ok($zip->set_number('6900811')->is_valid_number, '島根県松江市福原町');
ok($zip->set_number('6900812')->is_valid_number, '島根県松江市川原町');
ok($zip->set_number('6900813')->is_valid_number, '島根県松江市坂本町');
ok($zip->set_number('6900814')->is_valid_number, '島根県松江市東持田町');
ok($zip->set_number('6900815')->is_valid_number, '島根県松江市西持田町');
ok($zip->set_number('6900816')->is_valid_number, '島根県松江市北陵町');
ok($zip->set_number('6900821')->is_valid_number, '島根県松江市上東川津町');
ok($zip->set_number('6900822')->is_valid_number, '島根県松江市下東川津町');
ok($zip->set_number('6900823')->is_valid_number, '島根県松江市西川津町');
ok($zip->set_number('6900824')->is_valid_number, '島根県松江市菅田町');
ok($zip->set_number('6900825')->is_valid_number, '島根県松江市学園');
ok($zip->set_number('6900826')->is_valid_number, '島根県松江市学園南');
ok($zip->set_number('6900831')->is_valid_number, '島根県松江市大海崎町');
ok($zip->set_number('6900832')->is_valid_number, '島根県松江市大井町');
ok($zip->set_number('6900833')->is_valid_number, '島根県松江市福富町');
ok($zip->set_number('6900834')->is_valid_number, '島根県松江市朝酌町');
ok($zip->set_number('6900835')->is_valid_number, '島根県松江市西尾町');
ok($zip->set_number('6900841')->is_valid_number, '島根県松江市向島町');
ok($zip->set_number('6900842')->is_valid_number, '島根県松江市東本町');
ok($zip->set_number('6900843')->is_valid_number, '島根県松江市末次本町');
ok($zip->set_number('6900844')->is_valid_number, '島根県松江市東茶町');
ok($zip->set_number('6900845')->is_valid_number, '島根県松江市西茶町');
ok($zip->set_number('6900846')->is_valid_number, '島根県松江市末次町');
ok($zip->set_number('6900847')->is_valid_number, '島根県松江市片原町');
ok($zip->set_number('6900848')->is_valid_number, '島根県松江市苧町');
ok($zip->set_number('6900851')->is_valid_number, '島根県松江市堂形町');
ok($zip->set_number('6900852')->is_valid_number, '島根県松江市千鳥町');
ok($zip->set_number('6900854')->is_valid_number, '島根県松江市南平台');
ok($zip->set_number('6900855')->is_valid_number, '島根県松江市浜佐田町');
ok($zip->set_number('6900856')->is_valid_number, '島根県松江市薦津町');
ok($zip->set_number('6900859')->is_valid_number, '島根県松江市国屋町');
ok($zip->set_number('6900860')->is_valid_number, '島根県松江市西法吉町');
ok($zip->set_number('6900861')->is_valid_number, '島根県松江市法吉町');
ok($zip->set_number('6900862')->is_valid_number, '島根県松江市比津が丘');
ok($zip->set_number('6900863')->is_valid_number, '島根県松江市比津町');
ok($zip->set_number('6900864')->is_valid_number, '島根県松江市東生馬町');
ok($zip->set_number('6900865')->is_valid_number, '島根県松江市西生馬町');
ok($zip->set_number('6900866')->is_valid_number, '島根県松江市下佐陀町');
ok($zip->set_number('6900867')->is_valid_number, '島根県松江市上佐陀町');
ok($zip->set_number('6900868')->is_valid_number, '島根県松江市淞北台');
ok($zip->set_number('6900869')->is_valid_number, '島根県松江市うぐいす台');
ok($zip->set_number('6900871')->is_valid_number, '島根県松江市東奥谷町');
ok($zip->set_number('6900872')->is_valid_number, '島根県松江市奥谷町');
ok($zip->set_number('6900873')->is_valid_number, '島根県松江市内中原町');
ok($zip->set_number('6900874')->is_valid_number, '島根県松江市中原町');
ok($zip->set_number('6900875')->is_valid_number, '島根県松江市外中原町');
ok($zip->set_number('6900876')->is_valid_number, '島根県松江市黒田町');
ok($zip->set_number('6900877')->is_valid_number, '島根県松江市春日町');
ok($zip->set_number('6900878')->is_valid_number, '島根県松江市砂子町');
ok($zip->set_number('6900881')->is_valid_number, '島根県松江市石橋町');
ok($zip->set_number('6900882')->is_valid_number, '島根県松江市大輪町');
ok($zip->set_number('6900883')->is_valid_number, '島根県松江市北田町');
ok($zip->set_number('6900884')->is_valid_number, '島根県松江市南田町');
ok($zip->set_number('6900885')->is_valid_number, '島根県松江市米子町');
ok($zip->set_number('6900886')->is_valid_number, '島根県松江市母衣町');
ok($zip->set_number('6900887')->is_valid_number, '島根県松江市殿町');
ok($zip->set_number('6900888')->is_valid_number, '島根県松江市北堀町');
ok($zip->set_number('6901101')->is_valid_number, '島根県松江市本庄町');
ok($zip->set_number('6901102')->is_valid_number, '島根県松江市上本庄町');
ok($zip->set_number('6901103')->is_valid_number, '島根県松江市新庄町');
ok($zip->set_number('6901104')->is_valid_number, '島根県松江市上宇部尾町');
ok($zip->set_number('6901111')->is_valid_number, '島根県松江市枕木町');
ok($zip->set_number('6901112')->is_valid_number, '島根県松江市長海町');
ok($zip->set_number('6901113')->is_valid_number, '島根県松江市手角町');
ok($zip->set_number('6901114')->is_valid_number, '島根県松江市野原町');
ok($zip->set_number('6901115')->is_valid_number, '島根県松江市邑生町');
ok($zip->set_number('6901211')->is_valid_number, '島根県松江市島根町野井');
ok($zip->set_number('6901212')->is_valid_number, '島根県松江市島根町野波');
ok($zip->set_number('6901213')->is_valid_number, '島根県松江市島根町多古');
ok($zip->set_number('6901221')->is_valid_number, '島根県松江市美保関町北浦');
ok($zip->set_number('6901222')->is_valid_number, '島根県松江市美保関町千酌');
ok($zip->set_number('6901223')->is_valid_number, '島根県松江市美保関町笠浦');
ok($zip->set_number('6901311')->is_valid_number, '島根県松江市美保関町七類');
ok($zip->set_number('6901312')->is_valid_number, '島根県松江市美保関町森山(その他)');
ok($zip->set_number('6901313')->is_valid_number, '島根県松江市美保関町下宇部尾');
ok($zip->set_number('6901314')->is_valid_number, '島根県松江市美保関町菅浦');
ok($zip->set_number('6901315')->is_valid_number, '島根県松江市美保関町片江');
ok($zip->set_number('6901401')->is_valid_number, '島根県松江市八束町江島');
ok($zip->set_number('6901402')->is_valid_number, '島根県松江市八束町馬渡');
ok($zip->set_number('6901403')->is_valid_number, '島根県松江市八束町遅江');
ok($zip->set_number('6901404')->is_valid_number, '島根県松江市八束町波入');
ok($zip->set_number('6901405')->is_valid_number, '島根県松江市八束町入江');
ok($zip->set_number('6901406')->is_valid_number, '島根県松江市八束町二子');
ok($zip->set_number('6901407')->is_valid_number, '島根県松江市八束町寺津');
ok($zip->set_number('6901408')->is_valid_number, '島根県松江市八束町亀尻');
ok($zip->set_number('6901501')->is_valid_number, '島根県松江市美保関町美保関');
ok($zip->set_number('6901502')->is_valid_number, '島根県松江市美保関町雲津');
ok($zip->set_number('6901503')->is_valid_number, '島根県松江市美保関町諸喰');
ok($zip->set_number('6901504')->is_valid_number, '島根県松江市美保関町福浦');
ok($zip->set_number('6901505')->is_valid_number, '島根県松江市美保関町森山(古金崎)');
ok($zip->set_number('6902101')->is_valid_number, '島根県松江市八雲町日吉');
ok($zip->set_number('6902102')->is_valid_number, '島根県松江市八雲町東岩坂');
ok($zip->set_number('6902103')->is_valid_number, '島根県松江市八雲町西岩坂');
ok($zip->set_number('6902104')->is_valid_number, '島根県松江市八雲町熊野');
ok($zip->set_number('6902105')->is_valid_number, '島根県松江市八雲町平原');
ok($zip->set_number('6902311')->is_valid_number, '島根県雲南市吉田町上山');
ok($zip->set_number('6902312')->is_valid_number, '島根県雲南市吉田町曽木');
ok($zip->set_number('6902313')->is_valid_number, '島根県雲南市吉田町深野');
ok($zip->set_number('6902314')->is_valid_number, '島根県雲南市吉田町川手');
ok($zip->set_number('6902400')->is_valid_number, '島根県雲南市以下に掲載がない場合');
ok($zip->set_number('6902401')->is_valid_number, '島根県雲南市三刀屋町伊萱');
ok($zip->set_number('6902402')->is_valid_number, '島根県雲南市三刀屋町給下');
ok($zip->set_number('6902403')->is_valid_number, '島根県雲南市三刀屋町下熊谷');
ok($zip->set_number('6902404')->is_valid_number, '島根県雲南市三刀屋町三刀屋');
ok($zip->set_number('6902405')->is_valid_number, '島根県雲南市三刀屋町古城');
ok($zip->set_number('6902406')->is_valid_number, '島根県雲南市三刀屋町高窪');
ok($zip->set_number('6902511')->is_valid_number, '島根県雲南市三刀屋町上熊谷');
ok($zip->set_number('6902512')->is_valid_number, '島根県雲南市三刀屋町多久和');
ok($zip->set_number('6902513')->is_valid_number, '島根県雲南市三刀屋町粟谷');
ok($zip->set_number('6902521')->is_valid_number, '島根県雲南市三刀屋町神代');
ok($zip->set_number('6902522')->is_valid_number, '島根県雲南市三刀屋町六重');
ok($zip->set_number('6902523')->is_valid_number, '島根県雲南市三刀屋町中野');
ok($zip->set_number('6902524')->is_valid_number, '島根県雲南市三刀屋町須所');
ok($zip->set_number('6902525')->is_valid_number, '島根県雲南市三刀屋町坂本(森谷)');
ok($zip->set_number('6902625')->is_valid_number, '島根県雲南市三刀屋町坂本(その他)');
ok($zip->set_number('6902631')->is_valid_number, '島根県雲南市三刀屋町根波別所');
ok($zip->set_number('6902632')->is_valid_number, '島根県雲南市三刀屋町里坊');
ok($zip->set_number('6902633')->is_valid_number, '島根県雲南市三刀屋町殿河内');
ok($zip->set_number('6902634')->is_valid_number, '島根県雲南市三刀屋町乙加宮');
ok($zip->set_number('6902701')->is_valid_number, '島根県雲南市掛合町掛合');
ok($zip->set_number('6902702')->is_valid_number, '島根県雲南市掛合町入間');
ok($zip->set_number('6902703')->is_valid_number, '島根県雲南市掛合町波多');
ok($zip->set_number('6902704')->is_valid_number, '島根県雲南市掛合町穴見');
ok($zip->set_number('6902705')->is_valid_number, '島根県雲南市掛合町松笠');
ok($zip->set_number('6902706')->is_valid_number, '島根県雲南市掛合町多根');
ok($zip->set_number('6902801')->is_valid_number, '島根県雲南市吉田町吉田');
ok($zip->set_number('6902802')->is_valid_number, '島根県雲南市吉田町民谷');
ok($zip->set_number('6903200')->is_valid_number, '島根県飯石郡飯南町以下に掲載がない場合');
ok($zip->set_number('6903203')->is_valid_number, '島根県飯石郡飯南町都加賀');
ok($zip->set_number('6903204')->is_valid_number, '島根県飯石郡飯南町佐見');
ok($zip->set_number('6903205')->is_valid_number, '島根県飯石郡飯南町長谷');
ok($zip->set_number('6903206')->is_valid_number, '島根県飯石郡飯南町花栗');
ok($zip->set_number('6903207')->is_valid_number, '島根県飯石郡飯南町頓原');
ok($zip->set_number('6903311')->is_valid_number, '島根県飯石郡飯南町獅子');
ok($zip->set_number('6903312')->is_valid_number, '島根県飯石郡飯南町八神');
ok($zip->set_number('6903313')->is_valid_number, '島根県飯石郡飯南町志津見');
ok($zip->set_number('6903314')->is_valid_number, '島根県飯石郡飯南町角井');
ok($zip->set_number('6903401')->is_valid_number, '島根県飯石郡飯南町野萱');
ok($zip->set_number('6903402')->is_valid_number, '島根県飯石郡飯南町下来島');
ok($zip->set_number('6903403')->is_valid_number, '島根県飯石郡飯南町小田');
ok($zip->set_number('6903404')->is_valid_number, '島根県飯石郡飯南町真木');
ok($zip->set_number('6903405')->is_valid_number, '島根県飯石郡飯南町上来島');
ok($zip->set_number('6903511')->is_valid_number, '島根県飯石郡飯南町赤名');
ok($zip->set_number('6903512')->is_valid_number, '島根県飯石郡飯南町上赤名');
ok($zip->set_number('6903513')->is_valid_number, '島根県飯石郡飯南町下赤名');
ok($zip->set_number('6903514')->is_valid_number, '島根県飯石郡飯南町井戸谷');
ok($zip->set_number('6903515')->is_valid_number, '島根県飯石郡飯南町塩谷');
ok($zip->set_number('6903516')->is_valid_number, '島根県飯石郡飯南町畑田');
ok($zip->set_number('6910001')->is_valid_number, '島根県出雲市平田町');
ok($zip->set_number('6910002')->is_valid_number, '島根県出雲市西平田町');
ok($zip->set_number('6910003')->is_valid_number, '島根県出雲市灘分町');
ok($zip->set_number('6910004')->is_valid_number, '島根県出雲市島村町');
ok($zip->set_number('6910011')->is_valid_number, '島根県出雲市国富町');
ok($zip->set_number('6910012')->is_valid_number, '島根県出雲市西代町');
ok($zip->set_number('6910013')->is_valid_number, '島根県出雲市美談町');
ok($zip->set_number('6910014')->is_valid_number, '島根県出雲市口宇賀町');
ok($zip->set_number('6910015')->is_valid_number, '島根県出雲市西郷町');
ok($zip->set_number('6910021')->is_valid_number, '島根県出雲市奥宇賀町');
ok($zip->set_number('6910022')->is_valid_number, '島根県出雲市別所町');
ok($zip->set_number('6910023')->is_valid_number, '島根県出雲市唐川町');
ok($zip->set_number('6910024')->is_valid_number, '島根県出雲市猪目町');
ok($zip->set_number('6910025')->is_valid_number, '島根県出雲市河下町');
ok($zip->set_number('6910031')->is_valid_number, '島根県出雲市東福町');
ok($zip->set_number('6910032')->is_valid_number, '島根県出雲市本庄町');
ok($zip->set_number('6910033')->is_valid_number, '島根県出雲市万田町');
ok($zip->set_number('6910034')->is_valid_number, '島根県出雲市久多見町');
ok($zip->set_number('6910041')->is_valid_number, '島根県出雲市小津町');
ok($zip->set_number('6910042')->is_valid_number, '島根県出雲市十六島町');
ok($zip->set_number('6910043')->is_valid_number, '島根県出雲市釜浦町');
ok($zip->set_number('6910044')->is_valid_number, '島根県出雲市塩津町');
ok($zip->set_number('6910045')->is_valid_number, '島根県出雲市美保町');
ok($zip->set_number('6910051')->is_valid_number, '島根県出雲市坂浦町');
ok($zip->set_number('6910052')->is_valid_number, '島根県出雲市小伊津町');
ok($zip->set_number('6910053')->is_valid_number, '島根県出雲市三津町');
ok($zip->set_number('6910061')->is_valid_number, '島根県出雲市多久町');
ok($zip->set_number('6910062')->is_valid_number, '島根県出雲市多久谷町');
ok($zip->set_number('6910063')->is_valid_number, '島根県出雲市岡田町');
ok($zip->set_number('6910064')->is_valid_number, '島根県出雲市上岡田町');
ok($zip->set_number('6910065')->is_valid_number, '島根県出雲市東郷町');
ok($zip->set_number('6910066')->is_valid_number, '島根県出雲市野石谷町');
ok($zip->set_number('6910071')->is_valid_number, '島根県出雲市地合町');
ok($zip->set_number('6910072')->is_valid_number, '島根県出雲市野郷町');
ok($zip->set_number('6910073')->is_valid_number, '島根県出雲市美野町');
ok($zip->set_number('6910074')->is_valid_number, '島根県出雲市小境町');
ok($zip->set_number('6910075')->is_valid_number, '島根県出雲市鹿園寺町');
ok($zip->set_number('6910076')->is_valid_number, '島根県出雲市園町');
ok($zip->set_number('6920000')->is_valid_number, '島根県安来市以下に掲載がない場合');
ok($zip->set_number('6920001')->is_valid_number, '島根県安来市赤江町');
ok($zip->set_number('6920002')->is_valid_number, '島根県安来市上坂田町');
ok($zip->set_number('6920003')->is_valid_number, '島根県安来市西赤江町');
ok($zip->set_number('6920004')->is_valid_number, '島根県安来市久白町');
ok($zip->set_number('6920005')->is_valid_number, '島根県安来市日白町');
ok($zip->set_number('6920006')->is_valid_number, '島根県安来市西荒島町');
ok($zip->set_number('6920007')->is_valid_number, '島根県安来市荒島町');
ok($zip->set_number('6920011')->is_valid_number, '島根県安来市安来町');
ok($zip->set_number('6920012')->is_valid_number, '島根県安来市宮内町');
ok($zip->set_number('6920013')->is_valid_number, '島根県安来市月坂町');
ok($zip->set_number('6920014')->is_valid_number, '島根県安来市飯島町');
ok($zip->set_number('6920015')->is_valid_number, '島根県安来市今津町');
ok($zip->set_number('6920016')->is_valid_number, '島根県安来市東赤江町');
ok($zip->set_number('6920017')->is_valid_number, '島根県安来市下坂田町');
ok($zip->set_number('6920021')->is_valid_number, '島根県安来市新十神町');
ok($zip->set_number('6920022')->is_valid_number, '島根県安来市南十神町');
ok($zip->set_number('6920023')->is_valid_number, '島根県安来市黒井田町');
ok($zip->set_number('6920024')->is_valid_number, '島根県安来市島田町');
ok($zip->set_number('6920025')->is_valid_number, '島根県安来市穂日島町');
ok($zip->set_number('6920026')->is_valid_number, '島根県安来市吉佐町');
ok($zip->set_number('6920027')->is_valid_number, '島根県安来市門生町');
ok($zip->set_number('6920028')->is_valid_number, '島根県安来市汐手が丘');
ok($zip->set_number('6920031')->is_valid_number, '島根県安来市佐久保町');
ok($zip->set_number('6920032')->is_valid_number, '島根県安来市九重町');
ok($zip->set_number('6920033')->is_valid_number, '島根県安来市清水町');
ok($zip->set_number('6920034')->is_valid_number, '島根県安来市宇賀荘町');
ok($zip->set_number('6920035')->is_valid_number, '島根県安来市清瀬町');
ok($zip->set_number('6920036')->is_valid_number, '島根県安来市野方町');
ok($zip->set_number('6920037')->is_valid_number, '島根県安来市吉岡町');
ok($zip->set_number('6920041')->is_valid_number, '島根県安来市鳥木町');
ok($zip->set_number('6920042')->is_valid_number, '島根県安来市大塚町');
ok($zip->set_number('6920043')->is_valid_number, '島根県安来市上吉田町');
ok($zip->set_number('6920044')->is_valid_number, '島根県安来市下吉田町');
ok($zip->set_number('6920045')->is_valid_number, '島根県安来市柿谷町');
ok($zip->set_number('6920046')->is_valid_number, '島根県安来市折坂町');
ok($zip->set_number('6920047')->is_valid_number, '島根県安来市早田町');
ok($zip->set_number('6920051')->is_valid_number, '島根県安来市切川町');
ok($zip->set_number('6920052')->is_valid_number, '島根県安来市赤崎町');
ok($zip->set_number('6920053')->is_valid_number, '島根県安来市沢町');
ok($zip->set_number('6920054')->is_valid_number, '島根県安来市利弘町');
ok($zip->set_number('6920055')->is_valid_number, '島根県安来市飯生町');
ok($zip->set_number('6920056')->is_valid_number, '島根県安来市清井町');
ok($zip->set_number('6920057')->is_valid_number, '島根県安来市恵乃島町');
ok($zip->set_number('6920058')->is_valid_number, '島根県安来市西恵乃島町');
ok($zip->set_number('6920061')->is_valid_number, '島根県安来市中津町');
ok($zip->set_number('6920062')->is_valid_number, '島根県安来市実松町');
ok($zip->set_number('6920063')->is_valid_number, '島根県安来市植田町');
ok($zip->set_number('6920064')->is_valid_number, '島根県安来市古川町');
ok($zip->set_number('6920065')->is_valid_number, '島根県安来市岩舟町');
ok($zip->set_number('6920066')->is_valid_number, '島根県安来市飯梨町');
ok($zip->set_number('6920067')->is_valid_number, '島根県安来市田頼町');
ok($zip->set_number('6920071')->is_valid_number, '島根県安来市亀島町');
ok($zip->set_number('6920072')->is_valid_number, '島根県安来市能義町');
ok($zip->set_number('6920073')->is_valid_number, '島根県安来市矢田町');
ok($zip->set_number('6920074')->is_valid_number, '島根県安来市中海町');
ok($zip->set_number('6920075')->is_valid_number, '島根県安来市神庭町');
ok($zip->set_number('6920077')->is_valid_number, '島根県安来市西松井町');
ok($zip->set_number('6920201')->is_valid_number, '島根県安来市伯太町安田山形');
ok($zip->set_number('6920202')->is_valid_number, '島根県安来市伯太町安田関');
ok($zip->set_number('6920203')->is_valid_number, '島根県安来市伯太町未明');
ok($zip->set_number('6920204')->is_valid_number, '島根県安来市伯太町安田宮内');
ok($zip->set_number('6920205')->is_valid_number, '島根県安来市伯太町安田中');
ok($zip->set_number('6920206')->is_valid_number, '島根県安来市伯太町安田');
ok($zip->set_number('6920207')->is_valid_number, '島根県安来市伯太町東母里');
ok($zip->set_number('6920211')->is_valid_number, '島根県安来市伯太町母里');
ok($zip->set_number('6920212')->is_valid_number, '島根県安来市伯太町西母里');
ok($zip->set_number('6920213')->is_valid_number, '島根県安来市伯太町井尻');
ok($zip->set_number('6920214')->is_valid_number, '島根県安来市伯太町須山福冨');
ok($zip->set_number('6920215')->is_valid_number, '島根県安来市伯太町高江寸次');
ok($zip->set_number('6920216')->is_valid_number, '島根県安来市伯太町日次');
ok($zip->set_number('6920217')->is_valid_number, '島根県安来市伯太町横屋');
ok($zip->set_number('6920218')->is_valid_number, '島根県安来市伯太町峠之内');
ok($zip->set_number('6920321')->is_valid_number, '島根県安来市伯太町赤屋');
ok($zip->set_number('6920322')->is_valid_number, '島根県安来市伯太町上小竹');
ok($zip->set_number('6920323')->is_valid_number, '島根県安来市伯太町下小竹');
ok($zip->set_number('6920324')->is_valid_number, '島根県安来市伯太町草野');
ok($zip->set_number('6920325')->is_valid_number, '島根県安来市伯太町上十年畑');
ok($zip->set_number('6920326')->is_valid_number, '島根県安来市伯太町下十年畑');
ok($zip->set_number('6920401')->is_valid_number, '島根県安来市広瀬町石原');
ok($zip->set_number('6920402')->is_valid_number, '島根県安来市広瀬町町帳');
ok($zip->set_number('6920403')->is_valid_number, '島根県安来市広瀬町富田');
ok($zip->set_number('6920404')->is_valid_number, '島根県安来市広瀬町広瀬');
ok($zip->set_number('6920405')->is_valid_number, '島根県安来市広瀬町祖父谷');
ok($zip->set_number('6920411')->is_valid_number, '島根県安来市広瀬町菅原(下田原)');
ok($zip->set_number('6920412')->is_valid_number, '島根県安来市広瀬町下山佐');
ok($zip->set_number('6920413')->is_valid_number, '島根県安来市広瀬町上山佐');
ok($zip->set_number('6920621')->is_valid_number, '島根県安来市広瀬町菅原(その他)');
ok($zip->set_number('6920622')->is_valid_number, '島根県安来市広瀬町宇波');
ok($zip->set_number('6920623')->is_valid_number, '島根県安来市広瀬町布部');
ok($zip->set_number('6920624')->is_valid_number, '島根県安来市広瀬町西谷');
ok($zip->set_number('6920625')->is_valid_number, '島根県安来市広瀬町奥田原');
ok($zip->set_number('6920731')->is_valid_number, '島根県安来市広瀬町西比田');
ok($zip->set_number('6920732')->is_valid_number, '島根県安来市広瀬町梶福留');
ok($zip->set_number('6920733')->is_valid_number, '島根県安来市広瀬町東比田');
ok($zip->set_number('6930000')->is_valid_number, '島根県出雲市以下に掲載がない場合');
ok($zip->set_number('6930001')->is_valid_number, '島根県出雲市今市町');
ok($zip->set_number('6930002')->is_valid_number, '島根県出雲市今市町北本町');
ok($zip->set_number('6930003')->is_valid_number, '島根県出雲市今市町南本町');
ok($zip->set_number('6930004')->is_valid_number, '島根県出雲市渡橋町');
ok($zip->set_number('6930005')->is_valid_number, '島根県出雲市天神町');
ok($zip->set_number('6930006')->is_valid_number, '島根県出雲市白枝町');
ok($zip->set_number('6930007')->is_valid_number, '島根県出雲市駅北町');
ok($zip->set_number('6930008')->is_valid_number, '島根県出雲市駅南町');
ok($zip->set_number('6930011')->is_valid_number, '島根県出雲市大津町');
ok($zip->set_number('6930012')->is_valid_number, '島根県出雲市大津新崎町');
ok($zip->set_number('6930013')->is_valid_number, '島根県出雲市荻杼町');
ok($zip->set_number('6930014')->is_valid_number, '島根県出雲市武志町');
ok($zip->set_number('6930015')->is_valid_number, '島根県出雲市大津朝倉');
ok($zip->set_number('6930017')->is_valid_number, '島根県出雲市枝大津町');
ok($zip->set_number('6930021')->is_valid_number, '島根県出雲市塩冶町');
ok($zip->set_number('6930022')->is_valid_number, '島根県出雲市上塩冶町');
ok($zip->set_number('6930023')->is_valid_number, '島根県出雲市塩冶有原町');
ok($zip->set_number('6930024')->is_valid_number, '島根県出雲市塩冶神前');
ok($zip->set_number('6930025')->is_valid_number, '島根県出雲市塩冶町南町');
ok($zip->set_number('6930026')->is_valid_number, '島根県出雲市塩冶原町');
ok($zip->set_number('6930027')->is_valid_number, '島根県出雲市医大南町');
ok($zip->set_number('6930028')->is_valid_number, '島根県出雲市塩冶善行町');
ok($zip->set_number('6930029')->is_valid_number, '島根県出雲市築山新町');
ok($zip->set_number('6930031')->is_valid_number, '島根県出雲市古志町');
ok($zip->set_number('6930032')->is_valid_number, '島根県出雲市下古志町');
ok($zip->set_number('6930033')->is_valid_number, '島根県出雲市知井宮町');
ok($zip->set_number('6930034')->is_valid_number, '島根県出雲市神門町');
ok($zip->set_number('6930035')->is_valid_number, '島根県出雲市芦渡町');
ok($zip->set_number('6930036')->is_valid_number, '島根県出雲市平成町');
ok($zip->set_number('6930037')->is_valid_number, '島根県出雲市西新町');
ok($zip->set_number('6930041')->is_valid_number, '島根県出雲市西園町');
ok($zip->set_number('6930042')->is_valid_number, '島根県出雲市外園町');
ok($zip->set_number('6930043')->is_valid_number, '島根県出雲市長浜町');
ok($zip->set_number('6930044')->is_valid_number, '島根県出雲市荒茅町');
ok($zip->set_number('6930045')->is_valid_number, '島根県出雲市東園町');
ok($zip->set_number('6930046')->is_valid_number, '島根県出雲市下横町');
ok($zip->set_number('6930051')->is_valid_number, '島根県出雲市小山町');
ok($zip->set_number('6930052')->is_valid_number, '島根県出雲市松寄下町');
ok($zip->set_number('6930053')->is_valid_number, '島根県出雲市高松町');
ok($zip->set_number('6930054')->is_valid_number, '島根県出雲市浜町');
ok($zip->set_number('6930055')->is_valid_number, '島根県出雲市八島町');
ok($zip->set_number('6930056')->is_valid_number, '島根県出雲市江田町');
ok($zip->set_number('6930057')->is_valid_number, '島根県出雲市常松町');
ok($zip->set_number('6930058')->is_valid_number, '島根県出雲市矢野町');
ok($zip->set_number('6930061')->is_valid_number, '島根県出雲市姫原町');
ok($zip->set_number('6930062')->is_valid_number, '島根県出雲市中野町');
ok($zip->set_number('6930063')->is_valid_number, '島根県出雲市大塚町');
ok($zip->set_number('6930064')->is_valid_number, '島根県出雲市里方町');
ok($zip->set_number('6930065')->is_valid_number, '島根県出雲市平野町');
ok($zip->set_number('6930066')->is_valid_number, '島根県出雲市高岡町');
ok($zip->set_number('6930067')->is_valid_number, '島根県出雲市矢尾町');
ok($zip->set_number('6930068')->is_valid_number, '島根県出雲市姫原(1~4丁目)');
ok($zip->set_number('6930071')->is_valid_number, '島根県出雲市稲岡町');
ok($zip->set_number('6930072')->is_valid_number, '島根県出雲市日下町');
ok($zip->set_number('6930073')->is_valid_number, '島根県出雲市西林木町');
ok($zip->set_number('6930074')->is_valid_number, '島根県出雲市東林木町');
ok($zip->set_number('6930081')->is_valid_number, '島根県出雲市中野美保北');
ok($zip->set_number('6930082')->is_valid_number, '島根県出雲市中野美保南');
ok($zip->set_number('6930101')->is_valid_number, '島根県出雲市上島町');
ok($zip->set_number('6930102')->is_valid_number, '島根県出雲市西谷町');
ok($zip->set_number('6930103')->is_valid_number, '島根県出雲市野尻町');
ok($zip->set_number('6930104')->is_valid_number, '島根県出雲市稗原町');
ok($zip->set_number('6930105')->is_valid_number, '島根県出雲市宇那手町');
ok($zip->set_number('6930106')->is_valid_number, '島根県出雲市船津町');
ok($zip->set_number('6930211')->is_valid_number, '島根県出雲市馬木北町');
ok($zip->set_number('6930212')->is_valid_number, '島根県出雲市馬木町');
ok($zip->set_number('6930213')->is_valid_number, '島根県出雲市朝山町');
ok($zip->set_number('6930214')->is_valid_number, '島根県出雲市所原町');
ok($zip->set_number('6930215')->is_valid_number, '島根県出雲市見々久町');
ok($zip->set_number('6930216')->is_valid_number, '島根県出雲市乙立町');
ok($zip->set_number('6930501')->is_valid_number, '島根県出雲市佐田町朝原');
ok($zip->set_number('6930502')->is_valid_number, '島根県出雲市佐田町原田');
ok($zip->set_number('6930503')->is_valid_number, '島根県出雲市佐田町須佐');
ok($zip->set_number('6930504')->is_valid_number, '島根県出雲市佐田町大呂');
ok($zip->set_number('6930505')->is_valid_number, '島根県出雲市佐田町吉野');
ok($zip->set_number('6930506')->is_valid_number, '島根県出雲市佐田町反辺');
ok($zip->set_number('6930511')->is_valid_number, '島根県出雲市佐田町八幡原');
ok($zip->set_number('6930512')->is_valid_number, '島根県出雲市佐田町東村');
ok($zip->set_number('6930521')->is_valid_number, '島根県出雲市佐田町毛津');
ok($zip->set_number('6930522')->is_valid_number, '島根県出雲市佐田町一窪田');
ok($zip->set_number('6930523')->is_valid_number, '島根県出雲市佐田町佐津目');
ok($zip->set_number('6930524')->is_valid_number, '島根県出雲市佐田町高津屋');
ok($zip->set_number('6930525')->is_valid_number, '島根県出雲市佐田町下橋波');
ok($zip->set_number('6930526')->is_valid_number, '島根県出雲市佐田町上橋波');
ok($zip->set_number('6940000')->is_valid_number, '島根県大田市以下に掲載がない場合');
ok($zip->set_number('6940001')->is_valid_number, '島根県大田市山口町佐津目');
ok($zip->set_number('6940002')->is_valid_number, '島根県大田市山口町山口');
ok($zip->set_number('6940003')->is_valid_number, '島根県大田市三瓶町多根');
ok($zip->set_number('6940004')->is_valid_number, '島根県大田市三瓶町野城');
ok($zip->set_number('6940011')->is_valid_number, '島根県大田市川合町川合');
ok($zip->set_number('6940012')->is_valid_number, '島根県大田市川合町忍原');
ok($zip->set_number('6940013')->is_valid_number, '島根県大田市川合町吉永');
ok($zip->set_number('6940021')->is_valid_number, '島根県大田市久利町行恒');
ok($zip->set_number('6940022')->is_valid_number, '島根県大田市久利町市原');
ok($zip->set_number('6940023')->is_valid_number, '島根県大田市久利町佐摩');
ok($zip->set_number('6940024')->is_valid_number, '島根県大田市久利町久利');
ok($zip->set_number('6940025')->is_valid_number, '島根県大田市久利町松代');
ok($zip->set_number('6940031')->is_valid_number, '島根県大田市静間町');
ok($zip->set_number('6940032')->is_valid_number, '島根県大田市大屋町鬼村');
ok($zip->set_number('6940033')->is_valid_number, '島根県大田市大屋町大国');
ok($zip->set_number('6940034')->is_valid_number, '島根県大田市大屋町大屋');
ok($zip->set_number('6940035')->is_valid_number, '島根県大田市五十猛町');
ok($zip->set_number('6940041')->is_valid_number, '島根県大田市長久町長久');
ok($zip->set_number('6940042')->is_valid_number, '島根県大田市長久町稲用');
ok($zip->set_number('6940043')->is_valid_number, '島根県大田市長久町延里');
ok($zip->set_number('6940044')->is_valid_number, '島根県大田市長久町土江');
ok($zip->set_number('6940051')->is_valid_number, '島根県大田市久手町波根西');
ok($zip->set_number('6940052')->is_valid_number, '島根県大田市久手町刺鹿');
ok($zip->set_number('6940053')->is_valid_number, '島根県大田市鳥井町鳥越');
ok($zip->set_number('6940054')->is_valid_number, '島根県大田市鳥井町鳥井');
ok($zip->set_number('6940061')->is_valid_number, '島根県大田市富山町山中(押ケ峠)');
ok($zip->set_number('6940062')->is_valid_number, '島根県大田市大田町野城');
ok($zip->set_number('6940063')->is_valid_number, '島根県大田市大田町吉永');
ok($zip->set_number('6940064')->is_valid_number, '島根県大田市大田町大田');
ok($zip->set_number('6940221')->is_valid_number, '島根県大田市三瓶町上山');
ok($zip->set_number('6940222')->is_valid_number, '島根県大田市三瓶町志学');
ok($zip->set_number('6940223')->is_valid_number, '島根県大田市三瓶町池田');
ok($zip->set_number('6940224')->is_valid_number, '島根県大田市三瓶町小屋原');
ok($zip->set_number('6940301')->is_valid_number, '島根県大田市水上町荻原');
ok($zip->set_number('6940302')->is_valid_number, '島根県大田市水上町福原');
ok($zip->set_number('6940303')->is_valid_number, '島根県大田市水上町白坏');
ok($zip->set_number('6940304')->is_valid_number, '島根県大田市水上町三久須');
ok($zip->set_number('6940305')->is_valid_number, '島根県大田市大森町');
ok($zip->set_number('6940431')->is_valid_number, '島根県大田市祖式町');
ok($zip->set_number('6940432')->is_valid_number, '島根県大田市大代町新屋');
ok($zip->set_number('6940433')->is_valid_number, '島根県大田市大代町大家');
ok($zip->set_number('6950000')->is_valid_number, '島根県江津市以下に掲載がない場合');
ok($zip->set_number('6950001')->is_valid_number, '島根県江津市渡津町');
ok($zip->set_number('6950002')->is_valid_number, '島根県江津市浅利町');
ok($zip->set_number('6950003')->is_valid_number, '島根県江津市松川町下河戸');
ok($zip->set_number('6950004')->is_valid_number, '島根県江津市松川町市村');
ok($zip->set_number('6950005')->is_valid_number, '島根県江津市松川町長良');
ok($zip->set_number('6950006')->is_valid_number, '島根県江津市松川町八神');
ok($zip->set_number('6950007')->is_valid_number, '島根県江津市松川町太田');
ok($zip->set_number('6950011')->is_valid_number, '島根県江津市江津町');
ok($zip->set_number('6950012')->is_valid_number, '島根県江津市金田町');
ok($zip->set_number('6950013')->is_valid_number, '島根県江津市川平町南川上');
ok($zip->set_number('6950014')->is_valid_number, '島根県江津市川平町平田');
ok($zip->set_number('6950015')->is_valid_number, '島根県江津市島の星町');
ok($zip->set_number('6950016')->is_valid_number, '島根県江津市嘉久志町');
ok($zip->set_number('6950017')->is_valid_number, '島根県江津市和木町');
ok($zip->set_number('6950021')->is_valid_number, '島根県江津市都野津町');
ok($zip->set_number('6950022')->is_valid_number, '島根県江津市二宮町羽代');
ok($zip->set_number('6950023')->is_valid_number, '島根県江津市二宮町神村');
ok($zip->set_number('6950024')->is_valid_number, '島根県江津市二宮町神主');
ok($zip->set_number('6950101')->is_valid_number, '島根県浜田市下有福町');
ok($zip->set_number('6950102')->is_valid_number, '島根県浜田市宇野町');
ok($zip->set_number('6950103')->is_valid_number, '島根県浜田市大金町');
ok($zip->set_number('6950151')->is_valid_number, '島根県江津市千田町');
ok($zip->set_number('6950152')->is_valid_number, '島根県江津市跡市町');
ok($zip->set_number('6950153')->is_valid_number, '島根県江津市清見町');
ok($zip->set_number('6950154')->is_valid_number, '島根県江津市井沢町');
ok($zip->set_number('6950155')->is_valid_number, '島根県江津市有福温泉町本明');
ok($zip->set_number('6950156')->is_valid_number, '島根県江津市有福温泉町');
ok($zip->set_number('6960000')->is_valid_number, '島根県邑智郡川本町以下に掲載がない場合');
ok($zip->set_number('6960001')->is_valid_number, '島根県邑智郡川本町川本');
ok($zip->set_number('6960002')->is_valid_number, '島根県邑智郡川本町都賀行');
ok($zip->set_number('6960003')->is_valid_number, '島根県邑智郡川本町因原');
ok($zip->set_number('6960004')->is_valid_number, '島根県邑智郡川本町川下');
ok($zip->set_number('6960005')->is_valid_number, '島根県邑智郡川本町谷戸');
ok($zip->set_number('6960006')->is_valid_number, '島根県邑智郡川本町久座仁');
ok($zip->set_number('6960007')->is_valid_number, '島根県邑智郡川本町多田');
ok($zip->set_number('6960011')->is_valid_number, '島根県邑智郡川本町川内');
ok($zip->set_number('6960012')->is_valid_number, '島根県邑智郡川本町小谷');
ok($zip->set_number('6960013')->is_valid_number, '島根県邑智郡川本町馬野原');
ok($zip->set_number('6960100')->is_valid_number, '島根県邑智郡邑南町以下に掲載がない場合');
ok($zip->set_number('6960101')->is_valid_number, '島根県邑智郡邑南町井原');
ok($zip->set_number('6960102')->is_valid_number, '島根県邑智郡邑南町中野');
ok($zip->set_number('6960103')->is_valid_number, '島根県邑智郡邑南町矢上');
ok($zip->set_number('6960104')->is_valid_number, '島根県邑智郡邑南町日和');
ok($zip->set_number('6960131')->is_valid_number, '島根県邑智郡邑南町高水');
ok($zip->set_number('6960221')->is_valid_number, '島根県邑智郡邑南町鱒渕');
ok($zip->set_number('6960222')->is_valid_number, '島根県邑智郡邑南町下田所');
ok($zip->set_number('6960223')->is_valid_number, '島根県邑智郡邑南町下亀谷');
ok($zip->set_number('6960224')->is_valid_number, '島根県邑智郡邑南町上亀谷');
ok($zip->set_number('6960225')->is_valid_number, '島根県邑智郡邑南町上田所');
ok($zip->set_number('6960311')->is_valid_number, '島根県邑智郡邑南町三日市');
ok($zip->set_number('6960312')->is_valid_number, '島根県邑智郡邑南町出羽');
ok($zip->set_number('6960313')->is_valid_number, '島根県邑智郡邑南町山田');
ok($zip->set_number('6960314')->is_valid_number, '島根県邑智郡邑南町岩屋');
ok($zip->set_number('6960315')->is_valid_number, '島根県邑智郡邑南町大林');
ok($zip->set_number('6960316')->is_valid_number, '島根県邑智郡邑南町久喜');
ok($zip->set_number('6960317')->is_valid_number, '島根県邑智郡邑南町淀原');
ok($zip->set_number('6960401')->is_valid_number, '島根県邑智郡邑南町布施');
ok($zip->set_number('6960402')->is_valid_number, '島根県邑智郡邑南町伏谷');
ok($zip->set_number('6960403')->is_valid_number, '島根県邑智郡邑南町和田');
ok($zip->set_number('6960404')->is_valid_number, '島根県邑智郡邑南町原村');
ok($zip->set_number('6960405')->is_valid_number, '島根県邑智郡邑南町上原');
ok($zip->set_number('6960406')->is_valid_number, '島根県邑智郡邑南町高見');
ok($zip->set_number('6960407')->is_valid_number, '島根県邑智郡邑南町八色石');
ok($zip->set_number('6960501')->is_valid_number, '島根県邑智郡邑南町阿須那');
ok($zip->set_number('6960502')->is_valid_number, '島根県邑智郡邑南町木須田');
ok($zip->set_number('6960503')->is_valid_number, '島根県邑智郡邑南町宇都井');
ok($zip->set_number('6960504')->is_valid_number, '島根県邑智郡邑南町今井');
ok($zip->set_number('6960505')->is_valid_number, '島根県邑智郡邑南町戸河内');
ok($zip->set_number('6960506')->is_valid_number, '島根県邑智郡邑南町雪田');
ok($zip->set_number('6960601')->is_valid_number, '島根県邑智郡邑南町上田');
ok($zip->set_number('6960602')->is_valid_number, '島根県邑智郡邑南町上口羽');
ok($zip->set_number('6960603')->is_valid_number, '島根県邑智郡邑南町下口羽');
ok($zip->set_number('6960701')->is_valid_number, '島根県邑智郡美郷町潮村');
ok($zip->set_number('6960702')->is_valid_number, '島根県邑智郡美郷町上野');
ok($zip->set_number('6960703')->is_valid_number, '島根県邑智郡美郷町都賀西');
ok($zip->set_number('6960704')->is_valid_number, '島根県邑智郡美郷町都賀本郷');
ok($zip->set_number('6960705')->is_valid_number, '島根県邑智郡美郷町都賀行');
ok($zip->set_number('6960706')->is_valid_number, '島根県邑智郡美郷町長藤');
ok($zip->set_number('6960711')->is_valid_number, '島根県邑智郡美郷町宮内');
ok($zip->set_number('6960712')->is_valid_number, '島根県邑智郡美郷町比敷');
ok($zip->set_number('6960713')->is_valid_number, '島根県邑智郡美郷町村之郷');
ok($zip->set_number('6961131')->is_valid_number, '島根県邑智郡美郷町別府');
ok($zip->set_number('6961132')->is_valid_number, '島根県邑智郡美郷町志君');
ok($zip->set_number('6961133')->is_valid_number, '島根県邑智郡美郷町小林');
ok($zip->set_number('6961134')->is_valid_number, '島根県邑智郡美郷町惣森');
ok($zip->set_number('6961135')->is_valid_number, '島根県邑智郡美郷町小松地');
ok($zip->set_number('6961136')->is_valid_number, '島根県邑智郡美郷町内田');
ok($zip->set_number('6961137')->is_valid_number, '島根県邑智郡美郷町櫨谷');
ok($zip->set_number('6961141')->is_valid_number, '島根県邑智郡美郷町京覧原');
ok($zip->set_number('6961142')->is_valid_number, '島根県邑智郡美郷町久喜原');
ok($zip->set_number('6961143')->is_valid_number, '島根県邑智郡美郷町地頭所');
ok($zip->set_number('6961144')->is_valid_number, '島根県邑智郡美郷町小谷');
ok($zip->set_number('6961145')->is_valid_number, '島根県邑智郡美郷町港');
ok($zip->set_number('6961221')->is_valid_number, '島根県邑智郡川本町北佐木');
ok($zip->set_number('6961222')->is_valid_number, '島根県邑智郡川本町湯谷');
ok($zip->set_number('6961223')->is_valid_number, '島根県邑智郡川本町三俣');
ok($zip->set_number('6961224')->is_valid_number, '島根県邑智郡川本町三原');
ok($zip->set_number('6961225')->is_valid_number, '島根県邑智郡川本町南佐木');
ok($zip->set_number('6961226')->is_valid_number, '島根県邑智郡川本町田窪');
ok($zip->set_number('6970000')->is_valid_number, '島根県浜田市以下に掲載がない場合');
ok($zip->set_number('6970001')->is_valid_number, '島根県浜田市外ノ浦町');
ok($zip->set_number('6970002')->is_valid_number, '島根県浜田市生湯町');
ok($zip->set_number('6970003')->is_valid_number, '島根県浜田市国分町');
ok($zip->set_number('6970004')->is_valid_number, '島根県浜田市久代町');
ok($zip->set_number('6970005')->is_valid_number, '島根県浜田市上府町');
ok($zip->set_number('6970006')->is_valid_number, '島根県浜田市下府町');
ok($zip->set_number('6970007')->is_valid_number, '島根県浜田市高佐町');
ok($zip->set_number('6970011')->is_valid_number, '島根県浜田市後野町');
ok($zip->set_number('6970012')->is_valid_number, '島根県浜田市河内町');
ok($zip->set_number('6970013')->is_valid_number, '島根県浜田市三階町');
ok($zip->set_number('6970014')->is_valid_number, '島根県浜田市長見町');
ok($zip->set_number('6970015')->is_valid_number, '島根県浜田市竹迫町');
ok($zip->set_number('6970016')->is_valid_number, '島根県浜田市野原町');
ok($zip->set_number('6970017')->is_valid_number, '島根県浜田市原井町');
ok($zip->set_number('6970021')->is_valid_number, '島根県浜田市松原町');
ok($zip->set_number('6970022')->is_valid_number, '島根県浜田市浅井町');
ok($zip->set_number('6970023')->is_valid_number, '島根県浜田市長沢町');
ok($zip->set_number('6970024')->is_valid_number, '島根県浜田市黒川町');
ok($zip->set_number('6970025')->is_valid_number, '島根県浜田市琵琶町');
ok($zip->set_number('6970026')->is_valid_number, '島根県浜田市田町');
ok($zip->set_number('6970027')->is_valid_number, '島根県浜田市殿町');
ok($zip->set_number('6970031')->is_valid_number, '島根県浜田市紺屋町');
ok($zip->set_number('6970032')->is_valid_number, '島根県浜田市牛市町');
ok($zip->set_number('6970033')->is_valid_number, '島根県浜田市朝日町');
ok($zip->set_number('6970034')->is_valid_number, '島根県浜田市相生町');
ok($zip->set_number('6970035')->is_valid_number, '島根県浜田市杉戸町');
ok($zip->set_number('6970036')->is_valid_number, '島根県浜田市天満町');
ok($zip->set_number('6970037')->is_valid_number, '島根県浜田市新町');
ok($zip->set_number('6970041')->is_valid_number, '島根県浜田市片庭町');
ok($zip->set_number('6970042')->is_valid_number, '島根県浜田市錦町');
ok($zip->set_number('6970043')->is_valid_number, '島根県浜田市栄町');
ok($zip->set_number('6970044')->is_valid_number, '島根県浜田市蛭子町');
ok($zip->set_number('6970045')->is_valid_number, '島根県浜田市京町');
ok($zip->set_number('6970046')->is_valid_number, '島根県浜田市真光町');
ok($zip->set_number('6970047')->is_valid_number, '島根県浜田市清水町');
ok($zip->set_number('6970051')->is_valid_number, '島根県浜田市瀬戸ケ島町');
ok($zip->set_number('6970052')->is_valid_number, '島根県浜田市港町');
ok($zip->set_number('6970053')->is_valid_number, '島根県浜田市大辻町');
ok($zip->set_number('6970054')->is_valid_number, '島根県浜田市高田町');
ok($zip->set_number('6970055')->is_valid_number, '島根県浜田市元浜町');
ok($zip->set_number('6970056')->is_valid_number, '島根県浜田市原町');
ok($zip->set_number('6970057')->is_valid_number, '島根県浜田市瀬戸見町');
ok($zip->set_number('6970061')->is_valid_number, '島根県浜田市笠柄町');
ok($zip->set_number('6970062')->is_valid_number, '島根県浜田市熱田町');
ok($zip->set_number('6970063')->is_valid_number, '島根県浜田市長浜町');
ok($zip->set_number('6970064')->is_valid_number, '島根県浜田市内田町(百万騎)');
ok($zip->set_number('6970065')->is_valid_number, '島根県浜田市内村町(十文字原)');
ok($zip->set_number('6970121')->is_valid_number, '島根県浜田市金城町下来原');
ok($zip->set_number('6970122')->is_valid_number, '島根県浜田市金城町上来原');
ok($zip->set_number('6970123')->is_valid_number, '島根県浜田市金城町七条');
ok($zip->set_number('6970211')->is_valid_number, '島根県浜田市金城町波佐');
ok($zip->set_number('6970212')->is_valid_number, '島根県浜田市金城町長田');
ok($zip->set_number('6970213')->is_valid_number, '島根県浜田市金城町小国');
ok($zip->set_number('6970301')->is_valid_number, '島根県浜田市金城町追原');
ok($zip->set_number('6970302')->is_valid_number, '島根県浜田市金城町今福');
ok($zip->set_number('6970303')->is_valid_number, '島根県浜田市金城町久佐');
ok($zip->set_number('6970304')->is_valid_number, '島根県浜田市金城町宇津井');
ok($zip->set_number('6970305')->is_valid_number, '島根県浜田市金城町入野');
ok($zip->set_number('6970311')->is_valid_number, '島根県浜田市佐野町');
ok($zip->set_number('6970312')->is_valid_number, '島根県浜田市宇津井町');
ok($zip->set_number('6970421')->is_valid_number, '島根県浜田市旭町山ノ内');
ok($zip->set_number('6970422')->is_valid_number, '島根県浜田市旭町本郷');
ok($zip->set_number('6970423')->is_valid_number, '島根県浜田市旭町重富');
ok($zip->set_number('6970424')->is_valid_number, '島根県浜田市旭町和田');
ok($zip->set_number('6970425')->is_valid_number, '島根県浜田市旭町今市');
ok($zip->set_number('6970426')->is_valid_number, '島根県浜田市旭町丸原');
ok($zip->set_number('6970427')->is_valid_number, '島根県浜田市旭町木田');
ok($zip->set_number('6970431')->is_valid_number, '島根県浜田市旭町坂本(その他)');
ok($zip->set_number('6970511')->is_valid_number, '島根県浜田市旭町都川');
ok($zip->set_number('6970512')->is_valid_number, '島根県浜田市旭町来尾');
ok($zip->set_number('6970513')->is_valid_number, '島根県浜田市旭町坂本(八ツ木)');
ok($zip->set_number('6970514')->is_valid_number, '島根県浜田市旭町市木');
ok($zip->set_number('6970631')->is_valid_number, '島根県邑智郡邑南町市木');
ok($zip->set_number('6971121')->is_valid_number, '島根県浜田市弥栄町野坂');
ok($zip->set_number('6971122')->is_valid_number, '島根県浜田市弥栄町木都賀');
ok($zip->set_number('6971123')->is_valid_number, '島根県浜田市弥栄町田野原');
ok($zip->set_number('6971201')->is_valid_number, '島根県浜田市弥栄町栃木');
ok($zip->set_number('6971202')->is_valid_number, '島根県浜田市弥栄町小坂');
ok($zip->set_number('6971203')->is_valid_number, '島根県浜田市弥栄町高内');
ok($zip->set_number('6971204')->is_valid_number, '島根県浜田市弥栄町門田');
ok($zip->set_number('6971211')->is_valid_number, '島根県浜田市弥栄町長安本郷');
ok($zip->set_number('6971212')->is_valid_number, '島根県浜田市弥栄町三里');
ok($zip->set_number('6971213')->is_valid_number, '島根県浜田市弥栄町程原');
ok($zip->set_number('6971214')->is_valid_number, '島根県浜田市弥栄町大坪');
ok($zip->set_number('6971215')->is_valid_number, '島根県浜田市弥栄町稲代');
ok($zip->set_number('6971321')->is_valid_number, '島根県浜田市周布町');
ok($zip->set_number('6971322')->is_valid_number, '島根県浜田市日脚町');
ok($zip->set_number('6971323')->is_valid_number, '島根県浜田市内田町(その他)');
ok($zip->set_number('6971324')->is_valid_number, '島根県浜田市穂出町');
ok($zip->set_number('6971325')->is_valid_number, '島根県浜田市吉地町');
ok($zip->set_number('6971326')->is_valid_number, '島根県浜田市治和町');
ok($zip->set_number('6971327')->is_valid_number, '島根県浜田市津摩町');
ok($zip->set_number('6971331')->is_valid_number, '島根県浜田市内村町(その他)');
ok($zip->set_number('6971332')->is_valid_number, '島根県浜田市田橋町');
ok($zip->set_number('6971333')->is_valid_number, '島根県浜田市鍋石町');
ok($zip->set_number('6971334')->is_valid_number, '島根県浜田市櫟田原町');
ok($zip->set_number('6971335')->is_valid_number, '島根県浜田市井野町');
ok($zip->set_number('6971336')->is_valid_number, '島根県浜田市横山町');
ok($zip->set_number('6971337')->is_valid_number, '島根県浜田市西村町');
ok($zip->set_number('6971338')->is_valid_number, '島根県浜田市折居町');
ok($zip->set_number('6980000')->is_valid_number, '島根県益田市以下に掲載がない場合');
ok($zip->set_number('6980001')->is_valid_number, '島根県益田市久城町');
ok($zip->set_number('6980002')->is_valid_number, '島根県益田市下本郷町');
ok($zip->set_number('6980003')->is_valid_number, '島根県益田市乙吉町');
ok($zip->set_number('6980004')->is_valid_number, '島根県益田市東町');
ok($zip->set_number('6980005')->is_valid_number, '島根県益田市本町');
ok($zip->set_number('6980006')->is_valid_number, '島根県益田市三宅町');
ok($zip->set_number('6980007')->is_valid_number, '島根県益田市昭和町');
ok($zip->set_number('6980011')->is_valid_number, '島根県益田市染羽町');
ok($zip->set_number('6980012')->is_valid_number, '島根県益田市大谷町');
ok($zip->set_number('6980013')->is_valid_number, '島根県益田市久々茂町');
ok($zip->set_number('6980014')->is_valid_number, '島根県益田市岩倉町');
ok($zip->set_number('6980015')->is_valid_number, '島根県益田市栃山町');
ok($zip->set_number('6980016')->is_valid_number, '島根県益田市土井町');
ok($zip->set_number('6980017')->is_valid_number, '島根県益田市七尾町');
ok($zip->set_number('6980021')->is_valid_number, '島根県益田市幸町');
ok($zip->set_number('6980022')->is_valid_number, '島根県益田市有明町');
ok($zip->set_number('6980023')->is_valid_number, '島根県益田市常盤町');
ok($zip->set_number('6980024')->is_valid_number, '島根県益田市駅前町');
ok($zip->set_number('6980025')->is_valid_number, '島根県益田市あけぼの西町');
ok($zip->set_number('6980026')->is_valid_number, '島根県益田市あけぼの本町');
ok($zip->set_number('6980027')->is_valid_number, '島根県益田市あけぼの東町');
ok($zip->set_number('6980031')->is_valid_number, '島根県益田市多田町');
ok($zip->set_number('6980032')->is_valid_number, '島根県益田市水分町');
ok($zip->set_number('6980033')->is_valid_number, '島根県益田市元町');
ok($zip->set_number('6980034')->is_valid_number, '島根県益田市赤城町');
ok($zip->set_number('6980035')->is_valid_number, '島根県益田市栄町');
ok($zip->set_number('6980036')->is_valid_number, '島根県益田市須子町');
ok($zip->set_number('6980037')->is_valid_number, '島根県益田市飯田町');
ok($zip->set_number('6980041')->is_valid_number, '島根県益田市高津');
ok($zip->set_number('6980041')->is_valid_number, '島根県益田市高津町');
ok($zip->set_number('6980042')->is_valid_number, '島根県益田市中吉田町');
ok($zip->set_number('6980043')->is_valid_number, '島根県益田市中島町');
ok($zip->set_number('6980044')->is_valid_number, '島根県益田市中須町');
ok($zip->set_number('6980045')->is_valid_number, '島根県益田市かもしま北町');
ok($zip->set_number('6980046')->is_valid_number, '島根県益田市かもしま東町');
ok($zip->set_number('6980047')->is_valid_number, '島根県益田市かもしま西町');
ok($zip->set_number('6980051')->is_valid_number, '島根県益田市内田町(石見空港)');
ok($zip->set_number('6980201')->is_valid_number, '島根県益田市美都町板井川');
ok($zip->set_number('6980202')->is_valid_number, '島根県益田市美都町宇津川');
ok($zip->set_number('6980203')->is_valid_number, '島根県益田市美都町都茂');
ok($zip->set_number('6980204')->is_valid_number, '島根県益田市美都町山本');
ok($zip->set_number('6980205')->is_valid_number, '島根県益田市美都町三谷');
ok($zip->set_number('6980206')->is_valid_number, '島根県益田市美都町久原');
ok($zip->set_number('6980207')->is_valid_number, '島根県益田市美都町丸茂');
ok($zip->set_number('6980211')->is_valid_number, '島根県益田市美都町小原');
ok($zip->set_number('6980212')->is_valid_number, '島根県益田市美都町仙道');
ok($zip->set_number('6980213')->is_valid_number, '島根県益田市美都町朝倉');
ok($zip->set_number('6980214')->is_valid_number, '島根県益田市美都町笹倉');
ok($zip->set_number('6980411')->is_valid_number, '島根県益田市波田町');
ok($zip->set_number('6980412')->is_valid_number, '島根県益田市長沢町');
ok($zip->set_number('6980413')->is_valid_number, '島根県益田市馬谷町');
ok($zip->set_number('6980414')->is_valid_number, '島根県益田市下波田町');
ok($zip->set_number('6981201')->is_valid_number, '島根県益田市匹見町道川');
ok($zip->set_number('6981211')->is_valid_number, '島根県益田市匹見町匹見');
ok($zip->set_number('6981212')->is_valid_number, '島根県益田市匹見町紙祖');
ok($zip->set_number('6981213')->is_valid_number, '島根県益田市匹見町落合');
ok($zip->set_number('6981221')->is_valid_number, '島根県益田市匹見町澄川');
ok($zip->set_number('6981222')->is_valid_number, '島根県益田市匹見町広瀬');
ok($zip->set_number('6981223')->is_valid_number, '島根県益田市匹見町石谷');
ok($zip->set_number('6982141')->is_valid_number, '島根県益田市白上町');
ok($zip->set_number('6982142')->is_valid_number, '島根県益田市市原町');
ok($zip->set_number('6982143')->is_valid_number, '島根県益田市内田町(その他)');
ok($zip->set_number('6982144')->is_valid_number, '島根県益田市虫追町');
ok($zip->set_number('6982145')->is_valid_number, '島根県益田市川登町');
ok($zip->set_number('6982146')->is_valid_number, '島根県益田市中垣内町');
ok($zip->set_number('6982251')->is_valid_number, '島根県益田市黒周町');
ok($zip->set_number('6982252')->is_valid_number, '島根県益田市柏原町');
ok($zip->set_number('6982253')->is_valid_number, '島根県益田市愛栄町');
ok($zip->set_number('6982254')->is_valid_number, '島根県益田市桂平町');
ok($zip->set_number('6982255')->is_valid_number, '島根県益田市上黒谷町');
ok($zip->set_number('6990101')->is_valid_number, '島根県松江市東出雲町揖屋');
ok($zip->set_number('6990102')->is_valid_number, '島根県松江市東出雲町下意東');
ok($zip->set_number('6990103')->is_valid_number, '島根県松江市東出雲町上意東');
ok($zip->set_number('6990104')->is_valid_number, '島根県松江市東出雲町須田');
ok($zip->set_number('6990105')->is_valid_number, '島根県松江市東出雲町内馬');
ok($zip->set_number('6990106')->is_valid_number, '島根県松江市東出雲町春日');
ok($zip->set_number('6990107')->is_valid_number, '島根県松江市東出雲町今宮');
ok($zip->set_number('6990108')->is_valid_number, '島根県松江市東出雲町出雲郷');
ok($zip->set_number('6990109')->is_valid_number, '島根県松江市東出雲町錦浜');
ok($zip->set_number('6990110')->is_valid_number, '島根県松江市東出雲町錦新町');
ok($zip->set_number('6990111')->is_valid_number, '島根県松江市東出雲町意宇南');
ok($zip->set_number('6990112')->is_valid_number, '島根県松江市東出雲町意宇東');
ok($zip->set_number('6990201')->is_valid_number, '島根県松江市玉湯町玉造');
ok($zip->set_number('6990202')->is_valid_number, '島根県松江市玉湯町湯町');
ok($zip->set_number('6990203')->is_valid_number, '島根県松江市玉湯町布志名');
ok($zip->set_number('6990204')->is_valid_number, '島根県松江市玉湯町林');
ok($zip->set_number('6990205')->is_valid_number, '島根県松江市玉湯町大谷');
ok($zip->set_number('6990401')->is_valid_number, '島根県松江市宍道町宍道');
ok($zip->set_number('6990402')->is_valid_number, '島根県松江市宍道町白石');
ok($zip->set_number('6990403')->is_valid_number, '島根県松江市宍道町西来待');
ok($zip->set_number('6990404')->is_valid_number, '島根県松江市宍道町東来待');
ok($zip->set_number('6990405')->is_valid_number, '島根県松江市宍道町上来待');
ok($zip->set_number('6990406')->is_valid_number, '島根県松江市宍道町佐々布');
ok($zip->set_number('6990407')->is_valid_number, '島根県松江市宍道町伊志見');
ok($zip->set_number('6990408')->is_valid_number, '島根県松江市宍道町昭和');
ok($zip->set_number('6990501')->is_valid_number, '島根県出雲市斐川町学頭');
ok($zip->set_number('6990502')->is_valid_number, '島根県出雲市斐川町荘原');
ok($zip->set_number('6990503')->is_valid_number, '島根県出雲市斐川町神庭');
ok($zip->set_number('6990504')->is_valid_number, '島根県出雲市斐川町三絡');
ok($zip->set_number('6990505')->is_valid_number, '島根県出雲市斐川町上庄原');
ok($zip->set_number('6990551')->is_valid_number, '島根県出雲市斐川町沖洲');
ok($zip->set_number('6990552')->is_valid_number, '島根県出雲市斐川町中洲');
ok($zip->set_number('6990553')->is_valid_number, '島根県出雲市斐川町黒目');
ok($zip->set_number('6990554')->is_valid_number, '島根県出雲市斐川町三分市');
ok($zip->set_number('6990555')->is_valid_number, '島根県出雲市斐川町坂田');
ok($zip->set_number('6990611')->is_valid_number, '島根県出雲市斐川町阿宮');
ok($zip->set_number('6990612')->is_valid_number, '島根県出雲市斐川町出西');
ok($zip->set_number('6990613')->is_valid_number, '島根県出雲市斐川町神氷');
ok($zip->set_number('6990614')->is_valid_number, '島根県出雲市斐川町求院');
ok($zip->set_number('6990615')->is_valid_number, '島根県出雲市斐川町併川');
ok($zip->set_number('6990621')->is_valid_number, '島根県出雲市斐川町富村');
ok($zip->set_number('6990622')->is_valid_number, '島根県出雲市斐川町名島');
ok($zip->set_number('6990623')->is_valid_number, '島根県出雲市斐川町鳥井');
ok($zip->set_number('6990624')->is_valid_number, '島根県出雲市斐川町上直江');
ok($zip->set_number('6990631')->is_valid_number, '島根県出雲市斐川町直江');
ok($zip->set_number('6990641')->is_valid_number, '島根県出雲市斐川町美南');
ok($zip->set_number('6990642')->is_valid_number, '島根県出雲市斐川町福富');
ok($zip->set_number('6990643')->is_valid_number, '島根県出雲市斐川町原鹿');
ok($zip->set_number('6990644')->is_valid_number, '島根県出雲市斐川町今在家');
ok($zip->set_number('6990701')->is_valid_number, '島根県出雲市大社町杵築東');
ok($zip->set_number('6990702')->is_valid_number, '島根県出雲市大社町杵築北');
ok($zip->set_number('6990711')->is_valid_number, '島根県出雲市大社町杵築南');
ok($zip->set_number('6990721')->is_valid_number, '島根県出雲市大社町修理免');
ok($zip->set_number('6990722')->is_valid_number, '島根県出雲市大社町北荒木');
ok($zip->set_number('6990731')->is_valid_number, '島根県出雲市大社町遙堪');
ok($zip->set_number('6990732')->is_valid_number, '島根県出雲市大社町入南');
ok($zip->set_number('6990733')->is_valid_number, '島根県出雲市大社町菱根');
ok($zip->set_number('6990741')->is_valid_number, '島根県出雲市大社町中荒木');
ok($zip->set_number('6990751')->is_valid_number, '島根県出雲市大社町杵築西');
ok($zip->set_number('6990761')->is_valid_number, '島根県出雲市大社町鷺浦');
ok($zip->set_number('6990762')->is_valid_number, '島根県出雲市大社町鵜峠');
ok($zip->set_number('6990763')->is_valid_number, '島根県出雲市大社町日御碕');
ok($zip->set_number('6990764')->is_valid_number, '島根県出雲市大社町宇龍');
ok($zip->set_number('6990811')->is_valid_number, '島根県出雲市湖陵町差海');
ok($zip->set_number('6990812')->is_valid_number, '島根県出雲市湖陵町二部');
ok($zip->set_number('6990813')->is_valid_number, '島根県出雲市湖陵町三部');
ok($zip->set_number('6990814')->is_valid_number, '島根県出雲市湖陵町常楽寺');
ok($zip->set_number('6990815')->is_valid_number, '島根県出雲市湖陵町畑村');
ok($zip->set_number('6990816')->is_valid_number, '島根県出雲市湖陵町大池');
ok($zip->set_number('6990817')->is_valid_number, '島根県出雲市湖陵町板津');
ok($zip->set_number('6990821')->is_valid_number, '島根県出雲市大島町');
ok($zip->set_number('6990822')->is_valid_number, '島根県出雲市神西沖町');
ok($zip->set_number('6990823')->is_valid_number, '島根県出雲市東神西町');
ok($zip->set_number('6990824')->is_valid_number, '島根県出雲市西神西町');
ok($zip->set_number('6990825')->is_valid_number, '島根県出雲市神西新町');
ok($zip->set_number('6990901')->is_valid_number, '島根県出雲市多伎町久村');
ok($zip->set_number('6990902')->is_valid_number, '島根県出雲市多伎町多岐');
ok($zip->set_number('6990903')->is_valid_number, '島根県出雲市多伎町小田');
ok($zip->set_number('6990904')->is_valid_number, '島根県出雲市多伎町口田儀');
ok($zip->set_number('6990905')->is_valid_number, '島根県出雲市多伎町奥田儀');
ok($zip->set_number('6990906')->is_valid_number, '島根県出雲市多伎町神原');
ok($zip->set_number('6991101')->is_valid_number, '島根県雲南市加茂町大西');
ok($zip->set_number('6991102')->is_valid_number, '島根県雲南市加茂町立原');
ok($zip->set_number('6991103')->is_valid_number, '島根県雲南市加茂町近松');
ok($zip->set_number('6991104')->is_valid_number, '島根県雲南市加茂町南加茂');
ok($zip->set_number('6991105')->is_valid_number, '島根県雲南市加茂町宇治');
ok($zip->set_number('6991106')->is_valid_number, '島根県雲南市加茂町加茂中');
ok($zip->set_number('6991111')->is_valid_number, '島根県雲南市加茂町砂子原');
ok($zip->set_number('6991112')->is_valid_number, '島根県雲南市加茂町新宮');
ok($zip->set_number('6991113')->is_valid_number, '島根県雲南市加茂町東谷');
ok($zip->set_number('6991114')->is_valid_number, '島根県雲南市加茂町猪尾');
ok($zip->set_number('6991115')->is_valid_number, '島根県雲南市加茂町岩倉');
ok($zip->set_number('6991121')->is_valid_number, '島根県雲南市加茂町神原');
ok($zip->set_number('6991122')->is_valid_number, '島根県雲南市加茂町三代');
ok($zip->set_number('6991123')->is_valid_number, '島根県雲南市加茂町大竹');
ok($zip->set_number('6991124')->is_valid_number, '島根県雲南市加茂町延野');
ok($zip->set_number('6991125')->is_valid_number, '島根県雲南市加茂町大崎');
ok($zip->set_number('6991201')->is_valid_number, '島根県雲南市大東町小河内');
ok($zip->set_number('6991202')->is_valid_number, '島根県雲南市大東町刈畑');
ok($zip->set_number('6991203')->is_valid_number, '島根県雲南市大東町北村');
ok($zip->set_number('6991204')->is_valid_number, '島根県雲南市大東町薦澤');
ok($zip->set_number('6991205')->is_valid_number, '島根県雲南市大東町須賀');
ok($zip->set_number('6991206')->is_valid_number, '島根県雲南市大東町南村');
ok($zip->set_number('6991211')->is_valid_number, '島根県雲南市大東町上久野');
ok($zip->set_number('6991212')->is_valid_number, '島根県雲南市大東町下久野');
ok($zip->set_number('6991213')->is_valid_number, '島根県雲南市大東町大ケ谷');
ok($zip->set_number('6991214')->is_valid_number, '島根県雲南市大東町上佐世');
ok($zip->set_number('6991215')->is_valid_number, '島根県雲南市大東町下佐世');
ok($zip->set_number('6991216')->is_valid_number, '島根県雲南市大東町西阿用');
ok($zip->set_number('6991221')->is_valid_number, '島根県雲南市大東町飯田');
ok($zip->set_number('6991221')->is_valid_number, '島根県雲南市大東町岡村');
ok($zip->set_number('6991222')->is_valid_number, '島根県雲南市大東町川井');
ok($zip->set_number('6991223')->is_valid_number, '島根県雲南市大東町下阿用');
ok($zip->set_number('6991224')->is_valid_number, '島根県雲南市大東町東阿用');
ok($zip->set_number('6991231')->is_valid_number, '島根県雲南市大東町遠所');
ok($zip->set_number('6991232')->is_valid_number, '島根県雲南市大東町仁和寺');
ok($zip->set_number('6991233')->is_valid_number, '島根県雲南市大東町幡屋');
ok($zip->set_number('6991234')->is_valid_number, '島根県雲南市大東町前原');
ok($zip->set_number('6991241')->is_valid_number, '島根県雲南市大東町山王寺');
ok($zip->set_number('6991242')->is_valid_number, '島根県雲南市大東町大東下分');
ok($zip->set_number('6991243')->is_valid_number, '島根県雲南市大東町畑鵯');
ok($zip->set_number('6991244')->is_valid_number, '島根県雲南市大東町山田');
ok($zip->set_number('6991245')->is_valid_number, '島根県雲南市大東町養賀');
ok($zip->set_number('6991251')->is_valid_number, '島根県雲南市大東町新庄');
ok($zip->set_number('6991251')->is_valid_number, '島根県雲南市大東町大東');
ok($zip->set_number('6991252')->is_valid_number, '島根県雲南市大東町田中');
ok($zip->set_number('6991253')->is_valid_number, '島根県雲南市大東町中湯石');
ok($zip->set_number('6991261')->is_valid_number, '島根県雲南市大東町金成');
ok($zip->set_number('6991262')->is_valid_number, '島根県雲南市大東町塩田');
ok($zip->set_number('6991263')->is_valid_number, '島根県雲南市大東町篠淵');
ok($zip->set_number('6991264')->is_valid_number, '島根県雲南市大東町清田');
ok($zip->set_number('6991311')->is_valid_number, '島根県雲南市木次町里方');
ok($zip->set_number('6991312')->is_valid_number, '島根県雲南市木次町山方');
ok($zip->set_number('6991321')->is_valid_number, '島根県雲南市木次町宇谷');
ok($zip->set_number('6991322')->is_valid_number, '島根県雲南市木次町寺領');
ok($zip->set_number('6991323')->is_valid_number, '島根県雲南市木次町東日登');
ok($zip->set_number('6991324')->is_valid_number, '島根県雲南市木次町西日登');
ok($zip->set_number('6991331')->is_valid_number, '島根県雲南市木次町上熊谷');
ok($zip->set_number('6991332')->is_valid_number, '島根県雲南市木次町木次');
ok($zip->set_number('6991333')->is_valid_number, '島根県雲南市木次町下熊谷');
ok($zip->set_number('6991334')->is_valid_number, '島根県雲南市木次町新市');
ok($zip->set_number('6991341')->is_valid_number, '島根県雲南市木次町北原(その他)');
ok($zip->set_number('6991342')->is_valid_number, '島根県雲南市木次町平田');
ok($zip->set_number('6991343')->is_valid_number, '島根県雲南市木次町湯村');
ok($zip->set_number('6991401')->is_valid_number, '島根県雲南市木次町北原(尾白)');
ok($zip->set_number('6991431')->is_valid_number, '島根県仁多郡奥出雲町上三所');
ok($zip->set_number('6991432')->is_valid_number, '島根県仁多郡奥出雲町馬馳');
ok($zip->set_number('6991433')->is_valid_number, '島根県仁多郡奥出雲町八代');
ok($zip->set_number('6991434')->is_valid_number, '島根県仁多郡奥出雲町佐白');
ok($zip->set_number('6991500')->is_valid_number, '島根県仁多郡奥出雲町以下に掲載がない場合');
ok($zip->set_number('6991511')->is_valid_number, '島根県仁多郡奥出雲町三成');
ok($zip->set_number('6991512')->is_valid_number, '島根県仁多郡奥出雲町高尾');
ok($zip->set_number('6991513')->is_valid_number, '島根県仁多郡奥出雲町三沢');
ok($zip->set_number('6991514')->is_valid_number, '島根県仁多郡奥出雲町河内');
ok($zip->set_number('6991515')->is_valid_number, '島根県仁多郡奥出雲町鴨倉');
ok($zip->set_number('6991516')->is_valid_number, '島根県仁多郡奥出雲町三所');
ok($zip->set_number('6991517')->is_valid_number, '島根県仁多郡奥出雲町下阿井(宇根路)');
ok($zip->set_number('6991621')->is_valid_number, '島根県仁多郡奥出雲町上阿井');
ok($zip->set_number('6991622')->is_valid_number, '島根県仁多郡奥出雲町下阿井(その他)');
ok($zip->set_number('6991701')->is_valid_number, '島根県仁多郡奥出雲町亀嵩');
ok($zip->set_number('6991702')->is_valid_number, '島根県仁多郡奥出雲町郡');
ok($zip->set_number('6991703')->is_valid_number, '島根県仁多郡奥出雲町高田');
ok($zip->set_number('6991801')->is_valid_number, '島根県仁多郡奥出雲町竹崎');
ok($zip->set_number('6991802')->is_valid_number, '島根県仁多郡奥出雲町大呂');
ok($zip->set_number('6991811')->is_valid_number, '島根県仁多郡奥出雲町八川');
ok($zip->set_number('6991812')->is_valid_number, '島根県仁多郡奥出雲町大谷');
ok($zip->set_number('6991821')->is_valid_number, '島根県仁多郡奥出雲町稲原');
ok($zip->set_number('6991822')->is_valid_number, '島根県仁多郡奥出雲町下横田');
ok($zip->set_number('6991831')->is_valid_number, '島根県仁多郡奥出雲町中村');
ok($zip->set_number('6991832')->is_valid_number, '島根県仁多郡奥出雲町横田');
ok($zip->set_number('6991941')->is_valid_number, '島根県仁多郡奥出雲町大馬木');
ok($zip->set_number('6991942')->is_valid_number, '島根県仁多郡奥出雲町小馬木');
ok($zip->set_number('6992211')->is_valid_number, '島根県大田市波根町');
ok($zip->set_number('6992212')->is_valid_number, '島根県大田市朝山町仙山');
ok($zip->set_number('6992213')->is_valid_number, '島根県大田市朝山町朝倉');
ok($zip->set_number('6992214')->is_valid_number, '島根県大田市富山町神原');
ok($zip->set_number('6992215')->is_valid_number, '島根県大田市富山町才坂');
ok($zip->set_number('6992216')->is_valid_number, '島根県大田市富山町山中(その他)');
ok($zip->set_number('6992301')->is_valid_number, '島根県大田市仁摩町仁万');
ok($zip->set_number('6992302')->is_valid_number, '島根県大田市仁摩町宅野');
ok($zip->set_number('6992303')->is_valid_number, '島根県大田市仁摩町大国');
ok($zip->set_number('6992304')->is_valid_number, '島根県大田市仁摩町馬路');
ok($zip->set_number('6992305')->is_valid_number, '島根県大田市仁摩町天河内');
ok($zip->set_number('6992501')->is_valid_number, '島根県大田市温泉津町温泉津');
ok($zip->set_number('6992502')->is_valid_number, '島根県大田市温泉津町湯里');
ok($zip->set_number('6992503')->is_valid_number, '島根県大田市温泉津町西田');
ok($zip->set_number('6992504')->is_valid_number, '島根県大田市温泉津町荻村');
ok($zip->set_number('6992505')->is_valid_number, '島根県大田市温泉津町太田');
ok($zip->set_number('6992506')->is_valid_number, '島根県大田市温泉津町福田');
ok($zip->set_number('6992507')->is_valid_number, '島根県大田市温泉津町井田');
ok($zip->set_number('6992511')->is_valid_number, '島根県大田市温泉津町小浜');
ok($zip->set_number('6992512')->is_valid_number, '島根県大田市温泉津町飯原');
ok($zip->set_number('6992513')->is_valid_number, '島根県大田市温泉津町上村');
ok($zip->set_number('6992514')->is_valid_number, '島根県大田市温泉津町福光');
ok($zip->set_number('6992515')->is_valid_number, '島根県大田市温泉津町今浦');
ok($zip->set_number('6992516')->is_valid_number, '島根県大田市温泉津町吉浦');
ok($zip->set_number('6992831')->is_valid_number, '島根県江津市黒松町');
ok($zip->set_number('6992832')->is_valid_number, '島根県江津市波積町北');
ok($zip->set_number('6992833')->is_valid_number, '島根県江津市波積町本郷');
ok($zip->set_number('6992834')->is_valid_number, '島根県江津市波積町南');
ok($zip->set_number('6992835')->is_valid_number, '島根県江津市松川町上津井');
ok($zip->set_number('6992836')->is_valid_number, '島根県江津市松川町畑田');
ok($zip->set_number('6992837')->is_valid_number, '島根県江津市松川町上河戸');
ok($zip->set_number('6992841')->is_valid_number, '島根県江津市後地町');
ok($zip->set_number('6992842')->is_valid_number, '島根県江津市都治町');
ok($zip->set_number('6993161')->is_valid_number, '島根県江津市波子町');
ok($zip->set_number('6993162')->is_valid_number, '島根県江津市敬川町');
ok($zip->set_number('6993211')->is_valid_number, '島根県浜田市三隅町三隅');
ok($zip->set_number('6993212')->is_valid_number, '島根県浜田市三隅町向野田');
ok($zip->set_number('6993213')->is_valid_number, '島根県浜田市三隅町河内');
ok($zip->set_number('6993214')->is_valid_number, '島根県浜田市三隅町矢原');
ok($zip->set_number('6993215')->is_valid_number, '島根県浜田市三隅町井川');
ok($zip->set_number('6993215')->is_valid_number, '島根県浜田市三隅町下古和');
ok($zip->set_number('6993216')->is_valid_number, '島根県浜田市三隅町上古和');
ok($zip->set_number('6993217')->is_valid_number, '島根県浜田市三隅町黒沢');
ok($zip->set_number('6993221')->is_valid_number, '島根県浜田市三隅町東平原');
ok($zip->set_number('6993222')->is_valid_number, '島根県浜田市三隅町折居');
ok($zip->set_number('6993223')->is_valid_number, '島根県浜田市三隅町西河内');
ok($zip->set_number('6993224')->is_valid_number, '島根県浜田市三隅町湊浦');
ok($zip->set_number('6993225')->is_valid_number, '島根県浜田市三隅町古市場');
ok($zip->set_number('6993226')->is_valid_number, '島根県浜田市三隅町岡見');
ok($zip->set_number('6993301')->is_valid_number, '島根県浜田市三隅町井野');
ok($zip->set_number('6993302')->is_valid_number, '島根県浜田市三隅町芦谷');
ok($zip->set_number('6993303')->is_valid_number, '島根県浜田市三隅町室谷');
ok($zip->set_number('6993501')->is_valid_number, '島根県益田市金山町');
ok($zip->set_number('6993502')->is_valid_number, '島根県益田市木部町');
ok($zip->set_number('6993503')->is_valid_number, '島根県益田市下種町');
ok($zip->set_number('6993504')->is_valid_number, '島根県益田市種村町');
ok($zip->set_number('6993505')->is_valid_number, '島根県益田市土田町');
ok($zip->set_number('6993506')->is_valid_number, '島根県益田市西平原町');
ok($zip->set_number('6993671')->is_valid_number, '島根県益田市津田町');
ok($zip->set_number('6993672')->is_valid_number, '島根県益田市赤雁町');
ok($zip->set_number('6993673')->is_valid_number, '島根県益田市山折町');
ok($zip->set_number('6993674')->is_valid_number, '島根県益田市大草町');
ok($zip->set_number('6993675')->is_valid_number, '島根県益田市乙子町');
ok($zip->set_number('6993676')->is_valid_number, '島根県益田市遠田町');
ok($zip->set_number('6993761')->is_valid_number, '島根県益田市飯浦町');
ok($zip->set_number('6993762')->is_valid_number, '島根県益田市小浜町');
ok($zip->set_number('6993763')->is_valid_number, '島根県益田市戸田町');
ok($zip->set_number('6993764')->is_valid_number, '島根県益田市喜阿弥町');
ok($zip->set_number('6993765')->is_valid_number, '島根県益田市有田町');
ok($zip->set_number('6993766')->is_valid_number, '島根県益田市美濃地町');
ok($zip->set_number('6994111')->is_valid_number, '島根県江津市桜江町谷住郷');
ok($zip->set_number('6994221')->is_valid_number, '島根県江津市桜江町市山');
ok($zip->set_number('6994222')->is_valid_number, '島根県江津市桜江町今田');
ok($zip->set_number('6994223')->is_valid_number, '島根県江津市桜江町後山');
ok($zip->set_number('6994224')->is_valid_number, '島根県江津市桜江町江尾');
ok($zip->set_number('6994225')->is_valid_number, '島根県江津市桜江町小田');
ok($zip->set_number('6994226')->is_valid_number, '島根県江津市桜江町川戸');
ok($zip->set_number('6994311')->is_valid_number, '島根県邑智郡邑南町日貫');
ok($zip->set_number('6994431')->is_valid_number, '島根県江津市桜江町長谷');
ok($zip->set_number('6994432')->is_valid_number, '島根県江津市桜江町八戸');
ok($zip->set_number('6994501')->is_valid_number, '島根県江津市桜江町鹿賀');
ok($zip->set_number('6994502')->is_valid_number, '島根県江津市桜江町川越');
ok($zip->set_number('6994503')->is_valid_number, '島根県江津市桜江町田津');
ok($zip->set_number('6994504')->is_valid_number, '島根県江津市桜江町大貫');
ok($zip->set_number('6994505')->is_valid_number, '島根県江津市桜江町坂本');
ok($zip->set_number('6994600')->is_valid_number, '島根県邑智郡美郷町以下に掲載がない場合');
ok($zip->set_number('6994605')->is_valid_number, '島根県邑智郡美郷町高山');
ok($zip->set_number('6994621')->is_valid_number, '島根県邑智郡美郷町粕渕');
ok($zip->set_number('6994622')->is_valid_number, '島根県邑智郡美郷町久保');
ok($zip->set_number('6994623')->is_valid_number, '島根県邑智郡美郷町野井');
ok($zip->set_number('6994624')->is_valid_number, '島根県邑智郡美郷町明塚');
ok($zip->set_number('6994625')->is_valid_number, '島根県邑智郡美郷町簗瀬');
ok($zip->set_number('6994626')->is_valid_number, '島根県邑智郡美郷町乙原');
ok($zip->set_number('6994627')->is_valid_number, '島根県邑智郡美郷町吾郷');
ok($zip->set_number('6994631')->is_valid_number, '島根県邑智郡美郷町奥山');
ok($zip->set_number('6994632')->is_valid_number, '島根県邑智郡美郷町高畑');
ok($zip->set_number('6994633')->is_valid_number, '島根県邑智郡美郷町湯抱');
ok($zip->set_number('6994701')->is_valid_number, '島根県邑智郡美郷町浜原');
ok($zip->set_number('6994702')->is_valid_number, '島根県邑智郡美郷町上川戸');
ok($zip->set_number('6994703')->is_valid_number, '島根県邑智郡美郷町熊見');
ok($zip->set_number('6994704')->is_valid_number, '島根県邑智郡美郷町信喜');
ok($zip->set_number('6994706')->is_valid_number, '島根県邑智郡美郷町滝原');
ok($zip->set_number('6994707')->is_valid_number, '島根県邑智郡美郷町亀村');
ok($zip->set_number('6994711')->is_valid_number, '島根県邑智郡美郷町千原');
ok($zip->set_number('6994712')->is_valid_number, '島根県邑智郡美郷町九日市');
ok($zip->set_number('6994713')->is_valid_number, '島根県邑智郡美郷町酒谷');
ok($zip->set_number('6994714')->is_valid_number, '島根県邑智郡美郷町片山');
ok($zip->set_number('6994715')->is_valid_number, '島根県邑智郡美郷町石原');
ok($zip->set_number('6995121')->is_valid_number, '島根県益田市左ケ山町');
ok($zip->set_number('6995122')->is_valid_number, '島根県益田市本俣賀町');
ok($zip->set_number('6995123')->is_valid_number, '島根県益田市猪木谷町');
ok($zip->set_number('6995124')->is_valid_number, '島根県益田市薄原町');
ok($zip->set_number('6995125')->is_valid_number, '島根県益田市白岩町');
ok($zip->set_number('6995126')->is_valid_number, '島根県益田市隅村町');
ok($zip->set_number('6995127')->is_valid_number, '島根県益田市梅月町');
ok($zip->set_number('6995131')->is_valid_number, '島根県益田市安富町');
ok($zip->set_number('6995132')->is_valid_number, '島根県益田市横田町');
ok($zip->set_number('6995133')->is_valid_number, '島根県益田市神田町');
ok($zip->set_number('6995134')->is_valid_number, '島根県益田市向横田町');
ok($zip->set_number('6995201')->is_valid_number, '島根県鹿足郡津和野町商人(929~1117、1343~1734番地)');
ok($zip->set_number('6995202')->is_valid_number, '島根県鹿足郡津和野町左鐙');
ok($zip->set_number('6995203')->is_valid_number, '島根県鹿足郡津和野町相撲ケ原');
ok($zip->set_number('6995204')->is_valid_number, '島根県鹿足郡津和野町須川');
ok($zip->set_number('6995205')->is_valid_number, '島根県鹿足郡津和野町瀧谷');
ok($zip->set_number('6995206')->is_valid_number, '島根県鹿足郡津和野町瀧元');
ok($zip->set_number('6995207')->is_valid_number, '島根県鹿足郡津和野町枕瀬');
ok($zip->set_number('6995211')->is_valid_number, '島根県鹿足郡津和野町青原');
ok($zip->set_number('6995212')->is_valid_number, '島根県鹿足郡津和野町河村');
ok($zip->set_number('6995213')->is_valid_number, '島根県鹿足郡津和野町添谷');
ok($zip->set_number('6995214')->is_valid_number, '島根県鹿足郡津和野町溪村');
ok($zip->set_number('6995215')->is_valid_number, '島根県鹿足郡津和野町冨田');
ok($zip->set_number('6995216')->is_valid_number, '島根県鹿足郡津和野町池村');
ok($zip->set_number('6995217')->is_valid_number, '島根県鹿足郡津和野町柳村');
ok($zip->set_number('6995221')->is_valid_number, '島根県鹿足郡津和野町日原');
ok($zip->set_number('6995301')->is_valid_number, '島根県鹿足郡吉賀町柿木');
ok($zip->set_number('6995302')->is_valid_number, '島根県鹿足郡吉賀町福川');
ok($zip->set_number('6995303')->is_valid_number, '島根県鹿足郡吉賀町椛谷');
ok($zip->set_number('6995304')->is_valid_number, '島根県鹿足郡吉賀町白谷');
ok($zip->set_number('6995305')->is_valid_number, '島根県鹿足郡吉賀町下須');
ok($zip->set_number('6995306')->is_valid_number, '島根県鹿足郡吉賀町大野原');
ok($zip->set_number('6995307')->is_valid_number, '島根県鹿足郡吉賀町木部谷');
ok($zip->set_number('6995500')->is_valid_number, '島根県鹿足郡吉賀町以下に掲載がない場合');
ok($zip->set_number('6995501')->is_valid_number, '島根県鹿足郡吉賀町上高尻');
ok($zip->set_number('6995502')->is_valid_number, '島根県鹿足郡吉賀町田野原');
ok($zip->set_number('6995503')->is_valid_number, '島根県鹿足郡吉賀町樋口');
ok($zip->set_number('6995504')->is_valid_number, '島根県鹿足郡吉賀町蔵木');
ok($zip->set_number('6995505')->is_valid_number, '島根県鹿足郡吉賀町九郎原');
ok($zip->set_number('6995506')->is_valid_number, '島根県鹿足郡吉賀町有飯');
ok($zip->set_number('6995507')->is_valid_number, '島根県鹿足郡吉賀町下高尻');
ok($zip->set_number('6995511')->is_valid_number, '島根県鹿足郡吉賀町立戸');
ok($zip->set_number('6995512')->is_valid_number, '島根県鹿足郡吉賀町広石');
ok($zip->set_number('6995513')->is_valid_number, '島根県鹿足郡吉賀町六日市');
ok($zip->set_number('6995514')->is_valid_number, '島根県鹿足郡吉賀町立河内');
ok($zip->set_number('6995515')->is_valid_number, '島根県鹿足郡吉賀町幸地');
ok($zip->set_number('6995516')->is_valid_number, '島根県鹿足郡吉賀町沢田');
ok($zip->set_number('6995517')->is_valid_number, '島根県鹿足郡吉賀町注連川');
ok($zip->set_number('6995521')->is_valid_number, '島根県鹿足郡吉賀町真田');
ok($zip->set_number('6995522')->is_valid_number, '島根県鹿足郡吉賀町七日市');
ok($zip->set_number('6995523')->is_valid_number, '島根県鹿足郡吉賀町朝倉');
ok($zip->set_number('6995524')->is_valid_number, '島根県鹿足郡吉賀町蓼野');
ok($zip->set_number('6995525')->is_valid_number, '島根県鹿足郡吉賀町抜月');
ok($zip->set_number('6995600')->is_valid_number, '島根県鹿足郡津和野町以下に掲載がない場合');
ok($zip->set_number('6995601')->is_valid_number, '島根県鹿足郡津和野町商人(その他)');
ok($zip->set_number('6995602')->is_valid_number, '島根県鹿足郡津和野町直地');
ok($zip->set_number('6995603')->is_valid_number, '島根県鹿足郡津和野町笹山');
ok($zip->set_number('6995604')->is_valid_number, '島根県鹿足郡津和野町森村');
ok($zip->set_number('6995605')->is_valid_number, '島根県鹿足郡津和野町後田');
ok($zip->set_number('6995606')->is_valid_number, '島根県鹿足郡津和野町寺田');
ok($zip->set_number('6995607')->is_valid_number, '島根県鹿足郡津和野町耕田');
ok($zip->set_number('6995611')->is_valid_number, '島根県鹿足郡津和野町町田');
ok($zip->set_number('6995612')->is_valid_number, '島根県鹿足郡津和野町中座');
ok($zip->set_number('6995613')->is_valid_number, '島根県鹿足郡津和野町鷲原');
ok($zip->set_number('6995614')->is_valid_number, '島根県鹿足郡津和野町高峯');
ok($zip->set_number('6995615')->is_valid_number, '島根県鹿足郡津和野町名賀');
ok($zip->set_number('6995616')->is_valid_number, '島根県鹿足郡津和野町部栄');
ok($zip->set_number('6995617')->is_valid_number, '島根県鹿足郡津和野町田二穂');
ok($zip->set_number('6995621')->is_valid_number, '島根県鹿足郡津和野町内美');
ok($zip->set_number('6995622')->is_valid_number, '島根県鹿足郡津和野町邑輝');
ok($zip->set_number('6995631')->is_valid_number, '島根県鹿足郡津和野町中山');
ok($zip->set_number('6995632')->is_valid_number, '島根県鹿足郡津和野町豊稼');
ok($zip->set_number('6995633')->is_valid_number, '島根県鹿足郡津和野町長福');
ok($zip->set_number('6995634')->is_valid_number, '島根県鹿足郡津和野町中川');
ok($zip->set_number('6995635')->is_valid_number, '島根県鹿足郡津和野町山下');
ok($zip->set_number('6995636')->is_valid_number, '島根県鹿足郡津和野町中曽野');
ok($zip->set_number('6995637')->is_valid_number, '島根県鹿足郡津和野町吹野');
ok($zip->set_number('7000000')->is_valid_number, '岡山県岡山市北区以下に掲載がない場合');
ok($zip->set_number('7000000')->is_valid_number, '岡山県岡山市中区以下に掲載がない場合');
ok($zip->set_number('7000000')->is_valid_number, '岡山県岡山市東区以下に掲載がない場合');
ok($zip->set_number('7000000')->is_valid_number, '岡山県岡山市南区以下に掲載がない場合');
ok($zip->set_number('7000001')->is_valid_number, '岡山県岡山市北区宿');
ok($zip->set_number('7000002')->is_valid_number, '岡山県岡山市北区宿本町');
ok($zip->set_number('7000003')->is_valid_number, '岡山県岡山市北区半田町');
ok($zip->set_number('7000004')->is_valid_number, '岡山県岡山市北区法界院');
ok($zip->set_number('7000005')->is_valid_number, '岡山県岡山市北区理大町');
ok($zip->set_number('7000011')->is_valid_number, '岡山県岡山市北区学南町');
ok($zip->set_number('7000012')->is_valid_number, '岡山県岡山市北区いずみ町');
ok($zip->set_number('7000013')->is_valid_number, '岡山県岡山市北区伊福町');
ok($zip->set_number('7000014')->is_valid_number, '岡山県岡山市北区津倉町');
ok($zip->set_number('7000015')->is_valid_number, '岡山県岡山市北区京山');
ok($zip->set_number('7000016')->is_valid_number, '岡山県岡山市北区伊島町');
ok($zip->set_number('7000017')->is_valid_number, '岡山県岡山市北区伊島北町');
ok($zip->set_number('7000021')->is_valid_number, '岡山県岡山市北区国体町');
ok($zip->set_number('7000022')->is_valid_number, '岡山県岡山市北区岩田町');
ok($zip->set_number('7000023')->is_valid_number, '岡山県岡山市北区駅前町');
ok($zip->set_number('7000024')->is_valid_number, '岡山県岡山市北区駅元町');
ok($zip->set_number('7000025')->is_valid_number, '岡山県岡山市北区寿町');
ok($zip->set_number('7000026')->is_valid_number, '岡山県岡山市北区奉還町');
ok($zip->set_number('7000027')->is_valid_number, '岡山県岡山市北区清心町');
ok($zip->set_number('7000028')->is_valid_number, '岡山県岡山市北区絵図町');
ok($zip->set_number('7000031')->is_valid_number, '岡山県岡山市北区富町');
ok($zip->set_number('7000032')->is_valid_number, '岡山県岡山市北区昭和町');
ok($zip->set_number('7000033')->is_valid_number, '岡山県岡山市北区島田本町');
ok($zip->set_number('7000034')->is_valid_number, '岡山県岡山市北区高柳東町');
ok($zip->set_number('7000035')->is_valid_number, '岡山県岡山市北区高柳西町');
ok($zip->set_number('7000041')->is_valid_number, '岡山県岡山市北区岩井宮裏');
ok($zip->set_number('7000042')->is_valid_number, '岡山県岡山市北区三門東町');
ok($zip->set_number('7000043')->is_valid_number, '岡山県岡山市北区三門中町');
ok($zip->set_number('7000044')->is_valid_number, '岡山県岡山市北区三門西町');
ok($zip->set_number('7000045')->is_valid_number, '岡山県岡山市北区葵町');
ok($zip->set_number('7000046')->is_valid_number, '岡山県岡山市北区岩井');
ok($zip->set_number('7000047')->is_valid_number, '岡山県岡山市北区関西町');
ok($zip->set_number('7000051')->is_valid_number, '岡山県岡山市北区下伊福上町');
ok($zip->set_number('7000052')->is_valid_number, '岡山県岡山市北区下伊福');
ok($zip->set_number('7000053')->is_valid_number, '岡山県岡山市北区下伊福本町');
ok($zip->set_number('7000054')->is_valid_number, '岡山県岡山市北区下伊福西町');
ok($zip->set_number('7000055')->is_valid_number, '岡山県岡山市北区西崎');
ok($zip->set_number('7000056')->is_valid_number, '岡山県岡山市北区西崎本町');
ok($zip->set_number('7000061')->is_valid_number, '岡山県岡山市北区大安寺西町');
ok($zip->set_number('7000062')->is_valid_number, '岡山県岡山市北区大安寺中町');
ok($zip->set_number('7000063')->is_valid_number, '岡山県岡山市北区大安寺東町');
ok($zip->set_number('7000064')->is_valid_number, '岡山県岡山市北区大安寺南町');
ok($zip->set_number('7000065')->is_valid_number, '岡山県岡山市北区野殿東町');
ok($zip->set_number('7000066')->is_valid_number, '岡山県岡山市北区野殿西町');
ok($zip->set_number('7000067')->is_valid_number, '岡山県岡山市北区西野山町');
ok($zip->set_number('7000068')->is_valid_number, '岡山県岡山市北区東野山町');
ok($zip->set_number('7000071')->is_valid_number, '岡山県岡山市北区谷万成');
ok($zip->set_number('7000072')->is_valid_number, '岡山県岡山市北区万成東町');
ok($zip->set_number('7000073')->is_valid_number, '岡山県岡山市北区万成西町');
ok($zip->set_number('7000074')->is_valid_number, '岡山県岡山市北区矢坂東町');
ok($zip->set_number('7000075')->is_valid_number, '岡山県岡山市北区矢坂本町');
ok($zip->set_number('7000076')->is_valid_number, '岡山県岡山市北区矢坂西町');
ok($zip->set_number('7000080')->is_valid_number, '岡山県岡山市北区津島福居');
ok($zip->set_number('7000081')->is_valid_number, '岡山県岡山市北区津島東');
ok($zip->set_number('7000082')->is_valid_number, '岡山県岡山市北区津島中');
ok($zip->set_number('7000083')->is_valid_number, '岡山県岡山市北区津島新野');
ok($zip->set_number('7000084')->is_valid_number, '岡山県岡山市北区津島桑の木町');
ok($zip->set_number('7000085')->is_valid_number, '岡山県岡山市北区津島南');
ok($zip->set_number('7000086')->is_valid_number, '岡山県岡山市北区津島西坂');
ok($zip->set_number('7000087')->is_valid_number, '岡山県岡山市北区津島京町');
ok($zip->set_number('7000088')->is_valid_number, '岡山県岡山市北区津島笹が瀬');
ok($zip->set_number('7000089')->is_valid_number, '岡山県岡山市北区津島本町');
ok($zip->set_number('7000801')->is_valid_number, '岡山県岡山市北区三野本町');
ok($zip->set_number('7000802')->is_valid_number, '岡山県岡山市北区三野');
ok($zip->set_number('7000803')->is_valid_number, '岡山県岡山市北区北方');
ok($zip->set_number('7000804')->is_valid_number, '岡山県岡山市北区中井町');
ok($zip->set_number('7000805')->is_valid_number, '岡山県岡山市北区兵団');
ok($zip->set_number('7000806')->is_valid_number, '岡山県岡山市北区広瀬町');
ok($zip->set_number('7000807')->is_valid_number, '岡山県岡山市北区南方');
ok($zip->set_number('7000808')->is_valid_number, '岡山県岡山市北区大和町');
ok($zip->set_number('7000811')->is_valid_number, '岡山県岡山市北区番町');
ok($zip->set_number('7000812')->is_valid_number, '岡山県岡山市北区出石町');
ok($zip->set_number('7000813')->is_valid_number, '岡山県岡山市北区石関町');
ok($zip->set_number('7000814')->is_valid_number, '岡山県岡山市北区天神町');
ok($zip->set_number('7000815')->is_valid_number, '岡山県岡山市北区野田屋町');
ok($zip->set_number('7000816')->is_valid_number, '岡山県岡山市北区富田町');
ok($zip->set_number('7000817')->is_valid_number, '岡山県岡山市北区弓之町');
ok($zip->set_number('7000818')->is_valid_number, '岡山県岡山市北区蕃山町');
ok($zip->set_number('7000821')->is_valid_number, '岡山県岡山市北区中山下');
ok($zip->set_number('7000822')->is_valid_number, '岡山県岡山市北区表町');
ok($zip->set_number('7000823')->is_valid_number, '岡山県岡山市北区丸の内');
ok($zip->set_number('7000824')->is_valid_number, '岡山県岡山市北区内山下');
ok($zip->set_number('7000825')->is_valid_number, '岡山県岡山市北区田町');
ok($zip->set_number('7000826')->is_valid_number, '岡山県岡山市北区磨屋町');
ok($zip->set_number('7000827')->is_valid_number, '岡山県岡山市北区平和町');
ok($zip->set_number('7000831')->is_valid_number, '岡山県岡山市北区京橋町');
ok($zip->set_number('7000832')->is_valid_number, '岡山県岡山市北区京橋南町');
ok($zip->set_number('7000833')->is_valid_number, '岡山県岡山市北区天瀬');
ok($zip->set_number('7000834')->is_valid_number, '岡山県岡山市北区天瀬南町');
ok($zip->set_number('7000835')->is_valid_number, '岡山県岡山市北区東中央町');
ok($zip->set_number('7000836')->is_valid_number, '岡山県岡山市北区中央町');
ok($zip->set_number('7000837')->is_valid_number, '岡山県岡山市北区南中央町');
ok($zip->set_number('7000838')->is_valid_number, '岡山県岡山市北区京町');
ok($zip->set_number('7000841')->is_valid_number, '岡山県岡山市北区舟橋町');
ok($zip->set_number('7000842')->is_valid_number, '岡山県岡山市北区船頭町');
ok($zip->set_number('7000843')->is_valid_number, '岡山県岡山市北区二日市町');
ok($zip->set_number('7000844')->is_valid_number, '岡山県岡山市北区御舟入町');
ok($zip->set_number('7000845')->is_valid_number, '岡山県岡山市南区浜野');
ok($zip->set_number('7000846')->is_valid_number, '岡山県岡山市北区下内田町');
ok($zip->set_number('7000847')->is_valid_number, '岡山県岡山市北区山科町');
ok($zip->set_number('7000851')->is_valid_number, '岡山県岡山市北区七日市西町');
ok($zip->set_number('7000852')->is_valid_number, '岡山県岡山市北区七日市東町');
ok($zip->set_number('7000853')->is_valid_number, '岡山県岡山市南区豊浜町');
ok($zip->set_number('7000854')->is_valid_number, '岡山県岡山市北区十日市東町');
ok($zip->set_number('7000855')->is_valid_number, '岡山県岡山市北区十日市中町');
ok($zip->set_number('7000856')->is_valid_number, '岡山県岡山市北区十日市西町');
ok($zip->set_number('7000861')->is_valid_number, '岡山県岡山市北区清輝橋');
ok($zip->set_number('7000862')->is_valid_number, '岡山県岡山市北区清輝本町');
ok($zip->set_number('7000863')->is_valid_number, '岡山県岡山市北区新道');
ok($zip->set_number('7000864')->is_valid_number, '岡山県岡山市北区旭町');
ok($zip->set_number('7000865')->is_valid_number, '岡山県岡山市北区旭本町');
ok($zip->set_number('7000866')->is_valid_number, '岡山県岡山市北区岡南町');
ok($zip->set_number('7000867')->is_valid_number, '岡山県岡山市北区岡町');
ok($zip->set_number('7000901')->is_valid_number, '岡山県岡山市北区本町');
ok($zip->set_number('7000902')->is_valid_number, '岡山県岡山市北区錦町');
ok($zip->set_number('7000903')->is_valid_number, '岡山県岡山市北区幸町');
ok($zip->set_number('7000904')->is_valid_number, '岡山県岡山市北区柳町');
ok($zip->set_number('7000905')->is_valid_number, '岡山県岡山市北区春日町');
ok($zip->set_number('7000906')->is_valid_number, '岡山県岡山市北区大学町');
ok($zip->set_number('7000907')->is_valid_number, '岡山県岡山市北区下石井');
ok($zip->set_number('7000911')->is_valid_number, '岡山県岡山市北区大供本町');
ok($zip->set_number('7000912')->is_valid_number, '岡山県岡山市北区大供表町');
ok($zip->set_number('7000913')->is_valid_number, '岡山県岡山市北区大供');
ok($zip->set_number('7000914')->is_valid_number, '岡山県岡山市北区鹿田町');
ok($zip->set_number('7000915')->is_valid_number, '岡山県岡山市北区鹿田本町');
ok($zip->set_number('7000916')->is_valid_number, '岡山県岡山市北区西之町');
ok($zip->set_number('7000921')->is_valid_number, '岡山県岡山市北区東古松');
ok($zip->set_number('7000922')->is_valid_number, '岡山県岡山市北区東古松南町');
ok($zip->set_number('7000923')->is_valid_number, '岡山県岡山市北区大元駅前');
ok($zip->set_number('7000924')->is_valid_number, '岡山県岡山市北区大元');
ok($zip->set_number('7000925')->is_valid_number, '岡山県岡山市北区大元上町');
ok($zip->set_number('7000926')->is_valid_number, '岡山県岡山市北区西古松西町');
ok($zip->set_number('7000927')->is_valid_number, '岡山県岡山市北区西古松');
ok($zip->set_number('7000931')->is_valid_number, '岡山県岡山市北区奥田西町');
ok($zip->set_number('7000932')->is_valid_number, '岡山県岡山市北区奥田本町');
ok($zip->set_number('7000933')->is_valid_number, '岡山県岡山市北区奥田');
ok($zip->set_number('7000934')->is_valid_number, '岡山県岡山市北区奥田南町');
ok($zip->set_number('7000935')->is_valid_number, '岡山県岡山市北区神田町');
ok($zip->set_number('7000936')->is_valid_number, '岡山県岡山市北区富田');
ok($zip->set_number('7000941')->is_valid_number, '岡山県岡山市北区青江');
ok($zip->set_number('7000941')->is_valid_number, '岡山県岡山市南区青江');
ok($zip->set_number('7000942')->is_valid_number, '岡山県岡山市南区豊成');
ok($zip->set_number('7000943')->is_valid_number, '岡山県岡山市南区新福');
ok($zip->set_number('7000944')->is_valid_number, '岡山県岡山市南区泉田');
ok($zip->set_number('7000945')->is_valid_number, '岡山県岡山市南区新保');
ok($zip->set_number('7000951')->is_valid_number, '岡山県岡山市北区田中');
ok($zip->set_number('7000952')->is_valid_number, '岡山県岡山市北区平田');
ok($zip->set_number('7000953')->is_valid_number, '岡山県岡山市北区西市');
ok($zip->set_number('7000953')->is_valid_number, '岡山県岡山市南区西市');
ok($zip->set_number('7000954')->is_valid_number, '岡山県岡山市南区米倉');
ok($zip->set_number('7000955')->is_valid_number, '岡山県岡山市南区万倍');
ok($zip->set_number('7000956')->is_valid_number, '岡山県岡山市南区当新田');
ok($zip->set_number('7000961')->is_valid_number, '岡山県岡山市北区北長瀬本町');
ok($zip->set_number('7000962')->is_valid_number, '岡山県岡山市北区北長瀬表町');
ok($zip->set_number('7000963')->is_valid_number, '岡山県岡山市北区北長瀬');
ok($zip->set_number('7000964')->is_valid_number, '岡山県岡山市北区中仙道');
ok($zip->set_number('7000965')->is_valid_number, '岡山県岡山市北区西長瀬');
ok($zip->set_number('7000966')->is_valid_number, '岡山県岡山市北区日吉町');
ok($zip->set_number('7000971')->is_valid_number, '岡山県岡山市北区野田');
ok($zip->set_number('7000972')->is_valid_number, '岡山県岡山市北区上中野');
ok($zip->set_number('7000973')->is_valid_number, '岡山県岡山市北区下中野');
ok($zip->set_number('7000973')->is_valid_number, '岡山県岡山市南区下中野');
ok($zip->set_number('7000974')->is_valid_number, '岡山県岡山市北区今村');
ok($zip->set_number('7000975')->is_valid_number, '岡山県岡山市北区今');
ok($zip->set_number('7000976')->is_valid_number, '岡山県岡山市北区辰巳');
ok($zip->set_number('7000977')->is_valid_number, '岡山県岡山市北区問屋町');
ok($zip->set_number('7000981')->is_valid_number, '岡山県岡山市北区西島田町');
ok($zip->set_number('7000982')->is_valid_number, '岡山県岡山市北区中島田町');
ok($zip->set_number('7000983')->is_valid_number, '岡山県岡山市北区東島田町');
ok($zip->set_number('7000984')->is_valid_number, '岡山県岡山市北区桑田町');
ok($zip->set_number('7000985')->is_valid_number, '岡山県岡山市北区厚生町');
ok($zip->set_number('7000986')->is_valid_number, '岡山県岡山市北区新屋敷町');
ok($zip->set_number('7010101')->is_valid_number, '岡山県倉敷市日畑');
ok($zip->set_number('7010102')->is_valid_number, '岡山県倉敷市庄新町');
ok($zip->set_number('7010103')->is_valid_number, '岡山県倉敷市西尾');
ok($zip->set_number('7010104')->is_valid_number, '岡山県倉敷市山地');
ok($zip->set_number('7010105')->is_valid_number, '岡山県倉敷市矢部');
ok($zip->set_number('7010111')->is_valid_number, '岡山県倉敷市上東');
ok($zip->set_number('7010112')->is_valid_number, '岡山県倉敷市下庄');
ok($zip->set_number('7010113')->is_valid_number, '岡山県倉敷市栗坂');
ok($zip->set_number('7010114')->is_valid_number, '岡山県倉敷市松島');
ok($zip->set_number('7010115')->is_valid_number, '岡山県倉敷市二子');
ok($zip->set_number('7010131')->is_valid_number, '岡山県岡山市北区花尻みどり町');
ok($zip->set_number('7010132')->is_valid_number, '岡山県岡山市北区花尻ききょう町');
ok($zip->set_number('7010133')->is_valid_number, '岡山県岡山市北区花尻あかね町');
ok($zip->set_number('7010134')->is_valid_number, '岡山県岡山市北区花尻');
ok($zip->set_number('7010135')->is_valid_number, '岡山県岡山市北区東花尻');
ok($zip->set_number('7010136')->is_valid_number, '岡山県岡山市北区西花尻');
ok($zip->set_number('7010141')->is_valid_number, '岡山県岡山市北区白石東新町');
ok($zip->set_number('7010142')->is_valid_number, '岡山県岡山市北区白石西新町');
ok($zip->set_number('7010143')->is_valid_number, '岡山県岡山市北区白石');
ok($zip->set_number('7010144')->is_valid_number, '岡山県岡山市北区久米');
ok($zip->set_number('7010145')->is_valid_number, '岡山県岡山市北区今保');
ok($zip->set_number('7010151')->is_valid_number, '岡山県岡山市北区平野');
ok($zip->set_number('7010152')->is_valid_number, '岡山県岡山市北区延友');
ok($zip->set_number('7010153')->is_valid_number, '岡山県岡山市北区庭瀬');
ok($zip->set_number('7010161')->is_valid_number, '岡山県岡山市北区川入');
ok($zip->set_number('7010162')->is_valid_number, '岡山県岡山市北区納所');
ok($zip->set_number('7010163')->is_valid_number, '岡山県岡山市北区中撫川');
ok($zip->set_number('7010164')->is_valid_number, '岡山県岡山市北区撫川');
ok($zip->set_number('7010165')->is_valid_number, '岡山県岡山市北区大内田');
ok($zip->set_number('7010201')->is_valid_number, '岡山県岡山市南区妹尾崎');
ok($zip->set_number('7010202')->is_valid_number, '岡山県岡山市南区山田');
ok($zip->set_number('7010203')->is_valid_number, '岡山県岡山市南区古新田');
ok($zip->set_number('7010204')->is_valid_number, '岡山県岡山市南区大福');
ok($zip->set_number('7010205')->is_valid_number, '岡山県岡山市南区妹尾');
ok($zip->set_number('7010206')->is_valid_number, '岡山県岡山市南区箕島');
ok($zip->set_number('7010211')->is_valid_number, '岡山県岡山市南区東畦');
ok($zip->set_number('7010212')->is_valid_number, '岡山県岡山市南区内尾');
ok($zip->set_number('7010213')->is_valid_number, '岡山県岡山市南区中畦');
ok($zip->set_number('7010214')->is_valid_number, '岡山県岡山市南区曽根');
ok($zip->set_number('7010215')->is_valid_number, '岡山県岡山市南区西畦');
ok($zip->set_number('7010221')->is_valid_number, '岡山県岡山市南区藤田');
ok($zip->set_number('7010300')->is_valid_number, '岡山県都窪郡早島町以下に掲載がない場合');
ok($zip->set_number('7010301')->is_valid_number, '岡山県都窪郡早島町矢尾');
ok($zip->set_number('7010302')->is_valid_number, '岡山県都窪郡早島町若宮');
ok($zip->set_number('7010303')->is_valid_number, '岡山県都窪郡早島町前潟');
ok($zip->set_number('7010304')->is_valid_number, '岡山県都窪郡早島町早島');
ok($zip->set_number('7011131')->is_valid_number, '岡山県岡山市北区日応寺');
ok($zip->set_number('7011132')->is_valid_number, '岡山県岡山市北区田原');
ok($zip->set_number('7011133')->is_valid_number, '岡山県岡山市北区富吉');
ok($zip->set_number('7011134')->is_valid_number, '岡山県岡山市北区三和');
ok($zip->set_number('7011141')->is_valid_number, '岡山県岡山市北区菅野');
ok($zip->set_number('7011142')->is_valid_number, '岡山県岡山市北区高野');
ok($zip->set_number('7011143')->is_valid_number, '岡山県岡山市北区吉宗');
ok($zip->set_number('7011144')->is_valid_number, '岡山県岡山市北区栢谷');
ok($zip->set_number('7011145')->is_valid_number, '岡山県岡山市北区横井上');
ok($zip->set_number('7011151')->is_valid_number, '岡山県岡山市北区津高台');
ok($zip->set_number('7011152')->is_valid_number, '岡山県岡山市北区津高');
ok($zip->set_number('7011153')->is_valid_number, '岡山県岡山市北区富原');
ok($zip->set_number('7011154')->is_valid_number, '岡山県岡山市北区田益');
ok($zip->set_number('7011201')->is_valid_number, '岡山県岡山市北区首部');
ok($zip->set_number('7011202')->is_valid_number, '岡山県岡山市北区楢津');
ok($zip->set_number('7011203')->is_valid_number, '岡山県岡山市北区一宮山崎');
ok($zip->set_number('7011204')->is_valid_number, '岡山県岡山市北区今岡');
ok($zip->set_number('7011205')->is_valid_number, '岡山県岡山市北区佐山');
ok($zip->set_number('7011211')->is_valid_number, '岡山県岡山市北区一宮');
ok($zip->set_number('7011212')->is_valid_number, '岡山県岡山市北区尾上');
ok($zip->set_number('7011213')->is_valid_number, '岡山県岡山市北区西辛川');
ok($zip->set_number('7011214')->is_valid_number, '岡山県岡山市北区辛川市場');
ok($zip->set_number('7011221')->is_valid_number, '岡山県岡山市北区芳賀');
ok($zip->set_number('7011222')->is_valid_number, '岡山県岡山市北区松尾');
ok($zip->set_number('7011223')->is_valid_number, '岡山県岡山市北区大窪');
ok($zip->set_number('7011224')->is_valid_number, '岡山県岡山市北区長野');
ok($zip->set_number('7011225')->is_valid_number, '岡山県岡山市北区福谷');
ok($zip->set_number('7011226')->is_valid_number, '岡山県岡山市北区横尾');
ok($zip->set_number('7011331')->is_valid_number, '岡山県岡山市北区高松稲荷');
ok($zip->set_number('7011332')->is_valid_number, '岡山県岡山市北区平山');
ok($zip->set_number('7011333')->is_valid_number, '岡山県岡山市北区立田');
ok($zip->set_number('7011334')->is_valid_number, '岡山県岡山市北区高松原古才');
ok($zip->set_number('7011335')->is_valid_number, '岡山県岡山市北区高松');
ok($zip->set_number('7011336')->is_valid_number, '岡山県岡山市北区大崎');
ok($zip->set_number('7011337')->is_valid_number, '岡山県岡山市北区和井元');
ok($zip->set_number('7011341')->is_valid_number, '岡山県岡山市北区吉備津');
ok($zip->set_number('7011342')->is_valid_number, '岡山県岡山市北区加茂');
ok($zip->set_number('7011343')->is_valid_number, '岡山県岡山市北区惣爪');
ok($zip->set_number('7011344')->is_valid_number, '岡山県岡山市北区新庄下');
ok($zip->set_number('7011345')->is_valid_number, '岡山県岡山市北区新庄上');
ok($zip->set_number('7011346')->is_valid_number, '岡山県岡山市北区津寺');
ok($zip->set_number('7011351')->is_valid_number, '岡山県岡山市北区門前');
ok($zip->set_number('7011352')->is_valid_number, '岡山県岡山市北区小山');
ok($zip->set_number('7011353')->is_valid_number, '岡山県岡山市北区三手');
ok($zip->set_number('7011354')->is_valid_number, '岡山県岡山市北区高塚');
ok($zip->set_number('7011355')->is_valid_number, '岡山県岡山市北区高松田中');
ok($zip->set_number('7011356')->is_valid_number, '岡山県岡山市北区下土田');
ok($zip->set_number('7011357')->is_valid_number, '岡山県岡山市北区福崎');
ok($zip->set_number('7011461')->is_valid_number, '岡山県岡山市北区粟井');
ok($zip->set_number('7011462')->is_valid_number, '岡山県岡山市北区大井');
ok($zip->set_number('7011463')->is_valid_number, '岡山県岡山市北区足守');
ok($zip->set_number('7011464')->is_valid_number, '岡山県岡山市北区下足守');
ok($zip->set_number('7011465')->is_valid_number, '岡山県岡山市北区上土田');
ok($zip->set_number('7011521')->is_valid_number, '岡山県岡山市北区日近');
ok($zip->set_number('7011522')->is_valid_number, '岡山県岡山市北区杉谷');
ok($zip->set_number('7011523')->is_valid_number, '岡山県岡山市北区吉');
ok($zip->set_number('7011524')->is_valid_number, '岡山県岡山市北区下高田');
ok($zip->set_number('7011525')->is_valid_number, '岡山県岡山市北区上高田');
ok($zip->set_number('7011526')->is_valid_number, '岡山県岡山市北区山上');
ok($zip->set_number('7011527')->is_valid_number, '岡山県岡山市北区石妻');
ok($zip->set_number('7011601')->is_valid_number, '岡山県岡山市北区掛畑');
ok($zip->set_number('7011602')->is_valid_number, '岡山県岡山市北区真星');
ok($zip->set_number('7011603')->is_valid_number, '岡山県岡山市北区庄田');
ok($zip->set_number('7011604')->is_valid_number, '岡山県岡山市北区苔山');
ok($zip->set_number('7011605')->is_valid_number, '岡山県岡山市北区河原');
ok($zip->set_number('7011611')->is_valid_number, '岡山県岡山市北区東山内');
ok($zip->set_number('7011612')->is_valid_number, '岡山県岡山市北区西山内');
ok($zip->set_number('7011613')->is_valid_number, '岡山県岡山市北区間倉');
ok($zip->set_number('7012141')->is_valid_number, '岡山県岡山市北区牟佐');
ok($zip->set_number('7012142')->is_valid_number, '岡山県岡山市北区玉柏');
ok($zip->set_number('7012143')->is_valid_number, '岡山県岡山市北区下牧');
ok($zip->set_number('7012144')->is_valid_number, '岡山県岡山市北区中牧');
ok($zip->set_number('7012151')->is_valid_number, '岡山県岡山市北区金山寺');
ok($zip->set_number('7012152')->is_valid_number, '岡山県岡山市北区高野尻');
ok($zip->set_number('7012153')->is_valid_number, '岡山県岡山市北区畑鮎');
ok($zip->set_number('7012154')->is_valid_number, '岡山県岡山市北区原');
ok($zip->set_number('7012155')->is_valid_number, '岡山県岡山市北区中原');
ok($zip->set_number('7012201')->is_valid_number, '岡山県赤磐市小原');
ok($zip->set_number('7012202')->is_valid_number, '岡山県赤磐市坂辺');
ok($zip->set_number('7012203')->is_valid_number, '岡山県赤磐市惣分');
ok($zip->set_number('7012204')->is_valid_number, '岡山県赤磐市山手');
ok($zip->set_number('7012205')->is_valid_number, '岡山県赤磐市大屋');
ok($zip->set_number('7012211')->is_valid_number, '岡山県赤磐市北佐古田');
ok($zip->set_number('7012212')->is_valid_number, '岡山県赤磐市南佐古田');
ok($zip->set_number('7012213')->is_valid_number, '岡山県赤磐市今井');
ok($zip->set_number('7012214')->is_valid_number, '岡山県赤磐市東軽部');
ok($zip->set_number('7012215')->is_valid_number, '岡山県赤磐市西軽部');
ok($zip->set_number('7012216')->is_valid_number, '岡山県赤磐市多賀');
ok($zip->set_number('7012221')->is_valid_number, '岡山県赤磐市大苅田');
ok($zip->set_number('7012222')->is_valid_number, '岡山県赤磐市町苅田');
ok($zip->set_number('7012223')->is_valid_number, '岡山県赤磐市東窪田');
ok($zip->set_number('7012224')->is_valid_number, '岡山県赤磐市西窪田');
ok($zip->set_number('7012225')->is_valid_number, '岡山県赤磐市山口');
ok($zip->set_number('7012226')->is_valid_number, '岡山県赤磐市由津里');
ok($zip->set_number('7012431')->is_valid_number, '岡山県赤磐市戸津野');
ok($zip->set_number('7012432')->is_valid_number, '岡山県赤磐市塩木');
ok($zip->set_number('7012433')->is_valid_number, '岡山県赤磐市平山');
ok($zip->set_number('7012434')->is_valid_number, '岡山県赤磐市仁堀東');
ok($zip->set_number('7012435')->is_valid_number, '岡山県赤磐市仁堀中');
ok($zip->set_number('7012436')->is_valid_number, '岡山県赤磐市仁堀西');
ok($zip->set_number('7012437')->is_valid_number, '岡山県赤磐市中勢実');
ok($zip->set_number('7012441')->is_valid_number, '岡山県赤磐市西勢実');
ok($zip->set_number('7012442')->is_valid_number, '岡山県赤磐市広戸');
ok($zip->set_number('7012443')->is_valid_number, '岡山県赤磐市合田');
ok($zip->set_number('7012444')->is_valid_number, '岡山県赤磐市中畑');
ok($zip->set_number('7012445')->is_valid_number, '岡山県赤磐市石上');
ok($zip->set_number('7012446')->is_valid_number, '岡山県赤磐市小鎌');
ok($zip->set_number('7012501')->is_valid_number, '岡山県赤磐市河原屋');
ok($zip->set_number('7012502')->is_valid_number, '岡山県赤磐市草生');
ok($zip->set_number('7012503')->is_valid_number, '岡山県赤磐市周匝');
ok($zip->set_number('7012504')->is_valid_number, '岡山県赤磐市福田');
ok($zip->set_number('7012511')->is_valid_number, '岡山県赤磐市稲蒔');
ok($zip->set_number('7012512')->is_valid_number, '岡山県赤磐市暮田');
ok($zip->set_number('7012513')->is_valid_number, '岡山県赤磐市八島田');
ok($zip->set_number('7012514')->is_valid_number, '岡山県赤磐市石');
ok($zip->set_number('7012515')->is_valid_number, '岡山県赤磐市光木');
ok($zip->set_number('7012521')->is_valid_number, '岡山県赤磐市黒本');
ok($zip->set_number('7012522')->is_valid_number, '岡山県赤磐市黒沢');
ok($zip->set_number('7012523')->is_valid_number, '岡山県赤磐市中山');
ok($zip->set_number('7012524')->is_valid_number, '岡山県赤磐市滝山');
ok($zip->set_number('7012525')->is_valid_number, '岡山県赤磐市是里');
ok($zip->set_number('7012601')->is_valid_number, '岡山県美作市尾谷');
ok($zip->set_number('7012602')->is_valid_number, '岡山県美作市真神');
ok($zip->set_number('7012603')->is_valid_number, '岡山県美作市三保原');
ok($zip->set_number('7012604')->is_valid_number, '岡山県美作市福本');
ok($zip->set_number('7012605')->is_valid_number, '岡山県美作市奥');
ok($zip->set_number('7012606')->is_valid_number, '岡山県美作市井口');
ok($zip->set_number('7012611')->is_valid_number, '岡山県美作市北');
ok($zip->set_number('7012612')->is_valid_number, '岡山県美作市滝宮');
ok($zip->set_number('7012613')->is_valid_number, '岡山県美作市横尾');
ok($zip->set_number('7012614')->is_valid_number, '岡山県美作市上山');
ok($zip->set_number('7012615')->is_valid_number, '岡山県美作市中川');
ok($zip->set_number('7012616')->is_valid_number, '岡山県美作市南');
ok($zip->set_number('7012621')->is_valid_number, '岡山県美作市下山');
ok($zip->set_number('7012622')->is_valid_number, '岡山県美作市鳥渕');
ok($zip->set_number('7012623')->is_valid_number, '岡山県美作市英田青野');
ok($zip->set_number('7012624')->is_valid_number, '岡山県美作市中河内');
ok($zip->set_number('7012625')->is_valid_number, '岡山県美作市城田');
ok($zip->set_number('7013201')->is_valid_number, '岡山県備前市日生町寺山');
ok($zip->set_number('7013202')->is_valid_number, '岡山県備前市日生町寒河');
ok($zip->set_number('7013203')->is_valid_number, '岡山県備前市日生町大多府');
ok($zip->set_number('7013204')->is_valid_number, '岡山県備前市日生町日生');
ok($zip->set_number('7014200')->is_valid_number, '岡山県瀬戸内市以下に掲載がない場合');
ok($zip->set_number('7014211')->is_valid_number, '岡山県瀬戸内市邑久町庄田');
ok($zip->set_number('7014212')->is_valid_number, '岡山県瀬戸内市邑久町尻海');
ok($zip->set_number('7014213')->is_valid_number, '岡山県瀬戸内市邑久町山手');
ok($zip->set_number('7014214')->is_valid_number, '岡山県瀬戸内市邑久町本庄');
ok($zip->set_number('7014215')->is_valid_number, '岡山県瀬戸内市邑久町上山田');
ok($zip->set_number('7014216')->is_valid_number, '岡山県瀬戸内市邑久町下山田');
ok($zip->set_number('7014221')->is_valid_number, '岡山県瀬戸内市邑久町尾張');
ok($zip->set_number('7014222')->is_valid_number, '岡山県瀬戸内市邑久町豊安');
ok($zip->set_number('7014223')->is_valid_number, '岡山県瀬戸内市邑久町豊原');
ok($zip->set_number('7014224')->is_valid_number, '岡山県瀬戸内市邑久町東谷');
ok($zip->set_number('7014231')->is_valid_number, '岡山県瀬戸内市邑久町大窪');
ok($zip->set_number('7014232')->is_valid_number, '岡山県瀬戸内市邑久町北島');
ok($zip->set_number('7014233')->is_valid_number, '岡山県瀬戸内市邑久町向山');
ok($zip->set_number('7014234')->is_valid_number, '岡山県瀬戸内市邑久町大富');
ok($zip->set_number('7014241')->is_valid_number, '岡山県瀬戸内市邑久町福元');
ok($zip->set_number('7014243')->is_valid_number, '岡山県瀬戸内市邑久町宗三');
ok($zip->set_number('7014244')->is_valid_number, '岡山県瀬戸内市邑久町福中');
ok($zip->set_number('7014245')->is_valid_number, '岡山県瀬戸内市邑久町福山');
ok($zip->set_number('7014246')->is_valid_number, '岡山県瀬戸内市邑久町山田庄');
ok($zip->set_number('7014247')->is_valid_number, '岡山県瀬戸内市邑久町下笠加');
ok($zip->set_number('7014248')->is_valid_number, '岡山県瀬戸内市邑久町百田');
ok($zip->set_number('7014251')->is_valid_number, '岡山県瀬戸内市邑久町北池');
ok($zip->set_number('7014252')->is_valid_number, '岡山県瀬戸内市邑久町上笠加');
ok($zip->set_number('7014253')->is_valid_number, '岡山県瀬戸内市邑久町箕輪');
ok($zip->set_number('7014254')->is_valid_number, '岡山県瀬戸内市邑久町豆田');
ok($zip->set_number('7014261')->is_valid_number, '岡山県瀬戸内市長船町飯井');
ok($zip->set_number('7014262')->is_valid_number, '岡山県瀬戸内市長船町東須恵');
ok($zip->set_number('7014263')->is_valid_number, '岡山県瀬戸内市長船町西須恵');
ok($zip->set_number('7014264')->is_valid_number, '岡山県瀬戸内市長船町土師');
ok($zip->set_number('7014265')->is_valid_number, '岡山県瀬戸内市長船町福岡');
ok($zip->set_number('7014271')->is_valid_number, '岡山県瀬戸内市長船町長船');
ok($zip->set_number('7014272')->is_valid_number, '岡山県瀬戸内市長船町八日市');
ok($zip->set_number('7014273')->is_valid_number, '岡山県瀬戸内市長船町磯上');
ok($zip->set_number('7014274')->is_valid_number, '岡山県瀬戸内市長船町牛文');
ok($zip->set_number('7014275')->is_valid_number, '岡山県瀬戸内市長船町福里');
ok($zip->set_number('7014276')->is_valid_number, '岡山県瀬戸内市長船町服部');
ok($zip->set_number('7014301')->is_valid_number, '岡山県瀬戸内市牛窓町長浜');
ok($zip->set_number('7014302')->is_valid_number, '岡山県瀬戸内市牛窓町牛窓');
ok($zip->set_number('7014303')->is_valid_number, '岡山県瀬戸内市牛窓町鹿忍');
ok($zip->set_number('7014304')->is_valid_number, '岡山県瀬戸内市牛窓町千手');
ok($zip->set_number('7014501')->is_valid_number, '岡山県瀬戸内市邑久町虫明');
ok($zip->set_number('7014502')->is_valid_number, '岡山県瀬戸内市邑久町福谷');
ok($zip->set_number('7028001')->is_valid_number, '岡山県岡山市中区沖元');
ok($zip->set_number('7028002')->is_valid_number, '岡山県岡山市中区桑野');
ok($zip->set_number('7028003')->is_valid_number, '岡山県岡山市中区新築港');
ok($zip->set_number('7028004')->is_valid_number, '岡山県岡山市中区江並');
ok($zip->set_number('7028005')->is_valid_number, '岡山県岡山市中区江崎');
ok($zip->set_number('7028006')->is_valid_number, '岡山県岡山市中区藤崎');
ok($zip->set_number('7028011')->is_valid_number, '岡山県岡山市南区郡');
ok($zip->set_number('7028012')->is_valid_number, '岡山県岡山市南区北浦');
ok($zip->set_number('7028013')->is_valid_number, '岡山県岡山市南区飽浦');
ok($zip->set_number('7028014')->is_valid_number, '岡山県岡山市南区宮浦');
ok($zip->set_number('7028015')->is_valid_number, '岡山県岡山市南区阿津');
ok($zip->set_number('7028016')->is_valid_number, '岡山県岡山市南区小串');
ok($zip->set_number('7028021')->is_valid_number, '岡山県岡山市南区福田');
ok($zip->set_number('7028022')->is_valid_number, '岡山県岡山市南区福成');
ok($zip->set_number('7028023')->is_valid_number, '岡山県岡山市南区南輝');
ok($zip->set_number('7028024')->is_valid_number, '岡山県岡山市南区浦安南町');
ok($zip->set_number('7028025')->is_valid_number, '岡山県岡山市南区浦安西町');
ok($zip->set_number('7028026')->is_valid_number, '岡山県岡山市南区浦安本町');
ok($zip->set_number('7028027')->is_valid_number, '岡山県岡山市南区芳泉');
ok($zip->set_number('7028031')->is_valid_number, '岡山県岡山市南区福富西');
ok($zip->set_number('7028032')->is_valid_number, '岡山県岡山市南区福富中');
ok($zip->set_number('7028033')->is_valid_number, '岡山県岡山市南区福富東');
ok($zip->set_number('7028034')->is_valid_number, '岡山県岡山市南区福浜西町');
ok($zip->set_number('7028035')->is_valid_number, '岡山県岡山市南区福浜町');
ok($zip->set_number('7028036')->is_valid_number, '岡山県岡山市南区三浜町');
ok($zip->set_number('7028037')->is_valid_number, '岡山県岡山市南区千鳥町');
ok($zip->set_number('7028038')->is_valid_number, '岡山県岡山市南区松浜町');
ok($zip->set_number('7028041')->is_valid_number, '岡山県岡山市南区富浜町');
ok($zip->set_number('7028042')->is_valid_number, '岡山県岡山市南区洲崎');
ok($zip->set_number('7028043')->is_valid_number, '岡山県岡山市南区平福');
ok($zip->set_number('7028044')->is_valid_number, '岡山県岡山市南区福島');
ok($zip->set_number('7028045')->is_valid_number, '岡山県岡山市南区海岸通');
ok($zip->set_number('7028046')->is_valid_number, '岡山県岡山市南区立川町');
ok($zip->set_number('7028047')->is_valid_number, '岡山県岡山市南区若葉町');
ok($zip->set_number('7028048')->is_valid_number, '岡山県岡山市南区福吉町');
ok($zip->set_number('7028051')->is_valid_number, '岡山県岡山市南区築港元町');
ok($zip->set_number('7028052')->is_valid_number, '岡山県岡山市南区市場');
ok($zip->set_number('7028053')->is_valid_number, '岡山県岡山市南区築港栄町');
ok($zip->set_number('7028054')->is_valid_number, '岡山県岡山市南区築港ひかり町');
ok($zip->set_number('7028055')->is_valid_number, '岡山県岡山市南区築港緑町');
ok($zip->set_number('7028056')->is_valid_number, '岡山県岡山市南区築港新町');
ok($zip->set_number('7028057')->is_valid_number, '岡山県岡山市南区あけぼの町');
ok($zip->set_number('7028058')->is_valid_number, '岡山県岡山市南区並木町');
ok($zip->set_number('7038201')->is_valid_number, '岡山県岡山市中区四御神');
ok($zip->set_number('7038202')->is_valid_number, '岡山県岡山市中区湯迫');
ok($zip->set_number('7038203')->is_valid_number, '岡山県岡山市中区国府市場');
ok($zip->set_number('7038204')->is_valid_number, '岡山県岡山市中区雄町');
ok($zip->set_number('7038205')->is_valid_number, '岡山県岡山市中区中井');
ok($zip->set_number('7038206')->is_valid_number, '岡山県岡山市中区賞田');
ok($zip->set_number('7038207')->is_valid_number, '岡山県岡山市北区祇園');
ok($zip->set_number('7038207')->is_valid_number, '岡山県岡山市中区祇園');
ok($zip->set_number('7038208')->is_valid_number, '岡山県岡山市中区今在家');
ok($zip->set_number('7038211')->is_valid_number, '岡山県岡山市東区矢津');
ok($zip->set_number('7038212')->is_valid_number, '岡山県岡山市東区古都宿');
ok($zip->set_number('7038213')->is_valid_number, '岡山県岡山市東区藤井');
ok($zip->set_number('7038214')->is_valid_number, '岡山県岡山市東区鉄');
ok($zip->set_number('7038215')->is_valid_number, '岡山県岡山市東区古都南方');
ok($zip->set_number('7038216')->is_valid_number, '岡山県岡山市東区宍甘');
ok($zip->set_number('7038217')->is_valid_number, '岡山県岡山市中区土田');
ok($zip->set_number('7038221')->is_valid_number, '岡山県岡山市中区長岡');
ok($zip->set_number('7038222')->is_valid_number, '岡山県岡山市中区下');
ok($zip->set_number('7038223')->is_valid_number, '岡山県岡山市中区長利');
ok($zip->set_number('7038224')->is_valid_number, '岡山県岡山市中区米田');
ok($zip->set_number('7038225')->is_valid_number, '岡山県岡山市中区神下');
ok($zip->set_number('7038226')->is_valid_number, '岡山県岡山市中区今谷');
ok($zip->set_number('7038227')->is_valid_number, '岡山県岡山市中区兼基');
ok($zip->set_number('7038228')->is_valid_number, '岡山県岡山市中区乙多見');
ok($zip->set_number('7038231')->is_valid_number, '岡山県岡山市中区赤田');
ok($zip->set_number('7038232')->is_valid_number, '岡山県岡山市中区関');
ok($zip->set_number('7038233')->is_valid_number, '岡山県岡山市中区高屋');
ok($zip->set_number('7038234')->is_valid_number, '岡山県岡山市中区沢田');
ok($zip->set_number('7038235')->is_valid_number, '岡山県岡山市中区原尾島');
ok($zip->set_number('7038236')->is_valid_number, '岡山県岡山市中区国富');
ok($zip->set_number('7038237')->is_valid_number, '岡山県岡山市中区森下町');
ok($zip->set_number('7038238')->is_valid_number, '岡山県岡山市中区住吉町');
ok($zip->set_number('7038241')->is_valid_number, '岡山県岡山市中区高島新屋敷');
ok($zip->set_number('7038242')->is_valid_number, '岡山県岡山市中区高島');
ok($zip->set_number('7038243')->is_valid_number, '岡山県岡山市中区清水');
ok($zip->set_number('7038244')->is_valid_number, '岡山県岡山市中区藤原西町');
ok($zip->set_number('7038245')->is_valid_number, '岡山県岡山市中区藤原');
ok($zip->set_number('7038246')->is_valid_number, '岡山県岡山市中区藤原光町');
ok($zip->set_number('7038247')->is_valid_number, '岡山県岡山市中区さい東町');
ok($zip->set_number('7038248')->is_valid_number, '岡山県岡山市中区さい');
ok($zip->set_number('7038251')->is_valid_number, '岡山県岡山市中区竹田');
ok($zip->set_number('7038252')->is_valid_number, '岡山県岡山市中区中島');
ok($zip->set_number('7038253')->is_valid_number, '岡山県岡山市中区八幡東町');
ok($zip->set_number('7038254')->is_valid_number, '岡山県岡山市中区八幡');
ok($zip->set_number('7038255')->is_valid_number, '岡山県岡山市中区東川原');
ok($zip->set_number('7038256')->is_valid_number, '岡山県岡山市中区浜');
ok($zip->set_number('7038257')->is_valid_number, '岡山県岡山市北区後楽園');
ok($zip->set_number('7038258')->is_valid_number, '岡山県岡山市中区西川原');
ok($zip->set_number('7038261')->is_valid_number, '岡山県岡山市中区海吉');
ok($zip->set_number('7038262')->is_valid_number, '岡山県岡山市中区福泊');
ok($zip->set_number('7038263')->is_valid_number, '岡山県岡山市中区倉益');
ok($zip->set_number('7038264')->is_valid_number, '岡山県岡山市中区倉富');
ok($zip->set_number('7038265')->is_valid_number, '岡山県岡山市中区倉田');
ok($zip->set_number('7038266')->is_valid_number, '岡山県岡山市中区湊');
ok($zip->set_number('7038267')->is_valid_number, '岡山県岡山市中区山崎');
ok($zip->set_number('7038271')->is_valid_number, '岡山県岡山市中区円山');
ok($zip->set_number('7038272')->is_valid_number, '岡山県岡山市中区奥市');
ok($zip->set_number('7038273')->is_valid_number, '岡山県岡山市中区門田文化町');
ok($zip->set_number('7038274')->is_valid_number, '岡山県岡山市中区門田本町');
ok($zip->set_number('7038275')->is_valid_number, '岡山県岡山市中区門田屋敷');
ok($zip->set_number('7038276')->is_valid_number, '岡山県岡山市中区門田屋敷本町');
ok($zip->set_number('7038277')->is_valid_number, '岡山県岡山市中区御成町');
ok($zip->set_number('7038278')->is_valid_number, '岡山県岡山市中区古京町');
ok($zip->set_number('7038281')->is_valid_number, '岡山県岡山市中区東山');
ok($zip->set_number('7038282')->is_valid_number, '岡山県岡山市中区平井');
ok($zip->set_number('7038283')->is_valid_number, '岡山県岡山市中区赤坂南新町');
ok($zip->set_number('7038284')->is_valid_number, '岡山県岡山市中区網浜');
ok($zip->set_number('7038285')->is_valid_number, '岡山県岡山市中区桜橋');
ok($zip->set_number('7038286')->is_valid_number, '岡山県岡山市中区旭東町');
ok($zip->set_number('7038287')->is_valid_number, '岡山県岡山市中区赤坂台');
ok($zip->set_number('7038288')->is_valid_number, '岡山県岡山市中区赤坂本町');
ok($zip->set_number('7038291')->is_valid_number, '岡山県岡山市中区徳吉町');
ok($zip->set_number('7038292')->is_valid_number, '岡山県岡山市中区中納言町');
ok($zip->set_number('7038293')->is_valid_number, '岡山県岡山市中区小橋町');
ok($zip->set_number('7038294')->is_valid_number, '岡山県岡山市中区新京橋');
ok($zip->set_number('7038295')->is_valid_number, '岡山県岡山市中区御幸町');
ok($zip->set_number('7038296')->is_valid_number, '岡山県岡山市中区さくら住座');
ok($zip->set_number('7038297')->is_valid_number, '岡山県岡山市中区東中島町');
ok($zip->set_number('7038298')->is_valid_number, '岡山県岡山市中区西中島町');
ok($zip->set_number('7048101')->is_valid_number, '岡山県岡山市東区西隆寺');
ok($zip->set_number('7048102')->is_valid_number, '岡山県岡山市東区久保');
ok($zip->set_number('7048103')->is_valid_number, '岡山県岡山市東区河本町');
ok($zip->set_number('7048104')->is_valid_number, '岡山県岡山市東区富崎');
ok($zip->set_number('7048105')->is_valid_number, '岡山県岡山市東区吉原');
ok($zip->set_number('7048106')->is_valid_number, '岡山県岡山市東区西庄');
ok($zip->set_number('7048107')->is_valid_number, '岡山県岡山市東区福治');
ok($zip->set_number('7048111')->is_valid_number, '岡山県岡山市東区西大寺北');
ok($zip->set_number('7048112')->is_valid_number, '岡山県岡山市東区西大寺上');
ok($zip->set_number('7048113')->is_valid_number, '岡山県岡山市東区西大寺');
ok($zip->set_number('7048114')->is_valid_number, '岡山県岡山市東区西大寺東');
ok($zip->set_number('7048115')->is_valid_number, '岡山県岡山市東区向州');
ok($zip->set_number('7048116')->is_valid_number, '岡山県岡山市東区西大寺中');
ok($zip->set_number('7048117')->is_valid_number, '岡山県岡山市東区西大寺南');
ok($zip->set_number('7048121')->is_valid_number, '岡山県岡山市東区西大寺射越');
ok($zip->set_number('7048122')->is_valid_number, '岡山県岡山市東区西大寺新地');
ok($zip->set_number('7048123')->is_valid_number, '岡山県岡山市東区西大寺門前');
ok($zip->set_number('7048124')->is_valid_number, '岡山県岡山市東区西大寺五明');
ok($zip->set_number('7048125')->is_valid_number, '岡山県岡山市東区西大寺川口');
ok($zip->set_number('7048126')->is_valid_number, '岡山県岡山市東区西大寺浜');
ok($zip->set_number('7048127')->is_valid_number, '岡山県岡山市東区西大寺新');
ok($zip->set_number('7048131')->is_valid_number, '岡山県岡山市東区長沼');
ok($zip->set_number('7048132')->is_valid_number, '岡山県岡山市東区邑久郷');
ok($zip->set_number('7048133')->is_valid_number, '岡山県岡山市東区宿毛');
ok($zip->set_number('7048134')->is_valid_number, '岡山県岡山市東区北幸田');
ok($zip->set_number('7048135')->is_valid_number, '岡山県岡山市東区東幸西');
ok($zip->set_number('7048136')->is_valid_number, '岡山県岡山市東区西幸西');
ok($zip->set_number('7048137')->is_valid_number, '岡山県岡山市東区乙子');
ok($zip->set_number('7048138')->is_valid_number, '岡山県岡山市東区神崎町');
ok($zip->set_number('7048141')->is_valid_number, '岡山県岡山市東区下阿知');
ok($zip->set_number('7048142')->is_valid_number, '岡山県岡山市東区上阿知');
ok($zip->set_number('7048143')->is_valid_number, '岡山県岡山市東区千手');
ok($zip->set_number('7048144')->is_valid_number, '岡山県岡山市東区西大寺一宮');
ok($zip->set_number('7048145')->is_valid_number, '岡山県岡山市東区東幸崎');
ok($zip->set_number('7048146')->is_valid_number, '岡山県岡山市東区南水門町');
ok($zip->set_number('7048147')->is_valid_number, '岡山県岡山市東区正儀');
ok($zip->set_number('7048148')->is_valid_number, '岡山県岡山市東区水門町');
ok($zip->set_number('7048149')->is_valid_number, '岡山県岡山市東区幸地崎町');
ok($zip->set_number('7048151')->is_valid_number, '岡山県岡山市東区東片岡');
ok($zip->set_number('7048152')->is_valid_number, '岡山県岡山市東区宝伝');
ok($zip->set_number('7048153')->is_valid_number, '岡山県岡山市東区犬島');
ok($zip->set_number('7048154')->is_valid_number, '岡山県岡山市東区久々井');
ok($zip->set_number('7048155')->is_valid_number, '岡山県岡山市東区西片岡');
ok($zip->set_number('7048161')->is_valid_number, '岡山県岡山市東区九蟠');
ok($zip->set_number('7048162')->is_valid_number, '岡山県岡山市東区豊田');
ok($zip->set_number('7048163')->is_valid_number, '岡山県岡山市東区升田');
ok($zip->set_number('7048164')->is_valid_number, '岡山県岡山市東区光津');
ok($zip->set_number('7048165')->is_valid_number, '岡山県岡山市東区政津');
ok($zip->set_number('7048166')->is_valid_number, '岡山県岡山市東区君津');
ok($zip->set_number('7048171')->is_valid_number, '岡山県岡山市東区目黒町');
ok($zip->set_number('7048172')->is_valid_number, '岡山県岡山市東区大多羅町');
ok($zip->set_number('7048173')->is_valid_number, '岡山県岡山市東区可知');
ok($zip->set_number('7048174')->is_valid_number, '岡山県岡山市東区松新町');
ok($zip->set_number('7048175')->is_valid_number, '岡山県岡山市東区益野町');
ok($zip->set_number('7048176')->is_valid_number, '岡山県岡山市東区中川町');
ok($zip->set_number('7048181')->is_valid_number, '岡山県岡山市東区浅越');
ok($zip->set_number('7048182')->is_valid_number, '岡山県岡山市東区広谷');
ok($zip->set_number('7048183')->is_valid_number, '岡山県岡山市東区西大寺松崎');
ok($zip->set_number('7048184')->is_valid_number, '岡山県岡山市東区富士見町');
ok($zip->set_number('7048191')->is_valid_number, '岡山県岡山市東区西大寺中野');
ok($zip->set_number('7048192')->is_valid_number, '岡山県岡山市東区西大寺中野本町');
ok($zip->set_number('7048193')->is_valid_number, '岡山県岡山市東区金岡西町');
ok($zip->set_number('7048194')->is_valid_number, '岡山県岡山市東区金岡東町');
ok($zip->set_number('7048195')->is_valid_number, '岡山県岡山市東区西大寺金岡');
ok($zip->set_number('7048196')->is_valid_number, '岡山県岡山市東区金田');
ok($zip->set_number('7050000')->is_valid_number, '岡山県備前市以下に掲載がない場合');
ok($zip->set_number('7050001')->is_valid_number, '岡山県備前市伊部');
ok($zip->set_number('7050002')->is_valid_number, '岡山県備前市浦伊部');
ok($zip->set_number('7050003')->is_valid_number, '岡山県備前市大内');
ok($zip->set_number('7050011')->is_valid_number, '岡山県備前市香登西');
ok($zip->set_number('7050012')->is_valid_number, '岡山県備前市香登本');
ok($zip->set_number('7050013')->is_valid_number, '岡山県備前市福田');
ok($zip->set_number('7050014')->is_valid_number, '岡山県備前市新庄');
ok($zip->set_number('7050015')->is_valid_number, '岡山県備前市畠田');
ok($zip->set_number('7050016')->is_valid_number, '岡山県備前市坂根');
ok($zip->set_number('7050021')->is_valid_number, '岡山県備前市西片上');
ok($zip->set_number('7050022')->is_valid_number, '岡山県備前市東片上');
ok($zip->set_number('7050023')->is_valid_number, '岡山県備前市伊里中');
ok($zip->set_number('7050024')->is_valid_number, '岡山県備前市久々井');
ok($zip->set_number('7050025')->is_valid_number, '岡山県備前市鶴海');
ok($zip->set_number('7050026')->is_valid_number, '岡山県備前市佐山');
ok($zip->set_number('7050031')->is_valid_number, '岡山県備前市蕃山');
ok($zip->set_number('7050032')->is_valid_number, '岡山県備前市麻宇那');
ok($zip->set_number('7050033')->is_valid_number, '岡山県備前市穂浪');
ok($zip->set_number('7050034')->is_valid_number, '岡山県備前市友延');
ok($zip->set_number('7050035')->is_valid_number, '岡山県備前市木谷');
ok($zip->set_number('7050036')->is_valid_number, '岡山県備前市閑谷');
ok($zip->set_number('7050131')->is_valid_number, '岡山県備前市野谷');
ok($zip->set_number('7050132')->is_valid_number, '岡山県備前市三石');
ok($zip->set_number('7050133')->is_valid_number, '岡山県備前市八木山');
ok($zip->set_number('7060000')->is_valid_number, '岡山県玉野市以下に掲載がない場合');
ok($zip->set_number('7060001')->is_valid_number, '岡山県玉野市田井');
ok($zip->set_number('7060002')->is_valid_number, '岡山県玉野市築港');
ok($zip->set_number('7060011')->is_valid_number, '岡山県玉野市宇野');
ok($zip->set_number('7060012')->is_valid_number, '岡山県玉野市玉');
ok($zip->set_number('7060013')->is_valid_number, '岡山県玉野市奥玉');
ok($zip->set_number('7060014')->is_valid_number, '岡山県玉野市玉原');
ok($zip->set_number('7060021')->is_valid_number, '岡山県玉野市和田');
ok($zip->set_number('7060022')->is_valid_number, '岡山県玉野市向日比');
ok($zip->set_number('7060023')->is_valid_number, '岡山県玉野市深井町');
ok($zip->set_number('7060024')->is_valid_number, '岡山県玉野市御崎');
ok($zip->set_number('7060025')->is_valid_number, '岡山県玉野市明神町');
ok($zip->set_number('7060026')->is_valid_number, '岡山県玉野市羽根崎町');
ok($zip->set_number('7060027')->is_valid_number, '岡山県玉野市日比');
ok($zip->set_number('7060028')->is_valid_number, '岡山県玉野市渋川');
ok($zip->set_number('7060131')->is_valid_number, '岡山県玉野市東紅陽台');
ok($zip->set_number('7060132')->is_valid_number, '岡山県玉野市用吉');
ok($zip->set_number('7060133')->is_valid_number, '岡山県玉野市宇藤木');
ok($zip->set_number('7060134')->is_valid_number, '岡山県玉野市東高崎');
ok($zip->set_number('7060141')->is_valid_number, '岡山県玉野市槌ケ原');
ok($zip->set_number('7060142')->is_valid_number, '岡山県玉野市迫間');
ok($zip->set_number('7060143')->is_valid_number, '岡山県玉野市木目');
ok($zip->set_number('7060144')->is_valid_number, '岡山県玉野市小島地');
ok($zip->set_number('7060151')->is_valid_number, '岡山県玉野市長尾');
ok($zip->set_number('7060152')->is_valid_number, '岡山県玉野市永井');
ok($zip->set_number('7060153')->is_valid_number, '岡山県玉野市滝');
ok($zip->set_number('7060154')->is_valid_number, '岡山県玉野市広岡');
ok($zip->set_number('7060221')->is_valid_number, '岡山県玉野市八浜町八浜');
ok($zip->set_number('7060222')->is_valid_number, '岡山県玉野市八浜町見石');
ok($zip->set_number('7060223')->is_valid_number, '岡山県玉野市八浜町波知');
ok($zip->set_number('7060224')->is_valid_number, '岡山県玉野市八浜町大崎');
ok($zip->set_number('7060225')->is_valid_number, '岡山県玉野市南七区');
ok($zip->set_number('7060226')->is_valid_number, '岡山県玉野市東七区');
ok($zip->set_number('7060301')->is_valid_number, '岡山県玉野市北方');
ok($zip->set_number('7060302')->is_valid_number, '岡山県玉野市下山坂');
ok($zip->set_number('7060303')->is_valid_number, '岡山県玉野市上山坂');
ok($zip->set_number('7060304')->is_valid_number, '岡山県玉野市番田');
ok($zip->set_number('7060305')->is_valid_number, '岡山県玉野市胸上');
ok($zip->set_number('7060306')->is_valid_number, '岡山県玉野市石島');
ok($zip->set_number('7060311')->is_valid_number, '岡山県玉野市梶岡');
ok($zip->set_number('7060312')->is_valid_number, '岡山県玉野市東田井地');
ok($zip->set_number('7060313')->is_valid_number, '岡山県玉野市西田井地');
ok($zip->set_number('7060314')->is_valid_number, '岡山県玉野市東野崎');
ok($zip->set_number('7060314')->is_valid_number, '岡山県玉野市山田');
ok($zip->set_number('7060315')->is_valid_number, '岡山県玉野市後閑');
ok($zip->set_number('7060316')->is_valid_number, '岡山県玉野市沼');
ok($zip->set_number('7060317')->is_valid_number, '岡山県玉野市大薮');
ok($zip->set_number('7070000')->is_valid_number, '岡山県美作市以下に掲載がない場合');
ok($zip->set_number('7070001')->is_valid_number, '岡山県美作市上相');
ok($zip->set_number('7070002')->is_valid_number, '岡山県美作市中尾');
ok($zip->set_number('7070003')->is_valid_number, '岡山県美作市明見');
ok($zip->set_number('7070004')->is_valid_number, '岡山県美作市入田');
ok($zip->set_number('7070005')->is_valid_number, '岡山県美作市大井が丘');
ok($zip->set_number('7070011')->is_valid_number, '岡山県美作市和田');
ok($zip->set_number('7070012')->is_valid_number, '岡山県美作市田殿');
ok($zip->set_number('7070013')->is_valid_number, '岡山県美作市吉');
ok($zip->set_number('7070014')->is_valid_number, '岡山県美作市北山');
ok($zip->set_number('7070015')->is_valid_number, '岡山県美作市豊国原');
ok($zip->set_number('7070016')->is_valid_number, '岡山県美作市下香山');
ok($zip->set_number('7070021')->is_valid_number, '岡山県美作市楢原中');
ok($zip->set_number('7070022')->is_valid_number, '岡山県美作市楢原上');
ok($zip->set_number('7070023')->is_valid_number, '岡山県美作市平福');
ok($zip->set_number('7070024')->is_valid_number, '岡山県美作市楢原下');
ok($zip->set_number('7070025')->is_valid_number, '岡山県美作市栄町');
ok($zip->set_number('7070031')->is_valid_number, '岡山県美作市山口');
ok($zip->set_number('7070032')->is_valid_number, '岡山県美作市山外野');
ok($zip->set_number('7070033')->is_valid_number, '岡山県美作市大原');
ok($zip->set_number('7070034')->is_valid_number, '岡山県美作市猪臥');
ok($zip->set_number('7070035')->is_valid_number, '岡山県美作市平田');
ok($zip->set_number('7070036')->is_valid_number, '岡山県美作市北原');
ok($zip->set_number('7070037')->is_valid_number, '岡山県美作市友野');
ok($zip->set_number('7070041')->is_valid_number, '岡山県美作市林野');
ok($zip->set_number('7070042')->is_valid_number, '岡山県美作市朽木');
ok($zip->set_number('7070043')->is_valid_number, '岡山県美作市海内');
ok($zip->set_number('7070044')->is_valid_number, '岡山県美作市海田');
ok($zip->set_number('7070045')->is_valid_number, '岡山県美作市巨勢');
ok($zip->set_number('7070046')->is_valid_number, '岡山県美作市三倉田');
ok($zip->set_number('7070051')->is_valid_number, '岡山県美作市稲穂');
ok($zip->set_number('7070052')->is_valid_number, '岡山県美作市位田');
ok($zip->set_number('7070053')->is_valid_number, '岡山県美作市安蘇');
ok($zip->set_number('7070054')->is_valid_number, '岡山県美作市岩見田');
ok($zip->set_number('7070055')->is_valid_number, '岡山県美作市金原');
ok($zip->set_number('7070056')->is_valid_number, '岡山県美作市長内');
ok($zip->set_number('7070057')->is_valid_number, '岡山県美作市則平');
ok($zip->set_number('7070061')->is_valid_number, '岡山県美作市中山');
ok($zip->set_number('7070062')->is_valid_number, '岡山県美作市湯郷');
ok($zip->set_number('7070063')->is_valid_number, '岡山県美作市北坂');
ok($zip->set_number('7070064')->is_valid_number, '岡山県美作市殿所');
ok($zip->set_number('7070065')->is_valid_number, '岡山県美作市青木');
ok($zip->set_number('7070066')->is_valid_number, '岡山県美作市下大谷');
ok($zip->set_number('7070067')->is_valid_number, '岡山県美作市奥大谷');
ok($zip->set_number('7070111')->is_valid_number, '岡山県美作市久賀');
ok($zip->set_number('7070112')->is_valid_number, '岡山県美作市余野');
ok($zip->set_number('7070113')->is_valid_number, '岡山県美作市真加部');
ok($zip->set_number('7070121')->is_valid_number, '岡山県美作市長谷内');
ok($zip->set_number('7070122')->is_valid_number, '岡山県美作市馬形');
ok($zip->set_number('7070123')->is_valid_number, '岡山県美作市宗掛');
ok($zip->set_number('7070124')->is_valid_number, '岡山県美作市大町');
ok($zip->set_number('7070131')->is_valid_number, '岡山県美作市河内');
ok($zip->set_number('7070132')->is_valid_number, '岡山県美作市小畑');
ok($zip->set_number('7070133')->is_valid_number, '岡山県美作市杉原');
ok($zip->set_number('7070134')->is_valid_number, '岡山県美作市矢田');
ok($zip->set_number('7070201')->is_valid_number, '岡山県美作市梶並');
ok($zip->set_number('7070202')->is_valid_number, '岡山県美作市楮');
ok($zip->set_number('7070203')->is_valid_number, '岡山県美作市真殿');
ok($zip->set_number('7070204')->is_valid_number, '岡山県美作市右手');
ok($zip->set_number('7070205')->is_valid_number, '岡山県美作市東谷上');
ok($zip->set_number('7070206')->is_valid_number, '岡山県美作市東谷下');
ok($zip->set_number('7070401')->is_valid_number, '岡山県美作市後山');
ok($zip->set_number('7070402')->is_valid_number, '岡山県美作市中谷');
ok($zip->set_number('7070403')->is_valid_number, '岡山県美作市東青野');
ok($zip->set_number('7070404')->is_valid_number, '岡山県美作市太田');
ok($zip->set_number('7070405')->is_valid_number, '岡山県美作市野原');
ok($zip->set_number('7070406')->is_valid_number, '岡山県美作市東吉田');
ok($zip->set_number('7070407')->is_valid_number, '岡山県美作市川東');
ok($zip->set_number('7070411')->is_valid_number, '岡山県美作市江ノ原');
ok($zip->set_number('7070412')->is_valid_number, '岡山県美作市古町');
ok($zip->set_number('7070413')->is_valid_number, '岡山県美作市中町');
ok($zip->set_number('7070414')->is_valid_number, '岡山県美作市西町');
ok($zip->set_number('7070415')->is_valid_number, '岡山県美作市宮本');
ok($zip->set_number('7070416')->is_valid_number, '岡山県美作市今岡');
ok($zip->set_number('7070417')->is_valid_number, '岡山県美作市下町');
ok($zip->set_number('7070421')->is_valid_number, '岡山県美作市川上');
ok($zip->set_number('7070422')->is_valid_number, '岡山県美作市笹岡');
ok($zip->set_number('7070423')->is_valid_number, '岡山県美作市小原田');
ok($zip->set_number('7070424')->is_valid_number, '岡山県美作市野形');
ok($zip->set_number('7070425')->is_valid_number, '岡山県美作市下庄町');
ok($zip->set_number('7070426')->is_valid_number, '岡山県美作市桂坪');
ok($zip->set_number('7070427')->is_valid_number, '岡山県美作市滝');
ok($zip->set_number('7070431')->is_valid_number, '岡山県美作市田井');
ok($zip->set_number('7070432')->is_valid_number, '岡山県美作市赤田');
ok($zip->set_number('7070433')->is_valid_number, '岡山県美作市立石');
ok($zip->set_number('7070434')->is_valid_number, '岡山県美作市壬生');
ok($zip->set_number('7070435')->is_valid_number, '岡山県美作市沢田');
ok($zip->set_number('7070436')->is_valid_number, '岡山県美作市川戸');
ok($zip->set_number('7070437')->is_valid_number, '岡山県美作市粟野');
ok($zip->set_number('7070500')->is_valid_number, '岡山県英田郡西粟倉村以下に掲載がない場合');
ok($zip->set_number('7070501')->is_valid_number, '岡山県英田郡西粟倉村大茅');
ok($zip->set_number('7070502')->is_valid_number, '岡山県英田郡西粟倉村坂根');
ok($zip->set_number('7070503')->is_valid_number, '岡山県英田郡西粟倉村影石');
ok($zip->set_number('7070504')->is_valid_number, '岡山県英田郡西粟倉村長尾');
ok($zip->set_number('7070505')->is_valid_number, '岡山県英田郡西粟倉村筏津');
ok($zip->set_number('7070506')->is_valid_number, '岡山県英田郡西粟倉村知社');
ok($zip->set_number('7080000')->is_valid_number, '岡山県津山市以下に掲載がない場合');
ok($zip->set_number('7080001')->is_valid_number, '岡山県津山市小原');
ok($zip->set_number('7080002')->is_valid_number, '岡山県津山市上河原');
ok($zip->set_number('7080003')->is_valid_number, '岡山県津山市北園町');
ok($zip->set_number('7080004')->is_valid_number, '岡山県津山市山北');
ok($zip->set_number('7080005')->is_valid_number, '岡山県津山市城代町');
ok($zip->set_number('7080006')->is_valid_number, '岡山県津山市小田中');
ok($zip->set_number('7080007')->is_valid_number, '岡山県津山市総社');
ok($zip->set_number('7080011')->is_valid_number, '岡山県津山市上田邑');
ok($zip->set_number('7080012')->is_valid_number, '岡山県津山市下田邑');
ok($zip->set_number('7080013')->is_valid_number, '岡山県津山市二宮');
ok($zip->set_number('7080014')->is_valid_number, '岡山県津山市院庄');
ok($zip->set_number('7080015')->is_valid_number, '岡山県津山市神戸');
ok($zip->set_number('7080016')->is_valid_number, '岡山県津山市戸島');
ok($zip->set_number('7080021')->is_valid_number, '岡山県津山市北町');
ok($zip->set_number('7080022')->is_valid_number, '岡山県津山市山下');
ok($zip->set_number('7080023')->is_valid_number, '岡山県津山市大手町');
ok($zip->set_number('7080024')->is_valid_number, '岡山県津山市二階町');
ok($zip->set_number('7080031')->is_valid_number, '岡山県津山市材木町');
ok($zip->set_number('7080032')->is_valid_number, '岡山県津山市伏見町');
ok($zip->set_number('7080033')->is_valid_number, '岡山県津山市河原町');
ok($zip->set_number('7080034')->is_valid_number, '岡山県津山市船頭町');
ok($zip->set_number('7080035')->is_valid_number, '岡山県津山市吹屋町');
ok($zip->set_number('7080036')->is_valid_number, '岡山県津山市南新座');
ok($zip->set_number('7080037')->is_valid_number, '岡山県津山市戸川町');
ok($zip->set_number('7080041')->is_valid_number, '岡山県津山市鉄砲町');
ok($zip->set_number('7080042')->is_valid_number, '岡山県津山市新茅町');
ok($zip->set_number('7080043')->is_valid_number, '岡山県津山市茅町');
ok($zip->set_number('7080044')->is_valid_number, '岡山県津山市安岡町');
ok($zip->set_number('7080045')->is_valid_number, '岡山県津山市西寺町');
ok($zip->set_number('7080046')->is_valid_number, '岡山県津山市西今町');
ok($zip->set_number('7080047')->is_valid_number, '岡山県津山市宮脇町');
ok($zip->set_number('7080051')->is_valid_number, '岡山県津山市椿高下');
ok($zip->set_number('7080052')->is_valid_number, '岡山県津山市田町');
ok($zip->set_number('7080053')->is_valid_number, '岡山県津山市細工町');
ok($zip->set_number('7080061')->is_valid_number, '岡山県津山市元魚町');
ok($zip->set_number('7080062')->is_valid_number, '岡山県津山市京町');
ok($zip->set_number('7080063')->is_valid_number, '岡山県津山市小性町');
ok($zip->set_number('7080064')->is_valid_number, '岡山県津山市堺町');
ok($zip->set_number('7080065')->is_valid_number, '岡山県津山市新魚町');
ok($zip->set_number('7080066')->is_valid_number, '岡山県津山市桶屋町');
ok($zip->set_number('7080067')->is_valid_number, '岡山県津山市新職人町');
ok($zip->set_number('7080071')->is_valid_number, '岡山県津山市下紺屋町');
ok($zip->set_number('7080072')->is_valid_number, '岡山県津山市美濃町');
ok($zip->set_number('7080073')->is_valid_number, '岡山県津山市本町');
ok($zip->set_number('7080074')->is_valid_number, '岡山県津山市福渡町');
ok($zip->set_number('7080075')->is_valid_number, '岡山県津山市坪井町');
ok($zip->set_number('7080076')->is_valid_number, '岡山県津山市上紺屋町');
ok($zip->set_number('7080077')->is_valid_number, '岡山県津山市鍛治町');
ok($zip->set_number('7080300')->is_valid_number, '岡山県苫田郡鏡野町以下に掲載がない場合');
ok($zip->set_number('7080301')->is_valid_number, '岡山県苫田郡鏡野町越畑');
ok($zip->set_number('7080302')->is_valid_number, '岡山県苫田郡鏡野町岩屋');
ok($zip->set_number('7080303')->is_valid_number, '岡山県苫田郡鏡野町大町');
ok($zip->set_number('7080304')->is_valid_number, '岡山県苫田郡鏡野町真経');
ok($zip->set_number('7080305')->is_valid_number, '岡山県苫田郡鏡野町百谷');
ok($zip->set_number('7080311')->is_valid_number, '岡山県苫田郡鏡野町寺和田');
ok($zip->set_number('7080312')->is_valid_number, '岡山県苫田郡鏡野町香々美');
ok($zip->set_number('7080313')->is_valid_number, '岡山県苫田郡鏡野町公保田');
ok($zip->set_number('7080314')->is_valid_number, '岡山県苫田郡鏡野町沢田');
ok($zip->set_number('7080315')->is_valid_number, '岡山県苫田郡鏡野町市場');
ok($zip->set_number('7080316')->is_valid_number, '岡山県苫田郡鏡野町和田');
ok($zip->set_number('7080317')->is_valid_number, '岡山県苫田郡鏡野町土居');
ok($zip->set_number('7080321')->is_valid_number, '岡山県苫田郡鏡野町円宗寺');
ok($zip->set_number('7080322')->is_valid_number, '岡山県苫田郡鏡野町沖');
ok($zip->set_number('7080323')->is_valid_number, '岡山県苫田郡鏡野町寺元');
ok($zip->set_number('7080324')->is_valid_number, '岡山県苫田郡鏡野町竹田');
ok($zip->set_number('7080325')->is_valid_number, '岡山県苫田郡鏡野町瀬戸');
ok($zip->set_number('7080331')->is_valid_number, '岡山県苫田郡鏡野町布原');
ok($zip->set_number('7080332')->is_valid_number, '岡山県苫田郡鏡野町吉原');
ok($zip->set_number('7080333')->is_valid_number, '岡山県苫田郡鏡野町古川');
ok($zip->set_number('7080334')->is_valid_number, '岡山県苫田郡鏡野町宗枝');
ok($zip->set_number('7080335')->is_valid_number, '岡山県苫田郡鏡野町真加部');
ok($zip->set_number('7080341')->is_valid_number, '岡山県苫田郡鏡野町下原');
ok($zip->set_number('7080342')->is_valid_number, '岡山県苫田郡鏡野町薪森原');
ok($zip->set_number('7080343')->is_valid_number, '岡山県苫田郡鏡野町河本');
ok($zip->set_number('7080344')->is_valid_number, '岡山県苫田郡鏡野町原');
ok($zip->set_number('7080345')->is_valid_number, '岡山県苫田郡鏡野町高山');
ok($zip->set_number('7080351')->is_valid_number, '岡山県苫田郡鏡野町入');
ok($zip->set_number('7080352')->is_valid_number, '岡山県苫田郡鏡野町山城');
ok($zip->set_number('7080353')->is_valid_number, '岡山県苫田郡鏡野町中谷');
ok($zip->set_number('7080361')->is_valid_number, '岡山県苫田郡鏡野町上森原');
ok($zip->set_number('7080362')->is_valid_number, '岡山県苫田郡鏡野町貞永寺');
ok($zip->set_number('7080363')->is_valid_number, '岡山県苫田郡鏡野町小座');
ok($zip->set_number('7080364')->is_valid_number, '岡山県苫田郡鏡野町下森原');
ok($zip->set_number('7080365')->is_valid_number, '岡山県苫田郡鏡野町塚谷');
ok($zip->set_number('7080366')->is_valid_number, '岡山県苫田郡鏡野町馬場');
ok($zip->set_number('7080421')->is_valid_number, '岡山県苫田郡鏡野町井坂');
ok($zip->set_number('7080422')->is_valid_number, '岡山県苫田郡鏡野町養野');
ok($zip->set_number('7080423')->is_valid_number, '岡山県苫田郡鏡野町女原');
ok($zip->set_number('7080424')->is_valid_number, '岡山県苫田郡鏡野町杉');
ok($zip->set_number('7080425')->is_valid_number, '岡山県苫田郡鏡野町箱');
ok($zip->set_number('7080426')->is_valid_number, '岡山県苫田郡鏡野町西屋');
ok($zip->set_number('7080427')->is_valid_number, '岡山県苫田郡鏡野町至孝農');
ok($zip->set_number('7080431')->is_valid_number, '岡山県苫田郡鏡野町河内');
ok($zip->set_number('7080432')->is_valid_number, '岡山県苫田郡鏡野町久田上原');
ok($zip->set_number('7080433')->is_valid_number, '岡山県苫田郡鏡野町久田下原');
ok($zip->set_number('7080434')->is_valid_number, '岡山県苫田郡鏡野町土生');
ok($zip->set_number('7080435')->is_valid_number, '岡山県苫田郡鏡野町黒木');
ok($zip->set_number('7080501')->is_valid_number, '岡山県苫田郡鏡野町下斎原');
ok($zip->set_number('7080502')->is_valid_number, '岡山県苫田郡鏡野町長藤');
ok($zip->set_number('7080503')->is_valid_number, '岡山県苫田郡鏡野町奥津');
ok($zip->set_number('7080504')->is_valid_number, '岡山県苫田郡鏡野町奥津川西');
ok($zip->set_number('7080511')->is_valid_number, '岡山県苫田郡鏡野町羽出');
ok($zip->set_number('7080512')->is_valid_number, '岡山県苫田郡鏡野町羽出西谷');
ok($zip->set_number('7080601')->is_valid_number, '岡山県苫田郡鏡野町上齋原');
ok($zip->set_number('7080701')->is_valid_number, '岡山県苫田郡鏡野町富西谷');
ok($zip->set_number('7080702')->is_valid_number, '岡山県苫田郡鏡野町富東谷');
ok($zip->set_number('7080703')->is_valid_number, '岡山県苫田郡鏡野町富仲間');
ok($zip->set_number('7080704')->is_valid_number, '岡山県苫田郡鏡野町大');
ok($zip->set_number('7080705')->is_valid_number, '岡山県苫田郡鏡野町楠');
ok($zip->set_number('7080801')->is_valid_number, '岡山県津山市上横野');
ok($zip->set_number('7080802')->is_valid_number, '岡山県津山市大篠');
ok($zip->set_number('7080803')->is_valid_number, '岡山県津山市籾保');
ok($zip->set_number('7080804')->is_valid_number, '岡山県津山市勝部');
ok($zip->set_number('7080805')->is_valid_number, '岡山県津山市紫保井');
ok($zip->set_number('7080806')->is_valid_number, '岡山県津山市大田');
ok($zip->set_number('7080807')->is_valid_number, '岡山県津山市下横野');
ok($zip->set_number('7080811')->is_valid_number, '岡山県津山市西田辺');
ok($zip->set_number('7080812')->is_valid_number, '岡山県津山市東田辺');
ok($zip->set_number('7080813')->is_valid_number, '岡山県津山市山方');
ok($zip->set_number('7080814')->is_valid_number, '岡山県津山市東一宮');
ok($zip->set_number('7080815')->is_valid_number, '岡山県津山市一宮');
ok($zip->set_number('7080821')->is_valid_number, '岡山県津山市野介代');
ok($zip->set_number('7080822')->is_valid_number, '岡山県津山市林田');
ok($zip->set_number('7080823')->is_valid_number, '岡山県津山市弥生町');
ok($zip->set_number('7080824')->is_valid_number, '岡山県津山市沼');
ok($zip->set_number('7080825')->is_valid_number, '岡山県津山市志戸部');
ok($zip->set_number('7080831')->is_valid_number, '岡山県津山市上之町');
ok($zip->set_number('7080832')->is_valid_number, '岡山県津山市東新町');
ok($zip->set_number('7080833')->is_valid_number, '岡山県津山市西新町');
ok($zip->set_number('7080834')->is_valid_number, '岡山県津山市中之町');
ok($zip->set_number('7080835')->is_valid_number, '岡山県津山市勝間田町');
ok($zip->set_number('7080836')->is_valid_number, '岡山県津山市林田町');
ok($zip->set_number('7080837')->is_valid_number, '岡山県津山市橋本町');
ok($zip->set_number('7080841')->is_valid_number, '岡山県津山市川崎');
ok($zip->set_number('7080842')->is_valid_number, '岡山県津山市河辺');
ok($zip->set_number('7080843')->is_valid_number, '岡山県津山市国分寺');
ok($zip->set_number('7080844')->is_valid_number, '岡山県津山市瓜生原');
ok($zip->set_number('7080845')->is_valid_number, '岡山県津山市日上');
ok($zip->set_number('7080851')->is_valid_number, '岡山県津山市新田');
ok($zip->set_number('7080852')->is_valid_number, '岡山県津山市池ケ原');
ok($zip->set_number('7080853')->is_valid_number, '岡山県津山市堂尾');
ok($zip->set_number('7080854')->is_valid_number, '岡山県津山市中原');
ok($zip->set_number('7080855')->is_valid_number, '岡山県津山市金井');
ok($zip->set_number('7080856')->is_valid_number, '岡山県津山市西吉田');
ok($zip->set_number('7080857')->is_valid_number, '岡山県津山市福力');
ok($zip->set_number('7080861')->is_valid_number, '岡山県津山市八出');
ok($zip->set_number('7080862')->is_valid_number, '岡山県津山市横山');
ok($zip->set_number('7080863')->is_valid_number, '岡山県津山市小桁');
ok($zip->set_number('7080864')->is_valid_number, '岡山県津山市金屋');
ok($zip->set_number('7080865')->is_valid_number, '岡山県津山市押渕');
ok($zip->set_number('7080866')->is_valid_number, '岡山県津山市荒神山');
ok($zip->set_number('7080871')->is_valid_number, '岡山県津山市中島');
ok($zip->set_number('7080872')->is_valid_number, '岡山県津山市平福');
ok($zip->set_number('7080873')->is_valid_number, '岡山県津山市皿');
ok($zip->set_number('7080874')->is_valid_number, '岡山県津山市種');
ok($zip->set_number('7080875')->is_valid_number, '岡山県津山市福田');
ok($zip->set_number('7080876')->is_valid_number, '岡山県津山市高尾');
ok($zip->set_number('7080881')->is_valid_number, '岡山県津山市南町');
ok($zip->set_number('7080882')->is_valid_number, '岡山県津山市大谷');
ok($zip->set_number('7080883')->is_valid_number, '岡山県津山市一方');
ok($zip->set_number('7080884')->is_valid_number, '岡山県津山市津山口');
ok($zip->set_number('7080885')->is_valid_number, '岡山県津山市井口');
ok($zip->set_number('7080886')->is_valid_number, '岡山県津山市昭和町');
ok($zip->set_number('7081101')->is_valid_number, '岡山県津山市三浦');
ok($zip->set_number('7081102')->is_valid_number, '岡山県津山市妙原');
ok($zip->set_number('7081103')->is_valid_number, '岡山県津山市堀坂');
ok($zip->set_number('7081104')->is_valid_number, '岡山県津山市綾部');
ok($zip->set_number('7081105')->is_valid_number, '岡山県津山市吉見');
ok($zip->set_number('7081111')->is_valid_number, '岡山県津山市楢');
ok($zip->set_number('7081112')->is_valid_number, '岡山県津山市近長');
ok($zip->set_number('7081113')->is_valid_number, '岡山県津山市田熊');
ok($zip->set_number('7081114')->is_valid_number, '岡山県津山市福井');
ok($zip->set_number('7081115')->is_valid_number, '岡山県津山市河面');
ok($zip->set_number('7081116')->is_valid_number, '岡山県津山市野村');
ok($zip->set_number('7081117')->is_valid_number, '岡山県津山市草加部');
ok($zip->set_number('7081121')->is_valid_number, '岡山県津山市上高倉');
ok($zip->set_number('7081122')->is_valid_number, '岡山県津山市下高倉東');
ok($zip->set_number('7081123')->is_valid_number, '岡山県津山市下高倉西');
ok($zip->set_number('7081124')->is_valid_number, '岡山県津山市高野山西');
ok($zip->set_number('7081125')->is_valid_number, '岡山県津山市高野本郷');
ok($zip->set_number('7081126')->is_valid_number, '岡山県津山市押入');
ok($zip->set_number('7081201')->is_valid_number, '岡山県津山市奥津川');
ok($zip->set_number('7081201')->is_valid_number, '岡山県津山市加茂町下津川(奥津川)');
ok($zip->set_number('7081202')->is_valid_number, '岡山県津山市大岩');
ok($zip->set_number('7081203')->is_valid_number, '岡山県津山市大吉');
ok($zip->set_number('7081204')->is_valid_number, '岡山県津山市日本原');
ok($zip->set_number('7081205')->is_valid_number, '岡山県津山市新野東');
ok($zip->set_number('7081206')->is_valid_number, '岡山県津山市市場');
ok($zip->set_number('7081211')->is_valid_number, '岡山県津山市原');
ok($zip->set_number('7081212')->is_valid_number, '岡山県津山市安井');
ok($zip->set_number('7081213')->is_valid_number, '岡山県津山市下野田');
ok($zip->set_number('7081214')->is_valid_number, '岡山県津山市上野田');
ok($zip->set_number('7081215')->is_valid_number, '岡山県津山市杉宮');
ok($zip->set_number('7081216')->is_valid_number, '岡山県津山市中村');
ok($zip->set_number('7081221')->is_valid_number, '岡山県津山市西上');
ok($zip->set_number('7081222')->is_valid_number, '岡山県津山市西中');
ok($zip->set_number('7081223')->is_valid_number, '岡山県津山市坂上');
ok($zip->set_number('7081224')->is_valid_number, '岡山県津山市上村');
ok($zip->set_number('7081225')->is_valid_number, '岡山県津山市西下');
ok($zip->set_number('7081226')->is_valid_number, '岡山県津山市新野山形');
ok($zip->set_number('7081300')->is_valid_number, '岡山県勝田郡奈義町以下に掲載がない場合');
ok($zip->set_number('7081301')->is_valid_number, '岡山県勝田郡奈義町馬桑');
ok($zip->set_number('7081302')->is_valid_number, '岡山県勝田郡奈義町小坂');
ok($zip->set_number('7081303')->is_valid_number, '岡山県勝田郡奈義町皆木');
ok($zip->set_number('7081304')->is_valid_number, '岡山県勝田郡奈義町関本');
ok($zip->set_number('7081305')->is_valid_number, '岡山県勝田郡奈義町行方');
ok($zip->set_number('7081306')->is_valid_number, '岡山県勝田郡奈義町西原');
ok($zip->set_number('7081307')->is_valid_number, '岡山県勝田郡奈義町高円');
ok($zip->set_number('7081311')->is_valid_number, '岡山県勝田郡奈義町久常');
ok($zip->set_number('7081312')->is_valid_number, '岡山県勝田郡奈義町柿');
ok($zip->set_number('7081313')->is_valid_number, '岡山県勝田郡奈義町中島東');
ok($zip->set_number('7081314')->is_valid_number, '岡山県勝田郡奈義町荒内西');
ok($zip->set_number('7081315')->is_valid_number, '岡山県勝田郡奈義町中島西');
ok($zip->set_number('7081321')->is_valid_number, '岡山県勝田郡奈義町宮内');
ok($zip->set_number('7081322')->is_valid_number, '岡山県勝田郡奈義町成松');
ok($zip->set_number('7081323')->is_valid_number, '岡山県勝田郡奈義町豊沢');
ok($zip->set_number('7081324')->is_valid_number, '岡山県勝田郡奈義町広岡');
ok($zip->set_number('7081325')->is_valid_number, '岡山県勝田郡奈義町滝本');
ok($zip->set_number('7081326')->is_valid_number, '岡山県勝田郡奈義町上町川');
ok($zip->set_number('7081501')->is_valid_number, '岡山県久米郡美咲町安井');
ok($zip->set_number('7081502')->is_valid_number, '岡山県久米郡美咲町宮山');
ok($zip->set_number('7081503')->is_valid_number, '岡山県久米郡美咲町塩気');
ok($zip->set_number('7081504')->is_valid_number, '岡山県久米郡美咲町吉留');
ok($zip->set_number('7081505')->is_valid_number, '岡山県久米郡美咲町重藤');
ok($zip->set_number('7081506')->is_valid_number, '岡山県久米郡美咲町上間');
ok($zip->set_number('7081507')->is_valid_number, '岡山県久米郡美咲町百々');
ok($zip->set_number('7081511')->is_valid_number, '岡山県久米郡美咲町行信');
ok($zip->set_number('7081512')->is_valid_number, '岡山県久米郡美咲町松尾');
ok($zip->set_number('7081513')->is_valid_number, '岡山県久米郡美咲町藤田下');
ok($zip->set_number('7081514')->is_valid_number, '岡山県久米郡美咲町藤田上');
ok($zip->set_number('7081515')->is_valid_number, '岡山県久米郡美咲町下谷');
ok($zip->set_number('7081516')->is_valid_number, '岡山県久米郡美咲町連石');
ok($zip->set_number('7081521')->is_valid_number, '岡山県久米郡美咲町休石');
ok($zip->set_number('7081522')->is_valid_number, '岡山県久米郡美咲町惣田');
ok($zip->set_number('7081523')->is_valid_number, '岡山県久米郡美咲町吉ケ原');
ok($zip->set_number('7081524')->is_valid_number, '岡山県久米郡美咲町飯岡');
ok($zip->set_number('7081525')->is_valid_number, '岡山県久米郡美咲町王子');
ok($zip->set_number('7081526')->is_valid_number, '岡山県久米郡美咲町高下');
ok($zip->set_number('7081527')->is_valid_number, '岡山県久米郡美咲町柵原');
ok($zip->set_number('7081531')->is_valid_number, '岡山県久米郡美咲町栗子');
ok($zip->set_number('7081532')->is_valid_number, '岡山県久米郡美咲町小瀬');
ok($zip->set_number('7081533')->is_valid_number, '岡山県久米郡美咲町久木');
ok($zip->set_number('7081534')->is_valid_number, '岡山県久米郡美咲町藤原');
ok($zip->set_number('7081535')->is_valid_number, '岡山県久米郡美咲町高城');
ok($zip->set_number('7081536')->is_valid_number, '岡山県久米郡美咲町定宗');
ok($zip->set_number('7081541')->is_valid_number, '岡山県久米郡美咲町塚角');
ok($zip->set_number('7081542')->is_valid_number, '岡山県久米郡美咲町羽仁');
ok($zip->set_number('7081543')->is_valid_number, '岡山県久米郡美咲町書副');
ok($zip->set_number('7081544')->is_valid_number, '岡山県久米郡美咲町周佐');
ok($zip->set_number('7081545')->is_valid_number, '岡山県久米郡美咲町大戸上');
ok($zip->set_number('7081546')->is_valid_number, '岡山県久米郡美咲町大戸下');
ok($zip->set_number('7081547')->is_valid_number, '岡山県久米郡美咲町八神');
ok($zip->set_number('7090211')->is_valid_number, '岡山県備前市吉永町高田');
ok($zip->set_number('7090212')->is_valid_number, '岡山県備前市吉永町神根本');
ok($zip->set_number('7090213')->is_valid_number, '岡山県備前市吉永町今崎');
ok($zip->set_number('7090214')->is_valid_number, '岡山県備前市吉永町和意谷');
ok($zip->set_number('7090221')->is_valid_number, '岡山県備前市吉永町金谷');
ok($zip->set_number('7090222')->is_valid_number, '岡山県備前市吉永町福満');
ok($zip->set_number('7090223')->is_valid_number, '岡山県備前市吉永町南方');
ok($zip->set_number('7090224')->is_valid_number, '岡山県備前市吉永町吉永中');
ok($zip->set_number('7090225')->is_valid_number, '岡山県備前市吉永町三股');
ok($zip->set_number('7090226')->is_valid_number, '岡山県備前市吉永町岩崎');
ok($zip->set_number('7090301')->is_valid_number, '岡山県備前市吉永町加賀美');
ok($zip->set_number('7090302')->is_valid_number, '岡山県備前市吉永町多麻');
ok($zip->set_number('7090303')->is_valid_number, '岡山県備前市吉永町都留岐');
ok($zip->set_number('7090304')->is_valid_number, '岡山県備前市吉永町笹目');
ok($zip->set_number('7090400')->is_valid_number, '岡山県和気郡和気町以下に掲載がない場合');
ok($zip->set_number('7090401')->is_valid_number, '岡山県和気郡和気町保曽');
ok($zip->set_number('7090402')->is_valid_number, '岡山県和気郡和気町日笠上');
ok($zip->set_number('7090403')->is_valid_number, '岡山県和気郡和気町日笠下');
ok($zip->set_number('7090404')->is_valid_number, '岡山県和気郡和気町木倉');
ok($zip->set_number('7090411')->is_valid_number, '岡山県和気郡和気町吉田');
ok($zip->set_number('7090412')->is_valid_number, '岡山県和気郡和気町藤野');
ok($zip->set_number('7090413')->is_valid_number, '岡山県和気郡和気町泉');
ok($zip->set_number('7090414')->is_valid_number, '岡山県和気郡和気町大田原');
ok($zip->set_number('7090421')->is_valid_number, '岡山県和気郡和気町日室');
ok($zip->set_number('7090422')->is_valid_number, '岡山県和気郡和気町尺所');
ok($zip->set_number('7090431')->is_valid_number, '岡山県和気郡和気町清水');
ok($zip->set_number('7090432')->is_valid_number, '岡山県和気郡和気町大中山');
ok($zip->set_number('7090441')->is_valid_number, '岡山県和気郡和気町衣笠');
ok($zip->set_number('7090442')->is_valid_number, '岡山県和気郡和気町福富');
ok($zip->set_number('7090451')->is_valid_number, '岡山県和気郡和気町和気');
ok($zip->set_number('7090452')->is_valid_number, '岡山県和気郡和気町益原');
ok($zip->set_number('7090461')->is_valid_number, '岡山県和気郡和気町原');
ok($zip->set_number('7090462')->is_valid_number, '岡山県和気郡和気町本');
ok($zip->set_number('7090463')->is_valid_number, '岡山県和気郡和気町田原上');
ok($zip->set_number('7090464')->is_valid_number, '岡山県和気郡和気町田原下');
ok($zip->set_number('7090501')->is_valid_number, '岡山県和気郡和気町奥塩田');
ok($zip->set_number('7090502')->is_valid_number, '岡山県和気郡和気町丸山');
ok($zip->set_number('7090503')->is_valid_number, '岡山県和気郡和気町南山方');
ok($zip->set_number('7090504')->is_valid_number, '岡山県和気郡和気町北山方');
ok($zip->set_number('7090505')->is_valid_number, '岡山県和気郡和気町苦木');
ok($zip->set_number('7090506')->is_valid_number, '岡山県和気郡和気町塩田');
ok($zip->set_number('7090511')->is_valid_number, '岡山県和気郡和気町矢田');
ok($zip->set_number('7090512')->is_valid_number, '岡山県和気郡和気町田土');
ok($zip->set_number('7090513')->is_valid_number, '岡山県和気郡和気町岩戸');
ok($zip->set_number('7090514')->is_valid_number, '岡山県和気郡和気町佐伯');
ok($zip->set_number('7090515')->is_valid_number, '岡山県和気郡和気町米澤');
ok($zip->set_number('7090516')->is_valid_number, '岡山県和気郡和気町津瀬');
ok($zip->set_number('7090521')->is_valid_number, '岡山県和気郡和気町父井原');
ok($zip->set_number('7090522')->is_valid_number, '岡山県和気郡和気町加三方');
ok($zip->set_number('7090523')->is_valid_number, '岡山県和気郡和気町小坂');
ok($zip->set_number('7090524')->is_valid_number, '岡山県和気郡和気町田賀');
ok($zip->set_number('7090525')->is_valid_number, '岡山県和気郡和気町宇生');
ok($zip->set_number('7090526')->is_valid_number, '岡山県和気郡和気町矢田部');
ok($zip->set_number('7090601')->is_valid_number, '岡山県岡山市東区吉井');
ok($zip->set_number('7090602')->is_valid_number, '岡山県岡山市東区一日市');
ok($zip->set_number('7090603')->is_valid_number, '岡山県岡山市東区西祖');
ok($zip->set_number('7090604')->is_valid_number, '岡山県岡山市東区寺山');
ok($zip->set_number('7090605')->is_valid_number, '岡山県岡山市東区浅川');
ok($zip->set_number('7090606')->is_valid_number, '岡山県岡山市東区矢井');
ok($zip->set_number('7090607')->is_valid_number, '岡山県岡山市東区浦間');
ok($zip->set_number('7090611')->is_valid_number, '岡山県岡山市東区楢原');
ok($zip->set_number('7090612')->is_valid_number, '岡山県岡山市東区内ケ原');
ok($zip->set_number('7090613')->is_valid_number, '岡山県岡山市東区百枝月');
ok($zip->set_number('7090614')->is_valid_number, '岡山県岡山市東区竹原');
ok($zip->set_number('7090615')->is_valid_number, '岡山県岡山市東区才崎');
ok($zip->set_number('7090621')->is_valid_number, '岡山県岡山市東区沼');
ok($zip->set_number('7090622')->is_valid_number, '岡山県岡山市東区城東台東');
ok($zip->set_number('7090623')->is_valid_number, '岡山県岡山市東区城東台南');
ok($zip->set_number('7090624')->is_valid_number, '岡山県岡山市東区城東台西');
ok($zip->set_number('7090625')->is_valid_number, '岡山県岡山市東区上道北方');
ok($zip->set_number('7090626')->is_valid_number, '岡山県岡山市東区中尾');
ok($zip->set_number('7090631')->is_valid_number, '岡山県岡山市東区東平島');
ok($zip->set_number('7090632')->is_valid_number, '岡山県岡山市東区南古都');
ok($zip->set_number('7090633')->is_valid_number, '岡山県岡山市東区西平島');
ok($zip->set_number('7090634')->is_valid_number, '岡山県岡山市東区砂場');
ok($zip->set_number('7090635')->is_valid_number, '岡山県岡山市東区草ケ部');
ok($zip->set_number('7090636')->is_valid_number, '岡山県岡山市東区谷尻');
ok($zip->set_number('7090701')->is_valid_number, '岡山県赤磐市酌田');
ok($zip->set_number('7090702')->is_valid_number, '岡山県赤磐市岡');
ok($zip->set_number('7090703')->is_valid_number, '岡山県赤磐市殿谷');
ok($zip->set_number('7090704')->is_valid_number, '岡山県赤磐市沢原');
ok($zip->set_number('7090705')->is_valid_number, '岡山県赤磐市松木');
ok($zip->set_number('7090706')->is_valid_number, '岡山県赤磐市佐古');
ok($zip->set_number('7090711')->is_valid_number, '岡山県赤磐市円光寺');
ok($zip->set_number('7090712')->is_valid_number, '岡山県赤磐市吉原');
ok($zip->set_number('7090713')->is_valid_number, '岡山県赤磐市奥吉原');
ok($zip->set_number('7090714')->is_valid_number, '岡山県赤磐市千躰');
ok($zip->set_number('7090715')->is_valid_number, '岡山県赤磐市勢力');
ok($zip->set_number('7090716')->is_valid_number, '岡山県赤磐市徳富');
ok($zip->set_number('7090717')->is_valid_number, '岡山県赤磐市小瀬木');
ok($zip->set_number('7090718')->is_valid_number, '岡山県赤磐市釣井');
ok($zip->set_number('7090719')->is_valid_number, '岡山県赤磐市河田原');
ok($zip->set_number('7090721')->is_valid_number, '岡山県赤磐市桜が丘東');
ok($zip->set_number('7090731')->is_valid_number, '岡山県赤磐市石蓮寺');
ok($zip->set_number('7090732')->is_valid_number, '岡山県赤磐市可真下');
ok($zip->set_number('7090733')->is_valid_number, '岡山県赤磐市可真上');
ok($zip->set_number('7090734')->is_valid_number, '岡山県赤磐市弥上');
ok($zip->set_number('7090735')->is_valid_number, '岡山県赤磐市野間');
ok($zip->set_number('7090736')->is_valid_number, '岡山県赤磐市稗田');
ok($zip->set_number('7090800')->is_valid_number, '岡山県赤磐市以下に掲載がない場合');
ok($zip->set_number('7090801')->is_valid_number, '岡山県赤磐市神田');
ok($zip->set_number('7090802')->is_valid_number, '岡山県赤磐市桜が丘西');
ok($zip->set_number('7090803')->is_valid_number, '岡山県赤磐市中島');
ok($zip->set_number('7090804')->is_valid_number, '岡山県赤磐市日古木');
ok($zip->set_number('7090805')->is_valid_number, '岡山県赤磐市二井');
ok($zip->set_number('7090806')->is_valid_number, '岡山県赤磐市尾谷');
ok($zip->set_number('7090807')->is_valid_number, '岡山県赤磐市津崎');
ok($zip->set_number('7090811')->is_valid_number, '岡山県赤磐市高屋');
ok($zip->set_number('7090812')->is_valid_number, '岡山県赤磐市沼田');
ok($zip->set_number('7090813')->is_valid_number, '岡山県赤磐市斎富');
ok($zip->set_number('7090814')->is_valid_number, '岡山県赤磐市南方');
ok($zip->set_number('7090815')->is_valid_number, '岡山県赤磐市立川');
ok($zip->set_number('7090816')->is_valid_number, '岡山県赤磐市下市');
ok($zip->set_number('7090817')->is_valid_number, '岡山県赤磐市上市');
ok($zip->set_number('7090821')->is_valid_number, '岡山県赤磐市河本');
ok($zip->set_number('7090822')->is_valid_number, '岡山県赤磐市岩田');
ok($zip->set_number('7090823')->is_valid_number, '岡山県赤磐市長尾');
ok($zip->set_number('7090824')->is_valid_number, '岡山県赤磐市穂崎');
ok($zip->set_number('7090825')->is_valid_number, '岡山県赤磐市馬屋');
ok($zip->set_number('7090826')->is_valid_number, '岡山県赤磐市和田');
ok($zip->set_number('7090827')->is_valid_number, '岡山県赤磐市山陽');
ok($zip->set_number('7090831')->is_valid_number, '岡山県赤磐市五日市');
ok($zip->set_number('7090832')->is_valid_number, '岡山県赤磐市正崎');
ok($zip->set_number('7090833')->is_valid_number, '岡山県赤磐市熊崎');
ok($zip->set_number('7090834')->is_valid_number, '岡山県赤磐市鴨前');
ok($zip->set_number('7090835')->is_valid_number, '岡山県赤磐市西中');
ok($zip->set_number('7090836')->is_valid_number, '岡山県赤磐市下仁保');
ok($zip->set_number('7090837')->is_valid_number, '岡山県赤磐市上仁保');
ok($zip->set_number('7090838')->is_valid_number, '岡山県赤磐市斗有');
ok($zip->set_number('7090841')->is_valid_number, '岡山県岡山市東区瀬戸町万富');
ok($zip->set_number('7090842')->is_valid_number, '岡山県岡山市東区瀬戸町二日市');
ok($zip->set_number('7090843')->is_valid_number, '岡山県岡山市東区瀬戸町弓削');
ok($zip->set_number('7090844')->is_valid_number, '岡山県岡山市東区瀬戸町南方');
ok($zip->set_number('7090845')->is_valid_number, '岡山県岡山市東区瀬戸町鍛冶屋');
ok($zip->set_number('7090846')->is_valid_number, '岡山県岡山市東区瀬戸町大井');
ok($zip->set_number('7090851')->is_valid_number, '岡山県岡山市東区瀬戸町大内');
ok($zip->set_number('7090852')->is_valid_number, '岡山県岡山市東区瀬戸町肩脊');
ok($zip->set_number('7090853')->is_valid_number, '岡山県岡山市東区瀬戸町旭ヶ丘');
ok($zip->set_number('7090854')->is_valid_number, '岡山県岡山市東区瀬戸町江尻');
ok($zip->set_number('7090855')->is_valid_number, '岡山県岡山市東区瀬戸町沖');
ok($zip->set_number('7090856')->is_valid_number, '岡山県岡山市東区瀬戸町下');
ok($zip->set_number('7090861')->is_valid_number, '岡山県岡山市東区瀬戸町瀬戸');
ok($zip->set_number('7090862')->is_valid_number, '岡山県岡山市東区瀬戸町笹岡');
ok($zip->set_number('7090863')->is_valid_number, '岡山県岡山市東区瀬戸町観音寺');
ok($zip->set_number('7090864')->is_valid_number, '岡山県岡山市東区瀬戸町宿奥');
ok($zip->set_number('7090865')->is_valid_number, '岡山県岡山市東区瀬戸町菊山');
ok($zip->set_number('7090871')->is_valid_number, '岡山県岡山市東区瀬戸町塩納');
ok($zip->set_number('7090872')->is_valid_number, '岡山県岡山市東区瀬戸町宗堂');
ok($zip->set_number('7090873')->is_valid_number, '岡山県岡山市東区瀬戸町坂根');
ok($zip->set_number('7090874')->is_valid_number, '岡山県岡山市東区瀬戸町森末');
ok($zip->set_number('7090875')->is_valid_number, '岡山県岡山市東区瀬戸町寺地');
ok($zip->set_number('7090876')->is_valid_number, '岡山県岡山市東区瀬戸町光明谷');
ok($zip->set_number('7091201')->is_valid_number, '岡山県岡山市南区北七区');
ok($zip->set_number('7091202')->is_valid_number, '岡山県岡山市南区西七区');
ok($zip->set_number('7091203')->is_valid_number, '岡山県岡山市南区西紅陽台');
ok($zip->set_number('7091204')->is_valid_number, '岡山県岡山市南区西高崎');
ok($zip->set_number('7091211')->is_valid_number, '岡山県岡山市南区迫川');
ok($zip->set_number('7091212')->is_valid_number, '岡山県岡山市南区奥迫川');
ok($zip->set_number('7091213')->is_valid_number, '岡山県岡山市南区彦崎');
ok($zip->set_number('7091214')->is_valid_number, '岡山県岡山市南区川張');
ok($zip->set_number('7091215')->is_valid_number, '岡山県岡山市南区片岡');
ok($zip->set_number('7091216')->is_valid_number, '岡山県岡山市南区宗津');
ok($zip->set_number('7092101')->is_valid_number, '岡山県岡山市北区御津石上');
ok($zip->set_number('7092102')->is_valid_number, '岡山県岡山市北区御津中畑');
ok($zip->set_number('7092103')->is_valid_number, '岡山県岡山市北区御津矢知');
ok($zip->set_number('7092104')->is_valid_number, '岡山県岡山市北区御津平岡西');
ok($zip->set_number('7092105')->is_valid_number, '岡山県岡山市北区御津伊田');
ok($zip->set_number('7092106')->is_valid_number, '岡山県岡山市北区御津新庄');
ok($zip->set_number('7092107')->is_valid_number, '岡山県岡山市北区御津矢原');
ok($zip->set_number('7092111')->is_valid_number, '岡山県岡山市北区御津川高');
ok($zip->set_number('7092112')->is_valid_number, '岡山県岡山市北区御津国ケ原');
ok($zip->set_number('7092113')->is_valid_number, '岡山県岡山市北区御津芳谷');
ok($zip->set_number('7092114')->is_valid_number, '岡山県岡山市北区御津中牧');
ok($zip->set_number('7092115')->is_valid_number, '岡山県岡山市北区御津北野');
ok($zip->set_number('7092116')->is_valid_number, '岡山県岡山市北区御津中山');
ok($zip->set_number('7092117')->is_valid_number, '岡山県岡山市北区御津野々口');
ok($zip->set_number('7092121')->is_valid_number, '岡山県岡山市北区御津宇垣');
ok($zip->set_number('7092122')->is_valid_number, '岡山県岡山市北区御津吉尾');
ok($zip->set_number('7092123')->is_valid_number, '岡山県岡山市北区御津河内');
ok($zip->set_number('7092124')->is_valid_number, '岡山県岡山市北区御津高津');
ok($zip->set_number('7092125')->is_valid_number, '岡山県岡山市北区御津宇甘');
ok($zip->set_number('7092126')->is_valid_number, '岡山県岡山市北区御津勝尾');
ok($zip->set_number('7092131')->is_valid_number, '岡山県岡山市北区御津鹿瀬');
ok($zip->set_number('7092132')->is_valid_number, '岡山県岡山市北区御津草生');
ok($zip->set_number('7092133')->is_valid_number, '岡山県岡山市北区御津金川');
ok($zip->set_number('7092134')->is_valid_number, '岡山県岡山市北区御津下田');
ok($zip->set_number('7092135')->is_valid_number, '岡山県岡山市北区御津中泉');
ok($zip->set_number('7092136')->is_valid_number, '岡山県岡山市北区御津紙工');
ok($zip->set_number('7092137')->is_valid_number, '岡山県岡山市北区御津虎倉');
ok($zip->set_number('7092331')->is_valid_number, '岡山県加賀郡吉備中央町下加茂');
ok($zip->set_number('7092332')->is_valid_number, '岡山県加賀郡吉備中央町高谷');
ok($zip->set_number('7092333')->is_valid_number, '岡山県加賀郡吉備中央町加茂市場');
ok($zip->set_number('7092334')->is_valid_number, '岡山県加賀郡吉備中央町美原');
ok($zip->set_number('7092341')->is_valid_number, '岡山県加賀郡吉備中央町上加茂');
ok($zip->set_number('7092342')->is_valid_number, '岡山県加賀郡吉備中央町広面');
ok($zip->set_number('7092343')->is_valid_number, '岡山県加賀郡吉備中央町竹部');
ok($zip->set_number('7092344')->is_valid_number, '岡山県加賀郡吉備中央町上野');
ok($zip->set_number('7092345')->is_valid_number, '岡山県加賀郡吉備中央町平岡');
ok($zip->set_number('7092401')->is_valid_number, '岡山県加賀郡吉備中央町神瀬');
ok($zip->set_number('7092402')->is_valid_number, '岡山県加賀郡吉備中央町高富');
ok($zip->set_number('7092403')->is_valid_number, '岡山県加賀郡吉備中央町案田');
ok($zip->set_number('7092404')->is_valid_number, '岡山県加賀郡吉備中央町小森');
ok($zip->set_number('7092411')->is_valid_number, '岡山県加賀郡吉備中央町上田東');
ok($zip->set_number('7092412')->is_valid_number, '岡山県加賀郡吉備中央町円城');
ok($zip->set_number('7092413')->is_valid_number, '岡山県加賀郡吉備中央町上田西');
ok($zip->set_number('7092421')->is_valid_number, '岡山県加賀郡吉備中央町細田');
ok($zip->set_number('7092422')->is_valid_number, '岡山県加賀郡吉備中央町三納谷');
ok($zip->set_number('7092551')->is_valid_number, '岡山県加賀郡吉備中央町下土井');
ok($zip->set_number('7092552')->is_valid_number, '岡山県加賀郡吉備中央町井原');
ok($zip->set_number('7092553')->is_valid_number, '岡山県加賀郡吉備中央町富永');
ok($zip->set_number('7092554')->is_valid_number, '岡山県加賀郡吉備中央町和田');
ok($zip->set_number('7092661')->is_valid_number, '岡山県加賀郡吉備中央町豊岡下');
ok($zip->set_number('7092662')->is_valid_number, '岡山県加賀郡吉備中央町三谷');
ok($zip->set_number('7092663')->is_valid_number, '岡山県加賀郡吉備中央町大木');
ok($zip->set_number('7092664')->is_valid_number, '岡山県加賀郡吉備中央町豊岡上');
ok($zip->set_number('7092671')->is_valid_number, '岡山県加賀郡吉備中央町杉谷');
ok($zip->set_number('7092672')->is_valid_number, '岡山県加賀郡吉備中央町粟井谷');
ok($zip->set_number('7092673')->is_valid_number, '岡山県加賀郡吉備中央町尾原');
ok($zip->set_number('7092674')->is_valid_number, '岡山県加賀郡吉備中央町笹目');
ok($zip->set_number('7092675')->is_valid_number, '岡山県加賀郡吉備中央町福沢');
ok($zip->set_number('7092676')->is_valid_number, '岡山県加賀郡吉備中央町溝部');
ok($zip->set_number('7093101')->is_valid_number, '岡山県岡山市北区建部町鶴田');
ok($zip->set_number('7093102')->is_valid_number, '岡山県岡山市北区建部町和田南');
ok($zip->set_number('7093103')->is_valid_number, '岡山県岡山市北区建部町角石畝');
ok($zip->set_number('7093104')->is_valid_number, '岡山県岡山市北区建部町角石谷');
ok($zip->set_number('7093105')->is_valid_number, '岡山県岡山市北区建部町三明寺');
ok($zip->set_number('7093111')->is_valid_number, '岡山県岡山市北区建部町福渡');
ok($zip->set_number('7093112')->is_valid_number, '岡山県岡山市北区建部町川口');
ok($zip->set_number('7093113')->is_valid_number, '岡山県岡山市北区建部町下神目');
ok($zip->set_number('7093114')->is_valid_number, '岡山県岡山市北区建部町豊楽寺');
ok($zip->set_number('7093121')->is_valid_number, '岡山県岡山市北区建部町大田');
ok($zip->set_number('7093122')->is_valid_number, '岡山県岡山市北区建部町吉田');
ok($zip->set_number('7093123')->is_valid_number, '岡山県岡山市北区建部町土師方');
ok($zip->set_number('7093124')->is_valid_number, '岡山県岡山市北区建部町小倉');
ok($zip->set_number('7093131')->is_valid_number, '岡山県岡山市北区建部町市場');
ok($zip->set_number('7093132')->is_valid_number, '岡山県岡山市北区建部町中田');
ok($zip->set_number('7093133')->is_valid_number, '岡山県岡山市北区建部町西原');
ok($zip->set_number('7093134')->is_valid_number, '岡山県岡山市北区建部町桜');
ok($zip->set_number('7093141')->is_valid_number, '岡山県岡山市北区建部町品田');
ok($zip->set_number('7093142')->is_valid_number, '岡山県岡山市北区建部町建部上');
ok($zip->set_number('7093143')->is_valid_number, '岡山県岡山市北区建部町宮地');
ok($zip->set_number('7093144')->is_valid_number, '岡山県岡山市北区建部町富沢');
ok($zip->set_number('7093145')->is_valid_number, '岡山県岡山市北区建部町田地子');
ok($zip->set_number('7093401')->is_valid_number, '岡山県久米郡美咲町北');
ok($zip->set_number('7093402')->is_valid_number, '岡山県久米郡美咲町南');
ok($zip->set_number('7093403')->is_valid_number, '岡山県久米郡美咲町里');
ok($zip->set_number('7093404')->is_valid_number, '岡山県久米郡美咲町西川');
ok($zip->set_number('7093405')->is_valid_number, '岡山県久米郡美咲町西');
ok($zip->set_number('7093406')->is_valid_number, '岡山県久米郡美咲町西川上');
ok($zip->set_number('7093407')->is_valid_number, '岡山県久米郡美咲町中');
ok($zip->set_number('7093411')->is_valid_number, '岡山県久米郡美咲町上口');
ok($zip->set_number('7093412')->is_valid_number, '岡山県久米郡美咲町小山');
ok($zip->set_number('7093413')->is_valid_number, '岡山県久米郡美咲町栃原');
ok($zip->set_number('7093414')->is_valid_number, '岡山県久米郡美咲町西垪和');
ok($zip->set_number('7093415')->is_valid_number, '岡山県久米郡美咲町江与味');
ok($zip->set_number('7093416')->is_valid_number, '岡山県久米郡美咲町東垪和');
ok($zip->set_number('7093417')->is_valid_number, '岡山県久米郡美咲町中垪和');
ok($zip->set_number('7093600')->is_valid_number, '岡山県久米郡久米南町以下に掲載がない場合');
ok($zip->set_number('7093601')->is_valid_number, '岡山県久米郡久米南町北庄');
ok($zip->set_number('7093602')->is_valid_number, '岡山県久米郡久米南町里方');
ok($zip->set_number('7093603')->is_valid_number, '岡山県久米郡久米南町山ノ城');
ok($zip->set_number('7093604')->is_valid_number, '岡山県久米郡久米南町南庄');
ok($zip->set_number('7093605')->is_valid_number, '岡山県久米郡久米南町塩之内');
ok($zip->set_number('7093606')->is_valid_number, '岡山県久米郡久米南町羽出木');
ok($zip->set_number('7093611')->is_valid_number, '岡山県久米郡久米南町松');
ok($zip->set_number('7093612')->is_valid_number, '岡山県久米郡久米南町上弓削');
ok($zip->set_number('7093613')->is_valid_number, '岡山県久米郡久米南町西山寺');
ok($zip->set_number('7093614')->is_valid_number, '岡山県久米郡久米南町下弓削');
ok($zip->set_number('7093615')->is_valid_number, '岡山県久米郡久米南町上二ケ');
ok($zip->set_number('7093616')->is_valid_number, '岡山県久米郡久米南町全間');
ok($zip->set_number('7093617')->is_valid_number, '岡山県久米郡久米南町下二ケ');
ok($zip->set_number('7093621')->is_valid_number, '岡山県久米郡久米南町上籾');
ok($zip->set_number('7093622')->is_valid_number, '岡山県久米郡久米南町仏教寺');
ok($zip->set_number('7093623')->is_valid_number, '岡山県久米郡久米南町中籾');
ok($zip->set_number('7093624')->is_valid_number, '岡山県久米郡久米南町下籾');
ok($zip->set_number('7093625')->is_valid_number, '岡山県久米郡久米南町別所');
ok($zip->set_number('7093626')->is_valid_number, '岡山県久米郡久米南町上神目');
ok($zip->set_number('7093627')->is_valid_number, '岡山県久米郡久米南町神目中');
ok($zip->set_number('7093631')->is_valid_number, '岡山県久米郡久米南町宮地');
ok($zip->set_number('7093632')->is_valid_number, '岡山県久米郡久米南町山手');
ok($zip->set_number('7093633')->is_valid_number, '岡山県久米郡久米南町峠');
ok($zip->set_number('7093634')->is_valid_number, '岡山県久米郡久米南町京尾');
ok($zip->set_number('7093635')->is_valid_number, '岡山県久米郡久米南町南畑');
ok($zip->set_number('7093636')->is_valid_number, '岡山県久米郡久米南町安ケ乢');
ok($zip->set_number('7093700')->is_valid_number, '岡山県久米郡美咲町以下に掲載がない場合');
ok($zip->set_number('7093701')->is_valid_number, '岡山県久米郡美咲町錦織');
ok($zip->set_number('7093702')->is_valid_number, '岡山県久米郡美咲町打穴下');
ok($zip->set_number('7093703')->is_valid_number, '岡山県久米郡美咲町打穴中');
ok($zip->set_number('7093704')->is_valid_number, '岡山県久米郡美咲町打穴里');
ok($zip->set_number('7093705')->is_valid_number, '岡山県久米郡美咲町打穴上');
ok($zip->set_number('7093706')->is_valid_number, '岡山県久米郡美咲町打穴北');
ok($zip->set_number('7093707')->is_valid_number, '岡山県久米郡美咲町打穴西');
ok($zip->set_number('7093711')->is_valid_number, '岡山県久米郡美咲町越尾');
ok($zip->set_number('7093712')->is_valid_number, '岡山県久米郡美咲町金堀');
ok($zip->set_number('7093713')->is_valid_number, '岡山県久米郡美咲町新城');
ok($zip->set_number('7093714')->is_valid_number, '岡山県久米郡美咲町小原');
ok($zip->set_number('7093715')->is_valid_number, '岡山県久米郡美咲町西幸');
ok($zip->set_number('7093716')->is_valid_number, '岡山県久米郡美咲町頼元');
ok($zip->set_number('7093717')->is_valid_number, '岡山県久米郡美咲町原田');
ok($zip->set_number('7093721')->is_valid_number, '岡山県久米郡美咲町両山寺');
ok($zip->set_number('7093722')->is_valid_number, '岡山県久米郡美咲町大垪和東');
ok($zip->set_number('7093723')->is_valid_number, '岡山県久米郡美咲町境');
ok($zip->set_number('7093724')->is_valid_number, '岡山県久米郡美咲町角石祖母');
ok($zip->set_number('7093725')->is_valid_number, '岡山県久米郡美咲町和田北');
ok($zip->set_number('7093726')->is_valid_number, '岡山県久米郡美咲町大垪和西');
ok($zip->set_number('7093901')->is_valid_number, '岡山県津山市加茂町倉見');
ok($zip->set_number('7093902')->is_valid_number, '岡山県津山市加茂町黒木');
ok($zip->set_number('7093903')->is_valid_number, '岡山県津山市加茂町戸賀');
ok($zip->set_number('7093904')->is_valid_number, '岡山県津山市加茂町斉野谷');
ok($zip->set_number('7093905')->is_valid_number, '岡山県津山市加茂町塔中');
ok($zip->set_number('7093906')->is_valid_number, '岡山県津山市加茂町小中原');
ok($zip->set_number('7093907')->is_valid_number, '岡山県津山市加茂町宇野');
ok($zip->set_number('7093908')->is_valid_number, '岡山県津山市加茂町原口');
ok($zip->set_number('7093911')->is_valid_number, '岡山県津山市加茂町物見');
ok($zip->set_number('7093912')->is_valid_number, '岡山県津山市加茂町河井');
ok($zip->set_number('7093913')->is_valid_number, '岡山県津山市加茂町山下');
ok($zip->set_number('7093914')->is_valid_number, '岡山県津山市加茂町知和');
ok($zip->set_number('7093915')->is_valid_number, '岡山県津山市加茂町青柳');
ok($zip->set_number('7093921')->is_valid_number, '岡山県津山市加茂町公郷');
ok($zip->set_number('7093922')->is_valid_number, '岡山県津山市加茂町下津川');
ok($zip->set_number('7093923')->is_valid_number, '岡山県津山市加茂町桑原');
ok($zip->set_number('7093924')->is_valid_number, '岡山県津山市加茂町小渕');
ok($zip->set_number('7093931')->is_valid_number, '岡山県津山市加茂町中原');
ok($zip->set_number('7093932')->is_valid_number, '岡山県津山市加茂町成安');
ok($zip->set_number('7093933')->is_valid_number, '岡山県津山市加茂町行重');
ok($zip->set_number('7093934')->is_valid_number, '岡山県津山市加茂町楢井');
ok($zip->set_number('7093935')->is_valid_number, '岡山県津山市加茂町百々');
ok($zip->set_number('7093951')->is_valid_number, '岡山県津山市阿波');
ok($zip->set_number('7094201')->is_valid_number, '岡山県美作市小房');
ok($zip->set_number('7094202')->is_valid_number, '岡山県美作市梶原');
ok($zip->set_number('7094203')->is_valid_number, '岡山県美作市小野');
ok($zip->set_number('7094204')->is_valid_number, '岡山県美作市鷺巣');
ok($zip->set_number('7094205')->is_valid_number, '岡山県美作市粟井中');
ok($zip->set_number('7094211')->is_valid_number, '岡山県美作市五名');
ok($zip->set_number('7094212')->is_valid_number, '岡山県美作市宮原');
ok($zip->set_number('7094213')->is_valid_number, '岡山県美作市大聖寺');
ok($zip->set_number('7094214')->is_valid_number, '岡山県美作市豆田');
ok($zip->set_number('7094215')->is_valid_number, '岡山県美作市小ノ谷');
ok($zip->set_number('7094216')->is_valid_number, '岡山県美作市山手');
ok($zip->set_number('7094221')->is_valid_number, '岡山県美作市瀬戸');
ok($zip->set_number('7094222')->is_valid_number, '岡山県美作市岩辺');
ok($zip->set_number('7094223')->is_valid_number, '岡山県美作市大内谷');
ok($zip->set_number('7094224')->is_valid_number, '岡山県美作市豊野');
ok($zip->set_number('7094225')->is_valid_number, '岡山県美作市松脇');
ok($zip->set_number('7094226')->is_valid_number, '岡山県美作市鯰');
ok($zip->set_number('7094227')->is_valid_number, '岡山県美作市江見吉田');
ok($zip->set_number('7094231')->is_valid_number, '岡山県美作市南海');
ok($zip->set_number('7094232')->is_valid_number, '岡山県美作市芦河内');
ok($zip->set_number('7094233')->is_valid_number, '岡山県美作市藤生');
ok($zip->set_number('7094234')->is_valid_number, '岡山県美作市江見');
ok($zip->set_number('7094235')->is_valid_number, '岡山県美作市原');
ok($zip->set_number('7094236')->is_valid_number, '岡山県美作市川北');
ok($zip->set_number('7094241')->is_valid_number, '岡山県美作市日指');
ok($zip->set_number('7094242')->is_valid_number, '岡山県美作市田原');
ok($zip->set_number('7094243')->is_valid_number, '岡山県美作市蓮花寺');
ok($zip->set_number('7094244')->is_valid_number, '岡山県美作市土居');
ok($zip->set_number('7094245')->is_valid_number, '岡山県美作市竹田');
ok($zip->set_number('7094246')->is_valid_number, '岡山県美作市上福原');
ok($zip->set_number('7094247')->is_valid_number, '岡山県美作市山城');
ok($zip->set_number('7094251')->is_valid_number, '岡山県美作市白水');
ok($zip->set_number('7094252')->is_valid_number, '岡山県美作市角南');
ok($zip->set_number('7094253')->is_valid_number, '岡山県美作市柿ケ原');
ok($zip->set_number('7094254')->is_valid_number, '岡山県美作市万善');
ok($zip->set_number('7094255')->is_valid_number, '岡山県美作市国貞');
ok($zip->set_number('7094256')->is_valid_number, '岡山県美作市鈴家');
ok($zip->set_number('7094257')->is_valid_number, '岡山県美作市田渕');
ok($zip->set_number('7094300')->is_valid_number, '岡山県勝田郡勝央町以下に掲載がない場合');
ok($zip->set_number('7094301')->is_valid_number, '岡山県勝田郡勝央町下町川');
ok($zip->set_number('7094302')->is_valid_number, '岡山県勝田郡勝央町河原');
ok($zip->set_number('7094303')->is_valid_number, '岡山県勝田郡勝央町豊久田');
ok($zip->set_number('7094304')->is_valid_number, '岡山県勝田郡勝央町上香山');
ok($zip->set_number('7094305')->is_valid_number, '岡山県勝田郡勝央町曽井');
ok($zip->set_number('7094306')->is_valid_number, '岡山県勝田郡勝央町美野');
ok($zip->set_number('7094307')->is_valid_number, '岡山県勝田郡勝央町石生');
ok($zip->set_number('7094311')->is_valid_number, '岡山県勝田郡勝央町岡');
ok($zip->set_number('7094312')->is_valid_number, '岡山県勝田郡勝央町黒土');
ok($zip->set_number('7094313')->is_valid_number, '岡山県勝田郡勝央町小矢田');
ok($zip->set_number('7094314')->is_valid_number, '岡山県勝田郡勝央町東吉田');
ok($zip->set_number('7094315')->is_valid_number, '岡山県勝田郡勝央町畑屋');
ok($zip->set_number('7094316')->is_valid_number, '岡山県勝田郡勝央町勝間田');
ok($zip->set_number('7094321')->is_valid_number, '岡山県勝田郡勝央町太平台');
ok($zip->set_number('7094322')->is_valid_number, '岡山県勝田郡勝央町福吉');
ok($zip->set_number('7094323')->is_valid_number, '岡山県勝田郡勝央町黒坂');
ok($zip->set_number('7094324')->is_valid_number, '岡山県勝田郡勝央町為本');
ok($zip->set_number('7094331')->is_valid_number, '岡山県勝田郡勝央町植月北');
ok($zip->set_number('7094332')->is_valid_number, '岡山県勝田郡勝央町植月東');
ok($zip->set_number('7094333')->is_valid_number, '岡山県勝田郡勝央町田井');
ok($zip->set_number('7094334')->is_valid_number, '岡山県勝田郡勝央町平');
ok($zip->set_number('7094335')->is_valid_number, '岡山県勝田郡勝央町植月中');
ok($zip->set_number('7094601')->is_valid_number, '岡山県津山市宮部上');
ok($zip->set_number('7094602')->is_valid_number, '岡山県津山市宮部下');
ok($zip->set_number('7094603')->is_valid_number, '岡山県津山市中北下');
ok($zip->set_number('7094604')->is_valid_number, '岡山県津山市坪井下');
ok($zip->set_number('7094605')->is_valid_number, '岡山県津山市坪井上');
ok($zip->set_number('7094606')->is_valid_number, '岡山県津山市中北上');
ok($zip->set_number('7094611')->is_valid_number, '岡山県津山市領家');
ok($zip->set_number('7094612')->is_valid_number, '岡山県津山市くめ');
ok($zip->set_number('7094613')->is_valid_number, '岡山県津山市宮尾');
ok($zip->set_number('7094614')->is_valid_number, '岡山県津山市久米川南');
ok($zip->set_number('7094615')->is_valid_number, '岡山県津山市一色');
ok($zip->set_number('7094616')->is_valid_number, '岡山県津山市南方中');
ok($zip->set_number('7094621')->is_valid_number, '岡山県津山市神代');
ok($zip->set_number('7094622')->is_valid_number, '岡山県津山市戸脇');
ok($zip->set_number('7094623')->is_valid_number, '岡山県津山市桑下');
ok($zip->set_number('7094624')->is_valid_number, '岡山県津山市桑上');
ok($zip->set_number('7094625')->is_valid_number, '岡山県津山市里公文');
ok($zip->set_number('7094626')->is_valid_number, '岡山県津山市里公文上');
ok($zip->set_number('7094631')->is_valid_number, '岡山県津山市福田下');
ok($zip->set_number('7094632')->is_valid_number, '岡山県津山市八社');
ok($zip->set_number('7094633')->is_valid_number, '岡山県津山市油木上');
ok($zip->set_number('7094634')->is_valid_number, '岡山県津山市油木下');
ok($zip->set_number('7094635')->is_valid_number, '岡山県津山市油木北');
ok($zip->set_number('7100000')->is_valid_number, '岡山県倉敷市以下に掲載がない場合');
ok($zip->set_number('7100001')->is_valid_number, '岡山県倉敷市三田');
ok($zip->set_number('7100002')->is_valid_number, '岡山県倉敷市生坂');
ok($zip->set_number('7100003')->is_valid_number, '岡山県倉敷市平田');
ok($zip->set_number('7100004')->is_valid_number, '岡山県倉敷市西坂');
ok($zip->set_number('7100005')->is_valid_number, '岡山県倉敷市西岡');
ok($zip->set_number('7100006')->is_valid_number, '岡山県倉敷市祐安');
ok($zip->set_number('7100007')->is_valid_number, '岡山県倉敷市浅原');
ok($zip->set_number('7100011')->is_valid_number, '岡山県倉敷市徳芳');
ok($zip->set_number('7100012')->is_valid_number, '岡山県倉敷市鳥羽');
ok($zip->set_number('7100013')->is_valid_number, '岡山県倉敷市中帯江');
ok($zip->set_number('7100014')->is_valid_number, '岡山県倉敷市黒崎');
ok($zip->set_number('7100015')->is_valid_number, '岡山県倉敷市中庄団地');
ok($zip->set_number('7100016')->is_valid_number, '岡山県倉敷市中庄');
ok($zip->set_number('7100021')->is_valid_number, '岡山県倉敷市高須賀');
ok($zip->set_number('7100022')->is_valid_number, '岡山県倉敷市早高');
ok($zip->set_number('7100023')->is_valid_number, '岡山県倉敷市帯高');
ok($zip->set_number('7100024')->is_valid_number, '岡山県倉敷市亀山');
ok($zip->set_number('7100025')->is_valid_number, '岡山県倉敷市倉敷ハイツ');
ok($zip->set_number('7100026')->is_valid_number, '岡山県倉敷市加須山');
ok($zip->set_number('7100027')->is_valid_number, '岡山県倉敷市西田');
ok($zip->set_number('7100031')->is_valid_number, '岡山県倉敷市有城');
ok($zip->set_number('7100032')->is_valid_number, '岡山県倉敷市東粒浦');
ok($zip->set_number('7100033')->is_valid_number, '岡山県倉敷市粒江団地');
ok($zip->set_number('7100034')->is_valid_number, '岡山県倉敷市粒江');
ok($zip->set_number('7100035')->is_valid_number, '岡山県倉敷市黒石');
ok($zip->set_number('7100036')->is_valid_number, '岡山県倉敷市粒浦');
ok($zip->set_number('7100037')->is_valid_number, '岡山県倉敷市八軒屋');
ok($zip->set_number('7100038')->is_valid_number, '岡山県倉敷市新田');
ok($zip->set_number('7100041')->is_valid_number, '岡山県倉敷市五日市');
ok($zip->set_number('7100042')->is_valid_number, '岡山県倉敷市二日市');
ok($zip->set_number('7100043')->is_valid_number, '岡山県倉敷市羽島');
ok($zip->set_number('7100044')->is_valid_number, '岡山県倉敷市向山');
ok($zip->set_number('7100045')->is_valid_number, '岡山県倉敷市船倉町');
ok($zip->set_number('7100046')->is_valid_number, '岡山県倉敷市中央');
ok($zip->set_number('7100047')->is_valid_number, '岡山県倉敷市大島');
ok($zip->set_number('7100048')->is_valid_number, '岡山県倉敷市福島');
ok($zip->set_number('7100051')->is_valid_number, '岡山県倉敷市幸町');
ok($zip->set_number('7100052')->is_valid_number, '岡山県倉敷市美和');
ok($zip->set_number('7100053')->is_valid_number, '岡山県倉敷市東町');
ok($zip->set_number('7100054')->is_valid_number, '岡山県倉敷市本町');
ok($zip->set_number('7100055')->is_valid_number, '岡山県倉敷市阿知');
ok($zip->set_number('7100056')->is_valid_number, '岡山県倉敷市鶴形');
ok($zip->set_number('7100057')->is_valid_number, '岡山県倉敷市昭和');
ok($zip->set_number('7100061')->is_valid_number, '岡山県倉敷市浜ノ茶屋');
ok($zip->set_number('7100062')->is_valid_number, '岡山県倉敷市浜町');
ok($zip->set_number('7100063')->is_valid_number, '岡山県倉敷市日ノ出町');
ok($zip->set_number('7100064')->is_valid_number, '岡山県倉敷市青江');
ok($zip->set_number('7100065')->is_valid_number, '岡山県倉敷市宮前');
ok($zip->set_number('7100131')->is_valid_number, '岡山県倉敷市天城台');
ok($zip->set_number('7100132')->is_valid_number, '岡山県倉敷市藤戸町天城');
ok($zip->set_number('7100133')->is_valid_number, '岡山県倉敷市藤戸町藤戸');
ok($zip->set_number('7100141')->is_valid_number, '岡山県倉敷市串田');
ok($zip->set_number('7100142')->is_valid_number, '岡山県倉敷市林');
ok($zip->set_number('7100143')->is_valid_number, '岡山県倉敷市木見');
ok($zip->set_number('7100144')->is_valid_number, '岡山県倉敷市尾原');
ok($zip->set_number('7100145')->is_valid_number, '岡山県倉敷市福江');
ok($zip->set_number('7100146')->is_valid_number, '岡山県倉敷市曽原');
ok($zip->set_number('7100151')->is_valid_number, '岡山県岡山市南区植松');
ok($zip->set_number('7100251')->is_valid_number, '岡山県倉敷市玉島長尾');
ok($zip->set_number('7100252')->is_valid_number, '岡山県倉敷市玉島爪崎');
ok($zip->set_number('7100253')->is_valid_number, '岡山県倉敷市新倉敷駅前');
ok($zip->set_number('7100261')->is_valid_number, '岡山県倉敷市船穂町船穂');
ok($zip->set_number('7100262')->is_valid_number, '岡山県倉敷市船穂町水江');
ok($zip->set_number('7100263')->is_valid_number, '岡山県倉敷市船穂町柳井原');
ok($zip->set_number('7100801')->is_valid_number, '岡山県倉敷市酒津');
ok($zip->set_number('7100802')->is_valid_number, '岡山県倉敷市水江');
ok($zip->set_number('7100803')->is_valid_number, '岡山県倉敷市中島');
ok($zip->set_number('7100804')->is_valid_number, '岡山県倉敷市西阿知町新田');
ok($zip->set_number('7100805')->is_valid_number, '岡山県倉敷市片島町');
ok($zip->set_number('7100806')->is_valid_number, '岡山県倉敷市西阿知町西原');
ok($zip->set_number('7100807')->is_valid_number, '岡山県倉敷市西阿知町');
ok($zip->set_number('7100811')->is_valid_number, '岡山県倉敷市川入');
ok($zip->set_number('7100812')->is_valid_number, '岡山県倉敷市北浜町');
ok($zip->set_number('7100813')->is_valid_number, '岡山県倉敷市寿町');
ok($zip->set_number('7100814')->is_valid_number, '岡山県倉敷市石見町');
ok($zip->set_number('7100815')->is_valid_number, '岡山県倉敷市日吉町');
ok($zip->set_number('7100816')->is_valid_number, '岡山県倉敷市八王寺町');
ok($zip->set_number('7100817')->is_valid_number, '岡山県倉敷市大内');
ok($zip->set_number('7100821')->is_valid_number, '岡山県倉敷市川西町');
ok($zip->set_number('7100822')->is_valid_number, '岡山県倉敷市稲荷町');
ok($zip->set_number('7100823')->is_valid_number, '岡山県倉敷市南町');
ok($zip->set_number('7100824')->is_valid_number, '岡山県倉敷市白楽町');
ok($zip->set_number('7100825')->is_valid_number, '岡山県倉敷市安江');
ok($zip->set_number('7100826')->is_valid_number, '岡山県倉敷市老松町');
ok($zip->set_number('7100831')->is_valid_number, '岡山県倉敷市田ノ上');
ok($zip->set_number('7100832')->is_valid_number, '岡山県倉敷市田ノ上新町');
ok($zip->set_number('7100833')->is_valid_number, '岡山県倉敷市西中新田');
ok($zip->set_number('7100834')->is_valid_number, '岡山県倉敷市笹沖');
ok($zip->set_number('7100835')->is_valid_number, '岡山県倉敷市四十瀬');
ok($zip->set_number('7100836')->is_valid_number, '岡山県倉敷市沖');
ok($zip->set_number('7100837')->is_valid_number, '岡山県倉敷市沖新町');
ok($zip->set_number('7100841')->is_valid_number, '岡山県倉敷市堀南');
ok($zip->set_number('7100842')->is_valid_number, '岡山県倉敷市吉岡');
ok($zip->set_number('7100843')->is_valid_number, '岡山県倉敷市浦田');
ok($zip->set_number('7100844')->is_valid_number, '岡山県倉敷市福井');
ok($zip->set_number('7100845')->is_valid_number, '岡山県倉敷市西富井');
ok($zip->set_number('7100846')->is_valid_number, '岡山県倉敷市上富井');
ok($zip->set_number('7100847')->is_valid_number, '岡山県倉敷市東富井');
ok($zip->set_number('7101101')->is_valid_number, '岡山県倉敷市茶屋町');
ok($zip->set_number('7101102')->is_valid_number, '岡山県倉敷市茶屋町早沖');
ok($zip->set_number('7101201')->is_valid_number, '岡山県総社市久代');
ok($zip->set_number('7101202')->is_valid_number, '岡山県総社市山田');
ok($zip->set_number('7101203')->is_valid_number, '岡山県総社市新本');
ok($zip->set_number('7101301')->is_valid_number, '岡山県倉敷市真備町箭田');
ok($zip->set_number('7101302')->is_valid_number, '岡山県倉敷市真備町服部');
ok($zip->set_number('7101303')->is_valid_number, '岡山県倉敷市真備町妹');
ok($zip->set_number('7101304')->is_valid_number, '岡山県倉敷市真備町尾崎');
ok($zip->set_number('7101305')->is_valid_number, '岡山県倉敷市真備町市場');
ok($zip->set_number('7101306')->is_valid_number, '岡山県倉敷市真備町有井');
ok($zip->set_number('7101311')->is_valid_number, '岡山県倉敷市真備町岡田');
ok($zip->set_number('7101312')->is_valid_number, '岡山県倉敷市真備町辻田');
ok($zip->set_number('7101313')->is_valid_number, '岡山県倉敷市真備町川辺');
ok($zip->set_number('7101314')->is_valid_number, '岡山県倉敷市真備町下二万');
ok($zip->set_number('7101315')->is_valid_number, '岡山県倉敷市真備町上二万');
ok($zip->set_number('7110901')->is_valid_number, '岡山県倉敷市児島由加');
ok($zip->set_number('7110902')->is_valid_number, '岡山県倉敷市児島白尾');
ok($zip->set_number('7110903')->is_valid_number, '岡山県倉敷市児島田の口');
ok($zip->set_number('7110904')->is_valid_number, '岡山県倉敷市児島唐琴');
ok($zip->set_number('7110905')->is_valid_number, '岡山県倉敷市児島唐琴町');
ok($zip->set_number('7110906')->is_valid_number, '岡山県倉敷市児島下の町');
ok($zip->set_number('7110907')->is_valid_number, '岡山県倉敷市児島上の町');
ok($zip->set_number('7110911')->is_valid_number, '岡山県倉敷市児島小川');
ok($zip->set_number('7110912')->is_valid_number, '岡山県倉敷市児島小川町');
ok($zip->set_number('7110913')->is_valid_number, '岡山県倉敷市児島味野');
ok($zip->set_number('7110914')->is_valid_number, '岡山県倉敷市児島味野城');
ok($zip->set_number('7110915')->is_valid_number, '岡山県倉敷市児島味野山田町');
ok($zip->set_number('7110916')->is_valid_number, '岡山県倉敷市児島味野城山');
ok($zip->set_number('7110917')->is_valid_number, '岡山県倉敷市児島味野上');
ok($zip->set_number('7110921')->is_valid_number, '岡山県倉敷市児島駅前');
ok($zip->set_number('7110922')->is_valid_number, '岡山県倉敷市児島元浜町');
ok($zip->set_number('7110923')->is_valid_number, '岡山県倉敷市児島阿津');
ok($zip->set_number('7110924')->is_valid_number, '岡山県倉敷市大畠');
ok($zip->set_number('7110925')->is_valid_number, '岡山県倉敷市下津井田之浦');
ok($zip->set_number('7110926')->is_valid_number, '岡山県倉敷市下津井吹上');
ok($zip->set_number('7110927')->is_valid_number, '岡山県倉敷市下津井');
ok($zip->set_number('7110931')->is_valid_number, '岡山県倉敷市児島赤崎');
ok($zip->set_number('7110932')->is_valid_number, '岡山県倉敷市菰池');
ok($zip->set_number('7110933')->is_valid_number, '岡山県倉敷市児島通生');
ok($zip->set_number('7110934')->is_valid_number, '岡山県倉敷市児島塩生');
ok($zip->set_number('7110935')->is_valid_number, '岡山県倉敷市児島宇野津');
ok($zip->set_number('7110936')->is_valid_number, '岡山県倉敷市児島柳田町');
ok($zip->set_number('7110937')->is_valid_number, '岡山県倉敷市児島稗田町');
ok($zip->set_number('7128001')->is_valid_number, '岡山県倉敷市連島町西之浦');
ok($zip->set_number('7128002')->is_valid_number, '岡山県倉敷市連島町亀島新田');
ok($zip->set_number('7128003')->is_valid_number, '岡山県倉敷市水島明神町');
ok($zip->set_number('7128004')->is_valid_number, '岡山県倉敷市水島南亀島町');
ok($zip->set_number('7128005')->is_valid_number, '岡山県倉敷市水島北亀島町');
ok($zip->set_number('7128006')->is_valid_number, '岡山県倉敷市連島町鶴新田');
ok($zip->set_number('7128007')->is_valid_number, '岡山県倉敷市鶴の浦');
ok($zip->set_number('7128011')->is_valid_number, '岡山県倉敷市連島町連島');
ok($zip->set_number('7128012')->is_valid_number, '岡山県倉敷市連島');
ok($zip->set_number('7128013')->is_valid_number, '岡山県倉敷市亀島');
ok($zip->set_number('7128014')->is_valid_number, '岡山県倉敷市連島中央');
ok($zip->set_number('7128015')->is_valid_number, '岡山県倉敷市連島町矢柄');
ok($zip->set_number('7128021')->is_valid_number, '岡山県倉敷市水島東川町');
ok($zip->set_number('7128022')->is_valid_number, '岡山県倉敷市水島北緑町');
ok($zip->set_number('7128023')->is_valid_number, '岡山県倉敷市水島南緑町');
ok($zip->set_number('7128024')->is_valid_number, '岡山県倉敷市水島北春日町');
ok($zip->set_number('7128025')->is_valid_number, '岡山県倉敷市水島南春日町');
ok($zip->set_number('7128026')->is_valid_number, '岡山県倉敷市水島南瑞穂町');
ok($zip->set_number('7128027')->is_valid_number, '岡山県倉敷市水島北瑞穂町');
ok($zip->set_number('7128031')->is_valid_number, '岡山県倉敷市福田町浦田');
ok($zip->set_number('7128032')->is_valid_number, '岡山県倉敷市北畝');
ok($zip->set_number('7128033')->is_valid_number, '岡山県倉敷市水島東栄町');
ok($zip->set_number('7128034')->is_valid_number, '岡山県倉敷市水島西栄町');
ok($zip->set_number('7128035')->is_valid_number, '岡山県倉敷市水島東弥生町');
ok($zip->set_number('7128036')->is_valid_number, '岡山県倉敷市水島西弥生町');
ok($zip->set_number('7128037')->is_valid_number, '岡山県倉敷市水島東寿町');
ok($zip->set_number('7128038')->is_valid_number, '岡山県倉敷市水島西寿町');
ok($zip->set_number('7128039')->is_valid_number, '岡山県倉敷市水島相生町');
ok($zip->set_number('7128041')->is_valid_number, '岡山県倉敷市福田町福田');
ok($zip->set_number('7128042')->is_valid_number, '岡山県倉敷市福田町広江');
ok($zip->set_number('7128043')->is_valid_number, '岡山県倉敷市広江');
ok($zip->set_number('7128044')->is_valid_number, '岡山県倉敷市東塚');
ok($zip->set_number('7128045')->is_valid_number, '岡山県倉敷市福田町東塚');
ok($zip->set_number('7128046')->is_valid_number, '岡山県倉敷市福田町古新田');
ok($zip->set_number('7128051')->is_valid_number, '岡山県倉敷市中畝');
ok($zip->set_number('7128052')->is_valid_number, '岡山県倉敷市松江');
ok($zip->set_number('7128053')->is_valid_number, '岡山県倉敷市呼松');
ok($zip->set_number('7128053')->is_valid_number, '岡山県倉敷市呼松町');
ok($zip->set_number('7128054')->is_valid_number, '岡山県倉敷市潮通');
ok($zip->set_number('7128055')->is_valid_number, '岡山県倉敷市南畝');
ok($zip->set_number('7128056')->is_valid_number, '岡山県倉敷市水島福崎町');
ok($zip->set_number('7128057')->is_valid_number, '岡山県倉敷市水島東千鳥町');
ok($zip->set_number('7128058')->is_valid_number, '岡山県倉敷市水島東常盤町');
ok($zip->set_number('7128059')->is_valid_number, '岡山県倉敷市水島西常盤町');
ok($zip->set_number('7128061')->is_valid_number, '岡山県倉敷市神田');
ok($zip->set_number('7128062')->is_valid_number, '岡山県倉敷市水島北幸町');
ok($zip->set_number('7128063')->is_valid_number, '岡山県倉敷市水島南幸町');
ok($zip->set_number('7128064')->is_valid_number, '岡山県倉敷市水島青葉町');
ok($zip->set_number('7128065')->is_valid_number, '岡山県倉敷市水島西千鳥町');
ok($zip->set_number('7128066')->is_valid_number, '岡山県倉敷市水島高砂町');
ok($zip->set_number('7128071')->is_valid_number, '岡山県倉敷市水島海岸通');
ok($zip->set_number('7128072')->is_valid_number, '岡山県倉敷市水島中通');
ok($zip->set_number('7128073')->is_valid_number, '岡山県倉敷市水島西通');
ok($zip->set_number('7128074')->is_valid_number, '岡山県倉敷市水島川崎通');
ok($zip->set_number('7138101')->is_valid_number, '岡山県倉敷市玉島上成');
ok($zip->set_number('7138102')->is_valid_number, '岡山県倉敷市玉島');
ok($zip->set_number('7138103')->is_valid_number, '岡山県倉敷市玉島乙島');
ok($zip->set_number('7138111')->is_valid_number, '岡山県倉敷市玉島服部');
ok($zip->set_number('7138112')->is_valid_number, '岡山県倉敷市玉島陶');
ok($zip->set_number('7138113')->is_valid_number, '岡山県倉敷市玉島八島');
ok($zip->set_number('7138114')->is_valid_number, '岡山県倉敷市玉島道越');
ok($zip->set_number('7138115')->is_valid_number, '岡山県倉敷市玉島道口');
ok($zip->set_number('7138116')->is_valid_number, '岡山県倉敷市玉島富');
ok($zip->set_number('7138121')->is_valid_number, '岡山県倉敷市玉島阿賀崎');
ok($zip->set_number('7138122')->is_valid_number, '岡山県倉敷市玉島中央町');
ok($zip->set_number('7138123')->is_valid_number, '岡山県倉敷市玉島柏島');
ok($zip->set_number('7138124')->is_valid_number, '岡山県倉敷市玉島柏台');
ok($zip->set_number('7138125')->is_valid_number, '岡山県倉敷市玉島勇崎');
ok($zip->set_number('7138126')->is_valid_number, '岡山県倉敷市玉島黒崎');
ok($zip->set_number('7138127')->is_valid_number, '岡山県倉敷市玉島黒崎新町');
ok($zip->set_number('7140000')->is_valid_number, '岡山県笠岡市以下に掲載がない場合');
ok($zip->set_number('7140001')->is_valid_number, '岡山県笠岡市走出');
ok($zip->set_number('7140002')->is_valid_number, '岡山県笠岡市甲弩');
ok($zip->set_number('7140003')->is_valid_number, '岡山県笠岡市尾坂');
ok($zip->set_number('7140004')->is_valid_number, '岡山県笠岡市関戸');
ok($zip->set_number('7140005')->is_valid_number, '岡山県笠岡市新賀');
ok($zip->set_number('7140006')->is_valid_number, '岡山県笠岡市みの越');
ok($zip->set_number('7140007')->is_valid_number, '岡山県笠岡市山口');
ok($zip->set_number('7140011')->is_valid_number, '岡山県笠岡市吉田');
ok($zip->set_number('7140012')->is_valid_number, '岡山県笠岡市小平井');
ok($zip->set_number('7140013')->is_valid_number, '岡山県笠岡市大井南');
ok($zip->set_number('7140014')->is_valid_number, '岡山県笠岡市相生');
ok($zip->set_number('7140021')->is_valid_number, '岡山県笠岡市園井');
ok($zip->set_number('7140022')->is_valid_number, '岡山県笠岡市今立');
ok($zip->set_number('7140023')->is_valid_number, '岡山県笠岡市広浜');
ok($zip->set_number('7140024')->is_valid_number, '岡山県笠岡市馬飼');
ok($zip->set_number('7140025')->is_valid_number, '岡山県笠岡市春日台');
ok($zip->set_number('7140031')->is_valid_number, '岡山県笠岡市西大島新田');
ok($zip->set_number('7140032')->is_valid_number, '岡山県笠岡市西大島');
ok($zip->set_number('7140033')->is_valid_number, '岡山県笠岡市大島中');
ok($zip->set_number('7140034')->is_valid_number, '岡山県笠岡市神島外浦');
ok($zip->set_number('7140035')->is_valid_number, '岡山県笠岡市高島');
ok($zip->set_number('7140036')->is_valid_number, '岡山県笠岡市白石島');
ok($zip->set_number('7140037')->is_valid_number, '岡山県笠岡市真鍋島');
ok($zip->set_number('7140038')->is_valid_number, '岡山県笠岡市六島');
ok($zip->set_number('7140041')->is_valid_number, '岡山県笠岡市入江');
ok($zip->set_number('7140042')->is_valid_number, '岡山県笠岡市美の浜');
ok($zip->set_number('7140043')->is_valid_number, '岡山県笠岡市横島');
ok($zip->set_number('7140044')->is_valid_number, '岡山県笠岡市神島');
ok($zip->set_number('7140045')->is_valid_number, '岡山県笠岡市港町');
ok($zip->set_number('7140046')->is_valid_number, '岡山県笠岡市カブト南町');
ok($zip->set_number('7140047')->is_valid_number, '岡山県笠岡市拓海町');
ok($zip->set_number('7140048')->is_valid_number, '岡山県笠岡市緑町');
ok($zip->set_number('7140051')->is_valid_number, '岡山県笠岡市カブト東町');
ok($zip->set_number('7140052')->is_valid_number, '岡山県笠岡市カブト中央町');
ok($zip->set_number('7140053')->is_valid_number, '岡山県笠岡市カブト西町');
ok($zip->set_number('7140054')->is_valid_number, '岡山県笠岡市平成町');
ok($zip->set_number('7140055')->is_valid_number, '岡山県笠岡市生江浜');
ok($zip->set_number('7140056')->is_valid_number, '岡山県笠岡市旭が丘');
ok($zip->set_number('7140057')->is_valid_number, '岡山県笠岡市金浦');
ok($zip->set_number('7140061')->is_valid_number, '岡山県笠岡市大げ');
ok($zip->set_number('7140062')->is_valid_number, '岡山県笠岡市茂平');
ok($zip->set_number('7140063')->is_valid_number, '岡山県笠岡市鋼管町');
ok($zip->set_number('7140064')->is_valid_number, '岡山県笠岡市西茂平');
ok($zip->set_number('7140065')->is_valid_number, '岡山県笠岡市城見台');
ok($zip->set_number('7140066')->is_valid_number, '岡山県笠岡市用之江');
ok($zip->set_number('7140071')->is_valid_number, '岡山県笠岡市東大戸');
ok($zip->set_number('7140072')->is_valid_number, '岡山県笠岡市西大戸');
ok($zip->set_number('7140073')->is_valid_number, '岡山県笠岡市大河');
ok($zip->set_number('7140074')->is_valid_number, '岡山県笠岡市吉浜');
ok($zip->set_number('7140075')->is_valid_number, '岡山県笠岡市有田');
ok($zip->set_number('7140076')->is_valid_number, '岡山県笠岡市押撫');
ok($zip->set_number('7140077')->is_valid_number, '岡山県笠岡市篠坂');
ok($zip->set_number('7140078')->is_valid_number, '岡山県笠岡市入田');
ok($zip->set_number('7140081')->is_valid_number, '岡山県笠岡市笠岡');
ok($zip->set_number('7140082')->is_valid_number, '岡山県笠岡市一番町');
ok($zip->set_number('7140083')->is_valid_number, '岡山県笠岡市二番町');
ok($zip->set_number('7140084')->is_valid_number, '岡山県笠岡市三番町');
ok($zip->set_number('7140085')->is_valid_number, '岡山県笠岡市四番町');
ok($zip->set_number('7140086')->is_valid_number, '岡山県笠岡市五番町');
ok($zip->set_number('7140087')->is_valid_number, '岡山県笠岡市六番町');
ok($zip->set_number('7140088')->is_valid_number, '岡山県笠岡市中央町');
ok($zip->set_number('7140091')->is_valid_number, '岡山県笠岡市絵師');
ok($zip->set_number('7140092')->is_valid_number, '岡山県笠岡市富岡');
ok($zip->set_number('7140093')->is_valid_number, '岡山県笠岡市新横島');
ok($zip->set_number('7140094')->is_valid_number, '岡山県笠岡市七番町');
ok($zip->set_number('7140095')->is_valid_number, '岡山県笠岡市八番町');
ok($zip->set_number('7140096')->is_valid_number, '岡山県笠岡市九番町');
ok($zip->set_number('7140097')->is_valid_number, '岡山県笠岡市十番町');
ok($zip->set_number('7140098')->is_valid_number, '岡山県笠岡市十一番町');
ok($zip->set_number('7140101')->is_valid_number, '岡山県浅口市寄島町');
ok($zip->set_number('7140301')->is_valid_number, '岡山県笠岡市北木島町');
ok($zip->set_number('7140302')->is_valid_number, '岡山県笠岡市飛島');
ok($zip->set_number('7141200')->is_valid_number, '岡山県小田郡矢掛町以下に掲載がない場合');
ok($zip->set_number('7141201')->is_valid_number, '岡山県小田郡矢掛町矢掛');
ok($zip->set_number('7141202')->is_valid_number, '岡山県小田郡矢掛町小林');
ok($zip->set_number('7141203')->is_valid_number, '岡山県小田郡矢掛町上高末');
ok($zip->set_number('7141204')->is_valid_number, '岡山県小田郡矢掛町下高末');
ok($zip->set_number('7141205')->is_valid_number, '岡山県小田郡矢掛町宇角');
ok($zip->set_number('7141206')->is_valid_number, '岡山県小田郡矢掛町内田');
ok($zip->set_number('7141211')->is_valid_number, '岡山県小田郡矢掛町東三成');
ok($zip->set_number('7141212')->is_valid_number, '岡山県小田郡矢掛町横谷');
ok($zip->set_number('7141213')->is_valid_number, '岡山県小田郡矢掛町里山田');
ok($zip->set_number('7141214')->is_valid_number, '岡山県小田郡矢掛町南山田');
ok($zip->set_number('7141215')->is_valid_number, '岡山県小田郡矢掛町中');
ok($zip->set_number('7141221')->is_valid_number, '岡山県小田郡矢掛町宇内');
ok($zip->set_number('7141222')->is_valid_number, '岡山県小田郡矢掛町西川面');
ok($zip->set_number('7141223')->is_valid_number, '岡山県小田郡矢掛町東川面');
ok($zip->set_number('7141224')->is_valid_number, '岡山県小田郡矢掛町本堀');
ok($zip->set_number('7141225')->is_valid_number, '岡山県小田郡矢掛町浅海');
ok($zip->set_number('7141226')->is_valid_number, '岡山県小田郡矢掛町江良');
ok($zip->set_number('7141227')->is_valid_number, '岡山県小田郡矢掛町小田');
ok($zip->set_number('7141401')->is_valid_number, '岡山県井原市美星町明治');
ok($zip->set_number('7141402')->is_valid_number, '岡山県井原市美星町宇戸谷');
ok($zip->set_number('7141403')->is_valid_number, '岡山県井原市美星町上高末');
ok($zip->set_number('7141404')->is_valid_number, '岡山県井原市美星町烏頭');
ok($zip->set_number('7141405')->is_valid_number, '岡山県井原市美星町宇戸');
ok($zip->set_number('7141406')->is_valid_number, '岡山県井原市美星町三山');
ok($zip->set_number('7141407')->is_valid_number, '岡山県井原市美星町黒忠');
ok($zip->set_number('7141411')->is_valid_number, '岡山県井原市美星町大倉');
ok($zip->set_number('7141412')->is_valid_number, '岡山県井原市美星町東水砂');
ok($zip->set_number('7141413')->is_valid_number, '岡山県井原市美星町西水砂');
ok($zip->set_number('7141414')->is_valid_number, '岡山県井原市美星町黒木');
ok($zip->set_number('7141415')->is_valid_number, '岡山県井原市美星町星田');
ok($zip->set_number('7142101')->is_valid_number, '岡山県井原市芳井町梶江');
ok($zip->set_number('7142102')->is_valid_number, '岡山県井原市芳井町与井');
ok($zip->set_number('7142103')->is_valid_number, '岡山県井原市芳井町宇戸川');
ok($zip->set_number('7142104')->is_valid_number, '岡山県井原市芳井町花滝');
ok($zip->set_number('7142111')->is_valid_number, '岡山県井原市芳井町吉井');
ok($zip->set_number('7142112')->is_valid_number, '岡山県井原市芳井町簗瀬');
ok($zip->set_number('7142113')->is_valid_number, '岡山県井原市芳井町天神山');
ok($zip->set_number('7142114')->is_valid_number, '岡山県井原市芳井町川相');
ok($zip->set_number('7142121')->is_valid_number, '岡山県井原市芳井町佐屋');
ok($zip->set_number('7142122')->is_valid_number, '岡山県井原市芳井町種');
ok($zip->set_number('7142123')->is_valid_number, '岡山県井原市芳井町片塚');
ok($zip->set_number('7142124')->is_valid_number, '岡山県井原市芳井町井山');
ok($zip->set_number('7142125')->is_valid_number, '岡山県井原市芳井町池谷');
ok($zip->set_number('7142231')->is_valid_number, '岡山県井原市芳井町下鴫');
ok($zip->set_number('7142232')->is_valid_number, '岡山県井原市芳井町上鴫');
ok($zip->set_number('7142233')->is_valid_number, '岡山県井原市芳井町山村');
ok($zip->set_number('7142234')->is_valid_number, '岡山県井原市芳井町西三原');
ok($zip->set_number('7142341')->is_valid_number, '岡山県井原市芳井町東三原');
ok($zip->set_number('7150000')->is_valid_number, '岡山県井原市以下に掲載がない場合');
ok($zip->set_number('7150001')->is_valid_number, '岡山県井原市野上町');
ok($zip->set_number('7150002')->is_valid_number, '岡山県井原市神代町');
ok($zip->set_number('7150003')->is_valid_number, '岡山県井原市東江原町');
ok($zip->set_number('7150004')->is_valid_number, '岡山県井原市木之子町');
ok($zip->set_number('7150005')->is_valid_number, '岡山県井原市門田町');
ok($zip->set_number('7150006')->is_valid_number, '岡山県井原市西江原町');
ok($zip->set_number('7150011')->is_valid_number, '岡山県井原市稗原町');
ok($zip->set_number('7150012')->is_valid_number, '岡山県井原市青野町');
ok($zip->set_number('7150013')->is_valid_number, '岡山県井原市北山町');
ok($zip->set_number('7150014')->is_valid_number, '岡山県井原市七日市町');
ok($zip->set_number('7150015')->is_valid_number, '岡山県井原市西方町');
ok($zip->set_number('7150016')->is_valid_number, '岡山県井原市岩倉町');
ok($zip->set_number('7150017')->is_valid_number, '岡山県井原市下稲木町');
ok($zip->set_number('7150018')->is_valid_number, '岡山県井原市上稲木町');
ok($zip->set_number('7150019')->is_valid_number, '岡山県井原市井原町');
ok($zip->set_number('7150021')->is_valid_number, '岡山県井原市上出部町');
ok($zip->set_number('7150022')->is_valid_number, '岡山県井原市下出部町');
ok($zip->set_number('7150023')->is_valid_number, '岡山県井原市大江町');
ok($zip->set_number('7150024')->is_valid_number, '岡山県井原市高屋町');
ok($zip->set_number('7150025')->is_valid_number, '岡山県井原市笹賀町');
ok($zip->set_number('7150026')->is_valid_number, '岡山県井原市上出部町四季が丘');
ok($zip->set_number('7160000')->is_valid_number, '岡山県高梁市以下に掲載がない場合');
ok($zip->set_number('7160001')->is_valid_number, '岡山県高梁市津川町八川');
ok($zip->set_number('7160002')->is_valid_number, '岡山県高梁市津川町今津');
ok($zip->set_number('7160003')->is_valid_number, '岡山県高梁市高倉町大瀬八長');
ok($zip->set_number('7160004')->is_valid_number, '岡山県高梁市内山下');
ok($zip->set_number('7160005')->is_valid_number, '岡山県高梁市川端町');
ok($zip->set_number('7160006')->is_valid_number, '岡山県高梁市小高下町');
ok($zip->set_number('7160007')->is_valid_number, '岡山県高梁市奥万田町');
ok($zip->set_number('7160008')->is_valid_number, '岡山県高梁市和田町');
ok($zip->set_number('7160009')->is_valid_number, '岡山県高梁市間之町');
ok($zip->set_number('7160011')->is_valid_number, '岡山県高梁市本町');
ok($zip->set_number('7160012')->is_valid_number, '岡山県高梁市新町');
ok($zip->set_number('7160013')->is_valid_number, '岡山県高梁市片原町');
ok($zip->set_number('7160014')->is_valid_number, '岡山県高梁市中之町');
ok($zip->set_number('7160015')->is_valid_number, '岡山県高梁市石火矢町');
ok($zip->set_number('7160016')->is_valid_number, '岡山県高梁市頼久寺町');
ok($zip->set_number('7160017')->is_valid_number, '岡山県高梁市御前町');
ok($zip->set_number('7160018')->is_valid_number, '岡山県高梁市伊賀町');
ok($zip->set_number('7160019')->is_valid_number, '岡山県高梁市寺町');
ok($zip->set_number('7160021')->is_valid_number, '岡山県高梁市中間町');
ok($zip->set_number('7160022')->is_valid_number, '岡山県高梁市下町');
ok($zip->set_number('7160023')->is_valid_number, '岡山県高梁市鍜冶町');
ok($zip->set_number('7160024')->is_valid_number, '岡山県高梁市大工町');
ok($zip->set_number('7160025')->is_valid_number, '岡山県高梁市荒神町');
ok($zip->set_number('7160026')->is_valid_number, '岡山県高梁市甲賀町');
ok($zip->set_number('7160027')->is_valid_number, '岡山県高梁市八幡町');
ok($zip->set_number('7160028')->is_valid_number, '岡山県高梁市柿木町');
ok($zip->set_number('7160029')->is_valid_number, '岡山県高梁市向町');
ok($zip->set_number('7160031')->is_valid_number, '岡山県高梁市鉄砲町');
ok($zip->set_number('7160032')->is_valid_number, '岡山県高梁市弓之町');
ok($zip->set_number('7160033')->is_valid_number, '岡山県高梁市南町');
ok($zip->set_number('7160034')->is_valid_number, '岡山県高梁市東町');
ok($zip->set_number('7160035')->is_valid_number, '岡山県高梁市栄町');
ok($zip->set_number('7160036')->is_valid_number, '岡山県高梁市松原通');
ok($zip->set_number('7160037')->is_valid_number, '岡山県高梁市正宗町');
ok($zip->set_number('7160038')->is_valid_number, '岡山県高梁市浜町');
ok($zip->set_number('7160039')->is_valid_number, '岡山県高梁市旭町');
ok($zip->set_number('7160041')->is_valid_number, '岡山県高梁市上谷町');
ok($zip->set_number('7160042')->is_valid_number, '岡山県高梁市下谷町');
ok($zip->set_number('7160043')->is_valid_number, '岡山県高梁市原田北町');
ok($zip->set_number('7160044')->is_valid_number, '岡山県高梁市原田南町');
ok($zip->set_number('7160045')->is_valid_number, '岡山県高梁市中原町');
ok($zip->set_number('7160046')->is_valid_number, '岡山県高梁市横町');
ok($zip->set_number('7160047')->is_valid_number, '岡山県高梁市段町');
ok($zip->set_number('7160051')->is_valid_number, '岡山県高梁市松山');
ok($zip->set_number('7160052')->is_valid_number, '岡山県高梁市玉川町玉');
ok($zip->set_number('7160053')->is_valid_number, '岡山県高梁市玉川町下切');
ok($zip->set_number('7160054')->is_valid_number, '岡山県高梁市玉川町増原');
ok($zip->set_number('7160061')->is_valid_number, '岡山県高梁市落合町阿部');
ok($zip->set_number('7160062')->is_valid_number, '岡山県高梁市落合町近似');
ok($zip->set_number('7160063')->is_valid_number, '岡山県高梁市落合町原田');
ok($zip->set_number('7160064')->is_valid_number, '岡山県高梁市落合町福地');
ok($zip->set_number('7160065')->is_valid_number, '岡山県高梁市松原町大津寄');
ok($zip->set_number('7160066')->is_valid_number, '岡山県高梁市松原町松岡');
ok($zip->set_number('7160067')->is_valid_number, '岡山県高梁市松原町春木');
ok($zip->set_number('7160068')->is_valid_number, '岡山県高梁市松原町神原');
ok($zip->set_number('7160101')->is_valid_number, '岡山県高梁市成羽町下日名');
ok($zip->set_number('7160102')->is_valid_number, '岡山県高梁市成羽町上日名');
ok($zip->set_number('7160111')->is_valid_number, '岡山県高梁市成羽町下原');
ok($zip->set_number('7160112')->is_valid_number, '岡山県高梁市成羽町星原');
ok($zip->set_number('7160113')->is_valid_number, '岡山県高梁市成羽町佐々木');
ok($zip->set_number('7160121')->is_valid_number, '岡山県高梁市成羽町成羽');
ok($zip->set_number('7160122')->is_valid_number, '岡山県高梁市成羽町羽山');
ok($zip->set_number('7160201')->is_valid_number, '岡山県高梁市川上町地頭');
ok($zip->set_number('7160202')->is_valid_number, '岡山県高梁市川上町七地');
ok($zip->set_number('7160203')->is_valid_number, '岡山県高梁市川上町三沢');
ok($zip->set_number('7160204')->is_valid_number, '岡山県高梁市川上町領家');
ok($zip->set_number('7160205')->is_valid_number, '岡山県高梁市川上町臘数');
ok($zip->set_number('7160206')->is_valid_number, '岡山県高梁市川上町吉木');
ok($zip->set_number('7160207')->is_valid_number, '岡山県高梁市川上町仁賀');
ok($zip->set_number('7160211')->is_valid_number, '岡山県高梁市川上町上大竹');
ok($zip->set_number('7160212')->is_valid_number, '岡山県高梁市川上町下大竹');
ok($zip->set_number('7160221')->is_valid_number, '岡山県高梁市川上町高山市');
ok($zip->set_number('7160222')->is_valid_number, '岡山県高梁市川上町大原');
ok($zip->set_number('7160223')->is_valid_number, '岡山県高梁市川上町高山');
ok($zip->set_number('7160301')->is_valid_number, '岡山県高梁市備中町志藤用瀬');
ok($zip->set_number('7160302')->is_valid_number, '岡山県高梁市備中町布瀬');
ok($zip->set_number('7160303')->is_valid_number, '岡山県高梁市備中町長屋');
ok($zip->set_number('7160304')->is_valid_number, '岡山県高梁市備中町布賀');
ok($zip->set_number('7160311')->is_valid_number, '岡山県高梁市備中町平川');
ok($zip->set_number('7160321')->is_valid_number, '岡山県高梁市備中町東油野');
ok($zip->set_number('7160322')->is_valid_number, '岡山県高梁市備中町西油野');
ok($zip->set_number('7160323')->is_valid_number, '岡山県高梁市備中町西山');
ok($zip->set_number('7160331')->is_valid_number, '岡山県高梁市成羽町羽根');
ok($zip->set_number('7160332')->is_valid_number, '岡山県高梁市成羽町小泉');
ok($zip->set_number('7160333')->is_valid_number, '岡山県高梁市成羽町相坂');
ok($zip->set_number('7160334')->is_valid_number, '岡山県高梁市成羽町長地');
ok($zip->set_number('7160335')->is_valid_number, '岡山県高梁市成羽町布寄');
ok($zip->set_number('7161100')->is_valid_number, '岡山県加賀郡吉備中央町以下に掲載がない場合');
ok($zip->set_number('7161101')->is_valid_number, '岡山県加賀郡吉備中央町豊野');
ok($zip->set_number('7161102')->is_valid_number, '岡山県加賀郡吉備中央町黒土');
ok($zip->set_number('7161111')->is_valid_number, '岡山県加賀郡吉備中央町田土');
ok($zip->set_number('7161112')->is_valid_number, '岡山県加賀郡吉備中央町湯山');
ok($zip->set_number('7161121')->is_valid_number, '岡山県加賀郡吉備中央町納地');
ok($zip->set_number('7161122')->is_valid_number, '岡山県加賀郡吉備中央町竹荘');
ok($zip->set_number('7161131')->is_valid_number, '岡山県加賀郡吉備中央町上竹');
ok($zip->set_number('7161241')->is_valid_number, '岡山県加賀郡吉備中央町吉川');
ok($zip->set_number('7161242')->is_valid_number, '岡山県加賀郡吉備中央町黒山');
ok($zip->set_number('7161311')->is_valid_number, '岡山県高梁市巨瀬町');
ok($zip->set_number('7161321')->is_valid_number, '岡山県高梁市有漢町有漢');
ok($zip->set_number('7161322')->is_valid_number, '岡山県高梁市有漢町上有漢');
ok($zip->set_number('7161401')->is_valid_number, '岡山県真庭市五名');
ok($zip->set_number('7161402')->is_valid_number, '岡山県真庭市山田');
ok($zip->set_number('7161403')->is_valid_number, '岡山県真庭市宮地');
ok($zip->set_number('7161411')->is_valid_number, '岡山県真庭市上水田');
ok($zip->set_number('7161421')->is_valid_number, '岡山県真庭市下中津井');
ok($zip->set_number('7161422')->is_valid_number, '岡山県真庭市上中津井');
ok($zip->set_number('7161431')->is_valid_number, '岡山県真庭市阿口');
ok($zip->set_number('7161432')->is_valid_number, '岡山県真庭市上呰部');
ok($zip->set_number('7161433')->is_valid_number, '岡山県真庭市下呰部');
ok($zip->set_number('7161551')->is_valid_number, '岡山県加賀郡吉備中央町北');
ok($zip->set_number('7161552')->is_valid_number, '岡山県加賀郡吉備中央町岨谷');
ok($zip->set_number('7161553')->is_valid_number, '岡山県加賀郡吉備中央町宮地');
ok($zip->set_number('7161554')->is_valid_number, '岡山県加賀郡吉備中央町西');
ok($zip->set_number('7170001')->is_valid_number, '岡山県真庭市星山');
ok($zip->set_number('7170002')->is_valid_number, '岡山県真庭市菅谷');
ok($zip->set_number('7170003')->is_valid_number, '岡山県真庭市竹原');
ok($zip->set_number('7170004')->is_valid_number, '岡山県真庭市神庭');
ok($zip->set_number('7170005')->is_valid_number, '岡山県真庭市横部');
ok($zip->set_number('7170006')->is_valid_number, '岡山県真庭市組');
ok($zip->set_number('7170007')->is_valid_number, '岡山県真庭市本郷');
ok($zip->set_number('7170011')->is_valid_number, '岡山県真庭市見尾');
ok($zip->set_number('7170012')->is_valid_number, '岡山県真庭市山久世');
ok($zip->set_number('7170013')->is_valid_number, '岡山県真庭市勝山');
ok($zip->set_number('7170014')->is_valid_number, '岡山県真庭市柴原');
ok($zip->set_number('7170015')->is_valid_number, '岡山県真庭市岡');
ok($zip->set_number('7170016')->is_valid_number, '岡山県真庭市正吉');
ok($zip->set_number('7170017')->is_valid_number, '岡山県真庭市真賀');
ok($zip->set_number('7170021')->is_valid_number, '岡山県真庭市福谷');
ok($zip->set_number('7170022')->is_valid_number, '岡山県真庭市三田');
ok($zip->set_number('7170023')->is_valid_number, '岡山県真庭市江川');
ok($zip->set_number('7170024')->is_valid_number, '岡山県真庭市月田');
ok($zip->set_number('7170025')->is_valid_number, '岡山県真庭市後谷畝');
ok($zip->set_number('7170026')->is_valid_number, '岡山県真庭市荒田');
ok($zip->set_number('7170027')->is_valid_number, '岡山県真庭市神代');
ok($zip->set_number('7170101')->is_valid_number, '岡山県真庭市鉄山');
ok($zip->set_number('7170102')->is_valid_number, '岡山県真庭市黒田');
ok($zip->set_number('7170103')->is_valid_number, '岡山県真庭市田口');
ok($zip->set_number('7170104')->is_valid_number, '岡山県真庭市延風');
ok($zip->set_number('7170105')->is_valid_number, '岡山県真庭市美甘');
ok($zip->set_number('7170201')->is_valid_number, '岡山県真庭郡新庄村新庄村一円');
ok($zip->set_number('7170401')->is_valid_number, '岡山県真庭市田羽根');
ok($zip->set_number('7170402')->is_valid_number, '岡山県真庭市湯原温泉');
ok($zip->set_number('7170403')->is_valid_number, '岡山県真庭市下湯原');
ok($zip->set_number('7170404')->is_valid_number, '岡山県真庭市社');
ok($zip->set_number('7170405')->is_valid_number, '岡山県真庭市久見');
ok($zip->set_number('7170406')->is_valid_number, '岡山県真庭市豊栄');
ok($zip->set_number('7170411')->is_valid_number, '岡山県真庭市見明戸');
ok($zip->set_number('7170412')->is_valid_number, '岡山県真庭市本庄');
ok($zip->set_number('7170413')->is_valid_number, '岡山県真庭市禾津');
ok($zip->set_number('7170414')->is_valid_number, '岡山県真庭市釘貫小川');
ok($zip->set_number('7170415')->is_valid_number, '岡山県真庭市都喜足');
ok($zip->set_number('7170416')->is_valid_number, '岡山県真庭市仲間');
ok($zip->set_number('7170421')->is_valid_number, '岡山県真庭市粟谷');
ok($zip->set_number('7170422')->is_valid_number, '岡山県真庭市藤森');
ok($zip->set_number('7170423')->is_valid_number, '岡山県真庭市黒杭');
ok($zip->set_number('7170424')->is_valid_number, '岡山県真庭市種');
ok($zip->set_number('7170425')->is_valid_number, '岡山県真庭市小童谷');
ok($zip->set_number('7170426')->is_valid_number, '岡山県真庭市三世七原');
ok($zip->set_number('7170501')->is_valid_number, '岡山県真庭市蒜山中福田');
ok($zip->set_number('7170502')->is_valid_number, '岡山県真庭市蒜山富掛田');
ok($zip->set_number('7170503')->is_valid_number, '岡山県真庭市蒜山富山根');
ok($zip->set_number('7170504')->is_valid_number, '岡山県真庭市蒜山下福田');
ok($zip->set_number('7170505')->is_valid_number, '岡山県真庭市蒜山上長田');
ok($zip->set_number('7170506')->is_valid_number, '岡山県真庭市蒜山下長田');
ok($zip->set_number('7170507')->is_valid_number, '岡山県真庭市蒜山下見');
ok($zip->set_number('7170511')->is_valid_number, '岡山県真庭市蒜山初和');
ok($zip->set_number('7170512')->is_valid_number, '岡山県真庭市蒜山真加子');
ok($zip->set_number('7170513')->is_valid_number, '岡山県真庭市蒜山下和');
ok($zip->set_number('7170514')->is_valid_number, '岡山県真庭市蒜山吉田');
ok($zip->set_number('7170515')->is_valid_number, '岡山県真庭市蒜山別所');
ok($zip->set_number('7170601')->is_valid_number, '岡山県真庭市蒜山湯船');
ok($zip->set_number('7170602')->is_valid_number, '岡山県真庭市蒜山上福田');
ok($zip->set_number('7170603')->is_valid_number, '岡山県真庭市蒜山東茅部');
ok($zip->set_number('7170604')->is_valid_number, '岡山県真庭市蒜山西茅部');
ok($zip->set_number('7170611')->is_valid_number, '岡山県真庭市蒜山本茅部');
ok($zip->set_number('7170612')->is_valid_number, '岡山県真庭市蒜山上徳山');
ok($zip->set_number('7170613')->is_valid_number, '岡山県真庭市蒜山下徳山');
ok($zip->set_number('7170731')->is_valid_number, '岡山県真庭市曲り');
ok($zip->set_number('7170732')->is_valid_number, '岡山県真庭市高田山上');
ok($zip->set_number('7170733')->is_valid_number, '岡山県真庭市若代畝');
ok($zip->set_number('7170734')->is_valid_number, '岡山県真庭市野');
ok($zip->set_number('7170735')->is_valid_number, '岡山県真庭市下岩');
ok($zip->set_number('7170736')->is_valid_number, '岡山県真庭市古呂々尾中');
ok($zip->set_number('7170737')->is_valid_number, '岡山県真庭市清谷');
ok($zip->set_number('7170741')->is_valid_number, '岡山県真庭市若代');
ok($zip->set_number('7170742')->is_valid_number, '岡山県真庭市後谷');
ok($zip->set_number('7170743')->is_valid_number, '岡山県真庭市月田本');
ok($zip->set_number('7170744')->is_valid_number, '岡山県真庭市岩井谷');
ok($zip->set_number('7170745')->is_valid_number, '岡山県真庭市岩井畝');
ok($zip->set_number('7170746')->is_valid_number, '岡山県真庭市上');
ok($zip->set_number('7180000')->is_valid_number, '岡山県新見市以下に掲載がない場合');
ok($zip->set_number('7180001')->is_valid_number, '岡山県新見市上熊谷');
ok($zip->set_number('7180002')->is_valid_number, '岡山県新見市下熊谷');
ok($zip->set_number('7180003')->is_valid_number, '岡山県新見市高尾');
ok($zip->set_number('7180004')->is_valid_number, '岡山県新見市馬塚');
ok($zip->set_number('7180005')->is_valid_number, '岡山県新見市上市');
ok($zip->set_number('7180006')->is_valid_number, '岡山県新見市足立');
ok($zip->set_number('7180007')->is_valid_number, '岡山県新見市坂本');
ok($zip->set_number('7180011')->is_valid_number, '岡山県新見市新見');
ok($zip->set_number('7180012')->is_valid_number, '岡山県新見市唐松');
ok($zip->set_number('7180013')->is_valid_number, '岡山県新見市正田');
ok($zip->set_number('7180014')->is_valid_number, '岡山県新見市長屋');
ok($zip->set_number('7180015')->is_valid_number, '岡山県新見市石蟹');
ok($zip->set_number('7180016')->is_valid_number, '岡山県新見市金谷');
ok($zip->set_number('7180017')->is_valid_number, '岡山県新見市西方');
ok($zip->set_number('7180101')->is_valid_number, '岡山県新見市千屋');
ok($zip->set_number('7180102')->is_valid_number, '岡山県新見市千屋実');
ok($zip->set_number('7180103')->is_valid_number, '岡山県新見市千屋井原');
ok($zip->set_number('7180104')->is_valid_number, '岡山県新見市千屋花見');
ok($zip->set_number('7180211')->is_valid_number, '岡山県新見市菅生');
ok($zip->set_number('7180301')->is_valid_number, '岡山県新見市哲多町宮河内');
ok($zip->set_number('7180302')->is_valid_number, '岡山県新見市哲多町花木');
ok($zip->set_number('7180303')->is_valid_number, '岡山県新見市哲多町本郷');
ok($zip->set_number('7180304')->is_valid_number, '岡山県新見市哲多町成松');
ok($zip->set_number('7180305')->is_valid_number, '岡山県新見市哲多町荻尾');
ok($zip->set_number('7180306')->is_valid_number, '岡山県新見市哲多町矢戸');
ok($zip->set_number('7180307')->is_valid_number, '岡山県新見市哲多町老栄');
ok($zip->set_number('7180311')->is_valid_number, '岡山県新見市哲多町蚊家');
ok($zip->set_number('7180312')->is_valid_number, '岡山県新見市哲多町田淵');
ok($zip->set_number('7180313')->is_valid_number, '岡山県新見市哲多町大野');
ok($zip->set_number('7190101')->is_valid_number, '岡山県浅口市金光町上竹(その他)');
ok($zip->set_number('7190102')->is_valid_number, '岡山県浅口市金光町下竹');
ok($zip->set_number('7190103')->is_valid_number, '岡山県浅口市金光町八重');
ok($zip->set_number('7190104')->is_valid_number, '岡山県浅口市金光町占見新田');
ok($zip->set_number('7190105')->is_valid_number, '岡山県浅口市金光町占見');
ok($zip->set_number('7190106')->is_valid_number, '岡山県浅口市金光町地頭下');
ok($zip->set_number('7190111')->is_valid_number, '岡山県浅口市金光町大谷');
ok($zip->set_number('7190112')->is_valid_number, '岡山県浅口市金光町須恵');
ok($zip->set_number('7190113')->is_valid_number, '岡山県浅口市金光町佐方');
ok($zip->set_number('7190200')->is_valid_number, '岡山県浅口市以下に掲載がない場合');
ok($zip->set_number('7190221')->is_valid_number, '岡山県浅口市金光町上竹(遙照山)');
ok($zip->set_number('7190231')->is_valid_number, '岡山県浅口市鴨方町小坂西');
ok($zip->set_number('7190232')->is_valid_number, '岡山県浅口市鴨方町本庄');
ok($zip->set_number('7190233')->is_valid_number, '岡山県浅口市鴨方町地頭上');
ok($zip->set_number('7190234')->is_valid_number, '岡山県浅口市鴨方町益坂');
ok($zip->set_number('7190241')->is_valid_number, '岡山県浅口市鴨方町小坂東');
ok($zip->set_number('7190242')->is_valid_number, '岡山県浅口市鴨方町みどりケ丘');
ok($zip->set_number('7190243')->is_valid_number, '岡山県浅口市鴨方町鴨方');
ok($zip->set_number('7190244')->is_valid_number, '岡山県浅口市鴨方町深田');
ok($zip->set_number('7190251')->is_valid_number, '岡山県浅口市鴨方町六条院西');
ok($zip->set_number('7190252')->is_valid_number, '岡山県浅口市鴨方町六条院中');
ok($zip->set_number('7190253')->is_valid_number, '岡山県浅口市鴨方町鳩ケ丘');
ok($zip->set_number('7190254')->is_valid_number, '岡山県浅口市鴨方町六条院東');
ok($zip->set_number('7190300')->is_valid_number, '岡山県浅口郡里庄町以下に掲載がない場合');
ok($zip->set_number('7190301')->is_valid_number, '岡山県浅口郡里庄町里見');
ok($zip->set_number('7190302')->is_valid_number, '岡山県浅口郡里庄町新庄');
ok($zip->set_number('7190303')->is_valid_number, '岡山県浅口郡里庄町浜中');
ok($zip->set_number('7190304')->is_valid_number, '岡山県浅口郡里庄町新庄グリーンクレスト');
ok($zip->set_number('7191100')->is_valid_number, '岡山県総社市以下に掲載がない場合');
ok($zip->set_number('7191101')->is_valid_number, '岡山県総社市奥坂');
ok($zip->set_number('7191102')->is_valid_number, '岡山県総社市東阿曽');
ok($zip->set_number('7191103')->is_valid_number, '岡山県総社市西阿曽');
ok($zip->set_number('7191104')->is_valid_number, '岡山県総社市久米');
ok($zip->set_number('7191105')->is_valid_number, '岡山県総社市黒尾');
ok($zip->set_number('7191106')->is_valid_number, '岡山県総社市泉');
ok($zip->set_number('7191111')->is_valid_number, '岡山県総社市長良');
ok($zip->set_number('7191112')->is_valid_number, '岡山県総社市窪木');
ok($zip->set_number('7191113')->is_valid_number, '岡山県総社市南溝手');
ok($zip->set_number('7191114')->is_valid_number, '岡山県総社市金井戸');
ok($zip->set_number('7191115')->is_valid_number, '岡山県総社市福井');
ok($zip->set_number('7191116')->is_valid_number, '岡山県総社市刑部');
ok($zip->set_number('7191117')->is_valid_number, '岡山県総社市北溝手');
ok($zip->set_number('7191121')->is_valid_number, '岡山県総社市赤浜');
ok($zip->set_number('7191122')->is_valid_number, '岡山県総社市下林');
ok($zip->set_number('7191123')->is_valid_number, '岡山県総社市上林');
ok($zip->set_number('7191124')->is_valid_number, '岡山県総社市三須');
ok($zip->set_number('7191125')->is_valid_number, '岡山県総社市井手');
ok($zip->set_number('7191126')->is_valid_number, '岡山県総社市総社');
ok($zip->set_number('7191131')->is_valid_number, '岡山県総社市中央');
ok($zip->set_number('7191132')->is_valid_number, '岡山県総社市三輪');
ok($zip->set_number('7191133')->is_valid_number, '岡山県総社市中原');
ok($zip->set_number('7191134')->is_valid_number, '岡山県総社市真壁');
ok($zip->set_number('7191135')->is_valid_number, '岡山県総社市溝口');
ok($zip->set_number('7191136')->is_valid_number, '岡山県総社市駅前');
ok($zip->set_number('7191137')->is_valid_number, '岡山県総社市駅南');
ok($zip->set_number('7191141')->is_valid_number, '岡山県総社市福谷');
ok($zip->set_number('7191142')->is_valid_number, '岡山県総社市秦');
ok($zip->set_number('7191143')->is_valid_number, '岡山県総社市上原');
ok($zip->set_number('7191144')->is_valid_number, '岡山県総社市富原');
ok($zip->set_number('7191145')->is_valid_number, '岡山県総社市下原');
ok($zip->set_number('7191146')->is_valid_number, '岡山県総社市八代');
ok($zip->set_number('7191151')->is_valid_number, '岡山県総社市槇谷');
ok($zip->set_number('7191152')->is_valid_number, '岡山県総社市見延');
ok($zip->set_number('7191153')->is_valid_number, '岡山県総社市宍粟');
ok($zip->set_number('7191154')->is_valid_number, '岡山県総社市井尻野');
ok($zip->set_number('7191155')->is_valid_number, '岡山県総社市小寺');
ok($zip->set_number('7191156')->is_valid_number, '岡山県総社市門田');
ok($zip->set_number('7191161')->is_valid_number, '岡山県総社市宿');
ok($zip->set_number('7191162')->is_valid_number, '岡山県総社市岡谷');
ok($zip->set_number('7191163')->is_valid_number, '岡山県総社市地頭片山');
ok($zip->set_number('7191164')->is_valid_number, '岡山県総社市西郡');
ok($zip->set_number('7191165')->is_valid_number, '岡山県総社市西坂台');
ok($zip->set_number('7191171')->is_valid_number, '岡山県総社市清音三因');
ok($zip->set_number('7191172')->is_valid_number, '岡山県総社市清音軽部');
ok($zip->set_number('7191173')->is_valid_number, '岡山県総社市清音黒田');
ok($zip->set_number('7191174')->is_valid_number, '岡山県総社市清音古地');
ok($zip->set_number('7191175')->is_valid_number, '岡山県総社市清音上中島');
ok($zip->set_number('7191176')->is_valid_number, '岡山県総社市清音柿木');
ok($zip->set_number('7191311')->is_valid_number, '岡山県総社市美袋');
ok($zip->set_number('7191312')->is_valid_number, '岡山県総社市種井');
ok($zip->set_number('7191313')->is_valid_number, '岡山県総社市槁');
ok($zip->set_number('7191314')->is_valid_number, '岡山県総社市延原');
ok($zip->set_number('7191315')->is_valid_number, '岡山県総社市宇山');
ok($zip->set_number('7191316')->is_valid_number, '岡山県総社市日羽');
ok($zip->set_number('7191321')->is_valid_number, '岡山県総社市下倉');
ok($zip->set_number('7191322')->is_valid_number, '岡山県総社市影');
ok($zip->set_number('7191323')->is_valid_number, '岡山県総社市中尾');
ok($zip->set_number('7191324')->is_valid_number, '岡山県総社市原');
ok($zip->set_number('7192121')->is_valid_number, '岡山県高梁市川面町');
ok($zip->set_number('7192122')->is_valid_number, '岡山県高梁市高倉町田井');
ok($zip->set_number('7192123')->is_valid_number, '岡山県高梁市高倉町飯部');
ok($zip->set_number('7192231')->is_valid_number, '岡山県高梁市宇治町遠原');
ok($zip->set_number('7192232')->is_valid_number, '岡山県高梁市宇治町宇治');
ok($zip->set_number('7192233')->is_valid_number, '岡山県高梁市宇治町穴田');
ok($zip->set_number('7192234')->is_valid_number, '岡山県高梁市宇治町本郷');
ok($zip->set_number('7192341')->is_valid_number, '岡山県高梁市成羽町吹屋');
ok($zip->set_number('7192342')->is_valid_number, '岡山県高梁市成羽町中野');
ok($zip->set_number('7192343')->is_valid_number, '岡山県高梁市成羽町坂本');
ok($zip->set_number('7192401')->is_valid_number, '岡山県高梁市中井町津々');
ok($zip->set_number('7192402')->is_valid_number, '岡山県高梁市中井町西方');
ok($zip->set_number('7192551')->is_valid_number, '岡山県新見市井倉');
ok($zip->set_number('7192552')->is_valid_number, '岡山県新見市法曽');
ok($zip->set_number('7192641')->is_valid_number, '岡山県新見市草間(その他)');
ok($zip->set_number('7192642')->is_valid_number, '岡山県新見市足見');
ok($zip->set_number('7192643')->is_valid_number, '岡山県新見市土橋(その他)');
ok($zip->set_number('7192721')->is_valid_number, '岡山県新見市豊永赤馬');
ok($zip->set_number('7192722')->is_valid_number, '岡山県新見市豊永佐伏');
ok($zip->set_number('7192723')->is_valid_number, '岡山県新見市豊永宇山');
ok($zip->set_number('7192731')->is_valid_number, '岡山県新見市土橋(落方、寺内)');
ok($zip->set_number('7192732')->is_valid_number, '岡山県新見市草間(下湯川、横畑)');
ok($zip->set_number('7192801')->is_valid_number, '岡山県新見市神郷釜村');
ok($zip->set_number('7192802')->is_valid_number, '岡山県新見市神郷高瀬');
ok($zip->set_number('7193100')->is_valid_number, '岡山県真庭市以下に掲載がない場合');
ok($zip->set_number('7193101')->is_valid_number, '岡山県真庭市赤野');
ok($zip->set_number('7193102')->is_valid_number, '岡山県真庭市大庭');
ok($zip->set_number('7193103')->is_valid_number, '岡山県真庭市古見');
ok($zip->set_number('7193104')->is_valid_number, '岡山県真庭市田原');
ok($zip->set_number('7193105')->is_valid_number, '岡山県真庭市西原');
ok($zip->set_number('7193106')->is_valid_number, '岡山県真庭市野川');
ok($zip->set_number('7193107')->is_valid_number, '岡山県真庭市平松');
ok($zip->set_number('7193111')->is_valid_number, '岡山県真庭市開田');
ok($zip->set_number('7193112')->is_valid_number, '岡山県真庭市影');
ok($zip->set_number('7193113')->is_valid_number, '岡山県真庭市杉山');
ok($zip->set_number('7193114')->is_valid_number, '岡山県真庭市高屋');
ok($zip->set_number('7193115')->is_valid_number, '岡山県真庭市中');
ok($zip->set_number('7193116')->is_valid_number, '岡山県真庭市日名');
ok($zip->set_number('7193117')->is_valid_number, '岡山県真庭市福田');
ok($zip->set_number('7193121')->is_valid_number, '岡山県真庭市上河内');
ok($zip->set_number('7193122')->is_valid_number, '岡山県真庭市下河内');
ok($zip->set_number('7193123')->is_valid_number, '岡山県真庭市下見');
ok($zip->set_number('7193124')->is_valid_number, '岡山県真庭市中河内');
ok($zip->set_number('7193125')->is_valid_number, '岡山県真庭市法界寺');
ok($zip->set_number('7193126')->is_valid_number, '岡山県真庭市向津矢');
ok($zip->set_number('7193131')->is_valid_number, '岡山県真庭市上山');
ok($zip->set_number('7193132')->is_valid_number, '岡山県真庭市田原山上');
ok($zip->set_number('7193133')->is_valid_number, '岡山県真庭市旦土');
ok($zip->set_number('7193134')->is_valid_number, '岡山県真庭市野原');
ok($zip->set_number('7193135')->is_valid_number, '岡山県真庭市舞高');
ok($zip->set_number('7193136')->is_valid_number, '岡山県真庭市吉');
ok($zip->set_number('7193141')->is_valid_number, '岡山県真庭市上市瀬');
ok($zip->set_number('7193142')->is_valid_number, '岡山県真庭市木山');
ok($zip->set_number('7193143')->is_valid_number, '岡山県真庭市下市瀬');
ok($zip->set_number('7193144')->is_valid_number, '岡山県真庭市落合垂水');
ok($zip->set_number('7193145')->is_valid_number, '岡山県真庭市西河内');
ok($zip->set_number('7193146')->is_valid_number, '岡山県真庭市日野上');
ok($zip->set_number('7193151')->is_valid_number, '岡山県真庭市一色');
ok($zip->set_number('7193152')->is_valid_number, '岡山県真庭市鹿田');
ok($zip->set_number('7193153')->is_valid_number, '岡山県真庭市栗原');
ok($zip->set_number('7193154')->is_valid_number, '岡山県真庭市佐引');
ok($zip->set_number('7193155')->is_valid_number, '岡山県真庭市下方');
ok($zip->set_number('7193156')->is_valid_number, '岡山県真庭市関');
ok($zip->set_number('7193157')->is_valid_number, '岡山県真庭市別所');
ok($zip->set_number('7193201')->is_valid_number, '岡山県真庭市久世');
ok($zip->set_number('7193202')->is_valid_number, '岡山県真庭市中島');
ok($zip->set_number('7193203')->is_valid_number, '岡山県真庭市富尾');
ok($zip->set_number('7193204')->is_valid_number, '岡山県真庭市惣');
ok($zip->set_number('7193205')->is_valid_number, '岡山県真庭市草加部');
ok($zip->set_number('7193206')->is_valid_number, '岡山県真庭市神');
ok($zip->set_number('7193211')->is_valid_number, '岡山県真庭市樫西');
ok($zip->set_number('7193212')->is_valid_number, '岡山県真庭市三阪');
ok($zip->set_number('7193213')->is_valid_number, '岡山県真庭市多田');
ok($zip->set_number('7193214')->is_valid_number, '岡山県真庭市鍋屋');
ok($zip->set_number('7193221')->is_valid_number, '岡山県真庭市余野上');
ok($zip->set_number('7193222')->is_valid_number, '岡山県真庭市余野下');
ok($zip->set_number('7193223')->is_valid_number, '岡山県真庭市樫東');
ok($zip->set_number('7193224')->is_valid_number, '岡山県真庭市目木');
ok($zip->set_number('7193225')->is_valid_number, '岡山県真庭市中原');
ok($zip->set_number('7193226')->is_valid_number, '岡山県真庭市三崎');
ok($zip->set_number('7193227')->is_valid_number, '岡山県真庭市台金屋');
ok($zip->set_number('7193228')->is_valid_number, '岡山県真庭市五反');
ok($zip->set_number('7193501')->is_valid_number, '岡山県新見市大佐大井野');
ok($zip->set_number('7193502')->is_valid_number, '岡山県新見市大佐上刑部');
ok($zip->set_number('7193503')->is_valid_number, '岡山県新見市大佐小阪部');
ok($zip->set_number('7193504')->is_valid_number, '岡山県新見市大佐永富');
ok($zip->set_number('7193505')->is_valid_number, '岡山県新見市大佐布瀬');
ok($zip->set_number('7193506')->is_valid_number, '岡山県新見市大佐田治部');
ok($zip->set_number('7193507')->is_valid_number, '岡山県新見市大佐小南');
ok($zip->set_number('7193611')->is_valid_number, '岡山県新見市神郷下神代');
ok($zip->set_number('7193612')->is_valid_number, '岡山県新見市神郷油野');
ok($zip->set_number('7193701')->is_valid_number, '岡山県新見市哲西町矢田');
ok($zip->set_number('7193702')->is_valid_number, '岡山県新見市哲西町上神代');
ok($zip->set_number('7193811')->is_valid_number, '岡山県新見市哲西町大竹');
ok($zip->set_number('7193812')->is_valid_number, '岡山県新見市哲西町畑木');
ok($zip->set_number('7193813')->is_valid_number, '岡山県新見市哲西町八鳥');
ok($zip->set_number('7193814')->is_valid_number, '岡山県新見市哲西町大野部');
ok($zip->set_number('7200001')->is_valid_number, '広島県福山市御幸町上岩成');
ok($zip->set_number('7200002')->is_valid_number, '広島県福山市御幸町下岩成');
ok($zip->set_number('7200003')->is_valid_number, '広島県福山市御幸町森脇');
ok($zip->set_number('7200004')->is_valid_number, '広島県福山市御幸町中津原');
ok($zip->set_number('7200011')->is_valid_number, '広島県福山市横尾町');
ok($zip->set_number('7200013')->is_valid_number, '広島県福山市千田町千田');
ok($zip->set_number('7200014')->is_valid_number, '広島県福山市千田町薮路');
ok($zip->set_number('7200015')->is_valid_number, '広島県福山市千田町坂田');
ok($zip->set_number('7200016')->is_valid_number, '広島県福山市千田町坂田北');
ok($zip->set_number('7200017')->is_valid_number, '広島県福山市千田町');
ok($zip->set_number('7200021')->is_valid_number, '広島県福山市緑陽町');
ok($zip->set_number('7200022')->is_valid_number, '広島県福山市奈良津町');
ok($zip->set_number('7200023')->is_valid_number, '広島県福山市北美台');
ok($zip->set_number('7200024')->is_valid_number, '広島県福山市高美台');
ok($zip->set_number('7200025')->is_valid_number, '広島県福山市清水ケ丘');
ok($zip->set_number('7200031')->is_valid_number, '広島県福山市三吉町');
ok($zip->set_number('7200032')->is_valid_number, '広島県福山市三吉町南');
ok($zip->set_number('7200033')->is_valid_number, '広島県福山市旭町');
ok($zip->set_number('7200034')->is_valid_number, '広島県福山市若松町');
ok($zip->set_number('7200041')->is_valid_number, '広島県福山市寺町');
ok($zip->set_number('7200042')->is_valid_number, '広島県福山市御船町');
ok($zip->set_number('7200043')->is_valid_number, '広島県福山市船町');
ok($zip->set_number('7200044')->is_valid_number, '広島県福山市笠岡町');
ok($zip->set_number('7200045')->is_valid_number, '広島県福山市宝町');
ok($zip->set_number('7200046')->is_valid_number, '広島県福山市今町');
ok($zip->set_number('7200051')->is_valid_number, '広島県福山市桜馬場町');
ok($zip->set_number('7200052')->is_valid_number, '広島県福山市東町');
ok($zip->set_number('7200053')->is_valid_number, '広島県福山市大黒町');
ok($zip->set_number('7200054')->is_valid_number, '広島県福山市城見町');
ok($zip->set_number('7200055')->is_valid_number, '広島県福山市胡町');
ok($zip->set_number('7200056')->is_valid_number, '広島県福山市本町');
ok($zip->set_number('7200061')->is_valid_number, '広島県福山市丸之内');
ok($zip->set_number('7200062')->is_valid_number, '広島県福山市伏見町');
ok($zip->set_number('7200063')->is_valid_number, '広島県福山市元町');
ok($zip->set_number('7200064')->is_valid_number, '広島県福山市延広町');
ok($zip->set_number('7200065')->is_valid_number, '広島県福山市東桜町');
ok($zip->set_number('7200066')->is_valid_number, '広島県福山市三之丸町');
ok($zip->set_number('7200067')->is_valid_number, '広島県福山市西町');
ok($zip->set_number('7200071')->is_valid_number, '広島県福山市東吉津町');
ok($zip->set_number('7200072')->is_valid_number, '広島県福山市吉津町');
ok($zip->set_number('7200073')->is_valid_number, '広島県福山市北吉津町');
ok($zip->set_number('7200074')->is_valid_number, '広島県福山市北本庄');
ok($zip->set_number('7200075')->is_valid_number, '広島県福山市長者町');
ok($zip->set_number('7200076')->is_valid_number, '広島県福山市本庄町中');
ok($zip->set_number('7200077')->is_valid_number, '広島県福山市南本庄');
ok($zip->set_number('7200081')->is_valid_number, '広島県福山市向陽町');
ok($zip->set_number('7200082')->is_valid_number, '広島県福山市木之庄町');
ok($zip->set_number('7200083')->is_valid_number, '広島県福山市久松台');
ok($zip->set_number('7200091')->is_valid_number, '広島県福山市神島町');
ok($zip->set_number('7200092')->is_valid_number, '広島県福山市山手町');
ok($zip->set_number('7200093')->is_valid_number, '広島県福山市郷分町');
ok($zip->set_number('7200201')->is_valid_number, '広島県福山市鞆町鞆');
ok($zip->set_number('7200202')->is_valid_number, '広島県福山市鞆町後地');
ok($zip->set_number('7200203')->is_valid_number, '広島県福山市田尻町');
ok($zip->set_number('7200204')->is_valid_number, '広島県福山市走島町');
ok($zip->set_number('7200311')->is_valid_number, '広島県福山市沼隈町草深');
ok($zip->set_number('7200312')->is_valid_number, '広島県福山市沼隈町能登原');
ok($zip->set_number('7200313')->is_valid_number, '広島県福山市沼隈町常石');
ok($zip->set_number('7200401')->is_valid_number, '広島県福山市沼隈町上山南');
ok($zip->set_number('7200402')->is_valid_number, '広島県福山市沼隈町中山南');
ok($zip->set_number('7200403')->is_valid_number, '広島県福山市沼隈町下山南');
ok($zip->set_number('7200411')->is_valid_number, '広島県福山市熊野町');
ok($zip->set_number('7200541')->is_valid_number, '広島県福山市金江町金見');
ok($zip->set_number('7200542')->is_valid_number, '広島県福山市金江町藁江');
ok($zip->set_number('7200543')->is_valid_number, '広島県福山市藤江町');
ok($zip->set_number('7200551')->is_valid_number, '広島県尾道市浦崎町');
ok($zip->set_number('7200801')->is_valid_number, '広島県福山市入船町');
ok($zip->set_number('7200802')->is_valid_number, '広島県福山市松浜町');
ok($zip->set_number('7200803')->is_valid_number, '広島県福山市花園町');
ok($zip->set_number('7200804')->is_valid_number, '広島県福山市緑町');
ok($zip->set_number('7200805')->is_valid_number, '広島県福山市御門町');
ok($zip->set_number('7200806')->is_valid_number, '広島県福山市南町');
ok($zip->set_number('7200807')->is_valid_number, '広島県福山市明治町');
ok($zip->set_number('7200808')->is_valid_number, '広島県福山市昭和町');
ok($zip->set_number('7200809')->is_valid_number, '広島県福山市住吉町');
ok($zip->set_number('7200811')->is_valid_number, '広島県福山市紅葉町');
ok($zip->set_number('7200812')->is_valid_number, '広島県福山市霞町');
ok($zip->set_number('7200813')->is_valid_number, '広島県福山市道三町');
ok($zip->set_number('7200814')->is_valid_number, '広島県福山市光南町');
ok($zip->set_number('7200815')->is_valid_number, '広島県福山市野上町');
ok($zip->set_number('7200816')->is_valid_number, '広島県福山市地吹町');
ok($zip->set_number('7200817')->is_valid_number, '広島県福山市古野上町');
ok($zip->set_number('7200818')->is_valid_number, '広島県福山市西桜町');
ok($zip->set_number('7200821')->is_valid_number, '広島県福山市東川口町');
ok($zip->set_number('7200822')->is_valid_number, '広島県福山市川口町');
ok($zip->set_number('7200823')->is_valid_number, '広島県福山市千代田町');
ok($zip->set_number('7200824')->is_valid_number, '広島県福山市多治米町');
ok($zip->set_number('7200825')->is_valid_number, '広島県福山市沖野上町');
ok($zip->set_number('7200830')->is_valid_number, '広島県福山市水呑町三新田');
ok($zip->set_number('7200831')->is_valid_number, '広島県福山市草戸町');
ok($zip->set_number('7200832')->is_valid_number, '広島県福山市水呑町');
ok($zip->set_number('7200833')->is_valid_number, '広島県福山市水呑向丘');
ok($zip->set_number('7200834')->is_valid_number, '広島県福山市明王台');
ok($zip->set_number('7200835')->is_valid_number, '広島県福山市佐波町');
ok($zip->set_number('7200836')->is_valid_number, '広島県福山市瀬戸町長和');
ok($zip->set_number('7200837')->is_valid_number, '広島県福山市瀬戸町地頭分');
ok($zip->set_number('7200838')->is_valid_number, '広島県福山市瀬戸町山北');
ok($zip->set_number('7200839')->is_valid_number, '広島県福山市東明王台');
ok($zip->set_number('7200841')->is_valid_number, '広島県福山市津之郷町津之郷');
ok($zip->set_number('7200842')->is_valid_number, '広島県福山市津之郷町加屋');
ok($zip->set_number('7200843')->is_valid_number, '広島県福山市赤坂町赤坂');
ok($zip->set_number('7200844')->is_valid_number, '広島県福山市赤坂町早戸');
ok($zip->set_number('7200845')->is_valid_number, '広島県福山市芦田町福田(376-10「聖宝寺」)');
ok($zip->set_number('7201131')->is_valid_number, '広島県福山市駅家町万能倉');
ok($zip->set_number('7201132')->is_valid_number, '広島県福山市駅家町倉光');
ok($zip->set_number('7201133')->is_valid_number, '広島県福山市駅家町近田');
ok($zip->set_number('7201134')->is_valid_number, '広島県福山市駅家町中島');
ok($zip->set_number('7201135')->is_valid_number, '広島県福山市駅家町弥生ケ丘');
ok($zip->set_number('7201141')->is_valid_number, '広島県福山市駅家町江良');
ok($zip->set_number('7201142')->is_valid_number, '広島県福山市駅家町上山守');
ok($zip->set_number('7201143')->is_valid_number, '広島県福山市駅家町下山守');
ok($zip->set_number('7201144')->is_valid_number, '広島県福山市駅家町坊寺');
ok($zip->set_number('7201145')->is_valid_number, '広島県福山市駅家町今岡');
ok($zip->set_number('7201146')->is_valid_number, '広島県福山市駅家町大橋');
ok($zip->set_number('7201147')->is_valid_number, '広島県福山市駅家町向永谷');
ok($zip->set_number('7201261')->is_valid_number, '広島県福山市芦田町上有地');
ok($zip->set_number('7201262')->is_valid_number, '広島県福山市芦田町下有地');
ok($zip->set_number('7201263')->is_valid_number, '広島県福山市芦田町柞磨');
ok($zip->set_number('7201264')->is_valid_number, '広島県福山市芦田町福田(376-10を除く)');
ok($zip->set_number('7201265')->is_valid_number, '広島県福山市芦田町向陽台');
ok($zip->set_number('7201410')->is_valid_number, '広島県神石郡神石高原町高蓋');
ok($zip->set_number('7201411')->is_valid_number, '広島県神石郡神石高原町光信');
ok($zip->set_number('7201412')->is_valid_number, '広島県神石郡神石高原町光末');
ok($zip->set_number('7201413')->is_valid_number, '広島県神石郡神石高原町父木野');
ok($zip->set_number('7201414')->is_valid_number, '広島県神石郡神石高原町桑木');
ok($zip->set_number('7201415')->is_valid_number, '広島県神石郡神石高原町階見');
ok($zip->set_number('7201416')->is_valid_number, '広島県神石郡神石高原町木津和');
ok($zip->set_number('7201521')->is_valid_number, '広島県神石郡神石高原町阿下');
ok($zip->set_number('7201522')->is_valid_number, '広島県神石郡神石高原町小畠');
ok($zip->set_number('7201523')->is_valid_number, '広島県神石郡神石高原町亀石');
ok($zip->set_number('7201524')->is_valid_number, '広島県神石郡神石高原町常光');
ok($zip->set_number('7201525')->is_valid_number, '広島県神石郡神石高原町上');
ok($zip->set_number('7201601')->is_valid_number, '広島県神石郡神石高原町大矢');
ok($zip->set_number('7201602')->is_valid_number, '広島県神石郡神石高原町井関');
ok($zip->set_number('7201603')->is_valid_number, '広島県神石郡神石高原町時安');
ok($zip->set_number('7201604')->is_valid_number, '広島県神石郡神石高原町坂瀬川');
ok($zip->set_number('7201621')->is_valid_number, '広島県神石郡神石高原町李');
ok($zip->set_number('7201622')->is_valid_number, '広島県神石郡神石高原町近田');
ok($zip->set_number('7201623')->is_valid_number, '広島県神石郡神石高原町花済');
ok($zip->set_number('7201624')->is_valid_number, '広島県神石郡神石高原町上野');
ok($zip->set_number('7201701')->is_valid_number, '広島県神石郡神石高原町有木');
ok($zip->set_number('7201702')->is_valid_number, '広島県神石郡神石高原町上豊松');
ok($zip->set_number('7201703')->is_valid_number, '広島県神石郡神石高原町笹尾');
ok($zip->set_number('7201704')->is_valid_number, '広島県神石郡神石高原町下豊松');
ok($zip->set_number('7201705')->is_valid_number, '広島県神石郡神石高原町中平');
ok($zip->set_number('7201800')->is_valid_number, '広島県神石郡神石高原町以下に掲載がない場合');
ok($zip->set_number('7201811')->is_valid_number, '広島県神石郡神石高原町安田');
ok($zip->set_number('7201812')->is_valid_number, '広島県神石郡神石高原町油木');
ok($zip->set_number('7201901')->is_valid_number, '広島県神石郡神石高原町小野');
ok($zip->set_number('7201902')->is_valid_number, '広島県神石郡神石高原町新免');
ok($zip->set_number('7202101')->is_valid_number, '広島県福山市神辺町三谷');
ok($zip->set_number('7202102')->is_valid_number, '広島県福山市神辺町東中条');
ok($zip->set_number('7202103')->is_valid_number, '広島県福山市神辺町西中条');
ok($zip->set_number('7202104')->is_valid_number, '広島県福山市神辺町道上');
ok($zip->set_number('7202105')->is_valid_number, '広島県福山市神辺町十三軒屋');
ok($zip->set_number('7202106')->is_valid_number, '広島県福山市神辺町十九軒屋');
ok($zip->set_number('7202107')->is_valid_number, '広島県福山市神辺町新道上');
ok($zip->set_number('7202108')->is_valid_number, '広島県福山市神辺町新十九');
ok($zip->set_number('7202111')->is_valid_number, '広島県福山市神辺町上御領');
ok($zip->set_number('7202112')->is_valid_number, '広島県福山市神辺町八尋');
ok($zip->set_number('7202113')->is_valid_number, '広島県福山市神辺町旭丘');
ok($zip->set_number('7202114')->is_valid_number, '広島県福山市神辺町上竹田');
ok($zip->set_number('7202115')->is_valid_number, '広島県福山市神辺町下竹田');
ok($zip->set_number('7202116')->is_valid_number, '広島県福山市神辺町平野');
ok($zip->set_number('7202117')->is_valid_number, '広島県福山市神辺町下御領');
ok($zip->set_number('7202121')->is_valid_number, '広島県福山市神辺町湯野');
ok($zip->set_number('7202122')->is_valid_number, '広島県福山市神辺町新湯野');
ok($zip->set_number('7202123')->is_valid_number, '広島県福山市神辺町川北');
ok($zip->set_number('7202124')->is_valid_number, '広島県福山市神辺町川南');
ok($zip->set_number('7202125')->is_valid_number, '広島県福山市神辺町新徳田');
ok($zip->set_number('7202126')->is_valid_number, '広島県福山市神辺町徳田');
ok($zip->set_number('7202127')->is_valid_number, '広島県福山市神辺町箱田');
ok($zip->set_number('7202410')->is_valid_number, '広島県福山市加茂町八軒屋');
ok($zip->set_number('7202411')->is_valid_number, '広島県福山市北匠町');
ok($zip->set_number('7202412')->is_valid_number, '広島県福山市加茂町下加茂');
ok($zip->set_number('7202413')->is_valid_number, '広島県福山市駅家町法成寺');
ok($zip->set_number('7202414')->is_valid_number, '広島県福山市加茂町百谷');
ok($zip->set_number('7202415')->is_valid_number, '広島県福山市加茂町北山');
ok($zip->set_number('7202416')->is_valid_number, '広島県福山市加茂町粟根');
ok($zip->set_number('7202417')->is_valid_number, '広島県福山市加茂町芦原');
ok($zip->set_number('7202418')->is_valid_number, '広島県福山市加茂町中野');
ok($zip->set_number('7202419')->is_valid_number, '広島県福山市加茂町上加茂');
ok($zip->set_number('7202521')->is_valid_number, '広島県福山市駅家町服部本郷');
ok($zip->set_number('7202522')->is_valid_number, '広島県福山市駅家町服部永谷');
ok($zip->set_number('7202523')->is_valid_number, '広島県福山市駅家町新山');
ok($zip->set_number('7202524')->is_valid_number, '広島県福山市駅家町助元');
ok($zip->set_number('7202525')->is_valid_number, '広島県福山市駅家町雨木');
ok($zip->set_number('7202601')->is_valid_number, '広島県福山市山野町矢川');
ok($zip->set_number('7202602')->is_valid_number, '広島県福山市山野町山野');
ok($zip->set_number('7210000')->is_valid_number, '広島県福山市以下に掲載がない場合');
ok($zip->set_number('7210901')->is_valid_number, '広島県福山市春日町宇山');
ok($zip->set_number('7210902')->is_valid_number, '広島県福山市春日町浦上');
ok($zip->set_number('7210903')->is_valid_number, '広島県福山市坪生町');
ok($zip->set_number('7210904')->is_valid_number, '広島県福山市坪生町南');
ok($zip->set_number('7210906')->is_valid_number, '広島県福山市能島');
ok($zip->set_number('7210907')->is_valid_number, '広島県福山市春日町');
ok($zip->set_number('7210908')->is_valid_number, '広島県福山市春日町吉田');
ok($zip->set_number('7210911')->is_valid_number, '広島県福山市青葉台');
ok($zip->set_number('7210912')->is_valid_number, '広島県福山市東陽台');
ok($zip->set_number('7210913')->is_valid_number, '広島県福山市幕山台');
ok($zip->set_number('7210914')->is_valid_number, '広島県福山市大谷台');
ok($zip->set_number('7210915')->is_valid_number, '広島県福山市伊勢丘');
ok($zip->set_number('7210916')->is_valid_number, '広島県福山市春日台');
ok($zip->set_number('7210917')->is_valid_number, '広島県福山市春日池');
ok($zip->set_number('7210921')->is_valid_number, '広島県福山市大門町大門');
ok($zip->set_number('7210922')->is_valid_number, '広島県福山市大門町日之出丘');
ok($zip->set_number('7210923')->is_valid_number, '広島県福山市大門町野々浜');
ok($zip->set_number('7210924')->is_valid_number, '広島県福山市大門町旭');
ok($zip->set_number('7210925')->is_valid_number, '広島県福山市大門町坂里');
ok($zip->set_number('7210926')->is_valid_number, '広島県福山市大門町');
ok($zip->set_number('7210927')->is_valid_number, '広島県福山市大門町津之下');
ok($zip->set_number('7210929')->is_valid_number, '広島県福山市城興ケ丘');
ok($zip->set_number('7210931')->is_valid_number, '広島県福山市鋼管町');
ok($zip->set_number('7210941')->is_valid_number, '広島県福山市引野町北');
ok($zip->set_number('7210942')->is_valid_number, '広島県福山市引野町');
ok($zip->set_number('7210943')->is_valid_number, '広島県福山市平成台');
ok($zip->set_number('7210944')->is_valid_number, '広島県福山市引野町東');
ok($zip->set_number('7210945')->is_valid_number, '広島県福山市引野町南');
ok($zip->set_number('7210951')->is_valid_number, '広島県福山市新浜町');
ok($zip->set_number('7210952')->is_valid_number, '広島県福山市曙町');
ok($zip->set_number('7210953')->is_valid_number, '広島県福山市一文字町');
ok($zip->set_number('7210954')->is_valid_number, '広島県福山市卸町');
ok($zip->set_number('7210955')->is_valid_number, '広島県福山市新涯町');
ok($zip->set_number('7210956')->is_valid_number, '広島県福山市箕沖町');
ok($zip->set_number('7210957')->is_valid_number, '広島県福山市箕島町');
ok($zip->set_number('7210958')->is_valid_number, '広島県福山市西新涯町');
ok($zip->set_number('7210961')->is_valid_number, '広島県福山市明神町');
ok($zip->set_number('7210962')->is_valid_number, '広島県福山市東手城町');
ok($zip->set_number('7210963')->is_valid_number, '広島県福山市南手城町');
ok($zip->set_number('7210964')->is_valid_number, '広島県福山市港町');
ok($zip->set_number('7210965')->is_valid_number, '広島県福山市王子町');
ok($zip->set_number('7210966')->is_valid_number, '広島県福山市手城町');
ok($zip->set_number('7210971')->is_valid_number, '広島県福山市蔵王町');
ok($zip->set_number('7210972')->is_valid_number, '広島県福山市日吉台');
ok($zip->set_number('7210973')->is_valid_number, '広島県福山市南蔵王町');
ok($zip->set_number('7210974')->is_valid_number, '広島県福山市東深津町');
ok($zip->set_number('7210975')->is_valid_number, '広島県福山市西深津町');
ok($zip->set_number('7220000')->is_valid_number, '広島県尾道市以下に掲載がない場合');
ok($zip->set_number('7220001')->is_valid_number, '広島県尾道市手崎町');
ok($zip->set_number('7220002')->is_valid_number, '広島県尾道市古浜町');
ok($zip->set_number('7220003')->is_valid_number, '広島県尾道市東元町');
ok($zip->set_number('7220004')->is_valid_number, '広島県尾道市正徳町');
ok($zip->set_number('7220005')->is_valid_number, '広島県尾道市福地町');
ok($zip->set_number('7220006')->is_valid_number, '広島県尾道市沖側町');
ok($zip->set_number('7220007')->is_valid_number, '広島県尾道市吉和西元町');
ok($zip->set_number('7220008')->is_valid_number, '広島県尾道市吉和町');
ok($zip->set_number('7220011')->is_valid_number, '広島県尾道市桜町');
ok($zip->set_number('7220012')->is_valid_number, '広島県尾道市潮見町');
ok($zip->set_number('7220013')->is_valid_number, '広島県尾道市日比崎町');
ok($zip->set_number('7220014')->is_valid_number, '広島県尾道市新浜');
ok($zip->set_number('7220015')->is_valid_number, '広島県尾道市吉浦町');
ok($zip->set_number('7220016')->is_valid_number, '広島県尾道市神田町');
ok($zip->set_number('7220017')->is_valid_number, '広島県尾道市門田町');
ok($zip->set_number('7220018')->is_valid_number, '広島県尾道市平原');
ok($zip->set_number('7220021')->is_valid_number, '広島県尾道市久山田町');
ok($zip->set_number('7220022')->is_valid_number, '広島県尾道市栗原町');
ok($zip->set_number('7220023')->is_valid_number, '広島県尾道市東則末町');
ok($zip->set_number('7220024')->is_valid_number, '広島県尾道市西則末町');
ok($zip->set_number('7220025')->is_valid_number, '広島県尾道市栗原東');
ok($zip->set_number('7220026')->is_valid_number, '広島県尾道市栗原西');
ok($zip->set_number('7220031')->is_valid_number, '広島県尾道市三軒家町');
ok($zip->set_number('7220032')->is_valid_number, '広島県尾道市西土堂町');
ok($zip->set_number('7220033')->is_valid_number, '広島県尾道市東土堂町');
ok($zip->set_number('7220034')->is_valid_number, '広島県尾道市十四日元町');
ok($zip->set_number('7220035')->is_valid_number, '広島県尾道市土堂');
ok($zip->set_number('7220036')->is_valid_number, '広島県尾道市東御所町');
ok($zip->set_number('7220037')->is_valid_number, '広島県尾道市西御所町');
ok($zip->set_number('7220038')->is_valid_number, '広島県尾道市天満町');
ok($zip->set_number('7220041')->is_valid_number, '広島県尾道市防地町');
ok($zip->set_number('7220042')->is_valid_number, '広島県尾道市久保町');
ok($zip->set_number('7220043')->is_valid_number, '広島県尾道市東久保町');
ok($zip->set_number('7220044')->is_valid_number, '広島県尾道市西久保町');
ok($zip->set_number('7220045')->is_valid_number, '広島県尾道市久保');
ok($zip->set_number('7220046')->is_valid_number, '広島県尾道市長江');
ok($zip->set_number('7220047')->is_valid_number, '広島県尾道市十四日町');
ok($zip->set_number('7220051')->is_valid_number, '広島県尾道市東尾道');
ok($zip->set_number('7220052')->is_valid_number, '広島県尾道市山波町');
ok($zip->set_number('7220053')->is_valid_number, '広島県尾道市尾崎町');
ok($zip->set_number('7220054')->is_valid_number, '広島県尾道市尾崎本町');
ok($zip->set_number('7220055')->is_valid_number, '広島県尾道市新高山');
ok($zip->set_number('7220061')->is_valid_number, '広島県尾道市百島町');
ok($zip->set_number('7220062')->is_valid_number, '広島県尾道市向東町');
ok($zip->set_number('7220071')->is_valid_number, '広島県尾道市向島町立花');
ok($zip->set_number('7220072')->is_valid_number, '広島県尾道市向島町岩子島');
ok($zip->set_number('7220073')->is_valid_number, '広島県尾道市向島町');
ok($zip->set_number('7220201')->is_valid_number, '広島県尾道市原田町小原');
ok($zip->set_number('7220202')->is_valid_number, '広島県尾道市原田町梶山田');
ok($zip->set_number('7220211')->is_valid_number, '広島県尾道市美ノ郷町中野');
ok($zip->set_number('7220212')->is_valid_number, '広島県尾道市美ノ郷町本郷');
ok($zip->set_number('7220213')->is_valid_number, '広島県尾道市美ノ郷町白江');
ok($zip->set_number('7220214')->is_valid_number, '広島県尾道市美ノ郷町猪子迫');
ok($zip->set_number('7220215')->is_valid_number, '広島県尾道市美ノ郷町三成');
ok($zip->set_number('7220221')->is_valid_number, '広島県尾道市長者原');
ok($zip->set_number('7220231')->is_valid_number, '広島県尾道市木ノ庄町畑');
ok($zip->set_number('7220232')->is_valid_number, '広島県尾道市木ノ庄町木門田');
ok($zip->set_number('7220233')->is_valid_number, '広島県尾道市木ノ庄町市原');
ok($zip->set_number('7220234')->is_valid_number, '広島県尾道市木ノ庄町木梨');
ok($zip->set_number('7220235')->is_valid_number, '広島県尾道市木ノ庄町木梨山方');
ok($zip->set_number('7220311')->is_valid_number, '広島県尾道市御調町市');
ok($zip->set_number('7220312')->is_valid_number, '広島県尾道市御調町貝ケ原');
ok($zip->set_number('7220313')->is_valid_number, '広島県尾道市御調町平');
ok($zip->set_number('7220314')->is_valid_number, '広島県尾道市御調町大町');
ok($zip->set_number('7220315')->is_valid_number, '広島県尾道市御調町釜窪');
ok($zip->set_number('7220316')->is_valid_number, '広島県尾道市御調町花尻');
ok($zip->set_number('7220321')->is_valid_number, '広島県尾道市御調町本');
ok($zip->set_number('7220322')->is_valid_number, '広島県尾道市御調町三郎丸');
ok($zip->set_number('7220323')->is_valid_number, '広島県尾道市御調町大蔵');
ok($zip->set_number('7220324')->is_valid_number, '広島県尾道市御調町白太');
ok($zip->set_number('7220325')->is_valid_number, '広島県尾道市御調町中原');
ok($zip->set_number('7220326')->is_valid_number, '広島県尾道市御調町岩根');
ok($zip->set_number('7220331')->is_valid_number, '広島県尾道市御調町仁野');
ok($zip->set_number('7220332')->is_valid_number, '広島県尾道市御調町平木');
ok($zip->set_number('7220333')->is_valid_number, '広島県尾道市御調町大塔');
ok($zip->set_number('7220334')->is_valid_number, '広島県尾道市御調町菅');
ok($zip->set_number('7220335')->is_valid_number, '広島県尾道市御調町国守');
ok($zip->set_number('7220336')->is_valid_number, '広島県尾道市御調町江田');
ok($zip->set_number('7220341')->is_valid_number, '広島県尾道市御調町神');
ok($zip->set_number('7220342')->is_valid_number, '広島県尾道市御調町大田');
ok($zip->set_number('7220343')->is_valid_number, '広島県尾道市御調町丸河南');
ok($zip->set_number('7220344')->is_valid_number, '広島県尾道市御調町丸門田');
ok($zip->set_number('7220345')->is_valid_number, '広島県尾道市御調町徳永');
ok($zip->set_number('7220351')->is_valid_number, '広島県尾道市御調町大原');
ok($zip->set_number('7220352')->is_valid_number, '広島県尾道市御調町公文');
ok($zip->set_number('7220353')->is_valid_number, '広島県尾道市御調町高尾');
ok($zip->set_number('7220354')->is_valid_number, '広島県尾道市御調町綾目');
ok($zip->set_number('7220355')->is_valid_number, '広島県尾道市御調町山岡');
ok($zip->set_number('7220401')->is_valid_number, '広島県尾道市御調町千堂');
ok($zip->set_number('7220402')->is_valid_number, '広島県尾道市御調町下山田');
ok($zip->set_number('7220403')->is_valid_number, '広島県尾道市御調町大山田');
ok($zip->set_number('7220411')->is_valid_number, '広島県世羅郡世羅町宇津戸');
ok($zip->set_number('7220431')->is_valid_number, '広島県府中市諸毛町');
ok($zip->set_number('7220432')->is_valid_number, '広島県府中市小国町');
ok($zip->set_number('7221100')->is_valid_number, '広島県世羅郡世羅町以下に掲載がない場合');
ok($zip->set_number('7221111')->is_valid_number, '広島県世羅郡世羅町寺町');
ok($zip->set_number('7221112')->is_valid_number, '広島県世羅郡世羅町本郷');
ok($zip->set_number('7221113')->is_valid_number, '広島県世羅郡世羅町井折');
ok($zip->set_number('7221114')->is_valid_number, '広島県世羅郡世羅町東神崎');
ok($zip->set_number('7221115')->is_valid_number, '広島県世羅郡世羅町西神崎');
ok($zip->set_number('7221116')->is_valid_number, '広島県世羅郡世羅町青山');
ok($zip->set_number('7221117')->is_valid_number, '広島県世羅郡世羅町三郎丸');
ok($zip->set_number('7221121')->is_valid_number, '広島県世羅郡世羅町西上原');
ok($zip->set_number('7221122')->is_valid_number, '広島県世羅郡世羅町小世良');
ok($zip->set_number('7221123')->is_valid_number, '広島県世羅郡世羅町甲山');
ok($zip->set_number('7221201')->is_valid_number, '広島県世羅郡世羅町戸張');
ok($zip->set_number('7221202')->is_valid_number, '広島県世羅郡世羅町安田');
ok($zip->set_number('7221203')->is_valid_number, '広島県世羅郡世羅町徳市');
ok($zip->set_number('7221204')->is_valid_number, '広島県世羅郡世羅町京丸(石川、水の別)');
ok($zip->set_number('7221301')->is_valid_number, '広島県三原市久井町莇原');
ok($zip->set_number('7221302')->is_valid_number, '広島県三原市久井町吉田');
ok($zip->set_number('7221303')->is_valid_number, '広島県三原市久井町下津');
ok($zip->set_number('7221304')->is_valid_number, '広島県三原市久井町江木');
ok($zip->set_number('7221401')->is_valid_number, '広島県三原市本郷町船木(芋堀)');
ok($zip->set_number('7221411')->is_valid_number, '広島県三原市久井町泉');
ok($zip->set_number('7221412')->is_valid_number, '広島県三原市久井町和草');
ok($zip->set_number('7221413')->is_valid_number, '広島県三原市久井町羽倉');
ok($zip->set_number('7221414')->is_valid_number, '広島県三原市久井町坂井原');
ok($zip->set_number('7221415')->is_valid_number, '広島県三原市久井町土取');
ok($zip->set_number('7221416')->is_valid_number, '広島県三原市久井町山中野');
ok($zip->set_number('7221417')->is_valid_number, '広島県三原市久井町小林');
ok($zip->set_number('7221501')->is_valid_number, '広島県三原市八幡町垣内');
ok($zip->set_number('7221511')->is_valid_number, '広島県三原市八幡町篝');
ok($zip->set_number('7221512')->is_valid_number, '広島県三原市八幡町野串');
ok($zip->set_number('7221513')->is_valid_number, '広島県三原市八幡町宮内');
ok($zip->set_number('7221514')->is_valid_number, '広島県三原市八幡町屋中');
ok($zip->set_number('7221515')->is_valid_number, '広島県三原市八幡町美生');
ok($zip->set_number('7221516')->is_valid_number, '広島県三原市八幡町本庄');
ok($zip->set_number('7221561')->is_valid_number, '広島県尾道市御調町福井');
ok($zip->set_number('7221562')->is_valid_number, '広島県尾道市御調町津蟹');
ok($zip->set_number('7221563')->is_valid_number, '広島県尾道市御調町植野');
ok($zip->set_number('7221564')->is_valid_number, '広島県尾道市御調町今田');
ok($zip->set_number('7221565')->is_valid_number, '広島県尾道市御調町野間');
ok($zip->set_number('7221621')->is_valid_number, '広島県世羅郡世羅町京丸(その他)');
ok($zip->set_number('7221622')->is_valid_number, '広島県世羅郡世羅町堀越');
ok($zip->set_number('7221623')->is_valid_number, '広島県世羅郡世羅町中原');
ok($zip->set_number('7221624')->is_valid_number, '広島県世羅郡世羅町田打');
ok($zip->set_number('7221625')->is_valid_number, '広島県世羅郡世羅町重永');
ok($zip->set_number('7221626')->is_valid_number, '広島県世羅郡世羅町賀茂');
ok($zip->set_number('7221627')->is_valid_number, '広島県世羅郡世羅町青水');
ok($zip->set_number('7221701')->is_valid_number, '広島県世羅郡世羅町小国');
ok($zip->set_number('7221702')->is_valid_number, '広島県世羅郡世羅町山中福田');
ok($zip->set_number('7221731')->is_valid_number, '広島県世羅郡世羅町津口');
ok($zip->set_number('7221732')->is_valid_number, '広島県世羅郡世羅町黒渕');
ok($zip->set_number('7222101')->is_valid_number, '広島県尾道市因島大浜町');
ok($zip->set_number('7222102')->is_valid_number, '広島県尾道市因島重井町');
ok($zip->set_number('7222211')->is_valid_number, '広島県尾道市因島中庄町');
ok($zip->set_number('7222212')->is_valid_number, '広島県尾道市因島鏡浦町');
ok($zip->set_number('7222213')->is_valid_number, '広島県尾道市因島外浦町');
ok($zip->set_number('7222321')->is_valid_number, '広島県尾道市因島椋浦町');
ok($zip->set_number('7222322')->is_valid_number, '広島県尾道市因島三庄町');
ok($zip->set_number('7222323')->is_valid_number, '広島県尾道市因島土生町');
ok($zip->set_number('7222324')->is_valid_number, '広島県尾道市因島田熊町');
ok($zip->set_number('7222401')->is_valid_number, '広島県尾道市瀬戸田町御寺');
ok($zip->set_number('7222402')->is_valid_number, '広島県尾道市瀬戸田町宮原');
ok($zip->set_number('7222403')->is_valid_number, '広島県尾道市瀬戸田町荻');
ok($zip->set_number('7222404')->is_valid_number, '広島県尾道市瀬戸田町垂水');
ok($zip->set_number('7222405')->is_valid_number, '広島県尾道市瀬戸田町福田');
ok($zip->set_number('7222411')->is_valid_number, '広島県尾道市瀬戸田町瀬戸田');
ok($zip->set_number('7222412')->is_valid_number, '広島県尾道市瀬戸田町高根');
ok($zip->set_number('7222413')->is_valid_number, '広島県尾道市瀬戸田町沢');
ok($zip->set_number('7222414')->is_valid_number, '広島県尾道市瀬戸田町鹿田原');
ok($zip->set_number('7222415')->is_valid_number, '広島県尾道市瀬戸田町中野');
ok($zip->set_number('7222416')->is_valid_number, '広島県尾道市瀬戸田町林');
ok($zip->set_number('7222417')->is_valid_number, '広島県尾道市瀬戸田町名荷');
ok($zip->set_number('7222431')->is_valid_number, '広島県尾道市因島洲江町');
ok($zip->set_number('7222432')->is_valid_number, '広島県尾道市因島原町');
ok($zip->set_number('7222631')->is_valid_number, '広島県福山市内海町イ');
ok($zip->set_number('7222632')->is_valid_number, '広島県福山市内海町ロ');
ok($zip->set_number('7222633')->is_valid_number, '広島県福山市内海町ハ');
ok($zip->set_number('7222641')->is_valid_number, '広島県福山市内海町');
ok($zip->set_number('7230000')->is_valid_number, '広島県三原市以下に掲載がない場合');
ok($zip->set_number('7230001')->is_valid_number, '広島県三原市深町');
ok($zip->set_number('7230002')->is_valid_number, '広島県三原市中之町南');
ok($zip->set_number('7230003')->is_valid_number, '広島県三原市中之町');
ok($zip->set_number('7230004')->is_valid_number, '広島県三原市館町');
ok($zip->set_number('7230005')->is_valid_number, '広島県三原市桜山町');
ok($zip->set_number('7230006')->is_valid_number, '広島県三原市駒ケ原町');
ok($zip->set_number('7230007')->is_valid_number, '広島県三原市中之町北');
ok($zip->set_number('7230011')->is_valid_number, '広島県三原市東町');
ok($zip->set_number('7230012')->is_valid_number, '広島県三原市旭町');
ok($zip->set_number('7230013')->is_valid_number, '広島県三原市古浜');
ok($zip->set_number('7230014')->is_valid_number, '広島県三原市城町');
ok($zip->set_number('7230015')->is_valid_number, '広島県三原市円一町');
ok($zip->set_number('7230016')->is_valid_number, '広島県三原市宮沖');
ok($zip->set_number('7230017')->is_valid_number, '広島県三原市港町');
ok($zip->set_number('7230021')->is_valid_number, '広島県三原市鷺浦町須波');
ok($zip->set_number('7230022')->is_valid_number, '広島県三原市鷺浦町向田野浦');
ok($zip->set_number('7230031')->is_valid_number, '広島県三原市須波');
ok($zip->set_number('7230031')->is_valid_number, '広島県三原市須波町');
ok($zip->set_number('7230032')->is_valid_number, '広島県三原市須波西');
ok($zip->set_number('7230032')->is_valid_number, '広島県三原市須波西町');
ok($zip->set_number('7230033')->is_valid_number, '広島県三原市沖浦町');
ok($zip->set_number('7230034')->is_valid_number, '広島県三原市登町');
ok($zip->set_number('7230035')->is_valid_number, '広島県三原市須波ハイツ');
ok($zip->set_number('7230041')->is_valid_number, '広島県三原市和田');
ok($zip->set_number('7230042')->is_valid_number, '広島県三原市和田沖町');
ok($zip->set_number('7230043')->is_valid_number, '広島県三原市貝野町');
ok($zip->set_number('7230044')->is_valid_number, '広島県三原市宗郷');
ok($zip->set_number('7230045')->is_valid_number, '広島県三原市田野浦');
ok($zip->set_number('7230046')->is_valid_number, '広島県三原市明神');
ok($zip->set_number('7230047')->is_valid_number, '広島県三原市青葉台');
ok($zip->set_number('7230051')->is_valid_number, '広島県三原市宮浦');
ok($zip->set_number('7230052')->is_valid_number, '広島県三原市皆実');
ok($zip->set_number('7230053')->is_valid_number, '広島県三原市学園町');
ok($zip->set_number('7230054')->is_valid_number, '広島県三原市頼兼');
ok($zip->set_number('7230061')->is_valid_number, '広島県三原市八坂町');
ok($zip->set_number('7230062')->is_valid_number, '広島県三原市本町');
ok($zip->set_number('7230063')->is_valid_number, '広島県三原市西町');
ok($zip->set_number('7230064')->is_valid_number, '広島県三原市西宮');
ok($zip->set_number('7230065')->is_valid_number, '広島県三原市西野');
ok($zip->set_number('7230066')->is_valid_number, '広島県三原市大畑町');
ok($zip->set_number('7230131')->is_valid_number, '広島県三原市小坂町');
ok($zip->set_number('7230132')->is_valid_number, '広島県三原市長谷');
ok($zip->set_number('7230132')->is_valid_number, '広島県三原市長谷町');
ok($zip->set_number('7230133')->is_valid_number, '広島県三原市沼田');
ok($zip->set_number('7230133')->is_valid_number, '広島県三原市沼田町');
ok($zip->set_number('7230134')->is_valid_number, '広島県三原市新倉');
ok($zip->set_number('7230134')->is_valid_number, '広島県三原市新倉町');
ok($zip->set_number('7230141')->is_valid_number, '広島県三原市沼田東町両名');
ok($zip->set_number('7230142')->is_valid_number, '広島県三原市沼田東町末光');
ok($zip->set_number('7230143')->is_valid_number, '広島県三原市沼田東町釜山');
ok($zip->set_number('7230144')->is_valid_number, '広島県三原市沼田東町末広');
ok($zip->set_number('7230145')->is_valid_number, '広島県三原市沼田東町片島');
ok($zip->set_number('7230146')->is_valid_number, '広島県三原市沼田東町納所');
ok($zip->set_number('7230147')->is_valid_number, '広島県三原市沼田東町本市');
ok($zip->set_number('7230148')->is_valid_number, '広島県三原市沼田東町七宝');
ok($zip->set_number('7250000')->is_valid_number, '広島県竹原市以下に掲載がない場合');
ok($zip->set_number('7250001')->is_valid_number, '広島県竹原市田万里町');
ok($zip->set_number('7250002')->is_valid_number, '広島県竹原市西野町');
ok($zip->set_number('7250003')->is_valid_number, '広島県竹原市新庄町');
ok($zip->set_number('7250004')->is_valid_number, '広島県竹原市東野町');
ok($zip->set_number('7250005')->is_valid_number, '広島県竹原市仁賀町');
ok($zip->set_number('7250011')->is_valid_number, '広島県竹原市小梨町');
ok($zip->set_number('7250012')->is_valid_number, '広島県竹原市下野町');
ok($zip->set_number('7250013')->is_valid_number, '広島県竹原市吉名町');
ok($zip->set_number('7250021')->is_valid_number, '広島県竹原市竹原町');
ok($zip->set_number('7250022')->is_valid_number, '広島県竹原市本町');
ok($zip->set_number('7250023')->is_valid_number, '広島県竹原市田ノ浦');
ok($zip->set_number('7250024')->is_valid_number, '広島県竹原市港町');
ok($zip->set_number('7250025')->is_valid_number, '広島県竹原市塩町');
ok($zip->set_number('7250026')->is_valid_number, '広島県竹原市中央');
ok($zip->set_number('7250200')->is_valid_number, '広島県豊田郡大崎上島町以下に掲載がない場合');
ok($zip->set_number('7250231')->is_valid_number, '広島県豊田郡大崎上島町東野');
ok($zip->set_number('7250301')->is_valid_number, '広島県豊田郡大崎上島町中野');
ok($zip->set_number('7250302')->is_valid_number, '広島県豊田郡大崎上島町原田');
ok($zip->set_number('7250303')->is_valid_number, '広島県豊田郡大崎上島町大串');
ok($zip->set_number('7250401')->is_valid_number, '広島県豊田郡大崎上島町木江');
ok($zip->set_number('7250402')->is_valid_number, '広島県豊田郡大崎上島町沖浦');
ok($zip->set_number('7250403')->is_valid_number, '広島県豊田郡大崎上島町明石');
ok($zip->set_number('7260000')->is_valid_number, '広島県府中市以下に掲載がない場合');
ok($zip->set_number('7260001')->is_valid_number, '広島県府中市本山町');
ok($zip->set_number('7260002')->is_valid_number, '広島県府中市鵜飼町');
ok($zip->set_number('7260003')->is_valid_number, '広島県府中市元町');
ok($zip->set_number('7260004')->is_valid_number, '広島県府中市府川町');
ok($zip->set_number('7260005')->is_valid_number, '広島県府中市府中町');
ok($zip->set_number('7260006')->is_valid_number, '広島県府中市桜が丘');
ok($zip->set_number('7260011')->is_valid_number, '広島県府中市広谷町');
ok($zip->set_number('7260012')->is_valid_number, '広島県府中市中須町');
ok($zip->set_number('7260013')->is_valid_number, '広島県府中市高木町');
ok($zip->set_number('7260021')->is_valid_number, '広島県府中市土生町');
ok($zip->set_number('7260022')->is_valid_number, '広島県府中市用土町');
ok($zip->set_number('7260023')->is_valid_number, '広島県府中市栗柄町');
ok($zip->set_number('7260024')->is_valid_number, '広島県府中市僧殿町');
ok($zip->set_number('7260025')->is_valid_number, '広島県府中市河南町');
ok($zip->set_number('7260026')->is_valid_number, '広島県府中市三郎丸町');
ok($zip->set_number('7260027')->is_valid_number, '広島県府中市篠根町');
ok($zip->set_number('7260031')->is_valid_number, '広島県府中市荒谷町');
ok($zip->set_number('7260032')->is_valid_number, '広島県府中市出口町');
ok($zip->set_number('7260033')->is_valid_number, '広島県府中市目崎町');
ok($zip->set_number('7260034')->is_valid_number, '広島県府中市上山町');
ok($zip->set_number('7260035')->is_valid_number, '広島県府中市父石町');
ok($zip->set_number('7260036')->is_valid_number, '広島県府中市河面町');
ok($zip->set_number('7270000')->is_valid_number, '広島県庄原市以下に掲載がない場合');
ok($zip->set_number('7270001')->is_valid_number, '広島県庄原市大久保町');
ok($zip->set_number('7270002')->is_valid_number, '広島県庄原市高門町');
ok($zip->set_number('7270003')->is_valid_number, '広島県庄原市是松町');
ok($zip->set_number('7270004')->is_valid_number, '広島県庄原市新庄町');
ok($zip->set_number('7270005')->is_valid_number, '広島県庄原市川手町');
ok($zip->set_number('7270006')->is_valid_number, '広島県庄原市本町');
ok($zip->set_number('7270007')->is_valid_number, '広島県庄原市宮内町');
ok($zip->set_number('7270008')->is_valid_number, '広島県庄原市永末町');
ok($zip->set_number('7270011')->is_valid_number, '広島県庄原市東本町');
ok($zip->set_number('7270012')->is_valid_number, '広島県庄原市中本町');
ok($zip->set_number('7270013')->is_valid_number, '広島県庄原市西本町');
ok($zip->set_number('7270014')->is_valid_number, '広島県庄原市板橋町');
ok($zip->set_number('7270015')->is_valid_number, '広島県庄原市実留町');
ok($zip->set_number('7270016')->is_valid_number, '広島県庄原市一木町');
ok($zip->set_number('7270017')->is_valid_number, '広島県庄原市戸郷町');
ok($zip->set_number('7270021')->is_valid_number, '広島県庄原市三日市町');
ok($zip->set_number('7270022')->is_valid_number, '広島県庄原市上原町');
ok($zip->set_number('7270023')->is_valid_number, '広島県庄原市七塚町');
ok($zip->set_number('7270024')->is_valid_number, '広島県庄原市田原町');
ok($zip->set_number('7270025')->is_valid_number, '広島県庄原市市町');
ok($zip->set_number('7270026')->is_valid_number, '広島県庄原市掛田町');
ok($zip->set_number('7270111')->is_valid_number, '広島県庄原市口和町湯木');
ok($zip->set_number('7270112')->is_valid_number, '広島県庄原市口和町金田');
ok($zip->set_number('7270113')->is_valid_number, '広島県庄原市口和町常定');
ok($zip->set_number('7270114')->is_valid_number, '広島県庄原市口和町永田');
ok($zip->set_number('7270201')->is_valid_number, '広島県庄原市門田町');
ok($zip->set_number('7270202')->is_valid_number, '広島県庄原市濁川町');
ok($zip->set_number('7270203')->is_valid_number, '広島県庄原市川北町');
ok($zip->set_number('7270301')->is_valid_number, '広島県庄原市比和町比和');
ok($zip->set_number('7270302')->is_valid_number, '広島県庄原市比和町古頃');
ok($zip->set_number('7270311')->is_valid_number, '広島県庄原市比和町三河内');
ok($zip->set_number('7270312')->is_valid_number, '広島県庄原市比和町木屋原');
ok($zip->set_number('7270321')->is_valid_number, '広島県庄原市比和町森脇');
ok($zip->set_number('7270401')->is_valid_number, '広島県庄原市高野町和南原');
ok($zip->set_number('7270402')->is_valid_number, '広島県庄原市高野町新市');
ok($zip->set_number('7270403')->is_valid_number, '広島県庄原市高野町岡大内');
ok($zip->set_number('7270411')->is_valid_number, '広島県庄原市高野町上湯川');
ok($zip->set_number('7270412')->is_valid_number, '広島県庄原市高野町下湯川');
ok($zip->set_number('7270413')->is_valid_number, '広島県庄原市高野町南');
ok($zip->set_number('7270421')->is_valid_number, '広島県庄原市高野町中門田');
ok($zip->set_number('7270422')->is_valid_number, '広島県庄原市高野町奥門田');
ok($zip->set_number('7270423')->is_valid_number, '広島県庄原市高野町下門田');
ok($zip->set_number('7270424')->is_valid_number, '広島県庄原市高野町高暮');
ok($zip->set_number('7270425')->is_valid_number, '広島県庄原市高野町上里原');
ok($zip->set_number('7270621')->is_valid_number, '広島県庄原市春田町');
ok($zip->set_number('7270622')->is_valid_number, '広島県庄原市峰田町');
ok($zip->set_number('7270623')->is_valid_number, '広島県庄原市本村町');
ok($zip->set_number('7270624')->is_valid_number, '広島県庄原市上谷町');
ok($zip->set_number('7280000')->is_valid_number, '広島県三次市以下に掲載がない場合');
ok($zip->set_number('7280001')->is_valid_number, '広島県三次市山家町');
ok($zip->set_number('7280002')->is_valid_number, '広島県三次市西河内町');
ok($zip->set_number('7280003')->is_valid_number, '広島県三次市東河内町');
ok($zip->set_number('7280004')->is_valid_number, '広島県三次市穴笠町');
ok($zip->set_number('7280005')->is_valid_number, '広島県三次市後山町');
ok($zip->set_number('7280006')->is_valid_number, '広島県三次市畠敷町');
ok($zip->set_number('7280007')->is_valid_number, '広島県三次市小文町');
ok($zip->set_number('7280011')->is_valid_number, '広島県三次市十日市西');
ok($zip->set_number('7280012')->is_valid_number, '広島県三次市十日市中');
ok($zip->set_number('7280013')->is_valid_number, '広島県三次市十日市東');
ok($zip->set_number('7280014')->is_valid_number, '広島県三次市十日市南');
ok($zip->set_number('7280015')->is_valid_number, '広島県三次市十日市町');
ok($zip->set_number('7280016')->is_valid_number, '広島県三次市四拾貫町');
ok($zip->set_number('7280017')->is_valid_number, '広島県三次市南畑敷町');
ok($zip->set_number('7280021')->is_valid_number, '広島県三次市三次町');
ok($zip->set_number('7280022')->is_valid_number, '広島県三次市西酒屋町');
ok($zip->set_number('7280023')->is_valid_number, '広島県三次市東酒屋町');
ok($zip->set_number('7280024')->is_valid_number, '広島県三次市青河町');
ok($zip->set_number('7280025')->is_valid_number, '広島県三次市粟屋町');
ok($zip->set_number('7280026')->is_valid_number, '広島県三次市日下町');
ok($zip->set_number('7280027')->is_valid_number, '広島県三次市三原町');
ok($zip->set_number('7280101')->is_valid_number, '広島県三次市作木町岡三渕');
ok($zip->set_number('7280111')->is_valid_number, '広島県三次市作木町伊賀和志');
ok($zip->set_number('7280112')->is_valid_number, '広島県三次市作木町森山西');
ok($zip->set_number('7280113')->is_valid_number, '広島県三次市作木町森山東');
ok($zip->set_number('7280114')->is_valid_number, '広島県三次市作木町森山中');
ok($zip->set_number('7280115')->is_valid_number, '広島県三次市作木町大津');
ok($zip->set_number('7280121')->is_valid_number, '広島県三次市作木町大畠');
ok($zip->set_number('7280122')->is_valid_number, '広島県三次市作木町西野');
ok($zip->set_number('7280123')->is_valid_number, '広島県三次市作木町上作木');
ok($zip->set_number('7280124')->is_valid_number, '広島県三次市作木町下作木');
ok($zip->set_number('7280125')->is_valid_number, '広島県三次市作木町光守');
ok($zip->set_number('7280131')->is_valid_number, '広島県三次市作木町香淀');
ok($zip->set_number('7280132')->is_valid_number, '広島県三次市作木町大山');
ok($zip->set_number('7280133')->is_valid_number, '広島県三次市作木町門田');
ok($zip->set_number('7280201')->is_valid_number, '広島県三次市布野町上布野');
ok($zip->set_number('7280202')->is_valid_number, '広島県三次市布野町下布野');
ok($zip->set_number('7280203')->is_valid_number, '広島県三次市布野町戸河内');
ok($zip->set_number('7280211')->is_valid_number, '広島県三次市布野町横谷');
ok($zip->set_number('7280401')->is_valid_number, '広島県三次市君田町東入君');
ok($zip->set_number('7280402')->is_valid_number, '広島県三次市君田町西入君');
ok($zip->set_number('7280403')->is_valid_number, '広島県三次市君田町藤兼');
ok($zip->set_number('7280404')->is_valid_number, '広島県三次市君田町石原');
ok($zip->set_number('7280405')->is_valid_number, '広島県三次市君田町泉吉田');
ok($zip->set_number('7280406')->is_valid_number, '広島県三次市君田町櫃田');
ok($zip->set_number('7280407')->is_valid_number, '広島県三次市君田町茂田');
ok($zip->set_number('7280501')->is_valid_number, '広島県庄原市口和町宮内');
ok($zip->set_number('7280502')->is_valid_number, '広島県庄原市口和町向泉');
ok($zip->set_number('7280503')->is_valid_number, '広島県庄原市口和町大月');
ok($zip->set_number('7280504')->is_valid_number, '広島県庄原市口和町竹地谷');
ok($zip->set_number('7280621')->is_valid_number, '広島県三次市三若町');
ok($zip->set_number('7280622')->is_valid_number, '広島県三次市海渡町');
ok($zip->set_number('7280623')->is_valid_number, '広島県三次市石原町');
ok($zip->set_number('7280624')->is_valid_number, '広島県三次市上田町');
ok($zip->set_number('7280625')->is_valid_number, '広島県三次市有原町');
ok($zip->set_number('7290101')->is_valid_number, '広島県福山市高西町川尻');
ok($zip->set_number('7290102')->is_valid_number, '広島県福山市高西町真田');
ok($zip->set_number('7290103')->is_valid_number, '広島県福山市高西町南');
ok($zip->set_number('7290104')->is_valid_number, '広島県福山市松永町');
ok($zip->set_number('7290105')->is_valid_number, '広島県福山市南松永町');
ok($zip->set_number('7290106')->is_valid_number, '広島県福山市高西町');
ok($zip->set_number('7290111')->is_valid_number, '広島県福山市今津町');
ok($zip->set_number('7290112')->is_valid_number, '広島県福山市神村町');
ok($zip->set_number('7290113')->is_valid_number, '広島県福山市宮前町');
ok($zip->set_number('7290114')->is_valid_number, '広島県福山市柳津町');
ok($zip->set_number('7290115')->is_valid_number, '広島県福山市南今津町');
ok($zip->set_number('7290141')->is_valid_number, '広島県尾道市高須町');
ok($zip->set_number('7290142')->is_valid_number, '広島県尾道市西藤町');
ok($zip->set_number('7290251')->is_valid_number, '広島県福山市東村町');
ok($zip->set_number('7290252')->is_valid_number, '広島県福山市本郷町');
ok($zip->set_number('7290321')->is_valid_number, '広島県三原市木原');
ok($zip->set_number('7290321')->is_valid_number, '広島県三原市木原町');
ok($zip->set_number('7290322')->is_valid_number, '広島県三原市奥野山町');
ok($zip->set_number('7290323')->is_valid_number, '広島県三原市鉢ケ峰町');
ok($zip->set_number('7290324')->is_valid_number, '広島県三原市糸崎');
ok($zip->set_number('7290329')->is_valid_number, '広島県三原市糸崎南');
ok($zip->set_number('7290411')->is_valid_number, '広島県三原市本郷町船木(その他)');
ok($zip->set_number('7290412')->is_valid_number, '広島県三原市本郷町本郷');
ok($zip->set_number('7290413')->is_valid_number, '広島県三原市本郷町南方');
ok($zip->set_number('7290414')->is_valid_number, '広島県三原市下北方');
ok($zip->set_number('7290414')->is_valid_number, '広島県三原市本郷町下北方');
ok($zip->set_number('7290415')->is_valid_number, '広島県三原市本郷町上北方');
ok($zip->set_number('7290416')->is_valid_number, '広島県三原市本郷町善入寺');
ok($zip->set_number('7290417')->is_valid_number, '広島県三原市本郷南');
ok($zip->set_number('7290418')->is_valid_number, '広島県三原市本郷北');
ok($zip->set_number('7290419')->is_valid_number, '広島県三原市南方');
ok($zip->set_number('7290471')->is_valid_number, '広島県三原市高坂町許山');
ok($zip->set_number('7290472')->is_valid_number, '広島県三原市高坂町真良');
ok($zip->set_number('7290473')->is_valid_number, '広島県三原市沼田西町小原');
ok($zip->set_number('7290474')->is_valid_number, '広島県三原市沼田西町惣定');
ok($zip->set_number('7290475')->is_valid_number, '広島県三原市沼田西町松江');
ok($zip->set_number('7291211')->is_valid_number, '広島県三原市大和町大草');
ok($zip->set_number('7291212')->is_valid_number, '広島県三原市大和町姥ケ原');
ok($zip->set_number('7291213')->is_valid_number, '広島県三原市大和町平坂');
ok($zip->set_number('7291321')->is_valid_number, '広島県三原市大和町和木');
ok($zip->set_number('7291322')->is_valid_number, '広島県三原市大和町箱川');
ok($zip->set_number('7291323')->is_valid_number, '広島県三原市大和町大具');
ok($zip->set_number('7291331')->is_valid_number, '広島県三原市大和町椋梨');
ok($zip->set_number('7291332')->is_valid_number, '広島県三原市大和町上草井');
ok($zip->set_number('7291333')->is_valid_number, '広島県三原市大和町下草井');
ok($zip->set_number('7291401')->is_valid_number, '広島県三原市大和町蔵宗');
ok($zip->set_number('7291402')->is_valid_number, '広島県三原市大和町篠');
ok($zip->set_number('7291403')->is_valid_number, '広島県三原市大和町萩原');
ok($zip->set_number('7291404')->is_valid_number, '広島県三原市大和町福田');
ok($zip->set_number('7291405')->is_valid_number, '広島県三原市大和町上徳良');
ok($zip->set_number('7291406')->is_valid_number, '広島県三原市大和町下徳良');
ok($zip->set_number('7292251')->is_valid_number, '広島県三原市幸崎久和喜');
ok($zip->set_number('7292251')->is_valid_number, '広島県三原市幸崎町久和喜');
ok($zip->set_number('7292252')->is_valid_number, '広島県三原市幸崎能地');
ok($zip->set_number('7292252')->is_valid_number, '広島県三原市幸崎町能地');
ok($zip->set_number('7292253')->is_valid_number, '広島県三原市幸崎渡瀬');
ok($zip->set_number('7292253')->is_valid_number, '広島県三原市幸崎町渡瀬');
ok($zip->set_number('7292311')->is_valid_number, '広島県竹原市忠海町');
ok($zip->set_number('7292312')->is_valid_number, '広島県竹原市福田町');
ok($zip->set_number('7292313')->is_valid_number, '広島県竹原市高崎町');
ok($zip->set_number('7292314')->is_valid_number, '広島県竹原市忠海床浦');
ok($zip->set_number('7292315')->is_valid_number, '広島県竹原市忠海長浜');
ok($zip->set_number('7292316')->is_valid_number, '広島県竹原市忠海中町');
ok($zip->set_number('7292317')->is_valid_number, '広島県竹原市忠海東町');
ok($zip->set_number('7292361')->is_valid_number, '広島県三原市小泉町');
ok($zip->set_number('7293101')->is_valid_number, '広島県福山市新市町戸手');
ok($zip->set_number('7293102')->is_valid_number, '広島県福山市新市町相方');
ok($zip->set_number('7293103')->is_valid_number, '広島県福山市新市町新市');
ok($zip->set_number('7293104')->is_valid_number, '広島県福山市新市町宮内');
ok($zip->set_number('7293105')->is_valid_number, '広島県福山市新市町下安井');
ok($zip->set_number('7293106')->is_valid_number, '広島県福山市新市町上安井');
ok($zip->set_number('7293107')->is_valid_number, '広島県福山市新市町常');
ok($zip->set_number('7293111')->is_valid_number, '広島県福山市新市町金丸');
ok($zip->set_number('7293112')->is_valid_number, '広島県福山市新市町藤尾');
ok($zip->set_number('7293201')->is_valid_number, '広島県府中市斗升町');
ok($zip->set_number('7293202')->is_valid_number, '広島県府中市行縢町');
ok($zip->set_number('7293211')->is_valid_number, '広島県府中市木野山町');
ok($zip->set_number('7293212')->is_valid_number, '広島県府中市阿字町');
ok($zip->set_number('7293221')->is_valid_number, '広島県府中市河佐町');
ok($zip->set_number('7293222')->is_valid_number, '広島県府中市久佐町');
ok($zip->set_number('7293301')->is_valid_number, '広島県世羅郡世羅町小谷');
ok($zip->set_number('7293302')->is_valid_number, '広島県世羅郡世羅町川尻');
ok($zip->set_number('7293303')->is_valid_number, '広島県世羅郡世羅町東上原');
ok($zip->set_number('7293304')->is_valid_number, '広島県世羅郡世羅町赤屋');
ok($zip->set_number('7293305')->is_valid_number, '広島県世羅郡世羅町別迫');
ok($zip->set_number('7293306')->is_valid_number, '広島県世羅郡世羅町青近');
ok($zip->set_number('7293307')->is_valid_number, '広島県世羅郡世羅町伊尾');
ok($zip->set_number('7293401')->is_valid_number, '広島県府中市上下町小塚');
ok($zip->set_number('7293402')->is_valid_number, '広島県府中市上下町小堀');
ok($zip->set_number('7293403')->is_valid_number, '広島県府中市上下町階見');
ok($zip->set_number('7293404')->is_valid_number, '広島県府中市上下町二森');
ok($zip->set_number('7293405')->is_valid_number, '広島県府中市上下町有福');
ok($zip->set_number('7293411')->is_valid_number, '広島県府中市上下町井永');
ok($zip->set_number('7293412')->is_valid_number, '広島県府中市上下町岡屋');
ok($zip->set_number('7293413')->is_valid_number, '広島県府中市上下町水永');
ok($zip->set_number('7293414')->is_valid_number, '広島県府中市上下町佐倉');
ok($zip->set_number('7293415')->is_valid_number, '広島県府中市上下町矢多田');
ok($zip->set_number('7293421')->is_valid_number, '広島県府中市上下町深江');
ok($zip->set_number('7293422')->is_valid_number, '広島県府中市上下町国留');
ok($zip->set_number('7293423')->is_valid_number, '広島県府中市上下町矢野');
ok($zip->set_number('7293424')->is_valid_number, '広島県府中市上下町松崎');
ok($zip->set_number('7293431')->is_valid_number, '広島県府中市上下町上下');
ok($zip->set_number('7293511')->is_valid_number, '広島県神石郡神石高原町高光');
ok($zip->set_number('7293512')->is_valid_number, '広島県神石郡神石高原町草木');
ok($zip->set_number('7293513')->is_valid_number, '広島県神石郡神石高原町牧');
ok($zip->set_number('7293514')->is_valid_number, '広島県神石郡神石高原町田頭');
ok($zip->set_number('7293515')->is_valid_number, '広島県神石郡神石高原町福永');
ok($zip->set_number('7293516')->is_valid_number, '広島県神石郡神石高原町古川');
ok($zip->set_number('7293601')->is_valid_number, '広島県神石郡神石高原町相渡');
ok($zip->set_number('7293602')->is_valid_number, '広島県神石郡神石高原町永野');
ok($zip->set_number('7293701')->is_valid_number, '広島県庄原市総領町黒目');
ok($zip->set_number('7293702')->is_valid_number, '広島県庄原市総領町亀谷');
ok($zip->set_number('7293703')->is_valid_number, '広島県庄原市総領町下領家');
ok($zip->set_number('7293711')->is_valid_number, '広島県庄原市総領町五箇');
ok($zip->set_number('7293712')->is_valid_number, '広島県庄原市総領町上領家');
ok($zip->set_number('7293713')->is_valid_number, '広島県庄原市総領町中領家');
ok($zip->set_number('7293721')->is_valid_number, '広島県庄原市総領町稲草');
ok($zip->set_number('7293722')->is_valid_number, '広島県庄原市総領町木屋');
ok($zip->set_number('7294101')->is_valid_number, '広島県三次市甲奴町本郷');
ok($zip->set_number('7294102')->is_valid_number, '広島県三次市甲奴町西野');
ok($zip->set_number('7294103')->is_valid_number, '広島県三次市甲奴町小童');
ok($zip->set_number('7294104')->is_valid_number, '広島県三次市甲奴町宇賀');
ok($zip->set_number('7294105')->is_valid_number, '広島県三次市甲奴町梶田');
ok($zip->set_number('7294106')->is_valid_number, '広島県三次市甲奴町有田');
ok($zip->set_number('7294111')->is_valid_number, '広島県三次市甲奴町福田');
ok($zip->set_number('7294112')->is_valid_number, '広島県三次市甲奴町抜湯');
ok($zip->set_number('7294113')->is_valid_number, '広島県三次市甲奴町太郎丸');
ok($zip->set_number('7294201')->is_valid_number, '広島県三次市吉舎町知和');
ok($zip->set_number('7294202')->is_valid_number, '広島県三次市吉舎町上安田');
ok($zip->set_number('7294203')->is_valid_number, '広島県三次市吉舎町安田');
ok($zip->set_number('7294204')->is_valid_number, '広島県三次市吉舎町三玉');
ok($zip->set_number('7294205')->is_valid_number, '広島県三次市吉舎町海田原');
ok($zip->set_number('7294206')->is_valid_number, '広島県三次市吉舎町矢井');
ok($zip->set_number('7294207')->is_valid_number, '広島県三次市吉舎町敷地');
ok($zip->set_number('7294208')->is_valid_number, '広島県三次市吉舎町矢野地');
ok($zip->set_number('7294211')->is_valid_number, '広島県三次市吉舎町吉舎');
ok($zip->set_number('7294221')->is_valid_number, '広島県三次市吉舎町清綱');
ok($zip->set_number('7294222')->is_valid_number, '広島県三次市吉舎町丸田');
ok($zip->set_number('7294223')->is_valid_number, '広島県三次市吉舎町雲通');
ok($zip->set_number('7294224')->is_valid_number, '広島県三次市吉舎町辻');
ok($zip->set_number('7294225')->is_valid_number, '広島県三次市吉舎町徳市');
ok($zip->set_number('7294226')->is_valid_number, '広島県三次市吉舎町吉舎川之内');
ok($zip->set_number('7294227')->is_valid_number, '広島県三次市吉舎町檜');
ok($zip->set_number('7294301')->is_valid_number, '広島県三次市三良坂町光清');
ok($zip->set_number('7294302')->is_valid_number, '広島県三次市三良坂町仁賀');
ok($zip->set_number('7294303')->is_valid_number, '広島県三次市三良坂町灰塚');
ok($zip->set_number('7294304')->is_valid_number, '広島県三次市三良坂町三良坂');
ok($zip->set_number('7294305')->is_valid_number, '広島県三次市三良坂町長田');
ok($zip->set_number('7294306')->is_valid_number, '広島県三次市三良坂町岡田');
ok($zip->set_number('7294307')->is_valid_number, '広島県三次市三良坂町皆瀬');
ok($zip->set_number('7294308')->is_valid_number, '広島県三次市三良坂町田利');
ok($zip->set_number('7295111')->is_valid_number, '広島県庄原市東城町福代');
ok($zip->set_number('7295112')->is_valid_number, '広島県庄原市東城町新福代');
ok($zip->set_number('7295121')->is_valid_number, '広島県庄原市東城町川東');
ok($zip->set_number('7295122')->is_valid_number, '広島県庄原市東城町久代');
ok($zip->set_number('7295123')->is_valid_number, '広島県庄原市東城町戸宇');
ok($zip->set_number('7295124')->is_valid_number, '広島県庄原市東城町東城');
ok($zip->set_number('7295125')->is_valid_number, '広島県庄原市東城町川西');
ok($zip->set_number('7295126')->is_valid_number, '広島県庄原市東城町竹森');
ok($zip->set_number('7295127')->is_valid_number, '広島県庄原市東城町粟田');
ok($zip->set_number('7295128')->is_valid_number, '広島県庄原市東城町受原(隠地、中ノ谷)');
ok($zip->set_number('7295131')->is_valid_number, '広島県庄原市東城町新免');
ok($zip->set_number('7295132')->is_valid_number, '広島県庄原市東城町三坂');
ok($zip->set_number('7295241')->is_valid_number, '広島県庄原市東城町帝釈宇山');
ok($zip->set_number('7295242')->is_valid_number, '広島県庄原市東城町帝釈山中');
ok($zip->set_number('7295243')->is_valid_number, '広島県庄原市東城町帝釈始終');
ok($zip->set_number('7295244')->is_valid_number, '広島県庄原市東城町帝釈未渡');
ok($zip->set_number('7295451')->is_valid_number, '広島県庄原市東城町田黒');
ok($zip->set_number('7295452')->is_valid_number, '広島県庄原市東城町菅');
ok($zip->set_number('7295453')->is_valid_number, '広島県庄原市東城町受原(その他)');
ok($zip->set_number('7295454')->is_valid_number, '広島県庄原市東城町川鳥');
ok($zip->set_number('7295455')->is_valid_number, '広島県庄原市東城町保田');
ok($zip->set_number('7295456')->is_valid_number, '広島県庄原市東城町森');
ok($zip->set_number('7295501')->is_valid_number, '広島県庄原市東城町小奴可');
ok($zip->set_number('7295502')->is_valid_number, '広島県庄原市東城町内堀');
ok($zip->set_number('7295503')->is_valid_number, '広島県庄原市東城町千鳥');
ok($zip->set_number('7295504')->is_valid_number, '広島県庄原市東城町小串');
ok($zip->set_number('7295505')->is_valid_number, '広島県庄原市東城町塩原');
ok($zip->set_number('7295506')->is_valid_number, '広島県庄原市東城町加谷');
ok($zip->set_number('7295601')->is_valid_number, '広島県庄原市西城町小鳥原');
ok($zip->set_number('7295602')->is_valid_number, '広島県庄原市西城町油木');
ok($zip->set_number('7295603')->is_valid_number, '広島県庄原市西城町熊野(上梶谷、下梶谷、落合、明賀)');
ok($zip->set_number('7295611')->is_valid_number, '広島県庄原市西城町三坂');
ok($zip->set_number('7295612')->is_valid_number, '広島県庄原市西城町高尾');
ok($zip->set_number('7295613')->is_valid_number, '広島県庄原市西城町八鳥(明賀、杉ノ原、落合駅前、石塚、二重坂)');
ok($zip->set_number('7295721')->is_valid_number, '広島県庄原市西城町八鳥(その他)');
ok($zip->set_number('7295722')->is_valid_number, '広島県庄原市西城町大佐');
ok($zip->set_number('7295723')->is_valid_number, '広島県庄原市西城町平子');
ok($zip->set_number('7295731')->is_valid_number, '広島県庄原市西城町西城');
ok($zip->set_number('7295732')->is_valid_number, '広島県庄原市西城町栗');
ok($zip->set_number('7295733')->is_valid_number, '広島県庄原市西城町入江');
ok($zip->set_number('7295741')->is_valid_number, '広島県庄原市西城町熊野(その他)');
ok($zip->set_number('7295742')->is_valid_number, '広島県庄原市西城町中野');
ok($zip->set_number('7295743')->is_valid_number, '広島県庄原市西城町中迫');
ok($zip->set_number('7295744')->is_valid_number, '広島県庄原市西城町大屋');
ok($zip->set_number('7295745')->is_valid_number, '広島県庄原市西城町福山');
ok($zip->set_number('7295811')->is_valid_number, '広島県庄原市高町');
ok($zip->set_number('7295812')->is_valid_number, '広島県庄原市小用町');
ok($zip->set_number('7295813')->is_valid_number, '広島県庄原市川西町');
ok($zip->set_number('7296131')->is_valid_number, '広島県庄原市山内町');
ok($zip->set_number('7296132')->is_valid_number, '広島県庄原市本郷町');
ok($zip->set_number('7296133')->is_valid_number, '広島県庄原市殿垣内町');
ok($zip->set_number('7296134')->is_valid_number, '広島県庄原市木戸町');
ok($zip->set_number('7296141')->is_valid_number, '広島県庄原市水越町');
ok($zip->set_number('7296142')->is_valid_number, '広島県庄原市高茂町');
ok($zip->set_number('7296143')->is_valid_number, '広島県庄原市尾引町');
ok($zip->set_number('7296144')->is_valid_number, '広島県庄原市平和町');
ok($zip->set_number('7296201')->is_valid_number, '広島県三次市和知町');
ok($zip->set_number('7296202')->is_valid_number, '広島県三次市向江田町');
ok($zip->set_number('7296203')->is_valid_number, '広島県三次市志幸町');
ok($zip->set_number('7296204')->is_valid_number, '広島県三次市木乗町');
ok($zip->set_number('7296205')->is_valid_number, '広島県三次市塩町');
ok($zip->set_number('7296211')->is_valid_number, '広島県三次市大田幸町');
ok($zip->set_number('7296212')->is_valid_number, '広島県三次市糸井町');
ok($zip->set_number('7296213')->is_valid_number, '広島県三次市廻神町');
ok($zip->set_number('7296214')->is_valid_number, '広島県三次市高杉町');
ok($zip->set_number('7296215')->is_valid_number, '広島県三次市江田川之内町');
ok($zip->set_number('7296216')->is_valid_number, '広島県三次市小田幸町');
ok($zip->set_number('7296331')->is_valid_number, '広島県三次市下志和地町');
ok($zip->set_number('7296332')->is_valid_number, '広島県三次市上志和地町');
ok($zip->set_number('7296333')->is_valid_number, '広島県三次市下川立町');
ok($zip->set_number('7296334')->is_valid_number, '広島県三次市上川立町');
ok($zip->set_number('7296335')->is_valid_number, '広島県三次市秋町');
ok($zip->set_number('7296611')->is_valid_number, '広島県三次市三和町福田');
ok($zip->set_number('7296612')->is_valid_number, '広島県三次市三和町敷名(鉾畦)');
ok($zip->set_number('7296612')->is_valid_number, '広島県三次市三和町下板木');
ok($zip->set_number('7296613')->is_valid_number, '広島県三次市三和町有原');
ok($zip->set_number('7296614')->is_valid_number, '広島県三次市三和町羽出庭');
ok($zip->set_number('7296615')->is_valid_number, '広島県三次市三和町上板木');
ok($zip->set_number('7296616')->is_valid_number, '広島県三次市三和町大力谷');
ok($zip->set_number('7296701')->is_valid_number, '広島県三次市三和町飯田');
ok($zip->set_number('7296701')->is_valid_number, '広島県三次市三和町上壱');
ok($zip->set_number('7296702')->is_valid_number, '広島県三次市三和町敷名(その他)');
ok($zip->set_number('7296711')->is_valid_number, '広島県世羅郡世羅町黒川');
ok($zip->set_number('7296712')->is_valid_number, '広島県世羅郡世羅町吉原');
ok($zip->set_number('7296713')->is_valid_number, '広島県世羅郡世羅町中');
ok($zip->set_number('7296714')->is_valid_number, '広島県世羅郡世羅町上津田');
ok($zip->set_number('7296715')->is_valid_number, '広島県世羅郡世羅町下津田');
ok($zip->set_number('7296716')->is_valid_number, '広島県世羅郡世羅町長田');
ok($zip->set_number('7300000')->is_valid_number, '広島県広島市中区以下に掲載がない場合');
ok($zip->set_number('7300001')->is_valid_number, '広島県広島市中区白島北町');
ok($zip->set_number('7300002')->is_valid_number, '広島県広島市中区白島中町');
ok($zip->set_number('7300003')->is_valid_number, '広島県広島市中区白島九軒町');
ok($zip->set_number('7300004')->is_valid_number, '広島県広島市中区東白島町');
ok($zip->set_number('7300005')->is_valid_number, '広島県広島市中区西白島町');
ok($zip->set_number('7300011')->is_valid_number, '広島県広島市中区基町');
ok($zip->set_number('7300012')->is_valid_number, '広島県広島市中区上八丁堀');
ok($zip->set_number('7300013')->is_valid_number, '広島県広島市中区八丁堀');
ok($zip->set_number('7300014')->is_valid_number, '広島県広島市中区上幟町');
ok($zip->set_number('7300015')->is_valid_number, '広島県広島市中区橋本町');
ok($zip->set_number('7300016')->is_valid_number, '広島県広島市中区幟町');
ok($zip->set_number('7300017')->is_valid_number, '広島県広島市中区鉄砲町');
ok($zip->set_number('7300021')->is_valid_number, '広島県広島市中区胡町');
ok($zip->set_number('7300022')->is_valid_number, '広島県広島市中区銀山町');
ok($zip->set_number('7300023')->is_valid_number, '広島県広島市中区弥生町');
ok($zip->set_number('7300024')->is_valid_number, '広島県広島市中区西平塚町');
ok($zip->set_number('7300025')->is_valid_number, '広島県広島市中区東平塚町');
ok($zip->set_number('7300026')->is_valid_number, '広島県広島市中区田中町');
ok($zip->set_number('7300027')->is_valid_number, '広島県広島市中区薬研堀');
ok($zip->set_number('7300028')->is_valid_number, '広島県広島市中区流川町');
ok($zip->set_number('7300029')->is_valid_number, '広島県広島市中区三川町');
ok($zip->set_number('7300031')->is_valid_number, '広島県広島市中区紙屋町');
ok($zip->set_number('7300032')->is_valid_number, '広島県広島市中区立町');
ok($zip->set_number('7300033')->is_valid_number, '広島県広島市中区堀川町');
ok($zip->set_number('7300034')->is_valid_number, '広島県広島市中区新天地');
ok($zip->set_number('7300035')->is_valid_number, '広島県広島市中区本通');
ok($zip->set_number('7300036')->is_valid_number, '広島県広島市中区袋町');
ok($zip->set_number('7300037')->is_valid_number, '広島県広島市中区中町');
ok($zip->set_number('7300041')->is_valid_number, '広島県広島市中区小町');
ok($zip->set_number('7300042')->is_valid_number, '広島県広島市中区国泰寺町');
ok($zip->set_number('7300043')->is_valid_number, '広島県広島市中区富士見町');
ok($zip->set_number('7300044')->is_valid_number, '広島県広島市中区宝町');
ok($zip->set_number('7300045')->is_valid_number, '広島県広島市中区鶴見町');
ok($zip->set_number('7300046')->is_valid_number, '広島県広島市中区昭和町');
ok($zip->set_number('7300047')->is_valid_number, '広島県広島市中区平野町');
ok($zip->set_number('7300048')->is_valid_number, '広島県広島市中区竹屋町');
ok($zip->set_number('7300049')->is_valid_number, '広島県広島市中区南竹屋町');
ok($zip->set_number('7300051')->is_valid_number, '広島県広島市中区大手町');
ok($zip->set_number('7300052')->is_valid_number, '広島県広島市中区千田町');
ok($zip->set_number('7300053')->is_valid_number, '広島県広島市中区東千田町');
ok($zip->set_number('7300054')->is_valid_number, '広島県広島市中区南千田東町');
ok($zip->set_number('7300055')->is_valid_number, '広島県広島市中区南千田西町');
ok($zip->set_number('7300801')->is_valid_number, '広島県広島市中区寺町');
ok($zip->set_number('7300802')->is_valid_number, '広島県広島市中区本川町');
ok($zip->set_number('7300803')->is_valid_number, '広島県広島市中区広瀬北町');
ok($zip->set_number('7300804')->is_valid_number, '広島県広島市中区広瀬町');
ok($zip->set_number('7300805')->is_valid_number, '広島県広島市中区十日市町');
ok($zip->set_number('7300806')->is_valid_number, '広島県広島市中区西十日市町');
ok($zip->set_number('7300811')->is_valid_number, '広島県広島市中区中島町');
ok($zip->set_number('7300812')->is_valid_number, '広島県広島市中区加古町');
ok($zip->set_number('7300813')->is_valid_number, '広島県広島市中区住吉町');
ok($zip->set_number('7300814')->is_valid_number, '広島県広島市中区羽衣町');
ok($zip->set_number('7300821')->is_valid_number, '広島県広島市中区吉島町');
ok($zip->set_number('7300822')->is_valid_number, '広島県広島市中区吉島東');
ok($zip->set_number('7300823')->is_valid_number, '広島県広島市中区吉島西');
ok($zip->set_number('7300824')->is_valid_number, '広島県広島市中区吉島新町');
ok($zip->set_number('7300825')->is_valid_number, '広島県広島市中区光南');
ok($zip->set_number('7300826')->is_valid_number, '広島県広島市中区南吉島');
ok($zip->set_number('7300831')->is_valid_number, '広島県広島市中区江波西');
ok($zip->set_number('7300832')->is_valid_number, '広島県広島市中区江波東');
ok($zip->set_number('7300833')->is_valid_number, '広島県広島市中区江波本町');
ok($zip->set_number('7300834')->is_valid_number, '広島県広島市中区江波二本松');
ok($zip->set_number('7300835')->is_valid_number, '広島県広島市中区江波南');
ok($zip->set_number('7300836')->is_valid_number, '広島県広島市中区江波栄町');
ok($zip->set_number('7300837')->is_valid_number, '広島県広島市中区江波沖町');
ok($zip->set_number('7300841')->is_valid_number, '広島県広島市中区舟入町');
ok($zip->set_number('7300842')->is_valid_number, '広島県広島市中区舟入中町');
ok($zip->set_number('7300843')->is_valid_number, '広島県広島市中区舟入本町');
ok($zip->set_number('7300844')->is_valid_number, '広島県広島市中区舟入幸町');
ok($zip->set_number('7300845')->is_valid_number, '広島県広島市中区舟入川口町');
ok($zip->set_number('7300846')->is_valid_number, '広島県広島市中区西川口町');
ok($zip->set_number('7300847')->is_valid_number, '広島県広島市中区舟入南');
ok($zip->set_number('7300851')->is_valid_number, '広島県広島市中区榎町');
ok($zip->set_number('7300852')->is_valid_number, '広島県広島市中区猫屋町');
ok($zip->set_number('7300853')->is_valid_number, '広島県広島市中区堺町');
ok($zip->set_number('7300854')->is_valid_number, '広島県広島市中区土橋町');
ok($zip->set_number('7300855')->is_valid_number, '広島県広島市中区小網町');
ok($zip->set_number('7300856')->is_valid_number, '広島県広島市中区河原町');
ok($zip->set_number('7310100')->is_valid_number, '広島県広島市安佐南区以下に掲載がない場合');
ok($zip->set_number('7310101')->is_valid_number, '広島県広島市安佐南区八木');
ok($zip->set_number('7310101')->is_valid_number, '広島県広島市安佐南区八木町');
ok($zip->set_number('7310102')->is_valid_number, '広島県広島市安佐南区川内');
ok($zip->set_number('7310103')->is_valid_number, '広島県広島市安佐南区緑井');
ok($zip->set_number('7310111')->is_valid_number, '広島県広島市安佐南区東野');
ok($zip->set_number('7310112')->is_valid_number, '広島県広島市安佐南区東原');
ok($zip->set_number('7310113')->is_valid_number, '広島県広島市安佐南区西原');
ok($zip->set_number('7310121')->is_valid_number, '広島県広島市安佐南区中須');
ok($zip->set_number('7310122')->is_valid_number, '広島県広島市安佐南区中筋');
ok($zip->set_number('7310123')->is_valid_number, '広島県広島市安佐南区古市');
ok($zip->set_number('7310124')->is_valid_number, '広島県広島市安佐南区大町東');
ok($zip->set_number('7310125')->is_valid_number, '広島県広島市安佐南区大町西');
ok($zip->set_number('7310126')->is_valid_number, '広島県広島市安佐南区大町');
ok($zip->set_number('7310135')->is_valid_number, '広島県広島市安佐南区長束');
ok($zip->set_number('7310136')->is_valid_number, '広島県広島市安佐南区長束西');
ok($zip->set_number('7310137')->is_valid_number, '広島県広島市安佐南区山本');
ok($zip->set_number('7310137')->is_valid_number, '広島県広島市安佐南区山本町');
ok($zip->set_number('7310138')->is_valid_number, '広島県広島市安佐南区祇園');
ok($zip->set_number('7310139')->is_valid_number, '広島県広島市安佐南区山本新町');
ok($zip->set_number('7310141')->is_valid_number, '広島県広島市安佐南区相田');
ok($zip->set_number('7310142')->is_valid_number, '広島県広島市安佐南区高取南');
ok($zip->set_number('7310142')->is_valid_number, '広島県広島市安佐南区高取南町');
ok($zip->set_number('7310143')->is_valid_number, '広島県広島市安佐南区長楽寺');
ok($zip->set_number('7310143')->is_valid_number, '広島県広島市安佐南区長楽寺町');
ok($zip->set_number('7310144')->is_valid_number, '広島県広島市安佐南区高取北');
ok($zip->set_number('7310151')->is_valid_number, '広島県広島市安佐南区毘沙門台東');
ok($zip->set_number('7310152')->is_valid_number, '広島県広島市安佐南区毘沙門台');
ok($zip->set_number('7310153')->is_valid_number, '広島県広島市安佐南区安東');
ok($zip->set_number('7310154')->is_valid_number, '広島県広島市安佐南区上安');
ok($zip->set_number('7310154')->is_valid_number, '広島県広島市安佐南区上安町');
ok($zip->set_number('7310201')->is_valid_number, '広島県広島市安佐北区大林');
ok($zip->set_number('7310202')->is_valid_number, '広島県広島市安佐北区大林町');
ok($zip->set_number('7310211')->is_valid_number, '広島県広島市安佐北区三入');
ok($zip->set_number('7310212')->is_valid_number, '広島県広島市安佐北区三入東');
ok($zip->set_number('7310213')->is_valid_number, '広島県広島市安佐北区三入南');
ok($zip->set_number('7310214')->is_valid_number, '広島県広島市安佐北区可部町桐原');
ok($zip->set_number('7310215')->is_valid_number, '広島県広島市安佐北区可部町南原');
ok($zip->set_number('7310216')->is_valid_number, '広島県広島市安佐北区可部町上町屋');
ok($zip->set_number('7310217')->is_valid_number, '広島県広島市安佐北区可部町下町屋');
ok($zip->set_number('7310221')->is_valid_number, '広島県広島市安佐北区可部');
ok($zip->set_number('7310222')->is_valid_number, '広島県広島市安佐北区可部東');
ok($zip->set_number('7310223')->is_valid_number, '広島県広島市安佐北区可部南');
ok($zip->set_number('7310224')->is_valid_number, '広島県広島市安佐北区可部町中島');
ok($zip->set_number('7310225')->is_valid_number, '広島県広島市安佐北区可部町上原');
ok($zip->set_number('7310231')->is_valid_number, '広島県広島市安佐北区亀山');
ok($zip->set_number('7310232')->is_valid_number, '広島県広島市安佐北区亀山南');
ok($zip->set_number('7310233')->is_valid_number, '広島県広島市安佐北区亀山西');
ok($zip->set_number('7310234')->is_valid_number, '広島県広島市安佐北区可部町今井田');
ok($zip->set_number('7310235')->is_valid_number, '広島県広島市安佐北区可部町勝木');
ok($zip->set_number('7310236')->is_valid_number, '広島県広島市安佐北区可部町綾ケ谷');
ok($zip->set_number('7310301')->is_valid_number, '広島県安芸高田市八千代町土師');
ok($zip->set_number('7310302')->is_valid_number, '広島県安芸高田市八千代町勝田');
ok($zip->set_number('7310303')->is_valid_number, '広島県安芸高田市八千代町佐々井');
ok($zip->set_number('7310304')->is_valid_number, '広島県安芸高田市八千代町下根');
ok($zip->set_number('7310305')->is_valid_number, '広島県安芸高田市八千代町上根');
ok($zip->set_number('7310306')->is_valid_number, '広島県安芸高田市八千代町向山');
ok($zip->set_number('7310500')->is_valid_number, '広島県安芸高田市以下に掲載がない場合');
ok($zip->set_number('7310501')->is_valid_number, '広島県安芸高田市吉田町吉田');
ok($zip->set_number('7310502')->is_valid_number, '広島県安芸高田市吉田町国司');
ok($zip->set_number('7310511')->is_valid_number, '広島県安芸高田市吉田町竹原');
ok($zip->set_number('7310512')->is_valid_number, '広島県安芸高田市吉田町小山');
ok($zip->set_number('7310513')->is_valid_number, '広島県安芸高田市吉田町福原');
ok($zip->set_number('7310521')->is_valid_number, '広島県安芸高田市吉田町常友');
ok($zip->set_number('7310522')->is_valid_number, '広島県安芸高田市吉田町常楽寺');
ok($zip->set_number('7310523')->is_valid_number, '広島県安芸高田市吉田町山手');
ok($zip->set_number('7310524')->is_valid_number, '広島県安芸高田市吉田町川本');
ok($zip->set_number('7310525')->is_valid_number, '広島県安芸高田市吉田町中馬');
ok($zip->set_number('7310531')->is_valid_number, '広島県安芸高田市吉田町下入江');
ok($zip->set_number('7310532')->is_valid_number, '広島県安芸高田市吉田町上入江');
ok($zip->set_number('7310533')->is_valid_number, '広島県安芸高田市吉田町長屋');
ok($zip->set_number('7310534')->is_valid_number, '広島県安芸高田市吉田町桂');
ok($zip->set_number('7310535')->is_valid_number, '広島県安芸高田市吉田町高野');
ok($zip->set_number('7310541')->is_valid_number, '広島県安芸高田市吉田町山部');
ok($zip->set_number('7310542')->is_valid_number, '広島県安芸高田市吉田町相合');
ok($zip->set_number('7310543')->is_valid_number, '広島県安芸高田市吉田町西浦');
ok($zip->set_number('7310544')->is_valid_number, '広島県安芸高田市吉田町多治比');
ok($zip->set_number('7310611')->is_valid_number, '広島県安芸高田市美土里町横田');
ok($zip->set_number('7310612')->is_valid_number, '広島県安芸高田市美土里町本郷');
ok($zip->set_number('7310701')->is_valid_number, '広島県安芸高田市美土里町北');
ok($zip->set_number('7310702')->is_valid_number, '広島県安芸高田市美土里町桑田');
ok($zip->set_number('7310703')->is_valid_number, '広島県安芸高田市美土里町生田');
ok($zip->set_number('7311141')->is_valid_number, '広島県広島市安佐北区安佐町鈴張');
ok($zip->set_number('7311142')->is_valid_number, '広島県広島市安佐北区安佐町飯室');
ok($zip->set_number('7311171')->is_valid_number, '広島県広島市安佐北区安佐町小河内');
ok($zip->set_number('7311221')->is_valid_number, '広島県山県郡北広島町今吉田');
ok($zip->set_number('7311222')->is_valid_number, '広島県山県郡北広島町阿坂');
ok($zip->set_number('7311223')->is_valid_number, '広島県山県郡北広島町吉木(その他)');
ok($zip->set_number('7311500')->is_valid_number, '広島県山県郡北広島町以下に掲載がない場合');
ok($zip->set_number('7311501')->is_valid_number, '広島県山県郡北広島町川戸');
ok($zip->set_number('7311502')->is_valid_number, '広島県山県郡北広島町蔵迫');
ok($zip->set_number('7311503')->is_valid_number, '広島県山県郡北広島町有間');
ok($zip->set_number('7311504')->is_valid_number, '広島県山県郡北広島町寺原');
ok($zip->set_number('7311505')->is_valid_number, '広島県山県郡北広島町舞綱');
ok($zip->set_number('7311506')->is_valid_number, '広島県山県郡北広島町中山');
ok($zip->set_number('7311511')->is_valid_number, '広島県山県郡北広島町惣森');
ok($zip->set_number('7311512')->is_valid_number, '広島県山県郡北広島町川東');
ok($zip->set_number('7311513')->is_valid_number, '広島県山県郡北広島町川井');
ok($zip->set_number('7311514')->is_valid_number, '広島県山県郡北広島町新氏神');
ok($zip->set_number('7311515')->is_valid_number, '広島県山県郡北広島町壬生');
ok($zip->set_number('7311516')->is_valid_number, '広島県山県郡北広島町川西');
ok($zip->set_number('7311521')->is_valid_number, '広島県山県郡北広島町丁保余原');
ok($zip->set_number('7311522')->is_valid_number, '広島県山県郡北広島町新郷');
ok($zip->set_number('7311523')->is_valid_number, '広島県山県郡北広島町南方');
ok($zip->set_number('7311524')->is_valid_number, '広島県山県郡北広島町木次');
ok($zip->set_number('7311525')->is_valid_number, '広島県山県郡北広島町石井谷');
ok($zip->set_number('7311526')->is_valid_number, '広島県山県郡北広島町本地');
ok($zip->set_number('7311531')->is_valid_number, '広島県山県郡北広島町春木');
ok($zip->set_number('7311532')->is_valid_number, '広島県山県郡北広島町古保利');
ok($zip->set_number('7311533')->is_valid_number, '広島県山県郡北広島町有田');
ok($zip->set_number('7311534')->is_valid_number, '広島県山県郡北広島町後有田');
ok($zip->set_number('7311535')->is_valid_number, '広島県山県郡北広島町今田');
ok($zip->set_number('7311701')->is_valid_number, '広島県山県郡北広島町志路原');
ok($zip->set_number('7311702')->is_valid_number, '広島県山県郡北広島町上石');
ok($zip->set_number('7311703')->is_valid_number, '広島県山県郡北広島町海応寺');
ok($zip->set_number('7311704')->is_valid_number, '広島県山県郡北広島町下石');
ok($zip->set_number('7311705')->is_valid_number, '広島県山県郡北広島町西宗');
ok($zip->set_number('7311706')->is_valid_number, '広島県山県郡北広島町中原');
ok($zip->set_number('7311711')->is_valid_number, '広島県山県郡北広島町戸谷');
ok($zip->set_number('7311712')->is_valid_number, '広島県山県郡北広島町都志見');
ok($zip->set_number('7311713')->is_valid_number, '広島県山県郡北広島町長笹');
ok($zip->set_number('7311714')->is_valid_number, '広島県山県郡北広島町吉木(水根)');
ok($zip->set_number('7312101')->is_valid_number, '広島県山県郡北広島町宮迫');
ok($zip->set_number('7312102')->is_valid_number, '広島県山県郡北広島町岩戸');
ok($zip->set_number('7312103')->is_valid_number, '広島県山県郡北広島町新庄');
ok($zip->set_number('7312104')->is_valid_number, '広島県山県郡北広島町大朝');
ok($zip->set_number('7312105')->is_valid_number, '広島県山県郡北広島町田原');
ok($zip->set_number('7312106')->is_valid_number, '広島県山県郡北広島町筏津');
ok($zip->set_number('7312107')->is_valid_number, '広島県山県郡北広島町大塚');
ok($zip->set_number('7312201')->is_valid_number, '広島県山県郡北広島町高野');
ok($zip->set_number('7312202')->is_valid_number, '広島県山県郡北広島町溝口');
ok($zip->set_number('7312203')->is_valid_number, '広島県山県郡北広島町小原');
ok($zip->set_number('7312204')->is_valid_number, '広島県山県郡北広島町大暮');
ok($zip->set_number('7312205')->is_valid_number, '広島県山県郡北広島町米沢');
ok($zip->set_number('7312206')->is_valid_number, '広島県山県郡北広島町移原');
ok($zip->set_number('7312311')->is_valid_number, '広島県山県郡北広島町土橋');
ok($zip->set_number('7312312')->is_valid_number, '広島県山県郡北広島町奥原');
ok($zip->set_number('7312313')->is_valid_number, '広島県山県郡北広島町草安');
ok($zip->set_number('7312314')->is_valid_number, '広島県山県郡北広島町才乙');
ok($zip->set_number('7312315')->is_valid_number, '広島県山県郡北広島町大利原');
ok($zip->set_number('7312316')->is_valid_number, '広島県山県郡北広島町南門原');
ok($zip->set_number('7312317')->is_valid_number, '広島県山県郡北広島町苅屋形');
ok($zip->set_number('7312321')->is_valid_number, '広島県山県郡北広島町板村');
ok($zip->set_number('7312322')->is_valid_number, '広島県山県郡北広島町細見(その他)');
ok($zip->set_number('7312323')->is_valid_number, '広島県山県郡北広島町川小田');
ok($zip->set_number('7312324')->is_valid_number, '広島県山県郡北広島町奥中原');
ok($zip->set_number('7312431')->is_valid_number, '広島県山県郡北広島町荒神原');
ok($zip->set_number('7312432')->is_valid_number, '広島県山県郡北広島町中祖');
ok($zip->set_number('7312433')->is_valid_number, '広島県山県郡北広島町吉見坂');
ok($zip->set_number('7312434')->is_valid_number, '広島県山県郡北広島町橋山');
ok($zip->set_number('7312435')->is_valid_number, '広島県山県郡北広島町空城');
ok($zip->set_number('7312436')->is_valid_number, '広島県山県郡北広島町政所');
ok($zip->set_number('7312437')->is_valid_number, '広島県山県郡北広島町大元');
ok($zip->set_number('7312441')->is_valid_number, '広島県山県郡北広島町宮地');
ok($zip->set_number('7312442')->is_valid_number, '広島県山県郡北広島町雲耕');
ok($zip->set_number('7312551')->is_valid_number, '広島県山県郡北広島町東八幡原');
ok($zip->set_number('7312552')->is_valid_number, '広島県山県郡北広島町西八幡原');
ok($zip->set_number('7313161')->is_valid_number, '広島県広島市安佐南区沼田町伴');
ok($zip->set_number('7313163')->is_valid_number, '広島県広島市安佐南区伴北');
ok($zip->set_number('7313164')->is_valid_number, '広島県広島市安佐南区伴東');
ok($zip->set_number('7313165')->is_valid_number, '広島県広島市安佐南区伴中央');
ok($zip->set_number('7313166')->is_valid_number, '広島県広島市安佐南区大塚東');
ok($zip->set_number('7313167')->is_valid_number, '広島県広島市安佐南区大塚西');
ok($zip->set_number('7313168')->is_valid_number, '広島県広島市安佐南区伴南');
ok($zip->set_number('7313169')->is_valid_number, '広島県広島市安佐南区伴西');
ok($zip->set_number('7313171')->is_valid_number, '広島県広島市安佐南区伴北町');
ok($zip->set_number('7313172')->is_valid_number, '広島県広島市安佐南区伴東町');
ok($zip->set_number('7313173')->is_valid_number, '広島県広島市安佐南区大塚東町');
ok($zip->set_number('7313174')->is_valid_number, '広島県広島市安佐南区大塚西町');
ok($zip->set_number('7313175')->is_valid_number, '広島県広島市安佐南区伴西町');
ok($zip->set_number('7313271')->is_valid_number, '広島県広島市安佐南区沼田町阿戸');
ok($zip->set_number('7313272')->is_valid_number, '広島県広島市安佐南区沼田町吉山');
ok($zip->set_number('7313351')->is_valid_number, '広島県広島市安佐北区安佐町毛木');
ok($zip->set_number('7313352')->is_valid_number, '広島県広島市安佐北区安佐町後山');
ok($zip->set_number('7313353')->is_valid_number, '広島県広島市安佐北区安佐町宮野');
ok($zip->set_number('7313354')->is_valid_number, '広島県広島市安佐北区安佐町筒瀬');
ok($zip->set_number('7313355')->is_valid_number, '広島県広島市安佐北区安佐町動物園');
ok($zip->set_number('7313361')->is_valid_number, '広島県広島市安佐北区あさひが丘');
ok($zip->set_number('7313362')->is_valid_number, '広島県広島市安佐北区安佐町久地');
ok($zip->set_number('7313363')->is_valid_number, '広島県広島市安佐北区安佐町くすの木台');
ok($zip->set_number('7313411')->is_valid_number, '広島県山県郡安芸太田町穴');
ok($zip->set_number('7313412')->is_valid_number, '広島県山県郡安芸太田町坪野');
ok($zip->set_number('7313500')->is_valid_number, '広島県山県郡安芸太田町以下に掲載がない場合');
ok($zip->set_number('7313501')->is_valid_number, '広島県山県郡安芸太田町加計');
ok($zip->set_number('7313502')->is_valid_number, '広島県山県郡安芸太田町津浪');
ok($zip->set_number('7313503')->is_valid_number, '広島県山県郡安芸太田町観音');
ok($zip->set_number('7313551')->is_valid_number, '広島県山県郡安芸太田町猪山');
ok($zip->set_number('7313552')->is_valid_number, '広島県山県郡安芸太田町平見谷');
ok($zip->set_number('7313561')->is_valid_number, '広島県山県郡北広島町細見(下山)');
ok($zip->set_number('7313621')->is_valid_number, '広島県山県郡安芸太田町下筒賀');
ok($zip->set_number('7313622')->is_valid_number, '広島県山県郡安芸太田町下殿河内');
ok($zip->set_number('7313664')->is_valid_number, '広島県山県郡安芸太田町上殿');
ok($zip->set_number('7313701')->is_valid_number, '広島県山県郡安芸太田町上筒賀');
ok($zip->set_number('7313702')->is_valid_number, '広島県山県郡安芸太田町中筒賀');
ok($zip->set_number('7313801')->is_valid_number, '広島県山県郡安芸太田町横川');
ok($zip->set_number('7313810')->is_valid_number, '広島県山県郡安芸太田町戸河内');
ok($zip->set_number('7313812')->is_valid_number, '広島県山県郡安芸太田町遊谷');
ok($zip->set_number('7313813')->is_valid_number, '広島県山県郡安芸太田町柴木');
ok($zip->set_number('7313821')->is_valid_number, '広島県山県郡安芸太田町土居');
ok($zip->set_number('7313824')->is_valid_number, '広島県山県郡安芸太田町寺領');
ok($zip->set_number('7313831')->is_valid_number, '広島県山県郡安芸太田町川手');
ok($zip->set_number('7313832')->is_valid_number, '広島県山県郡安芸太田町梶ノ木');
ok($zip->set_number('7313833')->is_valid_number, '広島県山県郡安芸太田町板ケ谷');
ok($zip->set_number('7313834')->is_valid_number, '広島県山県郡安芸太田町松原');
ok($zip->set_number('7313835')->is_valid_number, '広島県山県郡安芸太田町小板');
ok($zip->set_number('7313842')->is_valid_number, '広島県山県郡安芸太田町田吹');
ok($zip->set_number('7313843')->is_valid_number, '広島県山県郡安芸太田町吉和郷');
ok($zip->set_number('7313844')->is_valid_number, '広島県山県郡安芸太田町打梨');
ok($zip->set_number('7313845')->is_valid_number, '広島県山県郡安芸太田町那須');
ok($zip->set_number('7314200')->is_valid_number, '広島県安芸郡熊野町以下に掲載がない場合');
ok($zip->set_number('7314211')->is_valid_number, '広島県安芸郡熊野町新宮');
ok($zip->set_number('7314212')->is_valid_number, '広島県安芸郡熊野町初神');
ok($zip->set_number('7314213')->is_valid_number, '広島県安芸郡熊野町萩原');
ok($zip->set_number('7314214')->is_valid_number, '広島県安芸郡熊野町中溝');
ok($zip->set_number('7314215')->is_valid_number, '広島県安芸郡熊野町城之堀');
ok($zip->set_number('7314221')->is_valid_number, '広島県安芸郡熊野町出来庭');
ok($zip->set_number('7314222')->is_valid_number, '広島県安芸郡熊野町呉地');
ok($zip->set_number('7314223')->is_valid_number, '広島県安芸郡熊野町川角');
ok($zip->set_number('7314224')->is_valid_number, '広島県安芸郡熊野町神田');
ok($zip->set_number('7314225')->is_valid_number, '広島県安芸郡熊野町石神');
ok($zip->set_number('7314226')->is_valid_number, '広島県安芸郡熊野町東山');
ok($zip->set_number('7314227')->is_valid_number, '広島県安芸郡熊野町貴船');
ok($zip->set_number('7314228')->is_valid_number, '広島県安芸郡熊野町柿迫');
ok($zip->set_number('7314229')->is_valid_number, '広島県安芸郡熊野町平谷');
ok($zip->set_number('7314231')->is_valid_number, '広島県広島市安芸区阿戸町');
ok($zip->set_number('7314300')->is_valid_number, '広島県安芸郡坂町以下に掲載がない場合');
ok($zip->set_number('7314301')->is_valid_number, '広島県安芸郡坂町坂町の次に番地がくる場合');
ok($zip->set_number('7314311')->is_valid_number, '広島県安芸郡坂町北新地');
ok($zip->set_number('7314312')->is_valid_number, '広島県安芸郡坂町平成ケ浜');
ok($zip->set_number('7314313')->is_valid_number, '広島県安芸郡坂町坂東');
ok($zip->set_number('7314314')->is_valid_number, '広島県安芸郡坂町坂西');
ok($zip->set_number('7314321')->is_valid_number, '広島県安芸郡坂町植田');
ok($zip->set_number('7314322')->is_valid_number, '広島県安芸郡坂町横浜東');
ok($zip->set_number('7314323')->is_valid_number, '広島県安芸郡坂町横浜中央');
ok($zip->set_number('7314324')->is_valid_number, '広島県安芸郡坂町横浜西');
ok($zip->set_number('7314325')->is_valid_number, '広島県安芸郡坂町鯛尾');
ok($zip->set_number('7314331')->is_valid_number, '広島県安芸郡坂町小屋浦');
ok($zip->set_number('7315100')->is_valid_number, '広島県広島市佐伯区以下に掲載がない場合');
ok($zip->set_number('7315101')->is_valid_number, '広島県広島市佐伯区五月が丘');
ok($zip->set_number('7315102')->is_valid_number, '広島県広島市佐伯区五日市町石内');
ok($zip->set_number('7315103')->is_valid_number, '広島県広島市佐伯区藤の木');
ok($zip->set_number('7315104')->is_valid_number, '広島県広島市佐伯区五日市町上小深川');
ok($zip->set_number('7315105')->is_valid_number, '広島県広島市佐伯区五日市町下小深川');
ok($zip->set_number('7315106')->is_valid_number, '広島県広島市佐伯区利松');
ok($zip->set_number('7315107')->is_valid_number, '広島県広島市佐伯区石内上');
ok($zip->set_number('7315108')->is_valid_number, '広島県広島市佐伯区石内南');
ok($zip->set_number('7315109')->is_valid_number, '広島県広島市佐伯区石内北');
ok($zip->set_number('7315111')->is_valid_number, '広島県広島市佐伯区美鈴が丘東');
ok($zip->set_number('7315112')->is_valid_number, '広島県広島市佐伯区美鈴が丘南');
ok($zip->set_number('7315113')->is_valid_number, '広島県広島市佐伯区美鈴が丘緑');
ok($zip->set_number('7315114')->is_valid_number, '広島県広島市佐伯区美鈴が丘西');
ok($zip->set_number('7315115')->is_valid_number, '広島県広島市佐伯区五日市町中地');
ok($zip->set_number('7315115')->is_valid_number, '広島県広島市佐伯区八幡東');
ok($zip->set_number('7315116')->is_valid_number, '広島県広島市佐伯区五日市町寺田');
ok($zip->set_number('7315116')->is_valid_number, '広島県広島市佐伯区八幡');
ok($zip->set_number('7315117')->is_valid_number, '広島県広島市佐伯区八幡が丘');
ok($zip->set_number('7315121')->is_valid_number, '広島県広島市佐伯区五日市町美鈴園');
ok($zip->set_number('7315122')->is_valid_number, '広島県広島市佐伯区五日市町皆賀');
ok($zip->set_number('7315123')->is_valid_number, '広島県広島市佐伯区五日市町昭和台');
ok($zip->set_number('7315124')->is_valid_number, '広島県広島市佐伯区皆賀');
ok($zip->set_number('7315125')->is_valid_number, '広島県広島市佐伯区五日市駅前');
ok($zip->set_number('7315126')->is_valid_number, '広島県広島市佐伯区新宮苑');
ok($zip->set_number('7315127')->is_valid_number, '広島県広島市佐伯区五日市');
ok($zip->set_number('7315128')->is_valid_number, '広島県広島市佐伯区五日市中央');
ok($zip->set_number('7315131')->is_valid_number, '広島県広島市佐伯区藤垂園');
ok($zip->set_number('7315132')->is_valid_number, '広島県広島市佐伯区吉見園');
ok($zip->set_number('7315133')->is_valid_number, '広島県広島市佐伯区旭園');
ok($zip->set_number('7315134')->is_valid_number, '広島県広島市佐伯区海老山町');
ok($zip->set_number('7315135')->is_valid_number, '広島県広島市佐伯区海老園');
ok($zip->set_number('7315136')->is_valid_number, '広島県広島市佐伯区楽々園');
ok($zip->set_number('7315137')->is_valid_number, '広島県広島市佐伯区美の里');
ok($zip->set_number('7315138')->is_valid_number, '広島県広島市佐伯区海老山南');
ok($zip->set_number('7315141')->is_valid_number, '広島県広島市佐伯区千同');
ok($zip->set_number('7315142')->is_valid_number, '広島県広島市佐伯区坪井');
ok($zip->set_number('7315142')->is_valid_number, '広島県広島市佐伯区坪井町');
ok($zip->set_number('7315143')->is_valid_number, '広島県広島市佐伯区三宅');
ok($zip->set_number('7315143')->is_valid_number, '広島県広島市佐伯区三宅町');
ok($zip->set_number('7315144')->is_valid_number, '広島県広島市佐伯区三筋');
ok($zip->set_number('7315145')->is_valid_number, '広島県広島市佐伯区隅の浜');
ok($zip->set_number('7315146')->is_valid_number, '広島県広島市佐伯区屋代');
ok($zip->set_number('7315147')->is_valid_number, '広島県広島市佐伯区屋代町');
ok($zip->set_number('7315151')->is_valid_number, '広島県広島市佐伯区五日市町上河内');
ok($zip->set_number('7315152')->is_valid_number, '広島県広島市佐伯区五日市町下河内');
ok($zip->set_number('7315153')->is_valid_number, '広島県広島市佐伯区河内南');
ok($zip->set_number('7315154')->is_valid_number, '広島県広島市佐伯区薬師が丘');
ok($zip->set_number('7315155')->is_valid_number, '広島県広島市佐伯区城山');
ok($zip->set_number('7315156')->is_valid_number, '広島県広島市佐伯区倉重');
ok($zip->set_number('7315157')->is_valid_number, '広島県広島市佐伯区観音台');
ok($zip->set_number('7315161')->is_valid_number, '広島県広島市佐伯区五日市港');
ok($zip->set_number('7315162')->is_valid_number, '広島県広島市佐伯区石内東');
ok($zip->set_number('7320000')->is_valid_number, '広島県広島市東区以下に掲載がない場合');
ok($zip->set_number('7320001')->is_valid_number, '広島県広島市東区戸坂惣田');
ok($zip->set_number('7320002')->is_valid_number, '広島県広島市東区戸坂山根');
ok($zip->set_number('7320003')->is_valid_number, '広島県広島市東区戸坂中町');
ok($zip->set_number('7320004')->is_valid_number, '広島県広島市東区戸坂山崎町');
ok($zip->set_number('7320005')->is_valid_number, '広島県広島市東区戸坂桜東町');
ok($zip->set_number('7320006')->is_valid_number, '広島県広島市東区戸坂桜西町');
ok($zip->set_number('7320007')->is_valid_number, '広島県広島市東区戸坂桜上町');
ok($zip->set_number('7320008')->is_valid_number, '広島県広島市東区戸坂くるめ木');
ok($zip->set_number('7320009')->is_valid_number, '広島県広島市東区戸坂千足');
ok($zip->set_number('7320011')->is_valid_number, '広島県広島市東区戸坂町');
ok($zip->set_number('7320012')->is_valid_number, '広島県広島市東区戸坂新町');
ok($zip->set_number('7320013')->is_valid_number, '広島県広島市東区戸坂南');
ok($zip->set_number('7320014')->is_valid_number, '広島県広島市東区戸坂大上');
ok($zip->set_number('7320015')->is_valid_number, '広島県広島市東区戸坂城山町');
ok($zip->set_number('7320016')->is_valid_number, '広島県広島市東区戸坂出江');
ok($zip->set_number('7320017')->is_valid_number, '広島県広島市東区戸坂数甲');
ok($zip->set_number('7320018')->is_valid_number, '広島県広島市東区戸坂長尾台');
ok($zip->set_number('7320021')->is_valid_number, '広島県広島市東区中山新町');
ok($zip->set_number('7320022')->is_valid_number, '広島県広島市東区中山鏡が丘');
ok($zip->set_number('7320023')->is_valid_number, '広島県広島市東区中山東');
ok($zip->set_number('7320024')->is_valid_number, '広島県広島市東区中山南');
ok($zip->set_number('7320025')->is_valid_number, '広島県広島市東区中山西');
ok($zip->set_number('7320026')->is_valid_number, '広島県広島市東区中山中町');
ok($zip->set_number('7320027')->is_valid_number, '広島県広島市東区中山上');
ok($zip->set_number('7320028')->is_valid_number, '広島県広島市東区中山北町');
ok($zip->set_number('7320029')->is_valid_number, '広島県広島市東区福田');
ok($zip->set_number('7320031')->is_valid_number, '広島県広島市東区馬木');
ok($zip->set_number('7320032')->is_valid_number, '広島県広島市東区上温品');
ok($zip->set_number('7320033')->is_valid_number, '広島県広島市東区温品');
ok($zip->set_number('7320034')->is_valid_number, '広島県広島市東区温品町');
ok($zip->set_number('7320035')->is_valid_number, '広島県広島市東区馬木町');
ok($zip->set_number('7320036')->is_valid_number, '広島県広島市東区福田町');
ok($zip->set_number('7320041')->is_valid_number, '広島県広島市東区矢賀町');
ok($zip->set_number('7320042')->is_valid_number, '広島県広島市東区矢賀');
ok($zip->set_number('7320043')->is_valid_number, '広島県広島市東区東山町');
ok($zip->set_number('7320044')->is_valid_number, '広島県広島市東区矢賀新町');
ok($zip->set_number('7320045')->is_valid_number, '広島県広島市東区曙');
ok($zip->set_number('7320046')->is_valid_number, '広島県広島市東区尾長東');
ok($zip->set_number('7320047')->is_valid_number, '広島県広島市東区尾長西');
ok($zip->set_number('7320048')->is_valid_number, '広島県広島市東区山根町');
ok($zip->set_number('7320049')->is_valid_number, '広島県広島市東区尾長町');
ok($zip->set_number('7320051')->is_valid_number, '広島県広島市東区光が丘');
ok($zip->set_number('7320052')->is_valid_number, '広島県広島市東区光町');
ok($zip->set_number('7320053')->is_valid_number, '広島県広島市東区若草町');
ok($zip->set_number('7320054')->is_valid_number, '広島県広島市東区愛宕町');
ok($zip->set_number('7320055')->is_valid_number, '広島県広島市東区東蟹屋町');
ok($zip->set_number('7320056')->is_valid_number, '広島県広島市東区上大須賀町');
ok($zip->set_number('7320057')->is_valid_number, '広島県広島市東区二葉の里');
ok($zip->set_number('7320061')->is_valid_number, '広島県広島市東区牛田山');
ok($zip->set_number('7320062')->is_valid_number, '広島県広島市東区牛田早稲田');
ok($zip->set_number('7320063')->is_valid_number, '広島県広島市東区牛田東');
ok($zip->set_number('7320064')->is_valid_number, '広島県広島市東区牛田南');
ok($zip->set_number('7320065')->is_valid_number, '広島県広島市東区牛田中');
ok($zip->set_number('7320066')->is_valid_number, '広島県広島市東区牛田本町');
ok($zip->set_number('7320067')->is_valid_number, '広島県広島市東区牛田旭');
ok($zip->set_number('7320068')->is_valid_number, '広島県広島市東区牛田新町');
ok($zip->set_number('7320801')->is_valid_number, '広島県広島市南区東駅町');
ok($zip->set_number('7320802')->is_valid_number, '広島県広島市南区大州');
ok($zip->set_number('7320803')->is_valid_number, '広島県広島市南区南蟹屋');
ok($zip->set_number('7320804')->is_valid_number, '広島県広島市南区西蟹屋');
ok($zip->set_number('7320805')->is_valid_number, '広島県広島市南区東荒神町');
ok($zip->set_number('7320806')->is_valid_number, '広島県広島市南区西荒神町');
ok($zip->set_number('7320807')->is_valid_number, '広島県広島市南区荒神町');
ok($zip->set_number('7320811')->is_valid_number, '広島県広島市南区段原');
ok($zip->set_number('7320814')->is_valid_number, '広島県広島市南区段原南');
ok($zip->set_number('7320815')->is_valid_number, '広島県広島市南区比治山公園');
ok($zip->set_number('7320816')->is_valid_number, '広島県広島市南区比治山本町');
ok($zip->set_number('7320817')->is_valid_number, '広島県広島市南区比治山町');
ok($zip->set_number('7320818')->is_valid_number, '広島県広島市南区段原日出');
ok($zip->set_number('7320819')->is_valid_number, '広島県広島市南区段原山崎');
ok($zip->set_number('7320821')->is_valid_number, '広島県広島市南区大須賀町');
ok($zip->set_number('7320822')->is_valid_number, '広島県広島市南区松原町');
ok($zip->set_number('7320823')->is_valid_number, '広島県広島市南区猿猴橋町');
ok($zip->set_number('7320824')->is_valid_number, '広島県広島市南区的場町');
ok($zip->set_number('7320825')->is_valid_number, '広島県広島市南区金屋町');
ok($zip->set_number('7320826')->is_valid_number, '広島県広島市南区松川町');
ok($zip->set_number('7320827')->is_valid_number, '広島県広島市南区稲荷町');
ok($zip->set_number('7320828')->is_valid_number, '広島県広島市南区京橋町');
ok($zip->set_number('7330000')->is_valid_number, '広島県広島市西区以下に掲載がない場合');
ok($zip->set_number('7330001')->is_valid_number, '広島県広島市西区大芝');
ok($zip->set_number('7330002')->is_valid_number, '広島県広島市西区楠木町');
ok($zip->set_number('7330003')->is_valid_number, '広島県広島市西区三篠町');
ok($zip->set_number('7330004')->is_valid_number, '広島県広島市西区打越町');
ok($zip->set_number('7330005')->is_valid_number, '広島県広島市西区三滝町');
ok($zip->set_number('7330006')->is_valid_number, '広島県広島市西区三篠北町');
ok($zip->set_number('7330007')->is_valid_number, '広島県広島市西区大宮');
ok($zip->set_number('7330011')->is_valid_number, '広島県広島市西区横川町');
ok($zip->set_number('7330012')->is_valid_number, '広島県広島市西区中広町');
ok($zip->set_number('7330013')->is_valid_number, '広島県広島市西区横川新町');
ok($zip->set_number('7330021')->is_valid_number, '広島県広島市西区上天満町');
ok($zip->set_number('7330022')->is_valid_number, '広島県広島市西区天満町');
ok($zip->set_number('7330023')->is_valid_number, '広島県広島市西区都町');
ok($zip->set_number('7330024')->is_valid_number, '広島県広島市西区福島町');
ok($zip->set_number('7330025')->is_valid_number, '広島県広島市西区小河内町');
ok($zip->set_number('7330031')->is_valid_number, '広島県広島市西区観音町');
ok($zip->set_number('7330032')->is_valid_number, '広島県広島市西区東観音町');
ok($zip->set_number('7330033')->is_valid_number, '広島県広島市西区観音本町');
ok($zip->set_number('7330034')->is_valid_number, '広島県広島市西区南観音町');
ok($zip->set_number('7330035')->is_valid_number, '広島県広島市西区南観音');
ok($zip->set_number('7330036')->is_valid_number, '広島県広島市西区観音新町');
ok($zip->set_number('7330037')->is_valid_number, '広島県広島市西区西観音町');
ok($zip->set_number('7330801')->is_valid_number, '広島県広島市西区新庄町');
ok($zip->set_number('7330802')->is_valid_number, '広島県広島市西区三滝本町');
ok($zip->set_number('7330803')->is_valid_number, '広島県広島市西区竜王町');
ok($zip->set_number('7330804')->is_valid_number, '広島県広島市西区山手町');
ok($zip->set_number('7330805')->is_valid_number, '広島県広島市西区三滝山');
ok($zip->set_number('7330811')->is_valid_number, '広島県広島市西区己斐東');
ok($zip->set_number('7330812')->is_valid_number, '広島県広島市西区己斐本町');
ok($zip->set_number('7330813')->is_valid_number, '広島県広島市西区己斐中');
ok($zip->set_number('7330814')->is_valid_number, '広島県広島市西区己斐西町');
ok($zip->set_number('7330815')->is_valid_number, '広島県広島市西区己斐上');
ok($zip->set_number('7330816')->is_valid_number, '広島県広島市西区己斐大迫');
ok($zip->set_number('7330821')->is_valid_number, '広島県広島市西区庚午北');
ok($zip->set_number('7330822')->is_valid_number, '広島県広島市西区庚午中');
ok($zip->set_number('7330823')->is_valid_number, '広島県広島市西区庚午南');
ok($zip->set_number('7330831')->is_valid_number, '広島県広島市西区扇');
ok($zip->set_number('7330832')->is_valid_number, '広島県広島市西区草津港');
ok($zip->set_number('7330833')->is_valid_number, '広島県広島市西区商工センター');
ok($zip->set_number('7330834')->is_valid_number, '広島県広島市西区草津新町');
ok($zip->set_number('7330841')->is_valid_number, '広島県広島市西区井口明神');
ok($zip->set_number('7330842')->is_valid_number, '広島県広島市西区井口');
ok($zip->set_number('7330843')->is_valid_number, '広島県広島市西区井口鈴が台');
ok($zip->set_number('7330844')->is_valid_number, '広島県広島市西区井口台');
ok($zip->set_number('7330845')->is_valid_number, '広島県広島市西区井口町');
ok($zip->set_number('7330851')->is_valid_number, '広島県広島市西区田方');
ok($zip->set_number('7330852')->is_valid_number, '広島県広島市西区鈴が峰町');
ok($zip->set_number('7330853')->is_valid_number, '広島県広島市西区山田新町');
ok($zip->set_number('7330854')->is_valid_number, '広島県広島市西区山田町');
ok($zip->set_number('7330861')->is_valid_number, '広島県広島市西区草津東');
ok($zip->set_number('7330862')->is_valid_number, '広島県広島市西区草津浜町');
ok($zip->set_number('7330863')->is_valid_number, '広島県広島市西区草津南');
ok($zip->set_number('7330864')->is_valid_number, '広島県広島市西区草津梅が台');
ok($zip->set_number('7330865')->is_valid_number, '広島県広島市西区草津本町');
ok($zip->set_number('7330871')->is_valid_number, '広島県広島市西区高須');
ok($zip->set_number('7330872')->is_valid_number, '広島県広島市西区古江東町');
ok($zip->set_number('7330873')->is_valid_number, '広島県広島市西区古江新町');
ok($zip->set_number('7330874')->is_valid_number, '広島県広島市西区古江西町');
ok($zip->set_number('7330875')->is_valid_number, '広島県広島市西区古江上');
ok($zip->set_number('7330876')->is_valid_number, '広島県広島市西区高須台');
ok($zip->set_number('7330877')->is_valid_number, '広島県広島市西区古田台');
ok($zip->set_number('7340000')->is_valid_number, '広島県広島市南区以下に掲載がない場合');
ok($zip->set_number('7340001')->is_valid_number, '広島県広島市南区出汐');
ok($zip->set_number('7340002')->is_valid_number, '広島県広島市南区西旭町');
ok($zip->set_number('7340003')->is_valid_number, '広島県広島市南区宇品東');
ok($zip->set_number('7340004')->is_valid_number, '広島県広島市南区宇品神田');
ok($zip->set_number('7340005')->is_valid_number, '広島県広島市南区翠');
ok($zip->set_number('7340006')->is_valid_number, '広島県広島市南区西翠町');
ok($zip->set_number('7340007')->is_valid_number, '広島県広島市南区皆実町');
ok($zip->set_number('7340011')->is_valid_number, '広島県広島市南区宇品海岸');
ok($zip->set_number('7340012')->is_valid_number, '広島県広島市南区元宇品町');
ok($zip->set_number('7340013')->is_valid_number, '広島県広島市南区出島');
ok($zip->set_number('7340014')->is_valid_number, '広島県広島市南区宇品西');
ok($zip->set_number('7340015')->is_valid_number, '広島県広島市南区宇品御幸');
ok($zip->set_number('7340016')->is_valid_number, '広島県広島市南区宇品町');
ok($zip->set_number('7340017')->is_valid_number, '広島県広島市南区似島町');
ok($zip->set_number('7340021')->is_valid_number, '広島県広島市南区上東雲町');
ok($zip->set_number('7340022')->is_valid_number, '広島県広島市南区東雲');
ok($zip->set_number('7340023')->is_valid_number, '広島県広島市南区東雲本町');
ok($zip->set_number('7340024')->is_valid_number, '広島県広島市南区仁保新町');
ok($zip->set_number('7340025')->is_valid_number, '広島県広島市南区東本浦町');
ok($zip->set_number('7340026')->is_valid_number, '広島県広島市南区仁保');
ok($zip->set_number('7340027')->is_valid_number, '広島県広島市南区仁保南');
ok($zip->set_number('7340031')->is_valid_number, '広島県広島市南区日宇那町');
ok($zip->set_number('7340032')->is_valid_number, '広島県広島市南区楠那町');
ok($zip->set_number('7340033')->is_valid_number, '広島県広島市南区丹那新町');
ok($zip->set_number('7340034')->is_valid_number, '広島県広島市南区丹那町');
ok($zip->set_number('7340035')->is_valid_number, '広島県広島市南区山城町');
ok($zip->set_number('7340036')->is_valid_number, '広島県広島市南区旭');
ok($zip->set_number('7340037')->is_valid_number, '広島県広島市南区霞');
ok($zip->set_number('7340041')->is_valid_number, '広島県広島市南区黄金山町');
ok($zip->set_number('7340042')->is_valid_number, '広島県広島市南区北大河町');
ok($zip->set_number('7340043')->is_valid_number, '広島県広島市南区南大河町');
ok($zip->set_number('7340044')->is_valid_number, '広島県広島市南区西霞町');
ok($zip->set_number('7340045')->is_valid_number, '広島県広島市南区西本浦町');
ok($zip->set_number('7340046')->is_valid_number, '広島県広島市南区東霞町');
ok($zip->set_number('7340047')->is_valid_number, '広島県広島市南区本浦町');
ok($zip->set_number('7340051')->is_valid_number, '広島県広島市南区東青崎町');
ok($zip->set_number('7340052')->is_valid_number, '広島県広島市南区堀越');
ok($zip->set_number('7340053')->is_valid_number, '広島県広島市南区青崎');
ok($zip->set_number('7340054')->is_valid_number, '広島県広島市南区月見町');
ok($zip->set_number('7340055')->is_valid_number, '広島県広島市南区向洋新町');
ok($zip->set_number('7340056')->is_valid_number, '広島県広島市南区向洋沖町');
ok($zip->set_number('7340057')->is_valid_number, '広島県広島市南区仁保沖町');
ok($zip->set_number('7340061')->is_valid_number, '広島県広島市南区向洋中町');
ok($zip->set_number('7340062')->is_valid_number, '広島県広島市南区向洋本町');
ok($zip->set_number('7340063')->is_valid_number, '広島県広島市南区向洋大原町');
ok($zip->set_number('7340064')->is_valid_number, '広島県広島市南区小磯町');
ok($zip->set_number('7340101')->is_valid_number, '広島県呉市豊浜町豊島');
ok($zip->set_number('7340102')->is_valid_number, '広島県呉市豊浜町大浜');
ok($zip->set_number('7340103')->is_valid_number, '広島県呉市豊浜町斎島');
ok($zip->set_number('7340301')->is_valid_number, '広島県呉市豊町大長');
ok($zip->set_number('7340302')->is_valid_number, '広島県呉市豊町御手洗');
ok($zip->set_number('7340303')->is_valid_number, '広島県呉市豊町沖友');
ok($zip->set_number('7340304')->is_valid_number, '広島県呉市豊町久比');
ok($zip->set_number('7350000')->is_valid_number, '広島県安芸郡府中町以下に掲載がない場合');
ok($zip->set_number('7350001')->is_valid_number, '広島県安芸郡府中町桜ケ丘');
ok($zip->set_number('7350002')->is_valid_number, '広島県安芸郡府中町清水ケ丘');
ok($zip->set_number('7350003')->is_valid_number, '広島県安芸郡府中町みくまり');
ok($zip->set_number('7350004')->is_valid_number, '広島県安芸郡府中町山田');
ok($zip->set_number('7350005')->is_valid_number, '広島県安芸郡府中町宮の町');
ok($zip->set_number('7350006')->is_valid_number, '広島県安芸郡府中町本町');
ok($zip->set_number('7350007')->is_valid_number, '広島県安芸郡府中町石井城');
ok($zip->set_number('7350008')->is_valid_number, '広島県安芸郡府中町鶴江');
ok($zip->set_number('7350009')->is_valid_number, '広島県安芸郡府中町城ケ丘');
ok($zip->set_number('7350011')->is_valid_number, '広島県安芸郡府中町瀬戸ハイム');
ok($zip->set_number('7350012')->is_valid_number, '広島県安芸郡府中町八幡');
ok($zip->set_number('7350013')->is_valid_number, '広島県安芸郡府中町浜田');
ok($zip->set_number('7350014')->is_valid_number, '広島県安芸郡府中町柳ケ丘');
ok($zip->set_number('7350015')->is_valid_number, '広島県安芸郡府中町青崎東');
ok($zip->set_number('7350016')->is_valid_number, '広島県安芸郡府中町青崎中');
ok($zip->set_number('7350017')->is_valid_number, '広島県安芸郡府中町青崎南');
ok($zip->set_number('7350021')->is_valid_number, '広島県安芸郡府中町大須');
ok($zip->set_number('7350022')->is_valid_number, '広島県安芸郡府中町大通');
ok($zip->set_number('7350023')->is_valid_number, '広島県安芸郡府中町浜田本町');
ok($zip->set_number('7350024')->is_valid_number, '広島県安芸郡府中町緑ケ丘');
ok($zip->set_number('7350025')->is_valid_number, '広島県安芸郡府中町鹿籠');
ok($zip->set_number('7350026')->is_valid_number, '広島県安芸郡府中町桃山');
ok($zip->set_number('7350027')->is_valid_number, '広島県安芸郡府中町千代');
ok($zip->set_number('7350028')->is_valid_number, '広島県安芸郡府中町新地');
ok($zip->set_number('7350029')->is_valid_number, '広島県安芸郡府中町茂陰');
ok($zip->set_number('7360000')->is_valid_number, '広島県広島市安芸区以下に掲載がない場合');
ok($zip->set_number('7360000')->is_valid_number, '広島県安芸郡海田町以下に掲載がない場合');
ok($zip->set_number('7360001')->is_valid_number, '広島県安芸郡海田町砂走');
ok($zip->set_number('7360002')->is_valid_number, '広島県安芸郡海田町国信');
ok($zip->set_number('7360003')->is_valid_number, '広島県安芸郡海田町曽田');
ok($zip->set_number('7360004')->is_valid_number, '広島県安芸郡海田町石原');
ok($zip->set_number('7360005')->is_valid_number, '広島県安芸郡海田町畝');
ok($zip->set_number('7360011')->is_valid_number, '広島県安芸郡海田町寺迫');
ok($zip->set_number('7360012')->is_valid_number, '広島県安芸郡海田町稲葉');
ok($zip->set_number('7360013')->is_valid_number, '広島県安芸郡海田町東');
ok($zip->set_number('7360014')->is_valid_number, '広島県安芸郡海田町三迫');
ok($zip->set_number('7360021')->is_valid_number, '広島県安芸郡海田町成本');
ok($zip->set_number('7360022')->is_valid_number, '広島県安芸郡海田町蟹原');
ok($zip->set_number('7360023')->is_valid_number, '広島県安芸郡海田町浜角');
ok($zip->set_number('7360024')->is_valid_number, '広島県安芸郡海田町西浜');
ok($zip->set_number('7360025')->is_valid_number, '広島県安芸郡海田町大立町');
ok($zip->set_number('7360026')->is_valid_number, '広島県安芸郡海田町幸町');
ok($zip->set_number('7360031')->is_valid_number, '広島県安芸郡海田町曙町');
ok($zip->set_number('7360032')->is_valid_number, '広島県安芸郡海田町南幸町');
ok($zip->set_number('7360033')->is_valid_number, '広島県安芸郡海田町南本町');
ok($zip->set_number('7360034')->is_valid_number, '広島県安芸郡海田町月見町');
ok($zip->set_number('7360035')->is_valid_number, '広島県安芸郡海田町日の出町');
ok($zip->set_number('7360041')->is_valid_number, '広島県安芸郡海田町大正町');
ok($zip->set_number('7360042')->is_valid_number, '広島県安芸郡海田町南大正町');
ok($zip->set_number('7360043')->is_valid_number, '広島県安芸郡海田町栄町');
ok($zip->set_number('7360044')->is_valid_number, '広島県安芸郡海田町南堀川町');
ok($zip->set_number('7360045')->is_valid_number, '広島県安芸郡海田町堀川町');
ok($zip->set_number('7360046')->is_valid_number, '広島県安芸郡海田町窪町');
ok($zip->set_number('7360051')->is_valid_number, '広島県安芸郡海田町つくも町');
ok($zip->set_number('7360052')->is_valid_number, '広島県安芸郡海田町南つくも町');
ok($zip->set_number('7360053')->is_valid_number, '広島県安芸郡海田町寿町');
ok($zip->set_number('7360054')->is_valid_number, '広島県安芸郡海田町西明神町');
ok($zip->set_number('7360055')->is_valid_number, '広島県安芸郡海田町南明神町');
ok($zip->set_number('7360056')->is_valid_number, '広島県安芸郡海田町明神町');
ok($zip->set_number('7360061')->is_valid_number, '広島県安芸郡海田町上市');
ok($zip->set_number('7360062')->is_valid_number, '広島県安芸郡海田町昭和町');
ok($zip->set_number('7360063')->is_valid_number, '広島県安芸郡海田町東昭和町');
ok($zip->set_number('7360064')->is_valid_number, '広島県安芸郡海田町昭和中町');
ok($zip->set_number('7360065')->is_valid_number, '広島県安芸郡海田町南昭和町');
ok($zip->set_number('7360066')->is_valid_number, '広島県安芸郡海田町中店');
ok($zip->set_number('7360067')->is_valid_number, '広島県安芸郡海田町稲荷町');
ok($zip->set_number('7360068')->is_valid_number, '広島県安芸郡海田町新町');
ok($zip->set_number('7360071')->is_valid_number, '広島県安芸郡海田町東海田');
ok($zip->set_number('7360081')->is_valid_number, '広島県広島市安芸区船越');
ok($zip->set_number('7360082')->is_valid_number, '広島県広島市安芸区船越南');
ok($zip->set_number('7360083')->is_valid_number, '広島県広島市安芸区矢野東');
ok($zip->set_number('7360084')->is_valid_number, '広島県広島市安芸区矢野新町');
ok($zip->set_number('7360085')->is_valid_number, '広島県広島市安芸区矢野西');
ok($zip->set_number('7360086')->is_valid_number, '広島県広島市安芸区矢野南');
ok($zip->set_number('7360087')->is_valid_number, '広島県広島市安芸区矢野町');
ok($zip->set_number('7360088')->is_valid_number, '広島県広島市安芸区畑賀');
ok($zip->set_number('7360089')->is_valid_number, '広島県広島市安芸区畑賀町');
ok($zip->set_number('7370000')->is_valid_number, '広島県呉市以下に掲載がない場合');
ok($zip->set_number('7370001')->is_valid_number, '広島県呉市阿賀北');
ok($zip->set_number('7370002')->is_valid_number, '広島県呉市広町(大空山)');
ok($zip->set_number('7370003')->is_valid_number, '広島県呉市阿賀中央');
ok($zip->set_number('7370004')->is_valid_number, '広島県呉市阿賀南');
ok($zip->set_number('7370005')->is_valid_number, '広島県呉市阿賀町');
ok($zip->set_number('7370011')->is_valid_number, '広島県呉市見晴');
ok($zip->set_number('7370012')->is_valid_number, '広島県呉市警固屋');
ok($zip->set_number('7370013')->is_valid_number, '広島県呉市的場');
ok($zip->set_number('7370014')->is_valid_number, '広島県呉市坪ノ内町');
ok($zip->set_number('7370015')->is_valid_number, '広島県呉市船見町');
ok($zip->set_number('7370021')->is_valid_number, '広島県呉市三和町');
ok($zip->set_number('7370022')->is_valid_number, '広島県呉市清水');
ok($zip->set_number('7370023')->is_valid_number, '広島県呉市青山町');
ok($zip->set_number('7370024')->is_valid_number, '広島県呉市宮原');
ok($zip->set_number('7370025')->is_valid_number, '広島県呉市室瀬町');
ok($zip->set_number('7370026')->is_valid_number, '広島県呉市神原町');
ok($zip->set_number('7370027')->is_valid_number, '広島県呉市昭和町');
ok($zip->set_number('7370028')->is_valid_number, '広島県呉市幸町');
ok($zip->set_number('7370029')->is_valid_number, '広島県呉市宝町');
ok($zip->set_number('7370031')->is_valid_number, '広島県呉市上長迫町');
ok($zip->set_number('7370032')->is_valid_number, '広島県呉市本町');
ok($zip->set_number('7370033')->is_valid_number, '広島県呉市寺本町');
ok($zip->set_number('7370034')->is_valid_number, '広島県呉市溝路町');
ok($zip->set_number('7370035')->is_valid_number, '広島県呉市長迫町');
ok($zip->set_number('7370041')->is_valid_number, '広島県呉市和庄');
ok($zip->set_number('7370042')->is_valid_number, '広島県呉市和庄本町');
ok($zip->set_number('7370043')->is_valid_number, '広島県呉市和庄登町');
ok($zip->set_number('7370044')->is_valid_number, '広島県呉市八幡町');
ok($zip->set_number('7370045')->is_valid_number, '広島県呉市本通');
ok($zip->set_number('7370046')->is_valid_number, '広島県呉市中通');
ok($zip->set_number('7370051')->is_valid_number, '広島県呉市中央');
ok($zip->set_number('7370052')->is_valid_number, '広島県呉市東中央');
ok($zip->set_number('7370053')->is_valid_number, '広島県呉市長ノ木町');
ok($zip->set_number('7370054')->is_valid_number, '広島県呉市上山田町');
ok($zip->set_number('7370055')->is_valid_number, '広島県呉市下山田町');
ok($zip->set_number('7370056')->is_valid_number, '広島県呉市朝日町');
ok($zip->set_number('7370061')->is_valid_number, '広島県呉市畝原町');
ok($zip->set_number('7370062')->is_valid_number, '広島県呉市西惣付町');
ok($zip->set_number('7370063')->is_valid_number, '広島県呉市東惣付町');
ok($zip->set_number('7370064')->is_valid_number, '広島県呉市西谷町');
ok($zip->set_number('7370065')->is_valid_number, '広島県呉市望地町');
ok($zip->set_number('7370071')->is_valid_number, '広島県呉市上畑町');
ok($zip->set_number('7370072')->is_valid_number, '広島県呉市東畑');
ok($zip->set_number('7370073')->is_valid_number, '広島県呉市東鹿田町');
ok($zip->set_number('7370074')->is_valid_number, '広島県呉市西鹿田');
ok($zip->set_number('7370075')->is_valid_number, '広島県呉市西畑町');
ok($zip->set_number('7370076')->is_valid_number, '広島県呉市吾妻');
ok($zip->set_number('7370077')->is_valid_number, '広島県呉市伏原');
ok($zip->set_number('7370078')->is_valid_number, '広島県呉市平原町');
ok($zip->set_number('7370079')->is_valid_number, '広島県呉市上平原町');
ok($zip->set_number('7370101')->is_valid_number, '広島県呉市広石内');
ok($zip->set_number('7370102')->is_valid_number, '広島県呉市広徳丸町');
ok($zip->set_number('7370103')->is_valid_number, '広島県呉市広塩焼');
ok($zip->set_number('7370104')->is_valid_number, '広島県呉市広町田');
ok($zip->set_number('7370105')->is_valid_number, '広島県呉市広中迫町');
ok($zip->set_number('7370106')->is_valid_number, '広島県呉市広三芦');
ok($zip->set_number('7370107')->is_valid_number, '広島県呉市広弁天橋町');
ok($zip->set_number('7370111')->is_valid_number, '広島県呉市広大広');
ok($zip->set_number('7370112')->is_valid_number, '広島県呉市広古新開');
ok($zip->set_number('7370113')->is_valid_number, '広島県呉市広横路');
ok($zip->set_number('7370114')->is_valid_number, '広島県呉市広文化町');
ok($zip->set_number('7370115')->is_valid_number, '広島県呉市広町(その他)');
ok($zip->set_number('7370121')->is_valid_number, '広島県呉市広吉松');
ok($zip->set_number('7370122')->is_valid_number, '広島県呉市広杭本町');
ok($zip->set_number('7370123')->is_valid_number, '広島県呉市広両谷');
ok($zip->set_number('7370124')->is_valid_number, '広島県呉市広中新開');
ok($zip->set_number('7370125')->is_valid_number, '広島県呉市広本町');
ok($zip->set_number('7370131')->is_valid_number, '広島県呉市広中町');
ok($zip->set_number('7370132')->is_valid_number, '広島県呉市広名田');
ok($zip->set_number('7370133')->is_valid_number, '広島県呉市広末広');
ok($zip->set_number('7370134')->is_valid_number, '広島県呉市広多賀谷');
ok($zip->set_number('7370135')->is_valid_number, '広島県呉市広津久茂町');
ok($zip->set_number('7370136')->is_valid_number, '広島県呉市広長浜');
ok($zip->set_number('7370137')->is_valid_number, '広島県呉市広小坪');
ok($zip->set_number('7370138')->is_valid_number, '広島県呉市広黄幡町');
ok($zip->set_number('7370141')->is_valid_number, '広島県呉市広大新開');
ok($zip->set_number('7370142')->is_valid_number, '広島県呉市広駅前');
ok($zip->set_number('7370143')->is_valid_number, '広島県呉市広白石');
ok($zip->set_number('7370144')->is_valid_number, '広島県呉市広白岳');
ok($zip->set_number('7370145')->is_valid_number, '広島県呉市仁方西神町');
ok($zip->set_number('7370146')->is_valid_number, '広島県呉市仁方宮上町');
ok($zip->set_number('7370151')->is_valid_number, '広島県呉市仁方中筋町');
ok($zip->set_number('7370152')->is_valid_number, '広島県呉市仁方本町');
ok($zip->set_number('7370153')->is_valid_number, '広島県呉市仁方大歳町');
ok($zip->set_number('7370154')->is_valid_number, '広島県呉市仁方桟橋通');
ok($zip->set_number('7370155')->is_valid_number, '広島県呉市仁方錦町');
ok($zip->set_number('7370156')->is_valid_number, '広島県呉市仁方皆実町');
ok($zip->set_number('7370157')->is_valid_number, '広島県呉市仁方町(その他)');
ok($zip->set_number('7370161')->is_valid_number, '広島県呉市郷原町');
ok($zip->set_number('7370162')->is_valid_number, '広島県呉市郷原学びの丘');
ok($zip->set_number('7370163')->is_valid_number, '広島県呉市郷原野路の里');
ok($zip->set_number('7370301')->is_valid_number, '広島県呉市下蒲刈町三之瀬');
ok($zip->set_number('7370302')->is_valid_number, '広島県呉市下蒲刈町大地蔵');
ok($zip->set_number('7370303')->is_valid_number, '広島県呉市下蒲刈町下島');
ok($zip->set_number('7370311')->is_valid_number, '広島県呉市蒲刈町向');
ok($zip->set_number('7370401')->is_valid_number, '広島県呉市蒲刈町宮盛');
ok($zip->set_number('7370402')->is_valid_number, '広島県呉市蒲刈町大浦');
ok($zip->set_number('7370403')->is_valid_number, '広島県呉市蒲刈町田戸');
ok($zip->set_number('7370801')->is_valid_number, '広島県呉市東辰川町');
ok($zip->set_number('7370802')->is_valid_number, '広島県呉市南辰川町');
ok($zip->set_number('7370803')->is_valid_number, '広島県呉市郷町');
ok($zip->set_number('7370804')->is_valid_number, '広島県呉市内神町');
ok($zip->set_number('7370805')->is_valid_number, '広島県呉市東片山町');
ok($zip->set_number('7370806')->is_valid_number, '広島県呉市西片山町');
ok($zip->set_number('7370807')->is_valid_number, '広島県呉市江原町');
ok($zip->set_number('7370808')->is_valid_number, '広島県呉市上内神町');
ok($zip->set_number('7370809')->is_valid_number, '広島県呉市西辰川');
ok($zip->set_number('7370811')->is_valid_number, '広島県呉市西中央');
ok($zip->set_number('7370812')->is_valid_number, '広島県呉市西三津田町');
ok($zip->set_number('7370813')->is_valid_number, '広島県呉市東三津田町');
ok($zip->set_number('7370814')->is_valid_number, '広島県呉市山手');
ok($zip->set_number('7370815')->is_valid_number, '広島県呉市荘山田村(二河山)');
ok($zip->set_number('7370816')->is_valid_number, '広島県呉市二河峡町');
ok($zip->set_number('7370817')->is_valid_number, '広島県呉市上二河町');
ok($zip->set_number('7370818')->is_valid_number, '広島県呉市二河町');
ok($zip->set_number('7370821')->is_valid_number, '広島県呉市三条');
ok($zip->set_number('7370822')->is_valid_number, '広島県呉市築地町');
ok($zip->set_number('7370823')->is_valid_number, '広島県呉市海岸');
ok($zip->set_number('7370824')->is_valid_number, '広島県呉市東川原石町');
ok($zip->set_number('7370825')->is_valid_number, '広島県呉市西川原石町');
ok($zip->set_number('7370826')->is_valid_number, '広島県呉市両城');
ok($zip->set_number('7370827')->is_valid_number, '広島県呉市西愛宕町');
ok($zip->set_number('7370828')->is_valid_number, '広島県呉市東愛宕町');
ok($zip->set_number('7370831')->is_valid_number, '広島県呉市光町');
ok($zip->set_number('7370832')->is_valid_number, '広島県呉市若葉町');
ok($zip->set_number('7370833')->is_valid_number, '広島県呉市晴海町');
ok($zip->set_number('7370834')->is_valid_number, '広島県呉市瀬戸見町');
ok($zip->set_number('7370835')->is_valid_number, '広島県呉市新宮町');
ok($zip->set_number('7370836')->is_valid_number, '広島県呉市北塩屋町');
ok($zip->set_number('7370837')->is_valid_number, '広島県呉市東塩屋町');
ok($zip->set_number('7370838')->is_valid_number, '広島県呉市西塩屋町');
ok($zip->set_number('7370841')->is_valid_number, '広島県呉市吉浦神賀町');
ok($zip->set_number('7370842')->is_valid_number, '広島県呉市吉浦東町');
ok($zip->set_number('7370843')->is_valid_number, '広島県呉市吉浦潭鼓町');
ok($zip->set_number('7370844')->is_valid_number, '広島県呉市吉浦池ノ浦町');
ok($zip->set_number('7370845')->is_valid_number, '広島県呉市吉浦新町');
ok($zip->set_number('7370846')->is_valid_number, '広島県呉市吉浦町(乙廻り)');
ok($zip->set_number('7370851')->is_valid_number, '広島県呉市吉浦新出町');
ok($zip->set_number('7370852')->is_valid_number, '広島県呉市吉浦東本町');
ok($zip->set_number('7370853')->is_valid_number, '広島県呉市吉浦中町');
ok($zip->set_number('7370854')->is_valid_number, '広島県呉市吉浦町(その他)');
ok($zip->set_number('7370861')->is_valid_number, '広島県呉市吉浦本町');
ok($zip->set_number('7370862')->is_valid_number, '広島県呉市狩留賀町');
ok($zip->set_number('7370863')->is_valid_number, '広島県呉市吉浦宮花町');
ok($zip->set_number('7370864')->is_valid_number, '広島県呉市吉浦西城町');
ok($zip->set_number('7370865')->is_valid_number, '広島県呉市吉浦岩神町');
ok($zip->set_number('7370866')->is_valid_number, '広島県呉市吉浦松葉町');
ok($zip->set_number('7370867')->is_valid_number, '広島県呉市吉浦上城町');
ok($zip->set_number('7370871')->is_valid_number, '広島県呉市長谷町');
ok($zip->set_number('7370872')->is_valid_number, '広島県呉市梅木町');
ok($zip->set_number('7370873')->is_valid_number, '広島県呉市汐見町');
ok($zip->set_number('7370874')->is_valid_number, '広島県呉市天応南町');
ok($zip->set_number('7370875')->is_valid_number, '広島県呉市天応大浜');
ok($zip->set_number('7370876')->is_valid_number, '広島県呉市天応宮町');
ok($zip->set_number('7370877')->is_valid_number, '広島県呉市弥生町');
ok($zip->set_number('7370878')->is_valid_number, '広島県呉市大山町');
ok($zip->set_number('7370881')->is_valid_number, '広島県呉市天応塩谷町');
ok($zip->set_number('7370882')->is_valid_number, '広島県呉市天応東久保');
ok($zip->set_number('7370883')->is_valid_number, '広島県呉市天応西条');
ok($zip->set_number('7370884')->is_valid_number, '広島県呉市天応伝十原町');
ok($zip->set_number('7370885')->is_valid_number, '広島県呉市天応福浦町');
ok($zip->set_number('7370901')->is_valid_number, '広島県呉市焼山ひばりケ丘町');
ok($zip->set_number('7370902')->is_valid_number, '広島県呉市焼山此原町');
ok($zip->set_number('7370903')->is_valid_number, '広島県呉市焼山西');
ok($zip->set_number('7370904')->is_valid_number, '広島県呉市焼山(打田)');
ok($zip->set_number('7370905')->is_valid_number, '広島県呉市焼山町(山の神)');
ok($zip->set_number('7370906')->is_valid_number, '広島県呉市焼山町(野登呂)');
ok($zip->set_number('7370907')->is_valid_number, '広島県呉市焼山町(その他)');
ok($zip->set_number('7370908')->is_valid_number, '広島県呉市焼山宮ケ迫');
ok($zip->set_number('7370911')->is_valid_number, '広島県呉市焼山北');
ok($zip->set_number('7370912')->is_valid_number, '広島県呉市焼山本庄');
ok($zip->set_number('7370913')->is_valid_number, '広島県呉市焼山泉ケ丘');
ok($zip->set_number('7370914')->is_valid_number, '広島県呉市押込西平町');
ok($zip->set_number('7370915')->is_valid_number, '広島県呉市押込');
ok($zip->set_number('7370921')->is_valid_number, '広島県呉市苗代町');
ok($zip->set_number('7370922')->is_valid_number, '広島県呉市栃原町');
ok($zip->set_number('7370923')->is_valid_number, '広島県呉市神山');
ok($zip->set_number('7370924')->is_valid_number, '広島県呉市焼山南');
ok($zip->set_number('7370931')->is_valid_number, '広島県呉市焼山三ツ石町');
ok($zip->set_number('7370932')->is_valid_number, '広島県呉市焼山松ケ丘');
ok($zip->set_number('7370933')->is_valid_number, '広島県呉市焼山桜ケ丘');
ok($zip->set_number('7370934')->is_valid_number, '広島県呉市焼山政畝');
ok($zip->set_number('7370935')->is_valid_number, '広島県呉市焼山中央');
ok($zip->set_number('7370936')->is_valid_number, '広島県呉市焼山東');
ok($zip->set_number('7371201')->is_valid_number, '広島県呉市音戸町坪井');
ok($zip->set_number('7371202')->is_valid_number, '広島県呉市音戸町引地');
ok($zip->set_number('7371203')->is_valid_number, '広島県呉市音戸町鰯浜');
ok($zip->set_number('7371204')->is_valid_number, '広島県呉市音戸町北隠渡');
ok($zip->set_number('7371205')->is_valid_number, '広島県呉市音戸町南隠渡');
ok($zip->set_number('7371206')->is_valid_number, '広島県呉市音戸町高須');
ok($zip->set_number('7371207')->is_valid_number, '広島県呉市音戸町波多見');
ok($zip->set_number('7371211')->is_valid_number, '広島県呉市音戸町畑');
ok($zip->set_number('7371212')->is_valid_number, '広島県呉市音戸町有清');
ok($zip->set_number('7371213')->is_valid_number, '広島県呉市音戸町先奥');
ok($zip->set_number('7371214')->is_valid_number, '広島県呉市音戸町藤脇');
ok($zip->set_number('7371215')->is_valid_number, '広島県呉市音戸町早瀬');
ok($zip->set_number('7371216')->is_valid_number, '広島県呉市音戸町田原');
ok($zip->set_number('7371217')->is_valid_number, '広島県呉市音戸町渡子');
ok($zip->set_number('7371377')->is_valid_number, '広島県呉市倉橋町');
ok($zip->set_number('7372100')->is_valid_number, '広島県江田島市以下に掲載がない場合');
ok($zip->set_number('7372101')->is_valid_number, '広島県江田島市大柿町飛渡瀬');
ok($zip->set_number('7372111')->is_valid_number, '広島県江田島市江田島町切串');
ok($zip->set_number('7372112')->is_valid_number, '広島県江田島市江田島町幸ノ浦');
ok($zip->set_number('7372113')->is_valid_number, '広島県江田島市江田島町大須');
ok($zip->set_number('7372121')->is_valid_number, '広島県江田島市江田島町小用');
ok($zip->set_number('7372122')->is_valid_number, '広島県江田島市江田島町中央');
ok($zip->set_number('7372123')->is_valid_number, '広島県江田島市江田島町国有無番地');
ok($zip->set_number('7372124')->is_valid_number, '広島県江田島市江田島町宮ノ原');
ok($zip->set_number('7372125')->is_valid_number, '広島県江田島市江田島町大原特借宿舎');
ok($zip->set_number('7372126')->is_valid_number, '広島県江田島市江田島町津久茂');
ok($zip->set_number('7372131')->is_valid_number, '広島県江田島市江田島町秋月');
ok($zip->set_number('7372132')->is_valid_number, '広島県江田島市江田島町江南');
ok($zip->set_number('7372133')->is_valid_number, '広島県江田島市江田島町鷲部');
ok($zip->set_number('7372211')->is_valid_number, '広島県江田島市大柿町柿浦');
ok($zip->set_number('7372212')->is_valid_number, '広島県江田島市大柿町大君');
ok($zip->set_number('7372213')->is_valid_number, '広島県江田島市大柿町大原');
ok($zip->set_number('7372214')->is_valid_number, '広島県江田島市大柿町深江');
ok($zip->set_number('7372215')->is_valid_number, '広島県江田島市大柿町小古江');
ok($zip->set_number('7372301')->is_valid_number, '広島県江田島市能美町中町');
ok($zip->set_number('7372302')->is_valid_number, '広島県江田島市能美町鹿川');
ok($zip->set_number('7372303')->is_valid_number, '広島県江田島市能美町高田');
ok($zip->set_number('7372311')->is_valid_number, '広島県江田島市沖美町岡大王');
ok($zip->set_number('7372312')->is_valid_number, '広島県江田島市沖美町畑');
ok($zip->set_number('7372313')->is_valid_number, '広島県江田島市沖美町是長');
ok($zip->set_number('7372314')->is_valid_number, '広島県江田島市沖美町美能');
ok($zip->set_number('7372315')->is_valid_number, '広島県江田島市沖美町高祖');
ok($zip->set_number('7372316')->is_valid_number, '広島県江田島市沖美町三吉');
ok($zip->set_number('7372501')->is_valid_number, '広島県呉市安浦町女子畑');
ok($zip->set_number('7372502')->is_valid_number, '広島県呉市安浦町三津口');
ok($zip->set_number('7372503')->is_valid_number, '広島県呉市安浦町安登');
ok($zip->set_number('7372504')->is_valid_number, '広島県呉市安浦町中切(その他)');
ok($zip->set_number('7372505')->is_valid_number, '広島県呉市安浦町内平');
ok($zip->set_number('7372506')->is_valid_number, '広島県呉市安浦町原畑');
ok($zip->set_number('7372507')->is_valid_number, '広島県呉市安浦町内海');
ok($zip->set_number('7372508')->is_valid_number, '広島県呉市安浦町中畑(その他)');
ok($zip->set_number('7372509')->is_valid_number, '広島県呉市安浦町下垣内');
ok($zip->set_number('7372511')->is_valid_number, '広島県呉市安浦町赤向坂');
ok($zip->set_number('7372512')->is_valid_number, '広島県呉市安浦町安登西');
ok($zip->set_number('7372513')->is_valid_number, '広島県呉市安浦町安登東');
ok($zip->set_number('7372514')->is_valid_number, '広島県呉市安浦町中央ハイツ');
ok($zip->set_number('7372515')->is_valid_number, '広島県呉市安浦町中央北');
ok($zip->set_number('7372516')->is_valid_number, '広島県呉市安浦町中央');
ok($zip->set_number('7372517')->is_valid_number, '広島県呉市安浦町水尻');
ok($zip->set_number('7372518')->is_valid_number, '広島県呉市安浦町内海北');
ok($zip->set_number('7372519')->is_valid_number, '広島県呉市安浦町内海南');
ok($zip->set_number('7372601')->is_valid_number, '広島県呉市川尻町原山');
ok($zip->set_number('7372602')->is_valid_number, '広島県呉市川尻町森');
ok($zip->set_number('7372603')->is_valid_number, '広島県呉市川尻町西');
ok($zip->set_number('7372604')->is_valid_number, '広島県呉市川尻町小仁方');
ok($zip->set_number('7372605')->is_valid_number, '広島県呉市川尻町久俊');
ok($zip->set_number('7372606')->is_valid_number, '広島県呉市川尻町久筋');
ok($zip->set_number('7372607')->is_valid_number, '広島県呉市川尻町東');
ok($zip->set_number('7372608')->is_valid_number, '広島県呉市川尻町小用');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市川尻町野呂山');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市仁方町(蕨谷)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市野呂山');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市広町(一本杉)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町中切(奥野原)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町中畑(鹿条原)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町中畑(侍屋敷)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町中畑(膳棚山)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町中畑(立小路)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町中畑(中央)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町中畑(東)');
ok($zip->set_number('7372609')->is_valid_number, '広島県呉市安浦町野呂山');
ok($zip->set_number('7372614')->is_valid_number, '広島県呉市川尻町大原');
ok($zip->set_number('7372615')->is_valid_number, '広島県呉市川尻町真光地');
ok($zip->set_number('7372616')->is_valid_number, '広島県呉市川尻町水落');
ok($zip->set_number('7372617')->is_valid_number, '広島県呉市川尻町小畑');
ok($zip->set_number('7372631')->is_valid_number, '広島県呉市川尻町板休');
ok($zip->set_number('7372632')->is_valid_number, '広島県呉市川尻町上畑');
ok($zip->set_number('7372633')->is_valid_number, '広島県呉市川尻町沖田');
ok($zip->set_number('7372634')->is_valid_number, '広島県呉市川尻町岩戸');
ok($zip->set_number('7372635')->is_valid_number, '広島県呉市川尻町柳迫');
ok($zip->set_number('7372636')->is_valid_number, '広島県呉市川尻町才野谷');
ok($zip->set_number('7372637')->is_valid_number, '広島県呉市川尻町後懸');
ok($zip->set_number('7380000')->is_valid_number, '広島県廿日市市以下に掲載がない場合');
ok($zip->set_number('7380001')->is_valid_number, '広島県廿日市市佐方');
ok($zip->set_number('7380002')->is_valid_number, '広島県廿日市市山陽園');
ok($zip->set_number('7380003')->is_valid_number, '広島県廿日市市佐方本町');
ok($zip->set_number('7380004')->is_valid_number, '広島県廿日市市桜尾');
ok($zip->set_number('7380005')->is_valid_number, '広島県廿日市市桜尾本町');
ok($zip->set_number('7380006')->is_valid_number, '広島県廿日市市大東');
ok($zip->set_number('7380007')->is_valid_number, '広島県廿日市市城内');
ok($zip->set_number('7380011')->is_valid_number, '広島県廿日市市駅前');
ok($zip->set_number('7380012')->is_valid_number, '広島県廿日市市天神');
ok($zip->set_number('7380013')->is_valid_number, '広島県廿日市市廿日市');
ok($zip->set_number('7380014')->is_valid_number, '広島県廿日市市住吉');
ok($zip->set_number('7380015')->is_valid_number, '広島県廿日市市本町');
ok($zip->set_number('7380016')->is_valid_number, '広島県廿日市市可愛');
ok($zip->set_number('7380017')->is_valid_number, '広島県廿日市市須賀');
ok($zip->set_number('7380021')->is_valid_number, '広島県廿日市市木材港北');
ok($zip->set_number('7380022')->is_valid_number, '広島県廿日市市木材港南');
ok($zip->set_number('7380023')->is_valid_number, '広島県廿日市市下平良');
ok($zip->set_number('7380024')->is_valid_number, '広島県廿日市市新宮');
ok($zip->set_number('7380025')->is_valid_number, '広島県廿日市市平良');
ok($zip->set_number('7380026')->is_valid_number, '広島県廿日市市上平良');
ok($zip->set_number('7380027')->is_valid_number, '広島県廿日市市平良山手');
ok($zip->set_number('7380031')->is_valid_number, '広島県廿日市市原');
ok($zip->set_number('7380032')->is_valid_number, '広島県廿日市市峰高');
ok($zip->set_number('7380033')->is_valid_number, '広島県廿日市市串戸');
ok($zip->set_number('7380034')->is_valid_number, '広島県廿日市市宮内');
ok($zip->set_number('7380035')->is_valid_number, '広島県廿日市市宮園');
ok($zip->set_number('7380036')->is_valid_number, '広島県廿日市市四季が丘');
ok($zip->set_number('7380037')->is_valid_number, '広島県廿日市市宮園上');
ok($zip->set_number('7380038')->is_valid_number, '広島県廿日市市四季が丘上');
ok($zip->set_number('7380039')->is_valid_number, '広島県廿日市市宮内工業団地');
ok($zip->set_number('7380041')->is_valid_number, '広島県廿日市市六本松');
ok($zip->set_number('7380042')->is_valid_number, '広島県廿日市市地御前');
ok($zip->set_number('7380043')->is_valid_number, '広島県廿日市市地御前北');
ok($zip->set_number('7380051')->is_valid_number, '広島県廿日市市阿品台北');
ok($zip->set_number('7380052')->is_valid_number, '広島県廿日市市阿品台東');
ok($zip->set_number('7380053')->is_valid_number, '広島県廿日市市阿品台');
ok($zip->set_number('7380054')->is_valid_number, '広島県廿日市市阿品');
ok($zip->set_number('7380055')->is_valid_number, '広島県廿日市市阿品台西');
ok($zip->set_number('7380056')->is_valid_number, '広島県廿日市市阿品台山の手');
ok($zip->set_number('7380060')->is_valid_number, '広島県廿日市市陽光台');
ok($zip->set_number('7380201')->is_valid_number, '広島県廿日市市永原');
ok($zip->set_number('7380202')->is_valid_number, '広島県廿日市市峠');
ok($zip->set_number('7380203')->is_valid_number, '広島県廿日市市友田');
ok($zip->set_number('7380204')->is_valid_number, '広島県廿日市市河津原');
ok($zip->set_number('7380205')->is_valid_number, '広島県廿日市市玖島');
ok($zip->set_number('7380221')->is_valid_number, '広島県廿日市市虫所山');
ok($zip->set_number('7380222')->is_valid_number, '広島県廿日市市津田');
ok($zip->set_number('7380223')->is_valid_number, '広島県廿日市市浅原');
ok($zip->set_number('7380224')->is_valid_number, '広島県廿日市市栗栖');
ok($zip->set_number('7380225')->is_valid_number, '広島県廿日市市中道');
ok($zip->set_number('7380226')->is_valid_number, '広島県廿日市市飯山');
ok($zip->set_number('7380281')->is_valid_number, '広島県廿日市市大野鴉ケ岡');
ok($zip->set_number('7380282')->is_valid_number, '広島県廿日市市大野渡ノ瀬');
ok($zip->set_number('7380301')->is_valid_number, '広島県廿日市市吉和');
ok($zip->set_number('7380511')->is_valid_number, '広島県広島市佐伯区湯来町葛原');
ok($zip->set_number('7380512')->is_valid_number, '広島県広島市佐伯区湯来町白砂');
ok($zip->set_number('7380513')->is_valid_number, '広島県広島市佐伯区湯来町菅沢(黒谷)');
ok($zip->set_number('7380513')->is_valid_number, '広島県広島市佐伯区湯来町伏谷');
ok($zip->set_number('7380514')->is_valid_number, '広島県広島市佐伯区杉並台');
ok($zip->set_number('7380601')->is_valid_number, '広島県広島市佐伯区湯来町和田');
ok($zip->set_number('7380602')->is_valid_number, '広島県広島市佐伯区湯来町麦谷');
ok($zip->set_number('7380603')->is_valid_number, '広島県広島市佐伯区湯来町下');
ok($zip->set_number('7380721')->is_valid_number, '広島県広島市佐伯区湯来町多田');
ok($zip->set_number('7380722')->is_valid_number, '広島県広島市佐伯区湯来町菅沢(その他)');
ok($zip->set_number('7390000')->is_valid_number, '広島県東広島市以下に掲載がない場合');
ok($zip->set_number('7390001')->is_valid_number, '広島県東広島市西条町西条');
ok($zip->set_number('7390002')->is_valid_number, '広島県東広島市西条町吉行');
ok($zip->set_number('7390003')->is_valid_number, '広島県東広島市西条町土与丸');
ok($zip->set_number('7390004')->is_valid_number, '広島県東広島市西条末広町');
ok($zip->set_number('7390005')->is_valid_number, '広島県東広島市西条大坪町');
ok($zip->set_number('7390006')->is_valid_number, '広島県東広島市西条上市町');
ok($zip->set_number('7390007')->is_valid_number, '広島県東広島市西条土与丸');
ok($zip->set_number('7390008')->is_valid_number, '広島県東広島市西条吉行東');
ok($zip->set_number('7390011')->is_valid_number, '広島県東広島市西条本町');
ok($zip->set_number('7390012')->is_valid_number, '広島県東広島市西条朝日町');
ok($zip->set_number('7390013')->is_valid_number, '広島県東広島市西条御条町');
ok($zip->set_number('7390014')->is_valid_number, '広島県東広島市西条昭和町');
ok($zip->set_number('7390015')->is_valid_number, '広島県東広島市西条栄町');
ok($zip->set_number('7390016')->is_valid_number, '広島県東広島市西条岡町');
ok($zip->set_number('7390021')->is_valid_number, '広島県東広島市西条町助実');
ok($zip->set_number('7390022')->is_valid_number, '広島県東広島市西条町上三永');
ok($zip->set_number('7390023')->is_valid_number, '広島県東広島市西条町下三永');
ok($zip->set_number('7390024')->is_valid_number, '広島県東広島市西条町御薗宇');
ok($zip->set_number('7390025')->is_valid_number, '広島県東広島市西条中央');
ok($zip->set_number('7390026')->is_valid_number, '広島県東広島市三永');
ok($zip->set_number('7390031')->is_valid_number, '広島県東広島市西条町福本');
ok($zip->set_number('7390032')->is_valid_number, '広島県東広島市西条町森近');
ok($zip->set_number('7390033')->is_valid_number, '広島県東広島市西条町馬木');
ok($zip->set_number('7390034')->is_valid_number, '広島県東広島市西条町大沢');
ok($zip->set_number('7390035')->is_valid_number, '広島県東広島市西条町郷曽');
ok($zip->set_number('7390036')->is_valid_number, '広島県東広島市西条町田口');
ok($zip->set_number('7390037')->is_valid_number, '広島県東広島市西大沢');
ok($zip->set_number('7390038')->is_valid_number, '広島県東広島市田口研究団地');
ok($zip->set_number('7390040')->is_valid_number, '広島県東広島市寺家駅前');
ok($zip->set_number('7390041')->is_valid_number, '広島県東広島市西条町寺家');
ok($zip->set_number('7390042')->is_valid_number, '広島県東広島市西条町西条東');
ok($zip->set_number('7390043')->is_valid_number, '広島県東広島市西条西本町');
ok($zip->set_number('7390044')->is_valid_number, '広島県東広島市西条町下見');
ok($zip->set_number('7390045')->is_valid_number, '広島県東広島市鏡山北');
ok($zip->set_number('7390046')->is_valid_number, '広島県東広島市鏡山');
ok($zip->set_number('7390047')->is_valid_number, '広島県東広島市西条下見');
ok($zip->set_number('7390048')->is_valid_number, '広島県東広島市西条東北町');
ok($zip->set_number('7390049')->is_valid_number, '広島県東広島市寺家産業団地');
ok($zip->set_number('7390131')->is_valid_number, '広島県東広島市八本松町篠');
ok($zip->set_number('7390132')->is_valid_number, '広島県東広島市八本松町正力');
ok($zip->set_number('7390133')->is_valid_number, '広島県東広島市八本松町米満');
ok($zip->set_number('7390141')->is_valid_number, '広島県東広島市八本松町飯田');
ok($zip->set_number('7390142')->is_valid_number, '広島県東広島市八本松東');
ok($zip->set_number('7390144')->is_valid_number, '広島県東広島市八本松南');
ok($zip->set_number('7390145')->is_valid_number, '広島県東広島市八本松町宗吉');
ok($zip->set_number('7390146')->is_valid_number, '広島県東広島市八本松飯田');
ok($zip->set_number('7390147')->is_valid_number, '広島県東広島市八本松西');
ok($zip->set_number('7390151')->is_valid_number, '広島県東広島市八本松町原');
ok($zip->set_number('7390152')->is_valid_number, '広島県東広島市八本松町吉川');
ok($zip->set_number('7390153')->is_valid_number, '広島県東広島市吉川工業団地');
ok($zip->set_number('7390261')->is_valid_number, '広島県東広島市志和町内');
ok($zip->set_number('7390262')->is_valid_number, '広島県東広島市志和町志和東');
ok($zip->set_number('7390263')->is_valid_number, '広島県東広島市志和流通');
ok($zip->set_number('7390264')->is_valid_number, '広島県東広島市志和町七条椛坂');
ok($zip->set_number('7390265')->is_valid_number, '広島県東広島市志和町冠');
ok($zip->set_number('7390266')->is_valid_number, '広島県東広島市志和町奥屋');
ok($zip->set_number('7390267')->is_valid_number, '広島県東広島市志和町別府');
ok($zip->set_number('7390268')->is_valid_number, '広島県東広島市志和町志和西');
ok($zip->set_number('7390269')->is_valid_number, '広島県東広島市志和町志和堀');
ok($zip->set_number('7390301')->is_valid_number, '広島県広島市安芸区上瀬野');
ok($zip->set_number('7390302')->is_valid_number, '広島県広島市安芸区上瀬野町');
ok($zip->set_number('7390303')->is_valid_number, '広島県広島市安芸区上瀬野南');
ok($zip->set_number('7390311')->is_valid_number, '広島県広島市安芸区瀬野');
ok($zip->set_number('7390312')->is_valid_number, '広島県広島市安芸区瀬野町');
ok($zip->set_number('7390313')->is_valid_number, '広島県広島市安芸区瀬野西');
ok($zip->set_number('7390314')->is_valid_number, '広島県広島市安芸区瀬野南');
ok($zip->set_number('7390315')->is_valid_number, '広島県広島市安芸区瀬野南町');
ok($zip->set_number('7390321')->is_valid_number, '広島県広島市安芸区中野');
ok($zip->set_number('7390322')->is_valid_number, '広島県広島市安芸区中野町');
ok($zip->set_number('7390323')->is_valid_number, '広島県広島市安芸区中野東');
ok($zip->set_number('7390324')->is_valid_number, '広島県広島市安芸区中野東町');
ok($zip->set_number('7390401')->is_valid_number, '広島県廿日市市福面');
ok($zip->set_number('7390402')->is_valid_number, '広島県廿日市市対厳山');
ok($zip->set_number('7390403')->is_valid_number, '広島県廿日市市大野下更地');
ok($zip->set_number('7390404')->is_valid_number, '広島県廿日市市大野十郎原');
ok($zip->set_number('7390405')->is_valid_number, '広島県廿日市市大野戸石川');
ok($zip->set_number('7390406')->is_valid_number, '広島県廿日市市大野中山');
ok($zip->set_number('7390407')->is_valid_number, '広島県廿日市市大野上更地');
ok($zip->set_number('7390408')->is_valid_number, '広島県廿日市市大野鯛ノ原');
ok($zip->set_number('7390411')->is_valid_number, '広島県廿日市市宮島口');
ok($zip->set_number('7390412')->is_valid_number, '広島県廿日市市宮島口西');
ok($zip->set_number('7390413')->is_valid_number, '広島県廿日市市宮島口上');
ok($zip->set_number('7390414')->is_valid_number, '広島県廿日市市宮島口東');
ok($zip->set_number('7390421')->is_valid_number, '広島県廿日市市深江');
ok($zip->set_number('7390422')->is_valid_number, '広島県廿日市市大野早時');
ok($zip->set_number('7390423')->is_valid_number, '広島県廿日市市大野賀撫津');
ok($zip->set_number('7390424')->is_valid_number, '広島県廿日市市前空');
ok($zip->set_number('7390425')->is_valid_number, '広島県廿日市市物見西');
ok($zip->set_number('7390426')->is_valid_number, '広島県廿日市市物見東');
ok($zip->set_number('7390432')->is_valid_number, '広島県廿日市市上の浜');
ok($zip->set_number('7390433')->is_valid_number, '広島県廿日市市下の浜');
ok($zip->set_number('7390434')->is_valid_number, '広島県廿日市市大野(1、2丁目)');
ok($zip->set_number('7390437')->is_valid_number, '広島県廿日市市大野中央');
ok($zip->set_number('7390441')->is_valid_number, '広島県廿日市市大野原');
ok($zip->set_number('7390442')->is_valid_number, '広島県廿日市市梅原');
ok($zip->set_number('7390443')->is_valid_number, '広島県廿日市市沖塩屋');
ok($zip->set_number('7390444')->is_valid_number, '広島県廿日市市林が原');
ok($zip->set_number('7390445')->is_valid_number, '広島県廿日市市塩屋');
ok($zip->set_number('7390446')->is_valid_number, '広島県廿日市市大野小山');
ok($zip->set_number('7390452')->is_valid_number, '広島県廿日市市丸石');
ok($zip->set_number('7390454')->is_valid_number, '広島県廿日市市宮浜温泉');
ok($zip->set_number('7390455')->is_valid_number, '広島県廿日市市八坂');
ok($zip->set_number('7390456')->is_valid_number, '広島県廿日市市大野垣ノ浦');
ok($zip->set_number('7390457')->is_valid_number, '広島県廿日市市大野下灘');
ok($zip->set_number('7390458')->is_valid_number, '広島県廿日市市大野鳴川');
ok($zip->set_number('7390459')->is_valid_number, '広島県廿日市市大野四十八坂');
ok($zip->set_number('7390461')->is_valid_number, '広島県廿日市市大野郷');
ok($zip->set_number('7390462')->is_valid_number, '広島県廿日市市大野陣場');
ok($zip->set_number('7390463')->is_valid_number, '広島県廿日市市大野小田ノ口');
ok($zip->set_number('7390464')->is_valid_number, '広島県廿日市市大野水ノ越');
ok($zip->set_number('7390466')->is_valid_number, '広島県廿日市市大野滝ノ下');
ok($zip->set_number('7390467')->is_valid_number, '広島県廿日市市大野中津岡');
ok($zip->set_number('7390471')->is_valid_number, '広島県廿日市市大野別府');
ok($zip->set_number('7390472')->is_valid_number, '広島県廿日市市大野棚田');
ok($zip->set_number('7390473')->is_valid_number, '広島県廿日市市大野田屋');
ok($zip->set_number('7390474')->is_valid_number, '広島県廿日市市大野土井');
ok($zip->set_number('7390475')->is_valid_number, '広島県廿日市市大野高畑');
ok($zip->set_number('7390476')->is_valid_number, '広島県廿日市市大野高見');
ok($zip->set_number('7390477')->is_valid_number, '広島県廿日市市大野水口');
ok($zip->set_number('7390478')->is_valid_number, '広島県廿日市市大野筏津');
ok($zip->set_number('7390479')->is_valid_number, '広島県廿日市市大野池田');
ok($zip->set_number('7390488')->is_valid_number, '広島県廿日市市大野(その他)');
ok($zip->set_number('7390501')->is_valid_number, '広島県廿日市市宮島町(杉之浦)');
ok($zip->set_number('7390502')->is_valid_number, '広島県廿日市市宮島町(杉之浦住宅)');
ok($zip->set_number('7390503')->is_valid_number, '広島県廿日市市宮島町(ひの木団地)');
ok($zip->set_number('7390504')->is_valid_number, '広島県廿日市市宮島町(港町)');
ok($zip->set_number('7390505')->is_valid_number, '広島県廿日市市宮島町(胡町)');
ok($zip->set_number('7390506')->is_valid_number, '広島県廿日市市宮島町(緑町)');
ok($zip->set_number('7390507')->is_valid_number, '広島県廿日市市宮島町(大砂利)');
ok($zip->set_number('7390511')->is_valid_number, '広島県廿日市市宮島町(伊勢町)');
ok($zip->set_number('7390512')->is_valid_number, '広島県廿日市市宮島町(新町)');
ok($zip->set_number('7390513')->is_valid_number, '広島県廿日市市宮島町(上西連町)');
ok($zip->set_number('7390514')->is_valid_number, '広島県廿日市市宮島町(東西連町)');
ok($zip->set_number('7390515')->is_valid_number, '広島県廿日市市宮島町(魚之棚町)');
ok($zip->set_number('7390516')->is_valid_number, '広島県廿日市市宮島町(桜町)');
ok($zip->set_number('7390517')->is_valid_number, '広島県廿日市市宮島町(大和町)');
ok($zip->set_number('7390518')->is_valid_number, '広島県廿日市市宮島町(下西連町)');
ok($zip->set_number('7390521')->is_valid_number, '広島県廿日市市宮島町(大町)');
ok($zip->set_number('7390522')->is_valid_number, '広島県廿日市市宮島町(南町)');
ok($zip->set_number('7390523')->is_valid_number, '広島県廿日市市宮島町(中江町)');
ok($zip->set_number('7390524')->is_valid_number, '広島県廿日市市宮島町(滝町)');
ok($zip->set_number('7390525')->is_valid_number, '広島県廿日市市宮島町(久保町)');
ok($zip->set_number('7390531')->is_valid_number, '広島県廿日市市宮島町(上中西町)');
ok($zip->set_number('7390532')->is_valid_number, '広島県廿日市市宮島町(東大西町)');
ok($zip->set_number('7390533')->is_valid_number, '広島県廿日市市宮島町(南大西町)');
ok($zip->set_number('7390534')->is_valid_number, '広島県廿日市市宮島町(西大西町)');
ok($zip->set_number('7390535')->is_valid_number, '広島県廿日市市宮島町(北大西町)');
ok($zip->set_number('7390536')->is_valid_number, '広島県廿日市市宮島町(下中西町)');
ok($zip->set_number('7390541')->is_valid_number, '広島県廿日市市宮島町(網之浦)');
ok($zip->set_number('7390542')->is_valid_number, '広島県廿日市市宮島町(多々良潟)');
ok($zip->set_number('7390543')->is_valid_number, '広島県廿日市市宮島町(室浜)');
ok($zip->set_number('7390550')->is_valid_number, '広島県廿日市市宮島町(浜之町)');
ok($zip->set_number('7390551')->is_valid_number, '広島県廿日市市宮島町(北之町東表)');
ok($zip->set_number('7390552')->is_valid_number, '広島県廿日市市宮島町(北之町西表)');
ok($zip->set_number('7390553')->is_valid_number, '広島県廿日市市宮島町(中之町表)');
ok($zip->set_number('7390554')->is_valid_number, '広島県廿日市市宮島町(幸町東表)');
ok($zip->set_number('7390555')->is_valid_number, '広島県廿日市市宮島町(幸町西表)');
ok($zip->set_number('7390556')->is_valid_number, '広島県廿日市市宮島町(幸町西浜)');
ok($zip->set_number('7390557')->is_valid_number, '広島県廿日市市宮島町(幸町東浜)');
ok($zip->set_number('7390558')->is_valid_number, '広島県廿日市市宮島町(中之町浜)');
ok($zip->set_number('7390559')->is_valid_number, '広島県廿日市市宮島町(北之町浜)');
ok($zip->set_number('7390588')->is_valid_number, '広島県廿日市市宮島町(その他)');
ok($zip->set_number('7390600')->is_valid_number, '広島県大竹市以下に掲載がない場合');
ok($zip->set_number('7390601')->is_valid_number, '広島県大竹市東栄');
ok($zip->set_number('7390602')->is_valid_number, '広島県大竹市南栄');
ok($zip->set_number('7390603')->is_valid_number, '広島県大竹市西栄');
ok($zip->set_number('7390604')->is_valid_number, '広島県大竹市北栄');
ok($zip->set_number('7390605')->is_valid_number, '広島県大竹市立戸');
ok($zip->set_number('7390606')->is_valid_number, '広島県大竹市御幸町');
ok($zip->set_number('7390607')->is_valid_number, '広島県大竹市阿多田');
ok($zip->set_number('7390611')->is_valid_number, '広島県大竹市新町');
ok($zip->set_number('7390612')->is_valid_number, '広島県大竹市油見');
ok($zip->set_number('7390613')->is_valid_number, '広島県大竹市本町');
ok($zip->set_number('7390614')->is_valid_number, '広島県大竹市白石');
ok($zip->set_number('7390615')->is_valid_number, '広島県大竹市元町');
ok($zip->set_number('7390616')->is_valid_number, '広島県大竹市木野');
ok($zip->set_number('7390621')->is_valid_number, '広島県大竹市港町');
ok($zip->set_number('7390622')->is_valid_number, '広島県大竹市晴海');
ok($zip->set_number('7390623')->is_valid_number, '広島県大竹市小方');
ok($zip->set_number('7390624')->is_valid_number, '広島県大竹市御園');
ok($zip->set_number('7390625')->is_valid_number, '広島県大竹市御園台');
ok($zip->set_number('7390626')->is_valid_number, '広島県大竹市三ツ石町');
ok($zip->set_number('7390627')->is_valid_number, '広島県大竹市小方町小方');
ok($zip->set_number('7390628')->is_valid_number, '広島県大竹市小方ケ丘');
ok($zip->set_number('7390631')->is_valid_number, '広島県大竹市防鹿');
ok($zip->set_number('7390632')->is_valid_number, '広島県大竹市穂仁原');
ok($zip->set_number('7390633')->is_valid_number, '広島県大竹市比作');
ok($zip->set_number('7390634')->is_valid_number, '広島県大竹市安条');
ok($zip->set_number('7390635')->is_valid_number, '広島県大竹市八丁');
ok($zip->set_number('7390636')->is_valid_number, '広島県大竹市前飯谷');
ok($zip->set_number('7390637')->is_valid_number, '広島県大竹市後飯谷');
ok($zip->set_number('7390641')->is_valid_number, '広島県大竹市栗谷町広原');
ok($zip->set_number('7390642')->is_valid_number, '広島県大竹市栗谷町奥谷尻');
ok($zip->set_number('7390643')->is_valid_number, '広島県大竹市栗谷町谷和');
ok($zip->set_number('7390644')->is_valid_number, '広島県大竹市栗谷町後原');
ok($zip->set_number('7390645')->is_valid_number, '広島県大竹市栗谷町小栗林');
ok($zip->set_number('7390646')->is_valid_number, '広島県大竹市栗谷町大栗林');
ok($zip->set_number('7390651')->is_valid_number, '広島県大竹市玖波');
ok($zip->set_number('7390652')->is_valid_number, '広島県大竹市明治新開');
ok($zip->set_number('7390653')->is_valid_number, '広島県大竹市黒川');
ok($zip->set_number('7390654')->is_valid_number, '広島県大竹市小方町黒川');
ok($zip->set_number('7390655')->is_valid_number, '広島県大竹市湯舟町');
ok($zip->set_number('7390656')->is_valid_number, '広島県大竹市玖波町');
ok($zip->set_number('7390657')->is_valid_number, '広島県大竹市松ケ原町');
ok($zip->set_number('7390661')->is_valid_number, '広島県廿日市市大野経小屋');
ok($zip->set_number('7390663')->is_valid_number, '広島県廿日市市大野奴メリ谷');
ok($zip->set_number('7390664')->is_valid_number, '広島県廿日市市大野嵐谷');
ok($zip->set_number('7390665')->is_valid_number, '広島県廿日市市大野横撫');
ok($zip->set_number('7390667')->is_valid_number, '広島県廿日市市大野猪ノウツ');
ok($zip->set_number('7391101')->is_valid_number, '広島県安芸高田市甲田町高田原');
ok($zip->set_number('7391102')->is_valid_number, '広島県安芸高田市甲田町上小原');
ok($zip->set_number('7391103')->is_valid_number, '広島県安芸高田市甲田町下小原');
ok($zip->set_number('7391104')->is_valid_number, '広島県安芸高田市甲田町上甲立');
ok($zip->set_number('7391105')->is_valid_number, '広島県安芸高田市甲田町下甲立');
ok($zip->set_number('7391106')->is_valid_number, '広島県安芸高田市甲田町浅塚');
ok($zip->set_number('7391107')->is_valid_number, '広島県安芸高田市甲田町糘地');
ok($zip->set_number('7391108')->is_valid_number, '広島県安芸高田市甲田町深瀬');
ok($zip->set_number('7391201')->is_valid_number, '広島県安芸高田市向原町坂');
ok($zip->set_number('7391202')->is_valid_number, '広島県安芸高田市向原町戸島');
ok($zip->set_number('7391203')->is_valid_number, '広島県安芸高田市向原町長田');
ok($zip->set_number('7391204')->is_valid_number, '広島県安芸高田市向原町有留');
ok($zip->set_number('7391205')->is_valid_number, '広島県安芸高田市向原町保垣');
ok($zip->set_number('7391301')->is_valid_number, '広島県広島市安佐北区白木町井原');
ok($zip->set_number('7391302')->is_valid_number, '広島県広島市安佐北区白木町古屋');
ok($zip->set_number('7391303')->is_valid_number, '広島県広島市安佐北区白木町志路');
ok($zip->set_number('7391411')->is_valid_number, '広島県広島市安佐北区白木町市川');
ok($zip->set_number('7391412')->is_valid_number, '広島県広島市安佐北区白木町小越');
ok($zip->set_number('7391413')->is_valid_number, '広島県広島市安佐北区白木町有留');
ok($zip->set_number('7391414')->is_valid_number, '広島県広島市安佐北区白木町秋山');
ok($zip->set_number('7391521')->is_valid_number, '広島県広島市安佐北区白木町三田');
ok($zip->set_number('7391700')->is_valid_number, '広島県広島市安佐北区以下に掲載がない場合');
ok($zip->set_number('7391731')->is_valid_number, '広島県広島市安佐北区落合');
ok($zip->set_number('7391732')->is_valid_number, '広島県広島市安佐北区落合南');
ok($zip->set_number('7391732')->is_valid_number, '広島県広島市安佐北区落合南町');
ok($zip->set_number('7391733')->is_valid_number, '広島県広島市安佐北区口田南');
ok($zip->set_number('7391733')->is_valid_number, '広島県広島市安佐北区口田南町');
ok($zip->set_number('7391734')->is_valid_number, '広島県広島市安佐北区口田');
ok($zip->set_number('7391734')->is_valid_number, '広島県広島市安佐北区口田町');
ok($zip->set_number('7391741')->is_valid_number, '広島県広島市安佐北区真亀');
ok($zip->set_number('7391742')->is_valid_number, '広島県広島市安佐北区亀崎');
ok($zip->set_number('7391743')->is_valid_number, '広島県広島市安佐北区倉掛');
ok($zip->set_number('7391751')->is_valid_number, '広島県広島市安佐北区深川');
ok($zip->set_number('7391751')->is_valid_number, '広島県広島市安佐北区深川町');
ok($zip->set_number('7391752')->is_valid_number, '広島県広島市安佐北区上深川町');
ok($zip->set_number('7391753')->is_valid_number, '広島県広島市安佐北区狩留家町');
ok($zip->set_number('7391754')->is_valid_number, '広島県広島市安佐北区小河原町');
ok($zip->set_number('7391801')->is_valid_number, '広島県安芸高田市高宮町川根');
ok($zip->set_number('7391802')->is_valid_number, '広島県安芸高田市高宮町佐々部');
ok($zip->set_number('7391803')->is_valid_number, '広島県安芸高田市高宮町船木');
ok($zip->set_number('7391804')->is_valid_number, '広島県安芸高田市高宮町房後');
ok($zip->set_number('7391805')->is_valid_number, '広島県安芸高田市高宮町原田');
ok($zip->set_number('7391806')->is_valid_number, '広島県安芸高田市高宮町来女木');
ok($zip->set_number('7391807')->is_valid_number, '広島県安芸高田市高宮町羽佐竹');
ok($zip->set_number('7392101')->is_valid_number, '広島県東広島市高屋町造賀');
ok($zip->set_number('7392102')->is_valid_number, '広島県東広島市高屋町杵原');
ok($zip->set_number('7392103')->is_valid_number, '広島県東広島市高屋町宮領');
ok($zip->set_number('7392104')->is_valid_number, '広島県東広島市高屋町大畠');
ok($zip->set_number('7392105')->is_valid_number, '広島県東広島市高屋町檜山');
ok($zip->set_number('7392106')->is_valid_number, '広島県東広島市高屋町稲木');
ok($zip->set_number('7392111')->is_valid_number, '広島県東広島市高屋町高屋堀');
ok($zip->set_number('7392112')->is_valid_number, '広島県東広島市高屋町貞重');
ok($zip->set_number('7392113')->is_valid_number, '広島県東広島市高屋町高屋東');
ok($zip->set_number('7392114')->is_valid_number, '広島県東広島市高屋町白市');
ok($zip->set_number('7392115')->is_valid_number, '広島県東広島市高屋高美が丘');
ok($zip->set_number('7392116')->is_valid_number, '広島県東広島市高屋うめの辺');
ok($zip->set_number('7392117')->is_valid_number, '広島県東広島市高屋台');
ok($zip->set_number('7392121')->is_valid_number, '広島県東広島市高屋町小谷');
ok($zip->set_number('7392122')->is_valid_number, '広島県東広島市高屋町重兼');
ok($zip->set_number('7392123')->is_valid_number, '広島県東広島市高屋町溝口');
ok($zip->set_number('7392124')->is_valid_number, '広島県東広島市高屋町郷');
ok($zip->set_number('7392125')->is_valid_number, '広島県東広島市高屋町中島');
ok($zip->set_number('7392201')->is_valid_number, '広島県東広島市河内町中河内');
ok($zip->set_number('7392202')->is_valid_number, '広島県東広島市河内町下河内');
ok($zip->set_number('7392203')->is_valid_number, '広島県東広島市河内町上河内');
ok($zip->set_number('7392204')->is_valid_number, '広島県東広島市河内町河戸');
ok($zip->set_number('7392205')->is_valid_number, '広島県東広島市河内町戸野');
ok($zip->set_number('7392206')->is_valid_number, '広島県東広島市河内町宇山');
ok($zip->set_number('7392207')->is_valid_number, '広島県東広島市河内町小田');
ok($zip->set_number('7392208')->is_valid_number, '広島県東広島市河内町入野');
ok($zip->set_number('7392209')->is_valid_number, '広島県東広島市入野中山台');
ok($zip->set_number('7392211')->is_valid_number, '広島県東広島市河内臨空団地');
ok($zip->set_number('7392301')->is_valid_number, '広島県東広島市福富町上竹仁');
ok($zip->set_number('7392302')->is_valid_number, '広島県東広島市福富町下竹仁');
ok($zip->set_number('7392303')->is_valid_number, '広島県東広島市福富町久芳');
ok($zip->set_number('7392304')->is_valid_number, '広島県東広島市福富町上戸野');
ok($zip->set_number('7392311')->is_valid_number, '広島県東広島市豊栄町乃美');
ok($zip->set_number('7392312')->is_valid_number, '広島県東広島市豊栄町別府');
ok($zip->set_number('7392313')->is_valid_number, '広島県東広島市豊栄町清武');
ok($zip->set_number('7392314')->is_valid_number, '広島県東広島市豊栄町飯田');
ok($zip->set_number('7392315')->is_valid_number, '広島県東広島市豊栄町吉原');
ok($zip->set_number('7392316')->is_valid_number, '広島県東広島市豊栄町安宿');
ok($zip->set_number('7392317')->is_valid_number, '広島県東広島市豊栄町鍛冶屋');
ok($zip->set_number('7392318')->is_valid_number, '広島県東広島市豊栄町能良');
ok($zip->set_number('7392401')->is_valid_number, '広島県東広島市安芸津町木谷');
ok($zip->set_number('7392402')->is_valid_number, '広島県東広島市安芸津町三津');
ok($zip->set_number('7392403')->is_valid_number, '広島県東広島市安芸津町風早');
ok($zip->set_number('7392404')->is_valid_number, '広島県東広島市安芸津町大田');
ok($zip->set_number('7392405')->is_valid_number, '広島県東広島市安芸津町小松原');
ok($zip->set_number('7392501')->is_valid_number, '広島県東広島市黒瀬町小多田');
ok($zip->set_number('7392502')->is_valid_number, '広島県東広島市黒瀬町国近');
ok($zip->set_number('7392503')->is_valid_number, '広島県東広島市黒瀬町南方');
ok($zip->set_number('7392504')->is_valid_number, '広島県東広島市黒瀬町宗近柳国');
ok($zip->set_number('7392611')->is_valid_number, '広島県東広島市黒瀬町大多田');
ok($zip->set_number('7392612')->is_valid_number, '広島県東広島市黒瀬町丸山');
ok($zip->set_number('7392613')->is_valid_number, '広島県東広島市黒瀬町楢原');
ok($zip->set_number('7392614')->is_valid_number, '広島県東広島市黒瀬松ケ丘');
ok($zip->set_number('7392615')->is_valid_number, '広島県東広島市黒瀬春日野');
ok($zip->set_number('7392616')->is_valid_number, '広島県東広島市黒瀬町兼広');
ok($zip->set_number('7392617')->is_valid_number, '広島県東広島市黒瀬町切田');
ok($zip->set_number('7392618')->is_valid_number, '広島県東広島市黒瀬桜が丘');
ok($zip->set_number('7392619')->is_valid_number, '広島県東広島市黒瀬切田が丘');
ok($zip->set_number('7392621')->is_valid_number, '広島県東広島市黒瀬町南方(賀茂精神医療センター)');
ok($zip->set_number('7392622')->is_valid_number, '広島県東広島市黒瀬町乃美尾');
ok($zip->set_number('7392623')->is_valid_number, '広島県東広島市黒瀬町川角');
ok($zip->set_number('7392624')->is_valid_number, '広島県東広島市黒瀬町菅田');
ok($zip->set_number('7392625')->is_valid_number, '広島県東広島市黒瀬町上保田');
ok($zip->set_number('7392626')->is_valid_number, '広島県東広島市黒瀬町市飯田');
ok($zip->set_number('7392627')->is_valid_number, '広島県東広島市黒瀬楢原北');
ok($zip->set_number('7392628')->is_valid_number, '広島県東広島市黒瀬楢原東');
ok($zip->set_number('7392629')->is_valid_number, '広島県東広島市黒瀬楢原西');
ok($zip->set_number('7392631')->is_valid_number, '広島県東広島市黒瀬学園台');
ok($zip->set_number('7392731')->is_valid_number, '広島県東広島市黒瀬町兼沢');
ok($zip->set_number('7392732')->is_valid_number, '広島県東広島市黒瀬町津江');
ok($zip->set_number('7400000')->is_valid_number, '山口県岩国市以下に掲載がない場合');
ok($zip->set_number('7400000')->is_valid_number, '山口県玖珂郡和木町以下に掲載がない場合');
ok($zip->set_number('7400001')->is_valid_number, '山口県岩国市装束町');
ok($zip->set_number('7400002')->is_valid_number, '山口県岩国市新港町');
ok($zip->set_number('7400003')->is_valid_number, '山口県岩国市飯田町');
ok($zip->set_number('7400004')->is_valid_number, '山口県岩国市昭和町');
ok($zip->set_number('7400011')->is_valid_number, '山口県岩国市立石町');
ok($zip->set_number('7400012')->is_valid_number, '山口県岩国市元町');
ok($zip->set_number('7400013')->is_valid_number, '山口県岩国市桂町');
ok($zip->set_number('7400014')->is_valid_number, '山口県岩国市日の出町');
ok($zip->set_number('7400015')->is_valid_number, '山口県岩国市川口町');
ok($zip->set_number('7400016')->is_valid_number, '山口県岩国市三笠町');
ok($zip->set_number('7400017')->is_valid_number, '山口県岩国市今津町');
ok($zip->set_number('7400018')->is_valid_number, '山口県岩国市麻里布町');
ok($zip->set_number('7400019')->is_valid_number, '山口県岩国市砂山町');
ok($zip->set_number('7400021')->is_valid_number, '山口県岩国市室の木町');
ok($zip->set_number('7400022')->is_valid_number, '山口県岩国市山手町');
ok($zip->set_number('7400023')->is_valid_number, '山口県岩国市川下町');
ok($zip->set_number('7400024')->is_valid_number, '山口県岩国市旭町');
ok($zip->set_number('7400025')->is_valid_number, '山口県岩国市三角町');
ok($zip->set_number('7400026')->is_valid_number, '山口県岩国市車町');
ok($zip->set_number('7400027')->is_valid_number, '山口県岩国市中津町');
ok($zip->set_number('7400028')->is_valid_number, '山口県岩国市楠町');
ok($zip->set_number('7400031')->is_valid_number, '山口県岩国市門前町');
ok($zip->set_number('7400032')->is_valid_number, '山口県岩国市尾津町');
ok($zip->set_number('7400033')->is_valid_number, '山口県岩国市灘町');
ok($zip->set_number('7400034')->is_valid_number, '山口県岩国市南岩国町');
ok($zip->set_number('7400035')->is_valid_number, '山口県岩国市海土路町');
ok($zip->set_number('7400036')->is_valid_number, '山口県岩国市藤生町');
ok($zip->set_number('7400037')->is_valid_number, '山口県岩国市愛宕町');
ok($zip->set_number('7400041')->is_valid_number, '山口県岩国市黒磯町');
ok($zip->set_number('7400042')->is_valid_number, '山口県岩国市青木町');
ok($zip->set_number('7400043')->is_valid_number, '山口県岩国市保津町');
ok($zip->set_number('7400044')->is_valid_number, '山口県岩国市通津');
ok($zip->set_number('7400045')->is_valid_number, '山口県岩国市長野');
ok($zip->set_number('7400051')->is_valid_number, '山口県岩国市柱島');
ok($zip->set_number('7400061')->is_valid_number, '山口県玖珂郡和木町和木');
ok($zip->set_number('7400062')->is_valid_number, '山口県玖珂郡和木町瀬田');
ok($zip->set_number('7400063')->is_valid_number, '山口県玖珂郡和木町関ケ浜');
ok($zip->set_number('7400301')->is_valid_number, '山口県岩国市行波');
ok($zip->set_number('7400302')->is_valid_number, '山口県岩国市下');
ok($zip->set_number('7400303')->is_valid_number, '山口県岩国市杭名');
ok($zip->set_number('7400304')->is_valid_number, '山口県岩国市相ノ谷');
ok($zip->set_number('7400305')->is_valid_number, '山口県岩国市二鹿');
ok($zip->set_number('7400306')->is_valid_number, '山口県岩国市天尾');
ok($zip->set_number('7400311')->is_valid_number, '山口県岩国市瓦谷');
ok($zip->set_number('7400312')->is_valid_number, '山口県岩国市守内');
ok($zip->set_number('7400313')->is_valid_number, '山口県岩国市保木');
ok($zip->set_number('7400314')->is_valid_number, '山口県岩国市寺山');
ok($zip->set_number('7400315')->is_valid_number, '山口県岩国市近延');
ok($zip->set_number('7400316')->is_valid_number, '山口県岩国市行正');
ok($zip->set_number('7400317')->is_valid_number, '山口県岩国市上田');
ok($zip->set_number('7400321')->is_valid_number, '山口県岩国市入野');
ok($zip->set_number('7400322')->is_valid_number, '山口県岩国市廿木');
ok($zip->set_number('7400323')->is_valid_number, '山口県岩国市大山');
ok($zip->set_number('7400324')->is_valid_number, '山口県岩国市伊房');
ok($zip->set_number('7400325')->is_valid_number, '山口県岩国市竹安');
ok($zip->set_number('7400326')->is_valid_number, '山口県岩国市土生');
ok($zip->set_number('7400327')->is_valid_number, '山口県岩国市角');
ok($zip->set_number('7400501')->is_valid_number, '山口県岩国市美川町小川');
ok($zip->set_number('7400502')->is_valid_number, '山口県岩国市美川町四馬神');
ok($zip->set_number('7400503')->is_valid_number, '山口県岩国市美川町添谷');
ok($zip->set_number('7400504')->is_valid_number, '山口県岩国市美川町南桑');
ok($zip->set_number('7400505')->is_valid_number, '山口県岩国市美川町根笠');
ok($zip->set_number('7400601')->is_valid_number, '山口県岩国市本郷町本谷');
ok($zip->set_number('7400602')->is_valid_number, '山口県岩国市本郷町本郷');
ok($zip->set_number('7400603')->is_valid_number, '山口県岩国市本郷町波野');
ok($zip->set_number('7400604')->is_valid_number, '山口県岩国市本郷町宇塚');
ok($zip->set_number('7400605')->is_valid_number, '山口県岩国市本郷町西黒沢');
ok($zip->set_number('7400721')->is_valid_number, '山口県岩国市錦町大野');
ok($zip->set_number('7400722')->is_valid_number, '山口県岩国市錦町中ノ瀬');
ok($zip->set_number('7400723')->is_valid_number, '山口県岩国市錦町府谷');
ok($zip->set_number('7400724')->is_valid_number, '山口県岩国市錦町広瀬');
ok($zip->set_number('7400725')->is_valid_number, '山口県岩国市錦町野谷');
ok($zip->set_number('7400811')->is_valid_number, '山口県岩国市錦町須川');
ok($zip->set_number('7400812')->is_valid_number, '山口県岩国市錦町深川');
ok($zip->set_number('7400901')->is_valid_number, '山口県岩国市錦町宇佐');
ok($zip->set_number('7400902')->is_valid_number, '山口県岩国市錦町宇佐郷(その他)');
ok($zip->set_number('7400903')->is_valid_number, '山口県岩国市錦町大原');
ok($zip->set_number('7400904')->is_valid_number, '山口県岩国市錦町宇佐郷(向峠)');
ok($zip->set_number('7401201')->is_valid_number, '山口県岩国市美和町秋掛');
ok($zip->set_number('7401202')->is_valid_number, '山口県岩国市美和町北中山');
ok($zip->set_number('7401211')->is_valid_number, '山口県岩国市美和町釜ケ原');
ok($zip->set_number('7401212')->is_valid_number, '山口県岩国市美和町黒沢');
ok($zip->set_number('7401213')->is_valid_number, '山口県岩国市美和町岸根');
ok($zip->set_number('7401214')->is_valid_number, '山口県岩国市美和町百合谷');
ok($zip->set_number('7401215')->is_valid_number, '山口県岩国市美和町長谷');
ok($zip->set_number('7401216')->is_valid_number, '山口県岩国市美和町日宛');
ok($zip->set_number('7401217')->is_valid_number, '山口県岩国市美和町大根川');
ok($zip->set_number('7401218')->is_valid_number, '山口県岩国市美和町中垣内');
ok($zip->set_number('7401219')->is_valid_number, '山口県岩国市美和町瀬戸ノ内');
ok($zip->set_number('7401221')->is_valid_number, '山口県岩国市美和町上駄床');
ok($zip->set_number('7401222')->is_valid_number, '山口県岩国市美和町田ノ口');
ok($zip->set_number('7401223')->is_valid_number, '山口県岩国市美和町滑');
ok($zip->set_number('7401224')->is_valid_number, '山口県岩国市美和町佐坂');
ok($zip->set_number('7401225')->is_valid_number, '山口県岩国市美和町渋前');
ok($zip->set_number('7401231')->is_valid_number, '山口県岩国市美和町生見');
ok($zip->set_number('7401232')->is_valid_number, '山口県岩国市美和町西畑');
ok($zip->set_number('7401241')->is_valid_number, '山口県岩国市美和町阿賀');
ok($zip->set_number('7401242')->is_valid_number, '山口県岩国市美和町下畑');
ok($zip->set_number('7401401')->is_valid_number, '山口県岩国市由宇町(寺迫)');
ok($zip->set_number('7401402')->is_valid_number, '山口県岩国市由宇町(小槇)');
ok($zip->set_number('7401403')->is_valid_number, '山口県岩国市由宇町(中倉)');
ok($zip->set_number('7401404')->is_valid_number, '山口県岩国市由宇町(西区)');
ok($zip->set_number('7401405')->is_valid_number, '山口県岩国市由宇町(笠塚)');
ok($zip->set_number('7401406')->is_valid_number, '山口県岩国市由宇町(峇清)');
ok($zip->set_number('7401407')->is_valid_number, '山口県岩国市由宇町(横道)');
ok($zip->set_number('7401411')->is_valid_number, '山口県岩国市由宇町(清水)');
ok($zip->set_number('7401412')->is_valid_number, '山口県岩国市由宇町(中村)');
ok($zip->set_number('7401413')->is_valid_number, '山口県岩国市由宇町(上北)');
ok($zip->set_number('7401424')->is_valid_number, '山口県岩国市由宇町港');
ok($zip->set_number('7401425')->is_valid_number, '山口県岩国市由宇町南沖');
ok($zip->set_number('7401426')->is_valid_number, '山口県岩国市由宇町由宇崎');
ok($zip->set_number('7401428')->is_valid_number, '山口県岩国市由宇町中央');
ok($zip->set_number('7401431')->is_valid_number, '山口県岩国市由宇町(有家)');
ok($zip->set_number('7401432')->is_valid_number, '山口県岩国市由宇町神東');
ok($zip->set_number('7401441')->is_valid_number, '山口県岩国市由宇町千鳥ケ丘');
ok($zip->set_number('7401451')->is_valid_number, '山口県岩国市由宇町南');
ok($zip->set_number('7401452')->is_valid_number, '山口県岩国市由宇町(正南)');
ok($zip->set_number('7401454')->is_valid_number, '山口県岩国市由宇町西');
ok($zip->set_number('7401455')->is_valid_number, '山口県岩国市由宇町北');
ok($zip->set_number('7401488')->is_valid_number, '山口県岩国市由宇町(その他)');
ok($zip->set_number('7410061')->is_valid_number, '山口県岩国市錦見');
ok($zip->set_number('7410062')->is_valid_number, '山口県岩国市岩国');
ok($zip->set_number('7410063')->is_valid_number, '山口県岩国市関戸');
ok($zip->set_number('7410071')->is_valid_number, '山口県岩国市牛野谷町');
ok($zip->set_number('7410072')->is_valid_number, '山口県岩国市平田');
ok($zip->set_number('7410073')->is_valid_number, '山口県岩国市柱野');
ok($zip->set_number('7410074')->is_valid_number, '山口県岩国市六呂師');
ok($zip->set_number('7410075')->is_valid_number, '山口県岩国市叶木');
ok($zip->set_number('7410081')->is_valid_number, '山口県岩国市横山');
ok($zip->set_number('7410082')->is_valid_number, '山口県岩国市川西');
ok($zip->set_number('7410083')->is_valid_number, '山口県岩国市御庄');
ok($zip->set_number('7410084')->is_valid_number, '山口県岩国市大谷');
ok($zip->set_number('7410085')->is_valid_number, '山口県岩国市持国');
ok($zip->set_number('7410091')->is_valid_number, '山口県岩国市小瀬');
ok($zip->set_number('7410092')->is_valid_number, '山口県岩国市多田');
ok($zip->set_number('7410093')->is_valid_number, '山口県岩国市田原');
ok($zip->set_number('7410094')->is_valid_number, '山口県岩国市阿品');
ok($zip->set_number('7420000')->is_valid_number, '山口県柳井市以下に掲載がない場合');
ok($zip->set_number('7420001')->is_valid_number, '山口県柳井市姫田');
ok($zip->set_number('7420002')->is_valid_number, '山口県柳井市山根');
ok($zip->set_number('7420003')->is_valid_number, '山口県柳井市片野西');
ok($zip->set_number('7420004')->is_valid_number, '山口県柳井市土手町');
ok($zip->set_number('7420005')->is_valid_number, '山口県柳井市天神');
ok($zip->set_number('7420006')->is_valid_number, '山口県柳井市新天地');
ok($zip->set_number('7420007')->is_valid_number, '山口県柳井市東土手');
ok($zip->set_number('7420008')->is_valid_number, '山口県柳井市新市北');
ok($zip->set_number('7420009')->is_valid_number, '山口県柳井市新市');
ok($zip->set_number('7420010')->is_valid_number, '山口県柳井市新市南');
ok($zip->set_number('7420011')->is_valid_number, '山口県柳井市新市沖');
ok($zip->set_number('7420012')->is_valid_number, '山口県柳井市北浜');
ok($zip->set_number('7420021')->is_valid_number, '山口県柳井市柳井');
ok($zip->set_number('7420022')->is_valid_number, '山口県柳井市柳井津');
ok($zip->set_number('7420023')->is_valid_number, '山口県柳井市南浜');
ok($zip->set_number('7420024')->is_valid_number, '山口県柳井市ニュータウン南町');
ok($zip->set_number('7420031')->is_valid_number, '山口県柳井市南町');
ok($zip->set_number('7420032')->is_valid_number, '山口県柳井市古開作');
ok($zip->set_number('7420033')->is_valid_number, '山口県柳井市新庄');
ok($zip->set_number('7420034')->is_valid_number, '山口県柳井市余田');
ok($zip->set_number('7420035')->is_valid_number, '山口県柳井市中央');
ok($zip->set_number('7420036')->is_valid_number, '山口県柳井市駅南');
ok($zip->set_number('7420041')->is_valid_number, '山口県柳井市平郡');
ok($zip->set_number('7420111')->is_valid_number, '山口県柳井市日積');
ok($zip->set_number('7420201')->is_valid_number, '山口県柳井市伊陸');
ok($zip->set_number('7420301')->is_valid_number, '山口県岩国市周東町祖生');
ok($zip->set_number('7420311')->is_valid_number, '山口県岩国市玖珂町(欽明路)');
ok($zip->set_number('7420312')->is_valid_number, '山口県岩国市玖珂町(上谷)');
ok($zip->set_number('7420313')->is_valid_number, '山口県岩国市玖珂町(下谷)');
ok($zip->set_number('7420314')->is_valid_number, '山口県岩国市玖珂町(野口)');
ok($zip->set_number('7420315')->is_valid_number, '山口県岩国市玖珂町(瀬田)');
ok($zip->set_number('7420321')->is_valid_number, '山口県岩国市玖珂町(市頭)');
ok($zip->set_number('7420322')->is_valid_number, '山口県岩国市玖珂町(上市)');
ok($zip->set_number('7420323')->is_valid_number, '山口県岩国市玖珂町(谷津)');
ok($zip->set_number('7420324')->is_valid_number, '山口県岩国市玖珂町(駅通)');
ok($zip->set_number('7420325')->is_valid_number, '山口県岩国市玖珂町(本町)');
ok($zip->set_number('7420326')->is_valid_number, '山口県岩国市玖珂町(同道)');
ok($zip->set_number('7420331')->is_valid_number, '山口県岩国市玖珂町(鞍掛)');
ok($zip->set_number('7420332')->is_valid_number, '山口県岩国市玖珂町(阿山)');
ok($zip->set_number('7420333')->is_valid_number, '山口県岩国市玖珂町(千束)');
ok($zip->set_number('7420334')->is_valid_number, '山口県岩国市玖珂町(臼田)');
ok($zip->set_number('7420335')->is_valid_number, '山口県岩国市玖珂町(新町)');
ok($zip->set_number('7420336')->is_valid_number, '山口県岩国市玖珂町(新市)');
ok($zip->set_number('7420337')->is_valid_number, '山口県岩国市玖珂町(久門給)');
ok($zip->set_number('7420338')->is_valid_number, '山口県岩国市玖珂町(有延)');
ok($zip->set_number('7420341')->is_valid_number, '山口県岩国市玖珂町(柳井田)');
ok($zip->set_number('7420342')->is_valid_number, '山口県岩国市玖珂町(大田)');
ok($zip->set_number('7420343')->is_valid_number, '山口県岩国市玖珂町(野地)');
ok($zip->set_number('7420344')->is_valid_number, '山口県岩国市玖珂町(番地のみ)');
ok($zip->set_number('7420411')->is_valid_number, '山口県岩国市周東町明見谷');
ok($zip->set_number('7420412')->is_valid_number, '山口県岩国市周東町川上');
ok($zip->set_number('7420413')->is_valid_number, '山口県岩国市周東町上久原');
ok($zip->set_number('7420414')->is_valid_number, '山口県岩国市周東町田尻');
ok($zip->set_number('7420415')->is_valid_number, '山口県岩国市周東町中山');
ok($zip->set_number('7420416')->is_valid_number, '山口県岩国市周東町用田');
ok($zip->set_number('7420417')->is_valid_number, '山口県岩国市周東町下久原');
ok($zip->set_number('7420421')->is_valid_number, '山口県岩国市周東町三瀬川');
ok($zip->set_number('7420422')->is_valid_number, '山口県岩国市周東町獺越');
ok($zip->set_number('7420423')->is_valid_number, '山口県岩国市周東町下須通');
ok($zip->set_number('7420424')->is_valid_number, '山口県岩国市周東町差川');
ok($zip->set_number('7420425')->is_valid_number, '山口県岩国市周東町西長野');
ok($zip->set_number('7420426')->is_valid_number, '山口県岩国市周東町上須通');
ok($zip->set_number('7420427')->is_valid_number, '山口県岩国市周東町樋余地');
ok($zip->set_number('7421100')->is_valid_number, '山口県熊毛郡平生町以下に掲載がない場合');
ok($zip->set_number('7421101')->is_valid_number, '山口県熊毛郡平生町平生町');
ok($zip->set_number('7421102')->is_valid_number, '山口県熊毛郡平生町平生村');
ok($zip->set_number('7421103')->is_valid_number, '山口県熊毛郡平生町竪ケ浜');
ok($zip->set_number('7421104')->is_valid_number, '山口県熊毛郡平生町宇佐木');
ok($zip->set_number('7421105')->is_valid_number, '山口県熊毛郡平生町大野北');
ok($zip->set_number('7421106')->is_valid_number, '山口県熊毛郡平生町大野南');
ok($zip->set_number('7421107')->is_valid_number, '山口県熊毛郡平生町曽根');
ok($zip->set_number('7421111')->is_valid_number, '山口県熊毛郡平生町佐賀');
ok($zip->set_number('7421112')->is_valid_number, '山口県熊毛郡平生町小郡');
ok($zip->set_number('7421113')->is_valid_number, '山口県熊毛郡平生町尾国');
ok($zip->set_number('7421114')->is_valid_number, '山口県熊毛郡平生町佐合島');
ok($zip->set_number('7421351')->is_valid_number, '山口県柳井市旭ケ丘');
ok($zip->set_number('7421352')->is_valid_number, '山口県柳井市伊保庄');
ok($zip->set_number('7421353')->is_valid_number, '山口県柳井市阿月');
ok($zip->set_number('7421400')->is_valid_number, '山口県熊毛郡上関町以下に掲載がない場合');
ok($zip->set_number('7421401')->is_valid_number, '山口県熊毛郡上関町祝島');
ok($zip->set_number('7421402')->is_valid_number, '山口県熊毛郡上関町長島');
ok($zip->set_number('7421403')->is_valid_number, '山口県熊毛郡上関町室津');
ok($zip->set_number('7421404')->is_valid_number, '山口県熊毛郡上関町八島');
ok($zip->set_number('7421500')->is_valid_number, '山口県熊毛郡田布施町以下に掲載がない場合');
ok($zip->set_number('7421501')->is_valid_number, '山口県熊毛郡田布施町大波野');
ok($zip->set_number('7421502')->is_valid_number, '山口県熊毛郡田布施町波野');
ok($zip->set_number('7421503')->is_valid_number, '山口県熊毛郡田布施町宿井');
ok($zip->set_number('7421504')->is_valid_number, '山口県熊毛郡田布施町川西');
ok($zip->set_number('7421511')->is_valid_number, '山口県熊毛郡田布施町下田布施');
ok($zip->set_number('7421512')->is_valid_number, '山口県熊毛郡田布施町麻郷奥');
ok($zip->set_number('7421513')->is_valid_number, '山口県熊毛郡田布施町麻郷');
ok($zip->set_number('7421513')->is_valid_number, '山口県熊毛郡田布施町麻郷団地');
ok($zip->set_number('7421514')->is_valid_number, '山口県熊毛郡田布施町別府');
ok($zip->set_number('7421515')->is_valid_number, '山口県熊毛郡田布施町上田布施');
ok($zip->set_number('7421516')->is_valid_number, '山口県熊毛郡田布施町馬島');
ok($zip->set_number('7421517')->is_valid_number, '山口県熊毛郡田布施町中央南');
ok($zip->set_number('7422100')->is_valid_number, '山口県大島郡周防大島町以下に掲載がない場合');
ok($zip->set_number('7422101')->is_valid_number, '山口県大島郡周防大島町西三蒲');
ok($zip->set_number('7422102')->is_valid_number, '山口県大島郡周防大島町東三蒲');
ok($zip->set_number('7422103')->is_valid_number, '山口県大島郡周防大島町西屋代');
ok($zip->set_number('7422104')->is_valid_number, '山口県大島郡周防大島町志佐');
ok($zip->set_number('7422105')->is_valid_number, '山口県大島郡周防大島町小松開作');
ok($zip->set_number('7422106')->is_valid_number, '山口県大島郡周防大島町小松');
ok($zip->set_number('7422107')->is_valid_number, '山口県大島郡周防大島町東屋代');
ok($zip->set_number('7422108')->is_valid_number, '山口県大島郡周防大島町笠佐島');
ok($zip->set_number('7422301')->is_valid_number, '山口県大島郡周防大島町久賀');
ok($zip->set_number('7422302')->is_valid_number, '山口県大島郡周防大島町椋野');
ok($zip->set_number('7422511')->is_valid_number, '山口県大島郡周防大島町片添');
ok($zip->set_number('7422512')->is_valid_number, '山口県大島郡周防大島町平野');
ok($zip->set_number('7422513')->is_valid_number, '山口県大島郡周防大島町森');
ok($zip->set_number('7422514')->is_valid_number, '山口県大島郡周防大島町神浦');
ok($zip->set_number('7422515')->is_valid_number, '山口県大島郡周防大島町内入');
ok($zip->set_number('7422516')->is_valid_number, '山口県大島郡周防大島町和田');
ok($zip->set_number('7422517')->is_valid_number, '山口県大島郡周防大島町小泊');
ok($zip->set_number('7422518')->is_valid_number, '山口県大島郡周防大島町和佐');
ok($zip->set_number('7422601')->is_valid_number, '山口県大島郡周防大島町伊保田');
ok($zip->set_number('7422601')->is_valid_number, '山口県大島郡周防大島町伊保田(雨振)');
ok($zip->set_number('7422601')->is_valid_number, '山口県大島郡周防大島町伊保田(小伊保田)');
ok($zip->set_number('7422601')->is_valid_number, '山口県大島郡周防大島町伊保田(情島)');
ok($zip->set_number('7422601')->is_valid_number, '山口県大島郡周防大島町伊保田(両源田)');
ok($zip->set_number('7422602')->is_valid_number, '山口県大島郡周防大島町油宇');
ok($zip->set_number('7422602')->is_valid_number, '山口県大島郡周防大島町油宇(馬ケ原)');
ok($zip->set_number('7422602')->is_valid_number, '山口県大島郡周防大島町油宇(日向泊)');
ok($zip->set_number('7422711')->is_valid_number, '山口県大島郡周防大島町家房');
ok($zip->set_number('7422712')->is_valid_number, '山口県大島郡周防大島町出井');
ok($zip->set_number('7422713')->is_valid_number, '山口県大島郡周防大島町津海木');
ok($zip->set_number('7422714')->is_valid_number, '山口県大島郡周防大島町戸田');
ok($zip->set_number('7422715')->is_valid_number, '山口県大島郡周防大島町横見');
ok($zip->set_number('7422716')->is_valid_number, '山口県大島郡周防大島町日見');
ok($zip->set_number('7422801')->is_valid_number, '山口県大島郡周防大島町浮島');
ok($zip->set_number('7422802')->is_valid_number, '山口県大島郡周防大島町油良');
ok($zip->set_number('7422803')->is_valid_number, '山口県大島郡周防大島町土居');
ok($zip->set_number('7422804')->is_valid_number, '山口県大島郡周防大島町日前');
ok($zip->set_number('7422805')->is_valid_number, '山口県大島郡周防大島町東安下庄');
ok($zip->set_number('7422806')->is_valid_number, '山口県大島郡周防大島町西安下庄');
ok($zip->set_number('7422807')->is_valid_number, '山口県大島郡周防大島町秋');
ok($zip->set_number('7422921')->is_valid_number, '山口県大島郡周防大島町西方');
ok($zip->set_number('7422921')->is_valid_number, '山口県大島郡周防大島町西方(大積)');
ok($zip->set_number('7422921')->is_valid_number, '山口県大島郡周防大島町西方(小積)');
ok($zip->set_number('7422921')->is_valid_number, '山口県大島郡周防大島町西方(下田)');
ok($zip->set_number('7422921')->is_valid_number, '山口県大島郡周防大島町西方(長崎)');
ok($zip->set_number('7422921')->is_valid_number, '山口県大島郡周防大島町西方(船越)');
ok($zip->set_number('7422922')->is_valid_number, '山口県大島郡周防大島町沖家室島');
ok($zip->set_number('7422923')->is_valid_number, '山口県大島郡周防大島町地家室');
ok($zip->set_number('7422923')->is_valid_number, '山口県大島郡周防大島町地家室(佐連)');
ok($zip->set_number('7422924')->is_valid_number, '山口県大島郡周防大島町外入');
ok($zip->set_number('7422924')->is_valid_number, '山口県大島郡周防大島町外入(伊崎)');
ok($zip->set_number('7430000')->is_valid_number, '山口県光市以下に掲載がない場合');
ok($zip->set_number('7430001')->is_valid_number, '山口県光市室積村');
ok($zip->set_number('7430002')->is_valid_number, '山口県光市室積浦');
ok($zip->set_number('7430003')->is_valid_number, '山口県光市牛島');
ok($zip->set_number('7430004')->is_valid_number, '山口県光市室積市延');
ok($zip->set_number('7430005')->is_valid_number, '山口県光市室積東ノ庄');
ok($zip->set_number('7430006')->is_valid_number, '山口県光市室積神田');
ok($zip->set_number('7430007')->is_valid_number, '山口県光市室積');
ok($zip->set_number('7430008')->is_valid_number, '山口県光市室積中央町');
ok($zip->set_number('7430009')->is_valid_number, '山口県光市室積松原');
ok($zip->set_number('7430011')->is_valid_number, '山口県光市光井');
ok($zip->set_number('7430012')->is_valid_number, '山口県光市千坊台');
ok($zip->set_number('7430013')->is_valid_number, '山口県光市中央');
ok($zip->set_number('7430021')->is_valid_number, '山口県光市浅江');
ok($zip->set_number('7430022')->is_valid_number, '山口県光市虹ケ浜');
ok($zip->set_number('7430023')->is_valid_number, '山口県光市光ケ丘');
ok($zip->set_number('7430031')->is_valid_number, '山口県光市虹ケ丘');
ok($zip->set_number('7430041')->is_valid_number, '山口県光市丸山町');
ok($zip->set_number('7430042')->is_valid_number, '山口県光市宝町');
ok($zip->set_number('7430043')->is_valid_number, '山口県光市協和町');
ok($zip->set_number('7430044')->is_valid_number, '山口県光市和田町');
ok($zip->set_number('7430045')->is_valid_number, '山口県光市宮ノ下町');
ok($zip->set_number('7430046')->is_valid_number, '山口県光市木園');
ok($zip->set_number('7430047')->is_valid_number, '山口県光市花園');
ok($zip->set_number('7430048')->is_valid_number, '山口県光市中村町');
ok($zip->set_number('7430051')->is_valid_number, '山口県光市岩狩');
ok($zip->set_number('7430052')->is_valid_number, '山口県光市三井');
ok($zip->set_number('7430061')->is_valid_number, '山口県光市小周防');
ok($zip->set_number('7430062')->is_valid_number, '山口県光市立野');
ok($zip->set_number('7430063')->is_valid_number, '山口県光市島田');
ok($zip->set_number('7430064')->is_valid_number, '山口県光市中島田');
ok($zip->set_number('7430065')->is_valid_number, '山口県光市上島田');
ok($zip->set_number('7430071')->is_valid_number, '山口県光市室積新開');
ok($zip->set_number('7430072')->is_valid_number, '山口県光市室積大町');
ok($zip->set_number('7430073')->is_valid_number, '山口県光市室積正木');
ok($zip->set_number('7430074')->is_valid_number, '山口県光市室積西ノ庄');
ok($zip->set_number('7430075')->is_valid_number, '山口県光市室積沖田');
ok($zip->set_number('7430101')->is_valid_number, '山口県光市塩田');
ok($zip->set_number('7430102')->is_valid_number, '山口県光市三輪');
ok($zip->set_number('7430103')->is_valid_number, '山口県光市岩田');
ok($zip->set_number('7430104')->is_valid_number, '山口県光市岩田立野');
ok($zip->set_number('7430105')->is_valid_number, '山口県光市束荷');
ok($zip->set_number('7440000')->is_valid_number, '山口県下松市以下に掲載がない場合');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(江ノ浦)');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(大松ケ浦)');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(尾郷)');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(尾泊)');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(小深浦)');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(瀬戸)');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(深浦)');
ok($zip->set_number('7440001')->is_valid_number, '山口県下松市笠戸島(本浦)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(江口)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(上豊井)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(下豊井)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(神田町)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(恋ケ浜)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(新町)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(洲鼻)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(住吉町)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(寺迫)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(寺迫半上)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(二宮町)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(花垣)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(東海岸通り)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(東豊井開作)');
ok($zip->set_number('7440002')->is_valid_number, '山口県下松市東豊井(松神町)');
ok($zip->set_number('7440003')->is_valid_number, '山口県下松市琴平町');
ok($zip->set_number('7440004')->is_valid_number, '山口県下松市青柳');
ok($zip->set_number('7440005')->is_valid_number, '山口県下松市古川町');
ok($zip->set_number('7440006')->is_valid_number, '山口県下松市旗岡');
ok($zip->set_number('7440007')->is_valid_number, '山口県下松市駅南');
ok($zip->set_number('7440008')->is_valid_number, '山口県下松市新川');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(相生町)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(旭町)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(幸町)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(汐見町)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(高砂町)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(所田)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(本町)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(都町)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(元町東)');
ok($zip->set_number('7440011')->is_valid_number, '山口県下松市西豊井(元町西)');
ok($zip->set_number('7440012')->is_valid_number, '山口県下松市北斗町');
ok($zip->set_number('7440013')->is_valid_number, '山口県下松市栄町');
ok($zip->set_number('7440014')->is_valid_number, '山口県下松市中市');
ok($zip->set_number('7440015')->is_valid_number, '山口県下松市大手町');
ok($zip->set_number('7440017')->is_valid_number, '山口県下松市東柳');
ok($zip->set_number('7440018')->is_valid_number, '山口県下松市西柳');
ok($zip->set_number('7440019')->is_valid_number, '山口県下松市桜町');
ok($zip->set_number('7440021')->is_valid_number, '山口県下松市平田');
ok($zip->set_number('7440021')->is_valid_number, '山口県下松市平田(東開作)');
ok($zip->set_number('7440021')->is_valid_number, '山口県下松市平田(西開作)');
ok($zip->set_number('7440022')->is_valid_number, '山口県下松市末武下');
ok($zip->set_number('7440022')->is_valid_number, '山口県下松市末武下(あけぼの町)');
ok($zip->set_number('7440022')->is_valid_number, '山口県下松市末武下(松中町)');
ok($zip->set_number('7440022')->is_valid_number, '山口県下松市末武下(弥生町)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(朝日台)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(荒神)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(西河原)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(東中村)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(広石)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(向香力)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(山根)');
ok($zip->set_number('7440023')->is_valid_number, '山口県下松市末武中(和田)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(上地)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(浴)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(戎町)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(華陵)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(下高塚)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(昭和)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(高橋)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(大黒町)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(常森)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(中市)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(西町)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(東町)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(緑ケ丘)');
ok($zip->set_number('7440024')->is_valid_number, '山口県下松市末武上(南花岡)');
ok($zip->set_number('7440025')->is_valid_number, '山口県下松市中央町');
ok($zip->set_number('7440027')->is_valid_number, '山口県下松市南花岡');
ok($zip->set_number('7440028')->is_valid_number, '山口県下松市藤光町');
ok($zip->set_number('7440029')->is_valid_number, '山口県下松市楠木町');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(猪ノ尻)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(上時宗)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(高垣団地)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(下村)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(為弘)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(大王団地)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(田園調布)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(藤立)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(時政)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(時宗)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(中村)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(西時宗)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(西村)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(西村団地)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(羽根田町)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(東時宗)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(東万ノ木団地)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(万ノ木町)');
ok($zip->set_number('7440031')->is_valid_number, '山口県下松市生野屋(宮本)');
ok($zip->set_number('7440032')->is_valid_number, '山口県下松市生野屋西');
ok($zip->set_number('7440033')->is_valid_number, '山口県下松市生野屋南');
ok($zip->set_number('7440041')->is_valid_number, '山口県下松市山田');
ok($zip->set_number('7440041')->is_valid_number, '山口県下松市山田(梅ノ木原)');
ok($zip->set_number('7440041')->is_valid_number, '山口県下松市山田(浴条)');
ok($zip->set_number('7440041')->is_valid_number, '山口県下松市山田(山田上)');
ok($zip->set_number('7440041')->is_valid_number, '山口県下松市山田(山田下)');
ok($zip->set_number('7440042')->is_valid_number, '山口県下松市切山');
ok($zip->set_number('7440042')->is_valid_number, '山口県下松市切山(切山上)');
ok($zip->set_number('7440042')->is_valid_number, '山口県下松市切山(切山中)');
ok($zip->set_number('7440042')->is_valid_number, '山口県下松市切山(切山下)');
ok($zip->set_number('7440042')->is_valid_number, '山口県下松市切山(中)');
ok($zip->set_number('7440043')->is_valid_number, '山口県下松市東陽');
ok($zip->set_number('7440051')->is_valid_number, '山口県下松市来巻');
ok($zip->set_number('7440051')->is_valid_number, '山口県下松市来巻(東)');
ok($zip->set_number('7440051')->is_valid_number, '山口県下松市来巻(西)');
ok($zip->set_number('7440052')->is_valid_number, '山口県下松市桃山町');
ok($zip->set_number('7440053')->is_valid_number, '山口県下松市東和');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(青葉台)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(大河内)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(岡市)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(岡ノ原町)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(川瀬)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(下松セントシティ)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(久保)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(久保市)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(黒杭)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(小野)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(幸ケ丘)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(昭和通り)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(城山台)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(素通り)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(谷)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(つつじケ丘)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(出合)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(殿ケ浴)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(中戸原)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(成川)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(二ノ瀬)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(葉山)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(日ノ出町)');
ok($zip->set_number('7440061')->is_valid_number, '山口県下松市河内(吉原)');
ok($zip->set_number('7440062')->is_valid_number, '山口県下松市昭和町');
ok($zip->set_number('7440063')->is_valid_number, '山口県下松市若宮町');
ok($zip->set_number('7440065')->is_valid_number, '山口県下松市星が丘');
ok($zip->set_number('7440071')->is_valid_number, '山口県下松市清瀬町');
ok($zip->set_number('7440072')->is_valid_number, '山口県下松市望町');
ok($zip->set_number('7440073')->is_valid_number, '山口県下松市美里町');
ok($zip->set_number('7440074')->is_valid_number, '山口県下松市潮音町');
ok($zip->set_number('7440075')->is_valid_number, '山口県下松市瑞穂町');
ok($zip->set_number('7440076')->is_valid_number, '山口県下松市せせらぎ町');
ok($zip->set_number('7440077')->is_valid_number, '山口県下松市中島町');
ok($zip->set_number('7440078')->is_valid_number, '山口県下松市西市');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(赤谷)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(清若)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(下谷一区)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(下谷二区)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(下谷三区)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(中瀬)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(中原)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(西平谷)');
ok($zip->set_number('7440271')->is_valid_number, '山口県下松市下谷(山高)');
ok($zip->set_number('7440272')->is_valid_number, '山口県下松市大藤谷');
ok($zip->set_number('7440273')->is_valid_number, '山口県下松市瀬戸');
ok($zip->set_number('7440273')->is_valid_number, '山口県下松市瀬戸(後山)');
ok($zip->set_number('7440273')->is_valid_number, '山口県下松市瀬戸(高橋)');
ok($zip->set_number('7440273')->is_valid_number, '山口県下松市瀬戸(中瀬)');
ok($zip->set_number('7440273')->is_valid_number, '山口県下松市瀬戸(中原)');
ok($zip->set_number('7440274')->is_valid_number, '山口県下松市温見');
ok($zip->set_number('7440274')->is_valid_number, '山口県下松市温見(後山)');
ok($zip->set_number('7440274')->is_valid_number, '山口県下松市温見(道谷)');
ok($zip->set_number('7440275')->is_valid_number, '山口県下松市中須南');
ok($zip->set_number('7440276')->is_valid_number, '山口県下松市米川');
ok($zip->set_number('7450000')->is_valid_number, '山口県周南市以下に掲載がない場合');
ok($zip->set_number('7450001')->is_valid_number, '山口県周南市辻町');
ok($zip->set_number('7450002')->is_valid_number, '山口県周南市二番町');
ok($zip->set_number('7450003')->is_valid_number, '山口県周南市三番町');
ok($zip->set_number('7450004')->is_valid_number, '山口県周南市毛利町');
ok($zip->set_number('7450005')->is_valid_number, '山口県周南市児玉町');
ok($zip->set_number('7450006')->is_valid_number, '山口県周南市花畠町');
ok($zip->set_number('7450007')->is_valid_number, '山口県周南市岐南町');
ok($zip->set_number('7450011')->is_valid_number, '山口県周南市桜馬場通り');
ok($zip->set_number('7450012')->is_valid_number, '山口県周南市川端町');
ok($zip->set_number('7450013')->is_valid_number, '山口県周南市昭和通り');
ok($zip->set_number('7450014')->is_valid_number, '山口県周南市飯島町');
ok($zip->set_number('7450015')->is_valid_number, '山口県周南市平和通り');
ok($zip->set_number('7450016')->is_valid_number, '山口県周南市若宮町');
ok($zip->set_number('7450017')->is_valid_number, '山口県周南市新町');
ok($zip->set_number('7450021')->is_valid_number, '山口県周南市柳町');
ok($zip->set_number('7450022')->is_valid_number, '山口県周南市橋本町');
ok($zip->set_number('7450023')->is_valid_number, '山口県周南市那智町');
ok($zip->set_number('7450024')->is_valid_number, '山口県周南市晴海町');
ok($zip->set_number('7450025')->is_valid_number, '山口県周南市築港町');
ok($zip->set_number('7450026')->is_valid_number, '山口県周南市住崎町');
ok($zip->set_number('7450027')->is_valid_number, '山口県周南市糀町');
ok($zip->set_number('7450031')->is_valid_number, '山口県周南市銀南街');
ok($zip->set_number('7450032')->is_valid_number, '山口県周南市銀座');
ok($zip->set_number('7450033')->is_valid_number, '山口県周南市みなみ銀座');
ok($zip->set_number('7450034')->is_valid_number, '山口県周南市御幸通り');
ok($zip->set_number('7450035')->is_valid_number, '山口県周南市有楽町');
ok($zip->set_number('7450036')->is_valid_number, '山口県周南市本町');
ok($zip->set_number('7450037')->is_valid_number, '山口県周南市栄町');
ok($zip->set_number('7450041')->is_valid_number, '山口県周南市戎町');
ok($zip->set_number('7450042')->is_valid_number, '山口県周南市野上町');
ok($zip->set_number('7450043')->is_valid_number, '山口県周南市都町');
ok($zip->set_number('7450044')->is_valid_number, '山口県周南市千代田町');
ok($zip->set_number('7450045')->is_valid_number, '山口県周南市徳山港町');
ok($zip->set_number('7450046')->is_valid_number, '山口県周南市権現町');
ok($zip->set_number('7450047')->is_valid_number, '山口県周南市入船町');
ok($zip->set_number('7450051')->is_valid_number, '山口県周南市沖見町');
ok($zip->set_number('7450052')->is_valid_number, '山口県周南市初音町');
ok($zip->set_number('7450053')->is_valid_number, '山口県周南市御影町');
ok($zip->set_number('7450054')->is_valid_number, '山口県周南市西松原');
ok($zip->set_number('7450055')->is_valid_number, '山口県周南市相生町');
ok($zip->set_number('7450056')->is_valid_number, '山口県周南市新宿通');
ok($zip->set_number('7450057')->is_valid_number, '山口県周南市大津島');
ok($zip->set_number('7450061')->is_valid_number, '山口県周南市鐘楼町');
ok($zip->set_number('7450062')->is_valid_number, '山口県周南市月丘町');
ok($zip->set_number('7450063')->is_valid_number, '山口県周南市今住町');
ok($zip->set_number('7450064')->is_valid_number, '山口県周南市住吉町');
ok($zip->set_number('7450065')->is_valid_number, '山口県周南市原宿町');
ok($zip->set_number('7450066')->is_valid_number, '山口県周南市岡田町');
ok($zip->set_number('7450071')->is_valid_number, '山口県周南市岐山通り');
ok($zip->set_number('7450072')->is_valid_number, '山口県周南市弥生町');
ok($zip->set_number('7450073')->is_valid_number, '山口県周南市代々木通り');
ok($zip->set_number('7450074')->is_valid_number, '山口県周南市今宿町');
ok($zip->set_number('7450075')->is_valid_number, '山口県周南市緑町');
ok($zip->set_number('7450076')->is_valid_number, '山口県周南市梅園町');
ok($zip->set_number('7450121')->is_valid_number, '山口県周南市須々万奥');
ok($zip->set_number('7450122')->is_valid_number, '山口県周南市須々万本郷');
ok($zip->set_number('7450123')->is_valid_number, '山口県周南市徳山(杉ケ峠)');
ok($zip->set_number('7450124')->is_valid_number, '山口県周南市莇地');
ok($zip->set_number('7450125')->is_valid_number, '山口県周南市長穂');
ok($zip->set_number('7450241')->is_valid_number, '山口県周南市大向');
ok($zip->set_number('7450242')->is_valid_number, '山口県周南市大道理');
ok($zip->set_number('7450301')->is_valid_number, '山口県周南市大潮');
ok($zip->set_number('7450302')->is_valid_number, '山口県周南市鹿野上');
ok($zip->set_number('7450303')->is_valid_number, '山口県周南市鹿野中');
ok($zip->set_number('7450304')->is_valid_number, '山口県周南市鹿野下');
ok($zip->set_number('7450401')->is_valid_number, '山口県周南市須万');
ok($zip->set_number('7450402')->is_valid_number, '山口県周南市金峰');
ok($zip->set_number('7450501')->is_valid_number, '山口県周南市八代');
ok($zip->set_number('7450511')->is_valid_number, '山口県周南市中須北');
ok($zip->set_number('7450512')->is_valid_number, '山口県周南市中須南');
ok($zip->set_number('7450611')->is_valid_number, '山口県周南市奥関屋');
ok($zip->set_number('7450612')->is_valid_number, '山口県周南市呼坂');
ok($zip->set_number('7450613')->is_valid_number, '山口県周南市夢ケ丘');
ok($zip->set_number('7450614')->is_valid_number, '山口県周南市御所尾原');
ok($zip->set_number('7450615')->is_valid_number, '山口県周南市勝間ヶ丘');
ok($zip->set_number('7450616')->is_valid_number, '山口県周南市緑ケ丘');
ok($zip->set_number('7450617')->is_valid_number, '山口県周南市勝間原');
ok($zip->set_number('7450618')->is_valid_number, '山口県周南市藤ヶ台');
ok($zip->set_number('7450621')->is_valid_number, '山口県周南市原');
ok($zip->set_number('7450622')->is_valid_number, '山口県周南市樋口');
ok($zip->set_number('7450623')->is_valid_number, '山口県周南市清尾');
ok($zip->set_number('7450631')->is_valid_number, '山口県周南市安田');
ok($zip->set_number('7450632')->is_valid_number, '山口県周南市鶴見台');
ok($zip->set_number('7450641')->is_valid_number, '山口県周南市小松原');
ok($zip->set_number('7450642')->is_valid_number, '山口県周南市中村');
ok($zip->set_number('7450643')->is_valid_number, '山口県周南市新清光台');
ok($zip->set_number('7450651')->is_valid_number, '山口県周南市大河内');
ok($zip->set_number('7450652')->is_valid_number, '山口県周南市幸ケ丘');
ok($zip->set_number('7450653')->is_valid_number, '山口県周南市清光台町');
ok($zip->set_number('7450654')->is_valid_number, '山口県周南市自由ケ丘');
ok($zip->set_number('7450661')->is_valid_number, '山口県周南市呼坂本町');
ok($zip->set_number('7450662')->is_valid_number, '山口県周南市高水原');
ok($zip->set_number('7450663')->is_valid_number, '山口県周南市熊毛中央町');
ok($zip->set_number('7450801')->is_valid_number, '山口県周南市久米');
ok($zip->set_number('7450802')->is_valid_number, '山口県周南市栗屋');
ok($zip->set_number('7450803')->is_valid_number, '山口県周南市大島');
ok($zip->set_number('7450804')->is_valid_number, '山口県周南市粭島');
ok($zip->set_number('7450805')->is_valid_number, '山口県周南市櫛ヶ浜');
ok($zip->set_number('7450806')->is_valid_number, '山口県周南市桜木');
ok($zip->set_number('7450807')->is_valid_number, '山口県周南市城ケ丘');
ok($zip->set_number('7450808')->is_valid_number, '山口県周南市平原町');
ok($zip->set_number('7450809')->is_valid_number, '山口県周南市久米中央');
ok($zip->set_number('7450811')->is_valid_number, '山口県周南市五月町');
ok($zip->set_number('7450812')->is_valid_number, '山口県周南市横浜町');
ok($zip->set_number('7450813')->is_valid_number, '山口県周南市由加町');
ok($zip->set_number('7450814')->is_valid_number, '山口県周南市鼓海');
ok($zip->set_number('7450815')->is_valid_number, '山口県周南市宮前町');
ok($zip->set_number('7450816')->is_valid_number, '山口県周南市遠石');
ok($zip->set_number('7450817')->is_valid_number, '山口県周南市上遠石町');
ok($zip->set_number('7450821')->is_valid_number, '山口県周南市曙町');
ok($zip->set_number('7450822')->is_valid_number, '山口県周南市孝田町');
ok($zip->set_number('7450823')->is_valid_number, '山口県周南市周陽');
ok($zip->set_number('7450824')->is_valid_number, '山口県周南市大内町');
ok($zip->set_number('7450825')->is_valid_number, '山口県周南市秋月');
ok($zip->set_number('7450826')->is_valid_number, '山口県周南市江の宮町');
ok($zip->set_number('7450827')->is_valid_number, '山口県周南市瀬戸見町');
ok($zip->set_number('7450831')->is_valid_number, '山口県周南市楠木');
ok($zip->set_number('7450832')->is_valid_number, '山口県周南市扇町');
ok($zip->set_number('7450833')->is_valid_number, '山口県周南市泉原町');
ok($zip->set_number('7450834')->is_valid_number, '山口県周南市清水町');
ok($zip->set_number('7450835')->is_valid_number, '山口県周南市舞車町');
ok($zip->set_number('7450836')->is_valid_number, '山口県周南市慶万町');
ok($zip->set_number('7450837')->is_valid_number, '山口県周南市譲羽');
ok($zip->set_number('7450841')->is_valid_number, '山口県周南市若草町');
ok($zip->set_number('7450842')->is_valid_number, '山口県周南市青山町');
ok($zip->set_number('7450843')->is_valid_number, '山口県周南市新宮町');
ok($zip->set_number('7450844')->is_valid_number, '山口県周南市速玉町');
ok($zip->set_number('7450845')->is_valid_number, '山口県周南市河東町');
ok($zip->set_number('7450846')->is_valid_number, '山口県周南市東山町');
ok($zip->set_number('7450847')->is_valid_number, '山口県周南市松保町');
ok($zip->set_number('7450851')->is_valid_number, '山口県周南市徳山(その他)');
ok($zip->set_number('7450852')->is_valid_number, '山口県周南市川曲');
ok($zip->set_number('7450853')->is_valid_number, '山口県周南市上村');
ok($zip->set_number('7450854')->is_valid_number, '山口県周南市中野');
ok($zip->set_number('7450855')->is_valid_number, '山口県周南市川上');
ok($zip->set_number('7450856')->is_valid_number, '山口県周南市浦山');
ok($zip->set_number('7450857')->is_valid_number, '山口県周南市浦山開作');
ok($zip->set_number('7450858')->is_valid_number, '山口県周南市花陽');
ok($zip->set_number('7450861')->is_valid_number, '山口県周南市新地');
ok($zip->set_number('7450862')->is_valid_number, '山口県周南市江口');
ok($zip->set_number('7450863')->is_valid_number, '山口県周南市御山町');
ok($zip->set_number('7450864')->is_valid_number, '山口県周南市北山');
ok($zip->set_number('7450865')->is_valid_number, '山口県周南市蓮ヶ浴');
ok($zip->set_number('7450866')->is_valid_number, '山口県周南市土越');
ok($zip->set_number('7450867')->is_valid_number, '山口県周南市新堀');
ok($zip->set_number('7450868')->is_valid_number, '山口県周南市南浦山町');
ok($zip->set_number('7450869')->is_valid_number, '山口県周南市東北山');
ok($zip->set_number('7450871')->is_valid_number, '山口県周南市御弓町');
ok($zip->set_number('7450872')->is_valid_number, '山口県周南市一番丁');
ok($zip->set_number('7450873')->is_valid_number, '山口県周南市三田川');
ok($zip->set_number('7450874')->is_valid_number, '山口県周南市公園区');
ok($zip->set_number('7450875')->is_valid_number, '山口県周南市西金剛山');
ok($zip->set_number('7450876')->is_valid_number, '山口県周南市中金剛山');
ok($zip->set_number('7450877')->is_valid_number, '山口県周南市東金剛山');
ok($zip->set_number('7450878')->is_valid_number, '山口県周南市幸の台');
ok($zip->set_number('7450881')->is_valid_number, '山口県周南市東辻');
ok($zip->set_number('7450882')->is_valid_number, '山口県周南市一ノ井手');
ok($zip->set_number('7450883')->is_valid_number, '山口県周南市栄谷');
ok($zip->set_number('7450884')->is_valid_number, '山口県周南市二ノ井手');
ok($zip->set_number('7450885')->is_valid_number, '山口県周南市高尾団地');
ok($zip->set_number('7450886')->is_valid_number, '山口県周南市黒岩町');
ok($zip->set_number('7450887')->is_valid_number, '山口県周南市馬屋');
ok($zip->set_number('7451131')->is_valid_number, '山口県周南市戸田');
ok($zip->set_number('7451132')->is_valid_number, '山口県周南市湯野');
ok($zip->set_number('7460001')->is_valid_number, '山口県周南市川崎');
ok($zip->set_number('7460002')->is_valid_number, '山口県周南市西千代田町');
ok($zip->set_number('7460003')->is_valid_number, '山口県周南市道源町');
ok($zip->set_number('7460004')->is_valid_number, '山口県周南市三笹町');
ok($zip->set_number('7460005')->is_valid_number, '山口県周南市渚町');
ok($zip->set_number('7460006')->is_valid_number, '山口県周南市開成町');
ok($zip->set_number('7460007')->is_valid_number, '山口県周南市竹島町');
ok($zip->set_number('7460008')->is_valid_number, '山口県周南市椎木町');
ok($zip->set_number('7460009')->is_valid_number, '山口県周南市川手');
ok($zip->set_number('7460011')->is_valid_number, '山口県周南市土井');
ok($zip->set_number('7460012')->is_valid_number, '山口県周南市政所');
ok($zip->set_number('7460013')->is_valid_number, '山口県周南市桶川町');
ok($zip->set_number('7460014')->is_valid_number, '山口県周南市古川町');
ok($zip->set_number('7460015')->is_valid_number, '山口県周南市清水');
ok($zip->set_number('7460016')->is_valid_number, '山口県周南市中央町');
ok($zip->set_number('7460017')->is_valid_number, '山口県周南市宮の前');
ok($zip->set_number('7460018')->is_valid_number, '山口県周南市大神');
ok($zip->set_number('7460019')->is_valid_number, '山口県周南市臨海町');
ok($zip->set_number('7460021')->is_valid_number, '山口県周南市花園町');
ok($zip->set_number('7460022')->is_valid_number, '山口県周南市野村');
ok($zip->set_number('7460023')->is_valid_number, '山口県周南市野村南町');
ok($zip->set_number('7460024')->is_valid_number, '山口県周南市古泉');
ok($zip->set_number('7460025')->is_valid_number, '山口県周南市古市');
ok($zip->set_number('7460026')->is_valid_number, '山口県周南市浜田');
ok($zip->set_number('7460027')->is_valid_number, '山口県周南市小川屋町');
ok($zip->set_number('7460028')->is_valid_number, '山口県周南市港町');
ok($zip->set_number('7460029')->is_valid_number, '山口県周南市平野');
ok($zip->set_number('7460031')->is_valid_number, '山口県周南市坂根町');
ok($zip->set_number('7460032')->is_valid_number, '山口県周南市河内町');
ok($zip->set_number('7460033')->is_valid_number, '山口県周南市新堤町');
ok($zip->set_number('7460034')->is_valid_number, '山口県周南市富田');
ok($zip->set_number('7460035')->is_valid_number, '山口県周南市日地町');
ok($zip->set_number('7460036')->is_valid_number, '山口県周南市温田');
ok($zip->set_number('7460037')->is_valid_number, '山口県周南市丸山町');
ok($zip->set_number('7460038')->is_valid_number, '山口県周南市福川');
ok($zip->set_number('7460039')->is_valid_number, '山口県周南市富田新町');
ok($zip->set_number('7460041')->is_valid_number, '山口県周南市社地町');
ok($zip->set_number('7460042')->is_valid_number, '山口県周南市福川南町');
ok($zip->set_number('7460043')->is_valid_number, '山口県周南市新田');
ok($zip->set_number('7460044')->is_valid_number, '山口県周南市西桝町');
ok($zip->set_number('7460045')->is_valid_number, '山口県周南市新地町');
ok($zip->set_number('7460051')->is_valid_number, '山口県周南市御姫町');
ok($zip->set_number('7460052')->is_valid_number, '山口県周南市中畷町');
ok($zip->set_number('7460053')->is_valid_number, '山口県周南市室尾');
ok($zip->set_number('7460054')->is_valid_number, '山口県周南市長田町');
ok($zip->set_number('7460055')->is_valid_number, '山口県周南市かせ河原町');
ok($zip->set_number('7460056')->is_valid_number, '山口県周南市羽島');
ok($zip->set_number('7460061')->is_valid_number, '山口県周南市皿山町');
ok($zip->set_number('7460062')->is_valid_number, '山口県周南市福川中市町');
ok($zip->set_number('7460063')->is_valid_number, '山口県周南市本陣町');
ok($zip->set_number('7460064')->is_valid_number, '山口県周南市若山');
ok($zip->set_number('7460065')->is_valid_number, '山口県周南市上迫町');
ok($zip->set_number('7460081')->is_valid_number, '山口県周南市四熊');
ok($zip->set_number('7460082')->is_valid_number, '山口県周南市下上');
ok($zip->set_number('7460083')->is_valid_number, '山口県周南市小畑');
ok($zip->set_number('7460084')->is_valid_number, '山口県周南市夜市');
ok($zip->set_number('7460101')->is_valid_number, '山口県周南市高瀬');
ok($zip->set_number('7460102')->is_valid_number, '山口県周南市夏切');
ok($zip->set_number('7460103')->is_valid_number, '山口県周南市垰');
ok($zip->set_number('7460104')->is_valid_number, '山口県周南市米光');
ok($zip->set_number('7460105')->is_valid_number, '山口県周南市馬神');
ok($zip->set_number('7470000')->is_valid_number, '山口県防府市以下に掲載がない場合');
ok($zip->set_number('7470001')->is_valid_number, '山口県防府市岩畠');
ok($zip->set_number('7470002')->is_valid_number, '山口県防府市酢貝');
ok($zip->set_number('7470003')->is_valid_number, '山口県防府市牟礼柳');
ok($zip->set_number('7470004')->is_valid_number, '山口県防府市牟礼');
ok($zip->set_number('7470005')->is_valid_number, '山口県防府市中西');
ok($zip->set_number('7470006')->is_valid_number, '山口県防府市敷山町');
ok($zip->set_number('7470011')->is_valid_number, '山口県防府市岸津');
ok($zip->set_number('7470012')->is_valid_number, '山口県防府市牟礼今宿');
ok($zip->set_number('7470013')->is_valid_number, '山口県防府市沖今宿');
ok($zip->set_number('7470014')->is_valid_number, '山口県防府市江泊');
ok($zip->set_number('7470021')->is_valid_number, '山口県防府市国分寺町');
ok($zip->set_number('7470022')->is_valid_number, '山口県防府市惣社町');
ok($zip->set_number('7470023')->is_valid_number, '山口県防府市多々良');
ok($zip->set_number('7470024')->is_valid_number, '山口県防府市国衙');
ok($zip->set_number('7470025')->is_valid_number, '山口県防府市美和町');
ok($zip->set_number('7470026')->is_valid_number, '山口県防府市緑町');
ok($zip->set_number('7470027')->is_valid_number, '山口県防府市南松崎町');
ok($zip->set_number('7470028')->is_valid_number, '山口県防府市東松崎町');
ok($zip->set_number('7470029')->is_valid_number, '山口県防府市松崎町');
ok($zip->set_number('7470031')->is_valid_number, '山口県防府市迫戸町');
ok($zip->set_number('7470032')->is_valid_number, '山口県防府市宮市町');
ok($zip->set_number('7470033')->is_valid_number, '山口県防府市上天神町');
ok($zip->set_number('7470034')->is_valid_number, '山口県防府市天神');
ok($zip->set_number('7470035')->is_valid_number, '山口県防府市栄町');
ok($zip->set_number('7470036')->is_valid_number, '山口県防府市戎町');
ok($zip->set_number('7470037')->is_valid_number, '山口県防府市八王子');
ok($zip->set_number('7470041')->is_valid_number, '山口県防府市本橋町');
ok($zip->set_number('7470042')->is_valid_number, '山口県防府市今市町');
ok($zip->set_number('7470043')->is_valid_number, '山口県防府市平和町');
ok($zip->set_number('7470044')->is_valid_number, '山口県防府市佐波');
ok($zip->set_number('7470045')->is_valid_number, '山口県防府市高倉');
ok($zip->set_number('7470046')->is_valid_number, '山口県防府市千日');
ok($zip->set_number('7470047')->is_valid_number, '山口県防府市新橋町');
ok($zip->set_number('7470051')->is_valid_number, '山口県防府市泉町');
ok($zip->set_number('7470052')->is_valid_number, '山口県防府市開出');
ok($zip->set_number('7470053')->is_valid_number, '山口県防府市開出本町');
ok($zip->set_number('7470054')->is_valid_number, '山口県防府市開出西町');
ok($zip->set_number('7470055')->is_valid_number, '山口県防府市中泉町');
ok($zip->set_number('7470056')->is_valid_number, '山口県防府市古祖原');
ok($zip->set_number('7470061')->is_valid_number, '山口県防府市東佐波令');
ok($zip->set_number('7470062')->is_valid_number, '山口県防府市上右田');
ok($zip->set_number('7470063')->is_valid_number, '山口県防府市下右田');
ok($zip->set_number('7470064')->is_valid_number, '山口県防府市高井');
ok($zip->set_number('7470065')->is_valid_number, '山口県防府市大崎');
ok($zip->set_number('7470066')->is_valid_number, '山口県防府市自由ケ丘');
ok($zip->set_number('7470067')->is_valid_number, '山口県防府市佐野');
ok($zip->set_number('7470101')->is_valid_number, '山口県防府市奥畑');
ok($zip->set_number('7470102')->is_valid_number, '山口県防府市久兼');
ok($zip->set_number('7470103')->is_valid_number, '山口県防府市和字');
ok($zip->set_number('7470104')->is_valid_number, '山口県防府市真尾');
ok($zip->set_number('7470105')->is_valid_number, '山口県防府市鈴屋');
ok($zip->set_number('7470106')->is_valid_number, '山口県防府市奈美');
ok($zip->set_number('7470107')->is_valid_number, '山口県防府市中山');
ok($zip->set_number('7470231')->is_valid_number, '山口県山口市徳地堀');
ok($zip->set_number('7470232')->is_valid_number, '山口県山口市徳地伊賀地');
ok($zip->set_number('7470233')->is_valid_number, '山口県山口市徳地岸見');
ok($zip->set_number('7470234')->is_valid_number, '山口県山口市徳地小古祖');
ok($zip->set_number('7470235')->is_valid_number, '山口県山口市徳地深谷');
ok($zip->set_number('7470341')->is_valid_number, '山口県山口市徳地引谷');
ok($zip->set_number('7470342')->is_valid_number, '山口県山口市徳地船路');
ok($zip->set_number('7470343')->is_valid_number, '山口県山口市徳地三谷');
ok($zip->set_number('7470344')->is_valid_number, '山口県山口市徳地八坂');
ok($zip->set_number('7470401')->is_valid_number, '山口県山口市徳地野谷');
ok($zip->set_number('7470402')->is_valid_number, '山口県山口市徳地柚木');
ok($zip->set_number('7470521')->is_valid_number, '山口県山口市徳地山畑');
ok($zip->set_number('7470522')->is_valid_number, '山口県山口市徳地島地');
ok($zip->set_number('7470523')->is_valid_number, '山口県山口市徳地上村');
ok($zip->set_number('7470524')->is_valid_number, '山口県山口市徳地藤木');
ok($zip->set_number('7470611')->is_valid_number, '山口県山口市徳地鯖河内');
ok($zip->set_number('7470612')->is_valid_number, '山口県山口市徳地串');
ok($zip->set_number('7470621')->is_valid_number, '山口県周南市巣山');
ok($zip->set_number('7470801')->is_valid_number, '山口県防府市駅南町');
ok($zip->set_number('7470802')->is_valid_number, '山口県防府市中央町');
ok($zip->set_number('7470803')->is_valid_number, '山口県防府市岡村町');
ok($zip->set_number('7470804')->is_valid_number, '山口県防府市松原町');
ok($zip->set_number('7470805')->is_valid_number, '山口県防府市鞠生町');
ok($zip->set_number('7470806')->is_valid_number, '山口県防府市石が口');
ok($zip->set_number('7470807')->is_valid_number, '山口県防府市桑南');
ok($zip->set_number('7470808')->is_valid_number, '山口県防府市桑山');
ok($zip->set_number('7470809')->is_valid_number, '山口県防府市寿町');
ok($zip->set_number('7470811')->is_valid_number, '山口県防府市車塚町');
ok($zip->set_number('7470812')->is_valid_number, '山口県防府市鋳物師町');
ok($zip->set_number('7470813')->is_valid_number, '山口県防府市東三田尻');
ok($zip->set_number('7470814')->is_valid_number, '山口県防府市三田尻');
ok($zip->set_number('7470815')->is_valid_number, '山口県防府市協和町');
ok($zip->set_number('7470816')->is_valid_number, '山口県防府市華浦');
ok($zip->set_number('7470817')->is_valid_number, '山口県防府市自力町');
ok($zip->set_number('7470818')->is_valid_number, '山口県防府市三田尻本町');
ok($zip->set_number('7470819')->is_valid_number, '山口県防府市お茶屋町');
ok($zip->set_number('7470821')->is_valid_number, '山口県防府市警固町');
ok($zip->set_number('7470822')->is_valid_number, '山口県防府市勝間');
ok($zip->set_number('7470823')->is_valid_number, '山口県防府市鐘紡町');
ok($zip->set_number('7470824')->is_valid_number, '山口県防府市新築地町');
ok($zip->set_number('7470825')->is_valid_number, '山口県防府市新田');
ok($zip->set_number('7470831')->is_valid_number, '山口県防府市向島');
ok($zip->set_number('7470832')->is_valid_number, '山口県防府市野島');
ok($zip->set_number('7470833')->is_valid_number, '山口県防府市浜方');
ok($zip->set_number('7470834')->is_valid_number, '山口県防府市田島');
ok($zip->set_number('7470835')->is_valid_number, '山口県防府市西浦');
ok($zip->set_number('7470836')->is_valid_number, '山口県防府市植松');
ok($zip->set_number('7470841')->is_valid_number, '山口県防府市仁井令町');
ok($zip->set_number('7470842')->is_valid_number, '山口県防府市清水町');
ok($zip->set_number('7470843')->is_valid_number, '山口県防府市東仁井令町');
ok($zip->set_number('7470844')->is_valid_number, '山口県防府市華園町');
ok($zip->set_number('7470845')->is_valid_number, '山口県防府市仁井令');
ok($zip->set_number('7470846')->is_valid_number, '山口県防府市伊佐江');
ok($zip->set_number('7470847')->is_valid_number, '山口県防府市伊佐江町');
ok($zip->set_number('7470848')->is_valid_number, '山口県防府市華城中央');
ok($zip->set_number('7470849')->is_valid_number, '山口県防府市西仁井令');
ok($zip->set_number('7471111')->is_valid_number, '山口県防府市富海');
ok($zip->set_number('7471221')->is_valid_number, '山口県山口市鋳銭司');
ok($zip->set_number('7471231')->is_valid_number, '山口県防府市切畑');
ok($zip->set_number('7471232')->is_valid_number, '山口県防府市台道');
ok($zip->set_number('7490101')->is_valid_number, '山口県柳井市神代');
ok($zip->set_number('7490102')->is_valid_number, '山口県柳井市大畠');
ok($zip->set_number('7490103')->is_valid_number, '山口県柳井市遠崎');
ok($zip->set_number('7500000')->is_valid_number, '山口県下関市以下に掲載がない場合');
ok($zip->set_number('7500001')->is_valid_number, '山口県下関市幸町');
ok($zip->set_number('7500002')->is_valid_number, '山口県下関市宮田町');
ok($zip->set_number('7500003')->is_valid_number, '山口県下関市阿弥陀寺町');
ok($zip->set_number('7500004')->is_valid_number, '山口県下関市中之町');
ok($zip->set_number('7500005')->is_valid_number, '山口県下関市唐戸町');
ok($zip->set_number('7500006')->is_valid_number, '山口県下関市南部町');
ok($zip->set_number('7500007')->is_valid_number, '山口県下関市赤間町');
ok($zip->set_number('7500008')->is_valid_number, '山口県下関市田中町');
ok($zip->set_number('7500009')->is_valid_number, '山口県下関市上田中町');
ok($zip->set_number('7500011')->is_valid_number, '山口県下関市名池町');
ok($zip->set_number('7500012')->is_valid_number, '山口県下関市観音崎町');
ok($zip->set_number('7500013')->is_valid_number, '山口県下関市入江町');
ok($zip->set_number('7500014')->is_valid_number, '山口県下関市岬之町');
ok($zip->set_number('7500015')->is_valid_number, '山口県下関市西入江町');
ok($zip->set_number('7500016')->is_valid_number, '山口県下関市細江町');
ok($zip->set_number('7500017')->is_valid_number, '山口県下関市細江新町');
ok($zip->set_number('7500018')->is_valid_number, '山口県下関市豊前田町');
ok($zip->set_number('7500019')->is_valid_number, '山口県下関市丸山町');
ok($zip->set_number('7500021')->is_valid_number, '山口県下関市長崎中央町');
ok($zip->set_number('7500022')->is_valid_number, '山口県下関市関西本町');
ok($zip->set_number('7500023')->is_valid_number, '山口県下関市長崎新町');
ok($zip->set_number('7500024')->is_valid_number, '山口県下関市笹山町');
ok($zip->set_number('7500025')->is_valid_number, '山口県下関市竹崎町');
ok($zip->set_number('7500026')->is_valid_number, '山口県下関市長門町');
ok($zip->set_number('7500027')->is_valid_number, '山口県下関市上条町');
ok($zip->set_number('7500028')->is_valid_number, '山口県下関市長崎本町');
ok($zip->set_number('7500029')->is_valid_number, '山口県下関市長崎町');
ok($zip->set_number('7500031')->is_valid_number, '山口県下関市春日町');
ok($zip->set_number('7500032')->is_valid_number, '山口県下関市関西町');
ok($zip->set_number('7500033')->is_valid_number, '山口県下関市山手町');
ok($zip->set_number('7500034')->is_valid_number, '山口県下関市西神田町');
ok($zip->set_number('7500035')->is_valid_number, '山口県下関市桜山町');
ok($zip->set_number('7500036')->is_valid_number, '山口県下関市あるかぽーと');
ok($zip->set_number('7500041')->is_valid_number, '山口県下関市向洋町');
ok($zip->set_number('7500042')->is_valid_number, '山口県下関市中央町');
ok($zip->set_number('7500043')->is_valid_number, '山口県下関市東神田町');
ok($zip->set_number('7500044')->is_valid_number, '山口県下関市神田町');
ok($zip->set_number('7500045')->is_valid_number, '山口県下関市元町');
ok($zip->set_number('7500046')->is_valid_number, '山口県下関市羽山町');
ok($zip->set_number('7500047')->is_valid_number, '山口県下関市向山町');
ok($zip->set_number('7500048')->is_valid_number, '山口県下関市東向山町');
ok($zip->set_number('7500049')->is_valid_number, '山口県下関市栄町');
ok($zip->set_number('7500051')->is_valid_number, '山口県下関市大坪本町');
ok($zip->set_number('7500052')->is_valid_number, '山口県下関市藤附町');
ok($zip->set_number('7500053')->is_valid_number, '山口県下関市大平町');
ok($zip->set_number('7500054')->is_valid_number, '山口県下関市西大坪町');
ok($zip->set_number('7500055')->is_valid_number, '山口県下関市南大坪町');
ok($zip->set_number('7500056')->is_valid_number, '山口県下関市筋ケ浜町');
ok($zip->set_number('7500057')->is_valid_number, '山口県下関市筋川町');
ok($zip->set_number('7500058')->is_valid_number, '山口県下関市金比羅町');
ok($zip->set_number('7500059')->is_valid_number, '山口県下関市汐入町');
ok($zip->set_number('7500061')->is_valid_number, '山口県下関市上新地町');
ok($zip->set_number('7500062')->is_valid_number, '山口県下関市新地西町');
ok($zip->set_number('7500063')->is_valid_number, '山口県下関市新地町');
ok($zip->set_number('7500064')->is_valid_number, '山口県下関市今浦町');
ok($zip->set_number('7500065')->is_valid_number, '山口県下関市伊崎町');
ok($zip->set_number('7500066')->is_valid_number, '山口県下関市東大和町');
ok($zip->set_number('7500067')->is_valid_number, '山口県下関市大和町');
ok($zip->set_number('7500071')->is_valid_number, '山口県下関市彦島海士郷町');
ok($zip->set_number('7500072')->is_valid_number, '山口県下関市彦島老町');
ok($zip->set_number('7500073')->is_valid_number, '山口県下関市彦島老の山公園');
ok($zip->set_number('7500074')->is_valid_number, '山口県下関市彦島本村町');
ok($zip->set_number('7500075')->is_valid_number, '山口県下関市彦島江の浦町');
ok($zip->set_number('7500076')->is_valid_number, '山口県下関市彦島弟子待町');
ok($zip->set_number('7500077')->is_valid_number, '山口県下関市彦島弟子待東町');
ok($zip->set_number('7500078')->is_valid_number, '山口県下関市彦島杉田町');
ok($zip->set_number('7500081')->is_valid_number, '山口県下関市彦島角倉町');
ok($zip->set_number('7500082')->is_valid_number, '山口県下関市彦島山中町');
ok($zip->set_number('7500083')->is_valid_number, '山口県下関市彦島桜ケ丘町');
ok($zip->set_number('7500084')->is_valid_number, '山口県下関市彦島向井町');
ok($zip->set_number('7500085')->is_valid_number, '山口県下関市彦島田の首町');
ok($zip->set_number('7500086')->is_valid_number, '山口県下関市彦島塩浜町');
ok($zip->set_number('7500087')->is_valid_number, '山口県下関市彦島福浦町');
ok($zip->set_number('7500091')->is_valid_number, '山口県下関市彦島緑町');
ok($zip->set_number('7500092')->is_valid_number, '山口県下関市彦島迫町');
ok($zip->set_number('7500093')->is_valid_number, '山口県下関市彦島西山町');
ok($zip->set_number('7500094')->is_valid_number, '山口県下関市彦島竹ノ子島町');
ok($zip->set_number('7500095')->is_valid_number, '山口県下関市六連島');
ok($zip->set_number('7500251')->is_valid_number, '山口県下関市植田');
ok($zip->set_number('7500252')->is_valid_number, '山口県下関市内日上');
ok($zip->set_number('7500253')->is_valid_number, '山口県下関市内日下');
ok($zip->set_number('7500301')->is_valid_number, '山口県下関市菊川町西中山');
ok($zip->set_number('7500302')->is_valid_number, '山口県下関市菊川町東中山');
ok($zip->set_number('7500303')->is_valid_number, '山口県下関市菊川町樅ノ木');
ok($zip->set_number('7500304')->is_valid_number, '山口県下関市菊川町道市');
ok($zip->set_number('7500305')->is_valid_number, '山口県下関市菊川町轡井');
ok($zip->set_number('7500306')->is_valid_number, '山口県下関市菊川町下保木');
ok($zip->set_number('7500307')->is_valid_number, '山口県下関市菊川町上保木');
ok($zip->set_number('7500311')->is_valid_number, '山口県下関市菊川町上大野');
ok($zip->set_number('7500312')->is_valid_number, '山口県下関市菊川町下大野');
ok($zip->set_number('7500313')->is_valid_number, '山口県下関市菊川町田部');
ok($zip->set_number('7500314')->is_valid_number, '山口県下関市菊川町上田部');
ok($zip->set_number('7500315')->is_valid_number, '山口県下関市菊川町七見');
ok($zip->set_number('7500316')->is_valid_number, '山口県下関市菊川町吉賀');
ok($zip->set_number('7500317')->is_valid_number, '山口県下関市菊川町下岡枝');
ok($zip->set_number('7500321')->is_valid_number, '山口県下関市菊川町上岡枝');
ok($zip->set_number('7500322')->is_valid_number, '山口県下関市菊川町楢崎');
ok($zip->set_number('7500323')->is_valid_number, '山口県下関市菊川町日新');
ok($zip->set_number('7500324')->is_valid_number, '山口県下関市菊川町久野');
ok($zip->set_number('7500325')->is_valid_number, '山口県下関市菊川町貴飯');
ok($zip->set_number('7500401')->is_valid_number, '山口県下関市豊田町殿居');
ok($zip->set_number('7500402')->is_valid_number, '山口県下関市豊田町佐野');
ok($zip->set_number('7500403')->is_valid_number, '山口県下関市豊田町一ノ俣');
ok($zip->set_number('7500404')->is_valid_number, '山口県下関市豊田町荒木');
ok($zip->set_number('7500405')->is_valid_number, '山口県下関市豊田町杢路子');
ok($zip->set_number('7500411')->is_valid_number, '山口県下関市豊田町宇内');
ok($zip->set_number('7500412')->is_valid_number, '山口県下関市豊田町稲見');
ok($zip->set_number('7500413')->is_valid_number, '山口県下関市豊田町金道');
ok($zip->set_number('7500414')->is_valid_number, '山口県下関市豊田町八道');
ok($zip->set_number('7500415')->is_valid_number, '山口県下関市豊田町浮石');
ok($zip->set_number('7500416')->is_valid_number, '山口県下関市豊田町鷹子');
ok($zip->set_number('7500421')->is_valid_number, '山口県下関市豊田町殿敷');
ok($zip->set_number('7500422')->is_valid_number, '山口県下関市豊田町楢原');
ok($zip->set_number('7500423')->is_valid_number, '山口県下関市豊田町西市');
ok($zip->set_number('7500424')->is_valid_number, '山口県下関市豊田町矢田');
ok($zip->set_number('7500425')->is_valid_number, '山口県下関市豊田町庭田');
ok($zip->set_number('7500431')->is_valid_number, '山口県下関市豊田町今出');
ok($zip->set_number('7500432')->is_valid_number, '山口県下関市豊田町地吉');
ok($zip->set_number('7500433')->is_valid_number, '山口県下関市豊田町大河内');
ok($zip->set_number('7500441')->is_valid_number, '山口県下関市豊田町中村');
ok($zip->set_number('7500442')->is_valid_number, '山口県下関市豊田町稲光');
ok($zip->set_number('7500443')->is_valid_number, '山口県下関市豊田町日野');
ok($zip->set_number('7500444')->is_valid_number, '山口県下関市豊田町萩原');
ok($zip->set_number('7500445')->is_valid_number, '山口県下関市豊田町東長野');
ok($zip->set_number('7500446')->is_valid_number, '山口県下関市豊田町高山');
ok($zip->set_number('7500451')->is_valid_number, '山口県下関市豊田町阿座上');
ok($zip->set_number('7500452')->is_valid_number, '山口県下関市豊田町江良');
ok($zip->set_number('7500453')->is_valid_number, '山口県下関市豊田町手洗');
ok($zip->set_number('7500454')->is_valid_number, '山口県下関市豊田町西長野');
ok($zip->set_number('7500455')->is_valid_number, '山口県下関市豊田町城戸');
ok($zip->set_number('7500601')->is_valid_number, '山口県美祢市豊田前町麻生上');
ok($zip->set_number('7500602')->is_valid_number, '山口県美祢市豊田前町麻生下');
ok($zip->set_number('7500603')->is_valid_number, '山口県美祢市豊田前町今山');
ok($zip->set_number('7500604')->is_valid_number, '山口県美祢市豊田前町保々');
ok($zip->set_number('7500605')->is_valid_number, '山口県美祢市豊田前町古烏帽子');
ok($zip->set_number('7500606')->is_valid_number, '山口県美祢市豊田前町嶽');
ok($zip->set_number('7501101')->is_valid_number, '山口県下関市吉田');
ok($zip->set_number('7501102')->is_valid_number, '山口県下関市吉田地方');
ok($zip->set_number('7501111')->is_valid_number, '山口県下関市宇津井');
ok($zip->set_number('7501112')->is_valid_number, '山口県下関市木屋川本町');
ok($zip->set_number('7501113')->is_valid_number, '山口県下関市木屋川南町');
ok($zip->set_number('7501114')->is_valid_number, '山口県下関市王喜本町');
ok($zip->set_number('7501115')->is_valid_number, '山口県下関市王喜宇津井');
ok($zip->set_number('7501116')->is_valid_number, '山口県下関市白崎');
ok($zip->set_number('7501121')->is_valid_number, '山口県下関市松屋');
ok($zip->set_number('7501122')->is_valid_number, '山口県下関市松屋上町');
ok($zip->set_number('7501123')->is_valid_number, '山口県下関市松屋東町');
ok($zip->set_number('7501124')->is_valid_number, '山口県下関市松屋本町');
ok($zip->set_number('7501131')->is_valid_number, '山口県下関市小月町');
ok($zip->set_number('7501132')->is_valid_number, '山口県下関市小月宮の町');
ok($zip->set_number('7501133')->is_valid_number, '山口県下関市小月高雄町');
ok($zip->set_number('7501134')->is_valid_number, '山口県下関市小月京泊');
ok($zip->set_number('7501135')->is_valid_number, '山口県下関市小月西の台');
ok($zip->set_number('7501136')->is_valid_number, '山口県下関市小月小島');
ok($zip->set_number('7501137')->is_valid_number, '山口県下関市小月南町');
ok($zip->set_number('7501141')->is_valid_number, '山口県下関市小月幸町');
ok($zip->set_number('7501142')->is_valid_number, '山口県下関市小月本町');
ok($zip->set_number('7501143')->is_valid_number, '山口県下関市小月駅前');
ok($zip->set_number('7501144')->is_valid_number, '山口県下関市小月茶屋');
ok($zip->set_number('7501145')->is_valid_number, '山口県下関市小月杉迫');
ok($zip->set_number('7501146')->is_valid_number, '山口県下関市小月公園町');
ok($zip->set_number('7501147')->is_valid_number, '山口県下関市小月市原町');
ok($zip->set_number('7501151')->is_valid_number, '山口県下関市清末');
ok($zip->set_number('7501152')->is_valid_number, '山口県下関市清末陣屋');
ok($zip->set_number('7501153')->is_valid_number, '山口県下関市清末鞍馬');
ok($zip->set_number('7501154')->is_valid_number, '山口県下関市清末本町');
ok($zip->set_number('7501155')->is_valid_number, '山口県下関市清末中町');
ok($zip->set_number('7501156')->is_valid_number, '山口県下関市清末東町');
ok($zip->set_number('7501161')->is_valid_number, '山口県下関市清末西町');
ok($zip->set_number('7501162')->is_valid_number, '山口県下関市清末五毛');
ok($zip->set_number('7501163')->is_valid_number, '山口県下関市清末千房');
ok($zip->set_number('7501164')->is_valid_number, '山口県下関市清末大門');
ok($zip->set_number('7501171')->is_valid_number, '山口県下関市阿内');
ok($zip->set_number('7510801')->is_valid_number, '山口県下関市勝谷');
ok($zip->set_number('7510802')->is_valid_number, '山口県下関市勝谷新町');
ok($zip->set_number('7510803')->is_valid_number, '山口県下関市前勝谷町');
ok($zip->set_number('7510804')->is_valid_number, '山口県下関市楠乃');
ok($zip->set_number('7510805')->is_valid_number, '山口県下関市一の宮住吉');
ok($zip->set_number('7510806')->is_valid_number, '山口県下関市一の宮町');
ok($zip->set_number('7510807')->is_valid_number, '山口県下関市一の宮学園町');
ok($zip->set_number('7510808')->is_valid_number, '山口県下関市一の宮本町');
ok($zip->set_number('7510809')->is_valid_number, '山口県下関市一の宮東町');
ok($zip->set_number('7510811')->is_valid_number, '山口県下関市藤ケ谷町');
ok($zip->set_number('7510812')->is_valid_number, '山口県下関市椋野上町');
ok($zip->set_number('7510813')->is_valid_number, '山口県下関市みもすそ川町');
ok($zip->set_number('7510814')->is_valid_number, '山口県下関市壇之浦町');
ok($zip->set_number('7510815')->is_valid_number, '山口県下関市本町');
ok($zip->set_number('7510816')->is_valid_number, '山口県下関市椋野町');
ok($zip->set_number('7510817')->is_valid_number, '山口県下関市一の宮卸本町');
ok($zip->set_number('7510818')->is_valid_number, '山口県下関市卸新町');
ok($zip->set_number('7510819')->is_valid_number, '山口県下関市武久西原台');
ok($zip->set_number('7510820')->is_valid_number, '山口県下関市新椋野');
ok($zip->set_number('7510821')->is_valid_number, '山口県下関市三河町');
ok($zip->set_number('7510822')->is_valid_number, '山口県下関市宝町');
ok($zip->set_number('7510823')->is_valid_number, '山口県下関市貴船町');
ok($zip->set_number('7510824')->is_valid_number, '山口県下関市山の口町');
ok($zip->set_number('7510825')->is_valid_number, '山口県下関市石神町');
ok($zip->set_number('7510826')->is_valid_number, '山口県下関市後田町');
ok($zip->set_number('7510827')->is_valid_number, '山口県下関市幡生本町');
ok($zip->set_number('7510828')->is_valid_number, '山口県下関市幡生町');
ok($zip->set_number('7510829')->is_valid_number, '山口県下関市幡生宮の下町');
ok($zip->set_number('7510830')->is_valid_number, '山口県下関市幡生新町');
ok($zip->set_number('7510831')->is_valid_number, '山口県下関市大学町');
ok($zip->set_number('7510832')->is_valid_number, '山口県下関市生野町');
ok($zip->set_number('7510833')->is_valid_number, '山口県下関市武久町');
ok($zip->set_number('7510834')->is_valid_number, '山口県下関市山の田東町');
ok($zip->set_number('7510835')->is_valid_number, '山口県下関市山の田南町');
ok($zip->set_number('7510836')->is_valid_number, '山口県下関市山の田西町');
ok($zip->set_number('7510837')->is_valid_number, '山口県下関市山の田中央町');
ok($zip->set_number('7510838')->is_valid_number, '山口県下関市山の田本町');
ok($zip->set_number('7510839')->is_valid_number, '山口県下関市山の田北町');
ok($zip->set_number('7510840')->is_valid_number, '山口県下関市長州出島');
ok($zip->set_number('7510841')->is_valid_number, '山口県下関市垢田町');
ok($zip->set_number('7510842')->is_valid_number, '山口県下関市新垢田南町');
ok($zip->set_number('7510843')->is_valid_number, '山口県下関市新垢田東町');
ok($zip->set_number('7510844')->is_valid_number, '山口県下関市新垢田西町');
ok($zip->set_number('7510845')->is_valid_number, '山口県下関市新垢田北町');
ok($zip->set_number('7510846')->is_valid_number, '山口県下関市垢田');
ok($zip->set_number('7510847')->is_valid_number, '山口県下関市古屋町');
ok($zip->set_number('7510848')->is_valid_number, '山口県下関市綾羅木南町');
ok($zip->set_number('7510849')->is_valid_number, '山口県下関市綾羅木本町');
ok($zip->set_number('7510851')->is_valid_number, '山口県下関市熊野西町');
ok($zip->set_number('7510852')->is_valid_number, '山口県下関市熊野町');
ok($zip->set_number('7510853')->is_valid_number, '山口県下関市川中豊町');
ok($zip->set_number('7510854')->is_valid_number, '山口県下関市稗田南町');
ok($zip->set_number('7510855')->is_valid_number, '山口県下関市稗田西町');
ok($zip->set_number('7510856')->is_valid_number, '山口県下関市稗田中町');
ok($zip->set_number('7510857')->is_valid_number, '山口県下関市稗田北町');
ok($zip->set_number('7510858')->is_valid_number, '山口県下関市稗田町');
ok($zip->set_number('7510859')->is_valid_number, '山口県下関市川中本町');
ok($zip->set_number('7510861')->is_valid_number, '山口県下関市伊倉東町');
ok($zip->set_number('7510862')->is_valid_number, '山口県下関市伊倉');
ok($zip->set_number('7510863')->is_valid_number, '山口県下関市伊倉本町');
ok($zip->set_number('7510864')->is_valid_number, '山口県下関市伊倉町');
ok($zip->set_number('7510865')->is_valid_number, '山口県下関市綾羅木新町');
ok($zip->set_number('7510866')->is_valid_number, '山口県下関市綾羅木');
ok($zip->set_number('7510867')->is_valid_number, '山口県下関市延行');
ok($zip->set_number('7510868')->is_valid_number, '山口県下関市有冨');
ok($zip->set_number('7510869')->is_valid_number, '山口県下関市伊倉新町');
ok($zip->set_number('7510871')->is_valid_number, '山口県下関市秋根');
ok($zip->set_number('7510872')->is_valid_number, '山口県下関市秋根南町');
ok($zip->set_number('7510873')->is_valid_number, '山口県下関市秋根西町');
ok($zip->set_number('7510874')->is_valid_number, '山口県下関市秋根新町');
ok($zip->set_number('7510875')->is_valid_number, '山口県下関市秋根本町');
ok($zip->set_number('7510876')->is_valid_number, '山口県下関市秋根北町');
ok($zip->set_number('7510877')->is_valid_number, '山口県下関市秋根東町');
ok($zip->set_number('7510878')->is_valid_number, '山口県下関市秋根上町');
ok($zip->set_number('7510879')->is_valid_number, '山口県下関市東勝谷');
ok($zip->set_number('7510881')->is_valid_number, '山口県下関市井田');
ok($zip->set_number('7510882')->is_valid_number, '山口県下関市田倉御殿町');
ok($zip->set_number('7510883')->is_valid_number, '山口県下関市田倉');
ok($zip->set_number('7510884')->is_valid_number, '山口県下関市形山');
ok($zip->set_number('7510885')->is_valid_number, '山口県下関市形山みどり町');
ok($zip->set_number('7510886')->is_valid_number, '山口県下関市石原');
ok($zip->set_number('7510887')->is_valid_number, '山口県下関市小野');
ok($zip->set_number('7510888')->is_valid_number, '山口県下関市形山町');
ok($zip->set_number('7520901')->is_valid_number, '山口県下関市山田');
ok($zip->set_number('7520902')->is_valid_number, '山口県下関市赤池町');
ok($zip->set_number('7520903')->is_valid_number, '山口県下関市員光町');
ok($zip->set_number('7520904')->is_valid_number, '山口県下関市員光');
ok($zip->set_number('7520905')->is_valid_number, '山口県下関市西観音町');
ok($zip->set_number('7520906')->is_valid_number, '山口県下関市東観音町');
ok($zip->set_number('7520907')->is_valid_number, '山口県下関市神田');
ok($zip->set_number('7520911')->is_valid_number, '山口県下関市王司神田');
ok($zip->set_number('7520912')->is_valid_number, '山口県下関市王司川端');
ok($zip->set_number('7520913')->is_valid_number, '山口県下関市乃木浜');
ok($zip->set_number('7520914')->is_valid_number, '山口県下関市千鳥浜町');
ok($zip->set_number('7520915')->is_valid_number, '山口県下関市王司本町');
ok($zip->set_number('7520916')->is_valid_number, '山口県下関市王司上町');
ok($zip->set_number('7520921')->is_valid_number, '山口県下関市才川');
ok($zip->set_number('7520922')->is_valid_number, '山口県下関市千鳥ケ丘町');
ok($zip->set_number('7520923')->is_valid_number, '山口県下関市宇部');
ok($zip->set_number('7520924')->is_valid_number, '山口県下関市王司南町');
ok($zip->set_number('7520925')->is_valid_number, '山口県下関市亀浜町');
ok($zip->set_number('7520926')->is_valid_number, '山口県下関市ゆめタウン');
ok($zip->set_number('7520927')->is_valid_number, '山口県下関市長府扇町');
ok($zip->set_number('7520928')->is_valid_number, '山口県下関市長府才川');
ok($zip->set_number('7520931')->is_valid_number, '山口県下関市松小田');
ok($zip->set_number('7520932')->is_valid_number, '山口県下関市長府松小田北町');
ok($zip->set_number('7520933')->is_valid_number, '山口県下関市長府松小田本町');
ok($zip->set_number('7520934')->is_valid_number, '山口県下関市長府松小田東町');
ok($zip->set_number('7520935')->is_valid_number, '山口県下関市長府松小田中町');
ok($zip->set_number('7520936')->is_valid_number, '山口県下関市長府松小田南町');
ok($zip->set_number('7520937')->is_valid_number, '山口県下関市長府松小田西町');
ok($zip->set_number('7520941')->is_valid_number, '山口県下関市長府新四王司町');
ok($zip->set_number('7520942')->is_valid_number, '山口県下関市長府四王司町');
ok($zip->set_number('7520943')->is_valid_number, '山口県下関市長府豊城町');
ok($zip->set_number('7520944')->is_valid_number, '山口県下関市長府中六波町');
ok($zip->set_number('7520945')->is_valid_number, '山口県下関市長府豊浦町');
ok($zip->set_number('7520946')->is_valid_number, '山口県下関市長府中尾町');
ok($zip->set_number('7520947')->is_valid_number, '山口県下関市長府満珠町');
ok($zip->set_number('7520948')->is_valid_number, '山口県下関市長府満珠新町');
ok($zip->set_number('7520951')->is_valid_number, '山口県下関市長府日の出町');
ok($zip->set_number('7520952')->is_valid_number, '山口県下関市長府江下町');
ok($zip->set_number('7520953')->is_valid_number, '山口県下関市長府港町');
ok($zip->set_number('7520954')->is_valid_number, '山口県下関市長府古城町');
ok($zip->set_number('7520955')->is_valid_number, '山口県下関市長府八幡町');
ok($zip->set_number('7520956')->is_valid_number, '山口県下関市長府前八幡町');
ok($zip->set_number('7520957')->is_valid_number, '山口県下関市長府印内町');
ok($zip->set_number('7520958')->is_valid_number, '山口県下関市長府金屋浜町');
ok($zip->set_number('7520959')->is_valid_number, '山口県下関市長府金屋町');
ok($zip->set_number('7520961')->is_valid_number, '山口県下関市長府珠の浦町');
ok($zip->set_number('7520962')->is_valid_number, '山口県下関市長府安養寺');
ok($zip->set_number('7520963')->is_valid_number, '山口県下関市長府中土居北町');
ok($zip->set_number('7520964')->is_valid_number, '山口県下関市長府中土居本町');
ok($zip->set_number('7520965')->is_valid_number, '山口県下関市長府三島町');
ok($zip->set_number('7520966')->is_valid_number, '山口県下関市長府亀の甲');
ok($zip->set_number('7520967')->is_valid_number, '山口県下関市長府宮の内町');
ok($zip->set_number('7520968')->is_valid_number, '山口県下関市長府紺屋町');
ok($zip->set_number('7520970')->is_valid_number, '山口県下関市長府惣社町');
ok($zip->set_number('7520971')->is_valid_number, '山口県下関市長府逢坂町');
ok($zip->set_number('7520972')->is_valid_number, '山口県下関市長府古江小路町');
ok($zip->set_number('7520973')->is_valid_number, '山口県下関市長府中之町');
ok($zip->set_number('7520974')->is_valid_number, '山口県下関市長府土居の内町');
ok($zip->set_number('7520975')->is_valid_number, '山口県下関市長府中浜町');
ok($zip->set_number('7520976')->is_valid_number, '山口県下関市長府南之町');
ok($zip->set_number('7520977')->is_valid_number, '山口県下関市長府東侍町');
ok($zip->set_number('7520978')->is_valid_number, '山口県下関市長府侍町');
ok($zip->set_number('7520979')->is_valid_number, '山口県下関市長府川端');
ok($zip->set_number('7520980')->is_valid_number, '山口県下関市長府黒門町');
ok($zip->set_number('7520981')->is_valid_number, '山口県下関市豊浦村');
ok($zip->set_number('7520982')->is_valid_number, '山口県下関市長府新松原町');
ok($zip->set_number('7520983')->is_valid_number, '山口県下関市長府松原町');
ok($zip->set_number('7520984')->is_valid_number, '山口県下関市長府宮崎町');
ok($zip->set_number('7520985')->is_valid_number, '山口県下関市長府外浦町');
ok($zip->set_number('7520986')->is_valid_number, '山口県下関市長府黒門東町');
ok($zip->set_number('7520987')->is_valid_number, '山口県下関市長府羽衣町');
ok($zip->set_number('7520988')->is_valid_number, '山口県下関市長府羽衣南町');
ok($zip->set_number('7520989')->is_valid_number, '山口県下関市長府黒門南町');
ok($zip->set_number('7520991')->is_valid_number, '山口県下関市高畑');
ok($zip->set_number('7520992')->is_valid_number, '山口県下関市長府野久留米町');
ok($zip->set_number('7520993')->is_valid_number, '山口県下関市長府浜浦町');
ok($zip->set_number('7520994')->is_valid_number, '山口県下関市長府高場町');
ok($zip->set_number('7520995')->is_valid_number, '山口県下関市長府浜浦南町');
ok($zip->set_number('7520996')->is_valid_number, '山口県下関市長府向田町');
ok($zip->set_number('7520997')->is_valid_number, '山口県下関市前田');
ok($zip->set_number('7520998')->is_valid_number, '山口県下関市長府浜浦西町');
ok($zip->set_number('7530000')->is_valid_number, '山口県山口市以下に掲載がない場合');
ok($zip->set_number('7530001')->is_valid_number, '山口県山口市宮野上');
ok($zip->set_number('7530011')->is_valid_number, '山口県山口市宮野下');
ok($zip->set_number('7530012')->is_valid_number, '山口県山口市青葉台');
ok($zip->set_number('7530015')->is_valid_number, '山口県山口市平野');
ok($zip->set_number('7530016')->is_valid_number, '山口県山口市緑ヶ丘');
ok($zip->set_number('7530017')->is_valid_number, '山口県山口市江良');
ok($zip->set_number('7530018')->is_valid_number, '山口県山口市七尾台');
ok($zip->set_number('7530021')->is_valid_number, '山口県山口市桜畠');
ok($zip->set_number('7530022')->is_valid_number, '山口県山口市折本');
ok($zip->set_number('7530023')->is_valid_number, '山口県山口市三の宮');
ok($zip->set_number('7530024')->is_valid_number, '山口県山口市金古曽町');
ok($zip->set_number('7530025')->is_valid_number, '山口県山口市芝崎町');
ok($zip->set_number('7530031')->is_valid_number, '山口県山口市古熊');
ok($zip->set_number('7530032')->is_valid_number, '山口県山口市堂の前町');
ok($zip->set_number('7530033')->is_valid_number, '山口県山口市大市町');
ok($zip->set_number('7530034')->is_valid_number, '山口県山口市下竪小路');
ok($zip->set_number('7530035')->is_valid_number, '山口県山口市上竪小路');
ok($zip->set_number('7530036')->is_valid_number, '山口県山口市円政寺');
ok($zip->set_number('7530036')->is_valid_number, '山口県山口市円政寺町');
ok($zip->set_number('7530037')->is_valid_number, '山口県山口市道祖町');
ok($zip->set_number('7530038')->is_valid_number, '山口県山口市石観音町');
ok($zip->set_number('7530041')->is_valid_number, '山口県山口市東山');
ok($zip->set_number('7530042')->is_valid_number, '山口県山口市惣太夫町');
ok($zip->set_number('7530043')->is_valid_number, '山口県山口市宮島町');
ok($zip->set_number('7530044')->is_valid_number, '山口県山口市鰐石町');
ok($zip->set_number('7530045')->is_valid_number, '山口県山口市黄金町');
ok($zip->set_number('7530046')->is_valid_number, '山口県山口市本町');
ok($zip->set_number('7530047')->is_valid_number, '山口県山口市道場門前');
ok($zip->set_number('7530048')->is_valid_number, '山口県山口市駅通り');
ok($zip->set_number('7530051')->is_valid_number, '山口県山口市旭通り');
ok($zip->set_number('7530052')->is_valid_number, '山口県山口市三和町');
ok($zip->set_number('7530053')->is_valid_number, '山口県山口市松美町');
ok($zip->set_number('7530054')->is_valid_number, '山口県山口市富田原町');
ok($zip->set_number('7530055')->is_valid_number, '山口県山口市今井町');
ok($zip->set_number('7530056')->is_valid_number, '山口県山口市湯田温泉');
ok($zip->set_number('7530057')->is_valid_number, '山口県山口市前町');
ok($zip->set_number('7530058')->is_valid_number, '山口県山口市下市町');
ok($zip->set_number('7530061')->is_valid_number, '山口県山口市朝倉町');
ok($zip->set_number('7530062')->is_valid_number, '山口県山口市荻町');
ok($zip->set_number('7530063')->is_valid_number, '山口県山口市元町');
ok($zip->set_number('7530064')->is_valid_number, '山口県山口市神田町');
ok($zip->set_number('7530065')->is_valid_number, '山口県山口市楠木町');
ok($zip->set_number('7530066')->is_valid_number, '山口県山口市泉町');
ok($zip->set_number('7530067')->is_valid_number, '山口県山口市赤妻町');
ok($zip->set_number('7530068')->is_valid_number, '山口県山口市錦町');
ok($zip->set_number('7530070')->is_valid_number, '山口県山口市白石');
ok($zip->set_number('7530071')->is_valid_number, '山口県山口市滝町');
ok($zip->set_number('7530072')->is_valid_number, '山口県山口市大手町');
ok($zip->set_number('7530073')->is_valid_number, '山口県山口市春日町');
ok($zip->set_number('7530074')->is_valid_number, '山口県山口市中央');
ok($zip->set_number('7530075')->is_valid_number, '山口県山口市中園町');
ok($zip->set_number('7530076')->is_valid_number, '山口県山口市泉都町');
ok($zip->set_number('7530077')->is_valid_number, '山口県山口市熊野町');
ok($zip->set_number('7530078')->is_valid_number, '山口県山口市緑町');
ok($zip->set_number('7530079')->is_valid_number, '山口県山口市糸米');
ok($zip->set_number('7530081')->is_valid_number, '山口県山口市香山町');
ok($zip->set_number('7530082')->is_valid_number, '山口県山口市水の上町');
ok($zip->set_number('7530083')->is_valid_number, '山口県山口市後河原');
ok($zip->set_number('7530084')->is_valid_number, '山口県山口市久保小路');
ok($zip->set_number('7530084')->is_valid_number, '山口県山口市諸願小路');
ok($zip->set_number('7530084')->is_valid_number, '山口県山口市銭湯小路');
ok($zip->set_number('7530085')->is_valid_number, '山口県山口市新馬場');
ok($zip->set_number('7530086')->is_valid_number, '山口県山口市中市町');
ok($zip->set_number('7530087')->is_valid_number, '山口県山口市米屋町');
ok($zip->set_number('7530088')->is_valid_number, '山口県山口市中河原');
ok($zip->set_number('7530088')->is_valid_number, '山口県山口市中河原町');
ok($zip->set_number('7530089')->is_valid_number, '山口県山口市亀山町');
ok($zip->set_number('7530091')->is_valid_number, '山口県山口市上宇野令');
ok($zip->set_number('7530091')->is_valid_number, '山口県山口市天花');
ok($zip->set_number('7530092')->is_valid_number, '山口県山口市八幡馬場');
ok($zip->set_number('7530093')->is_valid_number, '山口県山口市大殿大路');
ok($zip->set_number('7530094')->is_valid_number, '山口県山口市野田');
ok($zip->set_number('7530095')->is_valid_number, '山口県山口市木町');
ok($zip->set_number('7530101')->is_valid_number, '山口県萩市佐々並');
ok($zip->set_number('7530211')->is_valid_number, '山口県山口市大内長野');
ok($zip->set_number('7530212')->is_valid_number, '山口県山口市下小鯖');
ok($zip->set_number('7530213')->is_valid_number, '山口県山口市上小鯖');
ok($zip->set_number('7530214')->is_valid_number, '山口県山口市大内御堀');
ok($zip->set_number('7530215')->is_valid_number, '山口県山口市大内矢田');
ok($zip->set_number('7530221')->is_valid_number, '山口県山口市大内矢田北');
ok($zip->set_number('7530222')->is_valid_number, '山口県山口市大内矢田南');
ok($zip->set_number('7530231')->is_valid_number, '山口県山口市大内氷上');
ok($zip->set_number('7530241')->is_valid_number, '山口県山口市大内問田');
ok($zip->set_number('7530242')->is_valid_number, '山口県山口市大内小京都');
ok($zip->set_number('7530243')->is_valid_number, '山口県山口市大内姫山台');
ok($zip->set_number('7530251')->is_valid_number, '山口県山口市大内千坊');
ok($zip->set_number('7530252')->is_valid_number, '山口県山口市大内中央');
ok($zip->set_number('7530301')->is_valid_number, '山口県山口市仁保上郷');
ok($zip->set_number('7530302')->is_valid_number, '山口県山口市仁保中郷');
ok($zip->set_number('7530303')->is_valid_number, '山口県山口市仁保下郷');
ok($zip->set_number('7530801')->is_valid_number, '山口県山口市中尾');
ok($zip->set_number('7530811')->is_valid_number, '山口県山口市吉敷');
ok($zip->set_number('7530812')->is_valid_number, '山口県山口市宝町');
ok($zip->set_number('7530813')->is_valid_number, '山口県山口市吉敷中東');
ok($zip->set_number('7530814')->is_valid_number, '山口県山口市吉敷下東');
ok($zip->set_number('7530815')->is_valid_number, '山口県山口市維新公園');
ok($zip->set_number('7530816')->is_valid_number, '山口県山口市吉敷佐畑');
ok($zip->set_number('7530817')->is_valid_number, '山口県山口市吉敷赤田');
ok($zip->set_number('7530818')->is_valid_number, '山口県山口市吉敷上東');
ok($zip->set_number('7530821')->is_valid_number, '山口県山口市葵');
ok($zip->set_number('7530822')->is_valid_number, '山口県山口市周布町');
ok($zip->set_number('7530823')->is_valid_number, '山口県山口市若宮町');
ok($zip->set_number('7530824')->is_valid_number, '山口県山口市穂積町');
ok($zip->set_number('7530825')->is_valid_number, '山口県山口市矢原町');
ok($zip->set_number('7530826')->is_valid_number, '山口県山口市幸町');
ok($zip->set_number('7530831')->is_valid_number, '山口県山口市平井');
ok($zip->set_number('7530841')->is_valid_number, '山口県山口市吉田');
ok($zip->set_number('7530851')->is_valid_number, '山口県山口市黒川');
ok($zip->set_number('7530861')->is_valid_number, '山口県山口市矢原');
ok($zip->set_number('7530871')->is_valid_number, '山口県山口市朝田');
ok($zip->set_number('7530872')->is_valid_number, '山口県山口市朝田流通センター');
ok($zip->set_number('7530872')->is_valid_number, '山口県山口市小郡上郷流通センター');
ok($zip->set_number('7530872')->is_valid_number, '山口県山口市山口県流通センター');
ok($zip->set_number('7530891')->is_valid_number, '山口県山口市上天花町');
ok($zip->set_number('7540001')->is_valid_number, '山口県山口市小郡上郷');
ok($zip->set_number('7540002')->is_valid_number, '山口県山口市小郡下郷');
ok($zip->set_number('7540003')->is_valid_number, '山口県山口市小郡真名');
ok($zip->set_number('7540004')->is_valid_number, '山口県山口市小郡金堀町');
ok($zip->set_number('7540005')->is_valid_number, '山口県山口市小郡山手上町');
ok($zip->set_number('7540006')->is_valid_number, '山口県山口市小郡尾崎町');
ok($zip->set_number('7540007')->is_valid_number, '山口県山口市小郡円座東町');
ok($zip->set_number('7540008')->is_valid_number, '山口県山口市小郡円座西町');
ok($zip->set_number('7540011')->is_valid_number, '山口県山口市小郡御幸町');
ok($zip->set_number('7540012')->is_valid_number, '山口県山口市小郡船倉町');
ok($zip->set_number('7540013')->is_valid_number, '山口県山口市小郡緑町');
ok($zip->set_number('7540014')->is_valid_number, '山口県山口市小郡高砂町');
ok($zip->set_number('7540015')->is_valid_number, '山口県山口市小郡大江町');
ok($zip->set_number('7540020')->is_valid_number, '山口県山口市小郡平成町');
ok($zip->set_number('7540021')->is_valid_number, '山口県山口市小郡黄金町');
ok($zip->set_number('7540022')->is_valid_number, '山口県山口市小郡花園町');
ok($zip->set_number('7540023')->is_valid_number, '山口県山口市小郡前田町');
ok($zip->set_number('7540024')->is_valid_number, '山口県山口市小郡若草町');
ok($zip->set_number('7540025')->is_valid_number, '山口県山口市小郡平砂町');
ok($zip->set_number('7540026')->is_valid_number, '山口県山口市小郡栄町');
ok($zip->set_number('7540027')->is_valid_number, '山口県山口市小郡三軒屋町');
ok($zip->set_number('7540028')->is_valid_number, '山口県山口市小郡給領町');
ok($zip->set_number('7540029')->is_valid_number, '山口県山口市小郡維新町');
ok($zip->set_number('7540031')->is_valid_number, '山口県山口市小郡新町');
ok($zip->set_number('7540032')->is_valid_number, '山口県山口市小郡みらい町');
ok($zip->set_number('7540033')->is_valid_number, '山口県山口市小郡光が丘');
ok($zip->set_number('7540034')->is_valid_number, '山口県山口市小郡かぜの丘');
ok($zip->set_number('7540041')->is_valid_number, '山口県山口市小郡令和');
ok($zip->set_number('7540042')->is_valid_number, '山口県山口市小郡長谷');
ok($zip->set_number('7540043')->is_valid_number, '山口県山口市小郡明治');
ok($zip->set_number('7540044')->is_valid_number, '山口県山口市小郡大正町');
ok($zip->set_number('7540121')->is_valid_number, '山口県美祢市美東町長田');
ok($zip->set_number('7540122')->is_valid_number, '山口県美祢市美東町真名');
ok($zip->set_number('7540123')->is_valid_number, '山口県美祢市美東町小野');
ok($zip->set_number('7540211')->is_valid_number, '山口県美祢市美東町大田');
ok($zip->set_number('7540212')->is_valid_number, '山口県美祢市美東町綾木');
ok($zip->set_number('7540213')->is_valid_number, '山口県美祢市美東町長登');
ok($zip->set_number('7540214')->is_valid_number, '山口県美祢市美東町(その他)');
ok($zip->set_number('7540301')->is_valid_number, '山口県美祢市美東町絵堂');
ok($zip->set_number('7540302')->is_valid_number, '山口県美祢市美東町赤');
ok($zip->set_number('7540411')->is_valid_number, '山口県萩市明木');
ok($zip->set_number('7540511')->is_valid_number, '山口県美祢市秋芳町秋吉');
ok($zip->set_number('7540512')->is_valid_number, '山口県美祢市秋芳町岩永本郷');
ok($zip->set_number('7540513')->is_valid_number, '山口県美祢市秋芳町岩永下郷');
ok($zip->set_number('7540514')->is_valid_number, '山口県美祢市秋芳町(その他)');
ok($zip->set_number('7540601')->is_valid_number, '山口県美祢市秋芳町嘉万');
ok($zip->set_number('7540602')->is_valid_number, '山口県美祢市秋芳町青景');
ok($zip->set_number('7540603')->is_valid_number, '山口県美祢市秋芳町別府');
ok($zip->set_number('7540891')->is_valid_number, '山口県山口市陶');
ok($zip->set_number('7540892')->is_valid_number, '山口県山口市名田島');
ok($zip->set_number('7540893')->is_valid_number, '山口県山口市秋穂二島');
ok($zip->set_number('7540894')->is_valid_number, '山口県山口市佐山');
ok($zip->set_number('7540895')->is_valid_number, '山口県山口市深溝');
ok($zip->set_number('7540896')->is_valid_number, '山口県山口市江崎');
ok($zip->set_number('7540897')->is_valid_number, '山口県山口市嘉川');
ok($zip->set_number('7541101')->is_valid_number, '山口県山口市秋穂東');
ok($zip->set_number('7541102')->is_valid_number, '山口県山口市秋穂西');
ok($zip->set_number('7541277')->is_valid_number, '山口県山口市阿知須');
ok($zip->set_number('7541311')->is_valid_number, '山口県宇部市小野');
ok($zip->set_number('7541312')->is_valid_number, '山口県宇部市棯小野');
ok($zip->set_number('7541313')->is_valid_number, '山口県宇部市藤河内');
ok($zip->set_number('7541314')->is_valid_number, '山口県宇部市櫟原');
ok($zip->set_number('7541315')->is_valid_number, '山口県宇部市如意寺');
ok($zip->set_number('7550000')->is_valid_number, '山口県宇部市以下に掲載がない場合');
ok($zip->set_number('7550001')->is_valid_number, '山口県宇部市沖宇部');
ok($zip->set_number('7550002')->is_valid_number, '山口県宇部市亀浦');
ok($zip->set_number('7550003')->is_valid_number, '山口県宇部市則貞');
ok($zip->set_number('7550004')->is_valid_number, '山口県宇部市草江');
ok($zip->set_number('7550005')->is_valid_number, '山口県宇部市五十目山町');
ok($zip->set_number('7550006')->is_valid_number, '山口県宇部市岬町');
ok($zip->set_number('7550007')->is_valid_number, '山口県宇部市八王子町');
ok($zip->set_number('7550008')->is_valid_number, '山口県宇部市明神町');
ok($zip->set_number('7550009')->is_valid_number, '山口県宇部市東見初町');
ok($zip->set_number('7550011')->is_valid_number, '山口県宇部市昭和町');
ok($zip->set_number('7550012')->is_valid_number, '山口県宇部市幸町');
ok($zip->set_number('7550013')->is_valid_number, '山口県宇部市明治町');
ok($zip->set_number('7550014')->is_valid_number, '山口県宇部市末広町');
ok($zip->set_number('7550015')->is_valid_number, '山口県宇部市笹山町');
ok($zip->set_number('7550016')->is_valid_number, '山口県宇部市東芝中町');
ok($zip->set_number('7550017')->is_valid_number, '山口県宇部市芝中町');
ok($zip->set_number('7550018')->is_valid_number, '山口県宇部市錦町');
ok($zip->set_number('7550019')->is_valid_number, '山口県宇部市東新川町');
ok($zip->set_number('7550021')->is_valid_number, '山口県宇部市常藤町');
ok($zip->set_number('7550022')->is_valid_number, '山口県宇部市神原町');
ok($zip->set_number('7550023')->is_valid_number, '山口県宇部市恩田町');
ok($zip->set_number('7550024')->is_valid_number, '山口県宇部市野原');
ok($zip->set_number('7550025')->is_valid_number, '山口県宇部市野中');
ok($zip->set_number('7550026')->is_valid_number, '山口県宇部市松山町');
ok($zip->set_number('7550027')->is_valid_number, '山口県宇部市港町');
ok($zip->set_number('7550028')->is_valid_number, '山口県宇部市東本町');
ok($zip->set_number('7550029')->is_valid_number, '山口県宇部市新天町');
ok($zip->set_number('7550031')->is_valid_number, '山口県宇部市常盤町');
ok($zip->set_number('7550032')->is_valid_number, '山口県宇部市寿町');
ok($zip->set_number('7550033')->is_valid_number, '山口県宇部市琴芝町');
ok($zip->set_number('7550034')->is_valid_number, '山口県宇部市東琴芝');
ok($zip->set_number('7550035')->is_valid_number, '山口県宇部市西琴芝');
ok($zip->set_number('7550036')->is_valid_number, '山口県宇部市北琴芝');
ok($zip->set_number('7550037')->is_valid_number, '山口県宇部市西梶返');
ok($zip->set_number('7550038')->is_valid_number, '山口県宇部市海南町');
ok($zip->set_number('7550039')->is_valid_number, '山口県宇部市東梶返');
ok($zip->set_number('7550041')->is_valid_number, '山口県宇部市朝日町');
ok($zip->set_number('7550042')->is_valid_number, '山口県宇部市松島町');
ok($zip->set_number('7550043')->is_valid_number, '山口県宇部市相生町');
ok($zip->set_number('7550044')->is_valid_number, '山口県宇部市新町');
ok($zip->set_number('7550045')->is_valid_number, '山口県宇部市中央町');
ok($zip->set_number('7550046')->is_valid_number, '山口県宇部市南小串');
ok($zip->set_number('7550047')->is_valid_number, '山口県宇部市島');
ok($zip->set_number('7550048')->is_valid_number, '山口県宇部市下条');
ok($zip->set_number('7550049')->is_valid_number, '山口県宇部市西小串');
ok($zip->set_number('7550051')->is_valid_number, '山口県宇部市上町');
ok($zip->set_number('7550052')->is_valid_number, '山口県宇部市西本町');
ok($zip->set_number('7550053')->is_valid_number, '山口県宇部市西中町');
ok($zip->set_number('7550054')->is_valid_number, '山口県宇部市助田町');
ok($zip->set_number('7550055')->is_valid_number, '山口県宇部市居能町');
ok($zip->set_number('7550056')->is_valid_number, '山口県宇部市文京町');
ok($zip->set_number('7550057')->is_valid_number, '山口県宇部市藤曲');
ok($zip->set_number('7550058')->is_valid_number, '山口県宇部市中山');
ok($zip->set_number('7550061')->is_valid_number, '山口県宇部市若松町');
ok($zip->set_number('7550062')->is_valid_number, '山口県宇部市鵜の島町');
ok($zip->set_number('7550063')->is_valid_number, '山口県宇部市南浜町');
ok($zip->set_number('7550064')->is_valid_number, '山口県宇部市鍋倉町');
ok($zip->set_number('7550065')->is_valid_number, '山口県宇部市浜町');
ok($zip->set_number('7550066')->is_valid_number, '山口県宇部市小松原町');
ok($zip->set_number('7550067')->is_valid_number, '山口県宇部市小串');
ok($zip->set_number('7550068')->is_valid_number, '山口県宇部市東小串');
ok($zip->set_number('7550069')->is_valid_number, '山口県宇部市西桃山');
ok($zip->set_number('7550071')->is_valid_number, '山口県宇部市宮地町');
ok($zip->set_number('7550072')->is_valid_number, '山口県宇部市中村');
ok($zip->set_number('7550073')->is_valid_number, '山口県宇部市中尾');
ok($zip->set_number('7550074')->is_valid_number, '山口県宇部市川添');
ok($zip->set_number('7550075')->is_valid_number, '山口県宇部市琴崎町');
ok($zip->set_number('7550076')->is_valid_number, '山口県宇部市大小路');
ok($zip->set_number('7550077')->is_valid_number, '山口県宇部市山門');
ok($zip->set_number('7550078')->is_valid_number, '山口県宇部市寺の前町');
ok($zip->set_number('7550081')->is_valid_number, '山口県宇部市北小羽山町');
ok($zip->set_number('7550082')->is_valid_number, '山口県宇部市東小羽山町');
ok($zip->set_number('7550083')->is_valid_number, '山口県宇部市南小羽山町');
ok($zip->set_number('7550084')->is_valid_number, '山口県宇部市川上');
ok($zip->set_number('7550085')->is_valid_number, '山口県宇部市沼');
ok($zip->set_number('7550086')->is_valid_number, '山口県宇部市中宇部');
ok($zip->set_number('7550091')->is_valid_number, '山口県宇部市上宇部');
ok($zip->set_number('7550092')->is_valid_number, '山口県宇部市上野中町');
ok($zip->set_number('7550093')->is_valid_number, '山口県宇部市北迫新町');
ok($zip->set_number('7550094')->is_valid_number, '山口県宇部市ひらき台');
ok($zip->set_number('7550095')->is_valid_number, '山口県宇部市風呂ケ迫町');
ok($zip->set_number('7550096')->is_valid_number, '山口県宇部市開');
ok($zip->set_number('7550097')->is_valid_number, '山口県宇部市常盤台');
ok($zip->set_number('7550151')->is_valid_number, '山口県宇部市西岐波');
ok($zip->set_number('7550152')->is_valid_number, '山口県宇部市あすとぴあ');
ok($zip->set_number('7550153')->is_valid_number, '山口県宇部市床波');
ok($zip->set_number('7550154')->is_valid_number, '山口県宇部市今村南');
ok($zip->set_number('7550155')->is_valid_number, '山口県宇部市今村北');
ok($zip->set_number('7550241')->is_valid_number, '山口県宇部市東岐波');
ok($zip->set_number('7550801')->is_valid_number, '山口県宇部市上条');
ok($zip->set_number('7550802')->is_valid_number, '山口県宇部市北条');
ok($zip->set_number('7550803')->is_valid_number, '山口県宇部市東藤曲');
ok($zip->set_number('7550804')->is_valid_number, '山口県宇部市南中山町');
ok($zip->set_number('7550805')->is_valid_number, '山口県宇部市文京台');
ok($zip->set_number('7550806')->is_valid_number, '山口県宇部市浜田');
ok($zip->set_number('7550807')->is_valid_number, '山口県宇部市東平原');
ok($zip->set_number('7550808')->is_valid_number, '山口県宇部市西平原');
ok($zip->set_number('7550809')->is_valid_number, '山口県宇部市松崎町');
ok($zip->set_number('7550810')->is_valid_number, '山口県宇部市岩鼻町');
ok($zip->set_number('7560000')->is_valid_number, '山口県山陽小野田市以下に掲載がない場合');
ok($zip->set_number('7560001')->is_valid_number, '山口県山陽小野田市大休');
ok($zip->set_number('7560003')->is_valid_number, '山口県山陽小野田市有帆新町');
ok($zip->set_number('7560004')->is_valid_number, '山口県山陽小野田市中里');
ok($zip->set_number('7560005')->is_valid_number, '山口県山陽小野田市中村');
ok($zip->set_number('7560007')->is_valid_number, '山口県山陽小野田市北真土郷');
ok($zip->set_number('7560008')->is_valid_number, '山口県山陽小野田市大休団地');
ok($zip->set_number('7560009')->is_valid_number, '山口県山陽小野田市有帆上町');
ok($zip->set_number('7560010')->is_valid_number, '山口県山陽小野田市新有帆町');
ok($zip->set_number('7560011')->is_valid_number, '山口県山陽小野田市共和台');
ok($zip->set_number('7560012')->is_valid_number, '山口県山陽小野田市角石');
ok($zip->set_number('7560013')->is_valid_number, '山口県山陽小野田市片山');
ok($zip->set_number('7560014')->is_valid_number, '山口県山陽小野田市彼岸田');
ok($zip->set_number('7560015')->is_valid_number, '山口県山陽小野田市ひがんだ団地');
ok($zip->set_number('7560016')->is_valid_number, '山口県山陽小野田市南平台');
ok($zip->set_number('7560017')->is_valid_number, '山口県山陽小野田市仁保の上');
ok($zip->set_number('7560018')->is_valid_number, '山口県山陽小野田市東町');
ok($zip->set_number('7560019')->is_valid_number, '山口県山陽小野田市南真土郷');
ok($zip->set_number('7560021')->is_valid_number, '山口県山陽小野田市高畑');
ok($zip->set_number('7560022')->is_valid_number, '山口県山陽小野田市千崎西');
ok($zip->set_number('7560023')->is_valid_number, '山口県山陽小野田市千崎東');
ok($zip->set_number('7560024')->is_valid_number, '山口県山陽小野田市萩森');
ok($zip->set_number('7560025')->is_valid_number, '山口県山陽小野田市烏帽子岩');
ok($zip->set_number('7560026')->is_valid_number, '山口県山陽小野田市烏帽子岩団地');
ok($zip->set_number('7560027')->is_valid_number, '山口県山陽小野田市烏帽子岩前');
ok($zip->set_number('7560028')->is_valid_number, '山口県山陽小野田市共和町');
ok($zip->set_number('7560029')->is_valid_number, '山口県山陽小野田市船越');
ok($zip->set_number('7560030')->is_valid_number, '山口県山陽小野田市青葉台');
ok($zip->set_number('7560031')->is_valid_number, '山口県山陽小野田市平和町');
ok($zip->set_number('7560032')->is_valid_number, '山口県山陽小野田市平生町');
ok($zip->set_number('7560033')->is_valid_number, '山口県山陽小野田市若草町');
ok($zip->set_number('7560034')->is_valid_number, '山口県山陽小野田市緑が丘');
ok($zip->set_number('7560035')->is_valid_number, '山口県山陽小野田市平原');
ok($zip->set_number('7560036')->is_valid_number, '山口県山陽小野田市大塚団地');
ok($zip->set_number('7560037')->is_valid_number, '山口県山陽小野田市小松尾');
ok($zip->set_number('7560038')->is_valid_number, '山口県山陽小野田市有帆');
ok($zip->set_number('7560039')->is_valid_number, '山口県山陽小野田市千崎');
ok($zip->set_number('7560041')->is_valid_number, '山口県山陽小野田市上の郷');
ok($zip->set_number('7560042')->is_valid_number, '山口県山陽小野田市大塚');
ok($zip->set_number('7560043')->is_valid_number, '山口県山陽小野田市浜');
ok($zip->set_number('7560044')->is_valid_number, '山口県山陽小野田市郷');
ok($zip->set_number('7560045')->is_valid_number, '山口県山陽小野田市南高泊');
ok($zip->set_number('7560046')->is_valid_number, '山口県山陽小野田市西の郷');
ok($zip->set_number('7560047')->is_valid_number, '山口県山陽小野田市高浜');
ok($zip->set_number('7560048')->is_valid_number, '山口県山陽小野田市後潟下');
ok($zip->set_number('7560049')->is_valid_number, '山口県山陽小野田市後潟上');
ok($zip->set_number('7560051')->is_valid_number, '山口県山陽小野田市杵築');
ok($zip->set_number('7560052')->is_valid_number, '山口県山陽小野田市浜田町');
ok($zip->set_number('7560053')->is_valid_number, '山口県山陽小野田市下木屋');
ok($zip->set_number('7560054')->is_valid_number, '山口県山陽小野田市旦東');
ok($zip->set_number('7560055')->is_valid_number, '山口県山陽小野田市旦西');
ok($zip->set_number('7560056')->is_valid_number, '山口県山陽小野田市上木屋');
ok($zip->set_number('7560057')->is_valid_number, '山口県山陽小野田市西高泊');
ok($zip->set_number('7560060')->is_valid_number, '山口県山陽小野田市高千帆');
ok($zip->set_number('7560063')->is_valid_number, '山口県山陽小野田市石井手');
ok($zip->set_number('7560067')->is_valid_number, '山口県山陽小野田市柿の木坂');
ok($zip->set_number('7560071')->is_valid_number, '山口県山陽小野田市目出文化町');
ok($zip->set_number('7560072')->is_valid_number, '山口県山陽小野田市目出緑町');
ok($zip->set_number('7560073')->is_valid_number, '山口県山陽小野田市目出幸町');
ok($zip->set_number('7560074')->is_valid_number, '山口県山陽小野田市目出湖畔町');
ok($zip->set_number('7560075')->is_valid_number, '山口県山陽小野田市亀の甲');
ok($zip->set_number('7560076')->is_valid_number, '山口県山陽小野田市目出');
ok($zip->set_number('7560077')->is_valid_number, '山口県山陽小野田市目出新町');
ok($zip->set_number('7560080')->is_valid_number, '山口県山陽小野田市くし山');
ok($zip->set_number('7560086')->is_valid_number, '山口県山陽小野田市神帆町');
ok($zip->set_number('7560087')->is_valid_number, '山口県山陽小野田市高須');
ok($zip->set_number('7560088')->is_valid_number, '山口県山陽小野田市東高泊');
ok($zip->set_number('7560091')->is_valid_number, '山口県山陽小野田市日の出');
ok($zip->set_number('7560092')->is_valid_number, '山口県山陽小野田市新生');
ok($zip->set_number('7560093')->is_valid_number, '山口県山陽小野田市日産');
ok($zip->set_number('7560094')->is_valid_number, '山口県山陽小野田市市立病院');
ok($zip->set_number('7560095')->is_valid_number, '山口県山陽小野田市労災病院');
ok($zip->set_number('7560801')->is_valid_number, '山口県山陽小野田市北栄町');
ok($zip->set_number('7560802')->is_valid_number, '山口県山陽小野田市栄町');
ok($zip->set_number('7560803')->is_valid_number, '山口県山陽小野田市南中川町');
ok($zip->set_number('7560804')->is_valid_number, '山口県山陽小野田市長寿園');
ok($zip->set_number('7560805')->is_valid_number, '山口県山陽小野田市自由ヶ丘');
ok($zip->set_number('7560806')->is_valid_number, '山口県山陽小野田市中川');
ok($zip->set_number('7560807')->is_valid_number, '山口県山陽小野田市硫酸町');
ok($zip->set_number('7560808')->is_valid_number, '山口県山陽小野田市旭町');
ok($zip->set_number('7560809')->is_valid_number, '山口県山陽小野田市横土手');
ok($zip->set_number('7560811')->is_valid_number, '山口県山陽小野田市稲荷町');
ok($zip->set_number('7560812')->is_valid_number, '山口県山陽小野田市小野山');
ok($zip->set_number('7560813')->is_valid_number, '山口県山陽小野田市住吉本町');
ok($zip->set_number('7560814')->is_valid_number, '山口県山陽小野田市千代町');
ok($zip->set_number('7560815')->is_valid_number, '山口県山陽小野田市高栄');
ok($zip->set_number('7560816')->is_valid_number, '山口県山陽小野田市西住吉町');
ok($zip->set_number('7560817')->is_valid_number, '山口県山陽小野田市小野田');
ok($zip->set_number('7560821')->is_valid_number, '山口県山陽小野田市丸河内');
ok($zip->set_number('7560822')->is_valid_number, '山口県山陽小野田市北若山');
ok($zip->set_number('7560823')->is_valid_number, '山口県山陽小野田市心和園');
ok($zip->set_number('7560824')->is_valid_number, '山口県山陽小野田市中央');
ok($zip->set_number('7560825')->is_valid_number, '山口県山陽小野田市東住吉町');
ok($zip->set_number('7560831')->is_valid_number, '山口県山陽小野田市南若山');
ok($zip->set_number('7560832')->is_valid_number, '山口県山陽小野田市南竜王町');
ok($zip->set_number('7560833')->is_valid_number, '山口県山陽小野田市北竜王町');
ok($zip->set_number('7560834')->is_valid_number, '山口県山陽小野田市港町');
ok($zip->set_number('7560835')->is_valid_number, '山口県山陽小野田市セメント町');
ok($zip->set_number('7560836')->is_valid_number, '山口県山陽小野田市須恵');
ok($zip->set_number('7560837')->is_valid_number, '山口県山陽小野田市平成町');
ok($zip->set_number('7560841')->is_valid_number, '山口県山陽小野田市赤崎');
ok($zip->set_number('7560842')->is_valid_number, '山口県山陽小野田市刈屋中村');
ok($zip->set_number('7560843')->is_valid_number, '山口県山陽小野田市刈屋上条');
ok($zip->set_number('7560844')->is_valid_number, '山口県山陽小野田市木戸大鼻');
ok($zip->set_number('7560845')->is_valid_number, '山口県山陽小野田市木戸中ノ町');
ok($zip->set_number('7560846')->is_valid_number, '山口県山陽小野田市木戸新町');
ok($zip->set_number('7560847')->is_valid_number, '山口県山陽小野田市新沖');
ok($zip->set_number('7560848')->is_valid_number, '山口県山陽小野田市刈屋西条');
ok($zip->set_number('7560851')->is_valid_number, '山口県山陽小野田市桜が丘');
ok($zip->set_number('7560852')->is_valid_number, '山口県山陽小野田市奥若山');
ok($zip->set_number('7560853')->is_valid_number, '山口県山陽小野田市野来見');
ok($zip->set_number('7560854')->is_valid_number, '山口県山陽小野田市叶松');
ok($zip->set_number('7560855')->is_valid_number, '山口県山陽小野田市えびす町');
ok($zip->set_number('7560856')->is_valid_number, '山口県山陽小野田市古開作');
ok($zip->set_number('7560857')->is_valid_number, '山口県山陽小野田市古開作団地');
ok($zip->set_number('7560861')->is_valid_number, '山口県山陽小野田市波瀬');
ok($zip->set_number('7560862')->is_valid_number, '山口県山陽小野田市須恵西');
ok($zip->set_number('7560863')->is_valid_number, '山口県山陽小野田市上の台');
ok($zip->set_number('7560864')->is_valid_number, '山口県山陽小野田市西が迫');
ok($zip->set_number('7560865')->is_valid_number, '山口県山陽小野田市田の尻');
ok($zip->set_number('7560866')->is_valid_number, '山口県山陽小野田市大浜');
ok($zip->set_number('7560871')->is_valid_number, '山口県山陽小野田市あさひが丘');
ok($zip->set_number('7560872')->is_valid_number, '山口県山陽小野田市浜河内');
ok($zip->set_number('7560873')->is_valid_number, '山口県山陽小野田市大須恵');
ok($zip->set_number('7560874')->is_valid_number, '山口県山陽小野田市本山町');
ok($zip->set_number('7560875')->is_valid_number, '山口県山陽小野田市南松浜');
ok($zip->set_number('7560876')->is_valid_number, '山口県山陽小野田市本山団地');
ok($zip->set_number('7560877')->is_valid_number, '山口県山陽小野田市松浜');
ok($zip->set_number('7560878')->is_valid_number, '山口県山陽小野田市松浜団地');
ok($zip->set_number('7560881')->is_valid_number, '山口県山陽小野田市笹尾東');
ok($zip->set_number('7560882')->is_valid_number, '山口県山陽小野田市須田ノ木');
ok($zip->set_number('7560883')->is_valid_number, '山口県山陽小野田市東須田の木');
ok($zip->set_number('7560884')->is_valid_number, '山口県山陽小野田市大学通');
ok($zip->set_number('7560885')->is_valid_number, '山口県山陽小野田市西沖');
ok($zip->set_number('7560886')->is_valid_number, '山口県山陽小野田市夏目');
ok($zip->set_number('7560887')->is_valid_number, '山口県山陽小野田市松角');
ok($zip->set_number('7560888')->is_valid_number, '山口県山陽小野田市笹尾西');
ok($zip->set_number('7560889')->is_valid_number, '山口県山陽小野田市須恵東');
ok($zip->set_number('7570001')->is_valid_number, '山口県山陽小野田市厚狭');
ok($zip->set_number('7570002')->is_valid_number, '山口県山陽小野田市郡');
ok($zip->set_number('7570003')->is_valid_number, '山口県山陽小野田市山野井');
ok($zip->set_number('7570004')->is_valid_number, '山口県山陽小野田市山川');
ok($zip->set_number('7570005')->is_valid_number, '山口県山陽小野田市鴨庄');
ok($zip->set_number('7570006')->is_valid_number, '山口県山陽小野田市桜');
ok($zip->set_number('7570011')->is_valid_number, '山口県山陽小野田市津布田');
ok($zip->set_number('7570012')->is_valid_number, '山口県山陽小野田市埴生');
ok($zip->set_number('7570013')->is_valid_number, '山口県山陽小野田市福田');
ok($zip->set_number('7570211')->is_valid_number, '山口県宇部市芦河内');
ok($zip->set_number('7570212')->is_valid_number, '山口県宇部市今富');
ok($zip->set_number('7570213')->is_valid_number, '山口県宇部市奥万倉');
ok($zip->set_number('7570214')->is_valid_number, '山口県宇部市西万倉');
ok($zip->set_number('7570215')->is_valid_number, '山口県宇部市東万倉');
ok($zip->set_number('7570216')->is_valid_number, '山口県宇部市船木');
ok($zip->set_number('7570217')->is_valid_number, '山口県宇部市矢矯');
ok($zip->set_number('7570401')->is_valid_number, '山口県宇部市東吉部');
ok($zip->set_number('7570402')->is_valid_number, '山口県宇部市西吉部');
ok($zip->set_number('7580000')->is_valid_number, '山口県萩市以下に掲載がない場合');
ok($zip->set_number('7580001')->is_valid_number, '山口県萩市相島');
ok($zip->set_number('7580002')->is_valid_number, '山口県萩市櫃島');
ok($zip->set_number('7580003')->is_valid_number, '山口県萩市大島');
ok($zip->set_number('7580004')->is_valid_number, '山口県萩市肥島');
ok($zip->set_number('7580011')->is_valid_number, '山口県萩市椿東');
ok($zip->set_number('7580021')->is_valid_number, '山口県萩市今古萩町');
ok($zip->set_number('7580022')->is_valid_number, '山口県萩市浜崎町');
ok($zip->set_number('7580023')->is_valid_number, '山口県萩市浜崎新町');
ok($zip->set_number('7580024')->is_valid_number, '山口県萩市東浜崎町');
ok($zip->set_number('7580025')->is_valid_number, '山口県萩市土原');
ok($zip->set_number('7580026')->is_valid_number, '山口県萩市古萩町');
ok($zip->set_number('7580027')->is_valid_number, '山口県萩市吉田町');
ok($zip->set_number('7580031')->is_valid_number, '山口県萩市川島');
ok($zip->set_number('7580032')->is_valid_number, '山口県萩市北古萩町');
ok($zip->set_number('7580033')->is_valid_number, '山口県萩市恵美須町');
ok($zip->set_number('7580034')->is_valid_number, '山口県萩市熊谷町');
ok($zip->set_number('7580035')->is_valid_number, '山口県萩市細工町');
ok($zip->set_number('7580036')->is_valid_number, '山口県萩市塩屋町');
ok($zip->set_number('7580037')->is_valid_number, '山口県萩市津守町');
ok($zip->set_number('7580041')->is_valid_number, '山口県萩市江向');
ok($zip->set_number('7580042')->is_valid_number, '山口県萩市御許町');
ok($zip->set_number('7580043')->is_valid_number, '山口県萩市上五間町');
ok($zip->set_number('7580043')->is_valid_number, '山口県萩市下五間町');
ok($zip->set_number('7580044')->is_valid_number, '山口県萩市唐樋町');
ok($zip->set_number('7580045')->is_valid_number, '山口県萩市米屋町');
ok($zip->set_number('7580046')->is_valid_number, '山口県萩市西田町');
ok($zip->set_number('7580047')->is_valid_number, '山口県萩市東田町');
ok($zip->set_number('7580051')->is_valid_number, '山口県萩市油屋町');
ok($zip->set_number('7580052')->is_valid_number, '山口県萩市今魚店町');
ok($zip->set_number('7580053')->is_valid_number, '山口県萩市北片河町');
ok($zip->set_number('7580054')->is_valid_number, '山口県萩市樽屋町');
ok($zip->set_number('7580055')->is_valid_number, '山口県萩市春若町');
ok($zip->set_number('7580056')->is_valid_number, '山口県萩市古魚店町');
ok($zip->set_number('7580057')->is_valid_number, '山口県萩市堀内');
ok($zip->set_number('7580061')->is_valid_number, '山口県萩市椿');
ok($zip->set_number('7580062')->is_valid_number, '山口県萩市橋本町');
ok($zip->set_number('7580063')->is_valid_number, '山口県萩市山田');
ok($zip->set_number('7580071')->is_valid_number, '山口県萩市瓦町');
ok($zip->set_number('7580072')->is_valid_number, '山口県萩市呉服町');
ok($zip->set_number('7580073')->is_valid_number, '山口県萩市河添');
ok($zip->set_number('7580074')->is_valid_number, '山口県萩市平安古町');
ok($zip->set_number('7580076')->is_valid_number, '山口県萩市南片河町');
ok($zip->set_number('7580077')->is_valid_number, '山口県萩市南古萩町');
ok($zip->set_number('7580141')->is_valid_number, '山口県萩市川上');
ok($zip->set_number('7580211')->is_valid_number, '山口県萩市福井上');
ok($zip->set_number('7580212')->is_valid_number, '山口県萩市福井下');
ok($zip->set_number('7580213')->is_valid_number, '山口県萩市黒川');
ok($zip->set_number('7580301')->is_valid_number, '山口県萩市片俣');
ok($zip->set_number('7580302')->is_valid_number, '山口県萩市高佐上');
ok($zip->set_number('7580303')->is_valid_number, '山口県萩市高佐下');
ok($zip->set_number('7580304')->is_valid_number, '山口県萩市吉部上');
ok($zip->set_number('7580305')->is_valid_number, '山口県萩市吉部下');
ok($zip->set_number('7580501')->is_valid_number, '山口県萩市紫福');
ok($zip->set_number('7580611')->is_valid_number, '山口県阿武郡阿武町福田下');
ok($zip->set_number('7580612')->is_valid_number, '山口県阿武郡阿武町福田上');
ok($zip->set_number('7580613')->is_valid_number, '山口県阿武郡阿武町宇生賀');
ok($zip->set_number('7580701')->is_valid_number, '山口県萩市見島');
ok($zip->set_number('7590121')->is_valid_number, '山口県宇部市棚井');
ok($zip->set_number('7590122')->is_valid_number, '山口県宇部市吉見');
ok($zip->set_number('7590123')->is_valid_number, '山口県宇部市末信');
ok($zip->set_number('7590124')->is_valid_number, '山口県宇部市広瀬');
ok($zip->set_number('7590131')->is_valid_number, '山口県宇部市荒瀬');
ok($zip->set_number('7590132')->is_valid_number, '山口県宇部市山中');
ok($zip->set_number('7590133')->is_valid_number, '山口県宇部市車地');
ok($zip->set_number('7590134')->is_valid_number, '山口県宇部市善和');
ok($zip->set_number('7590135')->is_valid_number, '山口県宇部市瓜生野');
ok($zip->set_number('7590136')->is_valid_number, '山口県宇部市木田');
ok($zip->set_number('7590201')->is_valid_number, '山口県宇部市山の手町');
ok($zip->set_number('7590202')->is_valid_number, '山口県宇部市沖ノ旦');
ok($zip->set_number('7590203')->is_valid_number, '山口県宇部市中野開作');
ok($zip->set_number('7590204')->is_valid_number, '山口県宇部市妻崎開作');
ok($zip->set_number('7590205')->is_valid_number, '山口県宇部市西沖の山');
ok($zip->set_number('7590206')->is_valid_number, '山口県宇部市東須恵');
ok($zip->set_number('7590207')->is_valid_number, '山口県宇部市際波');
ok($zip->set_number('7590208')->is_valid_number, '山口県宇部市西宇部南');
ok($zip->set_number('7590209')->is_valid_number, '山口県宇部市厚南北');
ok($zip->set_number('7590211')->is_valid_number, '山口県宇部市西宇部北');
ok($zip->set_number('7590212')->is_valid_number, '山口県宇部市厚南中央');
ok($zip->set_number('7590213')->is_valid_number, '山口県宇部市黒石北');
ok($zip->set_number('7591231')->is_valid_number, '山口県山口市阿東生雲東分');
ok($zip->set_number('7591232')->is_valid_number, '山口県山口市阿東篠目');
ok($zip->set_number('7591341')->is_valid_number, '山口県山口市阿東生雲西分');
ok($zip->set_number('7591342')->is_valid_number, '山口県山口市阿東生雲中');
ok($zip->set_number('7591343')->is_valid_number, '山口県山口市阿東蔵目喜');
ok($zip->set_number('7591421')->is_valid_number, '山口県山口市阿東地福上');
ok($zip->set_number('7591422')->is_valid_number, '山口県山口市阿東地福下');
ok($zip->set_number('7591511')->is_valid_number, '山口県山口市阿東徳佐上');
ok($zip->set_number('7591512')->is_valid_number, '山口県山口市阿東徳佐中');
ok($zip->set_number('7591513')->is_valid_number, '山口県山口市阿東徳佐下');
ok($zip->set_number('7591601')->is_valid_number, '山口県山口市阿東嘉年上');
ok($zip->set_number('7591602')->is_valid_number, '山口県山口市阿東嘉年下');
ok($zip->set_number('7592131')->is_valid_number, '山口県美祢市伊佐町堀越');
ok($zip->set_number('7592141')->is_valid_number, '山口県美祢市東厚保町山中');
ok($zip->set_number('7592142')->is_valid_number, '山口県美祢市東厚保町川東');
ok($zip->set_number('7592151')->is_valid_number, '山口県美祢市西厚保町本郷');
ok($zip->set_number('7592152')->is_valid_number, '山口県美祢市西厚保町原');
ok($zip->set_number('7592200')->is_valid_number, '山口県美祢市以下に掲載がない場合');
ok($zip->set_number('7592211')->is_valid_number, '山口県美祢市大嶺町北分');
ok($zip->set_number('7592212')->is_valid_number, '山口県美祢市大嶺町東分');
ok($zip->set_number('7592213')->is_valid_number, '山口県美祢市大嶺町西分');
ok($zip->set_number('7592214')->is_valid_number, '山口県美祢市大嶺町奥分');
ok($zip->set_number('7592221')->is_valid_number, '山口県美祢市伊佐町河原');
ok($zip->set_number('7592222')->is_valid_number, '山口県美祢市伊佐町伊佐');
ok($zip->set_number('7592223')->is_valid_number, '山口県美祢市伊佐町奥万倉');
ok($zip->set_number('7592301')->is_valid_number, '山口県美祢市於福町上(駅前、岡田、上田代、栗ケ原、下田代、神柳、大明、立石、西寺、');
ok($zip->set_number('7592301')->is_valid_number, '山口県美祢市平野、古屋、宗済、横道、竜現地)');
ok($zip->set_number('7592302')->is_valid_number, '山口県美祢市於福町下(入水、榎田、金山、小杉、砂地、台、西畑、萩原、東中村、');
ok($zip->set_number('7592302')->is_valid_number, '山口県美祢市平国木、緑ケ丘、宮の前)');
ok($zip->set_number('7593111')->is_valid_number, '山口県萩市上田万');
ok($zip->set_number('7593112')->is_valid_number, '山口県萩市下田万');
ok($zip->set_number('7593113')->is_valid_number, '山口県萩市江崎');
ok($zip->set_number('7593201')->is_valid_number, '山口県萩市上小川西分');
ok($zip->set_number('7593202')->is_valid_number, '山口県萩市上小川東分');
ok($zip->set_number('7593203')->is_valid_number, '山口県萩市中小川');
ok($zip->set_number('7593204')->is_valid_number, '山口県萩市下小川');
ok($zip->set_number('7593301')->is_valid_number, '山口県萩市弥富上');
ok($zip->set_number('7593302')->is_valid_number, '山口県萩市弥富下');
ok($zip->set_number('7593303')->is_valid_number, '山口県萩市鈴野川');
ok($zip->set_number('7593411')->is_valid_number, '山口県萩市須佐');
ok($zip->set_number('7593501')->is_valid_number, '山口県阿武郡阿武町宇田');
ok($zip->set_number('7593502')->is_valid_number, '山口県阿武郡阿武町惣郷');
ok($zip->set_number('7593600')->is_valid_number, '山口県阿武郡阿武町以下に掲載がない場合');
ok($zip->set_number('7593611')->is_valid_number, '山口県萩市大井');
ok($zip->set_number('7593621')->is_valid_number, '山口県阿武郡阿武町木与');
ok($zip->set_number('7593622')->is_valid_number, '山口県阿武郡阿武町奈古');
ok($zip->set_number('7593721')->is_valid_number, '山口県萩市三見');
ok($zip->set_number('7593801')->is_valid_number, '山口県長門市三隅上');
ok($zip->set_number('7593802')->is_valid_number, '山口県長門市三隅中');
ok($zip->set_number('7593803')->is_valid_number, '山口県長門市三隅下');
ok($zip->set_number('7594100')->is_valid_number, '山口県長門市以下に掲載がない場合');
ok($zip->set_number('7594101')->is_valid_number, '山口県長門市東深川');
ok($zip->set_number('7594102')->is_valid_number, '山口県長門市西深川');
ok($zip->set_number('7594103')->is_valid_number, '山口県長門市深川湯本');
ok($zip->set_number('7594104')->is_valid_number, '山口県長門市渋木');
ok($zip->set_number('7594105')->is_valid_number, '山口県長門市真木');
ok($zip->set_number('7594106')->is_valid_number, '山口県長門市仙崎');
ok($zip->set_number('7594107')->is_valid_number, '山口県長門市通');
ok($zip->set_number('7594211')->is_valid_number, '山口県長門市俵山');
ok($zip->set_number('7594401')->is_valid_number, '山口県長門市日置上');
ok($zip->set_number('7594402')->is_valid_number, '山口県長門市日置中');
ok($zip->set_number('7594403')->is_valid_number, '山口県長門市日置下');
ok($zip->set_number('7594404')->is_valid_number, '山口県長門市日置野田');
ok($zip->set_number('7594405')->is_valid_number, '山口県長門市日置蔵小田');
ok($zip->set_number('7594501')->is_valid_number, '山口県長門市油谷蔵小田');
ok($zip->set_number('7594502')->is_valid_number, '山口県長門市油谷久富');
ok($zip->set_number('7594503')->is_valid_number, '山口県長門市油谷新別名');
ok($zip->set_number('7594504')->is_valid_number, '山口県長門市油谷河原');
ok($zip->set_number('7594505')->is_valid_number, '山口県長門市油谷伊上');
ok($zip->set_number('7594621')->is_valid_number, '山口県長門市油谷川尻');
ok($zip->set_number('7594622')->is_valid_number, '山口県長門市油谷向津具上');
ok($zip->set_number('7594623')->is_valid_number, '山口県長門市油谷向津具下');
ok($zip->set_number('7594623')->is_valid_number, '山口県長門市油谷向津具下(大浦)');
ok($zip->set_number('7594623')->is_valid_number, '山口県長門市油谷向津具下(久津)');
ok($zip->set_number('7594711')->is_valid_number, '山口県長門市油谷後畑');
ok($zip->set_number('7594712')->is_valid_number, '山口県長門市油谷津黄');
ok($zip->set_number('7594713')->is_valid_number, '山口県長門市油谷角山');
ok($zip->set_number('7595101')->is_valid_number, '山口県下関市豊北町粟野');
ok($zip->set_number('7595241')->is_valid_number, '山口県下関市豊北町阿川');
ok($zip->set_number('7595331')->is_valid_number, '山口県下関市豊北町神田');
ok($zip->set_number('7595332')->is_valid_number, '山口県下関市豊北町角島');
ok($zip->set_number('7595511')->is_valid_number, '山口県下関市豊北町滝部');
ok($zip->set_number('7595512')->is_valid_number, '山口県下関市豊北町田耕');
ok($zip->set_number('7595513')->is_valid_number, '山口県下関市豊北町神田上(7286~7339番地)');
ok($zip->set_number('7595513')->is_valid_number, '山口県下関市豊北町北宇賀');
ok($zip->set_number('7596121')->is_valid_number, '山口県下関市豊北町神田上(その他)');
ok($zip->set_number('7596122')->is_valid_number, '山口県下関市豊北町矢玉');
ok($zip->set_number('7596301')->is_valid_number, '山口県下関市豊浦町川棚');
ok($zip->set_number('7596302')->is_valid_number, '山口県下関市豊浦町小串');
ok($zip->set_number('7596303')->is_valid_number, '山口県下関市豊浦町宇賀');
ok($zip->set_number('7596311')->is_valid_number, '山口県下関市豊浦町吉永');
ok($zip->set_number('7596312')->is_valid_number, '山口県下関市豊浦町黒井');
ok($zip->set_number('7596313')->is_valid_number, '山口県下関市豊浦町豊洋台');
ok($zip->set_number('7596313')->is_valid_number, '山口県下関市豊浦町豊洋台新町');
ok($zip->set_number('7596314')->is_valid_number, '山口県下関市豊浦町厚母郷');
ok($zip->set_number('7596315')->is_valid_number, '山口県下関市豊浦町室津上');
ok($zip->set_number('7596316')->is_valid_number, '山口県下関市豊浦町室津下');
ok($zip->set_number('7596317')->is_valid_number, '山口県下関市豊浦町涌田後地');
ok($zip->set_number('7596521')->is_valid_number, '山口県下関市吉見古宿町');
ok($zip->set_number('7596522')->is_valid_number, '山口県下関市吉見竜王町');
ok($zip->set_number('7596523')->is_valid_number, '山口県下関市吉見下');
ok($zip->set_number('7596524')->is_valid_number, '山口県下関市吉見上');
ok($zip->set_number('7596525')->is_valid_number, '山口県下関市吉見里町');
ok($zip->set_number('7596531')->is_valid_number, '山口県下関市吉見本町');
ok($zip->set_number('7596532')->is_valid_number, '山口県下関市吉見新町');
ok($zip->set_number('7596533')->is_valid_number, '山口県下関市永田本町');
ok($zip->set_number('7596534')->is_valid_number, '山口県下関市永田郷');
ok($zip->set_number('7596541')->is_valid_number, '山口県下関市吉母');
ok($zip->set_number('7596542')->is_valid_number, '山口県下関市蓋井島');
ok($zip->set_number('7596601')->is_valid_number, '山口県下関市福江');
ok($zip->set_number('7596602')->is_valid_number, '山口県下関市蒲生野');
ok($zip->set_number('7596603')->is_valid_number, '山口県下関市安岡町');
ok($zip->set_number('7596604')->is_valid_number, '山口県下関市横野町');
ok($zip->set_number('7596605')->is_valid_number, '山口県下関市安岡');
ok($zip->set_number('7596611')->is_valid_number, '山口県下関市安岡本町');
ok($zip->set_number('7596612')->is_valid_number, '山口県下関市安岡駅前');
ok($zip->set_number('7596613')->is_valid_number, '山口県下関市富任町');
ok($zip->set_number('7596614')->is_valid_number, '山口県下関市梶栗町');
ok($zip->set_number('7596615')->is_valid_number, '山口県下関市冨任');
ok($zip->set_number('7600000')->is_valid_number, '香川県高松市以下に掲載がない場合');
ok($zip->set_number('7600001')->is_valid_number, '香川県高松市新北町');
ok($zip->set_number('7600002')->is_valid_number, '香川県高松市茜町');
ok($zip->set_number('7600003')->is_valid_number, '香川県高松市西町');
ok($zip->set_number('7600004')->is_valid_number, '香川県高松市西宝町');
ok($zip->set_number('7600005')->is_valid_number, '香川県高松市宮脇町');
ok($zip->set_number('7600006')->is_valid_number, '香川県高松市亀岡町');
ok($zip->set_number('7600007')->is_valid_number, '香川県高松市中央町');
ok($zip->set_number('7600008')->is_valid_number, '香川県高松市中野町');
ok($zip->set_number('7600009')->is_valid_number, '香川県高松市峰山町');
ok($zip->set_number('7600011')->is_valid_number, '香川県高松市浜ノ町');
ok($zip->set_number('7600012')->is_valid_number, '香川県高松市瀬戸内町');
ok($zip->set_number('7600013')->is_valid_number, '香川県高松市扇町');
ok($zip->set_number('7600014')->is_valid_number, '香川県高松市昭和町');
ok($zip->set_number('7600015')->is_valid_number, '香川県高松市紫雲町');
ok($zip->set_number('7600016')->is_valid_number, '香川県高松市幸町');
ok($zip->set_number('7600017')->is_valid_number, '香川県高松市番町');
ok($zip->set_number('7600018')->is_valid_number, '香川県高松市天神前');
ok($zip->set_number('7600019')->is_valid_number, '香川県高松市サンポート');
ok($zip->set_number('7600020')->is_valid_number, '香川県高松市錦町');
ok($zip->set_number('7600021')->is_valid_number, '香川県高松市西の丸町');
ok($zip->set_number('7600022')->is_valid_number, '香川県高松市西内町');
ok($zip->set_number('7600023')->is_valid_number, '香川県高松市寿町');
ok($zip->set_number('7600024')->is_valid_number, '香川県高松市兵庫町');
ok($zip->set_number('7600025')->is_valid_number, '香川県高松市古新町');
ok($zip->set_number('7600026')->is_valid_number, '香川県高松市磨屋町');
ok($zip->set_number('7600027')->is_valid_number, '香川県高松市紺屋町');
ok($zip->set_number('7600028')->is_valid_number, '香川県高松市鍛冶屋町');
ok($zip->set_number('7600029')->is_valid_number, '香川県高松市丸亀町');
ok($zip->set_number('7600030')->is_valid_number, '香川県高松市玉藻町');
ok($zip->set_number('7600031')->is_valid_number, '香川県高松市北浜町');
ok($zip->set_number('7600032')->is_valid_number, '香川県高松市本町');
ok($zip->set_number('7600033')->is_valid_number, '香川県高松市丸の内');
ok($zip->set_number('7600034')->is_valid_number, '香川県高松市内町');
ok($zip->set_number('7600035')->is_valid_number, '香川県高松市鶴屋町');
ok($zip->set_number('7600036')->is_valid_number, '香川県高松市城東町');
ok($zip->set_number('7600037')->is_valid_number, '香川県高松市東浜町');
ok($zip->set_number('7600038')->is_valid_number, '香川県高松市井口町');
ok($zip->set_number('7600040')->is_valid_number, '香川県高松市片原町');
ok($zip->set_number('7600041')->is_valid_number, '香川県高松市百間町');
ok($zip->set_number('7600042')->is_valid_number, '香川県高松市大工町');
ok($zip->set_number('7600043')->is_valid_number, '香川県高松市今新町');
ok($zip->set_number('7600044')->is_valid_number, '香川県高松市御坊町');
ok($zip->set_number('7600045')->is_valid_number, '香川県高松市古馬場町');
ok($zip->set_number('7600046')->is_valid_number, '香川県高松市通町');
ok($zip->set_number('7600047')->is_valid_number, '香川県高松市塩屋町');
ok($zip->set_number('7600048')->is_valid_number, '香川県高松市福田町');
ok($zip->set_number('7600049')->is_valid_number, '香川県高松市八坂町');
ok($zip->set_number('7600050')->is_valid_number, '香川県高松市亀井町');
ok($zip->set_number('7600051')->is_valid_number, '香川県高松市南新町');
ok($zip->set_number('7600052')->is_valid_number, '香川県高松市瓦町');
ok($zip->set_number('7600053')->is_valid_number, '香川県高松市田町');
ok($zip->set_number('7600054')->is_valid_number, '香川県高松市常磐町');
ok($zip->set_number('7600055')->is_valid_number, '香川県高松市観光通');
ok($zip->set_number('7600056')->is_valid_number, '香川県高松市中新町');
ok($zip->set_number('7600057')->is_valid_number, '香川県高松市旅籠町');
ok($zip->set_number('7600058')->is_valid_number, '香川県高松市東田町');
ok($zip->set_number('7600060')->is_valid_number, '香川県高松市末広町');
ok($zip->set_number('7600061')->is_valid_number, '香川県高松市築地町');
ok($zip->set_number('7600062')->is_valid_number, '香川県高松市塩上町');
ok($zip->set_number('7600063')->is_valid_number, '香川県高松市多賀町');
ok($zip->set_number('7600064')->is_valid_number, '香川県高松市朝日新町');
ok($zip->set_number('7600065')->is_valid_number, '香川県高松市朝日町');
ok($zip->set_number('7600066')->is_valid_number, '香川県高松市福岡町');
ok($zip->set_number('7600067')->is_valid_number, '香川県高松市松福町');
ok($zip->set_number('7600068')->is_valid_number, '香川県高松市松島町');
ok($zip->set_number('7600071')->is_valid_number, '香川県高松市藤塚町');
ok($zip->set_number('7600072')->is_valid_number, '香川県高松市花園町');
ok($zip->set_number('7600073')->is_valid_number, '香川県高松市栗林町');
ok($zip->set_number('7600074')->is_valid_number, '香川県高松市桜町');
ok($zip->set_number('7600075')->is_valid_number, '香川県高松市楠上町');
ok($zip->set_number('7600076')->is_valid_number, '香川県高松市観光町');
ok($zip->set_number('7600077')->is_valid_number, '香川県高松市上福岡町');
ok($zip->set_number('7600078')->is_valid_number, '香川県高松市今里町');
ok($zip->set_number('7600079')->is_valid_number, '香川県高松市松縄町');
ok($zip->set_number('7600080')->is_valid_number, '香川県高松市木太町');
ok($zip->set_number('7600091')->is_valid_number, '香川県高松市男木町');
ok($zip->set_number('7600092')->is_valid_number, '香川県高松市女木町');
ok($zip->set_number('7600093')->is_valid_number, '香川県高松市鶴市町(台山)');
ok($zip->set_number('7610101')->is_valid_number, '香川県高松市春日町');
ok($zip->set_number('7610102')->is_valid_number, '香川県高松市新田町甲');
ok($zip->set_number('7610103')->is_valid_number, '香川県高松市新田町乙');
ok($zip->set_number('7610104')->is_valid_number, '香川県高松市高松町');
ok($zip->set_number('7610111')->is_valid_number, '香川県高松市屋島東町');
ok($zip->set_number('7610112')->is_valid_number, '香川県高松市屋島中町');
ok($zip->set_number('7610113')->is_valid_number, '香川県高松市屋島西町');
ok($zip->set_number('7610121')->is_valid_number, '香川県高松市牟礼町牟礼');
ok($zip->set_number('7610122')->is_valid_number, '香川県高松市牟礼町大町');
ok($zip->set_number('7610123')->is_valid_number, '香川県高松市牟礼町原');
ok($zip->set_number('7610130')->is_valid_number, '香川県高松市庵治町');
ok($zip->set_number('7610301')->is_valid_number, '香川県高松市林町');
ok($zip->set_number('7610302')->is_valid_number, '香川県高松市上林町');
ok($zip->set_number('7610303')->is_valid_number, '香川県高松市六条町');
ok($zip->set_number('7610311')->is_valid_number, '香川県高松市元山町');
ok($zip->set_number('7610312')->is_valid_number, '香川県高松市東山崎町');
ok($zip->set_number('7610313')->is_valid_number, '香川県高松市下田井町');
ok($zip->set_number('7610321')->is_valid_number, '香川県高松市前田西町');
ok($zip->set_number('7610322')->is_valid_number, '香川県高松市前田東町');
ok($zip->set_number('7610323')->is_valid_number, '香川県高松市亀田町');
ok($zip->set_number('7610431')->is_valid_number, '香川県高松市小村町');
ok($zip->set_number('7610432')->is_valid_number, '香川県高松市亀田南町');
ok($zip->set_number('7610433')->is_valid_number, '香川県高松市十川西町');
ok($zip->set_number('7610434')->is_valid_number, '香川県高松市十川東町');
ok($zip->set_number('7610441')->is_valid_number, '香川県高松市由良町');
ok($zip->set_number('7610442')->is_valid_number, '香川県高松市川島本町');
ok($zip->set_number('7610443')->is_valid_number, '香川県高松市川島東町');
ok($zip->set_number('7610444')->is_valid_number, '香川県高松市池田町');
ok($zip->set_number('7610445')->is_valid_number, '香川県高松市西植田町');
ok($zip->set_number('7610446')->is_valid_number, '香川県高松市東植田町');
ok($zip->set_number('7610450')->is_valid_number, '香川県高松市三谷町');
ok($zip->set_number('7610611')->is_valid_number, '香川県木田郡三木町田中');
ok($zip->set_number('7610612')->is_valid_number, '香川県木田郡三木町氷上');
ok($zip->set_number('7610613')->is_valid_number, '香川県木田郡三木町上高岡');
ok($zip->set_number('7610614')->is_valid_number, '香川県木田郡三木町朝倉');
ok($zip->set_number('7610615')->is_valid_number, '香川県木田郡三木町小蓑');
ok($zip->set_number('7610700')->is_valid_number, '香川県木田郡三木町以下に掲載がない場合');
ok($zip->set_number('7610701')->is_valid_number, '香川県木田郡三木町池戸');
ok($zip->set_number('7610702')->is_valid_number, '香川県木田郡三木町平木');
ok($zip->set_number('7610703')->is_valid_number, '香川県木田郡三木町鹿伏');
ok($zip->set_number('7610704')->is_valid_number, '香川県木田郡三木町下高岡');
ok($zip->set_number('7610705')->is_valid_number, '香川県木田郡三木町井上');
ok($zip->set_number('7610821')->is_valid_number, '香川県木田郡三木町鹿庭');
ok($zip->set_number('7610822')->is_valid_number, '香川県木田郡三木町奥山');
ok($zip->set_number('7610823')->is_valid_number, '香川県木田郡三木町井戸');
ok($zip->set_number('7610901')->is_valid_number, '香川県さぬき市大川町富田西');
ok($zip->set_number('7610902')->is_valid_number, '香川県さぬき市大川町富田中');
ok($zip->set_number('7610903')->is_valid_number, '香川県さぬき市大川町富田東');
ok($zip->set_number('7610904')->is_valid_number, '香川県さぬき市大川町田面');
ok($zip->set_number('7610905')->is_valid_number, '香川県さぬき市大川町南川');
ok($zip->set_number('7611401')->is_valid_number, '香川県高松市香南町岡');
ok($zip->set_number('7611402')->is_valid_number, '香川県高松市香南町由佐');
ok($zip->set_number('7611403')->is_valid_number, '香川県高松市香南町吉光');
ok($zip->set_number('7611404')->is_valid_number, '香川県高松市香南町横井');
ok($zip->set_number('7611405')->is_valid_number, '香川県高松市香南町池内');
ok($zip->set_number('7611406')->is_valid_number, '香川県高松市香南町西庄');
ok($zip->set_number('7611501')->is_valid_number, '香川県高松市塩江町安原下(第1号)');
ok($zip->set_number('7611502')->is_valid_number, '香川県高松市塩江町安原下(第2号)');
ok($zip->set_number('7611503')->is_valid_number, '香川県高松市塩江町安原下(第3号)');
ok($zip->set_number('7611504')->is_valid_number, '香川県高松市塩江町安原下(その他)');
ok($zip->set_number('7611611')->is_valid_number, '香川県高松市塩江町安原上');
ok($zip->set_number('7611612')->is_valid_number, '香川県高松市塩江町安原上東');
ok($zip->set_number('7611613')->is_valid_number, '香川県高松市塩江町上西甲');
ok($zip->set_number('7611614')->is_valid_number, '香川県高松市塩江町上西乙');
ok($zip->set_number('7611615')->is_valid_number, '香川県高松市塩江町安原下(上小田)');
ok($zip->set_number('7611615')->is_valid_number, '香川県高松市塩江町安原下(炭谷)');
ok($zip->set_number('7611616')->is_valid_number, '香川県高松市菅沢町');
ok($zip->set_number('7611701')->is_valid_number, '香川県高松市香川町大野');
ok($zip->set_number('7611702')->is_valid_number, '香川県高松市香川町寺井');
ok($zip->set_number('7611703')->is_valid_number, '香川県高松市香川町浅野');
ok($zip->set_number('7611704')->is_valid_number, '香川県高松市香川町川内原');
ok($zip->set_number('7611705')->is_valid_number, '香川県高松市香川町川東下');
ok($zip->set_number('7611706')->is_valid_number, '香川県高松市香川町川東上');
ok($zip->set_number('7611707')->is_valid_number, '香川県高松市香川町東谷');
ok($zip->set_number('7611708')->is_valid_number, '香川県高松市香川町安原下');
ok($zip->set_number('7612101')->is_valid_number, '香川県綾歌郡綾川町畑田');
ok($zip->set_number('7612102')->is_valid_number, '香川県綾歌郡綾川町千疋');
ok($zip->set_number('7612103')->is_valid_number, '香川県綾歌郡綾川町陶');
ok($zip->set_number('7612201')->is_valid_number, '香川県綾歌郡綾川町枌所東');
ok($zip->set_number('7612202')->is_valid_number, '香川県綾歌郡綾川町枌所西');
ok($zip->set_number('7612203')->is_valid_number, '香川県綾歌郡綾川町山田上');
ok($zip->set_number('7612204')->is_valid_number, '香川県綾歌郡綾川町山田下');
ok($zip->set_number('7612205')->is_valid_number, '香川県綾歌郡綾川町東分');
ok($zip->set_number('7612206')->is_valid_number, '香川県綾歌郡綾川町西分');
ok($zip->set_number('7612207')->is_valid_number, '香川県綾歌郡綾川町羽床上');
ok($zip->set_number('7612208')->is_valid_number, '香川県綾歌郡綾川町牛川');
ok($zip->set_number('7612300')->is_valid_number, '香川県綾歌郡綾川町以下に掲載がない場合');
ok($zip->set_number('7612304')->is_valid_number, '香川県綾歌郡綾川町萱原');
ok($zip->set_number('7612305')->is_valid_number, '香川県綾歌郡綾川町滝宮');
ok($zip->set_number('7612306')->is_valid_number, '香川県綾歌郡綾川町北');
ok($zip->set_number('7612307')->is_valid_number, '香川県綾歌郡綾川町小野');
ok($zip->set_number('7612308')->is_valid_number, '香川県綾歌郡綾川町羽床下');
ok($zip->set_number('7612401')->is_valid_number, '香川県丸亀市綾歌町岡田上');
ok($zip->set_number('7612402')->is_valid_number, '香川県丸亀市綾歌町岡田下');
ok($zip->set_number('7612403')->is_valid_number, '香川県丸亀市綾歌町岡田西');
ok($zip->set_number('7612404')->is_valid_number, '香川県丸亀市綾歌町岡田東');
ok($zip->set_number('7612405')->is_valid_number, '香川県丸亀市綾歌町栗熊西');
ok($zip->set_number('7612406')->is_valid_number, '香川県丸亀市綾歌町栗熊東');
ok($zip->set_number('7612407')->is_valid_number, '香川県丸亀市綾歌町富熊(その他)');
ok($zip->set_number('7612408')->is_valid_number, '香川県丸亀市綾歌町富熊(富士見坂)');
ok($zip->set_number('7613110')->is_valid_number, '香川県香川郡直島町直島町一円');
ok($zip->set_number('7614100')->is_valid_number, '香川県小豆郡土庄町以下に掲載がない場合');
ok($zip->set_number('7614101')->is_valid_number, '香川県小豆郡土庄町甲、乙(その他)');
ok($zip->set_number('7614102')->is_valid_number, '香川県小豆郡土庄町甲、乙(港新町)');
ok($zip->set_number('7614103')->is_valid_number, '香川県小豆郡土庄町甲、乙(大木戸)');
ok($zip->set_number('7614104')->is_valid_number, '香川県小豆郡土庄町甲、乙(吉ケ浦)');
ok($zip->set_number('7614105')->is_valid_number, '香川県小豆郡土庄町甲、乙(西本町)');
ok($zip->set_number('7614106')->is_valid_number, '香川県小豆郡土庄町甲、乙(本町)');
ok($zip->set_number('7614111')->is_valid_number, '香川県小豆郡土庄町甲、乙(東港)');
ok($zip->set_number('7614112')->is_valid_number, '香川県小豆郡土庄町甲、乙(鹿島)');
ok($zip->set_number('7614113')->is_valid_number, '香川県小豆郡土庄町甲、乙(柳)');
ok($zip->set_number('7614114')->is_valid_number, '香川県小豆郡土庄町甲、乙(千軒)');
ok($zip->set_number('7614115')->is_valid_number, '香川県小豆郡土庄町甲、乙(小瀬)');
ok($zip->set_number('7614121')->is_valid_number, '香川県小豆郡土庄町渕崎');
ok($zip->set_number('7614122')->is_valid_number, '香川県小豆郡土庄町上庄');
ok($zip->set_number('7614131')->is_valid_number, '香川県小豆郡土庄町伊喜末(その他)');
ok($zip->set_number('7614132')->is_valid_number, '香川県小豆郡土庄町小江');
ok($zip->set_number('7614133')->is_valid_number, '香川県小豆郡土庄町長浜');
ok($zip->set_number('7614134')->is_valid_number, '香川県小豆郡土庄町滝宮');
ok($zip->set_number('7614141')->is_valid_number, '香川県小豆郡土庄町馬越');
ok($zip->set_number('7614142')->is_valid_number, '香川県小豆郡土庄町屋形崎');
ok($zip->set_number('7614143')->is_valid_number, '香川県小豆郡土庄町見目');
ok($zip->set_number('7614144')->is_valid_number, '香川県小豆郡土庄町小海');
ok($zip->set_number('7614145')->is_valid_number, '香川県小豆郡土庄町大部');
ok($zip->set_number('7614146')->is_valid_number, '香川県小豆郡土庄町小部');
ok($zip->set_number('7614151')->is_valid_number, '香川県小豆郡土庄町肥土山');
ok($zip->set_number('7614152')->is_valid_number, '香川県小豆郡土庄町黒岩');
ok($zip->set_number('7614153')->is_valid_number, '香川県小豆郡土庄町小馬越');
ok($zip->set_number('7614154')->is_valid_number, '香川県小豆郡土庄町笠滝');
ok($zip->set_number('7614155')->is_valid_number, '香川県小豆郡小豆島町中山(美しの原高原)');
ok($zip->set_number('7614155')->is_valid_number, '香川県小豆郡小豆島町中山(蛙子鳴滝)');
ok($zip->set_number('7614300')->is_valid_number, '香川県小豆郡小豆島町以下に掲載がない場合');
ok($zip->set_number('7614301')->is_valid_number, '香川県小豆郡小豆島町池田');
ok($zip->set_number('7614302')->is_valid_number, '香川県小豆郡小豆島町蒲生');
ok($zip->set_number('7614303')->is_valid_number, '香川県小豆郡小豆島町中山(その他)');
ok($zip->set_number('7614304')->is_valid_number, '香川県小豆郡小豆島町室生');
ok($zip->set_number('7614305')->is_valid_number, '香川県小豆郡小豆島町二面');
ok($zip->set_number('7614306')->is_valid_number, '香川県小豆郡小豆島町吉野');
ok($zip->set_number('7614307')->is_valid_number, '香川県小豆郡小豆島町蒲野');
ok($zip->set_number('7614308')->is_valid_number, '香川県小豆郡小豆島町神浦');
ok($zip->set_number('7614401')->is_valid_number, '香川県小豆郡小豆島町吉田');
ok($zip->set_number('7614402')->is_valid_number, '香川県小豆郡小豆島町福田');
ok($zip->set_number('7614403')->is_valid_number, '香川県小豆郡小豆島町当浜');
ok($zip->set_number('7614404')->is_valid_number, '香川県小豆郡小豆島町岩谷');
ok($zip->set_number('7614405')->is_valid_number, '香川県小豆郡小豆島町橘');
ok($zip->set_number('7614411')->is_valid_number, '香川県小豆郡小豆島町安田');
ok($zip->set_number('7614412')->is_valid_number, '香川県小豆郡小豆島町木庄');
ok($zip->set_number('7614421')->is_valid_number, '香川県小豆郡小豆島町苗羽');
ok($zip->set_number('7614422')->is_valid_number, '香川県小豆郡小豆島町古江');
ok($zip->set_number('7614423')->is_valid_number, '香川県小豆郡小豆島町堀越');
ok($zip->set_number('7614424')->is_valid_number, '香川県小豆郡小豆島町田浦');
ok($zip->set_number('7614425')->is_valid_number, '香川県小豆郡小豆島町坂手');
ok($zip->set_number('7614426')->is_valid_number, '香川県小豆郡小豆島町馬木');
ok($zip->set_number('7614431')->is_valid_number, '香川県小豆郡小豆島町片城');
ok($zip->set_number('7614432')->is_valid_number, '香川県小豆郡小豆島町草壁本町');
ok($zip->set_number('7614433')->is_valid_number, '香川県小豆郡小豆島町神懸通');
ok($zip->set_number('7614434')->is_valid_number, '香川県小豆郡小豆島町西村');
ok($zip->set_number('7614661')->is_valid_number, '香川県小豆郡土庄町豊島家浦');
ok($zip->set_number('7614662')->is_valid_number, '香川県小豆郡土庄町豊島唐櫃');
ok($zip->set_number('7614663')->is_valid_number, '香川県小豆郡土庄町豊島甲生');
ok($zip->set_number('7614664')->is_valid_number, '香川県小豆郡土庄町伊喜末(小豊島)');
ok($zip->set_number('7618001')->is_valid_number, '香川県高松市亀水町');
ok($zip->set_number('7618002')->is_valid_number, '香川県高松市生島町');
ok($zip->set_number('7618003')->is_valid_number, '香川県高松市神在川窪町');
ok($zip->set_number('7618004')->is_valid_number, '香川県高松市中山町');
ok($zip->set_number('7618005')->is_valid_number, '香川県高松市植松町');
ok($zip->set_number('7618011')->is_valid_number, '香川県高松市香西北町');
ok($zip->set_number('7618012')->is_valid_number, '香川県高松市香西本町');
ok($zip->set_number('7618013')->is_valid_number, '香川県高松市香西東町');
ok($zip->set_number('7618014')->is_valid_number, '香川県高松市香西南町');
ok($zip->set_number('7618015')->is_valid_number, '香川県高松市香西西町');
ok($zip->set_number('7618021')->is_valid_number, '香川県高松市鬼無町是竹');
ok($zip->set_number('7618022')->is_valid_number, '香川県高松市鬼無町佐料');
ok($zip->set_number('7618023')->is_valid_number, '香川県高松市鬼無町佐藤');
ok($zip->set_number('7618024')->is_valid_number, '香川県高松市鬼無町藤井');
ok($zip->set_number('7618025')->is_valid_number, '香川県高松市鬼無町山口');
ok($zip->set_number('7618026')->is_valid_number, '香川県高松市鬼無町鬼無');
ok($zip->set_number('7618031')->is_valid_number, '香川県高松市郷東町');
ok($zip->set_number('7618032')->is_valid_number, '香川県高松市鶴市町(その他)');
ok($zip->set_number('7618033')->is_valid_number, '香川県高松市飯田町');
ok($zip->set_number('7618041')->is_valid_number, '香川県高松市檀紙町');
ok($zip->set_number('7618042')->is_valid_number, '香川県高松市御厩町');
ok($zip->set_number('7618043')->is_valid_number, '香川県高松市中間町');
ok($zip->set_number('7618044')->is_valid_number, '香川県高松市円座町');
ok($zip->set_number('7618045')->is_valid_number, '香川県高松市西山崎町');
ok($zip->set_number('7618046')->is_valid_number, '香川県高松市川部町');
ok($zip->set_number('7618047')->is_valid_number, '香川県高松市岡本町');
ok($zip->set_number('7618051')->is_valid_number, '香川県高松市西春日町');
ok($zip->set_number('7618052')->is_valid_number, '香川県高松市松並町');
ok($zip->set_number('7618053')->is_valid_number, '香川県高松市西ハゼ町');
ok($zip->set_number('7618054')->is_valid_number, '香川県高松市東ハゼ町');
ok($zip->set_number('7618055')->is_valid_number, '香川県高松市紙町');
ok($zip->set_number('7618056')->is_valid_number, '香川県高松市上天神町');
ok($zip->set_number('7618057')->is_valid_number, '香川県高松市田村町');
ok($zip->set_number('7618058')->is_valid_number, '香川県高松市勅使町');
ok($zip->set_number('7618061')->is_valid_number, '香川県高松市室町');
ok($zip->set_number('7618062')->is_valid_number, '香川県高松市室新町');
ok($zip->set_number('7618063')->is_valid_number, '香川県高松市花ノ宮町');
ok($zip->set_number('7618064')->is_valid_number, '香川県高松市上之町');
ok($zip->set_number('7618071')->is_valid_number, '香川県高松市伏石町');
ok($zip->set_number('7618072')->is_valid_number, '香川県高松市三条町');
ok($zip->set_number('7618073')->is_valid_number, '香川県高松市太田下町');
ok($zip->set_number('7618074')->is_valid_number, '香川県高松市太田上町');
ok($zip->set_number('7618075')->is_valid_number, '香川県高松市多肥下町');
ok($zip->set_number('7618076')->is_valid_number, '香川県高松市多肥上町');
ok($zip->set_number('7618077')->is_valid_number, '香川県高松市出作町');
ok($zip->set_number('7618078')->is_valid_number, '香川県高松市仏生山町甲');
ok($zip->set_number('7618079')->is_valid_number, '香川県高松市仏生山町乙');
ok($zip->set_number('7618081')->is_valid_number, '香川県高松市成合町');
ok($zip->set_number('7618082')->is_valid_number, '香川県高松市鹿角町');
ok($zip->set_number('7618083')->is_valid_number, '香川県高松市三名町');
ok($zip->set_number('7618084')->is_valid_number, '香川県高松市一宮町');
ok($zip->set_number('7618085')->is_valid_number, '香川県高松市寺井町');
ok($zip->set_number('7620000')->is_valid_number, '香川県坂出市以下に掲載がない場合');
ok($zip->set_number('7620001')->is_valid_number, '香川県坂出市京町');
ok($zip->set_number('7620002')->is_valid_number, '香川県坂出市入船町');
ok($zip->set_number('7620003')->is_valid_number, '香川県坂出市久米町');
ok($zip->set_number('7620004')->is_valid_number, '香川県坂出市昭和町');
ok($zip->set_number('7620005')->is_valid_number, '香川県坂出市横津町');
ok($zip->set_number('7620006')->is_valid_number, '香川県坂出市旭町');
ok($zip->set_number('7620007')->is_valid_number, '香川県坂出市室町');
ok($zip->set_number('7620011')->is_valid_number, '香川県坂出市江尻町');
ok($zip->set_number('7620012')->is_valid_number, '香川県坂出市林田町');
ok($zip->set_number('7620013')->is_valid_number, '香川県坂出市王越町乃生');
ok($zip->set_number('7620014')->is_valid_number, '香川県坂出市王越町木沢');
ok($zip->set_number('7620015')->is_valid_number, '香川県坂出市大屋冨町');
ok($zip->set_number('7620016')->is_valid_number, '香川県坂出市青海町');
ok($zip->set_number('7620017')->is_valid_number, '香川県坂出市高屋町');
ok($zip->set_number('7620018')->is_valid_number, '香川県坂出市神谷町');
ok($zip->set_number('7620021')->is_valid_number, '香川県坂出市西庄町');
ok($zip->set_number('7620022')->is_valid_number, '香川県坂出市加茂町甲(氏部)');
ok($zip->set_number('7620023')->is_valid_number, '香川県坂出市加茂町(その他)');
ok($zip->set_number('7620024')->is_valid_number, '香川県坂出市府中町');
ok($zip->set_number('7620025')->is_valid_number, '香川県坂出市川津町');
ok($zip->set_number('7620026')->is_valid_number, '香川県坂出市小山町');
ok($zip->set_number('7620027')->is_valid_number, '香川県坂出市大池町');
ok($zip->set_number('7620031')->is_valid_number, '香川県坂出市文京町');
ok($zip->set_number('7620032')->is_valid_number, '香川県坂出市駒止町');
ok($zip->set_number('7620033')->is_valid_number, '香川県坂出市谷町');
ok($zip->set_number('7620034')->is_valid_number, '香川県坂出市福江町');
ok($zip->set_number('7620035')->is_valid_number, '香川県坂出市池園町');
ok($zip->set_number('7620036')->is_valid_number, '香川県坂出市花町');
ok($zip->set_number('7620037')->is_valid_number, '香川県坂出市青葉町');
ok($zip->set_number('7620038')->is_valid_number, '香川県坂出市笠指町');
ok($zip->set_number('7620041')->is_valid_number, '香川県坂出市八幡町');
ok($zip->set_number('7620042')->is_valid_number, '香川県坂出市白金町');
ok($zip->set_number('7620043')->is_valid_number, '香川県坂出市寿町');
ok($zip->set_number('7620044')->is_valid_number, '香川県坂出市本町');
ok($zip->set_number('7620045')->is_valid_number, '香川県坂出市元町');
ok($zip->set_number('7620046')->is_valid_number, '香川県坂出市富士見町');
ok($zip->set_number('7620047')->is_valid_number, '香川県坂出市新浜町');
ok($zip->set_number('7620051')->is_valid_number, '香川県坂出市御供所町');
ok($zip->set_number('7620052')->is_valid_number, '香川県坂出市沖の浜');
ok($zip->set_number('7620053')->is_valid_number, '香川県坂出市西大浜北');
ok($zip->set_number('7620054')->is_valid_number, '香川県坂出市西大浜南');
ok($zip->set_number('7620055')->is_valid_number, '香川県坂出市築港町');
ok($zip->set_number('7620056')->is_valid_number, '香川県坂出市中央町');
ok($zip->set_number('7620057')->is_valid_number, '香川県坂出市宮下町');
ok($zip->set_number('7620058')->is_valid_number, '香川県坂出市常盤町');
ok($zip->set_number('7620061')->is_valid_number, '香川県坂出市坂出町');
ok($zip->set_number('7620062')->is_valid_number, '香川県坂出市川崎町');
ok($zip->set_number('7620063')->is_valid_number, '香川県坂出市番の州公園');
ok($zip->set_number('7620064')->is_valid_number, '香川県坂出市番の州町');
ok($zip->set_number('7620065')->is_valid_number, '香川県坂出市番の州緑町');
ok($zip->set_number('7620066')->is_valid_number, '香川県坂出市沙弥島');
ok($zip->set_number('7620067')->is_valid_number, '香川県坂出市瀬居町');
ok($zip->set_number('7620071')->is_valid_number, '香川県坂出市与島町');
ok($zip->set_number('7620072')->is_valid_number, '香川県坂出市岩黒');
ok($zip->set_number('7620073')->is_valid_number, '香川県坂出市櫃石');
ok($zip->set_number('7620081')->is_valid_number, '香川県丸亀市飯山町東坂元');
ok($zip->set_number('7620082')->is_valid_number, '香川県丸亀市飯山町川原');
ok($zip->set_number('7620083')->is_valid_number, '香川県丸亀市飯山町下法軍寺');
ok($zip->set_number('7620084')->is_valid_number, '香川県丸亀市飯山町上法軍寺');
ok($zip->set_number('7620085')->is_valid_number, '香川県丸亀市飯山町東小川');
ok($zip->set_number('7620086')->is_valid_number, '香川県丸亀市飯山町真時');
ok($zip->set_number('7620087')->is_valid_number, '香川県丸亀市飯山町西坂元');
ok($zip->set_number('7630000')->is_valid_number, '香川県丸亀市以下に掲載がない場合');
ok($zip->set_number('7630001')->is_valid_number, '香川県丸亀市風袋町');
ok($zip->set_number('7630002')->is_valid_number, '香川県丸亀市瓦町');
ok($zip->set_number('7630003')->is_valid_number, '香川県丸亀市葭町');
ok($zip->set_number('7630004')->is_valid_number, '香川県丸亀市米屋町');
ok($zip->set_number('7630005')->is_valid_number, '香川県丸亀市松屋町');
ok($zip->set_number('7630006')->is_valid_number, '香川県丸亀市魚屋町');
ok($zip->set_number('7630007')->is_valid_number, '香川県丸亀市宗古町');
ok($zip->set_number('7630011')->is_valid_number, '香川県丸亀市富士見町');
ok($zip->set_number('7630012')->is_valid_number, '香川県丸亀市土居町');
ok($zip->set_number('7630013')->is_valid_number, '香川県丸亀市城東町');
ok($zip->set_number('7630014')->is_valid_number, '香川県丸亀市御供所町');
ok($zip->set_number('7630015')->is_valid_number, '香川県丸亀市北平山町');
ok($zip->set_number('7630021')->is_valid_number, '香川県丸亀市富屋町');
ok($zip->set_number('7630022')->is_valid_number, '香川県丸亀市浜町');
ok($zip->set_number('7630023')->is_valid_number, '香川県丸亀市本町');
ok($zip->set_number('7630024')->is_valid_number, '香川県丸亀市塩飽町');
ok($zip->set_number('7630025')->is_valid_number, '香川県丸亀市一番丁');
ok($zip->set_number('7630026')->is_valid_number, '香川県丸亀市六番丁');
ok($zip->set_number('7630027')->is_valid_number, '香川県丸亀市七番丁');
ok($zip->set_number('7630028')->is_valid_number, '香川県丸亀市八番丁');
ok($zip->set_number('7630029')->is_valid_number, '香川県丸亀市九番丁');
ok($zip->set_number('7630030')->is_valid_number, '香川県丸亀市十番丁');
ok($zip->set_number('7630031')->is_valid_number, '香川県丸亀市城南町');
ok($zip->set_number('7630032')->is_valid_number, '香川県丸亀市城西町');
ok($zip->set_number('7630033')->is_valid_number, '香川県丸亀市中府町');
ok($zip->set_number('7630034')->is_valid_number, '香川県丸亀市大手町');
ok($zip->set_number('7630041')->is_valid_number, '香川県丸亀市西平山町');
ok($zip->set_number('7630042')->is_valid_number, '香川県丸亀市港町');
ok($zip->set_number('7630043')->is_valid_number, '香川県丸亀市通町');
ok($zip->set_number('7630044')->is_valid_number, '香川県丸亀市福島町');
ok($zip->set_number('7630045')->is_valid_number, '香川県丸亀市新町');
ok($zip->set_number('7630046')->is_valid_number, '香川県丸亀市南条町');
ok($zip->set_number('7630047')->is_valid_number, '香川県丸亀市西本町');
ok($zip->set_number('7630048')->is_valid_number, '香川県丸亀市幸町');
ok($zip->set_number('7630051')->is_valid_number, '香川県丸亀市今津町');
ok($zip->set_number('7630052')->is_valid_number, '香川県丸亀市津森町');
ok($zip->set_number('7630053')->is_valid_number, '香川県丸亀市金倉町');
ok($zip->set_number('7630054')->is_valid_number, '香川県丸亀市中津町');
ok($zip->set_number('7630055')->is_valid_number, '香川県丸亀市新田町');
ok($zip->set_number('7630061')->is_valid_number, '香川県丸亀市昭和町');
ok($zip->set_number('7630062')->is_valid_number, '香川県丸亀市蓬莱町');
ok($zip->set_number('7630063')->is_valid_number, '香川県丸亀市新浜町');
ok($zip->set_number('7630064')->is_valid_number, '香川県丸亀市前塩屋町');
ok($zip->set_number('7630065')->is_valid_number, '香川県丸亀市塩屋町');
ok($zip->set_number('7630066')->is_valid_number, '香川県丸亀市天満町');
ok($zip->set_number('7630071')->is_valid_number, '香川県丸亀市田村町');
ok($zip->set_number('7630072')->is_valid_number, '香川県丸亀市山北町');
ok($zip->set_number('7630073')->is_valid_number, '香川県丸亀市柞原町');
ok($zip->set_number('7630074')->is_valid_number, '香川県丸亀市原田町');
ok($zip->set_number('7630075')->is_valid_number, '香川県丸亀市原田団地');
ok($zip->set_number('7630081')->is_valid_number, '香川県丸亀市土器町西');
ok($zip->set_number('7630082')->is_valid_number, '香川県丸亀市土器町東');
ok($zip->set_number('7630083')->is_valid_number, '香川県丸亀市土器町北');
ok($zip->set_number('7630084')->is_valid_number, '香川県丸亀市飯野町東二');
ok($zip->set_number('7630085')->is_valid_number, '香川県丸亀市飯野町東分');
ok($zip->set_number('7630086')->is_valid_number, '香川県丸亀市飯野町西分');
ok($zip->set_number('7630091')->is_valid_number, '香川県丸亀市川西町北');
ok($zip->set_number('7630092')->is_valid_number, '香川県丸亀市川西町南');
ok($zip->set_number('7630093')->is_valid_number, '香川県丸亀市郡家町');
ok($zip->set_number('7630094')->is_valid_number, '香川県丸亀市三条町');
ok($zip->set_number('7630095')->is_valid_number, '香川県丸亀市垂水町');
ok($zip->set_number('7630101')->is_valid_number, '香川県丸亀市広島町立石');
ok($zip->set_number('7630102')->is_valid_number, '香川県丸亀市広島町江の浦');
ok($zip->set_number('7630103')->is_valid_number, '香川県丸亀市広島町釜の越');
ok($zip->set_number('7630104')->is_valid_number, '香川県丸亀市広島町甲路');
ok($zip->set_number('7630105')->is_valid_number, '香川県丸亀市広島町青木');
ok($zip->set_number('7630106')->is_valid_number, '香川県丸亀市広島町市井');
ok($zip->set_number('7630107')->is_valid_number, '香川県丸亀市広島町茂浦');
ok($zip->set_number('7630108')->is_valid_number, '香川県丸亀市広島町小手島');
ok($zip->set_number('7630111')->is_valid_number, '香川県丸亀市手島町');
ok($zip->set_number('7630221')->is_valid_number, '香川県丸亀市本島町笠島');
ok($zip->set_number('7630222')->is_valid_number, '香川県丸亀市本島町甲生');
ok($zip->set_number('7630223')->is_valid_number, '香川県丸亀市本島町泊');
ok($zip->set_number('7630224')->is_valid_number, '香川県丸亀市本島町小阪');
ok($zip->set_number('7630225')->is_valid_number, '香川県丸亀市本島町生ノ浜');
ok($zip->set_number('7630226')->is_valid_number, '香川県丸亀市本島町尻浜');
ok($zip->set_number('7630227')->is_valid_number, '香川県丸亀市本島町福田');
ok($zip->set_number('7630228')->is_valid_number, '香川県丸亀市本島町大浦');
ok($zip->set_number('7630231')->is_valid_number, '香川県丸亀市牛島');
ok($zip->set_number('7640000')->is_valid_number, '香川県仲多度郡多度津町以下に掲載がない場合');
ok($zip->set_number('7640001')->is_valid_number, '香川県仲多度郡多度津町東新町');
ok($zip->set_number('7640002')->is_valid_number, '香川県仲多度郡多度津町家中');
ok($zip->set_number('7640003')->is_valid_number, '香川県仲多度郡多度津町元町');
ok($zip->set_number('7640004')->is_valid_number, '香川県仲多度郡多度津町仲ノ町');
ok($zip->set_number('7640005')->is_valid_number, '香川県仲多度郡多度津町大通り');
ok($zip->set_number('7640006')->is_valid_number, '香川県仲多度郡多度津町日の出町');
ok($zip->set_number('7640011')->is_valid_number, '香川県仲多度郡多度津町栄町');
ok($zip->set_number('7640012')->is_valid_number, '香川県仲多度郡多度津町桜川');
ok($zip->set_number('7640013')->is_valid_number, '香川県仲多度郡多度津町京町');
ok($zip->set_number('7640014')->is_valid_number, '香川県仲多度郡多度津町本通');
ok($zip->set_number('7640015')->is_valid_number, '香川県仲多度郡多度津町西浜');
ok($zip->set_number('7640016')->is_valid_number, '香川県仲多度郡多度津町東浜');
ok($zip->set_number('7640017')->is_valid_number, '香川県仲多度郡多度津町西港町');
ok($zip->set_number('7640018')->is_valid_number, '香川県仲多度郡多度津町東港町');
ok($zip->set_number('7640021')->is_valid_number, '香川県仲多度郡多度津町堀江');
ok($zip->set_number('7640022')->is_valid_number, '香川県仲多度郡多度津町北鴨');
ok($zip->set_number('7640023')->is_valid_number, '香川県仲多度郡多度津町若葉町');
ok($zip->set_number('7640024')->is_valid_number, '香川県仲多度郡多度津町幸町');
ok($zip->set_number('7640025')->is_valid_number, '香川県仲多度郡多度津町寿町');
ok($zip->set_number('7640026')->is_valid_number, '香川県仲多度郡多度津町南鴨');
ok($zip->set_number('7640027')->is_valid_number, '香川県仲多度郡多度津町道福寺');
ok($zip->set_number('7640028')->is_valid_number, '香川県仲多度郡多度津町葛原');
ok($zip->set_number('7640031')->is_valid_number, '香川県仲多度郡多度津町庄');
ok($zip->set_number('7640032')->is_valid_number, '香川県仲多度郡多度津町三井');
ok($zip->set_number('7640033')->is_valid_number, '香川県仲多度郡多度津町青木');
ok($zip->set_number('7640034')->is_valid_number, '香川県仲多度郡多度津町山階');
ok($zip->set_number('7640035')->is_valid_number, '香川県仲多度郡多度津町奥白方');
ok($zip->set_number('7640036')->is_valid_number, '香川県仲多度郡多度津町見立');
ok($zip->set_number('7640037')->is_valid_number, '香川県仲多度郡多度津町西白方');
ok($zip->set_number('7640038')->is_valid_number, '香川県仲多度郡多度津町東白方');
ok($zip->set_number('7640040')->is_valid_number, '香川県仲多度郡多度津町佐柳');
ok($zip->set_number('7640050')->is_valid_number, '香川県仲多度郡多度津町高見');
ok($zip->set_number('7650000')->is_valid_number, '香川県善通寺市以下に掲載がない場合');
ok($zip->set_number('7650001')->is_valid_number, '香川県善通寺市仙遊町');
ok($zip->set_number('7650002')->is_valid_number, '香川県善通寺市南町');
ok($zip->set_number('7650003')->is_valid_number, '香川県善通寺市善通寺町(丁目)');
ok($zip->set_number('7650004')->is_valid_number, '香川県善通寺市善通寺町(その他)');
ok($zip->set_number('7650011')->is_valid_number, '香川県善通寺市上吉田町(丁目)');
ok($zip->set_number('7650012')->is_valid_number, '香川県善通寺市上吉田町(その他)');
ok($zip->set_number('7650013')->is_valid_number, '香川県善通寺市文京町');
ok($zip->set_number('7650014')->is_valid_number, '香川県善通寺市生野本町');
ok($zip->set_number('7650021')->is_valid_number, '香川県善通寺市下吉田町');
ok($zip->set_number('7650022')->is_valid_number, '香川県善通寺市稲木町');
ok($zip->set_number('7650031')->is_valid_number, '香川県善通寺市金蔵寺町');
ok($zip->set_number('7650032')->is_valid_number, '香川県善通寺市原田町');
ok($zip->set_number('7650033')->is_valid_number, '香川県善通寺市木徳町');
ok($zip->set_number('7650040')->is_valid_number, '香川県善通寺市与北町');
ok($zip->set_number('7650051')->is_valid_number, '香川県善通寺市櫛梨町');
ok($zip->set_number('7650052')->is_valid_number, '香川県善通寺市大麻町');
ok($zip->set_number('7650053')->is_valid_number, '香川県善通寺市生野町');
ok($zip->set_number('7650061')->is_valid_number, '香川県善通寺市吉原町');
ok($zip->set_number('7650062')->is_valid_number, '香川県善通寺市碑殿町');
ok($zip->set_number('7650071')->is_valid_number, '香川県善通寺市弘田町');
ok($zip->set_number('7650072')->is_valid_number, '香川県善通寺市中村町(丁目)');
ok($zip->set_number('7650073')->is_valid_number, '香川県善通寺市中村町(その他)');
ok($zip->set_number('7660000')->is_valid_number, '香川県仲多度郡琴平町以下に掲載がない場合');
ok($zip->set_number('7660000')->is_valid_number, '香川県仲多度郡まんのう町以下に掲載がない場合');
ok($zip->set_number('7660001')->is_valid_number, '香川県仲多度郡琴平町琴平町の次に427番地以降がくる場合(川西)');
ok($zip->set_number('7660002')->is_valid_number, '香川県仲多度郡琴平町琴平町の次に1~426番地がくる場合(川東)');
ok($zip->set_number('7660003')->is_valid_number, '香川県仲多度郡琴平町五條');
ok($zip->set_number('7660004')->is_valid_number, '香川県仲多度郡琴平町榎井');
ok($zip->set_number('7660005')->is_valid_number, '香川県仲多度郡琴平町苗田');
ok($zip->set_number('7660006')->is_valid_number, '香川県仲多度郡琴平町上櫛梨');
ok($zip->set_number('7660007')->is_valid_number, '香川県仲多度郡琴平町下櫛梨');
ok($zip->set_number('7660011')->is_valid_number, '香川県仲多度郡まんのう町公文');
ok($zip->set_number('7660012')->is_valid_number, '香川県仲多度郡まんのう町西高篠');
ok($zip->set_number('7660013')->is_valid_number, '香川県仲多度郡まんのう町東高篠');
ok($zip->set_number('7660014')->is_valid_number, '香川県仲多度郡まんのう町羽間');
ok($zip->set_number('7660015')->is_valid_number, '香川県仲多度郡まんのう町長尾');
ok($zip->set_number('7660016')->is_valid_number, '香川県仲多度郡まんのう町炭所東');
ok($zip->set_number('7660017')->is_valid_number, '香川県仲多度郡まんのう町炭所西');
ok($zip->set_number('7660021')->is_valid_number, '香川県仲多度郡まんのう町四條');
ok($zip->set_number('7660022')->is_valid_number, '香川県仲多度郡まんのう町吉野下');
ok($zip->set_number('7660023')->is_valid_number, '香川県仲多度郡まんのう町吉野');
ok($zip->set_number('7660024')->is_valid_number, '香川県仲多度郡まんのう町神野');
ok($zip->set_number('7660025')->is_valid_number, '香川県仲多度郡まんのう町真野');
ok($zip->set_number('7660026')->is_valid_number, '香川県仲多度郡まんのう町岸上');
ok($zip->set_number('7660027')->is_valid_number, '香川県仲多度郡まんのう町五條');
ok($zip->set_number('7660201')->is_valid_number, '香川県仲多度郡まんのう町造田');
ok($zip->set_number('7660202')->is_valid_number, '香川県仲多度郡まんのう町中通');
ok($zip->set_number('7660203')->is_valid_number, '香川県仲多度郡まんのう町川東');
ok($zip->set_number('7660204')->is_valid_number, '香川県仲多度郡まんのう町勝浦');
ok($zip->set_number('7670000')->is_valid_number, '香川県三豊市以下に掲載がない場合');
ok($zip->set_number('7670001')->is_valid_number, '香川県三豊市高瀬町上高瀬');
ok($zip->set_number('7670002')->is_valid_number, '香川県三豊市高瀬町新名');
ok($zip->set_number('7670003')->is_valid_number, '香川県三豊市高瀬町比地中');
ok($zip->set_number('7670004')->is_valid_number, '香川県三豊市高瀬町比地');
ok($zip->set_number('7670011')->is_valid_number, '香川県三豊市高瀬町下勝間');
ok($zip->set_number('7670012')->is_valid_number, '香川県三豊市高瀬町上勝間');
ok($zip->set_number('7670013')->is_valid_number, '香川県三豊市高瀬町下麻');
ok($zip->set_number('7670014')->is_valid_number, '香川県三豊市高瀬町上麻');
ok($zip->set_number('7670021')->is_valid_number, '香川県三豊市高瀬町佐股');
ok($zip->set_number('7670022')->is_valid_number, '香川県三豊市高瀬町羽方');
ok($zip->set_number('7670031')->is_valid_number, '香川県三豊市三野町大見');
ok($zip->set_number('7670032')->is_valid_number, '香川県三豊市三野町下高瀬');
ok($zip->set_number('7670033')->is_valid_number, '香川県三豊市三野町吉津');
ok($zip->set_number('7680000')->is_valid_number, '香川県観音寺市以下に掲載がない場合');
ok($zip->set_number('7680001')->is_valid_number, '香川県観音寺市室本町');
ok($zip->set_number('7680002')->is_valid_number, '香川県観音寺市高屋町');
ok($zip->set_number('7680011')->is_valid_number, '香川県観音寺市出作町');
ok($zip->set_number('7680012')->is_valid_number, '香川県観音寺市植田町');
ok($zip->set_number('7680013')->is_valid_number, '香川県観音寺市村黒町');
ok($zip->set_number('7680014')->is_valid_number, '香川県観音寺市流岡町');
ok($zip->set_number('7680021')->is_valid_number, '香川県観音寺市吉岡町');
ok($zip->set_number('7680022')->is_valid_number, '香川県観音寺市本大町');
ok($zip->set_number('7680023')->is_valid_number, '香川県観音寺市古川町');
ok($zip->set_number('7680024')->is_valid_number, '香川県観音寺市中田井町');
ok($zip->set_number('7680031')->is_valid_number, '香川県観音寺市池之尻町');
ok($zip->set_number('7680032')->is_valid_number, '香川県観音寺市原町');
ok($zip->set_number('7680033')->is_valid_number, '香川県観音寺市新田町');
ok($zip->set_number('7680040')->is_valid_number, '香川県観音寺市柞田町');
ok($zip->set_number('7680051')->is_valid_number, '香川県観音寺市木之郷町');
ok($zip->set_number('7680052')->is_valid_number, '香川県観音寺市粟井町');
ok($zip->set_number('7680060')->is_valid_number, '香川県観音寺市観音寺町');
ok($zip->set_number('7680061')->is_valid_number, '香川県観音寺市八幡町');
ok($zip->set_number('7680062')->is_valid_number, '香川県観音寺市有明町');
ok($zip->set_number('7680063')->is_valid_number, '香川県観音寺市三本松町');
ok($zip->set_number('7680064')->is_valid_number, '香川県観音寺市琴浪町');
ok($zip->set_number('7680065')->is_valid_number, '香川県観音寺市瀬戸町');
ok($zip->set_number('7680066')->is_valid_number, '香川県観音寺市昭和町');
ok($zip->set_number('7680067')->is_valid_number, '香川県観音寺市坂本町');
ok($zip->set_number('7680068')->is_valid_number, '香川県観音寺市天神町');
ok($zip->set_number('7680069')->is_valid_number, '香川県観音寺市茂木町');
ok($zip->set_number('7680070')->is_valid_number, '香川県観音寺市南町');
ok($zip->set_number('7680071')->is_valid_number, '香川県観音寺市伊吹町');
ok($zip->set_number('7680072')->is_valid_number, '香川県観音寺市栄町');
ok($zip->set_number('7680073')->is_valid_number, '香川県観音寺市茂西町');
ok($zip->set_number('7680074')->is_valid_number, '香川県観音寺市幸町');
ok($zip->set_number('7680075')->is_valid_number, '香川県観音寺市西本町');
ok($zip->set_number('7680076')->is_valid_number, '香川県観音寺市港町');
ok($zip->set_number('7680077')->is_valid_number, '香川県観音寺市凪瀬町');
ok($zip->set_number('7680101')->is_valid_number, '香川県三豊市山本町辻');
ok($zip->set_number('7680102')->is_valid_number, '香川県三豊市山本町大野');
ok($zip->set_number('7680103')->is_valid_number, '香川県三豊市山本町財田西');
ok($zip->set_number('7680104')->is_valid_number, '香川県三豊市山本町神田');
ok($zip->set_number('7680105')->is_valid_number, '香川県三豊市山本町河内');
ok($zip->set_number('7690101')->is_valid_number, '香川県高松市国分寺町新居');
ok($zip->set_number('7690102')->is_valid_number, '香川県高松市国分寺町国分');
ok($zip->set_number('7690103')->is_valid_number, '香川県高松市国分寺町福家');
ok($zip->set_number('7690104')->is_valid_number, '香川県高松市国分寺町新名');
ok($zip->set_number('7690105')->is_valid_number, '香川県高松市国分寺町柏原');
ok($zip->set_number('7690200')->is_valid_number, '香川県綾歌郡宇多津町以下に掲載がない場合');
ok($zip->set_number('7690201')->is_valid_number, '香川県綾歌郡宇多津町浜一番丁');
ok($zip->set_number('7690202')->is_valid_number, '香川県綾歌郡宇多津町浜二番丁');
ok($zip->set_number('7690203')->is_valid_number, '香川県綾歌郡宇多津町浜三番丁');
ok($zip->set_number('7690204')->is_valid_number, '香川県綾歌郡宇多津町浜四番丁');
ok($zip->set_number('7690205')->is_valid_number, '香川県綾歌郡宇多津町浜五番丁');
ok($zip->set_number('7690206')->is_valid_number, '香川県綾歌郡宇多津町浜六番丁');
ok($zip->set_number('7690207')->is_valid_number, '香川県綾歌郡宇多津町浜七番丁');
ok($zip->set_number('7690208')->is_valid_number, '香川県綾歌郡宇多津町浜八番丁');
ok($zip->set_number('7690209')->is_valid_number, '香川県綾歌郡宇多津町浜九番丁');
ok($zip->set_number('7690210')->is_valid_number, '香川県綾歌郡宇多津町宇多津町の次に番地がくる場合');
ok($zip->set_number('7690211')->is_valid_number, '香川県綾歌郡宇多津町十楽寺');
ok($zip->set_number('7690212')->is_valid_number, '香川県綾歌郡宇多津町沼ノ池');
ok($zip->set_number('7690213')->is_valid_number, '香川県綾歌郡宇多津町東分');
ok($zip->set_number('7690221')->is_valid_number, '香川県綾歌郡宇多津町吉田');
ok($zip->set_number('7690222')->is_valid_number, '香川県綾歌郡宇多津町大橋');
ok($zip->set_number('7690223')->is_valid_number, '香川県綾歌郡宇多津町新開');
ok($zip->set_number('7690224')->is_valid_number, '香川県綾歌郡宇多津町平山');
ok($zip->set_number('7690225')->is_valid_number, '香川県綾歌郡宇多津町新町');
ok($zip->set_number('7690226')->is_valid_number, '香川県綾歌郡宇多津町坂下');
ok($zip->set_number('7690227')->is_valid_number, '香川県綾歌郡宇多津町岩屋');
ok($zip->set_number('7690228')->is_valid_number, '香川県綾歌郡宇多津町向山');
ok($zip->set_number('7690301')->is_valid_number, '香川県仲多度郡まんのう町佐文');
ok($zip->set_number('7690302')->is_valid_number, '香川県仲多度郡まんのう町塩入');
ok($zip->set_number('7690303')->is_valid_number, '香川県仲多度郡まんのう町七箇');
ok($zip->set_number('7690311')->is_valid_number, '香川県仲多度郡まんのう町買田');
ok($zip->set_number('7690312')->is_valid_number, '香川県仲多度郡まんのう町宮田');
ok($zip->set_number('7690313')->is_valid_number, '香川県仲多度郡まんのう町生間');
ok($zip->set_number('7690314')->is_valid_number, '香川県仲多度郡まんのう町帆山');
ok($zip->set_number('7690315')->is_valid_number, '香川県仲多度郡まんのう町後山');
ok($zip->set_number('7690316')->is_valid_number, '香川県仲多度郡まんのう町大口');
ok($zip->set_number('7690317')->is_valid_number, '香川県仲多度郡まんのう町新目');
ok($zip->set_number('7690318')->is_valid_number, '香川県仲多度郡まんのう町山脇');
ok($zip->set_number('7690319')->is_valid_number, '香川県仲多度郡まんのう町追上');
ok($zip->set_number('7690401')->is_valid_number, '香川県三豊市財田町財田上');
ok($zip->set_number('7690402')->is_valid_number, '香川県三豊市財田町財田中');
ok($zip->set_number('7691101')->is_valid_number, '香川県三豊市詫間町詫間');
ok($zip->set_number('7691102')->is_valid_number, '香川県三豊市詫間町松崎');
ok($zip->set_number('7691103')->is_valid_number, '香川県三豊市詫間町香田');
ok($zip->set_number('7691104')->is_valid_number, '香川県三豊市詫間町大浜');
ok($zip->set_number('7691105')->is_valid_number, '香川県三豊市詫間町積');
ok($zip->set_number('7691106')->is_valid_number, '香川県三豊市詫間町箱');
ok($zip->set_number('7691107')->is_valid_number, '香川県三豊市詫間町生里');
ok($zip->set_number('7691108')->is_valid_number, '香川県三豊市詫間町粟島');
ok($zip->set_number('7691109')->is_valid_number, '香川県三豊市詫間町志々島');
ok($zip->set_number('7691401')->is_valid_number, '香川県三豊市仁尾町仁尾己');
ok($zip->set_number('7691402')->is_valid_number, '香川県三豊市仁尾町仁尾戊');
ok($zip->set_number('7691403')->is_valid_number, '香川県三豊市仁尾町仁尾丙');
ok($zip->set_number('7691404')->is_valid_number, '香川県三豊市仁尾町仁尾乙');
ok($zip->set_number('7691405')->is_valid_number, '香川県三豊市仁尾町仁尾庚');
ok($zip->set_number('7691406')->is_valid_number, '香川県三豊市仁尾町仁尾辛');
ok($zip->set_number('7691407')->is_valid_number, '香川県三豊市仁尾町仁尾丁');
ok($zip->set_number('7691408')->is_valid_number, '香川県三豊市仁尾町仁尾甲');
ok($zip->set_number('7691410')->is_valid_number, '香川県三豊市仁尾町家の浦');
ok($zip->set_number('7691501')->is_valid_number, '香川県三豊市豊中町比地大');
ok($zip->set_number('7691502')->is_valid_number, '香川県三豊市豊中町笠田笠岡');
ok($zip->set_number('7691503')->is_valid_number, '香川県三豊市豊中町笠田竹田');
ok($zip->set_number('7691504')->is_valid_number, '香川県三豊市豊中町上高野');
ok($zip->set_number('7691505')->is_valid_number, '香川県三豊市豊中町本山乙');
ok($zip->set_number('7691506')->is_valid_number, '香川県三豊市豊中町本山甲');
ok($zip->set_number('7691507')->is_valid_number, '香川県三豊市豊中町岡本');
ok($zip->set_number('7691508')->is_valid_number, '香川県三豊市豊中町下高野');
ok($zip->set_number('7691601')->is_valid_number, '香川県観音寺市豊浜町姫浜');
ok($zip->set_number('7691602')->is_valid_number, '香川県観音寺市豊浜町和田浜');
ok($zip->set_number('7691603')->is_valid_number, '香川県観音寺市豊浜町和田');
ok($zip->set_number('7691604')->is_valid_number, '香川県観音寺市豊浜町箕浦');
ok($zip->set_number('7691611')->is_valid_number, '香川県観音寺市大野原町大野原');
ok($zip->set_number('7691612')->is_valid_number, '香川県観音寺市大野原町中姫');
ok($zip->set_number('7691613')->is_valid_number, '香川県観音寺市大野原町花稲');
ok($zip->set_number('7691614')->is_valid_number, '香川県観音寺市大野原町萩原');
ok($zip->set_number('7691615')->is_valid_number, '香川県観音寺市大野原町丸井');
ok($zip->set_number('7691616')->is_valid_number, '香川県観音寺市大野原町福田原');
ok($zip->set_number('7691617')->is_valid_number, '香川県観音寺市大野原町青岡');
ok($zip->set_number('7691621')->is_valid_number, '香川県観音寺市大野原町井関');
ok($zip->set_number('7691622')->is_valid_number, '香川県観音寺市大野原町内野々');
ok($zip->set_number('7691623')->is_valid_number, '香川県観音寺市大野原町田野々');
ok($zip->set_number('7691624')->is_valid_number, '香川県観音寺市大野原町有木');
ok($zip->set_number('7691625')->is_valid_number, '香川県観音寺市大野原町海老済');
ok($zip->set_number('7692101')->is_valid_number, '香川県さぬき市志度');
ok($zip->set_number('7692102')->is_valid_number, '香川県さぬき市鴨庄');
ok($zip->set_number('7692103')->is_valid_number, '香川県さぬき市小田');
ok($zip->set_number('7692104')->is_valid_number, '香川県さぬき市鴨部');
ok($zip->set_number('7692105')->is_valid_number, '香川県さぬき市末');
ok($zip->set_number('7692300')->is_valid_number, '香川県さぬき市以下に掲載がない場合');
ok($zip->set_number('7692301')->is_valid_number, '香川県さぬき市長尾東');
ok($zip->set_number('7692302')->is_valid_number, '香川県さぬき市長尾西');
ok($zip->set_number('7692303')->is_valid_number, '香川県さぬき市長尾名');
ok($zip->set_number('7692304')->is_valid_number, '香川県さぬき市昭和');
ok($zip->set_number('7692305')->is_valid_number, '香川県さぬき市前山');
ok($zip->set_number('7692306')->is_valid_number, '香川県さぬき市多和');
ok($zip->set_number('7692311')->is_valid_number, '香川県さぬき市造田宮西');
ok($zip->set_number('7692312')->is_valid_number, '香川県さぬき市造田是弘');
ok($zip->set_number('7692313')->is_valid_number, '香川県さぬき市造田野間田');
ok($zip->set_number('7692314')->is_valid_number, '香川県さぬき市造田乙井');
ok($zip->set_number('7692315')->is_valid_number, '香川県さぬき市造田(オレンジタウン)');
ok($zip->set_number('7692321')->is_valid_number, '香川県さぬき市寒川町石田東');
ok($zip->set_number('7692322')->is_valid_number, '香川県さぬき市寒川町石田西');
ok($zip->set_number('7692323')->is_valid_number, '香川県さぬき市寒川町神前');
ok($zip->set_number('7692401')->is_valid_number, '香川県さぬき市津田町津田');
ok($zip->set_number('7692402')->is_valid_number, '香川県さぬき市津田町鶴羽');
ok($zip->set_number('7692511')->is_valid_number, '香川県東かがわ市小磯');
ok($zip->set_number('7692512')->is_valid_number, '香川県東かがわ市落合');
ok($zip->set_number('7692513')->is_valid_number, '香川県東かがわ市大谷');
ok($zip->set_number('7692514')->is_valid_number, '香川県東かがわ市松崎');
ok($zip->set_number('7692515')->is_valid_number, '香川県東かがわ市町田');
ok($zip->set_number('7692516')->is_valid_number, '香川県東かがわ市土居');
ok($zip->set_number('7692517')->is_valid_number, '香川県東かがわ市三殿');
ok($zip->set_number('7692518')->is_valid_number, '香川県東かがわ市中山');
ok($zip->set_number('7692519')->is_valid_number, '香川県東かがわ市小砂');
ok($zip->set_number('7692520')->is_valid_number, '香川県東かがわ市馬篠');
ok($zip->set_number('7692521')->is_valid_number, '香川県東かがわ市大内');
ok($zip->set_number('7692601')->is_valid_number, '香川県東かがわ市三本松');
ok($zip->set_number('7692602')->is_valid_number, '香川県東かがわ市川東');
ok($zip->set_number('7692603')->is_valid_number, '香川県東かがわ市横内');
ok($zip->set_number('7692604')->is_valid_number, '香川県東かがわ市西村');
ok($zip->set_number('7692605')->is_valid_number, '香川県東かがわ市中筋');
ok($zip->set_number('7692606')->is_valid_number, '香川県東かがわ市水主');
ok($zip->set_number('7692700')->is_valid_number, '香川県東かがわ市以下に掲載がない場合');
ok($zip->set_number('7692701')->is_valid_number, '香川県東かがわ市湊');
ok($zip->set_number('7692702')->is_valid_number, '香川県東かがわ市松原');
ok($zip->set_number('7692703')->is_valid_number, '香川県東かがわ市伊座');
ok($zip->set_number('7692704')->is_valid_number, '香川県東かがわ市帰来');
ok($zip->set_number('7692705')->is_valid_number, '香川県東かがわ市白鳥');
ok($zip->set_number('7692711')->is_valid_number, '香川県東かがわ市東山');
ok($zip->set_number('7692712')->is_valid_number, '香川県東かがわ市西山');
ok($zip->set_number('7692713')->is_valid_number, '香川県東かがわ市与田山');
ok($zip->set_number('7692714')->is_valid_number, '香川県東かがわ市入野山');
ok($zip->set_number('7692715')->is_valid_number, '香川県東かがわ市五名');
ok($zip->set_number('7692901')->is_valid_number, '香川県東かがわ市引田');
ok($zip->set_number('7692902')->is_valid_number, '香川県東かがわ市馬宿');
ok($zip->set_number('7692903')->is_valid_number, '香川県東かがわ市南野');
ok($zip->set_number('7692904')->is_valid_number, '香川県東かがわ市坂元');
ok($zip->set_number('7692905')->is_valid_number, '香川県東かがわ市黒羽');
ok($zip->set_number('7692906')->is_valid_number, '香川県東かがわ市川股');
ok($zip->set_number('7692907')->is_valid_number, '香川県東かがわ市吉田');
ok($zip->set_number('7692908')->is_valid_number, '香川県東かがわ市小海');
ok($zip->set_number('7700000')->is_valid_number, '徳島県徳島市以下に掲載がない場合');
ok($zip->set_number('7700001')->is_valid_number, '徳島県徳島市春日町');
ok($zip->set_number('7700002')->is_valid_number, '徳島県徳島市春日');
ok($zip->set_number('7700003')->is_valid_number, '徳島県徳島市北田宮');
ok($zip->set_number('7700004')->is_valid_number, '徳島県徳島市南田宮');
ok($zip->set_number('7700005')->is_valid_number, '徳島県徳島市南矢三町');
ok($zip->set_number('7700006')->is_valid_number, '徳島県徳島市北矢三町');
ok($zip->set_number('7700011')->is_valid_number, '徳島県徳島市北佐古一番町');
ok($zip->set_number('7700012')->is_valid_number, '徳島県徳島市北佐古二番町');
ok($zip->set_number('7700021')->is_valid_number, '徳島県徳島市佐古一番町');
ok($zip->set_number('7700022')->is_valid_number, '徳島県徳島市佐古二番町');
ok($zip->set_number('7700023')->is_valid_number, '徳島県徳島市佐古三番町');
ok($zip->set_number('7700024')->is_valid_number, '徳島県徳島市佐古四番町');
ok($zip->set_number('7700025')->is_valid_number, '徳島県徳島市佐古五番町');
ok($zip->set_number('7700026')->is_valid_number, '徳島県徳島市佐古六番町');
ok($zip->set_number('7700027')->is_valid_number, '徳島県徳島市佐古七番町');
ok($zip->set_number('7700028')->is_valid_number, '徳島県徳島市佐古八番町');
ok($zip->set_number('7700031')->is_valid_number, '徳島県徳島市南佐古一番町');
ok($zip->set_number('7700032')->is_valid_number, '徳島県徳島市南佐古二番町');
ok($zip->set_number('7700033')->is_valid_number, '徳島県徳島市南佐古三番町');
ok($zip->set_number('7700034')->is_valid_number, '徳島県徳島市南佐古四番町');
ok($zip->set_number('7700035')->is_valid_number, '徳島県徳島市南佐古五番町');
ok($zip->set_number('7700036')->is_valid_number, '徳島県徳島市南佐古六番町');
ok($zip->set_number('7700037')->is_valid_number, '徳島県徳島市南佐古七番町');
ok($zip->set_number('7700038')->is_valid_number, '徳島県徳島市南佐古八番町');
ok($zip->set_number('7700039')->is_valid_number, '徳島県徳島市佐古山町');
ok($zip->set_number('7700041')->is_valid_number, '徳島県徳島市蔵本元町');
ok($zip->set_number('7700042')->is_valid_number, '徳島県徳島市蔵本町');
ok($zip->set_number('7700043')->is_valid_number, '徳島県徳島市南蔵本町');
ok($zip->set_number('7700044')->is_valid_number, '徳島県徳島市庄町');
ok($zip->set_number('7700045')->is_valid_number, '徳島県徳島市南庄町');
ok($zip->set_number('7700046')->is_valid_number, '徳島県徳島市鮎喰町');
ok($zip->set_number('7700047')->is_valid_number, '徳島県徳島市名東町');
ok($zip->set_number('7700048')->is_valid_number, '徳島県徳島市加茂名町');
ok($zip->set_number('7700051')->is_valid_number, '徳島県徳島市北島田町');
ok($zip->set_number('7700052')->is_valid_number, '徳島県徳島市中島田町');
ok($zip->set_number('7700053')->is_valid_number, '徳島県徳島市南島田町');
ok($zip->set_number('7700061')->is_valid_number, '徳島県徳島市不動北町');
ok($zip->set_number('7700062')->is_valid_number, '徳島県徳島市不動東町');
ok($zip->set_number('7700063')->is_valid_number, '徳島県徳島市不動本町');
ok($zip->set_number('7700064')->is_valid_number, '徳島県徳島市不動西町');
ok($zip->set_number('7700801')->is_valid_number, '徳島県徳島市上助任町');
ok($zip->set_number('7700802')->is_valid_number, '徳島県徳島市吉野本町');
ok($zip->set_number('7700803')->is_valid_number, '徳島県徳島市上吉野町');
ok($zip->set_number('7700804')->is_valid_number, '徳島県徳島市中吉野町');
ok($zip->set_number('7700805')->is_valid_number, '徳島県徳島市下助任町');
ok($zip->set_number('7700806')->is_valid_number, '徳島県徳島市北前川町');
ok($zip->set_number('7700807')->is_valid_number, '徳島県徳島市中前川町');
ok($zip->set_number('7700808')->is_valid_number, '徳島県徳島市南前川町');
ok($zip->set_number('7700811')->is_valid_number, '徳島県徳島市東吉野町');
ok($zip->set_number('7700812')->is_valid_number, '徳島県徳島市北常三島町');
ok($zip->set_number('7700813')->is_valid_number, '徳島県徳島市中常三島町');
ok($zip->set_number('7700814')->is_valid_number, '徳島県徳島市南常三島町');
ok($zip->set_number('7700815')->is_valid_number, '徳島県徳島市助任橋');
ok($zip->set_number('7700816')->is_valid_number, '徳島県徳島市助任本町');
ok($zip->set_number('7700821')->is_valid_number, '徳島県徳島市北出来島町');
ok($zip->set_number('7700822')->is_valid_number, '徳島県徳島市東出来島町');
ok($zip->set_number('7700823')->is_valid_number, '徳島県徳島市出来島本町');
ok($zip->set_number('7700824')->is_valid_number, '徳島県徳島市南出来島町');
ok($zip->set_number('7700831')->is_valid_number, '徳島県徳島市寺島本町西');
ok($zip->set_number('7700832')->is_valid_number, '徳島県徳島市寺島本町東');
ok($zip->set_number('7700833')->is_valid_number, '徳島県徳島市一番町');
ok($zip->set_number('7700834')->is_valid_number, '徳島県徳島市元町');
ok($zip->set_number('7700835')->is_valid_number, '徳島県徳島市藍場町');
ok($zip->set_number('7700841')->is_valid_number, '徳島県徳島市八百屋町');
ok($zip->set_number('7700842')->is_valid_number, '徳島県徳島市通町');
ok($zip->set_number('7700843')->is_valid_number, '徳島県徳島市両国本町');
ok($zip->set_number('7700844')->is_valid_number, '徳島県徳島市中通町');
ok($zip->set_number('7700845')->is_valid_number, '徳島県徳島市新内町');
ok($zip->set_number('7700846')->is_valid_number, '徳島県徳島市南内町');
ok($zip->set_number('7700847')->is_valid_number, '徳島県徳島市幸町');
ok($zip->set_number('7700851')->is_valid_number, '徳島県徳島市徳島町城内');
ok($zip->set_number('7700852')->is_valid_number, '徳島県徳島市徳島町');
ok($zip->set_number('7700853')->is_valid_number, '徳島県徳島市中徳島町');
ok($zip->set_number('7700854')->is_valid_number, '徳島県徳島市徳島本町');
ok($zip->set_number('7700855')->is_valid_number, '徳島県徳島市新蔵町');
ok($zip->set_number('7700856')->is_valid_number, '徳島県徳島市中洲町');
ok($zip->set_number('7700861')->is_valid_number, '徳島県徳島市住吉');
ok($zip->set_number('7700862')->is_valid_number, '徳島県徳島市城東町');
ok($zip->set_number('7700863')->is_valid_number, '徳島県徳島市安宅');
ok($zip->set_number('7700864')->is_valid_number, '徳島県徳島市大和町');
ok($zip->set_number('7700865')->is_valid_number, '徳島県徳島市南末広町');
ok($zip->set_number('7700866')->is_valid_number, '徳島県徳島市末広');
ok($zip->set_number('7700867')->is_valid_number, '徳島県徳島市新南福島');
ok($zip->set_number('7700868')->is_valid_number, '徳島県徳島市福島');
ok($zip->set_number('7700871')->is_valid_number, '徳島県徳島市金沢');
ok($zip->set_number('7700872')->is_valid_number, '徳島県徳島市北沖洲');
ok($zip->set_number('7700873')->is_valid_number, '徳島県徳島市東沖洲');
ok($zip->set_number('7700874')->is_valid_number, '徳島県徳島市南沖洲');
ok($zip->set_number('7700901')->is_valid_number, '徳島県徳島市西船場町');
ok($zip->set_number('7700902')->is_valid_number, '徳島県徳島市西新町');
ok($zip->set_number('7700903')->is_valid_number, '徳島県徳島市西大工町');
ok($zip->set_number('7700904')->is_valid_number, '徳島県徳島市新町橋');
ok($zip->set_number('7700905')->is_valid_number, '徳島県徳島市東大工町');
ok($zip->set_number('7700906')->is_valid_number, '徳島県徳島市東山手町');
ok($zip->set_number('7700907')->is_valid_number, '徳島県徳島市西山手町');
ok($zip->set_number('7700908')->is_valid_number, '徳島県徳島市眉山町');
ok($zip->set_number('7700909')->is_valid_number, '徳島県徳島市寺町');
ok($zip->set_number('7700911')->is_valid_number, '徳島県徳島市東船場町');
ok($zip->set_number('7700912')->is_valid_number, '徳島県徳島市東新町');
ok($zip->set_number('7700913')->is_valid_number, '徳島県徳島市南新町');
ok($zip->set_number('7700914')->is_valid_number, '徳島県徳島市籠屋町');
ok($zip->set_number('7700915')->is_valid_number, '徳島県徳島市富田町');
ok($zip->set_number('7700916')->is_valid_number, '徳島県徳島市銀座');
ok($zip->set_number('7700917')->is_valid_number, '徳島県徳島市両国橋');
ok($zip->set_number('7700918')->is_valid_number, '徳島県徳島市紺屋町');
ok($zip->set_number('7700921')->is_valid_number, '徳島県徳島市栄町');
ok($zip->set_number('7700922')->is_valid_number, '徳島県徳島市鷹匠町');
ok($zip->set_number('7700923')->is_valid_number, '徳島県徳島市大道');
ok($zip->set_number('7700924')->is_valid_number, '徳島県徳島市幟町');
ok($zip->set_number('7700925')->is_valid_number, '徳島県徳島市弓町');
ok($zip->set_number('7700926')->is_valid_number, '徳島県徳島市伊賀町');
ok($zip->set_number('7700927')->is_valid_number, '徳島県徳島市勢見町');
ok($zip->set_number('7700928')->is_valid_number, '徳島県徳島市二軒屋町');
ok($zip->set_number('7700929')->is_valid_number, '徳島県徳島市西富田町');
ok($zip->set_number('7700931')->is_valid_number, '徳島県徳島市富田浜');
ok($zip->set_number('7700932')->is_valid_number, '徳島県徳島市仲之町');
ok($zip->set_number('7700933')->is_valid_number, '徳島県徳島市南仲之町');
ok($zip->set_number('7700934')->is_valid_number, '徳島県徳島市秋田町');
ok($zip->set_number('7700935')->is_valid_number, '徳島県徳島市伊月町');
ok($zip->set_number('7700936')->is_valid_number, '徳島県徳島市中央通');
ok($zip->set_number('7700937')->is_valid_number, '徳島県徳島市富田橋');
ok($zip->set_number('7700938')->is_valid_number, '徳島県徳島市明神町');
ok($zip->set_number('7700939')->is_valid_number, '徳島県徳島市かちどき橋');
ok($zip->set_number('7700941')->is_valid_number, '徳島県徳島市万代町');
ok($zip->set_number('7700942')->is_valid_number, '徳島県徳島市昭和町');
ok($zip->set_number('7700943')->is_valid_number, '徳島県徳島市中昭和町');
ok($zip->set_number('7700944')->is_valid_number, '徳島県徳島市南昭和町');
ok($zip->set_number('7708001')->is_valid_number, '徳島県徳島市津田海岸町');
ok($zip->set_number('7708002')->is_valid_number, '徳島県徳島市津田町');
ok($zip->set_number('7708003')->is_valid_number, '徳島県徳島市津田本町');
ok($zip->set_number('7708004')->is_valid_number, '徳島県徳島市津田西町');
ok($zip->set_number('7708005')->is_valid_number, '徳島県徳島市津田浜之町');
ok($zip->set_number('7708006')->is_valid_number, '徳島県徳島市新浜町');
ok($zip->set_number('7708007')->is_valid_number, '徳島県徳島市新浜本町');
ok($zip->set_number('7708008')->is_valid_number, '徳島県徳島市西新浜町');
ok($zip->set_number('7708011')->is_valid_number, '徳島県徳島市論田町');
ok($zip->set_number('7708012')->is_valid_number, '徳島県徳島市大原町(その他)');
ok($zip->set_number('7708021')->is_valid_number, '徳島県徳島市雑賀町');
ok($zip->set_number('7708022')->is_valid_number, '徳島県徳島市大松町');
ok($zip->set_number('7708023')->is_valid_number, '徳島県徳島市勝占町');
ok($zip->set_number('7708024')->is_valid_number, '徳島県徳島市西須賀町');
ok($zip->set_number('7708025')->is_valid_number, '徳島県徳島市三軒屋町');
ok($zip->set_number('7708031')->is_valid_number, '徳島県徳島市大谷町');
ok($zip->set_number('7708032')->is_valid_number, '徳島県徳島市北山町');
ok($zip->set_number('7708033')->is_valid_number, '徳島県徳島市方上町');
ok($zip->set_number('7708040')->is_valid_number, '徳島県徳島市上八万町(その他)');
ok($zip->set_number('7708041')->is_valid_number, '徳島県徳島市上八万町西山(しらさぎ台)');
ok($zip->set_number('7708051')->is_valid_number, '徳島県徳島市沖浜町');
ok($zip->set_number('7708052')->is_valid_number, '徳島県徳島市沖浜');
ok($zip->set_number('7708053')->is_valid_number, '徳島県徳島市沖浜東');
ok($zip->set_number('7708054')->is_valid_number, '徳島県徳島市山城西');
ok($zip->set_number('7708055')->is_valid_number, '徳島県徳島市山城町');
ok($zip->set_number('7708056')->is_valid_number, '徳島県徳島市問屋町');
ok($zip->set_number('7708061')->is_valid_number, '徳島県徳島市西二軒屋町');
ok($zip->set_number('7708063')->is_valid_number, '徳島県徳島市南二軒屋町');
ok($zip->set_number('7708064')->is_valid_number, '徳島県徳島市城南町');
ok($zip->set_number('7708070')->is_valid_number, '徳島県徳島市八万町(その他)');
ok($zip->set_number('7708071')->is_valid_number, '徳島県徳島市八万町(中津山)');
ok($zip->set_number('7708072')->is_valid_number, '徳島県徳島市八万町(中津浦)');
ok($zip->set_number('7708073')->is_valid_number, '徳島県徳島市八万町(上福万)');
ok($zip->set_number('7708074')->is_valid_number, '徳島県徳島市八万町(下福万)');
ok($zip->set_number('7708075')->is_valid_number, '徳島県徳島市八万町(千鳥)');
ok($zip->set_number('7708076')->is_valid_number, '徳島県徳島市八万町(内浜)');
ok($zip->set_number('7708077')->is_valid_number, '徳島県徳島市八万町(夷山)');
ok($zip->set_number('7708078')->is_valid_number, '徳島県徳島市八万町(橋本)');
ok($zip->set_number('7708079')->is_valid_number, '徳島県徳島市八万町(大坪)');
ok($zip->set_number('7708081')->is_valid_number, '徳島県徳島市八万町(弐丈)');
ok($zip->set_number('7708082')->is_valid_number, '徳島県徳島市八万町(川南)');
ok($zip->set_number('7708083')->is_valid_number, '徳島県徳島市八万町(法花)');
ok($zip->set_number('7708084')->is_valid_number, '徳島県徳島市八万町(法花谷)');
ok($zip->set_number('7710101')->is_valid_number, '徳島県徳島市川内町(旭野)');
ok($zip->set_number('7710102')->is_valid_number, '徳島県徳島市川内町(小松北)');
ok($zip->set_number('7710103')->is_valid_number, '徳島県徳島市川内町(小松東)');
ok($zip->set_number('7710104')->is_valid_number, '徳島県徳島市川内町(小松西)');
ok($zip->set_number('7710105')->is_valid_number, '徳島県徳島市川内町(下別宮西)');
ok($zip->set_number('7710106')->is_valid_number, '徳島県徳島市川内町(下別宮東)');
ok($zip->set_number('7710111')->is_valid_number, '徳島県徳島市川内町(富久)');
ok($zip->set_number('7710112')->is_valid_number, '徳島県徳島市川内町(富吉)');
ok($zip->set_number('7710113')->is_valid_number, '徳島県徳島市川内町(松岡)');
ok($zip->set_number('7710114')->is_valid_number, '徳島県徳島市川内町(宮島本浦)');
ok($zip->set_number('7710115')->is_valid_number, '徳島県徳島市川内町(宮島浜)');
ok($zip->set_number('7710116')->is_valid_number, '徳島県徳島市川内町(宮島錦野)');
ok($zip->set_number('7710117')->is_valid_number, '徳島県徳島市川内町(鶴島)');
ok($zip->set_number('7710121')->is_valid_number, '徳島県徳島市川内町(鈴江東)');
ok($zip->set_number('7710122')->is_valid_number, '徳島県徳島市川内町(鈴江西)');
ok($zip->set_number('7710123')->is_valid_number, '徳島県徳島市川内町(鈴江北)');
ok($zip->set_number('7710124')->is_valid_number, '徳島県徳島市川内町(鈴江南)');
ok($zip->set_number('7710125')->is_valid_number, '徳島県徳島市川内町(金岡)');
ok($zip->set_number('7710126')->is_valid_number, '徳島県徳島市川内町(上別宮東)');
ok($zip->set_number('7710127')->is_valid_number, '徳島県徳島市川内町(上別宮南)');
ok($zip->set_number('7710128')->is_valid_number, '徳島県徳島市川内町(上別宮北)');
ok($zip->set_number('7710129')->is_valid_number, '徳島県徳島市川内町(北原)');
ok($zip->set_number('7710130')->is_valid_number, '徳島県徳島市川内町(加賀須野)');
ok($zip->set_number('7710131')->is_valid_number, '徳島県徳島市川内町(大松)');
ok($zip->set_number('7710132')->is_valid_number, '徳島県徳島市川内町(平石夷野)');
ok($zip->set_number('7710133')->is_valid_number, '徳島県徳島市川内町(平石夷野番外)');
ok($zip->set_number('7710134')->is_valid_number, '徳島県徳島市川内町(平石住吉)');
ok($zip->set_number('7710135')->is_valid_number, '徳島県徳島市川内町(平石若松)');
ok($zip->set_number('7710136')->is_valid_number, '徳島県徳島市川内町(平石古田)');
ok($zip->set_number('7710137')->is_valid_number, '徳島県徳島市川内町(平石若宮)');
ok($zip->set_number('7710138')->is_valid_number, '徳島県徳島市川内町(平石流通団地)');
ok($zip->set_number('7710139')->is_valid_number, '徳島県徳島市川内町(米津)');
ok($zip->set_number('7710141')->is_valid_number, '徳島県徳島市川内町(竹須賀)');
ok($zip->set_number('7710142')->is_valid_number, '徳島県徳島市川内町(沖島)');
ok($zip->set_number('7710143')->is_valid_number, '徳島県徳島市川内町(中島)');
ok($zip->set_number('7710144')->is_valid_number, '徳島県徳島市川内町(榎瀬)');
ok($zip->set_number('7710200')->is_valid_number, '徳島県板野郡松茂町以下に掲載がない場合');
ok($zip->set_number('7710200')->is_valid_number, '徳島県板野郡北島町以下に掲載がない場合');
ok($zip->set_number('7710201')->is_valid_number, '徳島県板野郡北島町北村');
ok($zip->set_number('7710202')->is_valid_number, '徳島県板野郡北島町太郎八須');
ok($zip->set_number('7710203')->is_valid_number, '徳島県板野郡北島町中村');
ok($zip->set_number('7710204')->is_valid_number, '徳島県板野郡北島町鯛浜');
ok($zip->set_number('7710205')->is_valid_number, '徳島県板野郡北島町江尻');
ok($zip->set_number('7710206')->is_valid_number, '徳島県板野郡北島町高房');
ok($zip->set_number('7710207')->is_valid_number, '徳島県板野郡北島町新喜来');
ok($zip->set_number('7710211')->is_valid_number, '徳島県板野郡松茂町長岸');
ok($zip->set_number('7710212')->is_valid_number, '徳島県板野郡松茂町中喜来');
ok($zip->set_number('7710213')->is_valid_number, '徳島県板野郡松茂町豊久');
ok($zip->set_number('7710214')->is_valid_number, '徳島県板野郡松茂町満穂');
ok($zip->set_number('7710215')->is_valid_number, '徳島県板野郡松茂町豊岡');
ok($zip->set_number('7710216')->is_valid_number, '徳島県板野郡松茂町長原');
ok($zip->set_number('7710217')->is_valid_number, '徳島県板野郡松茂町豊中');
ok($zip->set_number('7710218')->is_valid_number, '徳島県板野郡松茂町住吉');
ok($zip->set_number('7710219')->is_valid_number, '徳島県板野郡松茂町笹木野');
ok($zip->set_number('7710220')->is_valid_number, '徳島県板野郡松茂町広島');
ok($zip->set_number('7710360')->is_valid_number, '徳島県鳴門市瀬戸町明神(その他)');
ok($zip->set_number('7710361')->is_valid_number, '徳島県鳴門市瀬戸町堂浦');
ok($zip->set_number('7710362')->is_valid_number, '徳島県鳴門市瀬戸町北泊(小海)');
ok($zip->set_number('7710363')->is_valid_number, '徳島県鳴門市瀬戸町湊谷');
ok($zip->set_number('7710364')->is_valid_number, '徳島県鳴門市瀬戸町北泊(その他)');
ok($zip->set_number('7710365')->is_valid_number, '徳島県鳴門市瀬戸町小島田');
ok($zip->set_number('7710366')->is_valid_number, '徳島県鳴門市瀬戸町中島田');
ok($zip->set_number('7710367')->is_valid_number, '徳島県鳴門市瀬戸町大島田');
ok($zip->set_number('7710368')->is_valid_number, '徳島県鳴門市瀬戸町室');
ok($zip->set_number('7710369')->is_valid_number, '徳島県鳴門市瀬戸町撫佐');
ok($zip->set_number('7710371')->is_valid_number, '徳島県鳴門市北灘町櫛木');
ok($zip->set_number('7710372')->is_valid_number, '徳島県鳴門市北灘町粟田');
ok($zip->set_number('7710373')->is_valid_number, '徳島県鳴門市北灘町大浦');
ok($zip->set_number('7710374')->is_valid_number, '徳島県鳴門市北灘町宿毛谷');
ok($zip->set_number('7710375')->is_valid_number, '徳島県鳴門市北灘町鳥ケ丸');
ok($zip->set_number('7710376')->is_valid_number, '徳島県鳴門市北灘町折野');
ok($zip->set_number('7710377')->is_valid_number, '徳島県鳴門市北灘町大須');
ok($zip->set_number('7710378')->is_valid_number, '徳島県鳴門市北灘町碁浦');
ok($zip->set_number('7711151')->is_valid_number, '徳島県徳島市応神町古川');
ok($zip->set_number('7711152')->is_valid_number, '徳島県徳島市応神町中原');
ok($zip->set_number('7711153')->is_valid_number, '徳島県徳島市応神町吉成');
ok($zip->set_number('7711154')->is_valid_number, '徳島県徳島市応神町東貞方');
ok($zip->set_number('7711155')->is_valid_number, '徳島県徳島市応神町西貞方');
ok($zip->set_number('7711156')->is_valid_number, '徳島県徳島市応神町応神産業団地');
ok($zip->set_number('7711200')->is_valid_number, '徳島県板野郡藍住町以下に掲載がない場合');
ok($zip->set_number('7711201')->is_valid_number, '徳島県板野郡藍住町奥野(その他)');
ok($zip->set_number('7711202')->is_valid_number, '徳島県板野郡藍住町奥野(猪熊)');
ok($zip->set_number('7711202')->is_valid_number, '徳島県板野郡藍住町奥野(東中須)');
ok($zip->set_number('7711202')->is_valid_number, '徳島県板野郡藍住町奥野(前川)');
ok($zip->set_number('7711202')->is_valid_number, '徳島県板野郡藍住町奥野(和田)');
ok($zip->set_number('7711203')->is_valid_number, '徳島県板野郡藍住町奥野(矢上前)');
ok($zip->set_number('7711210')->is_valid_number, '徳島県板野郡藍住町徳命(その他)');
ok($zip->set_number('7711211')->is_valid_number, '徳島県板野郡藍住町徳命(元村)');
ok($zip->set_number('7711211')->is_valid_number, '徳島県板野郡藍住町徳命(元村東)');
ok($zip->set_number('7711212')->is_valid_number, '徳島県板野郡藍住町徳命(前須東)');
ok($zip->set_number('7711212')->is_valid_number, '徳島県板野郡藍住町徳命(前須西)');
ok($zip->set_number('7711220')->is_valid_number, '徳島県板野郡藍住町東中富(その他)');
ok($zip->set_number('7711221')->is_valid_number, '徳島県板野郡藍住町東中富(長江傍示)');
ok($zip->set_number('7711222')->is_valid_number, '徳島県板野郡藍住町東中富(北傍示)');
ok($zip->set_number('7711223')->is_valid_number, '徳島県板野郡藍住町東中富(敷地傍示)');
ok($zip->set_number('7711223')->is_valid_number, '徳島県板野郡藍住町東中富(天王傍示)');
ok($zip->set_number('7711224')->is_valid_number, '徳島県板野郡藍住町東中富(大塚傍示)');
ok($zip->set_number('7711224')->is_valid_number, '徳島県板野郡藍住町東中富(慶長)');
ok($zip->set_number('7711224')->is_valid_number, '徳島県板野郡藍住町東中富(貞享)');
ok($zip->set_number('7711224')->is_valid_number, '徳島県板野郡藍住町東中富(東安永)');
ok($zip->set_number('7711224')->is_valid_number, '徳島県板野郡藍住町東中富(西安永)');
ok($zip->set_number('7711224')->is_valid_number, '徳島県板野郡藍住町東中富(鑓場傍示)');
ok($zip->set_number('7711230')->is_valid_number, '徳島県板野郡藍住町富吉(その他)');
ok($zip->set_number('7711231')->is_valid_number, '徳島県板野郡藍住町富吉(須崎)');
ok($zip->set_number('7711231')->is_valid_number, '徳島県板野郡藍住町富吉(富吉)');
ok($zip->set_number('7711231')->is_valid_number, '徳島県板野郡藍住町富吉(豊吉)');
ok($zip->set_number('7711232')->is_valid_number, '徳島県板野郡藍住町富吉(地神)');
ok($zip->set_number('7711232')->is_valid_number, '徳島県板野郡藍住町富吉(穂実)');
ok($zip->set_number('7711240')->is_valid_number, '徳島県板野郡藍住町乙瀬');
ok($zip->set_number('7711250')->is_valid_number, '徳島県板野郡藍住町矢上(その他)');
ok($zip->set_number('7711251')->is_valid_number, '徳島県板野郡藍住町矢上(西)');
ok($zip->set_number('7711251')->is_valid_number, '徳島県板野郡藍住町矢上(原)');
ok($zip->set_number('7711252')->is_valid_number, '徳島県板野郡藍住町矢上(春日)');
ok($zip->set_number('7711252')->is_valid_number, '徳島県板野郡藍住町矢上(北分)');
ok($zip->set_number('7711253')->is_valid_number, '徳島県板野郡藍住町矢上(江ノ口)');
ok($zip->set_number('7711253')->is_valid_number, '徳島県板野郡藍住町矢上(安任)');
ok($zip->set_number('7711260')->is_valid_number, '徳島県板野郡藍住町笠木(その他)');
ok($zip->set_number('7711261')->is_valid_number, '徳島県板野郡藍住町笠木(東野)');
ok($zip->set_number('7711262')->is_valid_number, '徳島県板野郡藍住町笠木(中野)');
ok($zip->set_number('7711262')->is_valid_number, '徳島県板野郡藍住町笠木(西野)');
ok($zip->set_number('7711264')->is_valid_number, '徳島県板野郡藍住町住吉(その他)');
ok($zip->set_number('7711265')->is_valid_number, '徳島県板野郡藍住町住吉(逆藤)');
ok($zip->set_number('7711265')->is_valid_number, '徳島県板野郡藍住町住吉(神蔵)');
ok($zip->set_number('7711265')->is_valid_number, '徳島県板野郡藍住町住吉(千鳥ケ浜)');
ok($zip->set_number('7711266')->is_valid_number, '徳島県板野郡藍住町住吉(藤ノ木)');
ok($zip->set_number('7711266')->is_valid_number, '徳島県板野郡藍住町住吉(若宮)');
ok($zip->set_number('7711267')->is_valid_number, '徳島県板野郡藍住町住吉(乾)');
ok($zip->set_number('7711267')->is_valid_number, '徳島県板野郡藍住町住吉(江端)');
ok($zip->set_number('7711270')->is_valid_number, '徳島県板野郡藍住町勝瑞(その他)');
ok($zip->set_number('7711271')->is_valid_number, '徳島県板野郡藍住町勝瑞(幸島)');
ok($zip->set_number('7711272')->is_valid_number, '徳島県板野郡藍住町勝瑞(成長)');
ok($zip->set_number('7711273')->is_valid_number, '徳島県板野郡藍住町勝瑞(正喜地)');
ok($zip->set_number('7711273')->is_valid_number, '徳島県板野郡藍住町勝瑞(東勝地)');
ok($zip->set_number('7711300')->is_valid_number, '徳島県板野郡上板町以下に掲載がない場合');
ok($zip->set_number('7711301')->is_valid_number, '徳島県板野郡上板町鍛冶屋原');
ok($zip->set_number('7711302')->is_valid_number, '徳島県板野郡上板町七條');
ok($zip->set_number('7711310')->is_valid_number, '徳島県板野郡上板町泉谷');
ok($zip->set_number('7711311')->is_valid_number, '徳島県板野郡上板町引野');
ok($zip->set_number('7711320')->is_valid_number, '徳島県板野郡上板町神宅');
ok($zip->set_number('7711330')->is_valid_number, '徳島県板野郡上板町西分');
ok($zip->set_number('7711341')->is_valid_number, '徳島県板野郡上板町第十新田');
ok($zip->set_number('7711342')->is_valid_number, '徳島県板野郡上板町佐藤塚');
ok($zip->set_number('7711343')->is_valid_number, '徳島県板野郡上板町椎本');
ok($zip->set_number('7711344')->is_valid_number, '徳島県板野郡上板町下六條');
ok($zip->set_number('7711345')->is_valid_number, '徳島県板野郡上板町上六條');
ok($zip->set_number('7711346')->is_valid_number, '徳島県板野郡上板町高磯');
ok($zip->set_number('7711347')->is_valid_number, '徳島県板野郡上板町高瀬');
ok($zip->set_number('7711350')->is_valid_number, '徳島県板野郡上板町瀬部');
ok($zip->set_number('7711401')->is_valid_number, '徳島県阿波市吉野町柿原');
ok($zip->set_number('7711402')->is_valid_number, '徳島県阿波市吉野町西条');
ok($zip->set_number('7711403')->is_valid_number, '徳島県阿波市吉野町五条');
ok($zip->set_number('7711501')->is_valid_number, '徳島県阿波市土成町秋月');
ok($zip->set_number('7711502')->is_valid_number, '徳島県阿波市土成町水田');
ok($zip->set_number('7711503')->is_valid_number, '徳島県阿波市土成町浦池');
ok($zip->set_number('7711504')->is_valid_number, '徳島県阿波市土成町成当');
ok($zip->set_number('7711505')->is_valid_number, '徳島県阿波市土成町郡');
ok($zip->set_number('7711506')->is_valid_number, '徳島県阿波市土成町土成');
ok($zip->set_number('7711507')->is_valid_number, '徳島県阿波市土成町吉田');
ok($zip->set_number('7711508')->is_valid_number, '徳島県阿波市土成町宮川内');
ok($zip->set_number('7711509')->is_valid_number, '徳島県阿波市土成町高尾');
ok($zip->set_number('7711601')->is_valid_number, '徳島県阿波市市場町市場(興崎)');
ok($zip->set_number('7711602')->is_valid_number, '徳島県阿波市市場町市場(上野段)');
ok($zip->set_number('7711603')->is_valid_number, '徳島県阿波市市場町市場(岸ノ下)');
ok($zip->set_number('7711604')->is_valid_number, '徳島県阿波市市場町市場(町筋)');
ok($zip->set_number('7711610')->is_valid_number, '徳島県阿波市市場町香美(その他)');
ok($zip->set_number('7711611')->is_valid_number, '徳島県阿波市市場町香美(北香美)');
ok($zip->set_number('7711612')->is_valid_number, '徳島県阿波市市場町上喜来');
ok($zip->set_number('7711613')->is_valid_number, '徳島県阿波市市場町大俣');
ok($zip->set_number('7711614')->is_valid_number, '徳島県阿波市市場町犬墓(その他)');
ok($zip->set_number('7711615')->is_valid_number, '徳島県阿波市市場町大影');
ok($zip->set_number('7711616')->is_valid_number, '徳島県阿波市市場町日開谷');
ok($zip->set_number('7711621')->is_valid_number, '徳島県阿波市市場町尾開');
ok($zip->set_number('7711622')->is_valid_number, '徳島県阿波市市場町興崎');
ok($zip->set_number('7711623')->is_valid_number, '徳島県阿波市市場町切幡');
ok($zip->set_number('7711624')->is_valid_number, '徳島県阿波市市場町山野上');
ok($zip->set_number('7711625')->is_valid_number, '徳島県阿波市市場町八幡');
ok($zip->set_number('7711626')->is_valid_number, '徳島県阿波市市場町伊月');
ok($zip->set_number('7711627')->is_valid_number, '徳島県阿波市市場町大野島');
ok($zip->set_number('7711700')->is_valid_number, '徳島県阿波市以下に掲載がない場合');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町伊沢市');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町王地');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町王地南');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町大坪');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町大原');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町大道南');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町勝命');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町勝命北');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町庚申原');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町下喜来');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町下喜来南');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町新開');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町清原');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町谷島');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町谷島北');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町西清原');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町平川原北');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町平川原南');
ok($zip->set_number('7711701')->is_valid_number, '徳島県阿波市阿波町南谷島');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町伊勢');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町井出口');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町稲荷');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町大久保');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町柏谷左右');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町川添');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町北ノ名');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町山王');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町四歩一');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町下原');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町大次郎');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町谷口');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町寺サコ');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町天西山');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町西ノ岡');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町野神');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町久原');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町本町');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町本安');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町森沢');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町安政');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町山尻');
ok($zip->set_number('7711702')->is_valid_number, '徳島県阿波市阿波町早田');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町伊沢田');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町大道北');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町岡地');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町北柴生');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町北原');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町真福寺');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町綱懸');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町東条');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町中原');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町西柴生');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町西原');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町東柴生');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町東原');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町前島');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町丸山');
ok($zip->set_number('7711703')->is_valid_number, '徳島県阿波市阿波町南柴生');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町伊沢谷東縁');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町糸下');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町芋場');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町梅ノ木原');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町梅ノ東');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町小倉');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町亀底');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町北久保');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町北五味知');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町北正広');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町立割');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町西正広');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町八丁原');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町東正広');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町引地');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町広野');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町真重');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町南五味知');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町元町');
ok($zip->set_number('7711704')->is_valid_number, '徳島県阿波市阿波町山ノ神');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町赤坂');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町医王寺');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町居屋敷');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町梅川内');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町王子川');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町川久保');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町北整理');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町北山');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町五明');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町桜ノ岡');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町寒風');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町十善地');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町善地');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町高垣');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町栩ケ窪');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町馬場');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町日吉谷');
ok($zip->set_number('7711705')->is_valid_number, '徳島県阿波市阿波町松川内');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町岩津');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町植桜');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町乙岩津');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町北岡');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町北西谷');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町三本柳');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町中川原');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町中坪');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町中長峰');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町西島');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町西整理');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町西長峰');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町西林');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町東川原');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町東島');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町東整理');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町東長峰');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町東村');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町南川原');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町南整理');
ok($zip->set_number('7711706')->is_valid_number, '徳島県阿波市阿波町南西谷');
ok($zip->set_number('7711714')->is_valid_number, '徳島県阿波市市場町犬墓(小竹)');
ok($zip->set_number('7712101')->is_valid_number, '徳島県美馬市美馬町(入倉、大久保、切久保、正部、丈寄、清田)');
ok($zip->set_number('7712102')->is_valid_number, '徳島県美馬市美馬町(家ノ前、大池、大上、大北、大佐古、大前、岡ノ内、押上、茅原、');
ok($zip->set_number('7712102')->is_valid_number, '徳島県美馬市川ノ上、観音、栗林、黒砂、狙ケ内、猿坂、下白地、白地、炭釜、芹佐古、惣後、');
ok($zip->set_number('7712102')->is_valid_number, '徳島県美馬市惣田、外墓、滝ノ上、立見山、田ノ岡、狙坂、中岡、中野田ノ井、中横尾、長地、');
ok($zip->set_number('7712102')->is_valid_number, '徳島県美馬市西浦、西ノ谷、野田ノ井、橋谷、場シ所、東筋、平尾、平野、藤宇、前坂、');
ok($zip->set_number('7712102')->is_valid_number, '徳島県美馬市水ノ岡、味噌ケ久保、道ノ上、宮ノ岡、南畠、薬師ケ久保、山西屋敷、');
ok($zip->set_number('7712102')->is_valid_number, '徳島県美馬市山橋谷、横尾)');
ok($zip->set_number('7712103')->is_valid_number, '徳島県美馬市美馬町(一ノ宮、後谷、倉尾、三頭山、下後谷、高惣、谷尻、');
ok($zip->set_number('7712103')->is_valid_number, '徳島県美馬市露口、中沼田、中野、夏弥喜、ナロヲ、西大久保、西沼田、沼田、八ノ坪、');
ok($zip->set_number('7712103')->is_valid_number, '徳島県美馬市坊ケ谷、水久保、宗ノ分、屋内)');
ok($zip->set_number('7712104')->is_valid_number, '徳島県美馬市美馬町(鵜飼口、岡、小長谷、小長谷端、笠仏、川縁、荒神、助松、高畑、辰角、');
ok($zip->set_number('7712104')->is_valid_number, '徳島県美馬市谷頭、玉振前、チゲジ、天神東、轟、中黒、中須、中道北、中道南、ノツゴ、');
ok($zip->set_number('7712104')->is_valid_number, '徳島県美馬市ノリコヘ、橋本、東岸ノ下、東段、東宗重、坊僧、丸山、南原、明神原、');
ok($zip->set_number('7712104')->is_valid_number, '徳島県美馬市宗重、薬師)');
ok($zip->set_number('7712105')->is_valid_number, '徳島県美馬市美馬町(池ノ浦、銀杏木、梅ケ久保、駅、蛭子、柿木、鍵掛、願勝寺、');
ok($zip->set_number('7712105')->is_valid_number, '徳島県美馬市北土ケ久保、喜入道、滝宮、土ケ久保、西段、宮東、宮西、宮南、養泉)');
ok($zip->set_number('7712106')->is_valid_number, '徳島県美馬市美馬町(荒川、井出縁、井ノ神、大泉、大宮西、上突出、岸ノ下、北東原、');
ok($zip->set_number('7712106')->is_valid_number, '徳島県美馬市喜来市、里平野、下突出、谷ヨリ西、乳ノ木、寺ノ下、天神、天神北、中東原、');
ok($zip->set_number('7712106')->is_valid_number, '徳島県美馬市西荒川、沼田島、東荒川、南荒川、南東原、妙見、山嫁坂)');
ok($zip->set_number('7712107')->is_valid_number, '徳島県美馬市美馬町(雨下、上野、小原、境目、里西屋敷、下ノ段、城、滝下、竹ノ内、田辺、');
ok($zip->set_number('7712107')->is_valid_number, '徳島県美馬市谷口、栂尾、突落、中尾、中耕地、中筋、中通、中西、中山、長畑、夏蕨、');
ok($zip->set_number('7712107')->is_valid_number, '徳島県美馬市西宮ノ上、東宮ノ上、細野、前田、松ノ花、松ノ本、宮前、宮北、八幡、');
ok($zip->set_number('7712107')->is_valid_number, '徳島県美馬市山夏蕨、吉水)');
ok($zip->set_number('7712301')->is_valid_number, '徳島県三好市三野町清水');
ok($zip->set_number('7712302')->is_valid_number, '徳島県三好市三野町加茂野宮');
ok($zip->set_number('7712303')->is_valid_number, '徳島県三好市三野町勢力');
ok($zip->set_number('7712304')->is_valid_number, '徳島県三好市三野町芝生');
ok($zip->set_number('7712305')->is_valid_number, '徳島県三好市三野町太刀野');
ok($zip->set_number('7712306')->is_valid_number, '徳島県三好市三野町太刀野山');
ok($zip->set_number('7712501')->is_valid_number, '徳島県三好郡東みよし町昼間');
ok($zip->set_number('7712502')->is_valid_number, '徳島県三好郡東みよし町足代');
ok($zip->set_number('7712503')->is_valid_number, '徳島県三好郡東みよし町東山');
ok($zip->set_number('7713200')->is_valid_number, '徳島県名西郡神山町以下に掲載がない場合');
ok($zip->set_number('7713201')->is_valid_number, '徳島県名西郡神山町阿野(その他)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(石堂)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(井ノ谷)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(宇度木)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(上河内)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(川平)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(黒木)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(駒坂)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(地ノ平)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(神木)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(須賀)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(長瀬)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(長代)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(二ノ宮)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(日浦)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(東代次)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(広石)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(福原)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(府中)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(船底)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(本名)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(松尾)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(宮分)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(屋那瀬)');
ok($zip->set_number('7713202')->is_valid_number, '徳島県名西郡神山町阿野(代次)');
ok($zip->set_number('7713203')->is_valid_number, '徳島県名西郡神山町鬼籠野');
ok($zip->set_number('7713310')->is_valid_number, '徳島県名西郡神山町神領(その他)');
ok($zip->set_number('7713311')->is_valid_number, '徳島県名西郡神山町神領(石堂)');
ok($zip->set_number('7713311')->is_valid_number, '徳島県名西郡神山町神領(川北)');
ok($zip->set_number('7713311')->is_valid_number, '徳島県名西郡神山町神領(北)');
ok($zip->set_number('7713311')->is_valid_number, '徳島県名西郡神山町神領(谷)');
ok($zip->set_number('7713311')->is_valid_number, '徳島県名西郡神山町神領(東野間)');
ok($zip->set_number('7713311')->is_valid_number, '徳島県名西郡神山町神領(西野間)');
ok($zip->set_number('7713311')->is_valid_number, '徳島県名西郡神山町神領(本野間)');
ok($zip->set_number('7713421')->is_valid_number, '徳島県名西郡神山町下分');
ok($zip->set_number('7713422')->is_valid_number, '徳島県名西郡神山町上分');
ok($zip->set_number('7714100')->is_valid_number, '徳島県名東郡佐那河内村以下に掲載がない場合');
ok($zip->set_number('7714101')->is_valid_number, '徳島県名東郡佐那河内村下');
ok($zip->set_number('7714102')->is_valid_number, '徳島県名東郡佐那河内村上');
ok($zip->set_number('7714261')->is_valid_number, '徳島県徳島市丈六町(その他)');
ok($zip->set_number('7714262')->is_valid_number, '徳島県徳島市丈六町(長尾)');
ok($zip->set_number('7714263')->is_valid_number, '徳島県徳島市丈六町(丈領)');
ok($zip->set_number('7714264')->is_valid_number, '徳島県徳島市多家良町');
ok($zip->set_number('7714265')->is_valid_number, '徳島県徳島市飯谷町');
ok($zip->set_number('7714266')->is_valid_number, '徳島県徳島市八多町');
ok($zip->set_number('7714267')->is_valid_number, '徳島県徳島市渋野町');
ok($zip->set_number('7714300')->is_valid_number, '徳島県勝浦郡勝浦町以下に掲載がない場合');
ok($zip->set_number('7714301')->is_valid_number, '徳島県勝浦郡勝浦町沼江');
ok($zip->set_number('7714302')->is_valid_number, '徳島県勝浦郡勝浦町中角');
ok($zip->set_number('7714303')->is_valid_number, '徳島県勝浦郡勝浦町生名');
ok($zip->set_number('7714304')->is_valid_number, '徳島県勝浦郡勝浦町星谷');
ok($zip->set_number('7714305')->is_valid_number, '徳島県勝浦郡勝浦町久国');
ok($zip->set_number('7714306')->is_valid_number, '徳島県勝浦郡勝浦町棚野');
ok($zip->set_number('7714307')->is_valid_number, '徳島県勝浦郡勝浦町三渓');
ok($zip->set_number('7714308')->is_valid_number, '徳島県勝浦郡勝浦町坂本');
ok($zip->set_number('7714500')->is_valid_number, '徳島県勝浦郡上勝町以下に掲載がない場合');
ok($zip->set_number('7714501')->is_valid_number, '徳島県勝浦郡上勝町福原');
ok($zip->set_number('7714502')->is_valid_number, '徳島県勝浦郡上勝町旭');
ok($zip->set_number('7714503')->is_valid_number, '徳島県勝浦郡上勝町生実');
ok($zip->set_number('7714504')->is_valid_number, '徳島県勝浦郡上勝町傍示');
ok($zip->set_number('7714505')->is_valid_number, '徳島県勝浦郡上勝町正木');
ok($zip->set_number('7715170')->is_valid_number, '徳島県阿南市楠根町');
ok($zip->set_number('7715171')->is_valid_number, '徳島県阿南市熊谷町');
ok($zip->set_number('7715172')->is_valid_number, '徳島県阿南市吉井町');
ok($zip->set_number('7715173')->is_valid_number, '徳島県阿南市加茂町');
ok($zip->set_number('7715174')->is_valid_number, '徳島県阿南市水井町');
ok($zip->set_number('7715175')->is_valid_number, '徳島県阿南市細野町');
ok($zip->set_number('7715176')->is_valid_number, '徳島県阿南市大田井町');
ok($zip->set_number('7715177')->is_valid_number, '徳島県阿南市大井町');
ok($zip->set_number('7715178')->is_valid_number, '徳島県阿南市十八女町');
ok($zip->set_number('7715179')->is_valid_number, '徳島県阿南市深瀬町');
ok($zip->set_number('7715200')->is_valid_number, '徳島県那賀郡那賀町以下に掲載がない場合');
ok($zip->set_number('7715201')->is_valid_number, '徳島県那賀郡那賀町和食');
ok($zip->set_number('7715202')->is_valid_number, '徳島県那賀郡那賀町土佐');
ok($zip->set_number('7715203')->is_valid_number, '徳島県那賀郡那賀町和食郷');
ok($zip->set_number('7715204')->is_valid_number, '徳島県那賀郡那賀町中山');
ok($zip->set_number('7715205')->is_valid_number, '徳島県那賀郡那賀町百合谷');
ok($zip->set_number('7715206')->is_valid_number, '徳島県那賀郡那賀町百合');
ok($zip->set_number('7715207')->is_valid_number, '徳島県那賀郡那賀町阿井');
ok($zip->set_number('7715208')->is_valid_number, '徳島県那賀郡那賀町仁宇');
ok($zip->set_number('7715209')->is_valid_number, '徳島県那賀郡那賀町小仁宇');
ok($zip->set_number('7715320')->is_valid_number, '徳島県那賀郡那賀町榎谷');
ok($zip->set_number('7715321')->is_valid_number, '徳島県那賀郡那賀町馬路');
ok($zip->set_number('7715322')->is_valid_number, '徳島県那賀郡那賀町谷内');
ok($zip->set_number('7715323')->is_valid_number, '徳島県那賀郡那賀町相名');
ok($zip->set_number('7715324')->is_valid_number, '徳島県那賀郡那賀町井ノ谷');
ok($zip->set_number('7715325')->is_valid_number, '徳島県那賀郡那賀町平野');
ok($zip->set_number('7715326')->is_valid_number, '徳島県那賀郡那賀町内山');
ok($zip->set_number('7715327')->is_valid_number, '徳島県那賀郡那賀町西納');
ok($zip->set_number('7715328')->is_valid_number, '徳島県那賀郡那賀町請ノ谷');
ok($zip->set_number('7715329')->is_valid_number, '徳島県那賀郡那賀町竹ケ谷');
ok($zip->set_number('7715401')->is_valid_number, '徳島県那賀郡那賀町朝生');
ok($zip->set_number('7715402')->is_valid_number, '徳島県那賀郡那賀町簗ノ上');
ok($zip->set_number('7715403')->is_valid_number, '徳島県那賀郡那賀町鮎川');
ok($zip->set_number('7715404')->is_valid_number, '徳島県那賀郡那賀町牛輪');
ok($zip->set_number('7715405')->is_valid_number, '徳島県那賀郡那賀町入野');
ok($zip->set_number('7715406')->is_valid_number, '徳島県那賀郡那賀町延野');
ok($zip->set_number('7715407')->is_valid_number, '徳島県那賀郡那賀町雄');
ok($zip->set_number('7715408')->is_valid_number, '徳島県那賀郡那賀町吉野');
ok($zip->set_number('7715409')->is_valid_number, '徳島県那賀郡那賀町鉢');
ok($zip->set_number('7715410')->is_valid_number, '徳島県那賀郡那賀町大久保');
ok($zip->set_number('7715411')->is_valid_number, '徳島県那賀郡那賀町横石');
ok($zip->set_number('7715412')->is_valid_number, '徳島県那賀郡那賀町朴野');
ok($zip->set_number('7715413')->is_valid_number, '徳島県那賀郡那賀町蔭谷');
ok($zip->set_number('7715501')->is_valid_number, '徳島県那賀郡那賀町音谷');
ok($zip->set_number('7715502')->is_valid_number, '徳島県那賀郡那賀町桜谷');
ok($zip->set_number('7715503')->is_valid_number, '徳島県那賀郡那賀町小浜');
ok($zip->set_number('7715504')->is_valid_number, '徳島県那賀郡那賀町臼ケ谷');
ok($zip->set_number('7715505')->is_valid_number, '徳島県那賀郡那賀町長安');
ok($zip->set_number('7715506')->is_valid_number, '徳島県那賀郡那賀町桧曽根');
ok($zip->set_number('7715507')->is_valid_number, '徳島県那賀郡那賀町菖蒲');
ok($zip->set_number('7715508')->is_valid_number, '徳島県那賀郡那賀町東尾');
ok($zip->set_number('7715511')->is_valid_number, '徳島県那賀郡那賀町水崎');
ok($zip->set_number('7715512')->is_valid_number, '徳島県那賀郡那賀町小計');
ok($zip->set_number('7715513')->is_valid_number, '徳島県那賀郡那賀町古屋');
ok($zip->set_number('7715514')->is_valid_number, '徳島県那賀郡那賀町深森');
ok($zip->set_number('7715515')->is_valid_number, '徳島県那賀郡那賀町川俣');
ok($zip->set_number('7715516')->is_valid_number, '徳島県那賀郡那賀町大戸');
ok($zip->set_number('7715517')->is_valid_number, '徳島県那賀郡那賀町日真');
ok($zip->set_number('7715518')->is_valid_number, '徳島県那賀郡那賀町拝宮');
ok($zip->set_number('7715531')->is_valid_number, '徳島県那賀郡那賀町日浦');
ok($zip->set_number('7715532')->is_valid_number, '徳島県那賀郡那賀町花瀬');
ok($zip->set_number('7716101')->is_valid_number, '徳島県那賀郡那賀町阿津江');
ok($zip->set_number('7716102')->is_valid_number, '徳島県那賀郡那賀町木頭名');
ok($zip->set_number('7716103')->is_valid_number, '徳島県那賀郡那賀町出羽');
ok($zip->set_number('7716104')->is_valid_number, '徳島県那賀郡那賀町当山');
ok($zip->set_number('7716105')->is_valid_number, '徳島県那賀郡那賀町木頭');
ok($zip->set_number('7716106')->is_valid_number, '徳島県那賀郡那賀町坂州');
ok($zip->set_number('7716107')->is_valid_number, '徳島県那賀郡那賀町掛盤');
ok($zip->set_number('7716111')->is_valid_number, '徳島県那賀郡那賀町小泉');
ok($zip->set_number('7716112')->is_valid_number, '徳島県那賀郡那賀町高野');
ok($zip->set_number('7716113')->is_valid_number, '徳島県那賀郡那賀町寺内');
ok($zip->set_number('7716114')->is_valid_number, '徳島県那賀郡那賀町沢谷');
ok($zip->set_number('7716115')->is_valid_number, '徳島県那賀郡那賀町小畠');
ok($zip->set_number('7716116')->is_valid_number, '徳島県那賀郡那賀町横谷');
ok($zip->set_number('7716117')->is_valid_number, '徳島県那賀郡那賀町川成');
ok($zip->set_number('7716118')->is_valid_number, '徳島県那賀郡那賀町岩倉');
ok($zip->set_number('7716321')->is_valid_number, '徳島県那賀郡那賀町平谷');
ok($zip->set_number('7716322')->is_valid_number, '徳島県那賀郡那賀町大殿');
ok($zip->set_number('7716323')->is_valid_number, '徳島県那賀郡那賀町白石');
ok($zip->set_number('7716324')->is_valid_number, '徳島県那賀郡那賀町御所谷');
ok($zip->set_number('7716325')->is_valid_number, '徳島県那賀郡那賀町丈ケ谷');
ok($zip->set_number('7716326')->is_valid_number, '徳島県那賀郡那賀町府殿');
ok($zip->set_number('7716327')->is_valid_number, '徳島県那賀郡那賀町成瀬');
ok($zip->set_number('7716328')->is_valid_number, '徳島県那賀郡那賀町海川');
ok($zip->set_number('7716401')->is_valid_number, '徳島県那賀郡那賀町木頭助');
ok($zip->set_number('7716402')->is_valid_number, '徳島県那賀郡那賀町木頭出原');
ok($zip->set_number('7716403')->is_valid_number, '徳島県那賀郡那賀町木頭和無田');
ok($zip->set_number('7716404')->is_valid_number, '徳島県那賀郡那賀町木頭南宇');
ok($zip->set_number('7716405')->is_valid_number, '徳島県那賀郡那賀町木頭西宇');
ok($zip->set_number('7716511')->is_valid_number, '徳島県那賀郡那賀町木頭折宇');
ok($zip->set_number('7716512')->is_valid_number, '徳島県那賀郡那賀町木頭北川');
ok($zip->set_number('7720000')->is_valid_number, '徳島県鳴門市以下に掲載がない場合');
ok($zip->set_number('7720001')->is_valid_number, '徳島県鳴門市撫養町黒崎');
ok($zip->set_number('7720002')->is_valid_number, '徳島県鳴門市撫養町斎田');
ok($zip->set_number('7720003')->is_valid_number, '徳島県鳴門市撫養町南浜');
ok($zip->set_number('7720004')->is_valid_number, '徳島県鳴門市撫養町木津');
ok($zip->set_number('7720011')->is_valid_number, '徳島県鳴門市撫養町大桑島');
ok($zip->set_number('7720012')->is_valid_number, '徳島県鳴門市撫養町小桑島');
ok($zip->set_number('7720013')->is_valid_number, '徳島県鳴門市撫養町岡崎');
ok($zip->set_number('7720014')->is_valid_number, '徳島県鳴門市撫養町弁財天');
ok($zip->set_number('7720015')->is_valid_number, '徳島県鳴門市撫養町北浜');
ok($zip->set_number('7720016')->is_valid_number, '徳島県鳴門市撫養町林崎');
ok($zip->set_number('7720017')->is_valid_number, '徳島県鳴門市撫養町立岩');
ok($zip->set_number('7720021')->is_valid_number, '徳島県鳴門市里浦町里浦');
ok($zip->set_number('7720022')->is_valid_number, '徳島県鳴門市里浦町粟津');
ok($zip->set_number('7720031')->is_valid_number, '徳島県鳴門市大津町木津野');
ok($zip->set_number('7720032')->is_valid_number, '徳島県鳴門市大津町吉永');
ok($zip->set_number('7720033')->is_valid_number, '徳島県鳴門市大津町長江');
ok($zip->set_number('7720034')->is_valid_number, '徳島県鳴門市大津町徳長');
ok($zip->set_number('7720035')->is_valid_number, '徳島県鳴門市大津町矢倉');
ok($zip->set_number('7720041')->is_valid_number, '徳島県鳴門市大津町大代');
ok($zip->set_number('7720042')->is_valid_number, '徳島県鳴門市大津町備前島');
ok($zip->set_number('7720043')->is_valid_number, '徳島県鳴門市大津町段関');
ok($zip->set_number('7720044')->is_valid_number, '徳島県鳴門市大津町大幸');
ok($zip->set_number('7720051')->is_valid_number, '徳島県鳴門市鳴門町高島');
ok($zip->set_number('7720052')->is_valid_number, '徳島県鳴門市鳴門町三ツ石');
ok($zip->set_number('7720053')->is_valid_number, '徳島県鳴門市鳴門町土佐泊浦');
ok($zip->set_number('7720060')->is_valid_number, '徳島県鳴門市瀬戸町明神(楠谷、弐軒家、水汲谷)');
ok($zip->set_number('7730000')->is_valid_number, '徳島県小松島市以下に掲載がない場合');
ok($zip->set_number('7730001')->is_valid_number, '徳島県小松島市小松島町');
ok($zip->set_number('7730002')->is_valid_number, '徳島県小松島市神田瀬町');
ok($zip->set_number('7730003')->is_valid_number, '徳島県小松島市松島町');
ok($zip->set_number('7730004')->is_valid_number, '徳島県小松島市堀川町');
ok($zip->set_number('7730005')->is_valid_number, '徳島県小松島市南小松島町');
ok($zip->set_number('7730006')->is_valid_number, '徳島県小松島市横須町');
ok($zip->set_number('7730007')->is_valid_number, '徳島県小松島市金磯町');
ok($zip->set_number('7730008')->is_valid_number, '徳島県小松島市田野町');
ok($zip->set_number('7730009')->is_valid_number, '徳島県小松島市芝生町');
ok($zip->set_number('7730010')->is_valid_number, '徳島県小松島市日開野町');
ok($zip->set_number('7730011')->is_valid_number, '徳島県小松島市新居見町');
ok($zip->set_number('7730012')->is_valid_number, '徳島県小松島市田浦町');
ok($zip->set_number('7730013')->is_valid_number, '徳島県小松島市前原町');
ok($zip->set_number('7730014')->is_valid_number, '徳島県小松島市江田町');
ok($zip->set_number('7730015')->is_valid_number, '徳島県小松島市中田町');
ok($zip->set_number('7730016')->is_valid_number, '徳島県小松島市中郷町');
ok($zip->set_number('7730017')->is_valid_number, '徳島県小松島市立江町');
ok($zip->set_number('7730018')->is_valid_number, '徳島県小松島市櫛淵町');
ok($zip->set_number('7730019')->is_valid_number, '徳島県小松島市豊浦町');
ok($zip->set_number('7730020')->is_valid_number, '徳島県小松島市和田津開町');
ok($zip->set_number('7730021')->is_valid_number, '徳島県小松島市赤石町');
ok($zip->set_number('7730022')->is_valid_number, '徳島県小松島市大林町');
ok($zip->set_number('7730023')->is_valid_number, '徳島県小松島市坂野町');
ok($zip->set_number('7730024')->is_valid_number, '徳島県小松島市間新田町');
ok($zip->set_number('7730025')->is_valid_number, '徳島県小松島市和田島町(その他)');
ok($zip->set_number('7730031')->is_valid_number, '徳島県小松島市和田島町(松田新田)');
ok($zip->set_number('7730070')->is_valid_number, '徳島県徳島市大原町(小神子、小神子山)');
ok($zip->set_number('7740000')->is_valid_number, '徳島県阿南市以下に掲載がない場合');
ok($zip->set_number('7740001')->is_valid_number, '徳島県阿南市辰巳町');
ok($zip->set_number('7740002')->is_valid_number, '徳島県阿南市豊益町');
ok($zip->set_number('7740003')->is_valid_number, '徳島県阿南市畭町');
ok($zip->set_number('7740004')->is_valid_number, '徳島県阿南市福村町');
ok($zip->set_number('7740005')->is_valid_number, '徳島県阿南市向原町');
ok($zip->set_number('7740006')->is_valid_number, '徳島県阿南市黒津地町');
ok($zip->set_number('7740007')->is_valid_number, '徳島県阿南市出来町');
ok($zip->set_number('7740008')->is_valid_number, '徳島県阿南市原ケ崎町');
ok($zip->set_number('7740009')->is_valid_number, '徳島県阿南市西路見町');
ok($zip->set_number('7740011')->is_valid_number, '徳島県阿南市領家町');
ok($zip->set_number('7740012')->is_valid_number, '徳島県阿南市七見町');
ok($zip->set_number('7740013')->is_valid_number, '徳島県阿南市日開野町');
ok($zip->set_number('7740014')->is_valid_number, '徳島県阿南市学原町');
ok($zip->set_number('7740015')->is_valid_number, '徳島県阿南市才見町');
ok($zip->set_number('7740016')->is_valid_number, '徳島県阿南市中林町');
ok($zip->set_number('7740017')->is_valid_number, '徳島県阿南市見能林町');
ok($zip->set_number('7740021')->is_valid_number, '徳島県阿南市津乃峰町');
ok($zip->set_number('7740022')->is_valid_number, '徳島県阿南市大潟町');
ok($zip->set_number('7740023')->is_valid_number, '徳島県阿南市橘町(その他)');
ok($zip->set_number('7740030')->is_valid_number, '徳島県阿南市富岡町');
ok($zip->set_number('7740041')->is_valid_number, '徳島県阿南市住吉町');
ok($zip->set_number('7740042')->is_valid_number, '徳島県阿南市横見町');
ok($zip->set_number('7740043')->is_valid_number, '徳島県阿南市柳島町');
ok($zip->set_number('7740044')->is_valid_number, '徳島県阿南市上中町');
ok($zip->set_number('7740045')->is_valid_number, '徳島県阿南市宝田町');
ok($zip->set_number('7740046')->is_valid_number, '徳島県阿南市長生町');
ok($zip->set_number('7740047')->is_valid_number, '徳島県阿南市下大野町');
ok($zip->set_number('7740048')->is_valid_number, '徳島県阿南市中大野町');
ok($zip->set_number('7740049')->is_valid_number, '徳島県阿南市上大野町');
ok($zip->set_number('7741760')->is_valid_number, '徳島県阿南市伊島町');
ok($zip->set_number('7750000')->is_valid_number, '徳島県海部郡牟岐町以下に掲載がない場合');
ok($zip->set_number('7750001')->is_valid_number, '徳島県海部郡牟岐町河内');
ok($zip->set_number('7750002')->is_valid_number, '徳島県海部郡牟岐町橘');
ok($zip->set_number('7750003')->is_valid_number, '徳島県海部郡牟岐町辺川');
ok($zip->set_number('7750004')->is_valid_number, '徳島県海部郡牟岐町川長');
ok($zip->set_number('7750005')->is_valid_number, '徳島県海部郡牟岐町灘');
ok($zip->set_number('7750006')->is_valid_number, '徳島県海部郡牟岐町中村');
ok($zip->set_number('7750007')->is_valid_number, '徳島県海部郡牟岐町内妻');
ok($zip->set_number('7750010')->is_valid_number, '徳島県海部郡牟岐町牟岐浦(その他)');
ok($zip->set_number('7750011')->is_valid_number, '徳島県海部郡牟岐町牟岐浦(浜崎)');
ok($zip->set_number('7750012')->is_valid_number, '徳島県海部郡牟岐町牟岐浦(宮ノ本)');
ok($zip->set_number('7750013')->is_valid_number, '徳島県海部郡牟岐町牟岐浦(出羽島)');
ok($zip->set_number('7750101')->is_valid_number, '徳島県海部郡海陽町浅川');
ok($zip->set_number('7750200')->is_valid_number, '徳島県海部郡海陽町以下に掲載がない場合');
ok($zip->set_number('7750202')->is_valid_number, '徳島県海部郡海陽町四方原');
ok($zip->set_number('7750203')->is_valid_number, '徳島県海部郡海陽町大里');
ok($zip->set_number('7750204')->is_valid_number, '徳島県海部郡海陽町多良');
ok($zip->set_number('7750205')->is_valid_number, '徳島県海部郡海陽町吉野');
ok($zip->set_number('7750206')->is_valid_number, '徳島県海部郡海陽町熟田');
ok($zip->set_number('7750301')->is_valid_number, '徳島県海部郡海陽町鞆浦');
ok($zip->set_number('7750302')->is_valid_number, '徳島県海部郡海陽町奥浦');
ok($zip->set_number('7750303')->is_valid_number, '徳島県海部郡海陽町高園');
ok($zip->set_number('7750304')->is_valid_number, '徳島県海部郡海陽町野江');
ok($zip->set_number('7750305')->is_valid_number, '徳島県海部郡海陽町中山');
ok($zip->set_number('7750306')->is_valid_number, '徳島県海部郡海陽町櫛川');
ok($zip->set_number('7750307')->is_valid_number, '徳島県海部郡海陽町芝');
ok($zip->set_number('7750308')->is_valid_number, '徳島県海部郡海陽町吉田');
ok($zip->set_number('7750309')->is_valid_number, '徳島県海部郡海陽町富田');
ok($zip->set_number('7750310')->is_valid_number, '徳島県海部郡海陽町大井');
ok($zip->set_number('7750411')->is_valid_number, '徳島県海部郡海陽町平井');
ok($zip->set_number('7750412')->is_valid_number, '徳島県海部郡海陽町小川');
ok($zip->set_number('7750413')->is_valid_number, '徳島県海部郡海陽町神野');
ok($zip->set_number('7750414')->is_valid_number, '徳島県海部郡海陽町若松');
ok($zip->set_number('7750415')->is_valid_number, '徳島県海部郡海陽町相川');
ok($zip->set_number('7750501')->is_valid_number, '徳島県海部郡海陽町宍喰浦(その他)');
ok($zip->set_number('7750502')->is_valid_number, '徳島県海部郡海陽町久保');
ok($zip->set_number('7750503')->is_valid_number, '徳島県海部郡海陽町日比原');
ok($zip->set_number('7750504')->is_valid_number, '徳島県海部郡海陽町尾崎');
ok($zip->set_number('7750505')->is_valid_number, '徳島県海部郡海陽町芥附');
ok($zip->set_number('7750506')->is_valid_number, '徳島県海部郡海陽町角坂');
ok($zip->set_number('7750507')->is_valid_number, '徳島県海部郡海陽町広岡');
ok($zip->set_number('7750508')->is_valid_number, '徳島県海部郡海陽町小谷');
ok($zip->set_number('7750509')->is_valid_number, '徳島県海部郡海陽町塩深');
ok($zip->set_number('7750510')->is_valid_number, '徳島県海部郡海陽町船津');
ok($zip->set_number('7750511')->is_valid_number, '徳島県海部郡海陽町久尾');
ok($zip->set_number('7750512')->is_valid_number, '徳島県海部郡海陽町宍喰浦(那佐)');
ok($zip->set_number('7750513')->is_valid_number, '徳島県海部郡海陽町宍喰浦(竹ケ島)');
ok($zip->set_number('7760000')->is_valid_number, '徳島県吉野川市以下に掲載がない場合');
ok($zip->set_number('7760001')->is_valid_number, '徳島県吉野川市鴨島町牛島');
ok($zip->set_number('7760002')->is_valid_number, '徳島県吉野川市鴨島町麻植塚');
ok($zip->set_number('7760003')->is_valid_number, '徳島県吉野川市鴨島町内原');
ok($zip->set_number('7760004')->is_valid_number, '徳島県吉野川市鴨島町中島');
ok($zip->set_number('7760005')->is_valid_number, '徳島県吉野川市鴨島町喜来');
ok($zip->set_number('7760006')->is_valid_number, '徳島県吉野川市鴨島町喜来甲');
ok($zip->set_number('7760007')->is_valid_number, '徳島県吉野川市鴨島町喜来乙');
ok($zip->set_number('7760010')->is_valid_number, '徳島県吉野川市鴨島町鴨島');
ok($zip->set_number('7760011')->is_valid_number, '徳島県吉野川市鴨島町鴨島甲');
ok($zip->set_number('7760012')->is_valid_number, '徳島県吉野川市鴨島町鴨島乙');
ok($zip->set_number('7760013')->is_valid_number, '徳島県吉野川市鴨島町上下島');
ok($zip->set_number('7760014')->is_valid_number, '徳島県吉野川市鴨島町知恵島');
ok($zip->set_number('7760015')->is_valid_number, '徳島県吉野川市鴨島町粟島');
ok($zip->set_number('7760020')->is_valid_number, '徳島県吉野川市鴨島町西麻植');
ok($zip->set_number('7760031')->is_valid_number, '徳島県吉野川市鴨島町敷地');
ok($zip->set_number('7760032')->is_valid_number, '徳島県吉野川市鴨島町樋山地');
ok($zip->set_number('7760033')->is_valid_number, '徳島県吉野川市鴨島町飯尾');
ok($zip->set_number('7760034')->is_valid_number, '徳島県吉野川市鴨島町呉郷団地');
ok($zip->set_number('7760035')->is_valid_number, '徳島県吉野川市鴨島町森藤');
ok($zip->set_number('7760036')->is_valid_number, '徳島県吉野川市鴨島町山路');
ok($zip->set_number('7760037')->is_valid_number, '徳島県吉野川市鴨島町上浦');
ok($zip->set_number('7770001')->is_valid_number, '徳島県美馬市穴吹町三島(小島)');
ok($zip->set_number('7770002')->is_valid_number, '徳島県美馬市穴吹町三島(舞中島)');
ok($zip->set_number('7770003')->is_valid_number, '徳島県美馬市穴吹町三島(三谷)');
ok($zip->set_number('7770004')->is_valid_number, '徳島県美馬市穴吹町三島(大重)');
ok($zip->set_number('7770005')->is_valid_number, '徳島県美馬市穴吹町穴吹');
ok($zip->set_number('7770006')->is_valid_number, '徳島県美馬市穴吹町口山');
ok($zip->set_number('7770007')->is_valid_number, '徳島県美馬市穴吹町古宮');
ok($zip->set_number('7770301')->is_valid_number, '徳島県美馬市木屋平(市初、今丸、尾山、カゴミ、樫原、木中、桑柄、ケヤキヒラ、小日浦、');
ok($zip->set_number('7770301')->is_valid_number, '徳島県美馬市地神滝、菅蔵、杖谷、葛尾、ハジコノ、ビヤガイチ、二戸、三ツ木、貢、');
ok($zip->set_number('7770301')->is_valid_number, '徳島県美馬市南張、向樫原)');
ok($zip->set_number('7770302')->is_valid_number, '徳島県美馬市木屋平(麻衣、大北、川井、下名、竹尾、櫟木)');
ok($zip->set_number('7770303')->is_valid_number, '徳島県美馬市木屋平(川上、川上カケ、太合、太合カケ、谷口、谷口カケ、森遠、八幡、弓道)');
ok($zip->set_number('7780000')->is_valid_number, '徳島県三好市以下に掲載がない場合');
ok($zip->set_number('7780001')->is_valid_number, '徳島県三好市池田町ウエノ');
ok($zip->set_number('7780002')->is_valid_number, '徳島県三好市池田町マチ');
ok($zip->set_number('7780003')->is_valid_number, '徳島県三好市池田町サラダ');
ok($zip->set_number('7780004')->is_valid_number, '徳島県三好市池田町シンマチ');
ok($zip->set_number('7780005')->is_valid_number, '徳島県三好市池田町シマ');
ok($zip->set_number('7780006')->is_valid_number, '徳島県三好市池田町トウゲ');
ok($zip->set_number('7780007')->is_valid_number, '徳島県三好市池田町ヤマダ');
ok($zip->set_number('7780008')->is_valid_number, '徳島県三好市池田町クヤウジ');
ok($zip->set_number('7780009')->is_valid_number, '徳島県三好市池田町ヤサン');
ok($zip->set_number('7780010')->is_valid_number, '徳島県三好市池田町ウエマツ');
ok($zip->set_number('7780011')->is_valid_number, '徳島県三好市池田町ハヤシ');
ok($zip->set_number('7780012')->is_valid_number, '徳島県三好市池田町イケミナミ');
ok($zip->set_number('7780013')->is_valid_number, '徳島県三好市池田町シンヤマ');
ok($zip->set_number('7780014')->is_valid_number, '徳島県三好市池田町イタノ');
ok($zip->set_number('7780020')->is_valid_number, '徳島県三好市池田町州津');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(上久保)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(落)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(上中尾)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(谷浦)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(津寺)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(坪尻)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(中尾)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(西ノ岡)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(船原)');
ok($zip->set_number('7780031')->is_valid_number, '徳島県三好市池田町西山(横佐古)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(蔭)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(樫ノ下)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(岸ノ上)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(込野)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(下ノ浦)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(乳ノ木)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(乳ノ木道北)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(中塚)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(西谷)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(登リ尾)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(宮ノ西)');
ok($zip->set_number('7780032')->is_valid_number, '徳島県三好市池田町西山(宮ノ東)');
ok($zip->set_number('7780040')->is_valid_number, '徳島県三好市池田町西山(その他)');
ok($zip->set_number('7780101')->is_valid_number, '徳島県三好市西祖谷山村一宇');
ok($zip->set_number('7780101')->is_valid_number, '徳島県三好市西祖谷山村尾井ノ内');
ok($zip->set_number('7780101')->is_valid_number, '徳島県三好市西祖谷山村重末');
ok($zip->set_number('7780101')->is_valid_number, '徳島県三好市西祖谷山村田ノ内');
ok($zip->set_number('7780101')->is_valid_number, '徳島県三好市西祖谷山村戸ノ谷');
ok($zip->set_number('7780101')->is_valid_number, '徳島県三好市西祖谷山村眠谷');
ok($zip->set_number('7780101')->is_valid_number, '徳島県三好市西祖谷山村冥地');
ok($zip->set_number('7780102')->is_valid_number, '徳島県三好市西祖谷山村今久保');
ok($zip->set_number('7780102')->is_valid_number, '徳島県三好市西祖谷山村閑定');
ok($zip->set_number('7780102')->is_valid_number, '徳島県三好市西祖谷山村善徳');
ok($zip->set_number('7780102')->is_valid_number, '徳島県三好市西祖谷山村中尾');
ok($zip->set_number('7780103')->is_valid_number, '徳島県三好市西祖谷山村有瀬');
ok($zip->set_number('7780104')->is_valid_number, '徳島県三好市西祖谷山村吾橋');
ok($zip->set_number('7780104')->is_valid_number, '徳島県三好市西祖谷山村榎');
ok($zip->set_number('7780104')->is_valid_number, '徳島県三好市西祖谷山村上吾橋');
ok($zip->set_number('7780104')->is_valid_number, '徳島県三好市西祖谷山村下吾橋');
ok($zip->set_number('7780104')->is_valid_number, '徳島県三好市西祖谷山村土日浦');
ok($zip->set_number('7780104')->is_valid_number, '徳島県三好市西祖谷山村東山');
ok($zip->set_number('7780104')->is_valid_number, '徳島県三好市西祖谷山村南山');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村後山');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村後山西');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村後山向');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村徳善');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村徳善北');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村徳善西');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村西岡');
ok($zip->set_number('7780105')->is_valid_number, '徳島県三好市西祖谷山村東西岡');
ok($zip->set_number('7780165')->is_valid_number, '徳島県三好市池田町松尾(祖谷温泉、松本367-2番地)');
ok($zip->set_number('7780201')->is_valid_number, '徳島県三好市東祖谷菅生');
ok($zip->set_number('7780201')->is_valid_number, '徳島県三好市東祖谷見ノ越');
ok($zip->set_number('7780202')->is_valid_number, '徳島県三好市東祖谷落合');
ok($zip->set_number('7780202')->is_valid_number, '徳島県三好市東祖谷久保');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷奥の井');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷釜ケ谷');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷九鬼');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷栗枝渡');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷下瀬');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷中上');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷西山');
ok($zip->set_number('7780203')->is_valid_number, '徳島県三好市東祖谷林');
ok($zip->set_number('7780204')->is_valid_number, '徳島県三好市東祖谷大枝');
ok($zip->set_number('7780204')->is_valid_number, '徳島県三好市東祖谷大西');
ok($zip->set_number('7780204')->is_valid_number, '徳島県三好市東祖谷京上');
ok($zip->set_number('7780204')->is_valid_number, '徳島県三好市東祖谷若林');
ok($zip->set_number('7780205')->is_valid_number, '徳島県三好市東祖谷阿佐');
ok($zip->set_number('7780205')->is_valid_number, '徳島県三好市東祖谷小川');
ok($zip->set_number('7780205')->is_valid_number, '徳島県三好市東祖谷樫尾');
ok($zip->set_number('7780205')->is_valid_number, '徳島県三好市東祖谷古味');
ok($zip->set_number('7780205')->is_valid_number, '徳島県三好市東祖谷新居屋');
ok($zip->set_number('7780205')->is_valid_number, '徳島県三好市東祖谷麦生土');
ok($zip->set_number('7780205')->is_valid_number, '徳島県三好市東祖谷元井');
ok($zip->set_number('7780206')->is_valid_number, '徳島県三好市東祖谷今井');
ok($zip->set_number('7780206')->is_valid_number, '徳島県三好市東祖谷小島');
ok($zip->set_number('7780206')->is_valid_number, '徳島県三好市東祖谷佐野');
ok($zip->set_number('7780206')->is_valid_number, '徳島県三好市東祖谷高野');
ok($zip->set_number('7780206')->is_valid_number, '徳島県三好市東祖谷釣井');
ok($zip->set_number('7780206')->is_valid_number, '徳島県三好市東祖谷和田');
ok($zip->set_number('7785251')->is_valid_number, '徳島県三好市池田町白地');
ok($zip->set_number('7785252')->is_valid_number, '徳島県三好市池田町馬路');
ok($zip->set_number('7785253')->is_valid_number, '徳島県三好市池田町佐野');
ok($zip->set_number('7785254')->is_valid_number, '徳島県三好市山城町佐連(ミネ畑)');
ok($zip->set_number('7790100')->is_valid_number, '徳島県板野郡板野町以下に掲載がない場合');
ok($zip->set_number('7790101')->is_valid_number, '徳島県板野郡板野町大坂');
ok($zip->set_number('7790102')->is_valid_number, '徳島県板野郡板野町川端(その他)');
ok($zip->set_number('7790103')->is_valid_number, '徳島県板野郡板野町川端(新田)');
ok($zip->set_number('7790104')->is_valid_number, '徳島県板野郡板野町吹田');
ok($zip->set_number('7790105')->is_valid_number, '徳島県板野郡板野町大寺(その他)');
ok($zip->set_number('7790106')->is_valid_number, '徳島県板野郡板野町大寺(岡ノ宮)');
ok($zip->set_number('7790107')->is_valid_number, '徳島県板野郡板野町古城');
ok($zip->set_number('7790108')->is_valid_number, '徳島県板野郡板野町犬伏');
ok($zip->set_number('7790111')->is_valid_number, '徳島県板野郡板野町那東');
ok($zip->set_number('7790112')->is_valid_number, '徳島県板野郡板野町松谷');
ok($zip->set_number('7790113')->is_valid_number, '徳島県板野郡板野町黒谷');
ok($zip->set_number('7790114')->is_valid_number, '徳島県板野郡板野町羅漢');
ok($zip->set_number('7790115')->is_valid_number, '徳島県板野郡板野町矢武');
ok($zip->set_number('7790116')->is_valid_number, '徳島県板野郡板野町唐園');
ok($zip->set_number('7790117')->is_valid_number, '徳島県板野郡板野町中久保');
ok($zip->set_number('7790118')->is_valid_number, '徳島県板野郡板野町下庄');
ok($zip->set_number('7790119')->is_valid_number, '徳島県板野郡板野町西中富');
ok($zip->set_number('7790221')->is_valid_number, '徳島県鳴門市大麻町萩原');
ok($zip->set_number('7790222')->is_valid_number, '徳島県鳴門市大麻町三俣');
ok($zip->set_number('7790223')->is_valid_number, '徳島県鳴門市大麻町川崎');
ok($zip->set_number('7790224')->is_valid_number, '徳島県鳴門市大麻町津慈');
ok($zip->set_number('7790225')->is_valid_number, '徳島県鳴門市大麻町檜');
ok($zip->set_number('7790230')->is_valid_number, '徳島県鳴門市大麻町板東(その他)');
ok($zip->set_number('7790231')->is_valid_number, '徳島県鳴門市大麻町板東(大林)');
ok($zip->set_number('7790232')->is_valid_number, '徳島県鳴門市大麻町板東(辻見堂)');
ok($zip->set_number('7790233')->is_valid_number, '徳島県鳴門市大麻町板東(宝蔵)');
ok($zip->set_number('7790234')->is_valid_number, '徳島県鳴門市大麻町板東(采女)');
ok($zip->set_number('7790235')->is_valid_number, '徳島県鳴門市大麻町板東(永井)');
ok($zip->set_number('7790236')->is_valid_number, '徳島県鳴門市大麻町板東(西山田)');
ok($zip->set_number('7790237')->is_valid_number, '徳島県鳴門市大麻町板東(北条)');
ok($zip->set_number('7790238')->is_valid_number, '徳島県鳴門市大麻町板東(東山田)');
ok($zip->set_number('7790301')->is_valid_number, '徳島県鳴門市大麻町姫田');
ok($zip->set_number('7790302')->is_valid_number, '徳島県鳴門市大麻町大谷');
ok($zip->set_number('7790303')->is_valid_number, '徳島県鳴門市大麻町池谷');
ok($zip->set_number('7790304')->is_valid_number, '徳島県鳴門市大麻町松村');
ok($zip->set_number('7790305')->is_valid_number, '徳島県鳴門市大麻町高畑');
ok($zip->set_number('7790311')->is_valid_number, '徳島県鳴門市大麻町牛屋島');
ok($zip->set_number('7790312')->is_valid_number, '徳島県鳴門市大麻町東馬詰');
ok($zip->set_number('7790313')->is_valid_number, '徳島県鳴門市大麻町中馬詰');
ok($zip->set_number('7790314')->is_valid_number, '徳島県鳴門市大麻町西馬詰');
ok($zip->set_number('7790315')->is_valid_number, '徳島県鳴門市大麻町市場');
ok($zip->set_number('7791101')->is_valid_number, '徳島県阿南市羽ノ浦町中庄');
ok($zip->set_number('7791102')->is_valid_number, '徳島県阿南市羽ノ浦町宮倉');
ok($zip->set_number('7791103')->is_valid_number, '徳島県阿南市羽ノ浦町春日野');
ok($zip->set_number('7791104')->is_valid_number, '徳島県阿南市羽ノ浦町西春日野');
ok($zip->set_number('7791105')->is_valid_number, '徳島県阿南市羽ノ浦町古庄');
ok($zip->set_number('7791106')->is_valid_number, '徳島県阿南市羽ノ浦町岩脇(その他)');
ok($zip->set_number('7791107')->is_valid_number, '徳島県阿南市羽ノ浦町岩脇(奥ノ谷)');
ok($zip->set_number('7791108')->is_valid_number, '徳島県阿南市羽ノ浦町明見');
ok($zip->set_number('7791109')->is_valid_number, '徳島県阿南市羽ノ浦町古毛');
ok($zip->set_number('7791111')->is_valid_number, '徳島県阿南市那賀川町江野島');
ok($zip->set_number('7791112')->is_valid_number, '徳島県阿南市那賀川町色ケ島');
ok($zip->set_number('7791113')->is_valid_number, '徳島県阿南市那賀川町芳崎');
ok($zip->set_number('7791114')->is_valid_number, '徳島県阿南市那賀川町今津浦');
ok($zip->set_number('7791115')->is_valid_number, '徳島県阿南市那賀川町敷地');
ok($zip->set_number('7791116')->is_valid_number, '徳島県阿南市那賀川町小延');
ok($zip->set_number('7791117')->is_valid_number, '徳島県阿南市那賀川町島尻');
ok($zip->set_number('7791118')->is_valid_number, '徳島県阿南市那賀川町豊香野');
ok($zip->set_number('7791119')->is_valid_number, '徳島県阿南市那賀川町日向');
ok($zip->set_number('7791121')->is_valid_number, '徳島県阿南市那賀川町黒地');
ok($zip->set_number('7791122')->is_valid_number, '徳島県阿南市那賀川町八幡');
ok($zip->set_number('7791123')->is_valid_number, '徳島県阿南市那賀川町手島');
ok($zip->set_number('7791231')->is_valid_number, '徳島県阿南市那賀川町原');
ok($zip->set_number('7791232')->is_valid_number, '徳島県阿南市那賀川町西原');
ok($zip->set_number('7791233')->is_valid_number, '徳島県阿南市那賀川町大京原');
ok($zip->set_number('7791234')->is_valid_number, '徳島県阿南市那賀川町古津');
ok($zip->set_number('7791235')->is_valid_number, '徳島県阿南市那賀川町苅屋');
ok($zip->set_number('7791236')->is_valid_number, '徳島県阿南市那賀川町工地');
ok($zip->set_number('7791241')->is_valid_number, '徳島県阿南市那賀川町三栗');
ok($zip->set_number('7791242')->is_valid_number, '徳島県阿南市那賀川町赤池');
ok($zip->set_number('7791243')->is_valid_number, '徳島県阿南市那賀川町上福井');
ok($zip->set_number('7791244')->is_valid_number, '徳島県阿南市那賀川町みどり台');
ok($zip->set_number('7791245')->is_valid_number, '徳島県阿南市那賀川町中島');
ok($zip->set_number('7791246')->is_valid_number, '徳島県阿南市那賀川町北中島');
ok($zip->set_number('7791401')->is_valid_number, '徳島県阿南市内原町');
ok($zip->set_number('7791402')->is_valid_number, '徳島県阿南市桑野町');
ok($zip->set_number('7791403')->is_valid_number, '徳島県阿南市山口町');
ok($zip->set_number('7791404')->is_valid_number, '徳島県阿南市阿瀬比町');
ok($zip->set_number('7791510')->is_valid_number, '徳島県阿南市新野町');
ok($zip->set_number('7791620')->is_valid_number, '徳島県阿南市福井町');
ok($zip->set_number('7791630')->is_valid_number, '徳島県阿南市橘町(タテアジロ、袴、袴傍示、棒面)');
ok($zip->set_number('7791631')->is_valid_number, '徳島県阿南市橘町(小勝)');
ok($zip->set_number('7791740')->is_valid_number, '徳島県阿南市椿泊町');
ok($zip->set_number('7791750')->is_valid_number, '徳島県阿南市椿町');
ok($zip->set_number('7792101')->is_valid_number, '徳島県海部郡美波町西由岐');
ok($zip->set_number('7792102')->is_valid_number, '徳島県海部郡美波町港町');
ok($zip->set_number('7792103')->is_valid_number, '徳島県海部郡美波町西の地');
ok($zip->set_number('7792104')->is_valid_number, '徳島県海部郡美波町東由岐');
ok($zip->set_number('7792105')->is_valid_number, '徳島県海部郡美波町志和岐');
ok($zip->set_number('7792106')->is_valid_number, '徳島県海部郡美波町阿部');
ok($zip->set_number('7792107')->is_valid_number, '徳島県海部郡美波町伊座利');
ok($zip->set_number('7792108')->is_valid_number, '徳島県海部郡美波町木岐');
ok($zip->set_number('7792109')->is_valid_number, '徳島県海部郡美波町田井');
ok($zip->set_number('7792300')->is_valid_number, '徳島県海部郡美波町以下に掲載がない場合');
ok($zip->set_number('7792301')->is_valid_number, '徳島県海部郡美波町赤松');
ok($zip->set_number('7792302')->is_valid_number, '徳島県海部郡美波町北河内');
ok($zip->set_number('7792303')->is_valid_number, '徳島県海部郡美波町恵比須浜');
ok($zip->set_number('7792304')->is_valid_number, '徳島県海部郡美波町日和佐浦');
ok($zip->set_number('7792305')->is_valid_number, '徳島県海部郡美波町奥河内');
ok($zip->set_number('7792306')->is_valid_number, '徳島県海部郡美波町西河内');
ok($zip->set_number('7792307')->is_valid_number, '徳島県海部郡美波町山河内');
ok($zip->set_number('7793101')->is_valid_number, '徳島県徳島市国府町佐野塚');
ok($zip->set_number('7793102')->is_valid_number, '徳島県徳島市国府町西黒田');
ok($zip->set_number('7793103')->is_valid_number, '徳島県徳島市国府町東黒田');
ok($zip->set_number('7793104')->is_valid_number, '徳島県徳島市国府町西高輪');
ok($zip->set_number('7793105')->is_valid_number, '徳島県徳島市国府町東高輪');
ok($zip->set_number('7793106')->is_valid_number, '徳島県徳島市国府町花園');
ok($zip->set_number('7793111')->is_valid_number, '徳島県徳島市国府町竜王');
ok($zip->set_number('7793112')->is_valid_number, '徳島県徳島市国府町芝原');
ok($zip->set_number('7793113')->is_valid_number, '徳島県徳島市国府町川原田');
ok($zip->set_number('7793114')->is_valid_number, '徳島県徳島市国府町桜間');
ok($zip->set_number('7793115')->is_valid_number, '徳島県徳島市国府町敷地');
ok($zip->set_number('7793116')->is_valid_number, '徳島県徳島市国府町池尻');
ok($zip->set_number('7793117')->is_valid_number, '徳島県徳島市国府町日開');
ok($zip->set_number('7793118')->is_valid_number, '徳島県徳島市国府町井戸');
ok($zip->set_number('7793119')->is_valid_number, '徳島県徳島市国府町北岩延');
ok($zip->set_number('7793120')->is_valid_number, '徳島県徳島市国府町南岩延');
ok($zip->set_number('7793121')->is_valid_number, '徳島県徳島市国府町和田');
ok($zip->set_number('7793122')->is_valid_number, '徳島県徳島市国府町府中');
ok($zip->set_number('7793123')->is_valid_number, '徳島県徳島市国府町観音寺');
ok($zip->set_number('7793124')->is_valid_number, '徳島県徳島市国府町中');
ok($zip->set_number('7793125')->is_valid_number, '徳島県徳島市国府町早淵');
ok($zip->set_number('7793126')->is_valid_number, '徳島県徳島市国府町矢野');
ok($zip->set_number('7793127')->is_valid_number, '徳島県徳島市国府町西矢野');
ok($zip->set_number('7793128')->is_valid_number, '徳島県徳島市国府町延命');
ok($zip->set_number('7793131')->is_valid_number, '徳島県徳島市下町');
ok($zip->set_number('7793132')->is_valid_number, '徳島県徳島市一宮町');
ok($zip->set_number('7793133')->is_valid_number, '徳島県徳島市入田町');
ok($zip->set_number('7793200')->is_valid_number, '徳島県名西郡石井町以下に掲載がない場合');
ok($zip->set_number('7793201')->is_valid_number, '徳島県名西郡石井町高原(中須)');
ok($zip->set_number('7793202')->is_valid_number, '徳島県名西郡石井町高原(関)');
ok($zip->set_number('7793203')->is_valid_number, '徳島県名西郡石井町高原(平島)');
ok($zip->set_number('7793204')->is_valid_number, '徳島県名西郡石井町高原(西高原)');
ok($zip->set_number('7793205')->is_valid_number, '徳島県名西郡石井町高原(東高原)');
ok($zip->set_number('7793206')->is_valid_number, '徳島県名西郡石井町高原(池北)');
ok($zip->set_number('7793207')->is_valid_number, '徳島県名西郡石井町高原(桑島)');
ok($zip->set_number('7793208')->is_valid_number, '徳島県名西郡石井町高原(中島)');
ok($zip->set_number('7793211')->is_valid_number, '徳島県名西郡石井町藍畑(西覚円)');
ok($zip->set_number('7793212')->is_valid_number, '徳島県名西郡石井町藍畑(東覚円)');
ok($zip->set_number('7793213')->is_valid_number, '徳島県名西郡石井町藍畑(高畑)');
ok($zip->set_number('7793214')->is_valid_number, '徳島県名西郡石井町藍畑(第十)');
ok($zip->set_number('7793215')->is_valid_number, '徳島県名西郡石井町藍畑(竜王)');
ok($zip->set_number('7793221')->is_valid_number, '徳島県名西郡石井町高川原(南島)');
ok($zip->set_number('7793222')->is_valid_number, '徳島県名西郡石井町高川原(天神)');
ok($zip->set_number('7793223')->is_valid_number, '徳島県名西郡石井町高川原(高川原)');
ok($zip->set_number('7793224')->is_valid_number, '徳島県名西郡石井町高川原(加茂野)');
ok($zip->set_number('7793225')->is_valid_number, '徳島県名西郡石井町高川原(桜間)');
ok($zip->set_number('7793226')->is_valid_number, '徳島県名西郡石井町高川原(市楽)');
ok($zip->set_number('7793231')->is_valid_number, '徳島県名西郡石井町石井(重松)');
ok($zip->set_number('7793232')->is_valid_number, '徳島県名西郡石井町石井(城の内)');
ok($zip->set_number('7793233')->is_valid_number, '徳島県名西郡石井町石井(石井)');
ok($zip->set_number('7793234')->is_valid_number, '徳島県名西郡石井町石井(白鳥)');
ok($zip->set_number('7793235')->is_valid_number, '徳島県名西郡石井町石井(尼寺)');
ok($zip->set_number('7793236')->is_valid_number, '徳島県名西郡石井町石井(内谷)');
ok($zip->set_number('7793241')->is_valid_number, '徳島県名西郡石井町浦庄(諏訪)');
ok($zip->set_number('7793242')->is_valid_number, '徳島県名西郡石井町浦庄(国実)');
ok($zip->set_number('7793243')->is_valid_number, '徳島県名西郡石井町浦庄(大万)');
ok($zip->set_number('7793244')->is_valid_number, '徳島県名西郡石井町浦庄(下浦)');
ok($zip->set_number('7793245')->is_valid_number, '徳島県名西郡石井町浦庄(上浦)');
ok($zip->set_number('7793301')->is_valid_number, '徳島県吉野川市川島町川島');
ok($zip->set_number('7793302')->is_valid_number, '徳島県吉野川市川島町山田');
ok($zip->set_number('7793303')->is_valid_number, '徳島県吉野川市川島町桑村');
ok($zip->set_number('7793304')->is_valid_number, '徳島県吉野川市川島町宮島');
ok($zip->set_number('7793305')->is_valid_number, '徳島県吉野川市川島町児島');
ok($zip->set_number('7793306')->is_valid_number, '徳島県吉野川市川島町学');
ok($zip->set_number('7793307')->is_valid_number, '徳島県吉野川市川島町三ツ島');
ok($zip->set_number('7793401')->is_valid_number, '徳島県吉野川市山川町石堂');
ok($zip->set_number('7793401')->is_valid_number, '徳島県吉野川市山川町恵下');
ok($zip->set_number('7793401')->is_valid_number, '徳島県吉野川市山川町翁喜台');
ok($zip->set_number('7793401')->is_valid_number, '徳島県吉野川市山川町川東');
ok($zip->set_number('7793401')->is_valid_number, '徳島県吉野川市山川町住吉');
ok($zip->set_number('7793401')->is_valid_number, '徳島県吉野川市山川町建石');
ok($zip->set_number('7793401')->is_valid_number, '徳島県吉野川市山川町町');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町忌部');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町忌部山');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町岩戸');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町雲宮');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町堤内');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町天神');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町中須賀');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町流');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町西久保');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町西麓');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町東麓');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町宮北');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町宮島');
ok($zip->set_number('7793402')->is_valid_number, '徳島県吉野川市山川町山路');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町春日');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町北須賀');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町諏訪');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町堤外');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町八幡');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町前川');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町三島');
ok($zip->set_number('7793403')->is_valid_number, '徳島県吉野川市山川町若宮');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町市久保');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町一里塚');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町大須賀');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町大塚');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町麻掛');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町槻原');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町川田');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町川田市');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町川田天神');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町北島');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町鼓山');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町引地');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町日知利子');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町藤生');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町舟戸');
ok($zip->set_number('7793404')->is_valid_number, '徳島県吉野川市山川町湯立');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町赤刎');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町伊端穂');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町井上');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町井傍');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町牛ノ子尾');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町大藤谷');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町大峰');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町大室');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町奥原');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町柿木谷');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町楮本');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町片岸');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町川田八幡');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町木戸口');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町黒岩');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町桑ノ峰');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町高頭');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町御饌免');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町御旅館');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町権現谷');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町坂口');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町貞田');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町小路');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町瀬津');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町田ノ浦');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町塚穴');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町土仏西向');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町天神佐古');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町天王原');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町土橋');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町土橋ノ上');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町中ノ郷');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町鍋倉');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町野宮谷');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町八ケ久保');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町榛木原');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町一ツ石');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町平山');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町日鷲谷');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町宮谷');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町村雲');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町茂草');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町矢落');
ok($zip->set_number('7793405')->is_valid_number, '徳島県吉野川市山川町木綿麻山');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町榎谷');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町大内');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町奥川田');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町奥野井');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町皆瀬');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町楠根地');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町桑内');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町西野峰');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町久宗');
ok($zip->set_number('7793406')->is_valid_number, '徳島県吉野川市山川町馬見尾');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町青木');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町赤岩');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町朝日');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町安楽寺');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町浦山');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町祗園');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町境谷');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町坂田');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町新田谷');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町季邦');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町津由谷');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町西ノ原');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町旗見');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町東麦原');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町古城');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町丸山');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町宮地');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町迎坂');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町麦原');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町向坂');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町山ノ神');
ok($zip->set_number('7793407')->is_valid_number, '徳島県吉野川市山川町横走');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷愛後');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷穴地');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷一野山');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷大神');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷大平');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷柿谷');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷倉羅');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷古井');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷重野尾');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷下浦');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷下城戸');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷上戸峯');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷平');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷滝ケ山');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷田平');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷照尾');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷張');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷張峯');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷宮倉');
ok($zip->set_number('7793501')->is_valid_number, '徳島県吉野川市美郷宗田');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷大岸');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷大佐古');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷奥分');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷樫平');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷川向');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷岸宗');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷小竹');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷下畠');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷下林');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷竹屋敷');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷立石');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷谷向');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷中畠');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷中分');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷中村中筋');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷西條');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷西谷');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷西畠');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷西槇山');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷日浦');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷東');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷東條');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷東槇山');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷槇山');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷松尾');
ok($zip->set_number('7793502')->is_valid_number, '徳島県吉野川市美郷矢ノ丸');
ok($zip->set_number('7793503')->is_valid_number, '徳島県吉野川市美郷川俣');
ok($zip->set_number('7793503')->is_valid_number, '徳島県吉野川市美郷品野');
ok($zip->set_number('7793503')->is_valid_number, '徳島県吉野川市美郷高野尾');
ok($zip->set_number('7793503')->is_valid_number, '徳島県吉野川市美郷中筋');
ok($zip->set_number('7793503')->is_valid_number, '徳島県吉野川市美郷湯殿');
ok($zip->set_number('7793504')->is_valid_number, '徳島県吉野川市美郷毛無');
ok($zip->set_number('7793504')->is_valid_number, '徳島県吉野川市美郷土井ノ奥');
ok($zip->set_number('7793504')->is_valid_number, '徳島県吉野川市美郷峠');
ok($zip->set_number('7793504')->is_valid_number, '徳島県吉野川市美郷刷石');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷恵美子');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷大鹿');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷大野');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷奥丸');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷上谷');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷栗木');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷来見坂');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷暮石');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷古土地');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷木屋浦');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷山王');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷菅草');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷月野');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷栩谷');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷殿河');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷土用地');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷中谷');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷花地');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷東山峠');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷丸山');
ok($zip->set_number('7793505')->is_valid_number, '徳島県吉野川市美郷湯下');
ok($zip->set_number('7793600')->is_valid_number, '徳島県美馬市以下に掲載がない場合');
ok($zip->set_number('7793601')->is_valid_number, '徳島県美馬市脇町(拝原)');
ok($zip->set_number('7793602')->is_valid_number, '徳島県美馬市脇町猪尻(その他)');
ok($zip->set_number('7793603')->is_valid_number, '徳島県美馬市脇町猪尻(庄、土井、西上野)');
ok($zip->set_number('7793604')->is_valid_number, '徳島県美馬市脇町猪尻(古作)');
ok($zip->set_number('7793604')->is_valid_number, '徳島県美馬市脇町(北庄)');
ok($zip->set_number('7793610')->is_valid_number, '徳島県美馬市脇町脇町');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町岩倉');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町上ノ原');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町馬木');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町川原町');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町木ノ内');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町新町');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町助松');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町田上');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町野村');
ok($zip->set_number('7793620')->is_valid_number, '徳島県美馬市脇町別所');
ok($zip->set_number('7793625')->is_valid_number, '徳島県美馬市脇町(北星)');
ok($zip->set_number('7793631')->is_valid_number, '徳島県美馬市脇町(新山)');
ok($zip->set_number('7793632')->is_valid_number, '徳島県美馬市脇町(井口東、上ノ原)');
ok($zip->set_number('7793633')->is_valid_number, '徳島県美馬市脇町(井口)');
ok($zip->set_number('7793634')->is_valid_number, '徳島県美馬市脇町(小星)');
ok($zip->set_number('7793635')->is_valid_number, '徳島県美馬市脇町(川原柴、暮畑、梨子木、横倉)');
ok($zip->set_number('7793636')->is_valid_number, '徳島県美馬市脇町(芋穴、中八)');
ok($zip->set_number('7793637')->is_valid_number, '徳島県美馬市脇町(上中野、下中野、平帽子、舟木)');
ok($zip->set_number('7793638')->is_valid_number, '徳島県美馬市脇町(神楽田、西大谷、東大谷)');
ok($zip->set_number('7793639')->is_valid_number, '徳島県美馬市脇町(芋尻、小丸、白木、段、段名、中段、羽出床)');
ok($zip->set_number('7793741')->is_valid_number, '徳島県美馬市脇町(曽江名)');
ok($zip->set_number('7793742')->is_valid_number, '徳島県美馬市脇町(西赤谷)');
ok($zip->set_number('7793743')->is_valid_number, '徳島県美馬市脇町(東赤谷名)');
ok($zip->set_number('7793744')->is_valid_number, '徳島県美馬市脇町(西俣名)');
ok($zip->set_number('7793745')->is_valid_number, '徳島県美馬市脇町(東俣名)');
ok($zip->set_number('7794100')->is_valid_number, '徳島県美馬郡つるぎ町以下に掲載がない場合');
ok($zip->set_number('7794101')->is_valid_number, '徳島県美馬郡つるぎ町貞光(馬出、大須賀、中須賀、西浦、東浦、町、宮下)');
ok($zip->set_number('7794102')->is_valid_number, '徳島県美馬郡つるぎ町貞光(大坊、辻、西山、野口、平石、別所、前田)');
ok($zip->set_number('7794103')->is_valid_number, '徳島県美馬郡つるぎ町貞光(江ノ脇、岡、せせらぎ、宮内)');
ok($zip->set_number('7794104')->is_valid_number, '徳島県美馬郡つるぎ町貞光(太田西、太田東、太田東山、小長谷、小山北、柴内、柴山、僧地、僧山)');
ok($zip->set_number('7794105')->is_valid_number, '徳島県美馬郡つるぎ町貞光(浦山、乙部、皆瀬、竹屋敷、長谷、西丸井、引地、宅熊)');
ok($zip->set_number('7794106')->is_valid_number, '徳島県美馬郡つるぎ町貞光(大久保、皆瀬川向、捨子谷南、捨子谷北、谷向、中山、西谷、白村)');
ok($zip->set_number('7794107')->is_valid_number, '徳島県美馬郡つるぎ町貞光(家賀道上、家賀道下、平野、長木、長木影、広谷、広谷影、広谷東)');
ok($zip->set_number('7794108')->is_valid_number, '徳島県美馬郡つるぎ町貞光(川見、川見津、川見西、長瀬、日浦川向、東丸井、三木枋、森ノ本)');
ok($zip->set_number('7794109')->is_valid_number, '徳島県美馬郡つるぎ町貞光(吉良、木屋、猿飼、成谷、日浦、宮平、横野)');
ok($zip->set_number('7794301')->is_valid_number, '徳島県美馬郡つるぎ町一宇(一宇、蔭、樫地、剪宇、太刀之本)');
ok($zip->set_number('7794302')->is_valid_number, '徳島県美馬郡つるぎ町一宇(赤松、寺地)');
ok($zip->set_number('7794303')->is_valid_number, '徳島県美馬郡つるぎ町一宇(大横、木地屋、切越、十家、中横)');
ok($zip->set_number('7794304')->is_valid_number, '徳島県美馬郡つるぎ町一宇(伊良原、大野、九藤中、子安、久藪)');
ok($zip->set_number('7794305')->is_valid_number, '徳島県美馬郡つるぎ町一宇(出羽、臼木、漆日浦、大屋内、白井、平、明谷)');
ok($zip->set_number('7794306')->is_valid_number, '徳島県美馬郡つるぎ町一宇(漆野瀬、河内、桑平、葛籠、平井、廣澤、法正)');
ok($zip->set_number('7794307')->is_valid_number, '徳島県美馬郡つるぎ町一宇(大佐古、奥大野、川又、實平、中野)');
ok($zip->set_number('7794401')->is_valid_number, '徳島県美馬郡つるぎ町半田(逢坂、小野、天皇、中藪、松生)');
ok($zip->set_number('7794402')->is_valid_number, '徳島県美馬郡つるぎ町半田(上蔭、蔭名、田井、日浦)');
ok($zip->set_number('7794403')->is_valid_number, '徳島県美馬郡つるぎ町半田(木ノ内、京都、猿飼、白石、西久保、東久保、平良石)');
ok($zip->set_number('7794404')->is_valid_number, '徳島県美馬郡つるぎ町半田(青野、折坂、小井野、高清、坂根、下尾尻、下竹、上蓮、日谷尾)');
ok($zip->set_number('7794405')->is_valid_number, '徳島県美馬郡つるぎ町半田(葛城、上喜来、中熊、長野、日開野)');
ok($zip->set_number('7794406')->is_valid_number, '徳島県美馬郡つるぎ町半田(樫尾、紙屋、小谷、佐古戸、下喜来)');
ok($zip->set_number('7794407')->is_valid_number, '徳島県美馬郡つるぎ町半田(東毛田)');
ok($zip->set_number('7794700')->is_valid_number, '徳島県三好郡東みよし町以下に掲載がない場合');
ok($zip->set_number('7794701')->is_valid_number, '徳島県三好郡東みよし町加茂');
ok($zip->set_number('7794702')->is_valid_number, '徳島県三好郡東みよし町西庄');
ok($zip->set_number('7794703')->is_valid_number, '徳島県三好郡東みよし町中庄(その他)');
ok($zip->set_number('7794704')->is_valid_number, '徳島県三好郡東みよし町中庄(奥村)');
ok($zip->set_number('7794705')->is_valid_number, '徳島県三好郡東みよし町毛田(その他)');
ok($zip->set_number('7794706')->is_valid_number, '徳島県三好郡東みよし町毛田(黒長谷)');
ok($zip->set_number('7794707')->is_valid_number, '徳島県三好郡東みよし町毛田(大藤)');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町旭町');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町大佐古');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町片山');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町才長谷');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町新町');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町辻');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町仲ノ町');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町浜西');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町浜東');
ok($zip->set_number('7794801')->is_valid_number, '徳島県三好市井川町本町');
ok($zip->set_number('7794802')->is_valid_number, '徳島県三好市井川町井関');
ok($zip->set_number('7794802')->is_valid_number, '徳島県三好市井川町岡野前');
ok($zip->set_number('7794802')->is_valid_number, '徳島県三好市井川町御領田');
ok($zip->set_number('7794802')->is_valid_number, '徳島県三好市井川町流堂');
ok($zip->set_number('7794802')->is_valid_number, '徳島県三好市井川町野津後');
ok($zip->set_number('7794802')->is_valid_number, '徳島県三好市井川町向坂');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町島');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町タクミ田');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町田中');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町中岡');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町中村西');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町中村東');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町中村南');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町野津後流');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町八幡');
ok($zip->set_number('7794803')->is_valid_number, '徳島県三好市井川町吉岡');
ok($zip->set_number('7794804')->is_valid_number, '徳島県三好市井川町井内東');
ok($zip->set_number('7794805')->is_valid_number, '徳島県三好市井川町井内西');
ok($zip->set_number('7794806')->is_valid_number, '徳島県三好市井川町西井川');
ok($zip->set_number('7794807')->is_valid_number, '徳島県三好市井川町里川');
ok($zip->set_number('7795161')->is_valid_number, '徳島県三好市池田町中西');
ok($zip->set_number('7795162')->is_valid_number, '徳島県三好市池田町漆川');
ok($zip->set_number('7795163')->is_valid_number, '徳島県三好市池田町中津川');
ok($zip->set_number('7795164')->is_valid_number, '徳島県三好市池田町大利');
ok($zip->set_number('7795165')->is_valid_number, '徳島県三好市池田町松尾(その他)');
ok($zip->set_number('7795166')->is_valid_number, '徳島県三好市池田町川崎');
ok($zip->set_number('7795171')->is_valid_number, '徳島県三好市西祖谷山村下名');
ok($zip->set_number('7795172')->is_valid_number, '徳島県三好市西祖谷山村小祖谷');
ok($zip->set_number('7795173')->is_valid_number, '徳島県三好市西祖谷山村坂瀬');
ok($zip->set_number('7795301')->is_valid_number, '徳島県三好市山城町大和川');
ok($zip->set_number('7795302')->is_valid_number, '徳島県三好市山城町若山');
ok($zip->set_number('7795303')->is_valid_number, '徳島県三好市山城町下川');
ok($zip->set_number('7795304')->is_valid_number, '徳島県三好市山城町大川持');
ok($zip->set_number('7795305')->is_valid_number, '徳島県三好市山城町川口');
ok($zip->set_number('7795306')->is_valid_number, '徳島県三好市山城町寺野');
ok($zip->set_number('7795307')->is_valid_number, '徳島県三好市山城町相川');
ok($zip->set_number('7795311')->is_valid_number, '徳島県三好市山城町中ノ瀬');
ok($zip->set_number('7795312')->is_valid_number, '徳島県三好市山城町八千坊');
ok($zip->set_number('7795313')->is_valid_number, '徳島県三好市山城町黒川');
ok($zip->set_number('7795314')->is_valid_number, '徳島県三好市山城町岩戸');
ok($zip->set_number('7795315')->is_valid_number, '徳島県三好市山城町引地');
ok($zip->set_number('7795316')->is_valid_number, '徳島県三好市山城町末貞');
ok($zip->set_number('7795321')->is_valid_number, '徳島県三好市山城町国政');
ok($zip->set_number('7795322')->is_valid_number, '徳島県三好市山城町重実(その他)');
ok($zip->set_number('7795323')->is_valid_number, '徳島県三好市山城町中野');
ok($zip->set_number('7795324')->is_valid_number, '徳島県三好市山城町白川');
ok($zip->set_number('7795325')->is_valid_number, '徳島県三好市山城町光兼');
ok($zip->set_number('7795326')->is_valid_number, '徳島県三好市山城町仏子');
ok($zip->set_number('7795327')->is_valid_number, '徳島県三好市山城町尾又');
ok($zip->set_number('7795328')->is_valid_number, '徳島県三好市山城町粟山');
ok($zip->set_number('7795331')->is_valid_number, '徳島県三好市山城町茂地');
ok($zip->set_number('7795332')->is_valid_number, '徳島県三好市山城町小川谷');
ok($zip->set_number('7795333')->is_valid_number, '徳島県三好市山城町大野');
ok($zip->set_number('7795334')->is_valid_number, '徳島県三好市山城町信正');
ok($zip->set_number('7795335')->is_valid_number, '徳島県三好市山城町頼広');
ok($zip->set_number('7795336')->is_valid_number, '徳島県三好市山城町赤谷');
ok($zip->set_number('7795337')->is_valid_number, '徳島県三好市山城町平野');
ok($zip->set_number('7795341')->is_valid_number, '徳島県三好市山城町佐連(その他)');
ok($zip->set_number('7795342')->is_valid_number, '徳島県三好市山城町大谷');
ok($zip->set_number('7795343')->is_valid_number, '徳島県三好市山城町柴川');
ok($zip->set_number('7795344')->is_valid_number, '徳島県三好市山城町政友');
ok($zip->set_number('7795345')->is_valid_number, '徳島県三好市山城町瀬貝');
ok($zip->set_number('7795346')->is_valid_number, '徳島県三好市山城町脇');
ok($zip->set_number('7795347')->is_valid_number, '徳島県三好市山城町大月');
ok($zip->set_number('7795422')->is_valid_number, '徳島県三好市山城町重実(殿野)');
ok($zip->set_number('7795451')->is_valid_number, '徳島県三好市山城町西宇');
ok($zip->set_number('7795452')->is_valid_number, '徳島県三好市山城町上名');
ok($zip->set_number('7795453')->is_valid_number, '徳島県三好市山城町下名');
ok($zip->set_number('7800000')->is_valid_number, '高知県高知市以下に掲載がない場合');
ok($zip->set_number('7800001')->is_valid_number, '高知県高知市久礼野');
ok($zip->set_number('7800002')->is_valid_number, '高知県高知市重倉');
ok($zip->set_number('7800003')->is_valid_number, '高知県高知市七ツ淵');
ok($zip->set_number('7800004')->is_valid_number, '高知県高知市三谷');
ok($zip->set_number('7800021')->is_valid_number, '高知県高知市中秦泉寺');
ok($zip->set_number('7800022')->is_valid_number, '高知県高知市北秦泉寺');
ok($zip->set_number('7800023')->is_valid_number, '高知県高知市東秦泉寺');
ok($zip->set_number('7800024')->is_valid_number, '高知県高知市前里');
ok($zip->set_number('7800025')->is_valid_number, '高知県高知市愛宕山');
ok($zip->set_number('7800026')->is_valid_number, '高知県高知市秦南町');
ok($zip->set_number('7800027')->is_valid_number, '高知県高知市愛宕山南町');
ok($zip->set_number('7800031')->is_valid_number, '高知県高知市宇津野');
ok($zip->set_number('7800032')->is_valid_number, '高知県高知市加賀野井');
ok($zip->set_number('7800033')->is_valid_number, '高知県高知市西秦泉寺');
ok($zip->set_number('7800034')->is_valid_number, '高知県高知市三園町');
ok($zip->set_number('7800041')->is_valid_number, '高知県高知市入明町');
ok($zip->set_number('7800042')->is_valid_number, '高知県高知市洞ケ島町');
ok($zip->set_number('7800043')->is_valid_number, '高知県高知市寿町');
ok($zip->set_number('7800044')->is_valid_number, '高知県高知市中水道');
ok($zip->set_number('7800045')->is_valid_number, '高知県高知市幸町');
ok($zip->set_number('7800046')->is_valid_number, '高知県高知市伊勢崎町');
ok($zip->set_number('7800047')->is_valid_number, '高知県高知市相模町');
ok($zip->set_number('7800048')->is_valid_number, '高知県高知市吉田町');
ok($zip->set_number('7800051')->is_valid_number, '高知県高知市愛宕町');
ok($zip->set_number('7800052')->is_valid_number, '高知県高知市大川筋');
ok($zip->set_number('7800053')->is_valid_number, '高知県高知市駅前町');
ok($zip->set_number('7800054')->is_valid_number, '高知県高知市相生町');
ok($zip->set_number('7800055')->is_valid_number, '高知県高知市江陽町');
ok($zip->set_number('7800056')->is_valid_number, '高知県高知市北本町');
ok($zip->set_number('7800061')->is_valid_number, '高知県高知市栄田町');
ok($zip->set_number('7800062')->is_valid_number, '高知県高知市新本町');
ok($zip->set_number('7800063')->is_valid_number, '高知県高知市昭和町');
ok($zip->set_number('7800064')->is_valid_number, '高知県高知市和泉町');
ok($zip->set_number('7800065')->is_valid_number, '高知県高知市塩田町');
ok($zip->set_number('7800066')->is_valid_number, '高知県高知市比島町');
ok($zip->set_number('7800071')->is_valid_number, '高知県高知市高そね');
ok($zip->set_number('7800072')->is_valid_number, '高知県高知市杉井流');
ok($zip->set_number('7800816')->is_valid_number, '高知県高知市南宝永町');
ok($zip->set_number('7800817')->is_valid_number, '高知県高知市中宝永町');
ok($zip->set_number('7800818')->is_valid_number, '高知県高知市宝永町');
ok($zip->set_number('7800821')->is_valid_number, '高知県高知市桜井町');
ok($zip->set_number('7800822')->is_valid_number, '高知県高知市はりまや町');
ok($zip->set_number('7800823')->is_valid_number, '高知県高知市菜園場町');
ok($zip->set_number('7800824')->is_valid_number, '高知県高知市城見町');
ok($zip->set_number('7800825')->is_valid_number, '高知県高知市農人町');
ok($zip->set_number('7800833')->is_valid_number, '高知県高知市南はりまや町');
ok($zip->set_number('7800834')->is_valid_number, '高知県高知市堺町');
ok($zip->set_number('7800841')->is_valid_number, '高知県高知市帯屋町');
ok($zip->set_number('7800842')->is_valid_number, '高知県高知市追手筋');
ok($zip->set_number('7800843')->is_valid_number, '高知県高知市廿代町');
ok($zip->set_number('7800844')->is_valid_number, '高知県高知市永国寺町');
ok($zip->set_number('7800850')->is_valid_number, '高知県高知市丸ノ内');
ok($zip->set_number('7800861')->is_valid_number, '高知県高知市升形');
ok($zip->set_number('7800862')->is_valid_number, '高知県高知市鷹匠町');
ok($zip->set_number('7800863')->is_valid_number, '高知県高知市与力町');
ok($zip->set_number('7800864')->is_valid_number, '高知県高知市唐人町');
ok($zip->set_number('7800870')->is_valid_number, '高知県高知市本町');
ok($zip->set_number('7800901')->is_valid_number, '高知県高知市上町');
ok($zip->set_number('7800902')->is_valid_number, '高知県高知市本丁筋');
ok($zip->set_number('7800903')->is_valid_number, '高知県高知市水通町');
ok($zip->set_number('7800904')->is_valid_number, '高知県高知市通町');
ok($zip->set_number('7800911')->is_valid_number, '高知県高知市新屋敷');
ok($zip->set_number('7800912')->is_valid_number, '高知県高知市八反町');
ok($zip->set_number('7800913')->is_valid_number, '高知県高知市北八反町');
ok($zip->set_number('7800914')->is_valid_number, '高知県高知市宝町');
ok($zip->set_number('7800915')->is_valid_number, '高知県高知市小津町');
ok($zip->set_number('7800916')->is_valid_number, '高知県高知市城北町');
ok($zip->set_number('7800921')->is_valid_number, '高知県高知市井口町');
ok($zip->set_number('7800922')->is_valid_number, '高知県高知市平和町');
ok($zip->set_number('7800923')->is_valid_number, '高知県高知市三ノ丸');
ok($zip->set_number('7800924')->is_valid_number, '高知県高知市宮前町');
ok($zip->set_number('7800925')->is_valid_number, '高知県高知市西町');
ok($zip->set_number('7800926')->is_valid_number, '高知県高知市大膳町');
ok($zip->set_number('7800927')->is_valid_number, '高知県高知市山ノ端町');
ok($zip->set_number('7800928')->is_valid_number, '高知県高知市越前町');
ok($zip->set_number('7800929')->is_valid_number, '高知県高知市桜馬場');
ok($zip->set_number('7800931')->is_valid_number, '高知県高知市玉水町');
ok($zip->set_number('7800932')->is_valid_number, '高知県高知市縄手町');
ok($zip->set_number('7800933')->is_valid_number, '高知県高知市鏡川町');
ok($zip->set_number('7800934')->is_valid_number, '高知県高知市下島町');
ok($zip->set_number('7800935')->is_valid_number, '高知県高知市旭町');
ok($zip->set_number('7800936')->is_valid_number, '高知県高知市赤石町');
ok($zip->set_number('7800937')->is_valid_number, '高知県高知市中須賀町');
ok($zip->set_number('7800938')->is_valid_number, '高知県高知市旭駅前町');
ok($zip->set_number('7800941')->is_valid_number, '高知県高知市元町');
ok($zip->set_number('7800942')->is_valid_number, '高知県高知市南元町');
ok($zip->set_number('7800943')->is_valid_number, '高知県高知市旭上町');
ok($zip->set_number('7800944')->is_valid_number, '高知県高知市水源町');
ok($zip->set_number('7800945')->is_valid_number, '高知県高知市本宮町');
ok($zip->set_number('7800946')->is_valid_number, '高知県高知市上本宮町');
ok($zip->set_number('7800947')->is_valid_number, '高知県高知市大谷');
ok($zip->set_number('7800948')->is_valid_number, '高知県高知市岩ケ淵');
ok($zip->set_number('7800949')->is_valid_number, '高知県高知市鳥越');
ok($zip->set_number('7800951')->is_valid_number, '高知県高知市西塚ノ原');
ok($zip->set_number('7800952')->is_valid_number, '高知県高知市塚ノ原');
ok($zip->set_number('7800953')->is_valid_number, '高知県高知市長尾山町');
ok($zip->set_number('7800954')->is_valid_number, '高知県高知市佐々木町');
ok($zip->set_number('7800955')->is_valid_number, '高知県高知市旭天神町');
ok($zip->set_number('7800956')->is_valid_number, '高知県高知市北端町');
ok($zip->set_number('7800957')->is_valid_number, '高知県高知市山手町');
ok($zip->set_number('7800961')->is_valid_number, '高知県高知市蓮台');
ok($zip->set_number('7800962')->is_valid_number, '高知県高知市尾立');
ok($zip->set_number('7800963')->is_valid_number, '高知県高知市口細山');
ok($zip->set_number('7800964')->is_valid_number, '高知県高知市横内');
ok($zip->set_number('7800965')->is_valid_number, '高知県高知市福井町');
ok($zip->set_number('7800966')->is_valid_number, '高知県高知市福井扇町');
ok($zip->set_number('7800967')->is_valid_number, '高知県高知市福井東町');
ok($zip->set_number('7800971')->is_valid_number, '高知県高知市南万々');
ok($zip->set_number('7800972')->is_valid_number, '高知県高知市中万々');
ok($zip->set_number('7800973')->is_valid_number, '高知県高知市万々');
ok($zip->set_number('7800974')->is_valid_number, '高知県高知市円行寺');
ok($zip->set_number('7800975')->is_valid_number, '高知県高知市柴巻');
ok($zip->set_number('7800976')->is_valid_number, '高知県高知市みづき');
ok($zip->set_number('7800977')->is_valid_number, '高知県高知市みづき山');
ok($zip->set_number('7800981')->is_valid_number, '高知県高知市一ツ橋町');
ok($zip->set_number('7800982')->is_valid_number, '高知県高知市東久万');
ok($zip->set_number('7800983')->is_valid_number, '高知県高知市中久万');
ok($zip->set_number('7800984')->is_valid_number, '高知県高知市西久万');
ok($zip->set_number('7800985')->is_valid_number, '高知県高知市南久万');
ok($zip->set_number('7800991')->is_valid_number, '高知県高知市宗安寺');
ok($zip->set_number('7800992')->is_valid_number, '高知県高知市行川');
ok($zip->set_number('7800993')->is_valid_number, '高知県高知市針原');
ok($zip->set_number('7800994')->is_valid_number, '高知県高知市唐岩');
ok($zip->set_number('7800995')->is_valid_number, '高知県高知市領家');
ok($zip->set_number('7800996')->is_valid_number, '高知県高知市上里');
ok($zip->set_number('7808011')->is_valid_number, '高知県高知市梅ノ辻');
ok($zip->set_number('7808012')->is_valid_number, '高知県高知市天神町');
ok($zip->set_number('7808013')->is_valid_number, '高知県高知市筆山町');
ok($zip->set_number('7808014')->is_valid_number, '高知県高知市塩屋崎町');
ok($zip->set_number('7808015')->is_valid_number, '高知県高知市百石町');
ok($zip->set_number('7808017')->is_valid_number, '高知県高知市南竹島町');
ok($zip->set_number('7808018')->is_valid_number, '高知県高知市竹島町');
ok($zip->set_number('7808019')->is_valid_number, '高知県高知市北竹島町');
ok($zip->set_number('7808021')->is_valid_number, '高知県高知市孕東町');
ok($zip->set_number('7808022')->is_valid_number, '高知県高知市孕西町');
ok($zip->set_number('7808023')->is_valid_number, '高知県高知市六泉寺町');
ok($zip->set_number('7808024')->is_valid_number, '高知県高知市深谷町');
ok($zip->set_number('7808025')->is_valid_number, '高知県高知市南中山');
ok($zip->set_number('7808026')->is_valid_number, '高知県高知市北中山');
ok($zip->set_number('7808027')->is_valid_number, '高知県高知市高見町');
ok($zip->set_number('7808028')->is_valid_number, '高知県高知市北高見町');
ok($zip->set_number('7808031')->is_valid_number, '高知県高知市大原町');
ok($zip->set_number('7808032')->is_valid_number, '高知県高知市小石木町');
ok($zip->set_number('7808033')->is_valid_number, '高知県高知市幸崎');
ok($zip->set_number('7808034')->is_valid_number, '高知県高知市南河ノ瀬町');
ok($zip->set_number('7808035')->is_valid_number, '高知県高知市河ノ瀬町');
ok($zip->set_number('7808036')->is_valid_number, '高知県高知市東城山町');
ok($zip->set_number('7808037')->is_valid_number, '高知県高知市城山町');
ok($zip->set_number('7808038')->is_valid_number, '高知県高知市石立町');
ok($zip->set_number('7808039')->is_valid_number, '高知県高知市東石立町');
ok($zip->set_number('7808040')->is_valid_number, '高知県高知市神田');
ok($zip->set_number('7808050')->is_valid_number, '高知県高知市鴨部(その他)');
ok($zip->set_number('7808051')->is_valid_number, '高知県高知市鴨部上町');
ok($zip->set_number('7808052')->is_valid_number, '高知県高知市鴨部(丁目)');
ok($zip->set_number('7808061')->is_valid_number, '高知県高知市朝倉甲');
ok($zip->set_number('7808062')->is_valid_number, '高知県高知市朝倉乙');
ok($zip->set_number('7808063')->is_valid_number, '高知県高知市朝倉丙');
ok($zip->set_number('7808064')->is_valid_number, '高知県高知市朝倉丁');
ok($zip->set_number('7808065')->is_valid_number, '高知県高知市朝倉戊');
ok($zip->set_number('7808066')->is_valid_number, '高知県高知市朝倉己');
ok($zip->set_number('7808071')->is_valid_number, '高知県高知市鴨部高町');
ok($zip->set_number('7808072')->is_valid_number, '高知県高知市曙町');
ok($zip->set_number('7808073')->is_valid_number, '高知県高知市朝倉本町');
ok($zip->set_number('7808074')->is_valid_number, '高知県高知市朝倉横町');
ok($zip->set_number('7808075')->is_valid_number, '高知県高知市朝倉南町');
ok($zip->set_number('7808076')->is_valid_number, '高知県高知市朝倉東町');
ok($zip->set_number('7808077')->is_valid_number, '高知県高知市朝倉西町');
ok($zip->set_number('7808081')->is_valid_number, '高知県高知市若草町');
ok($zip->set_number('7808082')->is_valid_number, '高知県高知市若草南町');
ok($zip->set_number('7808083')->is_valid_number, '高知県高知市鵜来巣');
ok($zip->set_number('7808084')->is_valid_number, '高知県高知市槇山町');
ok($zip->set_number('7808085')->is_valid_number, '高知県高知市大谷公園町');
ok($zip->set_number('7808086')->is_valid_number, '高知県高知市針木東町');
ok($zip->set_number('7808087')->is_valid_number, '高知県高知市針木北');
ok($zip->set_number('7808088')->is_valid_number, '高知県高知市針木本町');
ok($zip->set_number('7808089')->is_valid_number, '高知県高知市針木南');
ok($zip->set_number('7808090')->is_valid_number, '高知県高知市針木西');
ok($zip->set_number('7810010')->is_valid_number, '高知県高知市薊野');
ok($zip->set_number('7810011')->is_valid_number, '高知県高知市薊野北町');
ok($zip->set_number('7810012')->is_valid_number, '高知県高知市薊野東町');
ok($zip->set_number('7810013')->is_valid_number, '高知県高知市薊野中町');
ok($zip->set_number('7810014')->is_valid_number, '高知県高知市薊野南町');
ok($zip->set_number('7810015')->is_valid_number, '高知県高知市薊野西町');
ok($zip->set_number('7810073')->is_valid_number, '高知県高知市北金田');
ok($zip->set_number('7810074')->is_valid_number, '高知県高知市南金田');
ok($zip->set_number('7810081')->is_valid_number, '高知県高知市北川添');
ok($zip->set_number('7810082')->is_valid_number, '高知県高知市南川添');
ok($zip->set_number('7810083')->is_valid_number, '高知県高知市北御座');
ok($zip->set_number('7810084')->is_valid_number, '高知県高知市南御座');
ok($zip->set_number('7810085')->is_valid_number, '高知県高知市札場');
ok($zip->set_number('7810086')->is_valid_number, '高知県高知市海老ノ丸');
ok($zip->set_number('7810087')->is_valid_number, '高知県高知市南久保');
ok($zip->set_number('7810088')->is_valid_number, '高知県高知市北久保');
ok($zip->set_number('7810111')->is_valid_number, '高知県高知市池');
ok($zip->set_number('7810112')->is_valid_number, '高知県高知市仁井田');
ok($zip->set_number('7810113')->is_valid_number, '高知県高知市種崎');
ok($zip->set_number('7810114')->is_valid_number, '高知県高知市十津');
ok($zip->set_number('7810240')->is_valid_number, '高知県高知市横浜');
ok($zip->set_number('7810241')->is_valid_number, '高知県高知市横浜新町');
ok($zip->set_number('7810242')->is_valid_number, '高知県高知市横浜西町');
ok($zip->set_number('7810243')->is_valid_number, '高知県高知市横浜東町');
ok($zip->set_number('7810244')->is_valid_number, '高知県高知市横浜南町');
ok($zip->set_number('7810245')->is_valid_number, '高知県高知市長浜蒔絵台');
ok($zip->set_number('7810250')->is_valid_number, '高知県高知市瀬戸');
ok($zip->set_number('7810251')->is_valid_number, '高知県高知市瀬戸西町');
ok($zip->set_number('7810252')->is_valid_number, '高知県高知市瀬戸東町');
ok($zip->set_number('7810253')->is_valid_number, '高知県高知市瀬戸南町');
ok($zip->set_number('7810261')->is_valid_number, '高知県高知市御畳瀬');
ok($zip->set_number('7810262')->is_valid_number, '高知県高知市浦戸');
ok($zip->set_number('7810270')->is_valid_number, '高知県高知市長浜');
ok($zip->set_number('7810271')->is_valid_number, '高知県高知市長浜宮田');
ok($zip->set_number('7810301')->is_valid_number, '高知県高知市春野町弘岡上');
ok($zip->set_number('7810302')->is_valid_number, '高知県高知市春野町弘岡中');
ok($zip->set_number('7810303')->is_valid_number, '高知県高知市春野町弘岡下');
ok($zip->set_number('7810304')->is_valid_number, '高知県高知市春野町西分');
ok($zip->set_number('7810311')->is_valid_number, '高知県高知市春野町芳原');
ok($zip->set_number('7810312')->is_valid_number, '高知県高知市春野町平和');
ok($zip->set_number('7810313')->is_valid_number, '高知県高知市春野町内ノ谷');
ok($zip->set_number('7810314')->is_valid_number, '高知県高知市春野町南ケ丘');
ok($zip->set_number('7810315')->is_valid_number, '高知県高知市春野町東諸木');
ok($zip->set_number('7810316')->is_valid_number, '高知県高知市春野町西諸木');
ok($zip->set_number('7810321')->is_valid_number, '高知県高知市春野町秋山');
ok($zip->set_number('7810322')->is_valid_number, '高知県高知市春野町甲殿');
ok($zip->set_number('7810323')->is_valid_number, '高知県高知市春野町仁ノ');
ok($zip->set_number('7810324')->is_valid_number, '高知県高知市春野町西畑');
ok($zip->set_number('7810325')->is_valid_number, '高知県高知市春野町森山');
ok($zip->set_number('7810801')->is_valid_number, '高知県高知市小倉町');
ok($zip->set_number('7810802')->is_valid_number, '高知県高知市丸池町');
ok($zip->set_number('7810803')->is_valid_number, '高知県高知市弥生町');
ok($zip->set_number('7810804')->is_valid_number, '高知県高知市日の出町');
ok($zip->set_number('7810805')->is_valid_number, '高知県高知市東雲町');
ok($zip->set_number('7810806')->is_valid_number, '高知県高知市知寄町');
ok($zip->set_number('7810811')->is_valid_number, '高知県高知市弘化台');
ok($zip->set_number('7810812')->is_valid_number, '高知県高知市若松町');
ok($zip->set_number('7810813')->is_valid_number, '高知県高知市青柳町');
ok($zip->set_number('7810814')->is_valid_number, '高知県高知市稲荷町');
ok($zip->set_number('7810815')->is_valid_number, '高知県高知市二葉町');
ok($zip->set_number('7810831')->is_valid_number, '高知県高知市中の島');
ok($zip->set_number('7810832')->is_valid_number, '高知県高知市九反田');
ok($zip->set_number('7811100')->is_valid_number, '高知県土佐市以下に掲載がない場合');
ok($zip->set_number('7811101')->is_valid_number, '高知県土佐市高岡町甲');
ok($zip->set_number('7811102')->is_valid_number, '高知県土佐市高岡町乙');
ok($zip->set_number('7811103')->is_valid_number, '高知県土佐市高岡町丙');
ok($zip->set_number('7811104')->is_valid_number, '高知県土佐市高岡町丁');
ok($zip->set_number('7811105')->is_valid_number, '高知県土佐市蓮池');
ok($zip->set_number('7811111')->is_valid_number, '高知県土佐市北地');
ok($zip->set_number('7811112')->is_valid_number, '高知県土佐市福田');
ok($zip->set_number('7811113')->is_valid_number, '高知県土佐市甲原');
ok($zip->set_number('7811114')->is_valid_number, '高知県土佐市谷地');
ok($zip->set_number('7811121')->is_valid_number, '高知県土佐市東鴨地');
ok($zip->set_number('7811122')->is_valid_number, '高知県土佐市本村');
ok($zip->set_number('7811123')->is_valid_number, '高知県土佐市西鴨地');
ok($zip->set_number('7811124')->is_valid_number, '高知県土佐市宮ノ内');
ok($zip->set_number('7811125')->is_valid_number, '高知県土佐市積善寺');
ok($zip->set_number('7811131')->is_valid_number, '高知県土佐市永野');
ok($zip->set_number('7811132')->is_valid_number, '高知県土佐市市野々');
ok($zip->set_number('7811133')->is_valid_number, '高知県土佐市鷹ノ巣');
ok($zip->set_number('7811134')->is_valid_number, '高知県土佐市家俊');
ok($zip->set_number('7811135')->is_valid_number, '高知県土佐市太郎丸');
ok($zip->set_number('7811136')->is_valid_number, '高知県土佐市浅井');
ok($zip->set_number('7811141')->is_valid_number, '高知県土佐市岩戸');
ok($zip->set_number('7811142')->is_valid_number, '高知県土佐市出間');
ok($zip->set_number('7811143')->is_valid_number, '高知県土佐市波介');
ok($zip->set_number('7811151')->is_valid_number, '高知県土佐市中島');
ok($zip->set_number('7811152')->is_valid_number, '高知県土佐市用石');
ok($zip->set_number('7811153')->is_valid_number, '高知県土佐市塚地');
ok($zip->set_number('7811154')->is_valid_number, '高知県土佐市新居');
ok($zip->set_number('7811161')->is_valid_number, '高知県土佐市宇佐町宇佐');
ok($zip->set_number('7811162')->is_valid_number, '高知県土佐市宇佐町渭浜');
ok($zip->set_number('7811163')->is_valid_number, '高知県土佐市宇佐町福島');
ok($zip->set_number('7811164')->is_valid_number, '高知県土佐市宇佐町井尻');
ok($zip->set_number('7811165')->is_valid_number, '高知県土佐市宇佐町竜');
ok($zip->set_number('7811300')->is_valid_number, '高知県高岡郡越知町以下に掲載がない場合');
ok($zip->set_number('7811301')->is_valid_number, '高知県高岡郡越知町越知甲');
ok($zip->set_number('7811302')->is_valid_number, '高知県高岡郡越知町越知乙');
ok($zip->set_number('7811303')->is_valid_number, '高知県高岡郡越知町越知丙');
ok($zip->set_number('7811304')->is_valid_number, '高知県高岡郡越知町越知丁');
ok($zip->set_number('7811305')->is_valid_number, '高知県高岡郡越知町野老山');
ok($zip->set_number('7811306')->is_valid_number, '高知県高岡郡越知町山室');
ok($zip->set_number('7811307')->is_valid_number, '高知県高岡郡越知町柴尾');
ok($zip->set_number('7811308')->is_valid_number, '高知県高岡郡越知町宮地');
ok($zip->set_number('7811311')->is_valid_number, '高知県高岡郡越知町今成');
ok($zip->set_number('7811312')->is_valid_number, '高知県高岡郡越知町横畠南');
ok($zip->set_number('7811313')->is_valid_number, '高知県高岡郡越知町横畠東');
ok($zip->set_number('7811314')->is_valid_number, '高知県高岡郡越知町横畠中');
ok($zip->set_number('7811315')->is_valid_number, '高知県高岡郡越知町横畠北');
ok($zip->set_number('7811321')->is_valid_number, '高知県高岡郡越知町鎌井田本村');
ok($zip->set_number('7811322')->is_valid_number, '高知県高岡郡越知町鎌井田桑薮');
ok($zip->set_number('7811323')->is_valid_number, '高知県高岡郡越知町鎌井田日ノ浦');
ok($zip->set_number('7811324')->is_valid_number, '高知県高岡郡越知町鎌井田清助');
ok($zip->set_number('7811325')->is_valid_number, '高知県高岡郡越知町浅尾');
ok($zip->set_number('7811326')->is_valid_number, '高知県高岡郡越知町片岡');
ok($zip->set_number('7811327')->is_valid_number, '高知県高岡郡越知町黒瀬');
ok($zip->set_number('7811328')->is_valid_number, '高知県高岡郡越知町南片岡');
ok($zip->set_number('7811331')->is_valid_number, '高知県高岡郡越知町五味');
ok($zip->set_number('7811332')->is_valid_number, '高知県高岡郡越知町中大平');
ok($zip->set_number('7811333')->is_valid_number, '高知県高岡郡越知町大平');
ok($zip->set_number('7811334')->is_valid_number, '高知県高岡郡越知町桐見川');
ok($zip->set_number('7811335')->is_valid_number, '高知県高岡郡越知町長者');
ok($zip->set_number('7811336')->is_valid_number, '高知県高岡郡越知町南ノ川');
ok($zip->set_number('7811337')->is_valid_number, '高知県高岡郡越知町佐之国');
ok($zip->set_number('7811338')->is_valid_number, '高知県高岡郡越知町峰');
ok($zip->set_number('7811500')->is_valid_number, '高知県吾川郡仁淀川町以下に掲載がない場合');
ok($zip->set_number('7811501')->is_valid_number, '高知県吾川郡仁淀川町大崎');
ok($zip->set_number('7811502')->is_valid_number, '高知県吾川郡仁淀川町川口');
ok($zip->set_number('7811503')->is_valid_number, '高知県吾川郡仁淀川町橘谷');
ok($zip->set_number('7811504')->is_valid_number, '高知県吾川郡仁淀川町藤ノ野');
ok($zip->set_number('7811505')->is_valid_number, '高知県吾川郡仁淀川町桜');
ok($zip->set_number('7811506')->is_valid_number, '高知県吾川郡仁淀川町鹿森');
ok($zip->set_number('7811511')->is_valid_number, '高知県吾川郡仁淀川町寺村');
ok($zip->set_number('7811512')->is_valid_number, '高知県吾川郡仁淀川町岩戸');
ok($zip->set_number('7811513')->is_valid_number, '高知県吾川郡仁淀川町峯岩戸');
ok($zip->set_number('7811514')->is_valid_number, '高知県吾川郡仁淀川町大板');
ok($zip->set_number('7811515')->is_valid_number, '高知県吾川郡仁淀川町蕨谷');
ok($zip->set_number('7811516')->is_valid_number, '高知県吾川郡仁淀川町中村');
ok($zip->set_number('7811517')->is_valid_number, '高知県吾川郡仁淀川町葛原');
ok($zip->set_number('7811518')->is_valid_number, '高知県吾川郡仁淀川町加枝');
ok($zip->set_number('7811520')->is_valid_number, '高知県吾川郡仁淀川町大蕨');
ok($zip->set_number('7811521')->is_valid_number, '高知県吾川郡仁淀川町本村');
ok($zip->set_number('7811522')->is_valid_number, '高知県吾川郡仁淀川町田村');
ok($zip->set_number('7811523')->is_valid_number, '高知県吾川郡仁淀川町宗津');
ok($zip->set_number('7811524')->is_valid_number, '高知県吾川郡仁淀川町長屋');
ok($zip->set_number('7811531')->is_valid_number, '高知県吾川郡仁淀川町久喜');
ok($zip->set_number('7811532')->is_valid_number, '高知県吾川郡仁淀川町相能');
ok($zip->set_number('7811533')->is_valid_number, '高知県吾川郡仁淀川町引地');
ok($zip->set_number('7811534')->is_valid_number, '高知県吾川郡仁淀川町遅越');
ok($zip->set_number('7811535')->is_valid_number, '高知県吾川郡仁淀川町二子野');
ok($zip->set_number('7811601')->is_valid_number, '高知県吾川郡仁淀川町大平');
ok($zip->set_number('7811602')->is_valid_number, '高知県吾川郡仁淀川町楮原');
ok($zip->set_number('7811603')->is_valid_number, '高知県吾川郡仁淀川町日浦');
ok($zip->set_number('7811604')->is_valid_number, '高知県吾川郡仁淀川町見ノ越');
ok($zip->set_number('7811605')->is_valid_number, '高知県吾川郡仁淀川町川内谷');
ok($zip->set_number('7811606')->is_valid_number, '高知県吾川郡仁淀川町土居(甲・乙)');
ok($zip->set_number('7811607')->is_valid_number, '高知県吾川郡仁淀川町北浦');
ok($zip->set_number('7811608')->is_valid_number, '高知県吾川郡仁淀川町坂本');
ok($zip->set_number('7811609')->is_valid_number, '高知県吾川郡仁淀川町寄合');
ok($zip->set_number('7811610')->is_valid_number, '高知県吾川郡仁淀川町竹ノ谷');
ok($zip->set_number('7811611')->is_valid_number, '高知県吾川郡仁淀川町岩丸');
ok($zip->set_number('7811612')->is_valid_number, '高知県吾川郡仁淀川町池川大渡');
ok($zip->set_number('7811613')->is_valid_number, '高知県吾川郡仁淀川町明戸岩');
ok($zip->set_number('7811614')->is_valid_number, '高知県吾川郡仁淀川町大西');
ok($zip->set_number('7811615')->is_valid_number, '高知県吾川郡仁淀川町岩柄');
ok($zip->set_number('7811616')->is_valid_number, '高知県吾川郡仁淀川町百川内');
ok($zip->set_number('7811617')->is_valid_number, '高知県吾川郡仁淀川町大野');
ok($zip->set_number('7811618')->is_valid_number, '高知県吾川郡仁淀川町椿山');
ok($zip->set_number('7811619')->is_valid_number, '高知県吾川郡仁淀川町用居甲(出丸、舟形、用居)');
ok($zip->set_number('7811620')->is_valid_number, '高知県吾川郡仁淀川町用居乙(瓜生野、折尾、桧谷)');
ok($zip->set_number('7811621')->is_valid_number, '高知県吾川郡仁淀川町入江谷');
ok($zip->set_number('7811622')->is_valid_number, '高知県吾川郡仁淀川町成川');
ok($zip->set_number('7811623')->is_valid_number, '高知県吾川郡仁淀川町余能');
ok($zip->set_number('7811624')->is_valid_number, '高知県吾川郡仁淀川町土居(その他)');
ok($zip->set_number('7811625')->is_valid_number, '高知県吾川郡仁淀川町吉ケ成');
ok($zip->set_number('7811626')->is_valid_number, '高知県吾川郡仁淀川町坪井川');
ok($zip->set_number('7811627')->is_valid_number, '高知県吾川郡仁淀川町宮ケ平');
ok($zip->set_number('7811628')->is_valid_number, '高知県吾川郡仁淀川町大屋');
ok($zip->set_number('7811741')->is_valid_number, '高知県吾川郡仁淀川町名野川');
ok($zip->set_number('7811742')->is_valid_number, '高知県吾川郡仁淀川町竹屋敷');
ok($zip->set_number('7811743')->is_valid_number, '高知県吾川郡仁淀川町崎ノ山');
ok($zip->set_number('7811744')->is_valid_number, '高知県吾川郡仁淀川町名野川大平');
ok($zip->set_number('7811745')->is_valid_number, '高知県吾川郡仁淀川町下北川');
ok($zip->set_number('7811746')->is_valid_number, '高知県吾川郡仁淀川町北川');
ok($zip->set_number('7811751')->is_valid_number, '高知県吾川郡仁淀川町大渡');
ok($zip->set_number('7811752')->is_valid_number, '高知県吾川郡仁淀川町峠ノ越');
ok($zip->set_number('7811753')->is_valid_number, '高知県吾川郡仁淀川町潰溜');
ok($zip->set_number('7811754')->is_valid_number, '高知県吾川郡仁淀川町北');
ok($zip->set_number('7811755')->is_valid_number, '高知県吾川郡仁淀川町森山');
ok($zip->set_number('7811756')->is_valid_number, '高知県吾川郡仁淀川町大尾');
ok($zip->set_number('7811757')->is_valid_number, '高知県吾川郡仁淀川町鷲ノ巣');
ok($zip->set_number('7811758')->is_valid_number, '高知県吾川郡仁淀川町橘');
ok($zip->set_number('7811761')->is_valid_number, '高知県吾川郡仁淀川町二ノ滝');
ok($zip->set_number('7811762')->is_valid_number, '高知県吾川郡仁淀川町下名野川');
ok($zip->set_number('7811763')->is_valid_number, '高知県吾川郡仁淀川町中');
ok($zip->set_number('7811764')->is_valid_number, '高知県吾川郡仁淀川町長坂');
ok($zip->set_number('7811765')->is_valid_number, '高知県吾川郡仁淀川町津江');
ok($zip->set_number('7811766')->is_valid_number, '高知県吾川郡仁淀川町上名野川');
ok($zip->set_number('7811801')->is_valid_number, '高知県吾川郡仁淀川町森');
ok($zip->set_number('7811802')->is_valid_number, '高知県吾川郡仁淀川町高瀬');
ok($zip->set_number('7811803')->is_valid_number, '高知県吾川郡仁淀川町別枝');
ok($zip->set_number('7811804')->is_valid_number, '高知県吾川郡仁淀川町川渡');
ok($zip->set_number('7811911')->is_valid_number, '高知県吾川郡仁淀川町長者乙');
ok($zip->set_number('7811912')->is_valid_number, '高知県吾川郡仁淀川町長者丁');
ok($zip->set_number('7811913')->is_valid_number, '高知県吾川郡仁淀川町長者丙');
ok($zip->set_number('7811914')->is_valid_number, '高知県吾川郡仁淀川町泉');
ok($zip->set_number('7811915')->is_valid_number, '高知県吾川郡仁淀川町大植');
ok($zip->set_number('7812100')->is_valid_number, '高知県吾川郡いの町以下に掲載がない場合');
ok($zip->set_number('7812100')->is_valid_number, '高知県高岡郡日高村以下に掲載がない場合');
ok($zip->set_number('7812101')->is_valid_number, '高知県吾川郡いの町大国町');
ok($zip->set_number('7812102')->is_valid_number, '高知県吾川郡いの町公園町');
ok($zip->set_number('7812103')->is_valid_number, '高知県吾川郡いの町幸町');
ok($zip->set_number('7812104')->is_valid_number, '高知県吾川郡いの町藤町');
ok($zip->set_number('7812105')->is_valid_number, '高知県吾川郡いの町新町');
ok($zip->set_number('7812106')->is_valid_number, '高知県吾川郡いの町駅南町');
ok($zip->set_number('7812107')->is_valid_number, '高知県吾川郡いの町駅前町');
ok($zip->set_number('7812108')->is_valid_number, '高知県吾川郡いの町駅東町');
ok($zip->set_number('7812110')->is_valid_number, '高知県吾川郡いの町いの町の次に番地がくる場合');
ok($zip->set_number('7812111')->is_valid_number, '高知県吾川郡いの町羽根町');
ok($zip->set_number('7812112')->is_valid_number, '高知県吾川郡いの町西町');
ok($zip->set_number('7812113')->is_valid_number, '高知県吾川郡いの町元町');
ok($zip->set_number('7812114')->is_valid_number, '高知県吾川郡いの町加茂町');
ok($zip->set_number('7812115')->is_valid_number, '高知県吾川郡いの町旭町');
ok($zip->set_number('7812116')->is_valid_number, '高知県吾川郡いの町柳町');
ok($zip->set_number('7812117')->is_valid_number, '高知県吾川郡いの町内野東町');
ok($zip->set_number('7812118')->is_valid_number, '高知県吾川郡いの町内野南町');
ok($zip->set_number('7812119')->is_valid_number, '高知県吾川郡いの町内野北町');
ok($zip->set_number('7812120')->is_valid_number, '高知県吾川郡いの町枝川');
ok($zip->set_number('7812121')->is_valid_number, '高知県吾川郡いの町池の内');
ok($zip->set_number('7812122')->is_valid_number, '高知県吾川郡いの町天王北');
ok($zip->set_number('7812123')->is_valid_number, '高知県吾川郡いの町天王南');
ok($zip->set_number('7812124')->is_valid_number, '高知県吾川郡いの町八田');
ok($zip->set_number('7812126')->is_valid_number, '高知県吾川郡いの町大内');
ok($zip->set_number('7812127')->is_valid_number, '高知県吾川郡いの町鎌田');
ok($zip->set_number('7812128')->is_valid_number, '高知県吾川郡いの町波川');
ok($zip->set_number('7812131')->is_valid_number, '高知県吾川郡いの町槇');
ok($zip->set_number('7812132')->is_valid_number, '高知県吾川郡いの町成山');
ok($zip->set_number('7812133')->is_valid_number, '高知県吾川郡いの町加田');
ok($zip->set_number('7812134')->is_valid_number, '高知県吾川郡いの町神谷');
ok($zip->set_number('7812135')->is_valid_number, '高知県吾川郡いの町小野');
ok($zip->set_number('7812136')->is_valid_number, '高知県吾川郡いの町鹿敷');
ok($zip->set_number('7812141')->is_valid_number, '高知県吾川郡いの町勝賀瀬');
ok($zip->set_number('7812142')->is_valid_number, '高知県吾川郡いの町中追');
ok($zip->set_number('7812143')->is_valid_number, '高知県吾川郡いの町楠瀬');
ok($zip->set_number('7812144')->is_valid_number, '高知県吾川郡いの町柳瀬本村');
ok($zip->set_number('7812145')->is_valid_number, '高知県吾川郡いの町柳瀬石見');
ok($zip->set_number('7812146')->is_valid_number, '高知県吾川郡いの町柳瀬上分');
ok($zip->set_number('7812151')->is_valid_number, '高知県高岡郡日高村下分');
ok($zip->set_number('7812152')->is_valid_number, '高知県高岡郡日高村沖名');
ok($zip->set_number('7812153')->is_valid_number, '高知県高岡郡日高村本郷');
ok($zip->set_number('7812154')->is_valid_number, '高知県高岡郡日高村岩目地');
ok($zip->set_number('7812155')->is_valid_number, '高知県高岡郡日高村九頭');
ok($zip->set_number('7812161')->is_valid_number, '高知県高岡郡日高村柱谷');
ok($zip->set_number('7812162')->is_valid_number, '高知県高岡郡日高村名越屋');
ok($zip->set_number('7812163')->is_valid_number, '高知県高岡郡日高村大花');
ok($zip->set_number('7812164')->is_valid_number, '高知県高岡郡日高村本村');
ok($zip->set_number('7812165')->is_valid_number, '高知県高岡郡日高村宮ノ谷');
ok($zip->set_number('7812166')->is_valid_number, '高知県高岡郡日高村長畑');
ok($zip->set_number('7812167')->is_valid_number, '高知県高岡郡日高村鴨地');
ok($zip->set_number('7812321')->is_valid_number, '高知県吾川郡いの町小川東津賀才');
ok($zip->set_number('7812322')->is_valid_number, '高知県吾川郡いの町小川西津賀才');
ok($zip->set_number('7812323')->is_valid_number, '高知県吾川郡いの町小川樅ノ木山');
ok($zip->set_number('7812324')->is_valid_number, '高知県吾川郡いの町小川新別');
ok($zip->set_number('7812325')->is_valid_number, '高知県吾川郡いの町小川柳野');
ok($zip->set_number('7812331')->is_valid_number, '高知県吾川郡いの町下八川甲');
ok($zip->set_number('7812332')->is_valid_number, '高知県吾川郡いの町下八川乙');
ok($zip->set_number('7812333')->is_valid_number, '高知県吾川郡いの町下八川丙');
ok($zip->set_number('7812334')->is_valid_number, '高知県吾川郡いの町下八川丁');
ok($zip->set_number('7812335')->is_valid_number, '高知県吾川郡いの町下八川十田');
ok($zip->set_number('7812401')->is_valid_number, '高知県吾川郡いの町上八川甲(枝川、大久保、木ノ瀬、土居、西川、本郷、柚ノ木野)');
ok($zip->set_number('7812402')->is_valid_number, '高知県吾川郡いの町上八川丙(柿薮、小申田、津賀谷、寺野、古江、連行)');
ok($zip->set_number('7812511')->is_valid_number, '高知県吾川郡いの町清水上分(伊守川、川窪、敷槇、土居、程野)');
ok($zip->set_number('7812512')->is_valid_number, '高知県吾川郡いの町清水下分(馬路、大野、川口、日比原、槇川、松ノ木)');
ok($zip->set_number('7812601')->is_valid_number, '高知県吾川郡いの町長沢');
ok($zip->set_number('7812602')->is_valid_number, '高知県吾川郡いの町戸中');
ok($zip->set_number('7812603')->is_valid_number, '高知県吾川郡いの町大森');
ok($zip->set_number('7812604')->is_valid_number, '高知県吾川郡いの町越裏門');
ok($zip->set_number('7812605')->is_valid_number, '高知県吾川郡いの町寺川');
ok($zip->set_number('7812611')->is_valid_number, '高知県吾川郡いの町脇ノ山');
ok($zip->set_number('7812612')->is_valid_number, '高知県吾川郡いの町高薮');
ok($zip->set_number('7812613')->is_valid_number, '高知県吾川郡いの町足谷');
ok($zip->set_number('7812614')->is_valid_number, '高知県吾川郡いの町葛原');
ok($zip->set_number('7812615')->is_valid_number, '高知県吾川郡いの町桑瀬');
ok($zip->set_number('7812616')->is_valid_number, '高知県吾川郡いの町中野川');
ok($zip->set_number('7813101')->is_valid_number, '高知県高知市鏡大河内');
ok($zip->set_number('7813102')->is_valid_number, '高知県高知市鏡小浜');
ok($zip->set_number('7813103')->is_valid_number, '高知県高知市鏡大利');
ok($zip->set_number('7813104')->is_valid_number, '高知県高知市鏡今井');
ok($zip->set_number('7813105')->is_valid_number, '高知県高知市鏡草峰');
ok($zip->set_number('7813106')->is_valid_number, '高知県高知市鏡白岩');
ok($zip->set_number('7813107')->is_valid_number, '高知県高知市鏡狩山');
ok($zip->set_number('7813108')->is_valid_number, '高知県高知市鏡吉原');
ok($zip->set_number('7813111')->is_valid_number, '高知県高知市鏡的渕');
ok($zip->set_number('7813112')->is_valid_number, '高知県高知市鏡去坂');
ok($zip->set_number('7813113')->is_valid_number, '高知県高知市鏡竹奈路');
ok($zip->set_number('7813114')->is_valid_number, '高知県高知市鏡敷ノ山');
ok($zip->set_number('7813115')->is_valid_number, '高知県高知市鏡柿ノ又');
ok($zip->set_number('7813121')->is_valid_number, '高知県高知市鏡横矢');
ok($zip->set_number('7813122')->is_valid_number, '高知県高知市鏡増原');
ok($zip->set_number('7813123')->is_valid_number, '高知県高知市鏡葛山');
ok($zip->set_number('7813124')->is_valid_number, '高知県高知市鏡梅ノ木');
ok($zip->set_number('7813125')->is_valid_number, '高知県高知市鏡小山');
ok($zip->set_number('7813201')->is_valid_number, '高知県高知市土佐山');
ok($zip->set_number('7813202')->is_valid_number, '高知県高知市土佐山都網');
ok($zip->set_number('7813203')->is_valid_number, '高知県高知市土佐山弘瀬');
ok($zip->set_number('7813211')->is_valid_number, '高知県高知市土佐山高川');
ok($zip->set_number('7813212')->is_valid_number, '高知県高知市土佐山梶谷');
ok($zip->set_number('7813213')->is_valid_number, '高知県高知市土佐山西川');
ok($zip->set_number('7813214')->is_valid_number, '高知県高知市土佐山菖蒲');
ok($zip->set_number('7813221')->is_valid_number, '高知県高知市土佐山桑尾');
ok($zip->set_number('7813222')->is_valid_number, '高知県高知市土佐山東川');
ok($zip->set_number('7813223')->is_valid_number, '高知県高知市土佐山中切');
ok($zip->set_number('7813331')->is_valid_number, '高知県土佐郡土佐町地蔵寺');
ok($zip->set_number('7813332')->is_valid_number, '高知県土佐郡土佐町栗木');
ok($zip->set_number('7813333')->is_valid_number, '高知県土佐郡土佐町東石原');
ok($zip->set_number('7813334')->is_valid_number, '高知県土佐郡土佐町西石原');
ok($zip->set_number('7813335')->is_valid_number, '高知県土佐郡土佐町有間');
ok($zip->set_number('7813336')->is_valid_number, '高知県土佐郡土佐町芥川');
ok($zip->set_number('7813337')->is_valid_number, '高知県土佐郡土佐町瀬戸');
ok($zip->set_number('7813400')->is_valid_number, '高知県土佐郡土佐町以下に掲載がない場合');
ok($zip->set_number('7813401')->is_valid_number, '高知県土佐郡土佐町土居');
ok($zip->set_number('7813402')->is_valid_number, '高知県土佐郡土佐町境');
ok($zip->set_number('7813403')->is_valid_number, '高知県土佐郡土佐町宮古野');
ok($zip->set_number('7813404')->is_valid_number, '高知県土佐郡土佐町溜井');
ok($zip->set_number('7813405')->is_valid_number, '高知県土佐郡土佐町南泉');
ok($zip->set_number('7813406')->is_valid_number, '高知県土佐郡土佐町高須');
ok($zip->set_number('7813407')->is_valid_number, '高知県土佐郡土佐町樫山');
ok($zip->set_number('7813408')->is_valid_number, '高知県土佐郡土佐町相川');
ok($zip->set_number('7813409')->is_valid_number, '高知県土佐郡土佐町和田');
ok($zip->set_number('7813521')->is_valid_number, '高知県土佐郡土佐町田井');
ok($zip->set_number('7813522')->is_valid_number, '高知県土佐郡土佐町大渕');
ok($zip->set_number('7813523')->is_valid_number, '高知県土佐郡土佐町古味');
ok($zip->set_number('7813524')->is_valid_number, '高知県土佐郡土佐町井尻');
ok($zip->set_number('7813525')->is_valid_number, '高知県土佐郡土佐町下川');
ok($zip->set_number('7813526')->is_valid_number, '高知県土佐郡土佐町上津川');
ok($zip->set_number('7813600')->is_valid_number, '高知県長岡郡本山町以下に掲載がない場合');
ok($zip->set_number('7813601')->is_valid_number, '高知県長岡郡本山町本山');
ok($zip->set_number('7813602')->is_valid_number, '高知県長岡郡本山町大石');
ok($zip->set_number('7813603')->is_valid_number, '高知県長岡郡本山町吉延');
ok($zip->set_number('7813604')->is_valid_number, '高知県長岡郡本山町井窪');
ok($zip->set_number('7813605')->is_valid_number, '高知県長岡郡本山町下津野');
ok($zip->set_number('7813606')->is_valid_number, '高知県長岡郡本山町高角');
ok($zip->set_number('7813607')->is_valid_number, '高知県長岡郡本山町古田');
ok($zip->set_number('7813608')->is_valid_number, '高知県長岡郡本山町木能津');
ok($zip->set_number('7813609')->is_valid_number, '高知県長岡郡本山町助藤');
ok($zip->set_number('7813610')->is_valid_number, '高知県長岡郡本山町下関');
ok($zip->set_number('7813611')->is_valid_number, '高知県長岡郡本山町上関甲');
ok($zip->set_number('7813612')->is_valid_number, '高知県長岡郡本山町上関乙');
ok($zip->set_number('7813613')->is_valid_number, '高知県長岡郡本山町北山甲');
ok($zip->set_number('7813614')->is_valid_number, '高知県長岡郡本山町北山乙');
ok($zip->set_number('7813615')->is_valid_number, '高知県長岡郡本山町北山丙');
ok($zip->set_number('7813617')->is_valid_number, '高知県長岡郡本山町寺家');
ok($zip->set_number('7813618')->is_valid_number, '高知県長岡郡本山町吉野');
ok($zip->set_number('7813619')->is_valid_number, '高知県長岡郡本山町立野');
ok($zip->set_number('7813620')->is_valid_number, '高知県長岡郡本山町坂本');
ok($zip->set_number('7813621')->is_valid_number, '高知県長岡郡本山町屋所');
ok($zip->set_number('7813622')->is_valid_number, '高知県長岡郡本山町沢ケ内');
ok($zip->set_number('7813623')->is_valid_number, '高知県長岡郡本山町瓜生野');
ok($zip->set_number('7813624')->is_valid_number, '高知県長岡郡本山町七戸');
ok($zip->set_number('7813700')->is_valid_number, '高知県土佐郡大川村以下に掲載がない場合');
ok($zip->set_number('7813701')->is_valid_number, '高知県土佐郡大川村船戸(その他)');
ok($zip->set_number('7813702')->is_valid_number, '高知県土佐郡大川村船戸(桃ケ谷)');
ok($zip->set_number('7813703')->is_valid_number, '高知県土佐郡大川村小松');
ok($zip->set_number('7813704')->is_valid_number, '高知県土佐郡大川村朝谷');
ok($zip->set_number('7813705')->is_valid_number, '高知県土佐郡大川村大北川');
ok($zip->set_number('7813711')->is_valid_number, '高知県土佐郡大川村高野');
ok($zip->set_number('7813712')->is_valid_number, '高知県土佐郡大川村川崎');
ok($zip->set_number('7813713')->is_valid_number, '高知県土佐郡大川村井野川');
ok($zip->set_number('7813714')->is_valid_number, '高知県土佐郡大川村大平');
ok($zip->set_number('7813715')->is_valid_number, '高知県土佐郡大川村小麦畝');
ok($zip->set_number('7813716')->is_valid_number, '高知県土佐郡大川村小北川');
ok($zip->set_number('7813717')->is_valid_number, '高知県土佐郡大川村大薮');
ok($zip->set_number('7813721')->is_valid_number, '高知県土佐郡大川村中切');
ok($zip->set_number('7813722')->is_valid_number, '高知県土佐郡大川村下小南川');
ok($zip->set_number('7813723')->is_valid_number, '高知県土佐郡大川村上小南川');
ok($zip->set_number('7813724')->is_valid_number, '高知県土佐郡大川村南野山');
ok($zip->set_number('7813725')->is_valid_number, '高知県土佐郡大川村下切');
ok($zip->set_number('7813741')->is_valid_number, '高知県土佐郡土佐町柚ノ木');
ok($zip->set_number('7813742')->is_valid_number, '高知県土佐郡土佐町南川');
ok($zip->set_number('7814201')->is_valid_number, '高知県香美市香北町永瀬');
ok($zip->set_number('7814202')->is_valid_number, '高知県香美市香北町蕨野');
ok($zip->set_number('7814203')->is_valid_number, '高知県香美市香北町白石');
ok($zip->set_number('7814204')->is_valid_number, '高知県香美市香北町根須');
ok($zip->set_number('7814205')->is_valid_number, '高知県香美市香北町吉野');
ok($zip->set_number('7814206')->is_valid_number, '高知県香美市香北町小川');
ok($zip->set_number('7814207')->is_valid_number, '高知県香美市香北町西川乙');
ok($zip->set_number('7814208')->is_valid_number, '高知県香美市香北町西川甲');
ok($zip->set_number('7814211')->is_valid_number, '高知県香美市香北町韮生野');
ok($zip->set_number('7814212')->is_valid_number, '高知県香美市香北町美良布');
ok($zip->set_number('7814213')->is_valid_number, '高知県香美市香北町下野尻');
ok($zip->set_number('7814214')->is_valid_number, '高知県香美市香北町太郎丸');
ok($zip->set_number('7814215')->is_valid_number, '高知県香美市香北町岩改');
ok($zip->set_number('7814216')->is_valid_number, '高知県香美市香北町萩野');
ok($zip->set_number('7814217')->is_valid_number, '高知県香美市香北町橋川野');
ok($zip->set_number('7814221')->is_valid_number, '高知県香美市香北町白川');
ok($zip->set_number('7814222')->is_valid_number, '高知県香美市香北町五百蔵');
ok($zip->set_number('7814223')->is_valid_number, '高知県香美市香北町有川');
ok($zip->set_number('7814224')->is_valid_number, '高知県香美市香北町有瀬');
ok($zip->set_number('7814225')->is_valid_number, '高知県香美市香北町西峯');
ok($zip->set_number('7814226')->is_valid_number, '高知県香美市香北町河野');
ok($zip->set_number('7814227')->is_valid_number, '高知県香美市香北町川ノ内');
ok($zip->set_number('7814231')->is_valid_number, '高知県香美市香北町日ノ御子');
ok($zip->set_number('7814232')->is_valid_number, '高知県香美市香北町谷相');
ok($zip->set_number('7814233')->is_valid_number, '高知県香美市香北町中谷');
ok($zip->set_number('7814234')->is_valid_number, '高知県香美市香北町横谷');
ok($zip->set_number('7814235')->is_valid_number, '高知県香美市香北町朴ノ木');
ok($zip->set_number('7814236')->is_valid_number, '高知県香美市香北町永野');
ok($zip->set_number('7814241')->is_valid_number, '高知県香美市香北町大井平');
ok($zip->set_number('7814242')->is_valid_number, '高知県香美市香北町大束');
ok($zip->set_number('7814243')->is_valid_number, '高知県香美市香北町梅久保');
ok($zip->set_number('7814244')->is_valid_number, '高知県香美市香北町日浦込');
ok($zip->set_number('7814245')->is_valid_number, '高知県香美市香北町清爪');
ok($zip->set_number('7814246')->is_valid_number, '高知県香美市香北町日比原');
ok($zip->set_number('7814247')->is_valid_number, '高知県香美市香北町猪野々');
ok($zip->set_number('7814401')->is_valid_number, '高知県香美市物部町大栃');
ok($zip->set_number('7814402')->is_valid_number, '高知県香美市物部町山崎(その他)');
ok($zip->set_number('7814403')->is_valid_number, '高知県香美市物部町押谷');
ok($zip->set_number('7814404')->is_valid_number, '高知県香美市物部町小浜');
ok($zip->set_number('7814405')->is_valid_number, '高知県香美市物部町根木屋');
ok($zip->set_number('7814406')->is_valid_number, '高知県香美市物部町仙頭');
ok($zip->set_number('7814411')->is_valid_number, '高知県香美市物部町中谷川');
ok($zip->set_number('7814412')->is_valid_number, '高知県香美市物部町拓');
ok($zip->set_number('7814413')->is_valid_number, '高知県香美市物部町庄谷相');
ok($zip->set_number('7814414')->is_valid_number, '高知県香美市物部町頓定');
ok($zip->set_number('7814415')->is_valid_number, '高知県香美市物部町舞川');
ok($zip->set_number('7814521')->is_valid_number, '高知県香美市物部町安丸');
ok($zip->set_number('7814522')->is_valid_number, '高知県香美市物部町黒代');
ok($zip->set_number('7814523')->is_valid_number, '高知県香美市物部町神池');
ok($zip->set_number('7814524')->is_valid_number, '高知県香美市物部町楮佐古');
ok($zip->set_number('7814525')->is_valid_number, '高知県香美市物部町柳瀬');
ok($zip->set_number('7814526')->is_valid_number, '高知県香美市物部町五王堂');
ok($zip->set_number('7814527')->is_valid_number, '高知県香美市物部町南池');
ok($zip->set_number('7814528')->is_valid_number, '高知県香美市物部町大西');
ok($zip->set_number('7814529')->is_valid_number, '高知県香美市物部町中上');
ok($zip->set_number('7814530')->is_valid_number, '高知県香美市物部町笹');
ok($zip->set_number('7814531')->is_valid_number, '高知県香美市物部町久保');
ok($zip->set_number('7814641')->is_valid_number, '高知県香美市物部町岡ノ内');
ok($zip->set_number('7814642')->is_valid_number, '高知県香美市物部町別役');
ok($zip->set_number('7814643')->is_valid_number, '高知県香美市物部町市宇');
ok($zip->set_number('7814644')->is_valid_number, '高知県香美市物部町別府');
ok($zip->set_number('7814645')->is_valid_number, '高知県香美市物部町山崎(桑ノ川)');
ok($zip->set_number('7815101')->is_valid_number, '高知県高知市布師田');
ok($zip->set_number('7815102')->is_valid_number, '高知県高知市大津甲');
ok($zip->set_number('7815103')->is_valid_number, '高知県高知市大津乙');
ok($zip->set_number('7815104')->is_valid_number, '高知県高知市介良(その他)');
ok($zip->set_number('7815105')->is_valid_number, '高知県高知市介良甲');
ok($zip->set_number('7815106')->is_valid_number, '高知県高知市介良乙');
ok($zip->set_number('7815107')->is_valid_number, '高知県高知市介良丙');
ok($zip->set_number('7815108')->is_valid_number, '高知県高知市潮見台');
ok($zip->set_number('7815200')->is_valid_number, '高知県香南市以下に掲載がない場合');
ok($zip->set_number('7815201')->is_valid_number, '高知県香南市野市町本村');
ok($zip->set_number('7815202')->is_valid_number, '高知県香南市野市町兎田');
ok($zip->set_number('7815203')->is_valid_number, '高知県香南市野市町中山田');
ok($zip->set_number('7815204')->is_valid_number, '高知県香南市野市町新宮');
ok($zip->set_number('7815205')->is_valid_number, '高知県香南市野市町みどり野東');
ok($zip->set_number('7815206')->is_valid_number, '高知県香南市野市町みどり野');
ok($zip->set_number('7815211')->is_valid_number, '高知県香南市野市町中ノ村');
ok($zip->set_number('7815212')->is_valid_number, '高知県香南市野市町土居');
ok($zip->set_number('7815213')->is_valid_number, '高知県香南市野市町東野');
ok($zip->set_number('7815221')->is_valid_number, '高知県香南市野市町父養寺');
ok($zip->set_number('7815222')->is_valid_number, '高知県香南市野市町母代寺');
ok($zip->set_number('7815223')->is_valid_number, '高知県香南市野市町西佐古');
ok($zip->set_number('7815224')->is_valid_number, '高知県香南市野市町東佐古');
ok($zip->set_number('7815231')->is_valid_number, '高知県香南市野市町深渕');
ok($zip->set_number('7815232')->is_valid_number, '高知県香南市野市町西野');
ok($zip->set_number('7815233')->is_valid_number, '高知県香南市野市町大谷');
ok($zip->set_number('7815234')->is_valid_number, '高知県香南市野市町上岡');
ok($zip->set_number('7815235')->is_valid_number, '高知県香南市野市町下井');
ok($zip->set_number('7815241')->is_valid_number, '高知県香南市吉川町吉原');
ok($zip->set_number('7815242')->is_valid_number, '高知県香南市吉川町古川');
ok($zip->set_number('7815310')->is_valid_number, '高知県香南市赤岡町');
ok($zip->set_number('7815331')->is_valid_number, '高知県香南市香我美町岸本');
ok($zip->set_number('7815332')->is_valid_number, '高知県香南市香我美町徳王子');
ok($zip->set_number('7815451')->is_valid_number, '高知県香南市香我美町上分');
ok($zip->set_number('7815452')->is_valid_number, '高知県香南市香我美町下分');
ok($zip->set_number('7815453')->is_valid_number, '高知県香南市香我美町山北');
ok($zip->set_number('7815454')->is_valid_number, '高知県香南市香我美町口西川');
ok($zip->set_number('7815455')->is_valid_number, '高知県香南市香我美町中西川');
ok($zip->set_number('7815461')->is_valid_number, '高知県香南市香我美町福万');
ok($zip->set_number('7815462')->is_valid_number, '高知県香南市香我美町山川');
ok($zip->set_number('7815463')->is_valid_number, '高知県香南市香我美町末延');
ok($zip->set_number('7815464')->is_valid_number, '高知県香南市香我美町末清');
ok($zip->set_number('7815465')->is_valid_number, '高知県香南市香我美町正延');
ok($zip->set_number('7815466')->is_valid_number, '高知県香南市香我美町別役');
ok($zip->set_number('7815467')->is_valid_number, '高知県香南市香我美町奥西川');
ok($zip->set_number('7815468')->is_valid_number, '高知県香南市香我美町撫川');
ok($zip->set_number('7815469')->is_valid_number, '高知県香南市香我美町舞川');
ok($zip->set_number('7815601')->is_valid_number, '高知県香南市夜須町坪井');
ok($zip->set_number('7815602')->is_valid_number, '高知県香南市夜須町千切');
ok($zip->set_number('7815603')->is_valid_number, '高知県香南市夜須町西山');
ok($zip->set_number('7815604')->is_valid_number, '高知県香南市夜須町出口');
ok($zip->set_number('7815605')->is_valid_number, '高知県香南市夜須町十ノ木');
ok($zip->set_number('7815606')->is_valid_number, '高知県香南市夜須町上夜須');
ok($zip->set_number('7815611')->is_valid_number, '高知県香南市夜須町夜須川');
ok($zip->set_number('7815612')->is_valid_number, '高知県香南市夜須町細川');
ok($zip->set_number('7815613')->is_valid_number, '高知県香南市夜須町国光');
ok($zip->set_number('7815614')->is_valid_number, '高知県香南市夜須町羽尾');
ok($zip->set_number('7815615')->is_valid_number, '高知県香南市夜須町沢谷');
ok($zip->set_number('7815616')->is_valid_number, '高知県香南市夜須町仲木屋');
ok($zip->set_number('7815621')->is_valid_number, '高知県香南市夜須町手結');
ok($zip->set_number('7815622')->is_valid_number, '高知県香南市夜須町手結山');
ok($zip->set_number('7815700')->is_valid_number, '高知県安芸郡芸西村以下に掲載がない場合');
ok($zip->set_number('7815701')->is_valid_number, '高知県安芸郡芸西村和食甲');
ok($zip->set_number('7815702')->is_valid_number, '高知県安芸郡芸西村和食乙');
ok($zip->set_number('7815703')->is_valid_number, '高知県安芸郡芸西村西分甲');
ok($zip->set_number('7815704')->is_valid_number, '高知県安芸郡芸西村西分乙');
ok($zip->set_number('7815705')->is_valid_number, '高知県安芸郡芸西村馬ノ上');
ok($zip->set_number('7815706')->is_valid_number, '高知県安芸郡芸西村道家');
ok($zip->set_number('7815707')->is_valid_number, '高知県安芸郡芸西村国光');
ok($zip->set_number('7815708')->is_valid_number, '高知県安芸郡芸西村久重');
ok($zip->set_number('7816200')->is_valid_number, '高知県安芸郡馬路村以下に掲載がない場合');
ok($zip->set_number('7816201')->is_valid_number, '高知県安芸郡馬路村馬路');
ok($zip->set_number('7816202')->is_valid_number, '高知県安芸郡馬路村魚梁瀬');
ok($zip->set_number('7816400')->is_valid_number, '高知県安芸郡奈半利町以下に掲載がない場合');
ok($zip->set_number('7816400')->is_valid_number, '高知県安芸郡安田町以下に掲載がない場合');
ok($zip->set_number('7816400')->is_valid_number, '高知県安芸郡北川村以下に掲載がない場合');
ok($zip->set_number('7816401')->is_valid_number, '高知県安芸郡奈半利町甲');
ok($zip->set_number('7816402')->is_valid_number, '高知県安芸郡奈半利町乙');
ok($zip->set_number('7816403')->is_valid_number, '高知県安芸郡奈半利町丙');
ok($zip->set_number('7816410')->is_valid_number, '高知県安芸郡田野町田野町一円');
ok($zip->set_number('7816421')->is_valid_number, '高知県安芸郡安田町安田');
ok($zip->set_number('7816422')->is_valid_number, '高知県安芸郡安田町唐浜');
ok($zip->set_number('7816423')->is_valid_number, '高知県安芸郡安田町西島');
ok($zip->set_number('7816424')->is_valid_number, '高知県安芸郡安田町隆見');
ok($zip->set_number('7816425')->is_valid_number, '高知県安芸郡安田町東島');
ok($zip->set_number('7816426')->is_valid_number, '高知県安芸郡安田町間下');
ok($zip->set_number('7816427')->is_valid_number, '高知県安芸郡安田町内京坊');
ok($zip->set_number('7816430')->is_valid_number, '高知県安芸郡安田町正弘');
ok($zip->set_number('7816431')->is_valid_number, '高知県安芸郡安田町別所');
ok($zip->set_number('7816432')->is_valid_number, '高知県安芸郡安田町西ノ川');
ok($zip->set_number('7816433')->is_valid_number, '高知県安芸郡安田町中ノ川');
ok($zip->set_number('7816434')->is_valid_number, '高知県安芸郡安田町与床');
ok($zip->set_number('7816435')->is_valid_number, '高知県安芸郡安田町船倉');
ok($zip->set_number('7816436')->is_valid_number, '高知県安芸郡安田町瀬切');
ok($zip->set_number('7816437')->is_valid_number, '高知県安芸郡安田町中里');
ok($zip->set_number('7816438')->is_valid_number, '高知県安芸郡安田町小川');
ok($zip->set_number('7816439')->is_valid_number, '高知県安芸郡安田町日々入');
ok($zip->set_number('7816441')->is_valid_number, '高知県安芸郡北川村野友甲');
ok($zip->set_number('7816442')->is_valid_number, '高知県安芸郡北川村野友乙');
ok($zip->set_number('7816443')->is_valid_number, '高知県安芸郡北川村加茂');
ok($zip->set_number('7816444')->is_valid_number, '高知県安芸郡北川村野川');
ok($zip->set_number('7816445')->is_valid_number, '高知県安芸郡北川村長山');
ok($zip->set_number('7816446')->is_valid_number, '高知県安芸郡北川村西谷');
ok($zip->set_number('7816447')->is_valid_number, '高知県安芸郡北川村木積');
ok($zip->set_number('7816448')->is_valid_number, '高知県安芸郡北川村宗ノ上');
ok($zip->set_number('7816449')->is_valid_number, '高知県安芸郡北川村柏木');
ok($zip->set_number('7816450')->is_valid_number, '高知県安芸郡北川村和田');
ok($zip->set_number('7816451')->is_valid_number, '高知県安芸郡北川村小島');
ok($zip->set_number('7816452')->is_valid_number, '高知県安芸郡北川村平鍋');
ok($zip->set_number('7816453')->is_valid_number, '高知県安芸郡北川村二タ又');
ok($zip->set_number('7816454')->is_valid_number, '高知県安芸郡北川村島');
ok($zip->set_number('7816455')->is_valid_number, '高知県安芸郡北川村久江ノ上');
ok($zip->set_number('7816456')->is_valid_number, '高知県安芸郡北川村久木');
ok($zip->set_number('7816457')->is_valid_number, '高知県安芸郡北川村弘瀬');
ok($zip->set_number('7816458')->is_valid_number, '高知県安芸郡北川村安倉');
ok($zip->set_number('7816459')->is_valid_number, '高知県安芸郡北川村菅ノ上');
ok($zip->set_number('7816460')->is_valid_number, '高知県安芸郡北川村竹屋敷');
ok($zip->set_number('7816741')->is_valid_number, '高知県室戸市羽根町甲');
ok($zip->set_number('7816742')->is_valid_number, '高知県室戸市羽根町乙');
ok($zip->set_number('7816831')->is_valid_number, '高知県室戸市吉良川町乙');
ok($zip->set_number('7816832')->is_valid_number, '高知県室戸市吉良川町甲');
ok($zip->set_number('7816833')->is_valid_number, '高知県室戸市吉良川町丙');
ok($zip->set_number('7817100')->is_valid_number, '高知県室戸市以下に掲載がない場合');
ok($zip->set_number('7817101')->is_valid_number, '高知県室戸市室戸岬町');
ok($zip->set_number('7817102')->is_valid_number, '高知県室戸市室津');
ok($zip->set_number('7817103')->is_valid_number, '高知県室戸市浮津');
ok($zip->set_number('7817104')->is_valid_number, '高知県室戸市浮津一番町');
ok($zip->set_number('7817105')->is_valid_number, '高知県室戸市浮津二番町');
ok($zip->set_number('7817106')->is_valid_number, '高知県室戸市浮津三番町');
ok($zip->set_number('7817107')->is_valid_number, '高知県室戸市元甲');
ok($zip->set_number('7817108')->is_valid_number, '高知県室戸市元乙');
ok($zip->set_number('7817109')->is_valid_number, '高知県室戸市領家');
ok($zip->set_number('7817220')->is_valid_number, '高知県室戸市佐喜浜町');
ok($zip->set_number('7817300')->is_valid_number, '高知県安芸郡東洋町以下に掲載がない場合');
ok($zip->set_number('7817301')->is_valid_number, '高知県安芸郡東洋町野根丙');
ok($zip->set_number('7817302')->is_valid_number, '高知県安芸郡東洋町野根甲');
ok($zip->set_number('7817303')->is_valid_number, '高知県安芸郡東洋町野根丁');
ok($zip->set_number('7817304')->is_valid_number, '高知県安芸郡東洋町野根乙');
ok($zip->set_number('7817411')->is_valid_number, '高知県安芸郡東洋町甲浦');
ok($zip->set_number('7817412')->is_valid_number, '高知県安芸郡東洋町河内');
ok($zip->set_number('7817413')->is_valid_number, '高知県安芸郡東洋町白浜');
ok($zip->set_number('7817414')->is_valid_number, '高知県安芸郡東洋町生見');
ok($zip->set_number('7818001')->is_valid_number, '高知県高知市土居町');
ok($zip->set_number('7818002')->is_valid_number, '高知県高知市役知町');
ok($zip->set_number('7818003')->is_valid_number, '高知県高知市北新田町');
ok($zip->set_number('7818004')->is_valid_number, '高知県高知市新田町');
ok($zip->set_number('7818005')->is_valid_number, '高知県高知市南新田町');
ok($zip->set_number('7818006')->is_valid_number, '高知県高知市萩町');
ok($zip->set_number('7818007')->is_valid_number, '高知県高知市仲田町');
ok($zip->set_number('7818008')->is_valid_number, '高知県高知市潮新町');
ok($zip->set_number('7818010')->is_valid_number, '高知県高知市桟橋通');
ok($zip->set_number('7818016')->is_valid_number, '高知県高知市南ノ丸町');
ok($zip->set_number('7818101')->is_valid_number, '高知県高知市高須砂地');
ok($zip->set_number('7818102')->is_valid_number, '高知県高知市高須本町');
ok($zip->set_number('7818103')->is_valid_number, '高知県高知市高須新木');
ok($zip->set_number('7818104')->is_valid_number, '高知県高知市高須(丁目)');
ok($zip->set_number('7818105')->is_valid_number, '高知県高知市高須東町');
ok($zip->set_number('7818111')->is_valid_number, '高知県高知市高須大島');
ok($zip->set_number('7818112')->is_valid_number, '高知県高知市高須大谷');
ok($zip->set_number('7818113')->is_valid_number, '高知県高知市高須絶海');
ok($zip->set_number('7818114')->is_valid_number, '高知県高知市高須西町');
ok($zip->set_number('7818121')->is_valid_number, '高知県高知市葛島');
ok($zip->set_number('7818122')->is_valid_number, '高知県高知市高須新町');
ok($zip->set_number('7818123')->is_valid_number, '高知県高知市高須');
ok($zip->set_number('7818124')->is_valid_number, '高知県高知市屋頭');
ok($zip->set_number('7818125')->is_valid_number, '高知県高知市五台山');
ok($zip->set_number('7818126')->is_valid_number, '高知県高知市吸江');
ok($zip->set_number('7818130')->is_valid_number, '高知県高知市一宮');
ok($zip->set_number('7818131')->is_valid_number, '高知県高知市一宮しなね');
ok($zip->set_number('7818132')->is_valid_number, '高知県高知市一宮東町');
ok($zip->set_number('7818133')->is_valid_number, '高知県高知市一宮徳谷');
ok($zip->set_number('7818134')->is_valid_number, '高知県高知市一宮中町');
ok($zip->set_number('7818135')->is_valid_number, '高知県高知市一宮南町');
ok($zip->set_number('7818136')->is_valid_number, '高知県高知市一宮西町');
ok($zip->set_number('7820000')->is_valid_number, '高知県香美市以下に掲載がない場合');
ok($zip->set_number('7820001')->is_valid_number, '高知県香美市土佐山田町杉田');
ok($zip->set_number('7820002')->is_valid_number, '高知県香美市土佐山田町船谷');
ok($zip->set_number('7820003')->is_valid_number, '高知県香美市土佐山田町宮ノ口');
ok($zip->set_number('7820004')->is_valid_number, '高知県香美市土佐山田町間');
ok($zip->set_number('7820005')->is_valid_number, '高知県香美市土佐山田町逆川');
ok($zip->set_number('7820006')->is_valid_number, '高知県香美市土佐山田町影山');
ok($zip->set_number('7820007')->is_valid_number, '高知県香美市土佐山田町林田');
ok($zip->set_number('7820008')->is_valid_number, '高知県香美市土佐山田町佐古薮');
ok($zip->set_number('7820009')->is_valid_number, '高知県香美市土佐山田町神母ノ木');
ok($zip->set_number('7820010')->is_valid_number, '高知県香美市土佐山田町テクノパーク');
ok($zip->set_number('7820011')->is_valid_number, '高知県香美市土佐山田町山田島');
ok($zip->set_number('7820012')->is_valid_number, '高知県香美市土佐山田町加茂');
ok($zip->set_number('7820013')->is_valid_number, '高知県香美市土佐山田町町田');
ok($zip->set_number('7820014')->is_valid_number, '高知県香美市土佐山田町小田島');
ok($zip->set_number('7820015')->is_valid_number, '高知県香美市土佐山田町下ノ村');
ok($zip->set_number('7820016')->is_valid_number, '高知県香美市土佐山田町山田(小島、八王子、原)');
ok($zip->set_number('7820017')->is_valid_number, '高知県香美市土佐山田町岩積');
ok($zip->set_number('7820018')->is_valid_number, '高知県香美市土佐山田町戸板島');
ok($zip->set_number('7820019')->is_valid_number, '高知県香美市土佐山田町中野');
ok($zip->set_number('7820021')->is_valid_number, '高知県香美市土佐山田町岩次');
ok($zip->set_number('7820022')->is_valid_number, '高知県香美市土佐山田町京田(立石)');
ok($zip->set_number('7820023')->is_valid_number, '高知県香美市土佐山田町京田(その他)');
ok($zip->set_number('7820024')->is_valid_number, '高知県香美市土佐山田町神通寺');
ok($zip->set_number('7820025')->is_valid_number, '高知県香美市土佐山田町松本');
ok($zip->set_number('7820031')->is_valid_number, '高知県香美市土佐山田町東本町');
ok($zip->set_number('7820032')->is_valid_number, '高知県香美市土佐山田町西本町');
ok($zip->set_number('7820033')->is_valid_number, '高知県香美市土佐山田町旭町');
ok($zip->set_number('7820034')->is_valid_number, '高知県香美市土佐山田町宝町');
ok($zip->set_number('7820035')->is_valid_number, '高知県香美市土佐山田町百石町');
ok($zip->set_number('7820036')->is_valid_number, '高知県香美市土佐山田町(古町)');
ok($zip->set_number('7820037')->is_valid_number, '高知県香美市土佐山田町宮前町');
ok($zip->set_number('7820038')->is_valid_number, '高知県香美市土佐山田町秦山町');
ok($zip->set_number('7820039')->is_valid_number, '高知県香美市土佐山田町栄町');
ok($zip->set_number('7820041')->is_valid_number, '高知県香美市土佐山田町(北本町)');
ok($zip->set_number('7820042')->is_valid_number, '高知県香美市土佐山田町(前山)');
ok($zip->set_number('7820043')->is_valid_number, '高知県香美市土佐山田町(北組西)');
ok($zip->set_number('7820044')->is_valid_number, '高知県香美市土佐山田町(中組)');
ok($zip->set_number('7820045')->is_valid_number, '高知県香美市土佐山田町(黒土)');
ok($zip->set_number('7820046')->is_valid_number, '高知県香美市土佐山田町(南組)');
ok($zip->set_number('7820047')->is_valid_number, '高知県香美市土佐山田町(その他)');
ok($zip->set_number('7820051')->is_valid_number, '高知県香美市土佐山田町楠目(油石、前行、談議所、中村、平田、伏原、予岳)');
ok($zip->set_number('7820054')->is_valid_number, '高知県香美市土佐山田町植');
ok($zip->set_number('7820055')->is_valid_number, '高知県香美市土佐山田町須江');
ok($zip->set_number('7820056')->is_valid_number, '高知県香美市土佐山田町上改田');
ok($zip->set_number('7820057')->is_valid_number, '高知県香美市土佐山田町久次');
ok($zip->set_number('7820058')->is_valid_number, '高知県香美市土佐山田町新改');
ok($zip->set_number('7820059')->is_valid_number, '高知県香美市土佐山田町入野');
ok($zip->set_number('7820061')->is_valid_number, '高知県香美市土佐山田町曽我部川');
ok($zip->set_number('7820062')->is_valid_number, '高知県香美市土佐山田町平山(その他)');
ok($zip->set_number('7820063')->is_valid_number, '高知県香美市土佐山田町東川');
ok($zip->set_number('7820064')->is_valid_number, '高知県香美市土佐山田町大法寺');
ok($zip->set_number('7820071')->is_valid_number, '高知県香美市土佐山田町佐竹');
ok($zip->set_number('7820072')->is_valid_number, '高知県香美市土佐山田町有谷');
ok($zip->set_number('7820073')->is_valid_number, '高知県香美市土佐山田町中後入');
ok($zip->set_number('7820074')->is_valid_number, '高知県香美市土佐山田町大後入');
ok($zip->set_number('7820075')->is_valid_number, '高知県香美市土佐山田町西後入');
ok($zip->set_number('7820076')->is_valid_number, '高知県香美市土佐山田町本村');
ok($zip->set_number('7820077')->is_valid_number, '高知県香美市土佐山田町佐野(仁井田)');
ok($zip->set_number('7820078')->is_valid_number, '高知県香美市土佐山田町大平');
ok($zip->set_number('7820079')->is_valid_number, '高知県香美市土佐山田町佐野(その他)');
ok($zip->set_number('7830000')->is_valid_number, '高知県南国市以下に掲載がない場合');
ok($zip->set_number('7830001')->is_valid_number, '高知県南国市日吉町');
ok($zip->set_number('7830002')->is_valid_number, '高知県南国市駅前町');
ok($zip->set_number('7830003')->is_valid_number, '高知県南国市西野田町');
ok($zip->set_number('7830004')->is_valid_number, '高知県南国市大そね甲');
ok($zip->set_number('7830005')->is_valid_number, '高知県南国市大そね乙');
ok($zip->set_number('7830006')->is_valid_number, '高知県南国市篠原');
ok($zip->set_number('7830007')->is_valid_number, '高知県南国市明見');
ok($zip->set_number('7830008')->is_valid_number, '高知県南国市伊達野');
ok($zip->set_number('7830011')->is_valid_number, '高知県南国市後免町');
ok($zip->set_number('7830012')->is_valid_number, '高知県南国市東山町');
ok($zip->set_number('7830013')->is_valid_number, '高知県南国市幸町');
ok($zip->set_number('7830014')->is_valid_number, '高知県南国市元町');
ok($zip->set_number('7830021')->is_valid_number, '高知県南国市野中');
ok($zip->set_number('7830022')->is_valid_number, '高知県南国市小籠');
ok($zip->set_number('7830023')->is_valid_number, '高知県南国市廿枝');
ok($zip->set_number('7830024')->is_valid_number, '高知県南国市東崎');
ok($zip->set_number('7830025')->is_valid_number, '高知県南国市下末松');
ok($zip->set_number('7830026')->is_valid_number, '高知県南国市上末松');
ok($zip->set_number('7830027')->is_valid_number, '高知県南国市三畠');
ok($zip->set_number('7830028')->is_valid_number, '高知県南国市陣山');
ok($zip->set_number('7830029')->is_valid_number, '高知県南国市西山');
ok($zip->set_number('7830031')->is_valid_number, '高知県南国市下野田');
ok($zip->set_number('7830032')->is_valid_number, '高知県南国市上野田');
ok($zip->set_number('7830033')->is_valid_number, '高知県南国市包末');
ok($zip->set_number('7830034')->is_valid_number, '高知県南国市堀ノ内');
ok($zip->set_number('7830035')->is_valid_number, '高知県南国市金地');
ok($zip->set_number('7830036')->is_valid_number, '高知県南国市福船');
ok($zip->set_number('7830037')->is_valid_number, '高知県南国市蔵福寺島');
ok($zip->set_number('7830040')->is_valid_number, '高知県南国市岡豊町滝本');
ok($zip->set_number('7830041')->is_valid_number, '高知県南国市岡豊町定林寺');
ok($zip->set_number('7830042')->is_valid_number, '高知県南国市岡豊町蒲原');
ok($zip->set_number('7830043')->is_valid_number, '高知県南国市岡豊町小蓮');
ok($zip->set_number('7830044')->is_valid_number, '高知県南国市岡豊町八幡');
ok($zip->set_number('7830045')->is_valid_number, '高知県南国市岡豊町吉田');
ok($zip->set_number('7830046')->is_valid_number, '高知県南国市岡豊町江村');
ok($zip->set_number('7830047')->is_valid_number, '高知県南国市岡豊町常通寺島');
ok($zip->set_number('7830048')->is_valid_number, '高知県南国市岡豊町小篭');
ok($zip->set_number('7830049')->is_valid_number, '高知県南国市岡豊町中島');
ok($zip->set_number('7830051')->is_valid_number, '高知県南国市岡豊町笠ノ川');
ok($zip->set_number('7830052')->is_valid_number, '高知県南国市左右山');
ok($zip->set_number('7830053')->is_valid_number, '高知県南国市国分');
ok($zip->set_number('7830054')->is_valid_number, '高知県南国市比江');
ok($zip->set_number('7830055')->is_valid_number, '高知県南国市双葉台');
ok($zip->set_number('7830056')->is_valid_number, '高知県南国市領石');
ok($zip->set_number('7830057')->is_valid_number, '高知県南国市八京');
ok($zip->set_number('7830058')->is_valid_number, '高知県南国市白木谷');
ok($zip->set_number('7830060')->is_valid_number, '高知県南国市蛍が丘');
ok($zip->set_number('7830061')->is_valid_number, '高知県南国市植野');
ok($zip->set_number('7830062')->is_valid_number, '高知県南国市久礼田');
ok($zip->set_number('7830063')->is_valid_number, '高知県南国市植田');
ok($zip->set_number('7830064')->is_valid_number, '高知県南国市宍崎');
ok($zip->set_number('7830065')->is_valid_number, '高知県南国市外山');
ok($zip->set_number('7830066')->is_valid_number, '高知県南国市成合');
ok($zip->set_number('7830067')->is_valid_number, '高知県南国市天行寺');
ok($zip->set_number('7830068')->is_valid_number, '高知県南国市才谷');
ok($zip->set_number('7830071')->is_valid_number, '高知県南国市亀岩');
ok($zip->set_number('7830072')->is_valid_number, '高知県南国市奈路');
ok($zip->set_number('7830073')->is_valid_number, '高知県南国市中谷');
ok($zip->set_number('7830074')->is_valid_number, '高知県南国市上倉');
ok($zip->set_number('7830075')->is_valid_number, '高知県南国市桑ノ川');
ok($zip->set_number('7830076')->is_valid_number, '高知県南国市黒滝');
ok($zip->set_number('7830077')->is_valid_number, '高知県南国市大改野');
ok($zip->set_number('7830078')->is_valid_number, '高知県南国市中ノ川');
ok($zip->set_number('7830081')->is_valid_number, '高知県南国市片山');
ok($zip->set_number('7830082')->is_valid_number, '高知県南国市里改田');
ok($zip->set_number('7830083')->is_valid_number, '高知県南国市浜改田');
ok($zip->set_number('7830084')->is_valid_number, '高知県南国市稲生');
ok($zip->set_number('7830085')->is_valid_number, '高知県南国市十市');
ok($zip->set_number('7830086')->is_valid_number, '高知県南国市緑ケ丘');
ok($zip->set_number('7830087')->is_valid_number, '高知県南国市三和琴平');
ok($zip->set_number('7830091')->is_valid_number, '高知県南国市立田');
ok($zip->set_number('7830092')->is_valid_number, '高知県南国市田村');
ok($zip->set_number('7830093')->is_valid_number, '高知県南国市物部');
ok($zip->set_number('7830094')->is_valid_number, '高知県南国市前浜');
ok($zip->set_number('7830095')->is_valid_number, '高知県南国市下島');
ok($zip->set_number('7830096')->is_valid_number, '高知県南国市久枝');
ok($zip->set_number('7830097')->is_valid_number, '高知県南国市日章あけぼの');
ok($zip->set_number('7840000')->is_valid_number, '高知県安芸市以下に掲載がない場合');
ok($zip->set_number('7840001')->is_valid_number, '高知県安芸市矢ノ丸');
ok($zip->set_number('7840002')->is_valid_number, '高知県安芸市花園町');
ok($zip->set_number('7840003')->is_valid_number, '高知県安芸市久世町');
ok($zip->set_number('7840004')->is_valid_number, '高知県安芸市本町');
ok($zip->set_number('7840005')->is_valid_number, '高知県安芸市港町');
ok($zip->set_number('7840006')->is_valid_number, '高知県安芸市日ノ出町');
ok($zip->set_number('7840007')->is_valid_number, '高知県安芸市寿町');
ok($zip->set_number('7840008')->is_valid_number, '高知県安芸市清和町');
ok($zip->set_number('7840010')->is_valid_number, '高知県安芸市東浜');
ok($zip->set_number('7840020')->is_valid_number, '高知県安芸市西浜');
ok($zip->set_number('7840021')->is_valid_number, '高知県安芸市幸町');
ok($zip->set_number('7840022')->is_valid_number, '高知県安芸市庄之芝町');
ok($zip->set_number('7840023')->is_valid_number, '高知県安芸市染井町');
ok($zip->set_number('7840024')->is_valid_number, '高知県安芸市千歳町');
ok($zip->set_number('7840025')->is_valid_number, '高知県安芸市津久茂町');
ok($zip->set_number('7840026')->is_valid_number, '高知県安芸市桜ケ丘町');
ok($zip->set_number('7840027')->is_valid_number, '高知県安芸市宝永町');
ok($zip->set_number('7840028')->is_valid_number, '高知県安芸市黒鳥');
ok($zip->set_number('7840029')->is_valid_number, '高知県安芸市植野');
ok($zip->set_number('7840031')->is_valid_number, '高知県安芸市穴内甲');
ok($zip->set_number('7840032')->is_valid_number, '高知県安芸市穴内乙');
ok($zip->set_number('7840033')->is_valid_number, '高知県安芸市赤野甲');
ok($zip->set_number('7840034')->is_valid_number, '高知県安芸市赤野乙');
ok($zip->set_number('7840041')->is_valid_number, '高知県安芸市僧津');
ok($zip->set_number('7840042')->is_valid_number, '高知県安芸市土居');
ok($zip->set_number('7840043')->is_valid_number, '高知県安芸市川北甲');
ok($zip->set_number('7840044')->is_valid_number, '高知県安芸市川北乙');
ok($zip->set_number('7840045')->is_valid_number, '高知県安芸市伊尾木');
ok($zip->set_number('7840046')->is_valid_number, '高知県安芸市下山');
ok($zip->set_number('7840051')->is_valid_number, '高知県安芸市井ノ口甲');
ok($zip->set_number('7840052')->is_valid_number, '高知県安芸市井ノ口乙');
ok($zip->set_number('7840053')->is_valid_number, '高知県安芸市小谷');
ok($zip->set_number('7840054')->is_valid_number, '高知県安芸市栃ノ木');
ok($zip->set_number('7840055')->is_valid_number, '高知県安芸市尾川甲');
ok($zip->set_number('7840056')->is_valid_number, '高知県安芸市尾川乙');
ok($zip->set_number('7840057')->is_valid_number, '高知県安芸市安芸ノ川甲');
ok($zip->set_number('7840058')->is_valid_number, '高知県安芸市安芸ノ川乙');
ok($zip->set_number('7840061')->is_valid_number, '高知県安芸市畑山甲');
ok($zip->set_number('7840062')->is_valid_number, '高知県安芸市畑山乙');
ok($zip->set_number('7840063')->is_valid_number, '高知県安芸市畑山丙');
ok($zip->set_number('7840064')->is_valid_number, '高知県安芸市舞川');
ok($zip->set_number('7840065')->is_valid_number, '高知県香美市物部町中津尾');
ok($zip->set_number('7840271')->is_valid_number, '高知県安芸市奈比賀');
ok($zip->set_number('7840272')->is_valid_number, '高知県安芸市入河内');
ok($zip->set_number('7840273')->is_valid_number, '高知県安芸市黒瀬');
ok($zip->set_number('7840274')->is_valid_number, '高知県安芸市大井甲');
ok($zip->set_number('7840275')->is_valid_number, '高知県安芸市大井乙');
ok($zip->set_number('7840276')->is_valid_number, '高知県安芸市古井');
ok($zip->set_number('7840277')->is_valid_number, '高知県安芸市島');
ok($zip->set_number('7840278')->is_valid_number, '高知県安芸市別役');
ok($zip->set_number('7850000')->is_valid_number, '高知県須崎市以下に掲載がない場合');
ok($zip->set_number('7850001')->is_valid_number, '高知県須崎市原町');
ok($zip->set_number('7850002')->is_valid_number, '高知県須崎市港町');
ok($zip->set_number('7850003')->is_valid_number, '高知県須崎市新町');
ok($zip->set_number('7850004')->is_valid_number, '高知県須崎市青木町');
ok($zip->set_number('7850005')->is_valid_number, '高知県須崎市東古市町');
ok($zip->set_number('7850006')->is_valid_number, '高知県須崎市浜町');
ok($zip->set_number('7850007')->is_valid_number, '高知県須崎市南古市町');
ok($zip->set_number('7850008')->is_valid_number, '高知県須崎市中町');
ok($zip->set_number('7850009')->is_valid_number, '高知県須崎市西町');
ok($zip->set_number('7850010')->is_valid_number, '高知県須崎市鍛冶町');
ok($zip->set_number('7850011')->is_valid_number, '高知県須崎市東糺町');
ok($zip->set_number('7850012')->is_valid_number, '高知県須崎市西糺町');
ok($zip->set_number('7850013')->is_valid_number, '高知県須崎市西古市町');
ok($zip->set_number('7850014')->is_valid_number, '高知県須崎市横町');
ok($zip->set_number('7850015')->is_valid_number, '高知県須崎市幸町');
ok($zip->set_number('7850016')->is_valid_number, '高知県須崎市栄町');
ok($zip->set_number('7850017')->is_valid_number, '高知県須崎市泉町');
ok($zip->set_number('7850018')->is_valid_number, '高知県須崎市須崎');
ok($zip->set_number('7850021')->is_valid_number, '高知県須崎市池ノ内');
ok($zip->set_number('7850022')->is_valid_number, '高知県須崎市下分甲');
ok($zip->set_number('7850023')->is_valid_number, '高知県須崎市下分乙');
ok($zip->set_number('7850024')->is_valid_number, '高知県須崎市安和');
ok($zip->set_number('7850025')->is_valid_number, '高知県須崎市下郷');
ok($zip->set_number('7850026')->is_valid_number, '高知県須崎市上分甲');
ok($zip->set_number('7850027')->is_valid_number, '高知県須崎市上分乙');
ok($zip->set_number('7850028')->is_valid_number, '高知県須崎市上分丙');
ok($zip->set_number('7850030')->is_valid_number, '高知県須崎市多ノ郷甲');
ok($zip->set_number('7850031')->is_valid_number, '高知県須崎市山手町');
ok($zip->set_number('7850032')->is_valid_number, '高知県須崎市潮田町');
ok($zip->set_number('7850033')->is_valid_number, '高知県須崎市大間西町');
ok($zip->set_number('7850034')->is_valid_number, '高知県須崎市大間本町');
ok($zip->set_number('7850035')->is_valid_number, '高知県須崎市大間東町');
ok($zip->set_number('7850036')->is_valid_number, '高知県須崎市緑町');
ok($zip->set_number('7850037')->is_valid_number, '高知県須崎市赤崎町');
ok($zip->set_number('7850041')->is_valid_number, '高知県須崎市西崎町');
ok($zip->set_number('7850042')->is_valid_number, '高知県須崎市妙見町');
ok($zip->set_number('7850043')->is_valid_number, '高知県須崎市土崎町');
ok($zip->set_number('7850044')->is_valid_number, '高知県須崎市吾井郷乙');
ok($zip->set_number('7850045')->is_valid_number, '高知県須崎市桑田山乙');
ok($zip->set_number('7850046')->is_valid_number, '高知県須崎市桑田山甲');
ok($zip->set_number('7850047')->is_valid_number, '高知県須崎市吾井郷甲');
ok($zip->set_number('7850051')->is_valid_number, '高知県須崎市神田');
ok($zip->set_number('7850052')->is_valid_number, '高知県須崎市押岡');
ok($zip->set_number('7850053')->is_valid_number, '高知県須崎市久通');
ok($zip->set_number('7850054')->is_valid_number, '高知県須崎市多ノ郷乙');
ok($zip->set_number('7850055')->is_valid_number, '高知県須崎市大谷');
ok($zip->set_number('7850056')->is_valid_number, '高知県須崎市野見');
ok($zip->set_number('7850057')->is_valid_number, '高知県須崎市桐間東');
ok($zip->set_number('7850058')->is_valid_number, '高知県須崎市桐間南');
ok($zip->set_number('7850059')->is_valid_number, '高知県須崎市桐間西');
ok($zip->set_number('7850161')->is_valid_number, '高知県須崎市浦ノ内西分');
ok($zip->set_number('7850162')->is_valid_number, '高知県須崎市浦ノ内東分(その他)');
ok($zip->set_number('7850163')->is_valid_number, '高知県須崎市浦ノ内東分(鳴無・坂内)');
ok($zip->set_number('7850164')->is_valid_number, '高知県須崎市浦ノ内立目摺木');
ok($zip->set_number('7850165')->is_valid_number, '高知県須崎市浦ノ内出見');
ok($zip->set_number('7850166')->is_valid_number, '高知県須崎市浦ノ内塩間');
ok($zip->set_number('7850167')->is_valid_number, '高知県須崎市浦ノ内灰方');
ok($zip->set_number('7850171')->is_valid_number, '高知県須崎市浦ノ内須ノ浦');
ok($zip->set_number('7850172')->is_valid_number, '高知県須崎市浦ノ内福良');
ok($zip->set_number('7850173')->is_valid_number, '高知県須崎市浦ノ内今川内');
ok($zip->set_number('7850174')->is_valid_number, '高知県須崎市浦ノ内下中山');
ok($zip->set_number('7850200')->is_valid_number, '高知県高岡郡津野町以下に掲載がない場合');
ok($zip->set_number('7850201')->is_valid_number, '高知県高岡郡津野町永野');
ok($zip->set_number('7850202')->is_valid_number, '高知県高岡郡津野町姫野々');
ok($zip->set_number('7850203')->is_valid_number, '高知県高岡郡津野町貝ノ川');
ok($zip->set_number('7850204')->is_valid_number, '高知県高岡郡津野町久保川');
ok($zip->set_number('7850205')->is_valid_number, '高知県高岡郡津野町西谷甲');
ok($zip->set_number('7850206')->is_valid_number, '高知県高岡郡津野町樺の川');
ok($zip->set_number('7850207')->is_valid_number, '高知県高岡郡津野町新土居');
ok($zip->set_number('7850208')->is_valid_number, '高知県高岡郡津野町三間川');
ok($zip->set_number('7850209')->is_valid_number, '高知県高岡郡津野町西谷乙');
ok($zip->set_number('7850210')->is_valid_number, '高知県高岡郡津野町貝ノ川床鍋');
ok($zip->set_number('7850211')->is_valid_number, '高知県高岡郡津野町白石甲');
ok($zip->set_number('7850212')->is_valid_number, '高知県高岡郡津野町白石乙');
ok($zip->set_number('7850213')->is_valid_number, '高知県高岡郡津野町白石丙');
ok($zip->set_number('7850214')->is_valid_number, '高知県高岡郡津野町杉ノ川甲');
ok($zip->set_number('7850215')->is_valid_number, '高知県高岡郡津野町杉ノ川乙');
ok($zip->set_number('7850216')->is_valid_number, '高知県高岡郡津野町杉ノ川丙');
ok($zip->set_number('7850217')->is_valid_number, '高知県高岡郡津野町黒川');
ok($zip->set_number('7850218')->is_valid_number, '高知県高岡郡津野町大野');
ok($zip->set_number('7850219')->is_valid_number, '高知県高岡郡津野町赤木');
ok($zip->set_number('7850411')->is_valid_number, '高知県高岡郡津野町船戸');
ok($zip->set_number('7850412')->is_valid_number, '高知県高岡郡津野町桑ケ市');
ok($zip->set_number('7850413')->is_valid_number, '高知県高岡郡津野町烏出川');
ok($zip->set_number('7850501')->is_valid_number, '高知県高岡郡津野町力石');
ok($zip->set_number('7850502')->is_valid_number, '高知県高岡郡津野町北川');
ok($zip->set_number('7850503')->is_valid_number, '高知県高岡郡津野町芳生野甲');
ok($zip->set_number('7850504')->is_valid_number, '高知県高岡郡津野町芳生野乙');
ok($zip->set_number('7850505')->is_valid_number, '高知県高岡郡津野町芳生野丙');
ok($zip->set_number('7850600')->is_valid_number, '高知県高岡郡檮原町以下に掲載がない場合');
ok($zip->set_number('7850601')->is_valid_number, '高知県高岡郡檮原町永野');
ok($zip->set_number('7850602')->is_valid_number, '高知県高岡郡檮原町井の谷');
ok($zip->set_number('7850603')->is_valid_number, '高知県高岡郡檮原町太田戸');
ok($zip->set_number('7850604')->is_valid_number, '高知県高岡郡檮原町横貝');
ok($zip->set_number('7850605')->is_valid_number, '高知県高岡郡檮原町下本村');
ok($zip->set_number('7850606')->is_valid_number, '高知県高岡郡檮原町上本村');
ok($zip->set_number('7850607')->is_valid_number, '高知県高岡郡檮原町田野々');
ok($zip->set_number('7850608')->is_valid_number, '高知県高岡郡檮原町後別当');
ok($zip->set_number('7850610')->is_valid_number, '高知県高岡郡檮原町檮原');
ok($zip->set_number('7850611')->is_valid_number, '高知県高岡郡檮原町飯母');
ok($zip->set_number('7850612')->is_valid_number, '高知県高岡郡檮原町川西路');
ok($zip->set_number('7850613')->is_valid_number, '高知県高岡郡檮原町大蔵谷');
ok($zip->set_number('7850621')->is_valid_number, '高知県高岡郡檮原町太郎川');
ok($zip->set_number('7850622')->is_valid_number, '高知県高岡郡檮原町神在居');
ok($zip->set_number('7850623')->is_valid_number, '高知県高岡郡檮原町仲洞');
ok($zip->set_number('7850624')->is_valid_number, '高知県高岡郡檮原町下折渡');
ok($zip->set_number('7850625')->is_valid_number, '高知県高岡郡檮原町上折渡');
ok($zip->set_number('7850626')->is_valid_number, '高知県高岡郡檮原町大野地');
ok($zip->set_number('7850627')->is_valid_number, '高知県高岡郡檮原町影野地');
ok($zip->set_number('7850631')->is_valid_number, '高知県高岡郡檮原町佐渡');
ok($zip->set_number('7850632')->is_valid_number, '高知県高岡郡檮原町初瀬本村');
ok($zip->set_number('7850633')->is_valid_number, '高知県高岡郡檮原町豊原');
ok($zip->set_number('7850634')->is_valid_number, '高知県高岡郡檮原町仲久保');
ok($zip->set_number('7850635')->is_valid_number, '高知県高岡郡檮原町川井');
ok($zip->set_number('7850636')->is_valid_number, '高知県高岡郡檮原町川口');
ok($zip->set_number('7850641')->is_valid_number, '高知県高岡郡檮原町上成');
ok($zip->set_number('7850642')->is_valid_number, '高知県高岡郡檮原町松谷');
ok($zip->set_number('7850643')->is_valid_number, '高知県高岡郡檮原町宮野々');
ok($zip->set_number('7850644')->is_valid_number, '高知県高岡郡檮原町広野');
ok($zip->set_number('7850645')->is_valid_number, '高知県高岡郡檮原町竹の薮');
ok($zip->set_number('7850646')->is_valid_number, '高知県高岡郡檮原町上西の川');
ok($zip->set_number('7850647')->is_valid_number, '高知県高岡郡檮原町下西の川');
ok($zip->set_number('7850648')->is_valid_number, '高知県高岡郡檮原町仲間');
ok($zip->set_number('7850651')->is_valid_number, '高知県高岡郡檮原町茶や谷');
ok($zip->set_number('7850652')->is_valid_number, '高知県高岡郡檮原町本も谷');
ok($zip->set_number('7850653')->is_valid_number, '高知県高岡郡檮原町中の川');
ok($zip->set_number('7850654')->is_valid_number, '高知県高岡郡檮原町上組');
ok($zip->set_number('7850655')->is_valid_number, '高知県高岡郡檮原町下組');
ok($zip->set_number('7850656')->is_valid_number, '高知県高岡郡檮原町東川');
ok($zip->set_number('7850657')->is_valid_number, '高知県高岡郡檮原町東向');
ok($zip->set_number('7850658')->is_valid_number, '高知県高岡郡檮原町富永');
ok($zip->set_number('7850661')->is_valid_number, '高知県高岡郡檮原町六丁');
ok($zip->set_number('7850662')->is_valid_number, '高知県高岡郡檮原町坂本川');
ok($zip->set_number('7850663')->is_valid_number, '高知県高岡郡檮原町文丸');
ok($zip->set_number('7850664')->is_valid_number, '高知県高岡郡檮原町神の山');
ok($zip->set_number('7850665')->is_valid_number, '高知県高岡郡檮原町坪野田');
ok($zip->set_number('7850666')->is_valid_number, '高知県高岡郡檮原町井高');
ok($zip->set_number('7850771')->is_valid_number, '高知県高岡郡檮原町大向');
ok($zip->set_number('7850772')->is_valid_number, '高知県高岡郡檮原町中平');
ok($zip->set_number('7850773')->is_valid_number, '高知県高岡郡檮原町松原');
ok($zip->set_number('7850774')->is_valid_number, '高知県高岡郡檮原町久保谷');
ok($zip->set_number('7850775')->is_valid_number, '高知県高岡郡檮原町島中');
ok($zip->set_number('7850776')->is_valid_number, '高知県高岡郡檮原町家籠戸');
ok($zip->set_number('7860000')->is_valid_number, '高知県高岡郡四万十町以下に掲載がない場合');
ok($zip->set_number('7860001')->is_valid_number, '高知県高岡郡四万十町藤ノ川');
ok($zip->set_number('7860002')->is_valid_number, '高知県高岡郡四万十町見付');
ok($zip->set_number('7860003')->is_valid_number, '高知県高岡郡四万十町金上野');
ok($zip->set_number('7860004')->is_valid_number, '高知県高岡郡四万十町茂串町');
ok($zip->set_number('7860005')->is_valid_number, '高知県高岡郡四万十町本町');
ok($zip->set_number('7860006')->is_valid_number, '高知県高岡郡四万十町東町');
ok($zip->set_number('7860007')->is_valid_number, '高知県高岡郡四万十町古市町');
ok($zip->set_number('7860008')->is_valid_number, '高知県高岡郡四万十町榊山町');
ok($zip->set_number('7860010')->is_valid_number, '高知県高岡郡四万十町窪川');
ok($zip->set_number('7860011')->is_valid_number, '高知県高岡郡四万十町香月が丘');
ok($zip->set_number('7860012')->is_valid_number, '高知県高岡郡四万十町北琴平町');
ok($zip->set_number('7860013')->is_valid_number, '高知県高岡郡四万十町琴平町');
ok($zip->set_number('7860014')->is_valid_number, '高知県高岡郡四万十町新開町');
ok($zip->set_number('7860015')->is_valid_number, '高知県高岡郡四万十町西原');
ok($zip->set_number('7860016')->is_valid_number, '高知県高岡郡四万十町大井野');
ok($zip->set_number('7860017')->is_valid_number, '高知県高岡郡四万十町神ノ西');
ok($zip->set_number('7860018')->is_valid_number, '高知県高岡郡四万十町仕出原');
ok($zip->set_number('7860021')->is_valid_number, '高知県高岡郡四万十町仁井田');
ok($zip->set_number('7860022')->is_valid_number, '高知県高岡郡四万十町小向');
ok($zip->set_number('7860023')->is_valid_number, '高知県高岡郡四万十町中ノ越');
ok($zip->set_number('7860024')->is_valid_number, '高知県高岡郡四万十町向川');
ok($zip->set_number('7860025')->is_valid_number, '高知県高岡郡四万十町富岡');
ok($zip->set_number('7860026')->is_valid_number, '高知県高岡郡四万十町平串');
ok($zip->set_number('7860027')->is_valid_number, '高知県高岡郡四万十町東大奈路');
ok($zip->set_number('7860028')->is_valid_number, '高知県高岡郡四万十町根元原');
ok($zip->set_number('7860031')->is_valid_number, '高知県高岡郡四万十町床鍋');
ok($zip->set_number('7860032')->is_valid_number, '高知県高岡郡四万十町影野');
ok($zip->set_number('7860033')->is_valid_number, '高知県高岡郡四万十町道徳');
ok($zip->set_number('7860034')->is_valid_number, '高知県高岡郡四万十町替坂本');
ok($zip->set_number('7860035')->is_valid_number, '高知県高岡郡四万十町六反地');
ok($zip->set_number('7860036')->is_valid_number, '高知県高岡郡四万十町下呉地');
ok($zip->set_number('7860037')->is_valid_number, '高知県高岡郡四万十町魚の川');
ok($zip->set_number('7860038')->is_valid_number, '高知県高岡郡四万十町奥呉地');
ok($zip->set_number('7860041')->is_valid_number, '高知県高岡郡四万十町奈路');
ok($zip->set_number('7860042')->is_valid_number, '高知県高岡郡四万十町黒石');
ok($zip->set_number('7860043')->is_valid_number, '高知県高岡郡四万十町本堂');
ok($zip->set_number('7860044')->is_valid_number, '高知県高岡郡四万十町与津地');
ok($zip->set_number('7860045')->is_valid_number, '高知県高岡郡四万十町興津(1~1699番)');
ok($zip->set_number('7860046')->is_valid_number, '高知県高岡郡四万十町興津(その他)');
ok($zip->set_number('7860047')->is_valid_number, '高知県高岡郡四万十町八千数');
ok($zip->set_number('7860048')->is_valid_number, '高知県高岡郡四万十町親ケ内');
ok($zip->set_number('7860049')->is_valid_number, '高知県高岡郡四万十町数神');
ok($zip->set_number('7860051')->is_valid_number, '高知県高岡郡四万十町平野');
ok($zip->set_number('7860052')->is_valid_number, '高知県高岡郡四万十町土居');
ok($zip->set_number('7860053')->is_valid_number, '高知県高岡郡四万十町弘見');
ok($zip->set_number('7860054')->is_valid_number, '高知県高岡郡四万十町飯ノ川');
ok($zip->set_number('7860055')->is_valid_number, '高知県高岡郡四万十町志和峰');
ok($zip->set_number('7860056')->is_valid_number, '高知県高岡郡四万十町志和');
ok($zip->set_number('7860057')->is_valid_number, '高知県高岡郡四万十町小鶴津');
ok($zip->set_number('7860058')->is_valid_number, '高知県高岡郡四万十町大鶴津');
ok($zip->set_number('7860061')->is_valid_number, '高知県高岡郡四万十町峰ノ上');
ok($zip->set_number('7860062')->is_valid_number, '高知県高岡郡四万十町若井川');
ok($zip->set_number('7860063')->is_valid_number, '高知県高岡郡四万十町高野');
ok($zip->set_number('7860064')->is_valid_number, '高知県高岡郡四万十町家地川');
ok($zip->set_number('7860065')->is_valid_number, '高知県高岡郡四万十町野地');
ok($zip->set_number('7860066')->is_valid_number, '高知県高岡郡四万十町天の川');
ok($zip->set_number('7860067')->is_valid_number, '高知県高岡郡四万十町大向');
ok($zip->set_number('7860068')->is_valid_number, '高知県高岡郡四万十町若井');
ok($zip->set_number('7860071')->is_valid_number, '高知県高岡郡四万十町奥神ノ川');
ok($zip->set_number('7860072')->is_valid_number, '高知県高岡郡四万十町中神ノ川');
ok($zip->set_number('7860073')->is_valid_number, '高知県高岡郡四万十町口神ノ川');
ok($zip->set_number('7860074')->is_valid_number, '高知県高岡郡四万十町南川口');
ok($zip->set_number('7860075')->is_valid_number, '高知県高岡郡四万十町秋丸');
ok($zip->set_number('7860076')->is_valid_number, '高知県高岡郡四万十町寺野');
ok($zip->set_number('7860077')->is_valid_number, '高知県高岡郡四万十町桧生原');
ok($zip->set_number('7860078')->is_valid_number, '高知県高岡郡四万十町折合');
ok($zip->set_number('7860081')->is_valid_number, '高知県高岡郡四万十町中村');
ok($zip->set_number('7860082')->is_valid_number, '高知県高岡郡四万十町七里');
ok($zip->set_number('7860083')->is_valid_number, '高知県高岡郡四万十町西川角');
ok($zip->set_number('7860084')->is_valid_number, '高知県高岡郡四万十町東川角');
ok($zip->set_number('7860085')->is_valid_number, '高知県高岡郡四万十町根々崎');
ok($zip->set_number('7860086')->is_valid_number, '高知県高岡郡四万十町宮内');
ok($zip->set_number('7860087')->is_valid_number, '高知県高岡郡四万十町作屋');
ok($zip->set_number('7860088')->is_valid_number, '高知県高岡郡四万十町市生原');
ok($zip->set_number('7860091')->is_valid_number, '高知県高岡郡四万十町川ノ内');
ok($zip->set_number('7860092')->is_valid_number, '高知県高岡郡四万十町勝賀野');
ok($zip->set_number('7860093')->is_valid_number, '高知県高岡郡四万十町東北ノ川');
ok($zip->set_number('7860094')->is_valid_number, '高知県高岡郡四万十町一斗俵');
ok($zip->set_number('7860095')->is_valid_number, '高知県高岡郡四万十町米奥');
ok($zip->set_number('7860096')->is_valid_number, '高知県高岡郡四万十町窪川中津川');
ok($zip->set_number('7860097')->is_valid_number, '高知県高岡郡四万十町日野地');
ok($zip->set_number('7860098')->is_valid_number, '高知県高岡郡四万十町上秋丸');
ok($zip->set_number('7860301')->is_valid_number, '高知県高岡郡四万十町大正(葛籠川、轟崎を含む)');
ok($zip->set_number('7860302')->is_valid_number, '高知県高岡郡四万十町瀬里');
ok($zip->set_number('7860303')->is_valid_number, '高知県高岡郡四万十町希ノ川');
ok($zip->set_number('7860304')->is_valid_number, '高知県高岡郡四万十町下岡');
ok($zip->set_number('7860305')->is_valid_number, '高知県高岡郡四万十町上岡');
ok($zip->set_number('7860306')->is_valid_number, '高知県高岡郡四万十町小石');
ok($zip->set_number('7860307')->is_valid_number, '高知県高岡郡四万十町江師');
ok($zip->set_number('7860308')->is_valid_number, '高知県高岡郡四万十町芳川');
ok($zip->set_number('7860311')->is_valid_number, '高知県高岡郡四万十町西ノ川');
ok($zip->set_number('7860312')->is_valid_number, '高知県高岡郡四万十町大正大奈路');
ok($zip->set_number('7860313')->is_valid_number, '高知県高岡郡四万十町木屋ケ内');
ok($zip->set_number('7860314')->is_valid_number, '高知県高岡郡四万十町下道');
ok($zip->set_number('7860315')->is_valid_number, '高知県高岡郡四万十町下津井');
ok($zip->set_number('7860316')->is_valid_number, '高知県高岡郡四万十町大正中津川');
ok($zip->set_number('7860321')->is_valid_number, '高知県高岡郡四万十町大正北ノ川');
ok($zip->set_number('7860322')->is_valid_number, '高知県高岡郡四万十町打井川');
ok($zip->set_number('7860323')->is_valid_number, '高知県高岡郡四万十町上宮');
ok($zip->set_number('7860324')->is_valid_number, '高知県高岡郡四万十町弘瀬');
ok($zip->set_number('7860325')->is_valid_number, '高知県高岡郡四万十町市ノ又');
ok($zip->set_number('7860326')->is_valid_number, '高知県高岡郡四万十町烏手');
ok($zip->set_number('7860327')->is_valid_number, '高知県高岡郡四万十町相去');
ok($zip->set_number('7860501')->is_valid_number, '高知県高岡郡四万十町地吉');
ok($zip->set_number('7860502')->is_valid_number, '高知県高岡郡四万十町古城');
ok($zip->set_number('7860503')->is_valid_number, '高知県高岡郡四万十町戸川');
ok($zip->set_number('7860504')->is_valid_number, '高知県高岡郡四万十町十川');
ok($zip->set_number('7860511')->is_valid_number, '高知県高岡郡四万十町昭和(その他)');
ok($zip->set_number('7860512')->is_valid_number, '高知県高岡郡四万十町昭和甲');
ok($zip->set_number('7860513')->is_valid_number, '高知県高岡郡四万十町昭和乙');
ok($zip->set_number('7860514')->is_valid_number, '高知県高岡郡四万十町河内');
ok($zip->set_number('7860515')->is_valid_number, '高知県高岡郡四万十町久保川');
ok($zip->set_number('7860516')->is_valid_number, '高知県高岡郡四万十町口大道');
ok($zip->set_number('7860517')->is_valid_number, '高知県高岡郡四万十町奥大道');
ok($zip->set_number('7860521')->is_valid_number, '高知県高岡郡四万十町津賀');
ok($zip->set_number('7860522')->is_valid_number, '高知県高岡郡四万十町茅吹手');
ok($zip->set_number('7860523')->is_valid_number, '高知県高岡郡四万十町浦越');
ok($zip->set_number('7860524')->is_valid_number, '高知県高岡郡四万十町里川');
ok($zip->set_number('7860525')->is_valid_number, '高知県高岡郡四万十町野々川');
ok($zip->set_number('7860531')->is_valid_number, '高知県高岡郡四万十町小野');
ok($zip->set_number('7860532')->is_valid_number, '高知県高岡郡四万十町大井川');
ok($zip->set_number('7860533')->is_valid_number, '高知県高岡郡四万十町井崎');
ok($zip->set_number('7860534')->is_valid_number, '高知県高岡郡四万十町広瀬');
ok($zip->set_number('7860535')->is_valid_number, '高知県高岡郡四万十町十和川口');
ok($zip->set_number('7870000')->is_valid_number, '高知県四万十市以下に掲載がない場合');
ok($zip->set_number('7870001')->is_valid_number, '高知県四万十市中村本町');
ok($zip->set_number('7870002')->is_valid_number, '高知県四万十市中村桜町');
ok($zip->set_number('7870003')->is_valid_number, '高知県四万十市中村丸の内(その他)');
ok($zip->set_number('7870004')->is_valid_number, '高知県四万十市中村丸の内(丸の内ハイランド)');
ok($zip->set_number('7870005')->is_valid_number, '高知県四万十市中村(桂山団地)');
ok($zip->set_number('7870006')->is_valid_number, '高知県四万十市麻生');
ok($zip->set_number('7870007')->is_valid_number, '高知県四万十市秋田');
ok($zip->set_number('7870008')->is_valid_number, '高知県四万十市安並');
ok($zip->set_number('7870009')->is_valid_number, '高知県四万十市佐岡');
ok($zip->set_number('7870010')->is_valid_number, '高知県四万十市古津賀');
ok($zip->set_number('7870011')->is_valid_number, '高知県四万十市右山元町');
ok($zip->set_number('7870012')->is_valid_number, '高知県四万十市右山五月町');
ok($zip->set_number('7870013')->is_valid_number, '高知県四万十市右山天神町');
ok($zip->set_number('7870014')->is_valid_number, '高知県四万十市駅前町');
ok($zip->set_number('7870015')->is_valid_number, '高知県四万十市右山');
ok($zip->set_number('7870016')->is_valid_number, '高知県四万十市角崎');
ok($zip->set_number('7870017')->is_valid_number, '高知県四万十市不破');
ok($zip->set_number('7870018')->is_valid_number, '高知県四万十市不破上町');
ok($zip->set_number('7870019')->is_valid_number, '高知県四万十市具同');
ok($zip->set_number('7870020')->is_valid_number, '高知県四万十市入田');
ok($zip->set_number('7870021')->is_valid_number, '高知県四万十市中村京町');
ok($zip->set_number('7870022')->is_valid_number, '高知県四万十市中村新町');
ok($zip->set_number('7870023')->is_valid_number, '高知県四万十市中村東町');
ok($zip->set_number('7870024')->is_valid_number, '高知県四万十市中村於東町');
ok($zip->set_number('7870025')->is_valid_number, '高知県四万十市中村一条通');
ok($zip->set_number('7870026')->is_valid_number, '高知県四万十市中村愛宕町');
ok($zip->set_number('7870027')->is_valid_number, '高知県四万十市中村天神橋');
ok($zip->set_number('7870028')->is_valid_number, '高知県四万十市中村山手通');
ok($zip->set_number('7870029')->is_valid_number, '高知県四万十市中村小姓町');
ok($zip->set_number('7870030')->is_valid_number, '高知県四万十市中村上小姓町');
ok($zip->set_number('7870031')->is_valid_number, '高知県四万十市中村東下町');
ok($zip->set_number('7870032')->is_valid_number, '高知県四万十市中村栄町');
ok($zip->set_number('7870033')->is_valid_number, '高知県四万十市中村大橋通');
ok($zip->set_number('7870034')->is_valid_number, '高知県四万十市中村弥生町');
ok($zip->set_number('7870035')->is_valid_number, '高知県四万十市中村羽生小路');
ok($zip->set_number('7870036')->is_valid_number, '高知県四万十市中村岩崎町');
ok($zip->set_number('7870037')->is_valid_number, '高知県四万十市中村四万十町');
ok($zip->set_number('7870038')->is_valid_number, '高知県四万十市中村百笑町');
ok($zip->set_number('7870050')->is_valid_number, '高知県四万十市渡川');
ok($zip->set_number('7870051')->is_valid_number, '高知県四万十市具同田黒');
ok($zip->set_number('7870052')->is_valid_number, '高知県四万十市赤松町');
ok($zip->set_number('7870150')->is_valid_number, '高知県四万十市井沢');
ok($zip->set_number('7870151')->is_valid_number, '高知県四万十市竹島');
ok($zip->set_number('7870152')->is_valid_number, '高知県四万十市鍋島');
ok($zip->set_number('7870153')->is_valid_number, '高知県四万十市双海');
ok($zip->set_number('7870154')->is_valid_number, '高知県四万十市平野');
ok($zip->set_number('7870155')->is_valid_number, '高知県四万十市下田');
ok($zip->set_number('7870156')->is_valid_number, '高知県四万十市坂本');
ok($zip->set_number('7870157')->is_valid_number, '高知県四万十市山路');
ok($zip->set_number('7870158')->is_valid_number, '高知県四万十市実崎');
ok($zip->set_number('7870159')->is_valid_number, '高知県四万十市深木');
ok($zip->set_number('7870160')->is_valid_number, '高知県四万十市間崎');
ok($zip->set_number('7870161')->is_valid_number, '高知県四万十市津蔵渕');
ok($zip->set_number('7870162')->is_valid_number, '高知県四万十市初崎');
ok($zip->set_number('7870163')->is_valid_number, '高知県四万十市名鹿');
ok($zip->set_number('7870240')->is_valid_number, '高知県土佐清水市立石');
ok($zip->set_number('7870241')->is_valid_number, '高知県土佐清水市布');
ok($zip->set_number('7870242')->is_valid_number, '高知県土佐清水市下ノ加江');
ok($zip->set_number('7870243')->is_valid_number, '高知県土佐清水市鍵掛');
ok($zip->set_number('7870244')->is_valid_number, '高知県土佐清水市久百々');
ok($zip->set_number('7870300')->is_valid_number, '高知県土佐清水市以下に掲載がない場合');
ok($zip->set_number('7870301')->is_valid_number, '高知県土佐清水市大岐');
ok($zip->set_number('7870302')->is_valid_number, '高知県土佐清水市以布利');
ok($zip->set_number('7870303')->is_valid_number, '高知県土佐清水市旭町');
ok($zip->set_number('7870304')->is_valid_number, '高知県土佐清水市元町');
ok($zip->set_number('7870305')->is_valid_number, '高知県土佐清水市天神町');
ok($zip->set_number('7870306')->is_valid_number, '高知県土佐清水市幸町');
ok($zip->set_number('7870307')->is_valid_number, '高知県土佐清水市緑ケ丘');
ok($zip->set_number('7870308')->is_valid_number, '高知県土佐清水市厚生町');
ok($zip->set_number('7870310')->is_valid_number, '高知県土佐清水市浦尻');
ok($zip->set_number('7870311')->is_valid_number, '高知県土佐清水市グリーンハイツ');
ok($zip->set_number('7870312')->is_valid_number, '高知県土佐清水市窪津');
ok($zip->set_number('7870313')->is_valid_number, '高知県土佐清水市津呂');
ok($zip->set_number('7870314')->is_valid_number, '高知県土佐清水市大谷');
ok($zip->set_number('7870315')->is_valid_number, '高知県土佐清水市足摺岬');
ok($zip->set_number('7870316')->is_valid_number, '高知県土佐清水市松尾');
ok($zip->set_number('7870317')->is_valid_number, '高知県土佐清水市大浜');
ok($zip->set_number('7870318')->is_valid_number, '高知県土佐清水市中浜');
ok($zip->set_number('7870320')->is_valid_number, '高知県土佐清水市清水');
ok($zip->set_number('7870321')->is_valid_number, '高知県土佐清水市浜町');
ok($zip->set_number('7870322')->is_valid_number, '高知県土佐清水市小江町');
ok($zip->set_number('7870323')->is_valid_number, '高知県土佐清水市寿町');
ok($zip->set_number('7870324')->is_valid_number, '高知県土佐清水市中央町');
ok($zip->set_number('7870325')->is_valid_number, '高知県土佐清水市栄町');
ok($zip->set_number('7870326')->is_valid_number, '高知県土佐清水市本町');
ok($zip->set_number('7870327')->is_valid_number, '高知県土佐清水市市場町');
ok($zip->set_number('7870328')->is_valid_number, '高知県土佐清水市戎町');
ok($zip->set_number('7870330')->is_valid_number, '高知県土佐清水市清水ヶ丘');
ok($zip->set_number('7870331')->is_valid_number, '高知県土佐清水市越前町');
ok($zip->set_number('7870332')->is_valid_number, '高知県土佐清水市汐見町');
ok($zip->set_number('7870333')->is_valid_number, '高知県土佐清水市西町');
ok($zip->set_number('7870334')->is_valid_number, '高知県土佐清水市加久見入沢町');
ok($zip->set_number('7870335')->is_valid_number, '高知県土佐清水市加久見新町');
ok($zip->set_number('7870336')->is_valid_number, '高知県土佐清水市加久見(その他)');
ok($zip->set_number('7870337')->is_valid_number, '高知県土佐清水市養老');
ok($zip->set_number('7870338')->is_valid_number, '高知県土佐清水市加久見(松崎)');
ok($zip->set_number('7870339')->is_valid_number, '高知県土佐清水市横道');
ok($zip->set_number('7870445')->is_valid_number, '高知県土佐清水市下益野');
ok($zip->set_number('7870446')->is_valid_number, '高知県土佐清水市斧積');
ok($zip->set_number('7870447')->is_valid_number, '高知県土佐清水市上野');
ok($zip->set_number('7870450')->is_valid_number, '高知県土佐清水市三崎');
ok($zip->set_number('7870451')->is_valid_number, '高知県土佐清水市三崎浦');
ok($zip->set_number('7870452')->is_valid_number, '高知県土佐清水市竜串');
ok($zip->set_number('7870453')->is_valid_number, '高知県土佐清水市爪白');
ok($zip->set_number('7870556')->is_valid_number, '高知県土佐清水市有永');
ok($zip->set_number('7870557')->is_valid_number, '高知県土佐清水市宗呂乙');
ok($zip->set_number('7870558')->is_valid_number, '高知県土佐清水市宗呂丙');
ok($zip->set_number('7870559')->is_valid_number, '高知県土佐清水市下川口');
ok($zip->set_number('7870560')->is_valid_number, '高知県土佐清水市片粕');
ok($zip->set_number('7870561')->is_valid_number, '高知県土佐清水市貝ノ川');
ok($zip->set_number('7870562')->is_valid_number, '高知県土佐清水市大津');
ok($zip->set_number('7870563')->is_valid_number, '高知県土佐清水市宗呂甲');
ok($zip->set_number('7870665')->is_valid_number, '高知県四万十市森沢');
ok($zip->set_number('7870666')->is_valid_number, '高知県四万十市楠島');
ok($zip->set_number('7870667')->is_valid_number, '高知県四万十市国見');
ok($zip->set_number('7870668')->is_valid_number, '高知県四万十市荒川');
ok($zip->set_number('7870669')->is_valid_number, '高知県四万十市江ノ村');
ok($zip->set_number('7870771')->is_valid_number, '高知県四万十市有岡');
ok($zip->set_number('7870772')->is_valid_number, '高知県四万十市横瀬');
ok($zip->set_number('7870773')->is_valid_number, '高知県四万十市磯ノ川');
ok($zip->set_number('7870774')->is_valid_number, '高知県四万十市生ノ川');
ok($zip->set_number('7870775')->is_valid_number, '高知県四万十市九樹');
ok($zip->set_number('7870776')->is_valid_number, '高知県四万十市上ノ土居');
ok($zip->set_number('7870800')->is_valid_number, '高知県幡多郡三原村以下に掲載がない場合');
ok($zip->set_number('7870801')->is_valid_number, '高知県幡多郡三原村柚ノ木');
ok($zip->set_number('7870802')->is_valid_number, '高知県幡多郡三原村宮ノ川');
ok($zip->set_number('7870803')->is_valid_number, '高知県幡多郡三原村来栖野');
ok($zip->set_number('7870804')->is_valid_number, '高知県幡多郡三原村上下長谷');
ok($zip->set_number('7870805')->is_valid_number, '高知県幡多郡三原村上長谷');
ok($zip->set_number('7870806')->is_valid_number, '高知県幡多郡三原村狼内');
ok($zip->set_number('7870807')->is_valid_number, '高知県幡多郡三原村成山');
ok($zip->set_number('7870811')->is_valid_number, '高知県幡多郡三原村芳井');
ok($zip->set_number('7870812')->is_valid_number, '高知県幡多郡三原村下長谷');
ok($zip->set_number('7870813')->is_valid_number, '高知県幡多郡三原村皆尾');
ok($zip->set_number('7870814')->is_valid_number, '高知県幡多郡三原村広野');
ok($zip->set_number('7870815')->is_valid_number, '高知県幡多郡三原村亀ノ川');
ok($zip->set_number('7870816')->is_valid_number, '高知県幡多郡三原村下切');
ok($zip->set_number('7871101')->is_valid_number, '高知県四万十市奥鴨川');
ok($zip->set_number('7871102')->is_valid_number, '高知県四万十市口鴨川');
ok($zip->set_number('7871103')->is_valid_number, '高知県四万十市板ノ川');
ok($zip->set_number('7871104')->is_valid_number, '高知県四万十市若藤');
ok($zip->set_number('7871105')->is_valid_number, '高知県四万十市利岡');
ok($zip->set_number('7871106')->is_valid_number, '高知県四万十市佐田');
ok($zip->set_number('7871107')->is_valid_number, '高知県四万十市岩田');
ok($zip->set_number('7871107')->is_valid_number, '高知県四万十市中村(大用寺)');
ok($zip->set_number('7871108')->is_valid_number, '高知県四万十市敷地');
ok($zip->set_number('7871109')->is_valid_number, '高知県四万十市田野川');
ok($zip->set_number('7871220')->is_valid_number, '高知県四万十市川登');
ok($zip->set_number('7871221')->is_valid_number, '高知県四万十市三里');
ok($zip->set_number('7871222')->is_valid_number, '高知県四万十市手洗川');
ok($zip->set_number('7871223')->is_valid_number, '高知県四万十市勝間(勝間川)');
ok($zip->set_number('7871224')->is_valid_number, '高知県四万十市勝間(その他)');
ok($zip->set_number('7871225')->is_valid_number, '高知県四万十市久保川');
ok($zip->set_number('7871226')->is_valid_number, '高知県四万十市鵜ノ江');
ok($zip->set_number('7871227')->is_valid_number, '高知県四万十市楠');
ok($zip->set_number('7871228')->is_valid_number, '高知県四万十市高瀬');
ok($zip->set_number('7871229')->is_valid_number, '高知県四万十市田出ノ川');
ok($zip->set_number('7871321')->is_valid_number, '高知県四万十市西土佐岩間');
ok($zip->set_number('7871322')->is_valid_number, '高知県四万十市西土佐茅生');
ok($zip->set_number('7871323')->is_valid_number, '高知県四万十市西土佐中半');
ok($zip->set_number('7871324')->is_valid_number, '高知県四万十市西土佐口屋内');
ok($zip->set_number('7871325')->is_valid_number, '高知県四万十市西土佐玖木');
ok($zip->set_number('7871326')->is_valid_number, '高知県四万十市西土佐奥屋内');
ok($zip->set_number('7871441')->is_valid_number, '高知県四万十市伊才原');
ok($zip->set_number('7871442')->is_valid_number, '高知県四万十市蕨岡甲');
ok($zip->set_number('7871443')->is_valid_number, '高知県四万十市蕨岡乙');
ok($zip->set_number('7871444')->is_valid_number, '高知県四万十市藤');
ok($zip->set_number('7871550')->is_valid_number, '高知県四万十市大用');
ok($zip->set_number('7871551')->is_valid_number, '高知県四万十市住次郎');
ok($zip->set_number('7871552')->is_valid_number, '高知県四万十市片魚');
ok($zip->set_number('7871553')->is_valid_number, '高知県四万十市大屋敷');
ok($zip->set_number('7871554')->is_valid_number, '高知県四万十市常六');
ok($zip->set_number('7871555')->is_valid_number, '高知県四万十市三ツ又');
ok($zip->set_number('7871556')->is_valid_number, '高知県四万十市小西ノ川');
ok($zip->set_number('7871557')->is_valid_number, '高知県四万十市大西ノ川');
ok($zip->set_number('7871558')->is_valid_number, '高知県四万十市古尾');
ok($zip->set_number('7871559')->is_valid_number, '高知県四万十市竹屋敷');
ok($zip->set_number('7871601')->is_valid_number, '高知県四万十市西土佐江川崎');
ok($zip->set_number('7871602')->is_valid_number, '高知県四万十市西土佐西ケ方');
ok($zip->set_number('7871603')->is_valid_number, '高知県四万十市西土佐用井');
ok($zip->set_number('7871604')->is_valid_number, '高知県四万十市西土佐藤ノ川');
ok($zip->set_number('7871605')->is_valid_number, '高知県四万十市西土佐長生');
ok($zip->set_number('7871606')->is_valid_number, '高知県四万十市西土佐半家');
ok($zip->set_number('7871607')->is_valid_number, '高知県四万十市西土佐江川');
ok($zip->set_number('7871611')->is_valid_number, '高知県四万十市西土佐橘');
ok($zip->set_number('7871612')->is_valid_number, '高知県四万十市西土佐津野川');
ok($zip->set_number('7871613')->is_valid_number, '高知県四万十市西土佐津賀');
ok($zip->set_number('7871614')->is_valid_number, '高知県四万十市西土佐薮ケ市');
ok($zip->set_number('7871615')->is_valid_number, '高知県四万十市西土佐大宮');
ok($zip->set_number('7871616')->is_valid_number, '高知県四万十市西土佐須崎');
ok($zip->set_number('7871617')->is_valid_number, '高知県四万十市西土佐下家地');
ok($zip->set_number('7871618')->is_valid_number, '高知県四万十市西土佐中家地');
ok($zip->set_number('7880000')->is_valid_number, '高知県宿毛市以下に掲載がない場合');
ok($zip->set_number('7880001')->is_valid_number, '高知県宿毛市中央');
ok($zip->set_number('7880002')->is_valid_number, '高知県宿毛市南沖須賀');
ok($zip->set_number('7880003')->is_valid_number, '高知県宿毛市幸町');
ok($zip->set_number('7880004')->is_valid_number, '高知県宿毛市長田町');
ok($zip->set_number('7880005')->is_valid_number, '高知県宿毛市萩原');
ok($zip->set_number('7880006')->is_valid_number, '高知県宿毛市桜町');
ok($zip->set_number('7880007')->is_valid_number, '高知県宿毛市松田町');
ok($zip->set_number('7880008')->is_valid_number, '高知県宿毛市与市明');
ok($zip->set_number('7880009')->is_valid_number, '高知県宿毛市駅東町');
ok($zip->set_number('7880010')->is_valid_number, '高知県宿毛市駅前町');
ok($zip->set_number('7880011')->is_valid_number, '高知県宿毛市新田');
ok($zip->set_number('7880012')->is_valid_number, '高知県宿毛市高砂');
ok($zip->set_number('7880013')->is_valid_number, '高知県宿毛市片島');
ok($zip->set_number('7880014')->is_valid_number, '高知県宿毛市大島');
ok($zip->set_number('7880015')->is_valid_number, '高知県宿毛市西片島');
ok($zip->set_number('7880016')->is_valid_number, '高知県宿毛市希望ヶ丘');
ok($zip->set_number('7880021')->is_valid_number, '高知県宿毛市池島');
ok($zip->set_number('7880022')->is_valid_number, '高知県宿毛市藻津');
ok($zip->set_number('7880023')->is_valid_number, '高知県宿毛市宇須々木');
ok($zip->set_number('7880024')->is_valid_number, '高知県宿毛市樺');
ok($zip->set_number('7880025')->is_valid_number, '高知県宿毛市西町');
ok($zip->set_number('7880026')->is_valid_number, '高知県宿毛市自由ケ丘');
ok($zip->set_number('7880027')->is_valid_number, '高知県宿毛市港南台');
ok($zip->set_number('7880028')->is_valid_number, '高知県宿毛市新港');
ok($zip->set_number('7880030')->is_valid_number, '高知県宿毛市四季の丘');
ok($zip->set_number('7880031')->is_valid_number, '高知県宿毛市貝塚');
ok($zip->set_number('7880032')->is_valid_number, '高知県宿毛市錦');
ok($zip->set_number('7880033')->is_valid_number, '高知県宿毛市小深浦');
ok($zip->set_number('7880034')->is_valid_number, '高知県宿毛市大深浦');
ok($zip->set_number('7880035')->is_valid_number, '高知県宿毛市草木薮');
ok($zip->set_number('7880036')->is_valid_number, '高知県宿毛市野地');
ok($zip->set_number('7880037')->is_valid_number, '高知県宿毛市山北');
ok($zip->set_number('7880038')->is_valid_number, '高知県宿毛市二ノ宮');
ok($zip->set_number('7880039')->is_valid_number, '高知県宿毛市中角');
ok($zip->set_number('7880041')->is_valid_number, '高知県宿毛市橋上町出井');
ok($zip->set_number('7880042')->is_valid_number, '高知県宿毛市橋上町楠山');
ok($zip->set_number('7880043')->is_valid_number, '高知県宿毛市橋上町坂本');
ok($zip->set_number('7880044')->is_valid_number, '高知県宿毛市橋上町神有');
ok($zip->set_number('7880045')->is_valid_number, '高知県宿毛市橋上町奥奈路');
ok($zip->set_number('7880046')->is_valid_number, '高知県宿毛市橋上町橋上');
ok($zip->set_number('7880047')->is_valid_number, '高知県宿毛市橋上町平野');
ok($zip->set_number('7880048')->is_valid_number, '高知県宿毛市橋上町京法');
ok($zip->set_number('7880049')->is_valid_number, '高知県宿毛市橋上町還住薮');
ok($zip->set_number('7880051')->is_valid_number, '高知県宿毛市押ノ川');
ok($zip->set_number('7880052')->is_valid_number, '高知県宿毛市和田');
ok($zip->set_number('7880053')->is_valid_number, '高知県宿毛市坂ノ下');
ok($zip->set_number('7880054')->is_valid_number, '高知県宿毛市さくらが丘');
ok($zip->set_number('7880261')->is_valid_number, '高知県宿毛市小筑紫町田ノ浦');
ok($zip->set_number('7880262')->is_valid_number, '高知県宿毛市小筑紫町小浦');
ok($zip->set_number('7880263')->is_valid_number, '高知県宿毛市小筑紫町内外ノ浦');
ok($zip->set_number('7880264')->is_valid_number, '高知県宿毛市小筑紫町呼崎');
ok($zip->set_number('7880265')->is_valid_number, '高知県宿毛市小筑紫町湊');
ok($zip->set_number('7880266')->is_valid_number, '高知県宿毛市小筑紫町大海');
ok($zip->set_number('7880267')->is_valid_number, '高知県宿毛市小筑紫町伊与野');
ok($zip->set_number('7880268')->is_valid_number, '高知県宿毛市小筑紫町都賀ノ川');
ok($zip->set_number('7880271')->is_valid_number, '高知県宿毛市小筑紫町小筑紫');
ok($zip->set_number('7880272')->is_valid_number, '高知県宿毛市小筑紫町石原');
ok($zip->set_number('7880273')->is_valid_number, '高知県宿毛市小筑紫町福良');
ok($zip->set_number('7880274')->is_valid_number, '高知県宿毛市小筑紫町栄喜');
ok($zip->set_number('7880300')->is_valid_number, '高知県幡多郡大月町以下に掲載がない場合');
ok($zip->set_number('7880302')->is_valid_number, '高知県幡多郡大月町弘見');
ok($zip->set_number('7880311')->is_valid_number, '高知県幡多郡大月町鉾土');
ok($zip->set_number('7880312')->is_valid_number, '高知県幡多郡大月町清王');
ok($zip->set_number('7880313')->is_valid_number, '高知県幡多郡大月町周防形');
ok($zip->set_number('7880314')->is_valid_number, '高知県幡多郡大月町頭集');
ok($zip->set_number('7880315')->is_valid_number, '高知県幡多郡大月町古満目');
ok($zip->set_number('7880321')->is_valid_number, '高知県幡多郡大月町春遠');
ok($zip->set_number('7880322')->is_valid_number, '高知県幡多郡大月町小才角');
ok($zip->set_number('7880323')->is_valid_number, '高知県幡多郡大月町才角');
ok($zip->set_number('7880324')->is_valid_number, '高知県幡多郡大月町大浦');
ok($zip->set_number('7880325')->is_valid_number, '高知県幡多郡大月町月ケ丘');
ok($zip->set_number('7880331')->is_valid_number, '高知県幡多郡大月町口目塚');
ok($zip->set_number('7880331')->is_valid_number, '高知県幡多郡大月町姫ノ井');
ok($zip->set_number('7880332')->is_valid_number, '高知県幡多郡大月町赤泊');
ok($zip->set_number('7880333')->is_valid_number, '高知県幡多郡大月町西泊');
ok($zip->set_number('7880334')->is_valid_number, '高知県幡多郡大月町樫ノ浦');
ok($zip->set_number('7880335')->is_valid_number, '高知県幡多郡大月町唐岩');
ok($zip->set_number('7880341')->is_valid_number, '高知県幡多郡大月町平山');
ok($zip->set_number('7880342')->is_valid_number, '高知県幡多郡大月町一切');
ok($zip->set_number('7880343')->is_valid_number, '高知県幡多郡大月町柏島');
ok($zip->set_number('7880351')->is_valid_number, '高知県幡多郡大月町安満地');
ok($zip->set_number('7880352')->is_valid_number, '高知県幡多郡大月町橘浦');
ok($zip->set_number('7880353')->is_valid_number, '高知県幡多郡大月町泊浦');
ok($zip->set_number('7880361')->is_valid_number, '高知県幡多郡大月町龍ケ迫');
ok($zip->set_number('7880362')->is_valid_number, '高知県幡多郡大月町芳ノ沢');
ok($zip->set_number('7880363')->is_valid_number, '高知県幡多郡大月町添ノ川');
ok($zip->set_number('7880677')->is_valid_number, '高知県宿毛市沖の島町母島');
ok($zip->set_number('7880678')->is_valid_number, '高知県宿毛市沖の島町弘瀬');
ok($zip->set_number('7880679')->is_valid_number, '高知県宿毛市沖の島町鵜来島');
ok($zip->set_number('7880781')->is_valid_number, '高知県宿毛市平田町黒川');
ok($zip->set_number('7880782')->is_valid_number, '高知県宿毛市平田町中山');
ok($zip->set_number('7880783')->is_valid_number, '高知県宿毛市平田町戸内');
ok($zip->set_number('7880784')->is_valid_number, '高知県宿毛市山奈町山田');
ok($zip->set_number('7880785')->is_valid_number, '高知県宿毛市山奈町芳奈');
ok($zip->set_number('7880786')->is_valid_number, '高知県宿毛市平田町東平');
ok($zip->set_number('7890156')->is_valid_number, '高知県長岡郡大豊町八川');
ok($zip->set_number('7890157')->is_valid_number, '高知県長岡郡大豊町筏木');
ok($zip->set_number('7890158')->is_valid_number, '高知県長岡郡大豊町岩原');
ok($zip->set_number('7890159')->is_valid_number, '高知県長岡郡大豊町西峰(三谷)');
ok($zip->set_number('7890160')->is_valid_number, '高知県長岡郡大豊町西峰(その他)');
ok($zip->set_number('7890161')->is_valid_number, '高知県長岡郡大豊町柚木');
ok($zip->set_number('7890162')->is_valid_number, '高知県長岡郡大豊町怒田');
ok($zip->set_number('7890163')->is_valid_number, '高知県長岡郡大豊町南大王');
ok($zip->set_number('7890164')->is_valid_number, '高知県長岡郡大豊町八畝');
ok($zip->set_number('7890165')->is_valid_number, '高知県長岡郡大豊町西川');
ok($zip->set_number('7890166')->is_valid_number, '高知県長岡郡大豊町東土居');
ok($zip->set_number('7890167')->is_valid_number, '高知県長岡郡大豊町粟生');
ok($zip->set_number('7890168')->is_valid_number, '高知県長岡郡大豊町立野');
ok($zip->set_number('7890169')->is_valid_number, '高知県長岡郡大豊町大平(その他)');
ok($zip->set_number('7890170')->is_valid_number, '高知県長岡郡大豊町大滝(落合)');
ok($zip->set_number('7890171')->is_valid_number, '高知県長岡郡大豊町大滝(その他)');
ok($zip->set_number('7890172')->is_valid_number, '高知県長岡郡大豊町川井');
ok($zip->set_number('7890173')->is_valid_number, '高知県長岡郡大豊町大平(高原)');
ok($zip->set_number('7890174')->is_valid_number, '高知県長岡郡大豊町中内');
ok($zip->set_number('7890231')->is_valid_number, '高知県長岡郡大豊町奥大田');
ok($zip->set_number('7890232')->is_valid_number, '高知県長岡郡大豊町梶ケ内(石堂、佐賀井)');
ok($zip->set_number('7890233')->is_valid_number, '高知県長岡郡大豊町磯谷');
ok($zip->set_number('7890234')->is_valid_number, '高知県長岡郡大豊町寺内(大田口)');
ok($zip->set_number('7890235')->is_valid_number, '高知県長岡郡大豊町船戸');
ok($zip->set_number('7890236')->is_valid_number, '高知県長岡郡大豊町和田(目付)');
ok($zip->set_number('7890237')->is_valid_number, '高知県長岡郡大豊町庵谷');
ok($zip->set_number('7890241')->is_valid_number, '高知県長岡郡大豊町川戸');
ok($zip->set_number('7890242')->is_valid_number, '高知県長岡郡大豊町連火');
ok($zip->set_number('7890243')->is_valid_number, '高知県長岡郡大豊町西久保');
ok($zip->set_number('7890244')->is_valid_number, '高知県長岡郡大豊町桃原');
ok($zip->set_number('7890245')->is_valid_number, '高知県長岡郡大豊町永淵');
ok($zip->set_number('7890246')->is_valid_number, '高知県長岡郡大豊町柳野');
ok($zip->set_number('7890247')->is_valid_number, '高知県長岡郡大豊町大砂子');
ok($zip->set_number('7890248')->is_valid_number, '高知県長岡郡大豊町大久保');
ok($zip->set_number('7890250')->is_valid_number, '高知県長岡郡大豊町黒石');
ok($zip->set_number('7890251')->is_valid_number, '高知県長岡郡大豊町中屋');
ok($zip->set_number('7890252')->is_valid_number, '高知県長岡郡大豊町上東');
ok($zip->set_number('7890253')->is_valid_number, '高知県長岡郡大豊町安野々');
ok($zip->set_number('7890254')->is_valid_number, '高知県長岡郡大豊町西土居');
ok($zip->set_number('7890255')->is_valid_number, '高知県長岡郡大豊町佐賀山');
ok($zip->set_number('7890300')->is_valid_number, '高知県長岡郡大豊町以下に掲載がない場合');
ok($zip->set_number('7890301')->is_valid_number, '高知県長岡郡大豊町津家(桧生)');
ok($zip->set_number('7890302')->is_valid_number, '高知県長岡郡大豊町葛原(その他)');
ok($zip->set_number('7890303')->is_valid_number, '高知県長岡郡大豊町川口');
ok($zip->set_number('7890304')->is_valid_number, '高知県長岡郡大豊町谷');
ok($zip->set_number('7890305')->is_valid_number, '高知県長岡郡大豊町式岩');
ok($zip->set_number('7890306')->is_valid_number, '高知県長岡郡大豊町尾生');
ok($zip->set_number('7890307')->is_valid_number, '高知県長岡郡大豊町穴内');
ok($zip->set_number('7890311')->is_valid_number, '高知県長岡郡大豊町杉');
ok($zip->set_number('7890312')->is_valid_number, '高知県長岡郡大豊町高須');
ok($zip->set_number('7890313')->is_valid_number, '高知県長岡郡大豊町川口南');
ok($zip->set_number('7890314')->is_valid_number, '高知県長岡郡大豊町日浦');
ok($zip->set_number('7890315')->is_valid_number, '高知県長岡郡大豊町中村大王');
ok($zip->set_number('7890316')->is_valid_number, '高知県長岡郡大豊町小川');
ok($zip->set_number('7890321')->is_valid_number, '高知県長岡郡大豊町角茂谷');
ok($zip->set_number('7890322')->is_valid_number, '高知県長岡郡大豊町戸手野');
ok($zip->set_number('7890323')->is_valid_number, '高知県長岡郡大豊町馬瀬');
ok($zip->set_number('7890324')->is_valid_number, '高知県長岡郡大豊町久寿軒');
ok($zip->set_number('7890325')->is_valid_number, '高知県長岡郡大豊町北川');
ok($zip->set_number('7890426')->is_valid_number, '高知県長岡郡大豊町立川上名');
ok($zip->set_number('7890427')->is_valid_number, '高知県長岡郡大豊町立川下名');
ok($zip->set_number('7890428')->is_valid_number, '高知県長岡郡大豊町葛原(千野々)');
ok($zip->set_number('7890581')->is_valid_number, '高知県香美市土佐山田町西又');
ok($zip->set_number('7890582')->is_valid_number, '高知県香美市土佐山田町角茂谷');
ok($zip->set_number('7890583')->is_valid_number, '高知県香美市土佐山田町平山(岡田丸、双子岩、向田)');
ok($zip->set_number('7890584')->is_valid_number, '高知県香美市土佐山田町北滝本');
ok($zip->set_number('7890585')->is_valid_number, '高知県香美市土佐山田町繁藤');
ok($zip->set_number('7890586')->is_valid_number, '高知県香美市土佐山田町樫谷');
ok($zip->set_number('7890587')->is_valid_number, '高知県香美市土佐山田町上穴内');
ok($zip->set_number('7891200')->is_valid_number, '高知県高岡郡佐川町以下に掲載がない場合');
ok($zip->set_number('7891201')->is_valid_number, '高知県高岡郡佐川町甲');
ok($zip->set_number('7891202')->is_valid_number, '高知県高岡郡佐川町乙');
ok($zip->set_number('7891203')->is_valid_number, '高知県高岡郡佐川町丙');
ok($zip->set_number('7891204')->is_valid_number, '高知県高岡郡佐川町加茂');
ok($zip->set_number('7891205')->is_valid_number, '高知県高岡郡佐川町室原');
ok($zip->set_number('7891211')->is_valid_number, '高知県高岡郡佐川町黒原');
ok($zip->set_number('7891212')->is_valid_number, '高知県高岡郡佐川町四ツ白');
ok($zip->set_number('7891213')->is_valid_number, '高知県高岡郡佐川町二ツ野');
ok($zip->set_number('7891214')->is_valid_number, '高知県高岡郡佐川町中野');
ok($zip->set_number('7891215')->is_valid_number, '高知県高岡郡佐川町瑞応');
ok($zip->set_number('7891216')->is_valid_number, '高知県高岡郡佐川町庄田');
ok($zip->set_number('7891217')->is_valid_number, '高知県高岡郡佐川町大田川');
ok($zip->set_number('7891218')->is_valid_number, '高知県高岡郡佐川町平野');
ok($zip->set_number('7891221')->is_valid_number, '高知県高岡郡佐川町本郷耕');
ok($zip->set_number('7891222')->is_valid_number, '高知県高岡郡佐川町西山組');
ok($zip->set_number('7891223')->is_valid_number, '高知県高岡郡佐川町西山耕');
ok($zip->set_number('7891224')->is_valid_number, '高知県高岡郡佐川町古畑耕');
ok($zip->set_number('7891225')->is_valid_number, '高知県高岡郡佐川町峰耕');
ok($zip->set_number('7891231')->is_valid_number, '高知県高岡郡佐川町永野');
ok($zip->set_number('7891232')->is_valid_number, '高知県高岡郡佐川町東組');
ok($zip->set_number('7891233')->is_valid_number, '高知県高岡郡佐川町中組');
ok($zip->set_number('7891234')->is_valid_number, '高知県高岡郡佐川町西組');
ok($zip->set_number('7891235')->is_valid_number, '高知県高岡郡佐川町川ノ内組');
ok($zip->set_number('7891300')->is_valid_number, '高知県高岡郡中土佐町以下に掲載がない場合');
ok($zip->set_number('7891301')->is_valid_number, '高知県高岡郡中土佐町久礼');
ok($zip->set_number('7891302')->is_valid_number, '高知県高岡郡中土佐町上ノ加江');
ok($zip->set_number('7891303')->is_valid_number, '高知県高岡郡中土佐町矢井賀甲');
ok($zip->set_number('7891304')->is_valid_number, '高知県高岡郡中土佐町矢井賀乙');
ok($zip->set_number('7891401')->is_valid_number, '高知県高岡郡中土佐町大野見吉野');
ok($zip->set_number('7891402')->is_valid_number, '高知県高岡郡中土佐町大野見橋谷');
ok($zip->set_number('7891403')->is_valid_number, '高知県高岡郡中土佐町大野見久万秋');
ok($zip->set_number('7891404')->is_valid_number, '高知県高岡郡中土佐町大野見奈路');
ok($zip->set_number('7891405')->is_valid_number, '高知県高岡郡中土佐町大野見伊勢川');
ok($zip->set_number('7891406')->is_valid_number, '高知県高岡郡中土佐町大野見槇野々');
ok($zip->set_number('7891407')->is_valid_number, '高知県高岡郡中土佐町大野見三ツ又');
ok($zip->set_number('7891408')->is_valid_number, '高知県高岡郡中土佐町大野見長野');
ok($zip->set_number('7891409')->is_valid_number, '高知県高岡郡中土佐町大野見竹原');
ok($zip->set_number('7891410')->is_valid_number, '高知県高岡郡中土佐町大野見栂ノ川');
ok($zip->set_number('7891411')->is_valid_number, '高知県高岡郡中土佐町大野見野老野');
ok($zip->set_number('7891412')->is_valid_number, '高知県高岡郡中土佐町大野見川奥');
ok($zip->set_number('7891413')->is_valid_number, '高知県高岡郡中土佐町大野見荒瀬');
ok($zip->set_number('7891414')->is_valid_number, '高知県高岡郡中土佐町大野見神母野');
ok($zip->set_number('7891415')->is_valid_number, '高知県高岡郡中土佐町大野見寺野');
ok($zip->set_number('7891416')->is_valid_number, '高知県高岡郡中土佐町大野見下ル川');
ok($zip->set_number('7891417')->is_valid_number, '高知県高岡郡中土佐町大野見萩中');
ok($zip->set_number('7891418')->is_valid_number, '高知県高岡郡中土佐町大野見大股');
ok($zip->set_number('7891419')->is_valid_number, '高知県高岡郡中土佐町大野見島ノ川');
ok($zip->set_number('7891701')->is_valid_number, '高知県幡多郡黒潮町市野瀬');
ok($zip->set_number('7891702')->is_valid_number, '高知県幡多郡黒潮町佐賀橘川');
ok($zip->set_number('7891703')->is_valid_number, '高知県幡多郡黒潮町拳ノ川');
ok($zip->set_number('7891704')->is_valid_number, '高知県幡多郡黒潮町川奥');
ok($zip->set_number('7891705')->is_valid_number, '高知県幡多郡黒潮町荷稲');
ok($zip->set_number('7891706')->is_valid_number, '高知県幡多郡黒潮町小黒ノ川');
ok($zip->set_number('7891707')->is_valid_number, '高知県幡多郡黒潮町中ノ川');
ok($zip->set_number('7891708')->is_valid_number, '高知県幡多郡黒潮町鈴');
ok($zip->set_number('7891711')->is_valid_number, '高知県幡多郡黒潮町市野々川');
ok($zip->set_number('7891712')->is_valid_number, '高知県幡多郡黒潮町不破原');
ok($zip->set_number('7891713')->is_valid_number, '高知県幡多郡黒潮町伊与喜');
ok($zip->set_number('7891714')->is_valid_number, '高知県幡多郡黒潮町藤縄');
ok($zip->set_number('7891715')->is_valid_number, '高知県幡多郡黒潮町熊井');
ok($zip->set_number('7891716')->is_valid_number, '高知県幡多郡黒潮町熊野浦');
ok($zip->set_number('7891720')->is_valid_number, '高知県幡多郡黒潮町佐賀(その他)');
ok($zip->set_number('7891721')->is_valid_number, '高知県幡多郡黒潮町佐賀(中角)');
ok($zip->set_number('7891722')->is_valid_number, '高知県幡多郡黒潮町佐賀(坂折)');
ok($zip->set_number('7891723')->is_valid_number, '高知県幡多郡黒潮町佐賀(馬地)');
ok($zip->set_number('7891724')->is_valid_number, '高知県幡多郡黒潮町佐賀(横浜)');
ok($zip->set_number('7891725')->is_valid_number, '高知県幡多郡黒潮町白浜');
ok($zip->set_number('7891900')->is_valid_number, '高知県幡多郡黒潮町以下に掲載がない場合');
ok($zip->set_number('7891901')->is_valid_number, '高知県幡多郡黒潮町上川口');
ok($zip->set_number('7891902')->is_valid_number, '高知県幡多郡黒潮町蜷川');
ok($zip->set_number('7891903')->is_valid_number, '高知県幡多郡黒潮町有井川');
ok($zip->set_number('7891904')->is_valid_number, '高知県幡多郡黒潮町伊田');
ok($zip->set_number('7891905')->is_valid_number, '高知県幡多郡黒潮町灘');
ok($zip->set_number('7891911')->is_valid_number, '高知県幡多郡黒潮町浮鞭');
ok($zip->set_number('7891912')->is_valid_number, '高知県幡多郡黒潮町口湊川');
ok($zip->set_number('7891913')->is_valid_number, '高知県幡多郡黒潮町奥湊川');
ok($zip->set_number('7891921')->is_valid_number, '高知県幡多郡黒潮町加持');
ok($zip->set_number('7891922')->is_valid_number, '高知県幡多郡黒潮町加持川');
ok($zip->set_number('7891923')->is_valid_number, '高知県幡多郡黒潮町大井川');
ok($zip->set_number('7891924')->is_valid_number, '高知県幡多郡黒潮町馬荷');
ok($zip->set_number('7891925')->is_valid_number, '高知県幡多郡黒潮町大方橘川');
ok($zip->set_number('7891931')->is_valid_number, '高知県幡多郡黒潮町入野');
ok($zip->set_number('7891932')->is_valid_number, '高知県幡多郡黒潮町下田の口');
ok($zip->set_number('7891933')->is_valid_number, '高知県幡多郡黒潮町田野浦');
ok($zip->set_number('7891934')->is_valid_number, '高知県幡多郡黒潮町出口');
ok($zip->set_number('7891935')->is_valid_number, '高知県幡多郡黒潮町上田の口');
ok($zip->set_number('7891936')->is_valid_number, '高知県幡多郡黒潮町御坊畑');
ok($zip->set_number('7900001')->is_valid_number, '愛媛県松山市一番町');
ok($zip->set_number('7900002')->is_valid_number, '愛媛県松山市二番町');
ok($zip->set_number('7900003')->is_valid_number, '愛媛県松山市三番町');
ok($zip->set_number('7900004')->is_valid_number, '愛媛県松山市大街道');
ok($zip->set_number('7900005')->is_valid_number, '愛媛県松山市花園町');
ok($zip->set_number('7900006')->is_valid_number, '愛媛県松山市南堀端町');
ok($zip->set_number('7900007')->is_valid_number, '愛媛県松山市堀之内');
ok($zip->set_number('7900008')->is_valid_number, '愛媛県松山市丸之内');
ok($zip->set_number('7900011')->is_valid_number, '愛媛県松山市千舟町');
ok($zip->set_number('7900012')->is_valid_number, '愛媛県松山市湊町');
ok($zip->set_number('7900013')->is_valid_number, '愛媛県松山市河原町');
ok($zip->set_number('7900014')->is_valid_number, '愛媛県松山市柳井町');
ok($zip->set_number('7900021')->is_valid_number, '愛媛県松山市真砂町');
ok($zip->set_number('7900022')->is_valid_number, '愛媛県松山市永代町');
ok($zip->set_number('7900023')->is_valid_number, '愛媛県松山市末広町');
ok($zip->set_number('7900024')->is_valid_number, '愛媛県松山市春日町');
ok($zip->set_number('7900025')->is_valid_number, '愛媛県松山市泉町');
ok($zip->set_number('7900026')->is_valid_number, '愛媛県松山市室町');
ok($zip->set_number('7900031')->is_valid_number, '愛媛県松山市雄郡');
ok($zip->set_number('7900032')->is_valid_number, '愛媛県松山市土橋町');
ok($zip->set_number('7900033')->is_valid_number, '愛媛県松山市北藤原町');
ok($zip->set_number('7900034')->is_valid_number, '愛媛県松山市藤原町');
ok($zip->set_number('7900035')->is_valid_number, '愛媛県松山市藤原');
ok($zip->set_number('7900036')->is_valid_number, '愛媛県松山市小栗');
ok($zip->set_number('7900037')->is_valid_number, '愛媛県松山市小栗町');
ok($zip->set_number('7900038')->is_valid_number, '愛媛県松山市和泉北');
ok($zip->set_number('7900041')->is_valid_number, '愛媛県松山市保免上');
ok($zip->set_number('7900042')->is_valid_number, '愛媛県松山市保免中');
ok($zip->set_number('7900043')->is_valid_number, '愛媛県松山市保免西');
ok($zip->set_number('7900044')->is_valid_number, '愛媛県松山市余戸東');
ok($zip->set_number('7900045')->is_valid_number, '愛媛県松山市余戸中');
ok($zip->set_number('7900046')->is_valid_number, '愛媛県松山市余戸西');
ok($zip->set_number('7900047')->is_valid_number, '愛媛県松山市余戸南');
ok($zip->set_number('7900048')->is_valid_number, '愛媛県松山市出合');
ok($zip->set_number('7900051')->is_valid_number, '愛媛県松山市生石町');
ok($zip->set_number('7900052')->is_valid_number, '愛媛県松山市竹原町');
ok($zip->set_number('7900053')->is_valid_number, '愛媛県松山市竹原');
ok($zip->set_number('7900054')->is_valid_number, '愛媛県松山市空港通(1、2丁目)');
ok($zip->set_number('7900055')->is_valid_number, '愛媛県松山市針田町');
ok($zip->set_number('7900056')->is_valid_number, '愛媛県松山市土居田町');
ok($zip->set_number('7900061')->is_valid_number, '愛媛県松山市南江戸町');
ok($zip->set_number('7900062')->is_valid_number, '愛媛県松山市南江戸');
ok($zip->set_number('7900063')->is_valid_number, '愛媛県松山市辻町');
ok($zip->set_number('7900064')->is_valid_number, '愛媛県松山市愛光町');
ok($zip->set_number('7900065')->is_valid_number, '愛媛県松山市宮西');
ok($zip->set_number('7900066')->is_valid_number, '愛媛県松山市宮田町');
ok($zip->set_number('7900067')->is_valid_number, '愛媛県松山市大手町');
ok($zip->set_number('7900801')->is_valid_number, '愛媛県松山市歩行町');
ok($zip->set_number('7900802')->is_valid_number, '愛媛県松山市喜与町');
ok($zip->set_number('7900803')->is_valid_number, '愛媛県松山市東雲町');
ok($zip->set_number('7900804')->is_valid_number, '愛媛県松山市中一万町');
ok($zip->set_number('7900805')->is_valid_number, '愛媛県松山市西一万町');
ok($zip->set_number('7900806')->is_valid_number, '愛媛県松山市緑町');
ok($zip->set_number('7900807')->is_valid_number, '愛媛県松山市平和通');
ok($zip->set_number('7900808')->is_valid_number, '愛媛県松山市若草町');
ok($zip->set_number('7900811')->is_valid_number, '愛媛県松山市本町');
ok($zip->set_number('7900812')->is_valid_number, '愛媛県松山市松前町');
ok($zip->set_number('7900813')->is_valid_number, '愛媛県松山市萱町');
ok($zip->set_number('7900814')->is_valid_number, '愛媛県松山市味酒町');
ok($zip->set_number('7900821')->is_valid_number, '愛媛県松山市木屋町');
ok($zip->set_number('7900822')->is_valid_number, '愛媛県松山市高砂町');
ok($zip->set_number('7900823')->is_valid_number, '愛媛県松山市清水町');
ok($zip->set_number('7900824')->is_valid_number, '愛媛県松山市御幸');
ok($zip->set_number('7900825')->is_valid_number, '愛媛県松山市道後樋又');
ok($zip->set_number('7900826')->is_valid_number, '愛媛県松山市文京町');
ok($zip->set_number('7900827')->is_valid_number, '愛媛県松山市鉄砲町');
ok($zip->set_number('7900831')->is_valid_number, '愛媛県松山市山田町');
ok($zip->set_number('7900832')->is_valid_number, '愛媛県松山市祝谷西町');
ok($zip->set_number('7900833')->is_valid_number, '愛媛県松山市祝谷');
ok($zip->set_number('7900834')->is_valid_number, '愛媛県松山市祝谷町');
ok($zip->set_number('7900835')->is_valid_number, '愛媛県松山市祝谷東町');
ok($zip->set_number('7900836')->is_valid_number, '愛媛県松山市道後鷺谷町');
ok($zip->set_number('7900837')->is_valid_number, '愛媛県松山市道後湯月町');
ok($zip->set_number('7900838')->is_valid_number, '愛媛県松山市桜谷町');
ok($zip->set_number('7900841')->is_valid_number, '愛媛県松山市道後多幸町');
ok($zip->set_number('7900842')->is_valid_number, '愛媛県松山市道後湯之町');
ok($zip->set_number('7900843')->is_valid_number, '愛媛県松山市道後町(1、2丁目)');
ok($zip->set_number('7900844')->is_valid_number, '愛媛県松山市道後一万');
ok($zip->set_number('7900845')->is_valid_number, '愛媛県松山市道後今市');
ok($zip->set_number('7900846')->is_valid_number, '愛媛県松山市道後北代');
ok($zip->set_number('7900847')->is_valid_number, '愛媛県松山市道後緑台');
ok($zip->set_number('7900848')->is_valid_number, '愛媛県松山市道後喜多町');
ok($zip->set_number('7900851')->is_valid_number, '愛媛県松山市常光寺町');
ok($zip->set_number('7900852')->is_valid_number, '愛媛県松山市石手');
ok($zip->set_number('7900853')->is_valid_number, '愛媛県松山市上市');
ok($zip->set_number('7900854')->is_valid_number, '愛媛県松山市岩崎町');
ok($zip->set_number('7900855')->is_valid_number, '愛媛県松山市持田町');
ok($zip->set_number('7900856')->is_valid_number, '愛媛県松山市南町');
ok($zip->set_number('7900857')->is_valid_number, '愛媛県松山市道後公園');
ok($zip->set_number('7900858')->is_valid_number, '愛媛県松山市道後姫塚');
ok($zip->set_number('7900861')->is_valid_number, '愛媛県松山市紅葉町');
ok($zip->set_number('7900862')->is_valid_number, '愛媛県松山市湯渡町');
ok($zip->set_number('7900863')->is_valid_number, '愛媛県松山市此花町');
ok($zip->set_number('7900864')->is_valid_number, '愛媛県松山市築山町');
ok($zip->set_number('7900865')->is_valid_number, '愛媛県松山市新立町');
ok($zip->set_number('7900866')->is_valid_number, '愛媛県松山市永木町');
ok($zip->set_number('7900867')->is_valid_number, '愛媛県松山市北立花町');
ok($zip->set_number('7900871')->is_valid_number, '愛媛県松山市東一万町');
ok($zip->set_number('7900872')->is_valid_number, '愛媛県松山市昭和町');
ok($zip->set_number('7900873')->is_valid_number, '愛媛県松山市北持田町');
ok($zip->set_number('7900874')->is_valid_number, '愛媛県松山市南持田町');
ok($zip->set_number('7900875')->is_valid_number, '愛媛県松山市御宝町');
ok($zip->set_number('7900876')->is_valid_number, '愛媛県松山市旭町');
ok($zip->set_number('7900877')->is_valid_number, '愛媛県松山市錦町');
ok($zip->set_number('7900878')->is_valid_number, '愛媛県松山市勝山町');
ok($zip->set_number('7900901')->is_valid_number, '愛媛県松山市新石手');
ok($zip->set_number('7900902')->is_valid_number, '愛媛県松山市石手白石');
ok($zip->set_number('7900903')->is_valid_number, '愛媛県松山市東野');
ok($zip->set_number('7900904')->is_valid_number, '愛媛県松山市正円寺');
ok($zip->set_number('7900905')->is_valid_number, '愛媛県松山市樽味');
ok($zip->set_number('7900911')->is_valid_number, '愛媛県松山市桑原');
ok($zip->set_number('7900912')->is_valid_number, '愛媛県松山市畑寺町');
ok($zip->set_number('7900913')->is_valid_number, '愛媛県松山市畑寺');
ok($zip->set_number('7900914')->is_valid_number, '愛媛県松山市三町');
ok($zip->set_number('7900915')->is_valid_number, '愛媛県松山市松末');
ok($zip->set_number('7900916')->is_valid_number, '愛媛県松山市束本');
ok($zip->set_number('7900921')->is_valid_number, '愛媛県松山市福音寺町');
ok($zip->set_number('7900922')->is_valid_number, '愛媛県松山市星岡');
ok($zip->set_number('7900922')->is_valid_number, '愛媛県松山市星岡町');
ok($zip->set_number('7900923')->is_valid_number, '愛媛県松山市北久米町');
ok($zip->set_number('7900924')->is_valid_number, '愛媛県松山市南久米町');
ok($zip->set_number('7900925')->is_valid_number, '愛媛県松山市鷹子町');
ok($zip->set_number('7900931')->is_valid_number, '愛媛県松山市西石井');
ok($zip->set_number('7900932')->is_valid_number, '愛媛県松山市東石井');
ok($zip->set_number('7900933')->is_valid_number, '愛媛県松山市越智');
ok($zip->set_number('7900934')->is_valid_number, '愛媛県松山市居相');
ok($zip->set_number('7900941')->is_valid_number, '愛媛県松山市和泉南');
ok($zip->set_number('7900942')->is_valid_number, '愛媛県松山市古川北');
ok($zip->set_number('7900943')->is_valid_number, '愛媛県松山市古川南');
ok($zip->set_number('7900944')->is_valid_number, '愛媛県松山市古川西');
ok($zip->set_number('7900945')->is_valid_number, '愛媛県松山市古川町');
ok($zip->set_number('7900946')->is_valid_number, '愛媛県松山市市坪北');
ok($zip->set_number('7900947')->is_valid_number, '愛媛県松山市市坪南');
ok($zip->set_number('7900948')->is_valid_number, '愛媛県松山市市坪西町');
ok($zip->set_number('7900951')->is_valid_number, '愛媛県松山市天山');
ok($zip->set_number('7900951')->is_valid_number, '愛媛県松山市天山町');
ok($zip->set_number('7900952')->is_valid_number, '愛媛県松山市朝生田町');
ok($zip->set_number('7900961')->is_valid_number, '愛媛県松山市日の出町');
ok($zip->set_number('7900962')->is_valid_number, '愛媛県松山市枝松');
ok($zip->set_number('7900963')->is_valid_number, '愛媛県松山市小坂');
ok($zip->set_number('7900964')->is_valid_number, '愛媛県松山市中村');
ok($zip->set_number('7900965')->is_valid_number, '愛媛県松山市祇園町');
ok($zip->set_number('7900966')->is_valid_number, '愛媛県松山市立花');
ok($zip->set_number('7900967')->is_valid_number, '愛媛県松山市拓川町');
ok($zip->set_number('7902641')->is_valid_number, '愛媛県松山市柳谷町');
ok($zip->set_number('7902642')->is_valid_number, '愛媛県松山市恩地町');
ok($zip->set_number('7902643')->is_valid_number, '愛媛県松山市梅木町');
ok($zip->set_number('7902644')->is_valid_number, '愛媛県松山市上総町');
ok($zip->set_number('7902645')->is_valid_number, '愛媛県松山市小屋町');
ok($zip->set_number('7902646')->is_valid_number, '愛媛県松山市神次郎町');
ok($zip->set_number('7902647')->is_valid_number, '愛媛県松山市城山町');
ok($zip->set_number('7902648')->is_valid_number, '愛媛県松山市菅沢町');
ok($zip->set_number('7910000')->is_valid_number, '愛媛県松山市以下に掲載がない場合');
ok($zip->set_number('7910054')->is_valid_number, '愛媛県松山市空港通(3~7丁目)');
ok($zip->set_number('7910101')->is_valid_number, '愛媛県松山市溝辺町');
ok($zip->set_number('7910102')->is_valid_number, '愛媛県松山市高野町');
ok($zip->set_number('7910103')->is_valid_number, '愛媛県松山市上高野町');
ok($zip->set_number('7910104')->is_valid_number, '愛媛県松山市食場町');
ok($zip->set_number('7910105')->is_valid_number, '愛媛県松山市杉立町');
ok($zip->set_number('7910111')->is_valid_number, '愛媛県松山市上伊台町');
ok($zip->set_number('7910112')->is_valid_number, '愛媛県松山市下伊台町');
ok($zip->set_number('7910113')->is_valid_number, '愛媛県松山市白水台');
ok($zip->set_number('7910114')->is_valid_number, '愛媛県松山市南白水');
ok($zip->set_number('7910120')->is_valid_number, '愛媛県松山市湯の山東');
ok($zip->set_number('7910121')->is_valid_number, '愛媛県松山市湯の山');
ok($zip->set_number('7910122')->is_valid_number, '愛媛県松山市末町');
ok($zip->set_number('7910123')->is_valid_number, '愛媛県松山市宿野町');
ok($zip->set_number('7910124')->is_valid_number, '愛媛県松山市青波町');
ok($zip->set_number('7910125')->is_valid_number, '愛媛県松山市湯山柳');
ok($zip->set_number('7910126')->is_valid_number, '愛媛県松山市玉谷町');
ok($zip->set_number('7910127')->is_valid_number, '愛媛県松山市藤野町');
ok($zip->set_number('7910128')->is_valid_number, '愛媛県松山市福見川町');
ok($zip->set_number('7910129')->is_valid_number, '愛媛県松山市川の郷町');
ok($zip->set_number('7910131')->is_valid_number, '愛媛県松山市水口町');
ok($zip->set_number('7910132')->is_valid_number, '愛媛県松山市河中町');
ok($zip->set_number('7910133')->is_valid_number, '愛媛県松山市東川町');
ok($zip->set_number('7910134')->is_valid_number, '愛媛県松山市大井野町');
ok($zip->set_number('7910135')->is_valid_number, '愛媛県松山市米野町');
ok($zip->set_number('7910150')->is_valid_number, '愛媛県松山市九川');
ok($zip->set_number('7910200')->is_valid_number, '愛媛県東温市以下に掲載がない場合');
ok($zip->set_number('7910201')->is_valid_number, '愛媛県東温市山之内');
ok($zip->set_number('7910202')->is_valid_number, '愛媛県東温市樋口');
ok($zip->set_number('7910203')->is_valid_number, '愛媛県東温市横河原');
ok($zip->set_number('7910204')->is_valid_number, '愛媛県東温市志津川');
ok($zip->set_number('7910205')->is_valid_number, '愛媛県東温市西岡');
ok($zip->set_number('7910206')->is_valid_number, '愛媛県東温市志津川南');
ok($zip->set_number('7910211')->is_valid_number, '愛媛県東温市見奈良');
ok($zip->set_number('7910212')->is_valid_number, '愛媛県東温市田窪');
ok($zip->set_number('7910213')->is_valid_number, '愛媛県東温市牛渕');
ok($zip->set_number('7910214')->is_valid_number, '愛媛県東温市南野田');
ok($zip->set_number('7910215')->is_valid_number, '愛媛県東温市北野田');
ok($zip->set_number('7910216')->is_valid_number, '愛媛県東温市野田');
ok($zip->set_number('7910221')->is_valid_number, '愛媛県東温市上村');
ok($zip->set_number('7910222')->is_valid_number, '愛媛県東温市下林');
ok($zip->set_number('7910223')->is_valid_number, '愛媛県東温市上林');
ok($zip->set_number('7910241')->is_valid_number, '愛媛県松山市小野町');
ok($zip->set_number('7910242')->is_valid_number, '愛媛県松山市北梅本町');
ok($zip->set_number('7910243')->is_valid_number, '愛媛県松山市平井町');
ok($zip->set_number('7910244')->is_valid_number, '愛媛県松山市水泥町');
ok($zip->set_number('7910245')->is_valid_number, '愛媛県松山市南梅本町');
ok($zip->set_number('7910301')->is_valid_number, '愛媛県東温市南方');
ok($zip->set_number('7910302')->is_valid_number, '愛媛県東温市吉久');
ok($zip->set_number('7910303')->is_valid_number, '愛媛県東温市北方');
ok($zip->set_number('7910311')->is_valid_number, '愛媛県東温市則之内甲');
ok($zip->set_number('7910312')->is_valid_number, '愛媛県東温市則之内乙');
ok($zip->set_number('7910313')->is_valid_number, '愛媛県東温市則之内丙');
ok($zip->set_number('7910314')->is_valid_number, '愛媛県東温市松瀬川');
ok($zip->set_number('7910315')->is_valid_number, '愛媛県東温市井内');
ok($zip->set_number('7910321')->is_valid_number, '愛媛県東温市河之内');
ok($zip->set_number('7910322')->is_valid_number, '愛媛県東温市滑川');
ok($zip->set_number('7910323')->is_valid_number, '愛媛県東温市明河');
ok($zip->set_number('7910501')->is_valid_number, '愛媛県西条市丹原町徳能出作');
ok($zip->set_number('7910502')->is_valid_number, '愛媛県西条市丹原町願連寺');
ok($zip->set_number('7910503')->is_valid_number, '愛媛県西条市丹原町今井');
ok($zip->set_number('7910504')->is_valid_number, '愛媛県西条市丹原町久妙寺');
ok($zip->set_number('7910505')->is_valid_number, '愛媛県西条市丹原町古田');
ok($zip->set_number('7910506')->is_valid_number, '愛媛県西条市丹原町徳能');
ok($zip->set_number('7910507')->is_valid_number, '愛媛県西条市丹原町高知');
ok($zip->set_number('7910508')->is_valid_number, '愛媛県西条市丹原町池田');
ok($zip->set_number('7910510')->is_valid_number, '愛媛県西条市丹原町丹原');
ok($zip->set_number('7910521')->is_valid_number, '愛媛県西条市丹原町長野');
ok($zip->set_number('7910522')->is_valid_number, '愛媛県西条市丹原町田野上方');
ok($zip->set_number('7910523')->is_valid_number, '愛媛県西条市丹原町北田野');
ok($zip->set_number('7910524')->is_valid_number, '愛媛県西条市丹原町高松');
ok($zip->set_number('7910525')->is_valid_number, '愛媛県西条市丹原町川根');
ok($zip->set_number('7910526')->is_valid_number, '愛媛県西条市丹原町田滝');
ok($zip->set_number('7910527')->is_valid_number, '愛媛県西条市丹原町関屋');
ok($zip->set_number('7910531')->is_valid_number, '愛媛県西条市丹原町来見');
ok($zip->set_number('7910532')->is_valid_number, '愛媛県西条市丹原町石経');
ok($zip->set_number('7910533')->is_valid_number, '愛媛県西条市丹原町明穂');
ok($zip->set_number('7910534')->is_valid_number, '愛媛県西条市丹原町寺尾');
ok($zip->set_number('7910535')->is_valid_number, '愛媛県西条市丹原町志川');
ok($zip->set_number('7910536')->is_valid_number, '愛媛県西条市丹原町湯谷口');
ok($zip->set_number('7910537')->is_valid_number, '愛媛県西条市丹原町臼坂');
ok($zip->set_number('7910538')->is_valid_number, '愛媛県西条市丹原町千原');
ok($zip->set_number('7910541')->is_valid_number, '愛媛県西条市丹原町鞍瀬');
ok($zip->set_number('7910542')->is_valid_number, '愛媛県西条市丹原町楠窪');
ok($zip->set_number('7910543')->is_valid_number, '愛媛県西条市丹原町明河');
ok($zip->set_number('7910562')->is_valid_number, '愛媛県西条市小松町石鎚(上戸石)');
ok($zip->set_number('7911101')->is_valid_number, '愛媛県松山市久米窪田町');
ok($zip->set_number('7911102')->is_valid_number, '愛媛県松山市来住町');
ok($zip->set_number('7911103')->is_valid_number, '愛媛県松山市今在家町');
ok($zip->set_number('7911104')->is_valid_number, '愛媛県松山市北土居');
ok($zip->set_number('7911105')->is_valid_number, '愛媛県松山市北井門');
ok($zip->set_number('7911106')->is_valid_number, '愛媛県松山市今在家');
ok($zip->set_number('7911111')->is_valid_number, '愛媛県松山市高井町');
ok($zip->set_number('7911112')->is_valid_number, '愛媛県松山市南高井町');
ok($zip->set_number('7911113')->is_valid_number, '愛媛県松山市森松町');
ok($zip->set_number('7911114')->is_valid_number, '愛媛県松山市井門町');
ok($zip->set_number('7911115')->is_valid_number, '愛媛県松山市土居町');
ok($zip->set_number('7911116')->is_valid_number, '愛媛県松山市南土居町');
ok($zip->set_number('7911121')->is_valid_number, '愛媛県松山市中野町');
ok($zip->set_number('7911122')->is_valid_number, '愛媛県松山市津吉町');
ok($zip->set_number('7911123')->is_valid_number, '愛媛県松山市東方町');
ok($zip->set_number('7911124')->is_valid_number, '愛媛県松山市上川原町');
ok($zip->set_number('7911125')->is_valid_number, '愛媛県松山市小村町');
ok($zip->set_number('7911126')->is_valid_number, '愛媛県松山市大橋町');
ok($zip->set_number('7911131')->is_valid_number, '愛媛県松山市窪野町');
ok($zip->set_number('7911132')->is_valid_number, '愛媛県松山市久谷町');
ok($zip->set_number('7911133')->is_valid_number, '愛媛県松山市浄瑠璃町');
ok($zip->set_number('7911134')->is_valid_number, '愛媛県松山市恵原町');
ok($zip->set_number('7911135')->is_valid_number, '愛媛県松山市西野町');
ok($zip->set_number('7911136')->is_valid_number, '愛媛県松山市上野町');
ok($zip->set_number('7911200')->is_valid_number, '愛媛県上浮穴郡久万高原町以下に掲載がない場合');
ok($zip->set_number('7911201')->is_valid_number, '愛媛県上浮穴郡久万高原町久万');
ok($zip->set_number('7911202')->is_valid_number, '愛媛県上浮穴郡久万高原町入野');
ok($zip->set_number('7911203')->is_valid_number, '愛媛県上浮穴郡久万高原町西明神');
ok($zip->set_number('7911204')->is_valid_number, '愛媛県上浮穴郡久万高原町東明神');
ok($zip->set_number('7911205')->is_valid_number, '愛媛県上浮穴郡久万高原町菅生');
ok($zip->set_number('7911206')->is_valid_number, '愛媛県上浮穴郡久万高原町上野尻');
ok($zip->set_number('7911207')->is_valid_number, '愛媛県上浮穴郡久万高原町下野尻');
ok($zip->set_number('7911211')->is_valid_number, '愛媛県上浮穴郡久万高原町上畑野川');
ok($zip->set_number('7911212')->is_valid_number, '愛媛県上浮穴郡久万高原町下畑野川');
ok($zip->set_number('7911213')->is_valid_number, '愛媛県上浮穴郡久万高原町直瀬');
ok($zip->set_number('7911221')->is_valid_number, '愛媛県上浮穴郡久万高原町露峰');
ok($zip->set_number('7911222')->is_valid_number, '愛媛県上浮穴郡久万高原町二名');
ok($zip->set_number('7911223')->is_valid_number, '愛媛県上浮穴郡久万高原町父野川');
ok($zip->set_number('7911501')->is_valid_number, '愛媛県上浮穴郡久万高原町上黒岩');
ok($zip->set_number('7911502')->is_valid_number, '愛媛県上浮穴郡久万高原町中黒岩');
ok($zip->set_number('7911503')->is_valid_number, '愛媛県上浮穴郡久万高原町日野浦');
ok($zip->set_number('7911504')->is_valid_number, '愛媛県上浮穴郡久万高原町大川');
ok($zip->set_number('7911505')->is_valid_number, '愛媛県上浮穴郡久万高原町有枝');
ok($zip->set_number('7911511')->is_valid_number, '愛媛県上浮穴郡久万高原町七鳥');
ok($zip->set_number('7911512')->is_valid_number, '愛媛県上浮穴郡久万高原町東川');
ok($zip->set_number('7911513')->is_valid_number, '愛媛県上浮穴郡久万高原町仕出');
ok($zip->set_number('7911514')->is_valid_number, '愛媛県上浮穴郡久万高原町沢渡');
ok($zip->set_number('7911515')->is_valid_number, '愛媛県上浮穴郡久万高原町黒藤川');
ok($zip->set_number('7911701')->is_valid_number, '愛媛県上浮穴郡久万高原町渋草');
ok($zip->set_number('7911702')->is_valid_number, '愛媛県上浮穴郡久万高原町大成');
ok($zip->set_number('7911703')->is_valid_number, '愛媛県上浮穴郡久万高原町笠方');
ok($zip->set_number('7911704')->is_valid_number, '愛媛県上浮穴郡久万高原町前組');
ok($zip->set_number('7911705')->is_valid_number, '愛媛県上浮穴郡久万高原町相の峰');
ok($zip->set_number('7911706')->is_valid_number, '愛媛県上浮穴郡久万高原町本組');
ok($zip->set_number('7911707')->is_valid_number, '愛媛県上浮穴郡久万高原町中組');
ok($zip->set_number('7911708')->is_valid_number, '愛媛県上浮穴郡久万高原町河の子');
ok($zip->set_number('7911709')->is_valid_number, '愛媛県上浮穴郡久万高原町相の木');
ok($zip->set_number('7911710')->is_valid_number, '愛媛県上浮穴郡久万高原町若山');
ok($zip->set_number('7911801')->is_valid_number, '愛媛県上浮穴郡久万高原町柳井川');
ok($zip->set_number('7911802')->is_valid_number, '愛媛県上浮穴郡久万高原町西谷');
ok($zip->set_number('7911803')->is_valid_number, '愛媛県上浮穴郡久万高原町中津');
ok($zip->set_number('7912100')->is_valid_number, '愛媛県伊予郡砥部町以下に掲載がない場合');
ok($zip->set_number('7912101')->is_valid_number, '愛媛県伊予郡砥部町高尾田(その他)');
ok($zip->set_number('7912102')->is_valid_number, '愛媛県伊予郡砥部町高尾田(砥部団地)');
ok($zip->set_number('7912103')->is_valid_number, '愛媛県伊予郡砥部町高尾田(上野団地)');
ok($zip->set_number('7912111')->is_valid_number, '愛媛県伊予郡砥部町八倉');
ok($zip->set_number('7912112')->is_valid_number, '愛媛県伊予郡砥部町重光');
ok($zip->set_number('7912113')->is_valid_number, '愛媛県伊予郡砥部町拾町');
ok($zip->set_number('7912114')->is_valid_number, '愛媛県伊予郡砥部町麻生');
ok($zip->set_number('7912115')->is_valid_number, '愛媛県伊予郡砥部町三角');
ok($zip->set_number('7912116')->is_valid_number, '愛媛県伊予郡砥部町原町');
ok($zip->set_number('7912117')->is_valid_number, '愛媛県伊予郡砥部町上原町');
ok($zip->set_number('7912120')->is_valid_number, '愛媛県伊予郡砥部町宮内(その他)');
ok($zip->set_number('7912121')->is_valid_number, '愛媛県伊予郡砥部町宮内(山並)');
ok($zip->set_number('7912122')->is_valid_number, '愛媛県伊予郡砥部町千足');
ok($zip->set_number('7912123')->is_valid_number, '愛媛県伊予郡砥部町川井');
ok($zip->set_number('7912124')->is_valid_number, '愛媛県伊予郡砥部町田ノ浦');
ok($zip->set_number('7912125')->is_valid_number, '愛媛県伊予郡砥部町七折');
ok($zip->set_number('7912126')->is_valid_number, '愛媛県伊予郡砥部町大角蔵');
ok($zip->set_number('7912131')->is_valid_number, '愛媛県伊予郡砥部町北川毛');
ok($zip->set_number('7912132')->is_valid_number, '愛媛県伊予郡砥部町大南');
ok($zip->set_number('7912133')->is_valid_number, '愛媛県伊予郡砥部町五本松');
ok($zip->set_number('7912134')->is_valid_number, '愛媛県伊予郡砥部町外山');
ok($zip->set_number('7912135')->is_valid_number, '愛媛県伊予郡砥部町鵜ノ崎');
ok($zip->set_number('7912141')->is_valid_number, '愛媛県伊予郡砥部町岩谷口');
ok($zip->set_number('7912142')->is_valid_number, '愛媛県伊予郡砥部町岩谷');
ok($zip->set_number('7912143')->is_valid_number, '愛媛県伊予郡砥部町川登');
ok($zip->set_number('7912144')->is_valid_number, '愛媛県伊予郡砥部町万年');
ok($zip->set_number('7912145')->is_valid_number, '愛媛県伊予郡砥部町大平');
ok($zip->set_number('7912201')->is_valid_number, '愛媛県伊予郡砥部町満穂');
ok($zip->set_number('7912202')->is_valid_number, '愛媛県伊予郡砥部町玉谷');
ok($zip->set_number('7912203')->is_valid_number, '愛媛県伊予郡砥部町中野川');
ok($zip->set_number('7912204')->is_valid_number, '愛媛県伊予郡砥部町高市');
ok($zip->set_number('7912205')->is_valid_number, '愛媛県伊予郡砥部町総津');
ok($zip->set_number('7912206')->is_valid_number, '愛媛県伊予郡砥部町多居谷');
ok($zip->set_number('7912207')->is_valid_number, '愛媛県伊予郡砥部町仙波');
ok($zip->set_number('7913100')->is_valid_number, '愛媛県伊予郡松前町以下に掲載がない場合');
ok($zip->set_number('7913101')->is_valid_number, '愛媛県伊予郡松前町南黒田');
ok($zip->set_number('7913102')->is_valid_number, '愛媛県伊予郡松前町北黒田');
ok($zip->set_number('7913110')->is_valid_number, '愛媛県伊予郡松前町浜');
ok($zip->set_number('7913120')->is_valid_number, '愛媛県伊予郡松前町筒井');
ok($zip->set_number('7913131')->is_valid_number, '愛媛県伊予郡松前町北川原');
ok($zip->set_number('7913132')->is_valid_number, '愛媛県伊予郡松前町西高柳');
ok($zip->set_number('7913133')->is_valid_number, '愛媛県伊予郡松前町昌農内');
ok($zip->set_number('7913134')->is_valid_number, '愛媛県伊予郡松前町西古泉');
ok($zip->set_number('7913141')->is_valid_number, '愛媛県伊予郡松前町恵久美');
ok($zip->set_number('7913142')->is_valid_number, '愛媛県伊予郡松前町上高柳');
ok($zip->set_number('7913143')->is_valid_number, '愛媛県伊予郡松前町大間');
ok($zip->set_number('7913151')->is_valid_number, '愛媛県伊予郡松前町東古泉');
ok($zip->set_number('7913152')->is_valid_number, '愛媛県伊予郡松前町永田');
ok($zip->set_number('7913153')->is_valid_number, '愛媛県伊予郡松前町大溝');
ok($zip->set_number('7913154')->is_valid_number, '愛媛県伊予郡松前町横田');
ok($zip->set_number('7913155')->is_valid_number, '愛媛県伊予郡松前町鶴吉');
ok($zip->set_number('7913161')->is_valid_number, '愛媛県伊予郡松前町神崎');
ok($zip->set_number('7913162')->is_valid_number, '愛媛県伊予郡松前町出作');
ok($zip->set_number('7913163')->is_valid_number, '愛媛県伊予郡松前町徳丸');
ok($zip->set_number('7913164')->is_valid_number, '愛媛県伊予郡松前町中川原');
ok($zip->set_number('7913201')->is_valid_number, '愛媛県伊予市中山町佐礼谷');
ok($zip->set_number('7913202')->is_valid_number, '愛媛県伊予市中山町栗田');
ok($zip->set_number('7913203')->is_valid_number, '愛媛県伊予市中山町出渕(豊岡・東町)');
ok($zip->set_number('7913204')->is_valid_number, '愛媛県伊予市中山町出渕(その他)');
ok($zip->set_number('7913205')->is_valid_number, '愛媛県伊予市中山町中山(泉町)');
ok($zip->set_number('7913206')->is_valid_number, '愛媛県伊予市中山町中山(その他)');
ok($zip->set_number('7913300')->is_valid_number, '愛媛県喜多郡内子町以下に掲載がない場合');
ok($zip->set_number('7913301')->is_valid_number, '愛媛県喜多郡内子町内子');
ok($zip->set_number('7913310')->is_valid_number, '愛媛県喜多郡内子町城廻');
ok($zip->set_number('7913321')->is_valid_number, '愛媛県喜多郡内子町川中');
ok($zip->set_number('7913322')->is_valid_number, '愛媛県喜多郡内子町知清');
ok($zip->set_number('7913331')->is_valid_number, '愛媛県喜多郡内子町立山');
ok($zip->set_number('7913332')->is_valid_number, '愛媛県喜多郡内子町袋口');
ok($zip->set_number('7913341')->is_valid_number, '愛媛県喜多郡内子町論田');
ok($zip->set_number('7913342')->is_valid_number, '愛媛県喜多郡内子町河内');
ok($zip->set_number('7913343')->is_valid_number, '愛媛県喜多郡内子町石畳');
ok($zip->set_number('7913351')->is_valid_number, '愛媛県喜多郡内子町五百木');
ok($zip->set_number('7913352')->is_valid_number, '愛媛県喜多郡内子町村前');
ok($zip->set_number('7913360')->is_valid_number, '愛媛県喜多郡内子町大瀬');
ok($zip->set_number('7913361')->is_valid_number, '愛媛県喜多郡内子町大瀬中央(鵜川、大久保、乙成、中野、本町1~3)');
ok($zip->set_number('7913362')->is_valid_number, '愛媛県喜多郡内子町大瀬北(乙影山、熊の滝、甲影山、程内)');
ok($zip->set_number('7913363')->is_valid_number, '愛媛県喜多郡内子町大瀬東');
ok($zip->set_number('7913364')->is_valid_number, '愛媛県喜多郡内子町大瀬南');
ok($zip->set_number('7913501')->is_valid_number, '愛媛県喜多郡内子町小田');
ok($zip->set_number('7913502')->is_valid_number, '愛媛県喜多郡内子町寺村');
ok($zip->set_number('7913503')->is_valid_number, '愛媛県喜多郡内子町日野川');
ok($zip->set_number('7913504')->is_valid_number, '愛媛県喜多郡内子町大平');
ok($zip->set_number('7913505')->is_valid_number, '愛媛県喜多郡内子町立石');
ok($zip->set_number('7913506')->is_valid_number, '愛媛県喜多郡内子町南山');
ok($zip->set_number('7913511')->is_valid_number, '愛媛県喜多郡内子町吉野川');
ok($zip->set_number('7913512')->is_valid_number, '愛媛県喜多郡内子町中田渡');
ok($zip->set_number('7913513')->is_valid_number, '愛媛県喜多郡内子町上田渡');
ok($zip->set_number('7913514')->is_valid_number, '愛媛県喜多郡内子町臼杵');
ok($zip->set_number('7913521')->is_valid_number, '愛媛県喜多郡内子町本川');
ok($zip->set_number('7913522')->is_valid_number, '愛媛県喜多郡内子町中川');
ok($zip->set_number('7913523')->is_valid_number, '愛媛県喜多郡内子町上川');
ok($zip->set_number('7913524')->is_valid_number, '愛媛県喜多郡内子町小田深山');
ok($zip->set_number('7914321')->is_valid_number, '愛媛県松山市元怒和');
ok($zip->set_number('7914322')->is_valid_number, '愛媛県松山市上怒和');
ok($zip->set_number('7914323')->is_valid_number, '愛媛県松山市二神');
ok($zip->set_number('7914324')->is_valid_number, '愛媛県松山市津和地');
ok($zip->set_number('7914431')->is_valid_number, '愛媛県松山市睦月');
ok($zip->set_number('7914432')->is_valid_number, '愛媛県松山市野忽那');
ok($zip->set_number('7914501')->is_valid_number, '愛媛県松山市中島大浦');
ok($zip->set_number('7914502')->is_valid_number, '愛媛県松山市小浜');
ok($zip->set_number('7914503')->is_valid_number, '愛媛県松山市長師');
ok($zip->set_number('7914504')->is_valid_number, '愛媛県松山市宮野');
ok($zip->set_number('7914505')->is_valid_number, '愛媛県松山市神浦');
ok($zip->set_number('7914506')->is_valid_number, '愛媛県松山市宇和間');
ok($zip->set_number('7914507')->is_valid_number, '愛媛県松山市熊田');
ok($zip->set_number('7914508')->is_valid_number, '愛媛県松山市吉木');
ok($zip->set_number('7914509')->is_valid_number, '愛媛県松山市饒');
ok($zip->set_number('7914510')->is_valid_number, '愛媛県松山市畑里');
ok($zip->set_number('7914511')->is_valid_number, '愛媛県松山市中島粟井');
ok($zip->set_number('7918001')->is_valid_number, '愛媛県松山市平田町');
ok($zip->set_number('7918002')->is_valid_number, '愛媛県松山市谷町');
ok($zip->set_number('7918003')->is_valid_number, '愛媛県松山市志津川町');
ok($zip->set_number('7918004')->is_valid_number, '愛媛県松山市鴨川');
ok($zip->set_number('7918005')->is_valid_number, '愛媛県松山市東長戸');
ok($zip->set_number('7918006')->is_valid_number, '愛媛県松山市安城寺町');
ok($zip->set_number('7918007')->is_valid_number, '愛媛県松山市高木町');
ok($zip->set_number('7918011')->is_valid_number, '愛媛県松山市吉藤');
ok($zip->set_number('7918012')->is_valid_number, '愛媛県松山市姫原');
ok($zip->set_number('7918013')->is_valid_number, '愛媛県松山市山越(丁目)');
ok($zip->set_number('7918014')->is_valid_number, '愛媛県松山市山越町');
ok($zip->set_number('7918015')->is_valid_number, '愛媛県松山市中央');
ok($zip->set_number('7918016')->is_valid_number, '愛媛県松山市久万ノ台');
ok($zip->set_number('7918017')->is_valid_number, '愛媛県松山市西長戸町');
ok($zip->set_number('7918018')->is_valid_number, '愛媛県松山市問屋町');
ok($zip->set_number('7918019')->is_valid_number, '愛媛県松山市青葉台');
ok($zip->set_number('7918021')->is_valid_number, '愛媛県松山市六軒家町');
ok($zip->set_number('7918022')->is_valid_number, '愛媛県松山市美沢');
ok($zip->set_number('7918023')->is_valid_number, '愛媛県松山市朝美');
ok($zip->set_number('7918024')->is_valid_number, '愛媛県松山市朝日ケ丘');
ok($zip->set_number('7918025')->is_valid_number, '愛媛県松山市衣山');
ok($zip->set_number('7918026')->is_valid_number, '愛媛県松山市山西町');
ok($zip->set_number('7918027')->is_valid_number, '愛媛県松山市明神丘');
ok($zip->set_number('7918031')->is_valid_number, '愛媛県松山市北斎院町');
ok($zip->set_number('7918032')->is_valid_number, '愛媛県松山市南斎院町');
ok($zip->set_number('7918034')->is_valid_number, '愛媛県松山市富久町');
ok($zip->set_number('7918035')->is_valid_number, '愛媛県松山市久保田町');
ok($zip->set_number('7918036')->is_valid_number, '愛媛県松山市高岡町');
ok($zip->set_number('7918041')->is_valid_number, '愛媛県松山市北吉田町');
ok($zip->set_number('7918042')->is_valid_number, '愛媛県松山市南吉田町');
ok($zip->set_number('7918043')->is_valid_number, '愛媛県松山市東垣生町');
ok($zip->set_number('7918044')->is_valid_number, '愛媛県松山市西垣生町');
ok($zip->set_number('7918051')->is_valid_number, '愛媛県松山市梅田町');
ok($zip->set_number('7918052')->is_valid_number, '愛媛県松山市須賀町');
ok($zip->set_number('7918053')->is_valid_number, '愛媛県松山市若葉町');
ok($zip->set_number('7918054')->is_valid_number, '愛媛県松山市松江町');
ok($zip->set_number('7918055')->is_valid_number, '愛媛県松山市清住');
ok($zip->set_number('7918056')->is_valid_number, '愛媛県松山市別府町');
ok($zip->set_number('7918057')->is_valid_number, '愛媛県松山市大可賀');
ok($zip->set_number('7918058')->is_valid_number, '愛媛県松山市海岸通');
ok($zip->set_number('7918060')->is_valid_number, '愛媛県松山市三津ふ頭');
ok($zip->set_number('7918061')->is_valid_number, '愛媛県松山市三津');
ok($zip->set_number('7918062')->is_valid_number, '愛媛県松山市住吉');
ok($zip->set_number('7918063')->is_valid_number, '愛媛県松山市神田町');
ok($zip->set_number('7918064')->is_valid_number, '愛媛県松山市元町');
ok($zip->set_number('7918065')->is_valid_number, '愛媛県松山市三杉町');
ok($zip->set_number('7918066')->is_valid_number, '愛媛県松山市祓川');
ok($zip->set_number('7918067')->is_valid_number, '愛媛県松山市古三津');
ok($zip->set_number('7918067')->is_valid_number, '愛媛県松山市古三津町');
ok($zip->set_number('7918068')->is_valid_number, '愛媛県松山市みどりケ丘');
ok($zip->set_number('7918069')->is_valid_number, '愛媛県松山市吉野町');
ok($zip->set_number('7918071')->is_valid_number, '愛媛県松山市松ノ木');
ok($zip->set_number('7918072')->is_valid_number, '愛媛県松山市桜ケ丘');
ok($zip->set_number('7918073')->is_valid_number, '愛媛県松山市船ケ谷町');
ok($zip->set_number('7918074')->is_valid_number, '愛媛県松山市東山町');
ok($zip->set_number('7918075')->is_valid_number, '愛媛県松山市ひばりケ丘');
ok($zip->set_number('7918076')->is_valid_number, '愛媛県松山市会津町');
ok($zip->set_number('7918077')->is_valid_number, '愛媛県松山市内浜町');
ok($zip->set_number('7918078')->is_valid_number, '愛媛県松山市中須賀');
ok($zip->set_number('7918079')->is_valid_number, '愛媛県松山市高山町');
ok($zip->set_number('7918081')->is_valid_number, '愛媛県松山市高浜町');
ok($zip->set_number('7918082')->is_valid_number, '愛媛県松山市梅津寺町');
ok($zip->set_number('7918083')->is_valid_number, '愛媛県松山市新浜町');
ok($zip->set_number('7918084')->is_valid_number, '愛媛県松山市石風呂町');
ok($zip->set_number('7918085')->is_valid_number, '愛媛県松山市港山町');
ok($zip->set_number('7918086')->is_valid_number, '愛媛県松山市辰巳町');
ok($zip->set_number('7918087')->is_valid_number, '愛媛県松山市春美町');
ok($zip->set_number('7918091')->is_valid_number, '愛媛県松山市門田町');
ok($zip->set_number('7918092')->is_valid_number, '愛媛県松山市由良町');
ok($zip->set_number('7918093')->is_valid_number, '愛媛県松山市泊町');
ok($zip->set_number('7920000')->is_valid_number, '愛媛県新居浜市以下に掲載がない場合');
ok($zip->set_number('7920001')->is_valid_number, '愛媛県新居浜市惣開町');
ok($zip->set_number('7920002')->is_valid_number, '愛媛県新居浜市磯浦町');
ok($zip->set_number('7920003')->is_valid_number, '愛媛県新居浜市新田町');
ok($zip->set_number('7920004')->is_valid_number, '愛媛県新居浜市北新町');
ok($zip->set_number('7920005')->is_valid_number, '愛媛県新居浜市江口町');
ok($zip->set_number('7920006')->is_valid_number, '愛媛県新居浜市河内町');
ok($zip->set_number('7920007')->is_valid_number, '愛媛県新居浜市前田町');
ok($zip->set_number('7920008')->is_valid_number, '愛媛県新居浜市王子町');
ok($zip->set_number('7920009')->is_valid_number, '愛媛県新居浜市星越町');
ok($zip->set_number('7920011')->is_valid_number, '愛媛県新居浜市西原町');
ok($zip->set_number('7920012')->is_valid_number, '愛媛県新居浜市中須賀町');
ok($zip->set_number('7920013')->is_valid_number, '愛媛県新居浜市泉池町');
ok($zip->set_number('7920014')->is_valid_number, '愛媛県新居浜市西町');
ok($zip->set_number('7920015')->is_valid_number, '愛媛県新居浜市大江町');
ok($zip->set_number('7920016')->is_valid_number, '愛媛県新居浜市港町');
ok($zip->set_number('7920017')->is_valid_number, '愛媛県新居浜市若水町');
ok($zip->set_number('7920021')->is_valid_number, '愛媛県新居浜市泉宮町');
ok($zip->set_number('7920022')->is_valid_number, '愛媛県新居浜市徳常町');
ok($zip->set_number('7920023')->is_valid_number, '愛媛県新居浜市繁本町');
ok($zip->set_number('7920024')->is_valid_number, '愛媛県新居浜市宮西町');
ok($zip->set_number('7920025')->is_valid_number, '愛媛県新居浜市一宮町');
ok($zip->set_number('7920026')->is_valid_number, '愛媛県新居浜市久保田町');
ok($zip->set_number('7920031')->is_valid_number, '愛媛県新居浜市高木町');
ok($zip->set_number('7920032')->is_valid_number, '愛媛県新居浜市政枝町');
ok($zip->set_number('7920033')->is_valid_number, '愛媛県新居浜市横水町');
ok($zip->set_number('7920034')->is_valid_number, '愛媛県新居浜市滝の宮町');
ok($zip->set_number('7920035')->is_valid_number, '愛媛県新居浜市西の土居町');
ok($zip->set_number('7920041')->is_valid_number, '愛媛県新居浜市中村松木');
ok($zip->set_number('7920042')->is_valid_number, '愛媛県新居浜市本郷');
ok($zip->set_number('7920043')->is_valid_number, '愛媛県新居浜市土橋');
ok($zip->set_number('7920044')->is_valid_number, '愛媛県新居浜市中村');
ok($zip->set_number('7920045')->is_valid_number, '愛媛県新居浜市中萩町');
ok($zip->set_number('7920046')->is_valid_number, '愛媛県新居浜市上原');
ok($zip->set_number('7920047')->is_valid_number, '愛媛県新居浜市御蔵町');
ok($zip->set_number('7920050')->is_valid_number, '愛媛県新居浜市萩生');
ok($zip->set_number('7920060')->is_valid_number, '愛媛県新居浜市大生院');
ok($zip->set_number('7920071')->is_valid_number, '愛媛県新居浜市金子丙');
ok($zip->set_number('7920072')->is_valid_number, '愛媛県新居浜市新居浜乙');
ok($zip->set_number('7920080')->is_valid_number, '愛媛県今治市宮窪町四阪島');
ok($zip->set_number('7920801')->is_valid_number, '愛媛県新居浜市菊本町');
ok($zip->set_number('7920802')->is_valid_number, '愛媛県新居浜市新須賀町');
ok($zip->set_number('7920803')->is_valid_number, '愛媛県新居浜市平形町');
ok($zip->set_number('7920804')->is_valid_number, '愛媛県新居浜市田所町');
ok($zip->set_number('7920805')->is_valid_number, '愛媛県新居浜市八雲町');
ok($zip->set_number('7920811')->is_valid_number, '愛媛県新居浜市庄内町');
ok($zip->set_number('7920812')->is_valid_number, '愛媛県新居浜市坂井町');
ok($zip->set_number('7920813')->is_valid_number, '愛媛県新居浜市下泉町');
ok($zip->set_number('7920814')->is_valid_number, '愛媛県新居浜市城下町');
ok($zip->set_number('7920815')->is_valid_number, '愛媛県新居浜市岸の上町');
ok($zip->set_number('7920821')->is_valid_number, '愛媛県新居浜市瀬戸町');
ok($zip->set_number('7920822')->is_valid_number, '愛媛県新居浜市寿町');
ok($zip->set_number('7920823')->is_valid_number, '愛媛県新居浜市外山町');
ok($zip->set_number('7920824')->is_valid_number, '愛媛県新居浜市上泉町');
ok($zip->set_number('7920825')->is_valid_number, '愛媛県新居浜市星原町');
ok($zip->set_number('7920826')->is_valid_number, '愛媛県新居浜市喜光地町');
ok($zip->set_number('7920827')->is_valid_number, '愛媛県新居浜市西喜光地町');
ok($zip->set_number('7920828')->is_valid_number, '愛媛県新居浜市松原町');
ok($zip->set_number('7920829')->is_valid_number, '愛媛県新居浜市松木町');
ok($zip->set_number('7920831')->is_valid_number, '愛媛県新居浜市西連寺町');
ok($zip->set_number('7920832')->is_valid_number, '愛媛県新居浜市西泉町');
ok($zip->set_number('7920833')->is_valid_number, '愛媛県新居浜市宮原町');
ok($zip->set_number('7920834')->is_valid_number, '愛媛県新居浜市中西町');
ok($zip->set_number('7920835')->is_valid_number, '愛媛県新居浜市山根町');
ok($zip->set_number('7920836')->is_valid_number, '愛媛県新居浜市篠場町');
ok($zip->set_number('7920837')->is_valid_number, '愛媛県新居浜市山田町');
ok($zip->set_number('7920841')->is_valid_number, '愛媛県新居浜市中筋町');
ok($zip->set_number('7920842')->is_valid_number, '愛媛県新居浜市北内町');
ok($zip->set_number('7920843')->is_valid_number, '愛媛県新居浜市吉岡町');
ok($zip->set_number('7920844')->is_valid_number, '愛媛県新居浜市角野新田町');
ok($zip->set_number('7920845')->is_valid_number, '愛媛県新居浜市種子川町');
ok($zip->set_number('7920846')->is_valid_number, '愛媛県新居浜市立川町(立川山を含む)');
ok($zip->set_number('7920847')->is_valid_number, '愛媛県新居浜市大永山');
ok($zip->set_number('7920848')->is_valid_number, '愛媛県新居浜市種子川山');
ok($zip->set_number('7920851')->is_valid_number, '愛媛県新居浜市観音原町');
ok($zip->set_number('7920852')->is_valid_number, '愛媛県新居浜市東田');
ok($zip->set_number('7920853')->is_valid_number, '愛媛県新居浜市光明寺');
ok($zip->set_number('7920854')->is_valid_number, '愛媛県新居浜市国領');
ok($zip->set_number('7920855')->is_valid_number, '愛媛県新居浜市七宝台町');
ok($zip->set_number('7920856')->is_valid_number, '愛媛県新居浜市船木');
ok($zip->set_number('7920857')->is_valid_number, '愛媛県新居浜市角野');
ok($zip->set_number('7920861')->is_valid_number, '愛媛県新居浜市清水町');
ok($zip->set_number('7920862')->is_valid_number, '愛媛県新居浜市沢津町');
ok($zip->set_number('7920863')->is_valid_number, '愛媛県新居浜市南小松原町');
ok($zip->set_number('7920864')->is_valid_number, '愛媛県新居浜市東雲町');
ok($zip->set_number('7920865')->is_valid_number, '愛媛県新居浜市桜木町');
ok($zip->set_number('7920866')->is_valid_number, '愛媛県新居浜市宇高町');
ok($zip->set_number('7920867')->is_valid_number, '愛媛県新居浜市高津町');
ok($zip->set_number('7920868')->is_valid_number, '愛媛県新居浜市松の木町');
ok($zip->set_number('7920871')->is_valid_number, '愛媛県新居浜市八幡');
ok($zip->set_number('7920872')->is_valid_number, '愛媛県新居浜市垣生(丁目)');
ok($zip->set_number('7920873')->is_valid_number, '愛媛県新居浜市垣生(番地)');
ok($zip->set_number('7920874')->is_valid_number, '愛媛県新居浜市長岩町');
ok($zip->set_number('7920881')->is_valid_number, '愛媛県新居浜市松神子');
ok($zip->set_number('7920882')->is_valid_number, '愛媛県新居浜市又野');
ok($zip->set_number('7920883')->is_valid_number, '愛媛県新居浜市落神町');
ok($zip->set_number('7920884')->is_valid_number, '愛媛県新居浜市神郷');
ok($zip->set_number('7920885')->is_valid_number, '愛媛県新居浜市清住町');
ok($zip->set_number('7920886')->is_valid_number, '愛媛県新居浜市郷(丁目)');
ok($zip->set_number('7920887')->is_valid_number, '愛媛県新居浜市高田');
ok($zip->set_number('7920888')->is_valid_number, '愛媛県新居浜市田の上');
ok($zip->set_number('7920890')->is_valid_number, '愛媛県新居浜市楠崎');
ok($zip->set_number('7920891')->is_valid_number, '愛媛県新居浜市大島');
ok($zip->set_number('7920892')->is_valid_number, '愛媛県新居浜市黒島');
ok($zip->set_number('7920893')->is_valid_number, '愛媛県新居浜市多喜浜');
ok($zip->set_number('7920894')->is_valid_number, '愛媛県新居浜市郷(その他)');
ok($zip->set_number('7920895')->is_valid_number, '愛媛県新居浜市郷乙');
ok($zip->set_number('7920896')->is_valid_number, '愛媛県新居浜市阿島(その他)');
ok($zip->set_number('7920897')->is_valid_number, '愛媛県新居浜市阿島乙');
ok($zip->set_number('7920898')->is_valid_number, '愛媛県新居浜市荷内町');
ok($zip->set_number('7930000')->is_valid_number, '愛媛県西条市以下に掲載がない場合');
ok($zip->set_number('7930001')->is_valid_number, '愛媛県西条市玉津');
ok($zip->set_number('7930002')->is_valid_number, '愛媛県西条市天神');
ok($zip->set_number('7930003')->is_valid_number, '愛媛県西条市ひうち');
ok($zip->set_number('7930004')->is_valid_number, '愛媛県西条市船屋甲');
ok($zip->set_number('7930005')->is_valid_number, '愛媛県西条市船屋乙');
ok($zip->set_number('7930006')->is_valid_number, '愛媛県西条市下島山甲');
ok($zip->set_number('7930007')->is_valid_number, '愛媛県西条市下島山乙');
ok($zip->set_number('7930010')->is_valid_number, '愛媛県西条市飯岡');
ok($zip->set_number('7930016')->is_valid_number, '愛媛県西条市大浜');
ok($zip->set_number('7930017')->is_valid_number, '愛媛県西条市早川');
ok($zip->set_number('7930021')->is_valid_number, '愛媛県西条市神拝乙');
ok($zip->set_number('7930022')->is_valid_number, '愛媛県西条市本町');
ok($zip->set_number('7930023')->is_valid_number, '愛媛県西条市明屋敷');
ok($zip->set_number('7930024')->is_valid_number, '愛媛県西条市大師町');
ok($zip->set_number('7930025')->is_valid_number, '愛媛県西条市栄町');
ok($zip->set_number('7930026')->is_valid_number, '愛媛県西条市東町');
ok($zip->set_number('7930027')->is_valid_number, '愛媛県西条市朔日市');
ok($zip->set_number('7930028')->is_valid_number, '愛媛県西条市新田');
ok($zip->set_number('7930030')->is_valid_number, '愛媛県西条市大町');
ok($zip->set_number('7930034')->is_valid_number, '愛媛県西条市明神木');
ok($zip->set_number('7930035')->is_valid_number, '愛媛県西条市福武甲');
ok($zip->set_number('7930036')->is_valid_number, '愛媛県西条市福武乙');
ok($zip->set_number('7930037')->is_valid_number, '愛媛県西条市市之川');
ok($zip->set_number('7930038')->is_valid_number, '愛媛県西条市丸野');
ok($zip->set_number('7930039')->is_valid_number, '愛媛県西条市保野');
ok($zip->set_number('7930041')->is_valid_number, '愛媛県西条市神拝甲');
ok($zip->set_number('7930042')->is_valid_number, '愛媛県西条市喜多川');
ok($zip->set_number('7930043')->is_valid_number, '愛媛県西条市樋之口');
ok($zip->set_number('7930044')->is_valid_number, '愛媛県西条市古川甲');
ok($zip->set_number('7930045')->is_valid_number, '愛媛県西条市古川乙');
ok($zip->set_number('7930046')->is_valid_number, '愛媛県西条市港');
ok($zip->set_number('7930051')->is_valid_number, '愛媛県西条市安知生');
ok($zip->set_number('7930052')->is_valid_number, '愛媛県西条市中西');
ok($zip->set_number('7930053')->is_valid_number, '愛媛県西条市洲之内甲');
ok($zip->set_number('7930054')->is_valid_number, '愛媛県西条市中野甲');
ok($zip->set_number('7930055')->is_valid_number, '愛媛県西条市中野乙');
ok($zip->set_number('7930056')->is_valid_number, '愛媛県西条市中野丙');
ok($zip->set_number('7930057')->is_valid_number, '愛媛県西条市津越');
ok($zip->set_number('7930061')->is_valid_number, '愛媛県西条市禎瑞');
ok($zip->set_number('7930062')->is_valid_number, '愛媛県西条市西田甲');
ok($zip->set_number('7930063')->is_valid_number, '愛媛県西条市西泉甲');
ok($zip->set_number('7930064')->is_valid_number, '愛媛県西条市西泉乙');
ok($zip->set_number('7930065')->is_valid_number, '愛媛県西条市楢木');
ok($zip->set_number('7930066')->is_valid_number, '愛媛県西条市野々市');
ok($zip->set_number('7930067')->is_valid_number, '愛媛県西条市坂元甲');
ok($zip->set_number('7930071')->is_valid_number, '愛媛県西条市氷見甲');
ok($zip->set_number('7930072')->is_valid_number, '愛媛県西条市氷見乙');
ok($zip->set_number('7930073')->is_valid_number, '愛媛県西条市氷見丙');
ok($zip->set_number('7930074')->is_valid_number, '愛媛県西条市氷見丁');
ok($zip->set_number('7930075')->is_valid_number, '愛媛県西条市氷見戊');
ok($zip->set_number('7930101')->is_valid_number, '愛媛県西条市千町');
ok($zip->set_number('7930102')->is_valid_number, '愛媛県西条市藤之石');
ok($zip->set_number('7930103')->is_valid_number, '愛媛県西条市荒川');
ok($zip->set_number('7930211')->is_valid_number, '愛媛県西条市大保木');
ok($zip->set_number('7930212')->is_valid_number, '愛媛県西条市黒瀬');
ok($zip->set_number('7930213')->is_valid_number, '愛媛県西条市兎之山');
ok($zip->set_number('7930214')->is_valid_number, '愛媛県西条市中奥');
ok($zip->set_number('7930215')->is_valid_number, '愛媛県西条市西之川');
ok($zip->set_number('7930216')->is_valid_number, '愛媛県西条市東之川');
ok($zip->set_number('7940000')->is_valid_number, '愛媛県今治市以下に掲載がない場合');
ok($zip->set_number('7940001')->is_valid_number, '愛媛県今治市砂場町');
ok($zip->set_number('7940002')->is_valid_number, '愛媛県今治市大浜町');
ok($zip->set_number('7940003')->is_valid_number, '愛媛県今治市湊町');
ok($zip->set_number('7940004')->is_valid_number, '愛媛県今治市鐘場町');
ok($zip->set_number('7940005')->is_valid_number, '愛媛県今治市大新田町');
ok($zip->set_number('7940006')->is_valid_number, '愛媛県今治市石井町');
ok($zip->set_number('7940007')->is_valid_number, '愛媛県今治市近見町');
ok($zip->set_number('7940011')->is_valid_number, '愛媛県今治市北浜町');
ok($zip->set_number('7940012')->is_valid_number, '愛媛県今治市美保町');
ok($zip->set_number('7940013')->is_valid_number, '愛媛県今治市片原町');
ok($zip->set_number('7940014')->is_valid_number, '愛媛県今治市今治村(比岐島)');
ok($zip->set_number('7940015')->is_valid_number, '愛媛県今治市常盤町');
ok($zip->set_number('7940016')->is_valid_number, '愛媛県今治市中浜町');
ok($zip->set_number('7940017')->is_valid_number, '愛媛県今治市風早町');
ok($zip->set_number('7940018')->is_valid_number, '愛媛県今治市本町');
ok($zip->set_number('7940021')->is_valid_number, '愛媛県今治市米屋町');
ok($zip->set_number('7940022')->is_valid_number, '愛媛県今治市室屋町');
ok($zip->set_number('7940023')->is_valid_number, '愛媛県今治市栄町');
ok($zip->set_number('7940024')->is_valid_number, '愛媛県今治市共栄町');
ok($zip->set_number('7940025')->is_valid_number, '愛媛県今治市大正町');
ok($zip->set_number('7940026')->is_valid_number, '愛媛県今治市別宮町');
ok($zip->set_number('7940027')->is_valid_number, '愛媛県今治市南大門町');
ok($zip->set_number('7940028')->is_valid_number, '愛媛県今治市北宝来町');
ok($zip->set_number('7940031')->is_valid_number, '愛媛県今治市恵美須町');
ok($zip->set_number('7940032')->is_valid_number, '愛媛県今治市天保山町');
ok($zip->set_number('7940033')->is_valid_number, '愛媛県今治市東門町');
ok($zip->set_number('7940034')->is_valid_number, '愛媛県今治市美須賀町');
ok($zip->set_number('7940035')->is_valid_number, '愛媛県今治市枝堀町');
ok($zip->set_number('7940036')->is_valid_number, '愛媛県今治市通町');
ok($zip->set_number('7940037')->is_valid_number, '愛媛県今治市黄金町');
ok($zip->set_number('7940038')->is_valid_number, '愛媛県今治市末広町');
ok($zip->set_number('7940041')->is_valid_number, '愛媛県今治市松本町');
ok($zip->set_number('7940042')->is_valid_number, '愛媛県今治市旭町');
ok($zip->set_number('7940043')->is_valid_number, '愛媛県今治市南宝来町');
ok($zip->set_number('7940044')->is_valid_number, '愛媛県今治市蔵敷町');
ok($zip->set_number('7940051')->is_valid_number, '愛媛県今治市高地町');
ok($zip->set_number('7940052')->is_valid_number, '愛媛県今治市宮下町');
ok($zip->set_number('7940053')->is_valid_number, '愛媛県今治市山方町');
ok($zip->set_number('7940054')->is_valid_number, '愛媛県今治市北日吉町');
ok($zip->set_number('7940055')->is_valid_number, '愛媛県今治市中日吉町');
ok($zip->set_number('7940056')->is_valid_number, '愛媛県今治市南日吉町');
ok($zip->set_number('7940057')->is_valid_number, '愛媛県今治市泉川町');
ok($zip->set_number('7940058')->is_valid_number, '愛媛県今治市蒼社町');
ok($zip->set_number('7940059')->is_valid_number, '愛媛県今治市鯉池町');
ok($zip->set_number('7940061')->is_valid_number, '愛媛県今治市馬越二番耕地');
ok($zip->set_number('7940062')->is_valid_number, '愛媛県今治市馬越町');
ok($zip->set_number('7940063')->is_valid_number, '愛媛県今治市片山');
ok($zip->set_number('7940064')->is_valid_number, '愛媛県今治市小泉');
ok($zip->set_number('7940065')->is_valid_number, '愛媛県今治市別名');
ok($zip->set_number('7940066')->is_valid_number, '愛媛県今治市高橋');
ok($zip->set_number('7940067')->is_valid_number, '愛媛県今治市高橋ふれあいの丘');
ok($zip->set_number('7940068')->is_valid_number, '愛媛県今治市にぎわい広場');
ok($zip->set_number('7940069')->is_valid_number, '愛媛県今治市クリエイティブヒルズ');
ok($zip->set_number('7940071')->is_valid_number, '愛媛県今治市山路町');
ok($zip->set_number('7940072')->is_valid_number, '愛媛県今治市山路');
ok($zip->set_number('7940073')->is_valid_number, '愛媛県今治市矢田');
ok($zip->set_number('7940074')->is_valid_number, '愛媛県今治市神宮');
ok($zip->set_number('7940081')->is_valid_number, '愛媛県今治市阿方');
ok($zip->set_number('7940082')->is_valid_number, '愛媛県今治市野間');
ok($zip->set_number('7940083')->is_valid_number, '愛媛県今治市宅間');
ok($zip->set_number('7940084')->is_valid_number, '愛媛県今治市延喜');
ok($zip->set_number('7940085')->is_valid_number, '愛媛県今治市いこいの丘');
ok($zip->set_number('7940086')->is_valid_number, '愛媛県今治市しまなみの杜');
ok($zip->set_number('7940087')->is_valid_number, '愛媛県今治市しまなみヒルズ');
ok($zip->set_number('7940101')->is_valid_number, '愛媛県今治市玉川町三反地');
ok($zip->set_number('7940102')->is_valid_number, '愛媛県今治市玉川町大野');
ok($zip->set_number('7940103')->is_valid_number, '愛媛県今治市玉川町法界寺');
ok($zip->set_number('7940104')->is_valid_number, '愛媛県今治市玉川町摺木');
ok($zip->set_number('7940105')->is_valid_number, '愛媛県今治市玉川町與和木');
ok($zip->set_number('7940106')->is_valid_number, '愛媛県今治市玉川町鍋地');
ok($zip->set_number('7940107')->is_valid_number, '愛媛県今治市玉川町桂');
ok($zip->set_number('7940108')->is_valid_number, '愛媛県今治市玉川町御厩');
ok($zip->set_number('7940109')->is_valid_number, '愛媛県今治市玉川町長谷');
ok($zip->set_number('7940111')->is_valid_number, '愛媛県今治市玉川町中村');
ok($zip->set_number('7940112')->is_valid_number, '愛媛県今治市玉川町小鴨部');
ok($zip->set_number('7940113')->is_valid_number, '愛媛県今治市玉川町別所');
ok($zip->set_number('7940114')->is_valid_number, '愛媛県今治市玉川町八幡');
ok($zip->set_number('7940115')->is_valid_number, '愛媛県今治市玉川町高野');
ok($zip->set_number('7940116')->is_valid_number, '愛媛県今治市玉川町畑寺');
ok($zip->set_number('7940117')->is_valid_number, '愛媛県今治市玉川町鬼原');
ok($zip->set_number('7940121')->is_valid_number, '愛媛県今治市玉川町鈍川');
ok($zip->set_number('7940122')->is_valid_number, '愛媛県今治市玉川町木地');
ok($zip->set_number('7940123')->is_valid_number, '愛媛県今治市玉川町龍岡下');
ok($zip->set_number('7940124')->is_valid_number, '愛媛県今治市玉川町龍岡上');
ok($zip->set_number('7940125')->is_valid_number, '愛媛県今治市玉川町葛谷');
ok($zip->set_number('7940801')->is_valid_number, '愛媛県今治市東鳥生町');
ok($zip->set_number('7940802')->is_valid_number, '愛媛県今治市南鳥生町');
ok($zip->set_number('7940803')->is_valid_number, '愛媛県今治市北鳥生町');
ok($zip->set_number('7940804')->is_valid_number, '愛媛県今治市祇園町');
ok($zip->set_number('7940805')->is_valid_number, '愛媛県今治市広紹寺町');
ok($zip->set_number('7940811')->is_valid_number, '愛媛県今治市南高下町');
ok($zip->set_number('7940812')->is_valid_number, '愛媛県今治市北高下町');
ok($zip->set_number('7940813')->is_valid_number, '愛媛県今治市衣干町');
ok($zip->set_number('7940814')->is_valid_number, '愛媛県今治市横田町');
ok($zip->set_number('7940815')->is_valid_number, '愛媛県今治市土橋町');
ok($zip->set_number('7940821')->is_valid_number, '愛媛県今治市立花町');
ok($zip->set_number('7940822')->is_valid_number, '愛媛県今治市河南町');
ok($zip->set_number('7940823')->is_valid_number, '愛媛県今治市郷本町');
ok($zip->set_number('7940824')->is_valid_number, '愛媛県今治市石橋町');
ok($zip->set_number('7940825')->is_valid_number, '愛媛県今治市郷六ケ内町');
ok($zip->set_number('7940826')->is_valid_number, '愛媛県今治市郷新屋敷町');
ok($zip->set_number('7940827')->is_valid_number, '愛媛県今治市辻堂');
ok($zip->set_number('7940831')->is_valid_number, '愛媛県今治市八町東');
ok($zip->set_number('7940832')->is_valid_number, '愛媛県今治市八町西');
ok($zip->set_number('7940840')->is_valid_number, '愛媛県今治市中寺');
ok($zip->set_number('7940850')->is_valid_number, '愛媛県今治市新谷');
ok($zip->set_number('7940861')->is_valid_number, '愛媛県今治市五十嵐');
ok($zip->set_number('7940862')->is_valid_number, '愛媛県今治市四村');
ok($zip->set_number('7940863')->is_valid_number, '愛媛県今治市徳重');
ok($zip->set_number('7941101')->is_valid_number, '愛媛県今治市関前岡村');
ok($zip->set_number('7941102')->is_valid_number, '愛媛県今治市関前小大下');
ok($zip->set_number('7941103')->is_valid_number, '愛媛県今治市関前大下');
ok($zip->set_number('7941301')->is_valid_number, '愛媛県今治市大三島町肥海');
ok($zip->set_number('7941302')->is_valid_number, '愛媛県今治市大三島町大見');
ok($zip->set_number('7941303')->is_valid_number, '愛媛県今治市大三島町明日');
ok($zip->set_number('7941304')->is_valid_number, '愛媛県今治市大三島町宮浦');
ok($zip->set_number('7941305')->is_valid_number, '愛媛県今治市大三島町台');
ok($zip->set_number('7941306')->is_valid_number, '愛媛県今治市大三島町野々江');
ok($zip->set_number('7941307')->is_valid_number, '愛媛県今治市大三島町口総');
ok($zip->set_number('7941308')->is_valid_number, '愛媛県今治市大三島町浦戸');
ok($zip->set_number('7941309')->is_valid_number, '愛媛県今治市大三島町宗方');
ok($zip->set_number('7941401')->is_valid_number, '愛媛県今治市上浦町盛');
ok($zip->set_number('7941402')->is_valid_number, '愛媛県今治市上浦町井口');
ok($zip->set_number('7941403')->is_valid_number, '愛媛県今治市上浦町甘崎');
ok($zip->set_number('7941404')->is_valid_number, '愛媛県今治市上浦町瀬戸');
ok($zip->set_number('7942101')->is_valid_number, '愛媛県今治市吉海町田浦');
ok($zip->set_number('7942102')->is_valid_number, '愛媛県今治市吉海町泊');
ok($zip->set_number('7942103')->is_valid_number, '愛媛県今治市吉海町福田');
ok($zip->set_number('7942104')->is_valid_number, '愛媛県今治市吉海町仁江');
ok($zip->set_number('7942110')->is_valid_number, '愛媛県今治市吉海町八幡');
ok($zip->set_number('7942111')->is_valid_number, '愛媛県今治市吉海町幸新田');
ok($zip->set_number('7942112')->is_valid_number, '愛媛県今治市吉海町本庄');
ok($zip->set_number('7942113')->is_valid_number, '愛媛県今治市吉海町椋名');
ok($zip->set_number('7942114')->is_valid_number, '愛媛県今治市吉海町名');
ok($zip->set_number('7942115')->is_valid_number, '愛媛県今治市吉海町南浦');
ok($zip->set_number('7942116')->is_valid_number, '愛媛県今治市吉海町名駒');
ok($zip->set_number('7942117')->is_valid_number, '愛媛県今治市吉海町正味');
ok($zip->set_number('7942118')->is_valid_number, '愛媛県今治市吉海町臥間');
ok($zip->set_number('7942119')->is_valid_number, '愛媛県今治市吉海町津島');
ok($zip->set_number('7942201')->is_valid_number, '愛媛県今治市宮窪町早川');
ok($zip->set_number('7942202')->is_valid_number, '愛媛県今治市宮窪町余所国');
ok($zip->set_number('7942203')->is_valid_number, '愛媛県今治市宮窪町宮窪');
ok($zip->set_number('7942204')->is_valid_number, '愛媛県今治市宮窪町友浦');
ok($zip->set_number('7942301')->is_valid_number, '愛媛県今治市伯方町有津');
ok($zip->set_number('7942302')->is_valid_number, '愛媛県今治市伯方町叶浦');
ok($zip->set_number('7942303')->is_valid_number, '愛媛県今治市伯方町伊方');
ok($zip->set_number('7942304')->is_valid_number, '愛媛県今治市伯方町北浦');
ok($zip->set_number('7942305')->is_valid_number, '愛媛県今治市伯方町木浦');
ok($zip->set_number('7942410')->is_valid_number, '愛媛県越智郡上島町岩城');
ok($zip->set_number('7942500')->is_valid_number, '愛媛県越智郡上島町以下に掲載がない場合');
ok($zip->set_number('7942501')->is_valid_number, '愛媛県越智郡上島町弓削久司浦');
ok($zip->set_number('7942502')->is_valid_number, '愛媛県越智郡上島町弓削沢津');
ok($zip->set_number('7942503')->is_valid_number, '愛媛県越智郡上島町弓削上弓削');
ok($zip->set_number('7942503')->is_valid_number, '愛媛県越智郡上島町弓削百貫');
ok($zip->set_number('7942504')->is_valid_number, '愛媛県越智郡上島町弓削引野');
ok($zip->set_number('7942505')->is_valid_number, '愛媛県越智郡上島町弓削明神');
ok($zip->set_number('7942506')->is_valid_number, '愛媛県越智郡上島町弓削下弓削');
ok($zip->set_number('7942507')->is_valid_number, '愛媛県越智郡上島町弓削藤谷');
ok($zip->set_number('7942508')->is_valid_number, '愛媛県越智郡上島町弓削太田');
ok($zip->set_number('7942509')->is_valid_number, '愛媛県越智郡上島町弓削土生');
ok($zip->set_number('7942510')->is_valid_number, '愛媛県越智郡上島町弓削鎌田');
ok($zip->set_number('7942511')->is_valid_number, '愛媛県越智郡上島町弓削日比');
ok($zip->set_number('7942512')->is_valid_number, '愛媛県越智郡上島町弓削狩尾');
ok($zip->set_number('7942513')->is_valid_number, '愛媛県越智郡上島町弓削大谷');
ok($zip->set_number('7942520')->is_valid_number, '愛媛県越智郡上島町弓削佐島');
ok($zip->set_number('7942530')->is_valid_number, '愛媛県越智郡上島町弓削豊島');
ok($zip->set_number('7942540')->is_valid_number, '愛媛県越智郡上島町魚島一番耕地');
ok($zip->set_number('7942541')->is_valid_number, '愛媛県越智郡上島町魚島二番耕地');
ok($zip->set_number('7942542')->is_valid_number, '愛媛県越智郡上島町魚島三番耕地');
ok($zip->set_number('7942550')->is_valid_number, '愛媛県越智郡上島町生名');
ok($zip->set_number('7950000')->is_valid_number, '愛媛県大洲市以下に掲載がない場合');
ok($zip->set_number('7950001')->is_valid_number, '愛媛県大洲市北只');
ok($zip->set_number('7950002')->is_valid_number, '愛媛県大洲市松尾');
ok($zip->set_number('7950003')->is_valid_number, '愛媛県大洲市梅川');
ok($zip->set_number('7950004')->is_valid_number, '愛媛県大洲市長谷');
ok($zip->set_number('7950005')->is_valid_number, '愛媛県大洲市横野(久保)');
ok($zip->set_number('7950006')->is_valid_number, '愛媛県大洲市野佐来');
ok($zip->set_number('7950007')->is_valid_number, '愛媛県大洲市稲積');
ok($zip->set_number('7950008')->is_valid_number, '愛媛県大洲市黒木');
ok($zip->set_number('7950009')->is_valid_number, '愛媛県大洲市北裏');
ok($zip->set_number('7950011')->is_valid_number, '愛媛県大洲市柚木');
ok($zip->set_number('7950012')->is_valid_number, '愛媛県大洲市大洲');
ok($zip->set_number('7950013')->is_valid_number, '愛媛県大洲市西大洲');
ok($zip->set_number('7950021')->is_valid_number, '愛媛県大洲市平野町野田');
ok($zip->set_number('7950022')->is_valid_number, '愛媛県大洲市平野町平地(その他)');
ok($zip->set_number('7950023')->is_valid_number, '愛媛県大洲市平野町平地(横野)');
ok($zip->set_number('7950024')->is_valid_number, '愛媛県大洲市高山');
ok($zip->set_number('7950025')->is_valid_number, '愛媛県大洲市阿蔵');
ok($zip->set_number('7950031')->is_valid_number, '愛媛県大洲市多田');
ok($zip->set_number('7950032')->is_valid_number, '愛媛県大洲市上須戒');
ok($zip->set_number('7950041')->is_valid_number, '愛媛県大洲市八多喜町');
ok($zip->set_number('7950042')->is_valid_number, '愛媛県大洲市米津');
ok($zip->set_number('7950043')->is_valid_number, '愛媛県大洲市米津(甲)');
ok($zip->set_number('7950044')->is_valid_number, '愛媛県大洲市手成');
ok($zip->set_number('7950045')->is_valid_number, '愛媛県大洲市東宇山');
ok($zip->set_number('7950046')->is_valid_number, '愛媛県大洲市春賀');
ok($zip->set_number('7950051')->is_valid_number, '愛媛県大洲市五郎');
ok($zip->set_number('7950052')->is_valid_number, '愛媛県大洲市若宮');
ok($zip->set_number('7950053')->is_valid_number, '愛媛県大洲市常磐町');
ok($zip->set_number('7950054')->is_valid_number, '愛媛県大洲市中村');
ok($zip->set_number('7950061')->is_valid_number, '愛媛県大洲市徳森');
ok($zip->set_number('7950062')->is_valid_number, '愛媛県大洲市市木');
ok($zip->set_number('7950063')->is_valid_number, '愛媛県大洲市田口');
ok($zip->set_number('7950064')->is_valid_number, '愛媛県大洲市東大洲');
ok($zip->set_number('7950065')->is_valid_number, '愛媛県大洲市東若宮');
ok($zip->set_number('7950069')->is_valid_number, '愛媛県大洲市新谷');
ok($zip->set_number('7950070')->is_valid_number, '愛媛県大洲市新谷丙');
ok($zip->set_number('7950071')->is_valid_number, '愛媛県大洲市新谷乙');
ok($zip->set_number('7950072')->is_valid_number, '愛媛県大洲市新谷甲');
ok($zip->set_number('7950073')->is_valid_number, '愛媛県大洲市新谷町');
ok($zip->set_number('7950074')->is_valid_number, '愛媛県大洲市恋木');
ok($zip->set_number('7950075')->is_valid_number, '愛媛県大洲市喜多山');
ok($zip->set_number('7950076')->is_valid_number, '愛媛県大洲市藤縄');
ok($zip->set_number('7950077')->is_valid_number, '愛媛県大洲市柳沢');
ok($zip->set_number('7950078')->is_valid_number, '愛媛県大洲市田処');
ok($zip->set_number('7950081')->is_valid_number, '愛媛県大洲市菅田町菅田甲');
ok($zip->set_number('7950081')->is_valid_number, '愛媛県大洲市菅田町菅田丙');
ok($zip->set_number('7950082')->is_valid_number, '愛媛県大洲市菅田町菅田乙');
ok($zip->set_number('7950083')->is_valid_number, '愛媛県大洲市菅田町大竹');
ok($zip->set_number('7950084')->is_valid_number, '愛媛県大洲市菅田町宇津甲');
ok($zip->set_number('7950085')->is_valid_number, '愛媛県大洲市菅田町宇津乙');
ok($zip->set_number('7950086')->is_valid_number, '愛媛県大洲市成能');
ok($zip->set_number('7950087')->is_valid_number, '愛媛県大洲市森山');
ok($zip->set_number('7950088')->is_valid_number, '愛媛県大洲市宇和川');
ok($zip->set_number('7950089')->is_valid_number, '愛媛県大洲市蔵川');
ok($zip->set_number('7950301')->is_valid_number, '愛媛県喜多郡内子町五十崎');
ok($zip->set_number('7950302')->is_valid_number, '愛媛県喜多郡内子町大久喜');
ok($zip->set_number('7950303')->is_valid_number, '愛媛県喜多郡内子町平岡');
ok($zip->set_number('7950304')->is_valid_number, '愛媛県喜多郡内子町重松');
ok($zip->set_number('7950305')->is_valid_number, '愛媛県喜多郡内子町宿間');
ok($zip->set_number('7950306')->is_valid_number, '愛媛県喜多郡内子町福岡');
ok($zip->set_number('7950307')->is_valid_number, '愛媛県喜多郡内子町北表');
ok($zip->set_number('7950308')->is_valid_number, '愛媛県喜多郡内子町山鳥坂');
ok($zip->set_number('7950309')->is_valid_number, '愛媛県喜多郡内子町只海');
ok($zip->set_number('7960000')->is_valid_number, '愛媛県八幡浜市以下に掲載がない場合');
ok($zip->set_number('7960001')->is_valid_number, '愛媛県八幡浜市向灘');
ok($zip->set_number('7960002')->is_valid_number, '愛媛県八幡浜市大平(花園町)');
ok($zip->set_number('7960003')->is_valid_number, '愛媛県八幡浜市大平(その他)');
ok($zip->set_number('7960004')->is_valid_number, '愛媛県八幡浜市大平(津羽井)');
ok($zip->set_number('7960005')->is_valid_number, '愛媛県八幡浜市高野地');
ok($zip->set_number('7960010')->is_valid_number, '愛媛県八幡浜市松柏');
ok($zip->set_number('7960011')->is_valid_number, '愛媛県八幡浜市木多町');
ok($zip->set_number('7960012')->is_valid_number, '愛媛県八幡浜市南柏');
ok($zip->set_number('7960013')->is_valid_number, '愛媛県八幡浜市山越');
ok($zip->set_number('7960014')->is_valid_number, '愛媛県八幡浜市新和田町');
ok($zip->set_number('7960020')->is_valid_number, '愛媛県八幡浜市神宮');
ok($zip->set_number('7960021')->is_valid_number, '愛媛県八幡浜市桧谷');
ok($zip->set_number('7960022')->is_valid_number, '愛媛県八幡浜市駅前');
ok($zip->set_number('7960023')->is_valid_number, '愛媛県八幡浜市神宮前');
ok($zip->set_number('7960024')->is_valid_number, '愛媛県八幡浜市神宮通');
ok($zip->set_number('7960025')->is_valid_number, '愛媛県八幡浜市東矢野町');
ok($zip->set_number('7960026')->is_valid_number, '愛媛県八幡浜市矢野町(その他)');
ok($zip->set_number('7960027')->is_valid_number, '愛媛県八幡浜市松蔭町');
ok($zip->set_number('7960028')->is_valid_number, '愛媛県八幡浜市清水町');
ok($zip->set_number('7960029')->is_valid_number, '愛媛県八幡浜市花小路');
ok($zip->set_number('7960031')->is_valid_number, '愛媛県八幡浜市江戸岡');
ok($zip->set_number('7960032')->is_valid_number, '愛媛県八幡浜市東新川');
ok($zip->set_number('7960033')->is_valid_number, '愛媛県八幡浜市大正町');
ok($zip->set_number('7960034')->is_valid_number, '愛媛県八幡浜市浜田町');
ok($zip->set_number('7960035')->is_valid_number, '愛媛県八幡浜市須崎');
ok($zip->set_number('7960036')->is_valid_number, '愛媛県八幡浜市新川');
ok($zip->set_number('7960037')->is_valid_number, '愛媛県八幡浜市昭和通');
ok($zip->set_number('7960038')->is_valid_number, '愛媛県八幡浜市清水町花小路');
ok($zip->set_number('7960041')->is_valid_number, '愛媛県八幡浜市裁判所通');
ok($zip->set_number('7960042')->is_valid_number, '愛媛県八幡浜市喜多町');
ok($zip->set_number('7960043')->is_valid_number, '愛媛県八幡浜市東近江屋町');
ok($zip->set_number('7960044')->is_valid_number, '愛媛県八幡浜市西近江屋町');
ok($zip->set_number('7960045')->is_valid_number, '愛媛県八幡浜市西近江屋町浜通');
ok($zip->set_number('7960046')->is_valid_number, '愛媛県八幡浜市旧港');
ok($zip->set_number('7960047')->is_valid_number, '愛媛県八幡浜市白浜通');
ok($zip->set_number('7960048')->is_valid_number, '愛媛県八幡浜市北浜');
ok($zip->set_number('7960051')->is_valid_number, '愛媛県八幡浜市幸町');
ok($zip->set_number('7960052')->is_valid_number, '愛媛県八幡浜市松本町');
ok($zip->set_number('7960053')->is_valid_number, '愛媛県八幡浜市海望園');
ok($zip->set_number('7960054')->is_valid_number, '愛媛県八幡浜市琴平町');
ok($zip->set_number('7960055')->is_valid_number, '愛媛県八幡浜市大門');
ok($zip->set_number('7960056')->is_valid_number, '愛媛県八幡浜市愛宕');
ok($zip->set_number('7960057')->is_valid_number, '愛媛県八幡浜市愛宕山団地');
ok($zip->set_number('7960061')->is_valid_number, '愛媛県八幡浜市海老崎');
ok($zip->set_number('7960062')->is_valid_number, '愛媛県八幡浜市新栄町');
ok($zip->set_number('7960063')->is_valid_number, '愛媛県八幡浜市横町');
ok($zip->set_number('7960064')->is_valid_number, '愛媛県八幡浜市船場通');
ok($zip->set_number('7960065')->is_valid_number, '愛媛県八幡浜市片山町');
ok($zip->set_number('7960066')->is_valid_number, '愛媛県八幡浜市本町');
ok($zip->set_number('7960067')->is_valid_number, '愛媛県八幡浜市中央');
ok($zip->set_number('7960068')->is_valid_number, '愛媛県八幡浜市浜之町');
ok($zip->set_number('7960069')->is_valid_number, '愛媛県八幡浜市下道');
ok($zip->set_number('7960071')->is_valid_number, '愛媛県八幡浜市新町');
ok($zip->set_number('7960072')->is_valid_number, '愛媛県八幡浜市港町');
ok($zip->set_number('7960073')->is_valid_number, '愛媛県八幡浜市戎町');
ok($zip->set_number('7960074')->is_valid_number, '愛媛県八幡浜市新港');
ok($zip->set_number('7960075')->is_valid_number, '愛媛県八幡浜市仲之町');
ok($zip->set_number('7960076')->is_valid_number, '愛媛県八幡浜市千代田町');
ok($zip->set_number('7960077')->is_valid_number, '愛媛県八幡浜市旧役場前通');
ok($zip->set_number('7960079')->is_valid_number, '愛媛県八幡浜市新港戎町');
ok($zip->set_number('7960081')->is_valid_number, '愛媛県八幡浜市朝潮橋');
ok($zip->set_number('7960082')->is_valid_number, '愛媛県八幡浜市北大黒町');
ok($zip->set_number('7960083')->is_valid_number, '愛媛県八幡浜市大黒町');
ok($zip->set_number('7960084')->is_valid_number, '愛媛県八幡浜市南大黒町');
ok($zip->set_number('7960085')->is_valid_number, '愛媛県八幡浜市天神通');
ok($zip->set_number('7960086')->is_valid_number, '愛媛県八幡浜市旭町');
ok($zip->set_number('7960087')->is_valid_number, '愛媛県八幡浜市沖新田');
ok($zip->set_number('7960088')->is_valid_number, '愛媛県八幡浜市八幡浜市の次に番地がくる場合');
ok($zip->set_number('7960089')->is_valid_number, '愛媛県八幡浜市出島');
ok($zip->set_number('7960111')->is_valid_number, '愛媛県八幡浜市保内町喜木');
ok($zip->set_number('7960112')->is_valid_number, '愛媛県八幡浜市保内町須川');
ok($zip->set_number('7960170')->is_valid_number, '愛媛県八幡浜市日土町');
ok($zip->set_number('7960201')->is_valid_number, '愛媛県八幡浜市保内町川之石');
ok($zip->set_number('7960202')->is_valid_number, '愛媛県八幡浜市保内町宮内');
ok($zip->set_number('7960203')->is_valid_number, '愛媛県八幡浜市保内町磯崎');
ok($zip->set_number('7960204')->is_valid_number, '愛媛県八幡浜市保内町喜木津');
ok($zip->set_number('7960205')->is_valid_number, '愛媛県八幡浜市保内町広早');
ok($zip->set_number('7960300')->is_valid_number, '愛媛県西宇和郡伊方町以下に掲載がない場合');
ok($zip->set_number('7960301')->is_valid_number, '愛媛県西宇和郡伊方町湊浦');
ok($zip->set_number('7960302')->is_valid_number, '愛媛県西宇和郡伊方町小中浦');
ok($zip->set_number('7960303')->is_valid_number, '愛媛県西宇和郡伊方町亀浦');
ok($zip->set_number('7960304')->is_valid_number, '愛媛県西宇和郡伊方町伊方越');
ok($zip->set_number('7960305')->is_valid_number, '愛媛県西宇和郡伊方町河内');
ok($zip->set_number('7960306')->is_valid_number, '愛媛県西宇和郡伊方町仁田之浜');
ok($zip->set_number('7960307')->is_valid_number, '愛媛県西宇和郡伊方町中之浜');
ok($zip->set_number('7960308')->is_valid_number, '愛媛県西宇和郡伊方町大浜');
ok($zip->set_number('7960311')->is_valid_number, '愛媛県西宇和郡伊方町中浦');
ok($zip->set_number('7960312')->is_valid_number, '愛媛県西宇和郡伊方町川永田');
ok($zip->set_number('7960313')->is_valid_number, '愛媛県西宇和郡伊方町豊之浦');
ok($zip->set_number('7960421')->is_valid_number, '愛媛県西宇和郡伊方町九町');
ok($zip->set_number('7960422')->is_valid_number, '愛媛県西宇和郡伊方町二見');
ok($zip->set_number('7960501')->is_valid_number, '愛媛県西宇和郡伊方町足成');
ok($zip->set_number('7960502')->is_valid_number, '愛媛県西宇和郡伊方町三机');
ok($zip->set_number('7960503')->is_valid_number, '愛媛県西宇和郡伊方町大江');
ok($zip->set_number('7960504')->is_valid_number, '愛媛県西宇和郡伊方町志津');
ok($zip->set_number('7960505')->is_valid_number, '愛媛県西宇和郡伊方町小島');
ok($zip->set_number('7960506')->is_valid_number, '愛媛県西宇和郡伊方町塩成');
ok($zip->set_number('7960611')->is_valid_number, '愛媛県西宇和郡伊方町川之浜');
ok($zip->set_number('7960612')->is_valid_number, '愛媛県西宇和郡伊方町大久');
ok($zip->set_number('7960613')->is_valid_number, '愛媛県西宇和郡伊方町神崎');
ok($zip->set_number('7960614')->is_valid_number, '愛媛県西宇和郡伊方町田部');
ok($zip->set_number('7960615')->is_valid_number, '愛媛県西宇和郡伊方町高茂');
ok($zip->set_number('7960801')->is_valid_number, '愛媛県西宇和郡伊方町三崎');
ok($zip->set_number('7960802')->is_valid_number, '愛媛県西宇和郡伊方町高浦');
ok($zip->set_number('7960803')->is_valid_number, '愛媛県西宇和郡伊方町佐田');
ok($zip->set_number('7960804')->is_valid_number, '愛媛県西宇和郡伊方町大佐田');
ok($zip->set_number('7960805')->is_valid_number, '愛媛県西宇和郡伊方町井野浦');
ok($zip->set_number('7960811')->is_valid_number, '愛媛県西宇和郡伊方町松');
ok($zip->set_number('7960812')->is_valid_number, '愛媛県西宇和郡伊方町明神');
ok($zip->set_number('7960813')->is_valid_number, '愛媛県西宇和郡伊方町二名津');
ok($zip->set_number('7960814')->is_valid_number, '愛媛県西宇和郡伊方町平礒');
ok($zip->set_number('7960815')->is_valid_number, '愛媛県西宇和郡伊方町釜木');
ok($zip->set_number('7960816')->is_valid_number, '愛媛県西宇和郡伊方町名取');
ok($zip->set_number('7960821')->is_valid_number, '愛媛県西宇和郡伊方町与侈');
ok($zip->set_number('7960822')->is_valid_number, '愛媛県西宇和郡伊方町串');
ok($zip->set_number('7960823')->is_valid_number, '愛媛県西宇和郡伊方町正野');
ok($zip->set_number('7960901')->is_valid_number, '愛媛県西予市三瓶町周木');
ok($zip->set_number('7960902')->is_valid_number, '愛媛県西予市三瓶町長早');
ok($zip->set_number('7960903')->is_valid_number, '愛媛県西予市三瓶町二及');
ok($zip->set_number('7960904')->is_valid_number, '愛媛県西予市三瓶町垣生');
ok($zip->set_number('7960905')->is_valid_number, '愛媛県西予市三瓶町鴫山');
ok($zip->set_number('7960906')->is_valid_number, '愛媛県西予市三瓶町和泉');
ok($zip->set_number('7960907')->is_valid_number, '愛媛県西予市三瓶町朝立');
ok($zip->set_number('7960908')->is_valid_number, '愛媛県西予市三瓶町津布理');
ok($zip->set_number('7960909')->is_valid_number, '愛媛県西予市三瓶町安土');
ok($zip->set_number('7960910')->is_valid_number, '愛媛県西予市三瓶町有網代');
ok($zip->set_number('7960911')->is_valid_number, '愛媛県西予市三瓶町有太刀');
ok($zip->set_number('7960912')->is_valid_number, '愛媛県西予市三瓶町蔵貫浦');
ok($zip->set_number('7960913')->is_valid_number, '愛媛県西予市三瓶町蔵貫');
ok($zip->set_number('7960914')->is_valid_number, '愛媛県西予市三瓶町皆江');
ok($zip->set_number('7960915')->is_valid_number, '愛媛県西予市三瓶町下泊');
ok($zip->set_number('7968001')->is_valid_number, '愛媛県八幡浜市大谷口');
ok($zip->set_number('7968002')->is_valid_number, '愛媛県八幡浜市広瀬');
ok($zip->set_number('7968003')->is_valid_number, '愛媛県八幡浜市古町');
ok($zip->set_number('7968004')->is_valid_number, '愛媛県八幡浜市産業通');
ok($zip->set_number('7968005')->is_valid_number, '愛媛県八幡浜市矢野町(徳雲坊)');
ok($zip->set_number('7968006')->is_valid_number, '愛媛県八幡浜市八代(丁目)');
ok($zip->set_number('7968007')->is_valid_number, '愛媛県八幡浜市八代(番地)');
ok($zip->set_number('7968008')->is_valid_number, '愛媛県八幡浜市栗野浦');
ok($zip->set_number('7968010')->is_valid_number, '愛媛県八幡浜市五反田');
ok($zip->set_number('7968011')->is_valid_number, '愛媛県八幡浜市元城団地');
ok($zip->set_number('7968015')->is_valid_number, '愛媛県八幡浜市国木');
ok($zip->set_number('7968020')->is_valid_number, '愛媛県八幡浜市郷');
ok($zip->set_number('7968025')->is_valid_number, '愛媛県八幡浜市川之内');
ok($zip->set_number('7968030')->is_valid_number, '愛媛県八幡浜市中津川');
ok($zip->set_number('7968035')->is_valid_number, '愛媛県八幡浜市若山');
ok($zip->set_number('7968036')->is_valid_number, '愛媛県八幡浜市釜倉');
ok($zip->set_number('7968037')->is_valid_number, '愛媛県八幡浜市谷');
ok($zip->set_number('7968038')->is_valid_number, '愛媛県八幡浜市横平');
ok($zip->set_number('7968039')->is_valid_number, '愛媛県八幡浜市布喜川');
ok($zip->set_number('7968040')->is_valid_number, '愛媛県八幡浜市舌間');
ok($zip->set_number('7968041')->is_valid_number, '愛媛県八幡浜市合田');
ok($zip->set_number('7968050')->is_valid_number, '愛媛県八幡浜市川上町川名津');
ok($zip->set_number('7968051')->is_valid_number, '愛媛県八幡浜市川上町上泊');
ok($zip->set_number('7968052')->is_valid_number, '愛媛県八幡浜市川上町白石');
ok($zip->set_number('7968053')->is_valid_number, '愛媛県八幡浜市真網代');
ok($zip->set_number('7968054')->is_valid_number, '愛媛県八幡浜市穴井');
ok($zip->set_number('7968060')->is_valid_number, '愛媛県八幡浜市大島');
ok($zip->set_number('7970000')->is_valid_number, '愛媛県西予市以下に掲載がない場合');
ok($zip->set_number('7970001')->is_valid_number, '愛媛県西予市宇和町田野中');
ok($zip->set_number('7970002')->is_valid_number, '愛媛県西予市宇和町平野');
ok($zip->set_number('7970003')->is_valid_number, '愛媛県西予市宇和町窪');
ok($zip->set_number('7970004')->is_valid_number, '愛媛県西予市宇和町伊崎');
ok($zip->set_number('7970005')->is_valid_number, '愛媛県西予市宇和町常定寺');
ok($zip->set_number('7970006')->is_valid_number, '愛媛県西予市宇和町新城');
ok($zip->set_number('7970007')->is_valid_number, '愛媛県西予市宇和町明石');
ok($zip->set_number('7970008')->is_valid_number, '愛媛県西予市宇和町さくら');
ok($zip->set_number('7970010')->is_valid_number, '愛媛県西予市宇和町明間');
ok($zip->set_number('7970011')->is_valid_number, '愛媛県西予市宇和町下川');
ok($zip->set_number('7970012')->is_valid_number, '愛媛県西予市宇和町皆田');
ok($zip->set_number('7970013')->is_valid_number, '愛媛県西予市宇和町稲生');
ok($zip->set_number('7970014')->is_valid_number, '愛媛県西予市宇和町伊賀上');
ok($zip->set_number('7970015')->is_valid_number, '愛媛県西予市宇和町卯之町');
ok($zip->set_number('7970016')->is_valid_number, '愛媛県西予市宇和町神領');
ok($zip->set_number('7970017')->is_valid_number, '愛媛県西予市宇和町ひまわり');
ok($zip->set_number('7970018')->is_valid_number, '愛媛県西予市宇和町下松葉');
ok($zip->set_number('7970020')->is_valid_number, '愛媛県西予市宇和町久枝');
ok($zip->set_number('7970021')->is_valid_number, '愛媛県西予市宇和町野田');
ok($zip->set_number('7970022')->is_valid_number, '愛媛県西予市宇和町小野田');
ok($zip->set_number('7970023')->is_valid_number, '愛媛県西予市宇和町山田');
ok($zip->set_number('7970024')->is_valid_number, '愛媛県西予市宇和町西山田');
ok($zip->set_number('7970025')->is_valid_number, '愛媛県西予市宇和町郷内');
ok($zip->set_number('7970026')->is_valid_number, '愛媛県西予市宇和町岩木');
ok($zip->set_number('7970027')->is_valid_number, '愛媛県西予市宇和町小原');
ok($zip->set_number('7970028')->is_valid_number, '愛媛県西予市宇和町れんげ');
ok($zip->set_number('7970029')->is_valid_number, '愛媛県西予市宇和町永長');
ok($zip->set_number('7970030')->is_valid_number, '愛媛県西予市宇和町清沢');
ok($zip->set_number('7970031')->is_valid_number, '愛媛県西予市宇和町杢所');
ok($zip->set_number('7970032')->is_valid_number, '愛媛県西予市宇和町田苗真土');
ok($zip->set_number('7970033')->is_valid_number, '愛媛県西予市宇和町岡山');
ok($zip->set_number('7970034')->is_valid_number, '愛媛県西予市宇和町伊延');
ok($zip->set_number('7970035')->is_valid_number, '愛媛県西予市宇和町河内');
ok($zip->set_number('7970036')->is_valid_number, '愛媛県西予市宇和町久保');
ok($zip->set_number('7970037')->is_valid_number, '愛媛県西予市宇和町信里');
ok($zip->set_number('7970041')->is_valid_number, '愛媛県西予市宇和町東多田');
ok($zip->set_number('7970042')->is_valid_number, '愛媛県西予市宇和町瀬戸');
ok($zip->set_number('7970043')->is_valid_number, '愛媛県西予市宇和町大江');
ok($zip->set_number('7970044')->is_valid_number, '愛媛県西予市宇和町加茂');
ok($zip->set_number('7970045')->is_valid_number, '愛媛県西予市宇和町坂戸');
ok($zip->set_number('7970046')->is_valid_number, '愛媛県西予市宇和町上松葉');
ok($zip->set_number('7970111')->is_valid_number, '愛媛県西予市明浜町俵津');
ok($zip->set_number('7970112')->is_valid_number, '愛媛県西予市明浜町渡江');
ok($zip->set_number('7970113')->is_valid_number, '愛媛県西予市明浜町狩浜');
ok($zip->set_number('7970201')->is_valid_number, '愛媛県西予市明浜町高山');
ok($zip->set_number('7970202')->is_valid_number, '愛媛県西予市明浜町宮野浦');
ok($zip->set_number('7970203')->is_valid_number, '愛媛県西予市明浜町田之浜');
ok($zip->set_number('7971101')->is_valid_number, '愛媛県西予市野村町白髭');
ok($zip->set_number('7971102')->is_valid_number, '愛媛県西予市野村町松渓');
ok($zip->set_number('7971103')->is_valid_number, '愛媛県西予市野村町四郎谷');
ok($zip->set_number('7971104')->is_valid_number, '愛媛県西予市野村町河西');
ok($zip->set_number('7971105')->is_valid_number, '愛媛県西予市野村町長谷');
ok($zip->set_number('7971106')->is_valid_number, '愛媛県西予市野村町旭');
ok($zip->set_number('7971107')->is_valid_number, '愛媛県西予市野村町鳥鹿野');
ok($zip->set_number('7971211')->is_valid_number, '愛媛県西予市野村町阿下');
ok($zip->set_number('7971212')->is_valid_number, '愛媛県西予市野村町野村');
ok($zip->set_number('7971213')->is_valid_number, '愛媛県西予市野村町片川');
ok($zip->set_number('7971214')->is_valid_number, '愛媛県西予市野村町富野川');
ok($zip->set_number('7971215')->is_valid_number, '愛媛県西予市野村町高瀬');
ok($zip->set_number('7971216')->is_valid_number, '愛媛県西予市野村町蔵良');
ok($zip->set_number('7971217')->is_valid_number, '愛媛県西予市野村町平野');
ok($zip->set_number('7971321')->is_valid_number, '愛媛県西予市野村町予子林');
ok($zip->set_number('7971322')->is_valid_number, '愛媛県西予市野村町坂石');
ok($zip->set_number('7971323')->is_valid_number, '愛媛県西予市野村町釜川');
ok($zip->set_number('7971324')->is_valid_number, '愛媛県西予市野村町大西');
ok($zip->set_number('7971325')->is_valid_number, '愛媛県西予市野村町中通川');
ok($zip->set_number('7971326')->is_valid_number, '愛媛県西予市野村町鎌田');
ok($zip->set_number('7971327')->is_valid_number, '愛媛県西予市野村町栗木');
ok($zip->set_number('7971328')->is_valid_number, '愛媛県西予市野村町西');
ok($zip->set_number('7971431')->is_valid_number, '愛媛県西予市野村町舟戸');
ok($zip->set_number('7971432')->is_valid_number, '愛媛県西予市野村町惣川');
ok($zip->set_number('7971433')->is_valid_number, '愛媛県西予市野村町小松');
ok($zip->set_number('7971434')->is_valid_number, '愛媛県西予市野村町大野ケ原');
ok($zip->set_number('7971501')->is_valid_number, '愛媛県大洲市肱川町中居谷');
ok($zip->set_number('7971502')->is_valid_number, '愛媛県大洲市肱川町名荷谷');
ok($zip->set_number('7971503')->is_valid_number, '愛媛県大洲市肱川町宇和川');
ok($zip->set_number('7971504')->is_valid_number, '愛媛県大洲市肱川町山鳥坂');
ok($zip->set_number('7971505')->is_valid_number, '愛媛県大洲市肱川町予子林');
ok($zip->set_number('7971506')->is_valid_number, '愛媛県大洲市肱川町中津');
ok($zip->set_number('7971507')->is_valid_number, '愛媛県大洲市肱川町大谷');
ok($zip->set_number('7971508')->is_valid_number, '愛媛県大洲市肱川町西');
ok($zip->set_number('7971601')->is_valid_number, '愛媛県大洲市河辺町植松');
ok($zip->set_number('7971602')->is_valid_number, '愛媛県大洲市河辺町山鳥坂');
ok($zip->set_number('7971603')->is_valid_number, '愛媛県大洲市河辺町横山');
ok($zip->set_number('7971604')->is_valid_number, '愛媛県大洲市河辺町川崎');
ok($zip->set_number('7971605')->is_valid_number, '愛媛県大洲市河辺町河都');
ok($zip->set_number('7971606')->is_valid_number, '愛媛県大洲市河辺町三嶋');
ok($zip->set_number('7971607')->is_valid_number, '愛媛県大洲市河辺町川上');
ok($zip->set_number('7971608')->is_valid_number, '愛媛県大洲市河辺町北平');
ok($zip->set_number('7971701')->is_valid_number, '愛媛県西予市城川町土居');
ok($zip->set_number('7971702')->is_valid_number, '愛媛県西予市城川町古市');
ok($zip->set_number('7971703')->is_valid_number, '愛媛県西予市城川町窪野');
ok($zip->set_number('7971704')->is_valid_number, '愛媛県西予市城川町川津南');
ok($zip->set_number('7971705')->is_valid_number, '愛媛県西予市城川町高野子');
ok($zip->set_number('7971711')->is_valid_number, '愛媛県西予市城川町野井川');
ok($zip->set_number('7971712')->is_valid_number, '愛媛県西予市城川町遊子谷');
ok($zip->set_number('7971713')->is_valid_number, '愛媛県西予市城川町嘉喜尾');
ok($zip->set_number('7971714')->is_valid_number, '愛媛県西予市城川町男河内');
ok($zip->set_number('7971715')->is_valid_number, '愛媛県西予市城川町田穂');
ok($zip->set_number('7971716')->is_valid_number, '愛媛県西予市城川町魚成');
ok($zip->set_number('7971717')->is_valid_number, '愛媛県西予市城川町下相');
ok($zip->set_number('7980000')->is_valid_number, '愛媛県宇和島市以下に掲載がない場合');
ok($zip->set_number('7980001')->is_valid_number, '愛媛県宇和島市大浦(赤松)');
ok($zip->set_number('7980002')->is_valid_number, '愛媛県宇和島市大浦(その他)');
ok($zip->set_number('7980003')->is_valid_number, '愛媛県宇和島市住吉町');
ok($zip->set_number('7980004')->is_valid_number, '愛媛県宇和島市朝日町');
ok($zip->set_number('7980005')->is_valid_number, '愛媛県宇和島市築地町');
ok($zip->set_number('7980006')->is_valid_number, '愛媛県宇和島市弁天町');
ok($zip->set_number('7980007')->is_valid_number, '愛媛県宇和島市寿町');
ok($zip->set_number('7980010')->is_valid_number, '愛媛県宇和島市北新町');
ok($zip->set_number('7980010')->is_valid_number, '愛媛県宇和島市藤江');
ok($zip->set_number('7980011')->is_valid_number, '愛媛県宇和島市須賀通');
ok($zip->set_number('7980012')->is_valid_number, '愛媛県宇和島市和霊町');
ok($zip->set_number('7980013')->is_valid_number, '愛媛県宇和島市御幸町');
ok($zip->set_number('7980014')->is_valid_number, '愛媛県宇和島市和霊公園');
ok($zip->set_number('7980015')->is_valid_number, '愛媛県宇和島市和霊元町');
ok($zip->set_number('7980016')->is_valid_number, '愛媛県宇和島市和霊中町');
ok($zip->set_number('7980017')->is_valid_number, '愛媛県宇和島市和霊東町');
ok($zip->set_number('7980020')->is_valid_number, '愛媛県宇和島市高串');
ok($zip->set_number('7980021')->is_valid_number, '愛媛県宇和島市光満');
ok($zip->set_number('7980022')->is_valid_number, '愛媛県宇和島市伊吹町(その他)');
ok($zip->set_number('7980023')->is_valid_number, '愛媛県宇和島市伊吹町(北宇和島町)');
ok($zip->set_number('7980024')->is_valid_number, '愛媛県宇和島市伊吹町(北通)');
ok($zip->set_number('7980025')->is_valid_number, '愛媛県宇和島市伊吹町(東通)');
ok($zip->set_number('7980026')->is_valid_number, '愛媛県宇和島市泉町');
ok($zip->set_number('7980027')->is_valid_number, '愛媛県宇和島市柿原');
ok($zip->set_number('7980030')->is_valid_number, '愛媛県宇和島市曙町');
ok($zip->set_number('7980031')->is_valid_number, '愛媛県宇和島市栄町港');
ok($zip->set_number('7980032')->is_valid_number, '愛媛県宇和島市恵美須町');
ok($zip->set_number('7980033')->is_valid_number, '愛媛県宇和島市鶴島町');
ok($zip->set_number('7980034')->is_valid_number, '愛媛県宇和島市錦町');
ok($zip->set_number('7980035')->is_valid_number, '愛媛県宇和島市新町');
ok($zip->set_number('7980036')->is_valid_number, '愛媛県宇和島市天神町');
ok($zip->set_number('7980037')->is_valid_number, '愛媛県宇和島市丸穂町(丁目)');
ok($zip->set_number('7980038')->is_valid_number, '愛媛県宇和島市丸穂(番地)');
ok($zip->set_number('7980039')->is_valid_number, '愛媛県宇和島市大宮町');
ok($zip->set_number('7980040')->is_valid_number, '愛媛県宇和島市中央町');
ok($zip->set_number('7980041')->is_valid_number, '愛媛県宇和島市本町追手');
ok($zip->set_number('7980042')->is_valid_number, '愛媛県宇和島市愛宕町');
ok($zip->set_number('7980043')->is_valid_number, '愛媛県宇和島市宇和津町');
ok($zip->set_number('7980044')->is_valid_number, '愛媛県宇和島市野川(その他)');
ok($zip->set_number('7980045')->is_valid_number, '愛媛県宇和島市大超寺奥');
ok($zip->set_number('7980050')->is_valid_number, '愛媛県宇和島市堀端町');
ok($zip->set_number('7980051')->is_valid_number, '愛媛県宇和島市広小路');
ok($zip->set_number('7980052')->is_valid_number, '愛媛県宇和島市京町');
ok($zip->set_number('7980053')->is_valid_number, '愛媛県宇和島市賀古町');
ok($zip->set_number('7980054')->is_valid_number, '愛媛県宇和島市笹町');
ok($zip->set_number('7980060')->is_valid_number, '愛媛県宇和島市丸之内');
ok($zip->set_number('7980061')->is_valid_number, '愛媛県宇和島市御殿町');
ok($zip->set_number('7980062')->is_valid_number, '愛媛県宇和島市桜町');
ok($zip->set_number('7980063')->is_valid_number, '愛媛県宇和島市御徒町');
ok($zip->set_number('7980064')->is_valid_number, '愛媛県宇和島市佐伯町');
ok($zip->set_number('7980065')->is_valid_number, '愛媛県宇和島市天赦公園');
ok($zip->set_number('7980066')->is_valid_number, '愛媛県宇和島市文京町');
ok($zip->set_number('7980067')->is_valid_number, '愛媛県宇和島市桝形町');
ok($zip->set_number('7980068')->is_valid_number, '愛媛県宇和島市明倫町');
ok($zip->set_number('7980070')->is_valid_number, '愛媛県宇和島市神田川原');
ok($zip->set_number('7980071')->is_valid_number, '愛媛県宇和島市妙典寺前');
ok($zip->set_number('7980072')->is_valid_number, '愛媛県宇和島市元結掛');
ok($zip->set_number('7980073')->is_valid_number, '愛媛県宇和島市山際');
ok($zip->set_number('7980074')->is_valid_number, '愛媛県宇和島市並松');
ok($zip->set_number('7980075')->is_valid_number, '愛媛県宇和島市川内(その他)');
ok($zip->set_number('7980076')->is_valid_number, '愛媛県宇和島市川内(薬師谷)');
ok($zip->set_number('7980077')->is_valid_number, '愛媛県宇和島市保田');
ok($zip->set_number('7980078')->is_valid_number, '愛媛県宇和島市祝森');
ok($zip->set_number('7980080')->is_valid_number, '愛媛県宇和島市新田町');
ok($zip->set_number('7980081')->is_valid_number, '愛媛県宇和島市中沢町');
ok($zip->set_number('7980082')->is_valid_number, '愛媛県宇和島市長堀');
ok($zip->set_number('7980083')->is_valid_number, '愛媛県宇和島市夏目町');
ok($zip->set_number('7980084')->is_valid_number, '愛媛県宇和島市寄松');
ok($zip->set_number('7980085')->is_valid_number, '愛媛県宇和島市宮下');
ok($zip->set_number('7980086')->is_valid_number, '愛媛県宇和島市別当');
ok($zip->set_number('7980087')->is_valid_number, '愛媛県宇和島市坂下津');
ok($zip->set_number('7980088')->is_valid_number, '愛媛県宇和島市保手');
ok($zip->set_number('7980090')->is_valid_number, '愛媛県宇和島市白浜');
ok($zip->set_number('7980091')->is_valid_number, '愛媛県宇和島市石応');
ok($zip->set_number('7980092')->is_valid_number, '愛媛県宇和島市小浜');
ok($zip->set_number('7980093')->is_valid_number, '愛媛県宇和島市小池');
ok($zip->set_number('7980094')->is_valid_number, '愛媛県宇和島市蕨');
ok($zip->set_number('7980095')->is_valid_number, '愛媛県宇和島市平浦');
ok($zip->set_number('7980096')->is_valid_number, '愛媛県宇和島市本九島');
ok($zip->set_number('7980097')->is_valid_number, '愛媛県宇和島市百之浦');
ok($zip->set_number('7980098')->is_valid_number, '愛媛県宇和島市蛤');
ok($zip->set_number('7980099')->is_valid_number, '愛媛県宇和島市日振島');
ok($zip->set_number('7980101')->is_valid_number, '愛媛県宇和島市三浦東');
ok($zip->set_number('7980102')->is_valid_number, '愛媛県宇和島市三浦西');
ok($zip->set_number('7980103')->is_valid_number, '愛媛県宇和島市遊子');
ok($zip->set_number('7980104')->is_valid_number, '愛媛県宇和島市下波');
ok($zip->set_number('7980211')->is_valid_number, '愛媛県宇和島市蒋渕');
ok($zip->set_number('7980212')->is_valid_number, '愛媛県宇和島市戸島');
ok($zip->set_number('7981101')->is_valid_number, '愛媛県宇和島市三間町大藤');
ok($zip->set_number('7981102')->is_valid_number, '愛媛県宇和島市三間町則');
ok($zip->set_number('7981103')->is_valid_number, '愛媛県宇和島市三間町成家');
ok($zip->set_number('7981104')->is_valid_number, '愛媛県宇和島市三間町曽根');
ok($zip->set_number('7981105')->is_valid_number, '愛媛県宇和島市三間町是能');
ok($zip->set_number('7981111')->is_valid_number, '愛媛県宇和島市三間町北増穂');
ok($zip->set_number('7981112')->is_valid_number, '愛媛県宇和島市三間町宮野下');
ok($zip->set_number('7981113')->is_valid_number, '愛媛県宇和島市三間町迫目');
ok($zip->set_number('7981114')->is_valid_number, '愛媛県宇和島市三間町務田');
ok($zip->set_number('7981115')->is_valid_number, '愛媛県宇和島市三間町戸雁');
ok($zip->set_number('7981116')->is_valid_number, '愛媛県宇和島市三間町黒井地');
ok($zip->set_number('7981121')->is_valid_number, '愛媛県宇和島市三間町川之内');
ok($zip->set_number('7981122')->is_valid_number, '愛媛県宇和島市三間町小沢川');
ok($zip->set_number('7981123')->is_valid_number, '愛媛県宇和島市三間町元宗');
ok($zip->set_number('7981124')->is_valid_number, '愛媛県宇和島市三間町増田');
ok($zip->set_number('7981125')->is_valid_number, '愛媛県宇和島市三間町土居中');
ok($zip->set_number('7981131')->is_valid_number, '愛媛県宇和島市三間町田川');
ok($zip->set_number('7981132')->is_valid_number, '愛媛県宇和島市三間町波岡');
ok($zip->set_number('7981133')->is_valid_number, '愛媛県宇和島市三間町中野中');
ok($zip->set_number('7981134')->is_valid_number, '愛媛県宇和島市三間町金銅');
ok($zip->set_number('7981135')->is_valid_number, '愛媛県宇和島市三間町古藤田');
ok($zip->set_number('7981136')->is_valid_number, '愛媛県宇和島市三間町大内');
ok($zip->set_number('7981137')->is_valid_number, '愛媛県宇和島市三間町兼近');
ok($zip->set_number('7981138')->is_valid_number, '愛媛県宇和島市三間町土居垣内');
ok($zip->set_number('7981139')->is_valid_number, '愛媛県宇和島市三間町是延');
ok($zip->set_number('7981141')->is_valid_number, '愛媛県宇和島市三間町音地');
ok($zip->set_number('7981142')->is_valid_number, '愛媛県宇和島市三間町三間中間');
ok($zip->set_number('7981143')->is_valid_number, '愛媛県宇和島市三間町黒川');
ok($zip->set_number('7981300')->is_valid_number, '愛媛県北宇和郡鬼北町以下に掲載がない場合');
ok($zip->set_number('7981301')->is_valid_number, '愛媛県北宇和郡鬼北町大宿');
ok($zip->set_number('7981302')->is_valid_number, '愛媛県北宇和郡鬼北町下大野');
ok($zip->set_number('7981303')->is_valid_number, '愛媛県北宇和郡鬼北町広見');
ok($zip->set_number('7981311')->is_valid_number, '愛媛県北宇和郡鬼北町小松');
ok($zip->set_number('7981312')->is_valid_number, '愛媛県北宇和郡鬼北町川上');
ok($zip->set_number('7981313')->is_valid_number, '愛媛県北宇和郡鬼北町延川');
ok($zip->set_number('7981314')->is_valid_number, '愛媛県北宇和郡鬼北町久保');
ok($zip->set_number('7981321')->is_valid_number, '愛媛県北宇和郡鬼北町小倉');
ok($zip->set_number('7981322')->is_valid_number, '愛媛県北宇和郡鬼北町上川');
ok($zip->set_number('7981323')->is_valid_number, '愛媛県北宇和郡鬼北町岩谷');
ok($zip->set_number('7981324')->is_valid_number, '愛媛県北宇和郡鬼北町小西野々');
ok($zip->set_number('7981331')->is_valid_number, '愛媛県北宇和郡鬼北町興野々');
ok($zip->set_number('7981332')->is_valid_number, '愛媛県北宇和郡鬼北町出目');
ok($zip->set_number('7981333')->is_valid_number, '愛媛県北宇和郡鬼北町永野市');
ok($zip->set_number('7981341')->is_valid_number, '愛媛県北宇和郡鬼北町近永(旭町)');
ok($zip->set_number('7981342')->is_valid_number, '愛媛県北宇和郡鬼北町近永(栄町)');
ok($zip->set_number('7981343')->is_valid_number, '愛媛県北宇和郡鬼北町近永(新町)');
ok($zip->set_number('7981344')->is_valid_number, '愛媛県北宇和郡鬼北町近永(本町)');
ok($zip->set_number('7981345')->is_valid_number, '愛媛県北宇和郡鬼北町近永(南町)');
ok($zip->set_number('7981351')->is_valid_number, '愛媛県北宇和郡鬼北町奈良(その他)');
ok($zip->set_number('7981352')->is_valid_number, '愛媛県北宇和郡鬼北町奈良(成川)');
ok($zip->set_number('7981353')->is_valid_number, '愛媛県北宇和郡鬼北町奈良(水分)');
ok($zip->set_number('7981354')->is_valid_number, '愛媛県北宇和郡鬼北町北川');
ok($zip->set_number('7981355')->is_valid_number, '愛媛県北宇和郡鬼北町芝');
ok($zip->set_number('7981356')->is_valid_number, '愛媛県北宇和郡鬼北町中野川');
ok($zip->set_number('7981361')->is_valid_number, '愛媛県北宇和郡鬼北町国遠');
ok($zip->set_number('7981362')->is_valid_number, '愛媛県北宇和郡鬼北町清延');
ok($zip->set_number('7981363')->is_valid_number, '愛媛県北宇和郡鬼北町内深田');
ok($zip->set_number('7981364')->is_valid_number, '愛媛県北宇和郡鬼北町吉波');
ok($zip->set_number('7981365')->is_valid_number, '愛媛県北宇和郡鬼北町西仲');
ok($zip->set_number('7981366')->is_valid_number, '愛媛県北宇和郡鬼北町東仲');
ok($zip->set_number('7981367')->is_valid_number, '愛媛県北宇和郡鬼北町沢松');
ok($zip->set_number('7981371')->is_valid_number, '愛媛県北宇和郡鬼北町生田');
ok($zip->set_number('7981372')->is_valid_number, '愛媛県北宇和郡鬼北町西野々');
ok($zip->set_number('7981373')->is_valid_number, '愛媛県北宇和郡鬼北町清水');
ok($zip->set_number('7981374')->is_valid_number, '愛媛県北宇和郡鬼北町成藤');
ok($zip->set_number('7981375')->is_valid_number, '愛媛県北宇和郡鬼北町畔屋');
ok($zip->set_number('7981501')->is_valid_number, '愛媛県北宇和郡鬼北町上鍵山');
ok($zip->set_number('7981502')->is_valid_number, '愛媛県北宇和郡鬼北町下鍵山');
ok($zip->set_number('7981503')->is_valid_number, '愛媛県北宇和郡鬼北町上大野');
ok($zip->set_number('7981504')->is_valid_number, '愛媛県北宇和郡鬼北町日向谷');
ok($zip->set_number('7981505')->is_valid_number, '愛媛県北宇和郡鬼北町父野川上');
ok($zip->set_number('7981506')->is_valid_number, '愛媛県北宇和郡鬼北町父野川中');
ok($zip->set_number('7981507')->is_valid_number, '愛媛県北宇和郡鬼北町父野川下');
ok($zip->set_number('7982100')->is_valid_number, '愛媛県北宇和郡松野町以下に掲載がない場合');
ok($zip->set_number('7982101')->is_valid_number, '愛媛県北宇和郡松野町松丸');
ok($zip->set_number('7982102')->is_valid_number, '愛媛県北宇和郡松野町延野々');
ok($zip->set_number('7982103')->is_valid_number, '愛媛県北宇和郡松野町豊岡');
ok($zip->set_number('7982104')->is_valid_number, '愛媛県北宇和郡松野町富岡');
ok($zip->set_number('7982105')->is_valid_number, '愛媛県北宇和郡松野町上家地');
ok($zip->set_number('7982106')->is_valid_number, '愛媛県北宇和郡松野町目黒');
ok($zip->set_number('7982111')->is_valid_number, '愛媛県北宇和郡松野町吉野');
ok($zip->set_number('7982112')->is_valid_number, '愛媛県北宇和郡松野町蕨生');
ok($zip->set_number('7982113')->is_valid_number, '愛媛県北宇和郡松野町奥野川');
ok($zip->set_number('7982146')->is_valid_number, '愛媛県宇和島市野川(滑床)');
ok($zip->set_number('7983271')->is_valid_number, '愛媛県宇和島市津島町御内');
ok($zip->set_number('7983272')->is_valid_number, '愛媛県宇和島市津島町槇川');
ok($zip->set_number('7983301')->is_valid_number, '愛媛県宇和島市津島町岩松');
ok($zip->set_number('7983302')->is_valid_number, '愛媛県宇和島市津島町高田');
ok($zip->set_number('7983303')->is_valid_number, '愛媛県宇和島市津島町近家');
ok($zip->set_number('7983311')->is_valid_number, '愛媛県宇和島市津島町岩渕');
ok($zip->set_number('7983312')->is_valid_number, '愛媛県宇和島市津島町山財');
ok($zip->set_number('7983313')->is_valid_number, '愛媛県宇和島市津島町増穂');
ok($zip->set_number('7983321')->is_valid_number, '愛媛県宇和島市津島町下畑地(乙を除く)');
ok($zip->set_number('7983322')->is_valid_number, '愛媛県宇和島市津島町下畑地乙(上槇)');
ok($zip->set_number('7983323')->is_valid_number, '愛媛県宇和島市津島町上畑地');
ok($zip->set_number('7983331')->is_valid_number, '愛媛県宇和島市津島町後');
ok($zip->set_number('7983332')->is_valid_number, '愛媛県宇和島市津島町須下');
ok($zip->set_number('7983333')->is_valid_number, '愛媛県宇和島市津島町成');
ok($zip->set_number('7983334')->is_valid_number, '愛媛県宇和島市津島町漁家');
ok($zip->set_number('7983335')->is_valid_number, '愛媛県宇和島市津島町平井');
ok($zip->set_number('7983336')->is_valid_number, '愛媛県宇和島市津島町曲烏');
ok($zip->set_number('7983337')->is_valid_number, '愛媛県宇和島市津島町大浦');
ok($zip->set_number('7983338')->is_valid_number, '愛媛県宇和島市津島町柿之浦');
ok($zip->set_number('7983341')->is_valid_number, '愛媛県宇和島市津島町塩定');
ok($zip->set_number('7983342')->is_valid_number, '愛媛県宇和島市津島町浦知');
ok($zip->set_number('7983343')->is_valid_number, '愛媛県宇和島市津島町針木');
ok($zip->set_number('7983344')->is_valid_number, '愛媛県宇和島市津島町嵐');
ok($zip->set_number('7983345')->is_valid_number, '愛媛県宇和島市津島町横浦');
ok($zip->set_number('7983346')->is_valid_number, '愛媛県宇和島市津島町鼡鳴');
ok($zip->set_number('7983351')->is_valid_number, '愛媛県宇和島市津島町弓立');
ok($zip->set_number('7983352')->is_valid_number, '愛媛県宇和島市津島町坪井');
ok($zip->set_number('7983353')->is_valid_number, '愛媛県宇和島市津島町泥目水');
ok($zip->set_number('7983354')->is_valid_number, '愛媛県宇和島市津島町田颪');
ok($zip->set_number('7983355')->is_valid_number, '愛媛県宇和島市津島町脇');
ok($zip->set_number('7983356')->is_valid_number, '愛媛県宇和島市津島町曽根');
ok($zip->set_number('7983357')->is_valid_number, '愛媛県宇和島市津島町田之浜');
ok($zip->set_number('7983358')->is_valid_number, '愛媛県宇和島市津島町竹ケ島');
ok($zip->set_number('7983361')->is_valid_number, '愛媛県宇和島市津島町北灘甲');
ok($zip->set_number('7983362')->is_valid_number, '愛媛県宇和島市津島町北灘乙');
ok($zip->set_number('7983363')->is_valid_number, '愛媛県宇和島市津島町北灘丙');
ok($zip->set_number('7983364')->is_valid_number, '愛媛県宇和島市津島町北灘丁(大日提、小日提)');
ok($zip->set_number('7983701')->is_valid_number, '愛媛県南宇和郡愛南町柏');
ok($zip->set_number('7983702')->is_valid_number, '愛媛県南宇和郡愛南町柏崎');
ok($zip->set_number('7983703')->is_valid_number, '愛媛県南宇和郡愛南町須ノ川');
ok($zip->set_number('7983704')->is_valid_number, '愛媛県南宇和郡愛南町平碆');
ok($zip->set_number('7983705')->is_valid_number, '愛媛県南宇和郡愛南町家串');
ok($zip->set_number('7983706')->is_valid_number, '愛媛県南宇和郡愛南町油袋');
ok($zip->set_number('7983707')->is_valid_number, '愛媛県南宇和郡愛南町魚神山');
ok($zip->set_number('7983708')->is_valid_number, '愛媛県南宇和郡愛南町網代');
ok($zip->set_number('7984100')->is_valid_number, '愛媛県南宇和郡愛南町以下に掲載がない場合');
ok($zip->set_number('7984101')->is_valid_number, '愛媛県南宇和郡愛南町御荘菊川');
ok($zip->set_number('7984102')->is_valid_number, '愛媛県南宇和郡愛南町御荘平山');
ok($zip->set_number('7984103')->is_valid_number, '愛媛県南宇和郡愛南町御荘長洲');
ok($zip->set_number('7984104')->is_valid_number, '愛媛県南宇和郡愛南町御荘和口');
ok($zip->set_number('7984105')->is_valid_number, '愛媛県南宇和郡愛南町御荘長月');
ok($zip->set_number('7984110')->is_valid_number, '愛媛県南宇和郡愛南町御荘平城');
ok($zip->set_number('7984121')->is_valid_number, '愛媛県南宇和郡愛南町御荘深泥');
ok($zip->set_number('7984122')->is_valid_number, '愛媛県南宇和郡愛南町防城成川');
ok($zip->set_number('7984123')->is_valid_number, '愛媛県南宇和郡愛南町赤水');
ok($zip->set_number('7984124')->is_valid_number, '愛媛県南宇和郡愛南町高畑');
ok($zip->set_number('7984125')->is_valid_number, '愛媛県南宇和郡愛南町中浦');
ok($zip->set_number('7984126')->is_valid_number, '愛媛県南宇和郡愛南町猿鳴');
ok($zip->set_number('7984131')->is_valid_number, '愛媛県南宇和郡愛南町城辺甲');
ok($zip->set_number('7984132')->is_valid_number, '愛媛県南宇和郡愛南町城辺乙');
ok($zip->set_number('7984133')->is_valid_number, '愛媛県南宇和郡愛南町緑乙');
ok($zip->set_number('7984134')->is_valid_number, '愛媛県南宇和郡愛南町緑甲');
ok($zip->set_number('7984135')->is_valid_number, '愛媛県南宇和郡愛南町緑丙');
ok($zip->set_number('7984136')->is_valid_number, '愛媛県南宇和郡愛南町僧都');
ok($zip->set_number('7984201')->is_valid_number, '愛媛県南宇和郡愛南町越田');
ok($zip->set_number('7984202')->is_valid_number, '愛媛県南宇和郡愛南町弓立');
ok($zip->set_number('7984203')->is_valid_number, '愛媛県南宇和郡愛南町小浦');
ok($zip->set_number('7984204')->is_valid_number, '愛媛県南宇和郡愛南町樫月');
ok($zip->set_number('7984205')->is_valid_number, '愛媛県南宇和郡愛南町船越');
ok($zip->set_number('7984206')->is_valid_number, '愛媛県南宇和郡愛南町内泊');
ok($zip->set_number('7984207')->is_valid_number, '愛媛県南宇和郡愛南町中泊');
ok($zip->set_number('7984208')->is_valid_number, '愛媛県南宇和郡愛南町外泊');
ok($zip->set_number('7984209')->is_valid_number, '愛媛県南宇和郡愛南町鹿島');
ok($zip->set_number('7984211')->is_valid_number, '愛媛県南宇和郡愛南町久家');
ok($zip->set_number('7984212')->is_valid_number, '愛媛県南宇和郡愛南町下久家');
ok($zip->set_number('7984213')->is_valid_number, '愛媛県南宇和郡愛南町樽見');
ok($zip->set_number('7984214')->is_valid_number, '愛媛県南宇和郡愛南町大成川');
ok($zip->set_number('7984215')->is_valid_number, '愛媛県南宇和郡愛南町小成川');
ok($zip->set_number('7984216')->is_valid_number, '愛媛県南宇和郡愛南町福浦');
ok($zip->set_number('7984217')->is_valid_number, '愛媛県南宇和郡愛南町麦ケ浦');
ok($zip->set_number('7984218')->is_valid_number, '愛媛県南宇和郡愛南町武者泊');
ok($zip->set_number('7984219')->is_valid_number, '愛媛県南宇和郡愛南町高茂');
ok($zip->set_number('7984341')->is_valid_number, '愛媛県南宇和郡愛南町蓮乗寺');
ok($zip->set_number('7984342')->is_valid_number, '愛媛県南宇和郡愛南町深浦');
ok($zip->set_number('7984343')->is_valid_number, '愛媛県南宇和郡愛南町垣内');
ok($zip->set_number('7984344')->is_valid_number, '愛媛県南宇和郡愛南町岩水');
ok($zip->set_number('7984345')->is_valid_number, '愛媛県南宇和郡愛南町敦盛');
ok($zip->set_number('7984346')->is_valid_number, '愛媛県南宇和郡愛南町柿ノ浦');
ok($zip->set_number('7984347')->is_valid_number, '愛媛県南宇和郡愛南町大浜');
ok($zip->set_number('7984348')->is_valid_number, '愛媛県南宇和郡愛南町中玉');
ok($zip->set_number('7984349')->is_valid_number, '愛媛県南宇和郡愛南町脇本');
ok($zip->set_number('7984351')->is_valid_number, '愛媛県南宇和郡愛南町鯆越');
ok($zip->set_number('7984352')->is_valid_number, '愛媛県南宇和郡愛南町古月');
ok($zip->set_number('7984353')->is_valid_number, '愛媛県南宇和郡愛南町久良');
ok($zip->set_number('7984401')->is_valid_number, '愛媛県南宇和郡愛南町正木');
ok($zip->set_number('7984402')->is_valid_number, '愛媛県南宇和郡愛南町増田');
ok($zip->set_number('7984403')->is_valid_number, '愛媛県南宇和郡愛南町小山');
ok($zip->set_number('7984404')->is_valid_number, '愛媛県南宇和郡愛南町中川');
ok($zip->set_number('7984405')->is_valid_number, '愛媛県南宇和郡愛南町満倉');
ok($zip->set_number('7984406')->is_valid_number, '愛媛県南宇和郡愛南町広見');
ok($zip->set_number('7984407')->is_valid_number, '愛媛県南宇和郡愛南町上大道');
ok($zip->set_number('7984408')->is_valid_number, '愛媛県南宇和郡愛南町一本松');
ok($zip->set_number('7990101')->is_valid_number, '愛媛県四国中央市川之江町');
ok($zip->set_number('7990102')->is_valid_number, '愛媛県四国中央市川之江町長須');
ok($zip->set_number('7990103')->is_valid_number, '愛媛県四国中央市川之江町余木');
ok($zip->set_number('7990111')->is_valid_number, '愛媛県四国中央市金生町下分');
ok($zip->set_number('7990112')->is_valid_number, '愛媛県四国中央市金生町山田井');
ok($zip->set_number('7990113')->is_valid_number, '愛媛県四国中央市妻鳥町');
ok($zip->set_number('7990121')->is_valid_number, '愛媛県四国中央市上分町');
ok($zip->set_number('7990122')->is_valid_number, '愛媛県四国中央市金田町半田');
ok($zip->set_number('7990123')->is_valid_number, '愛媛県四国中央市金田町金川');
ok($zip->set_number('7990124')->is_valid_number, '愛媛県四国中央市金田町三角寺');
ok($zip->set_number('7990125')->is_valid_number, '愛媛県四国中央市柴生町');
ok($zip->set_number('7990126')->is_valid_number, '愛媛県四国中央市下川町');
ok($zip->set_number('7990127')->is_valid_number, '愛媛県四国中央市川滝町下山');
ok($zip->set_number('7990128')->is_valid_number, '愛媛県四国中央市川滝町領家');
ok($zip->set_number('7990301')->is_valid_number, '愛媛県四国中央市新宮町馬立');
ok($zip->set_number('7990302')->is_valid_number, '愛媛県四国中央市新宮町上山');
ok($zip->set_number('7990303')->is_valid_number, '愛媛県四国中央市新宮町新宮');
ok($zip->set_number('7990304')->is_valid_number, '愛媛県四国中央市新宮町新瀬川');
ok($zip->set_number('7990400')->is_valid_number, '愛媛県四国中央市以下に掲載がない場合');
ok($zip->set_number('7990401')->is_valid_number, '愛媛県四国中央市村松町');
ok($zip->set_number('7990402')->is_valid_number, '愛媛県四国中央市三島紙屋町');
ok($zip->set_number('7990403')->is_valid_number, '愛媛県四国中央市三島朝日');
ok($zip->set_number('7990404')->is_valid_number, '愛媛県四国中央市三島宮川');
ok($zip->set_number('7990405')->is_valid_number, '愛媛県四国中央市三島中央');
ok($zip->set_number('7990411')->is_valid_number, '愛媛県四国中央市下柏町');
ok($zip->set_number('7990412')->is_valid_number, '愛媛県四国中央市上柏町');
ok($zip->set_number('7990413')->is_valid_number, '愛媛県四国中央市中曽根町');
ok($zip->set_number('7990421')->is_valid_number, '愛媛県四国中央市三島金子');
ok($zip->set_number('7990422')->is_valid_number, '愛媛県四国中央市中之庄町');
ok($zip->set_number('7990423')->is_valid_number, '愛媛県四国中央市具定町');
ok($zip->set_number('7990431')->is_valid_number, '愛媛県四国中央市寒川町');
ok($zip->set_number('7990432')->is_valid_number, '愛媛県四国中央市豊岡町大町');
ok($zip->set_number('7990433')->is_valid_number, '愛媛県四国中央市豊岡町豊田');
ok($zip->set_number('7990434')->is_valid_number, '愛媛県四国中央市豊岡町五良野');
ok($zip->set_number('7990435')->is_valid_number, '愛媛県四国中央市豊岡町長田');
ok($zip->set_number('7990436')->is_valid_number, '愛媛県四国中央市豊岡町岡銅');
ok($zip->set_number('7990641')->is_valid_number, '愛媛県四国中央市金砂町小川山');
ok($zip->set_number('7990642')->is_valid_number, '愛媛県四国中央市金砂町平野山');
ok($zip->set_number('7990643')->is_valid_number, '愛媛県四国中央市富郷町寒川山');
ok($zip->set_number('7990644')->is_valid_number, '愛媛県四国中央市富郷町豊坂');
ok($zip->set_number('7990645')->is_valid_number, '愛媛県四国中央市富郷町津根山');
ok($zip->set_number('7990650')->is_valid_number, '愛媛県新居浜市別子山');
ok($zip->set_number('7990701')->is_valid_number, '愛媛県四国中央市土居町中村');
ok($zip->set_number('7990702')->is_valid_number, '愛媛県四国中央市土居町小林');
ok($zip->set_number('7990703')->is_valid_number, '愛媛県四国中央市土居町藤原');
ok($zip->set_number('7990704')->is_valid_number, '愛媛県四国中央市土居町津根');
ok($zip->set_number('7990705')->is_valid_number, '愛媛県四国中央市土居町野田');
ok($zip->set_number('7990711')->is_valid_number, '愛媛県四国中央市土居町土居');
ok($zip->set_number('7990712')->is_valid_number, '愛媛県四国中央市土居町入野');
ok($zip->set_number('7990713')->is_valid_number, '愛媛県四国中央市土居町浦山');
ok($zip->set_number('7990714')->is_valid_number, '愛媛県四国中央市土居町畑野');
ok($zip->set_number('7990721')->is_valid_number, '愛媛県四国中央市土居町上野');
ok($zip->set_number('7990722')->is_valid_number, '愛媛県四国中央市土居町北野');
ok($zip->set_number('7990723')->is_valid_number, '愛媛県四国中央市土居町天満');
ok($zip->set_number('7990724')->is_valid_number, '愛媛県四国中央市土居町蕪崎');
ok($zip->set_number('7991101')->is_valid_number, '愛媛県西条市小松町新屋敷');
ok($zip->set_number('7991102')->is_valid_number, '愛媛県西条市小松町南川');
ok($zip->set_number('7991103')->is_valid_number, '愛媛県西条市小松町北川');
ok($zip->set_number('7991104')->is_valid_number, '愛媛県西条市小松町妙口');
ok($zip->set_number('7991105')->is_valid_number, '愛媛県西条市小松町大郷');
ok($zip->set_number('7991106')->is_valid_number, '愛媛県西条市小松町大頭');
ok($zip->set_number('7991107')->is_valid_number, '愛媛県西条市小松町明穂');
ok($zip->set_number('7991108')->is_valid_number, '愛媛県西条市小松町安井');
ok($zip->set_number('7991111')->is_valid_number, '愛媛県西条市小松町石鎚(湯浪)');
ok($zip->set_number('7991112')->is_valid_number, '愛媛県西条市小松町石鎚(その他)');
ok($zip->set_number('7991301')->is_valid_number, '愛媛県西条市三芳');
ok($zip->set_number('7991302')->is_valid_number, '愛媛県西条市楠');
ok($zip->set_number('7991303')->is_valid_number, '愛媛県西条市河原津');
ok($zip->set_number('7991304')->is_valid_number, '愛媛県西条市河原津新田');
ok($zip->set_number('7991311')->is_valid_number, '愛媛県西条市宮之内');
ok($zip->set_number('7991312')->is_valid_number, '愛媛県西条市大野');
ok($zip->set_number('7991313')->is_valid_number, '愛媛県西条市旦之上');
ok($zip->set_number('7991314')->is_valid_number, '愛媛県西条市河之内');
ok($zip->set_number('7991315')->is_valid_number, '愛媛県西条市黒谷');
ok($zip->set_number('7991316')->is_valid_number, '愛媛県西条市福成寺');
ok($zip->set_number('7991317')->is_valid_number, '愛媛県西条市実報寺');
ok($zip->set_number('7991321')->is_valid_number, '愛媛県西条市高田(その他)');
ok($zip->set_number('7991322')->is_valid_number, '愛媛県西条市国安');
ok($zip->set_number('7991323')->is_valid_number, '愛媛県西条市桑村');
ok($zip->set_number('7991324')->is_valid_number, '愛媛県西条市高田(正法寺)');
ok($zip->set_number('7991325')->is_valid_number, '愛媛県西条市新市');
ok($zip->set_number('7991331')->is_valid_number, '愛媛県西条市新町');
ok($zip->set_number('7991332')->is_valid_number, '愛媛県西条市安用出作');
ok($zip->set_number('7991333')->is_valid_number, '愛媛県西条市安用');
ok($zip->set_number('7991334')->is_valid_number, '愛媛県西条市広岡');
ok($zip->set_number('7991335')->is_valid_number, '愛媛県西条市石延');
ok($zip->set_number('7991336')->is_valid_number, '愛媛県西条市上市');
ok($zip->set_number('7991341')->is_valid_number, '愛媛県西条市壬生川');
ok($zip->set_number('7991342')->is_valid_number, '愛媛県西条市大新田');
ok($zip->set_number('7991343')->is_valid_number, '愛媛県西条市喜多台');
ok($zip->set_number('7991344')->is_valid_number, '愛媛県西条市円海寺');
ok($zip->set_number('7991345')->is_valid_number, '愛媛県西条市明理川');
ok($zip->set_number('7991351')->is_valid_number, '愛媛県西条市三津屋');
ok($zip->set_number('7991352')->is_valid_number, '愛媛県西条市三津屋東');
ok($zip->set_number('7991353')->is_valid_number, '愛媛県西条市三津屋南');
ok($zip->set_number('7991354')->is_valid_number, '愛媛県西条市北条');
ok($zip->set_number('7991361')->is_valid_number, '愛媛県西条市広江');
ok($zip->set_number('7991362')->is_valid_number, '愛媛県西条市今在家');
ok($zip->set_number('7991363')->is_valid_number, '愛媛県西条市玉之江');
ok($zip->set_number('7991364')->is_valid_number, '愛媛県西条市石田');
ok($zip->set_number('7991371')->is_valid_number, '愛媛県西条市周布');
ok($zip->set_number('7991372')->is_valid_number, '愛媛県西条市吉田');
ok($zip->set_number('7991501')->is_valid_number, '愛媛県今治市喜田村(番地)');
ok($zip->set_number('7991502')->is_valid_number, '愛媛県今治市喜田村(丁目)');
ok($zip->set_number('7991503')->is_valid_number, '愛媛県今治市富田新港');
ok($zip->set_number('7991504')->is_valid_number, '愛媛県今治市拝志');
ok($zip->set_number('7991505')->is_valid_number, '愛媛県今治市東村(番地)');
ok($zip->set_number('7991506')->is_valid_number, '愛媛県今治市東村(丁目)');
ok($zip->set_number('7991507')->is_valid_number, '愛媛県今治市東村南');
ok($zip->set_number('7991511')->is_valid_number, '愛媛県今治市上徳');
ok($zip->set_number('7991512')->is_valid_number, '愛媛県今治市高市');
ok($zip->set_number('7991513')->is_valid_number, '愛媛県今治市松木');
ok($zip->set_number('7991514')->is_valid_number, '愛媛県今治市町谷');
ok($zip->set_number('7991521')->is_valid_number, '愛媛県今治市古国分');
ok($zip->set_number('7991522')->is_valid_number, '愛媛県今治市桜井(丁目)');
ok($zip->set_number('7991523')->is_valid_number, '愛媛県今治市郷桜井');
ok($zip->set_number('7991524')->is_valid_number, '愛媛県今治市桜井(番地)');
ok($zip->set_number('7991525')->is_valid_number, '愛媛県今治市湯ノ浦');
ok($zip->set_number('7991526')->is_valid_number, '愛媛県今治市孫兵衛作');
ok($zip->set_number('7991527')->is_valid_number, '愛媛県今治市長沢');
ok($zip->set_number('7991531')->is_valid_number, '愛媛県今治市唐子台東');
ok($zip->set_number('7991532')->is_valid_number, '愛媛県今治市唐子台西');
ok($zip->set_number('7991533')->is_valid_number, '愛媛県今治市国分');
ok($zip->set_number('7991534')->is_valid_number, '愛媛県今治市桜井団地');
ok($zip->set_number('7991535')->is_valid_number, '愛媛県今治市登畑');
ok($zip->set_number('7991536')->is_valid_number, '愛媛県今治市旦');
ok($zip->set_number('7991537')->is_valid_number, '愛媛県今治市宮ヶ崎');
ok($zip->set_number('7991601')->is_valid_number, '愛媛県今治市古谷');
ok($zip->set_number('7991602')->is_valid_number, '愛媛県今治市山口');
ok($zip->set_number('7991603')->is_valid_number, '愛媛県今治市朝倉下');
ok($zip->set_number('7991604')->is_valid_number, '愛媛県今治市朝倉北');
ok($zip->set_number('7991605')->is_valid_number, '愛媛県今治市朝倉南甲');
ok($zip->set_number('7991606')->is_valid_number, '愛媛県今治市朝倉南乙');
ok($zip->set_number('7991607')->is_valid_number, '愛媛県今治市朝倉上');
ok($zip->set_number('7991608')->is_valid_number, '愛媛県今治市朝倉南丙');
ok($zip->set_number('7992101')->is_valid_number, '愛媛県今治市波方町波方');
ok($zip->set_number('7992102')->is_valid_number, '愛媛県今治市波方町樋口');
ok($zip->set_number('7992103')->is_valid_number, '愛媛県今治市波方町小部');
ok($zip->set_number('7992104')->is_valid_number, '愛媛県今治市波方町宮崎');
ok($zip->set_number('7992105')->is_valid_number, '愛媛県今治市波方町馬刀潟');
ok($zip->set_number('7992106')->is_valid_number, '愛媛県今治市波方町森上');
ok($zip->set_number('7992107')->is_valid_number, '愛媛県今治市波方町西浦');
ok($zip->set_number('7992108')->is_valid_number, '愛媛県今治市波方町岡');
ok($zip->set_number('7992109')->is_valid_number, '愛媛県今治市波方町養老');
ok($zip->set_number('7992110')->is_valid_number, '愛媛県今治市波方町大浦');
ok($zip->set_number('7992110')->is_valid_number, '愛媛県今治市波方町郷');
ok($zip->set_number('7992111')->is_valid_number, '愛媛県今治市小浦町');
ok($zip->set_number('7992112')->is_valid_number, '愛媛県今治市波止浜(丁目)');
ok($zip->set_number('7992113')->is_valid_number, '愛媛県今治市高部');
ok($zip->set_number('7992114')->is_valid_number, '愛媛県今治市杣田');
ok($zip->set_number('7992115')->is_valid_number, '愛媛県今治市中堀');
ok($zip->set_number('7992116')->is_valid_number, '愛媛県今治市内堀');
ok($zip->set_number('7992117')->is_valid_number, '愛媛県今治市地堀');
ok($zip->set_number('7992118')->is_valid_number, '愛媛県今治市波止浜(番地)');
ok($zip->set_number('7992121')->is_valid_number, '愛媛県今治市来島(その他)');
ok($zip->set_number('7992122')->is_valid_number, '愛媛県今治市来島(小島)');
ok($zip->set_number('7992123')->is_valid_number, '愛媛県今治市馬島');
ok($zip->set_number('7992201')->is_valid_number, '愛媛県今治市大西町九王');
ok($zip->set_number('7992202')->is_valid_number, '愛媛県今治市大西町紺原');
ok($zip->set_number('7992203')->is_valid_number, '愛媛県今治市大西町新町');
ok($zip->set_number('7992204')->is_valid_number, '愛媛県今治市大西町大井浜');
ok($zip->set_number('7992205')->is_valid_number, '愛媛県今治市大西町宮脇');
ok($zip->set_number('7992206')->is_valid_number, '愛媛県今治市大西町脇');
ok($zip->set_number('7992207')->is_valid_number, '愛媛県今治市大西町山之内');
ok($zip->set_number('7992208')->is_valid_number, '愛媛県今治市大西町星浦');
ok($zip->set_number('7992209')->is_valid_number, '愛媛県今治市大西町別府');
ok($zip->set_number('7992301')->is_valid_number, '愛媛県今治市菊間町佐方');
ok($zip->set_number('7992302')->is_valid_number, '愛媛県今治市菊間町種');
ok($zip->set_number('7992303')->is_valid_number, '愛媛県今治市菊間町浜');
ok($zip->set_number('7992304')->is_valid_number, '愛媛県今治市菊間町池原');
ok($zip->set_number('7992305')->is_valid_number, '愛媛県今治市菊間町松尾');
ok($zip->set_number('7992306')->is_valid_number, '愛媛県今治市菊間町河之内');
ok($zip->set_number('7992307')->is_valid_number, '愛媛県今治市菊間町川上');
ok($zip->set_number('7992308')->is_valid_number, '愛媛県今治市菊間町中川');
ok($zip->set_number('7992309')->is_valid_number, '愛媛県今治市菊間町高田');
ok($zip->set_number('7992310')->is_valid_number, '愛媛県今治市菊間町長坂');
ok($zip->set_number('7992311')->is_valid_number, '愛媛県今治市菊間町西山');
ok($zip->set_number('7992312')->is_valid_number, '愛媛県今治市菊間町田之尻');
ok($zip->set_number('7992401')->is_valid_number, '愛媛県松山市浅海原');
ok($zip->set_number('7992402')->is_valid_number, '愛媛県松山市浅海本谷');
ok($zip->set_number('7992403')->is_valid_number, '愛媛県松山市萩原');
ok($zip->set_number('7992404')->is_valid_number, '愛媛県松山市庄');
ok($zip->set_number('7992405')->is_valid_number, '愛媛県松山市上難波');
ok($zip->set_number('7992406')->is_valid_number, '愛媛県松山市中通');
ok($zip->set_number('7992407')->is_valid_number, '愛媛県松山市下難波');
ok($zip->set_number('7992408')->is_valid_number, '愛媛県松山市大浦');
ok($zip->set_number('7992410')->is_valid_number, '愛媛県松山市小山田');
ok($zip->set_number('7992411')->is_valid_number, '愛媛県松山市儀式');
ok($zip->set_number('7992412')->is_valid_number, '愛媛県松山市庄府');
ok($zip->set_number('7992413')->is_valid_number, '愛媛県松山市立岩米之野');
ok($zip->set_number('7992414')->is_valid_number, '愛媛県松山市立岩中村');
ok($zip->set_number('7992415')->is_valid_number, '愛媛県松山市猿川');
ok($zip->set_number('7992416')->is_valid_number, '愛媛県松山市猪木');
ok($zip->set_number('7992416')->is_valid_number, '愛媛県松山市滝本');
ok($zip->set_number('7992417')->is_valid_number, '愛媛県松山市才之原');
ok($zip->set_number('7992418')->is_valid_number, '愛媛県松山市尾儀原');
ok($zip->set_number('7992419')->is_valid_number, '愛媛県松山市猿川原');
ok($zip->set_number('7992421')->is_valid_number, '愛媛県松山市正岡神田');
ok($zip->set_number('7992422')->is_valid_number, '愛媛県松山市高田');
ok($zip->set_number('7992423')->is_valid_number, '愛媛県松山市院内');
ok($zip->set_number('7992424')->is_valid_number, '愛媛県松山市八反地');
ok($zip->set_number('7992425')->is_valid_number, '愛媛県松山市中西外');
ok($zip->set_number('7992426')->is_valid_number, '愛媛県松山市中西内');
ok($zip->set_number('7992430')->is_valid_number, '愛媛県松山市北条辻');
ok($zip->set_number('7992431')->is_valid_number, '愛媛県松山市北条');
ok($zip->set_number('7992432')->is_valid_number, '愛媛県松山市土手内');
ok($zip->set_number('7992433')->is_valid_number, '愛媛県松山市安居島');
ok($zip->set_number('7992434')->is_valid_number, '愛媛県松山市柳原');
ok($zip->set_number('7992435')->is_valid_number, '愛媛県松山市府中');
ok($zip->set_number('7992436')->is_valid_number, '愛媛県松山市河野別府');
ok($zip->set_number('7992437')->is_valid_number, '愛媛県松山市夏目');
ok($zip->set_number('7992438')->is_valid_number, '愛媛県松山市河野中須賀');
ok($zip->set_number('7992439')->is_valid_number, '愛媛県松山市片山');
ok($zip->set_number('7992441')->is_valid_number, '愛媛県松山市宮内');
ok($zip->set_number('7992442')->is_valid_number, '愛媛県松山市常保免');
ok($zip->set_number('7992443')->is_valid_number, '愛媛県松山市善応寺');
ok($zip->set_number('7992444')->is_valid_number, '愛媛県松山市横谷');
ok($zip->set_number('7992445')->is_valid_number, '愛媛県松山市河野高山');
ok($zip->set_number('7992446')->is_valid_number, '愛媛県松山市牛谷');
ok($zip->set_number('7992447')->is_valid_number, '愛媛県松山市佐古');
ok($zip->set_number('7992451')->is_valid_number, '愛媛県松山市小川谷');
ok($zip->set_number('7992452')->is_valid_number, '愛媛県松山市平林');
ok($zip->set_number('7992453')->is_valid_number, '愛媛県松山市麓');
ok($zip->set_number('7992454')->is_valid_number, '愛媛県松山市客');
ok($zip->set_number('7992455')->is_valid_number, '愛媛県松山市常竹');
ok($zip->set_number('7992456')->is_valid_number, '愛媛県松山市本谷');
ok($zip->set_number('7992457')->is_valid_number, '愛媛県松山市西谷');
ok($zip->set_number('7992458')->is_valid_number, '愛媛県松山市大西谷');
ok($zip->set_number('7992460')->is_valid_number, '愛媛県松山市苞木');
ok($zip->set_number('7992461')->is_valid_number, '愛媛県松山市鹿峰');
ok($zip->set_number('7992462')->is_valid_number, '愛媛県松山市久保');
ok($zip->set_number('7992463')->is_valid_number, '愛媛県松山市粟井河原');
ok($zip->set_number('7992464')->is_valid_number, '愛媛県松山市安岡');
ok($zip->set_number('7992465')->is_valid_number, '愛媛県松山市和田');
ok($zip->set_number('7992466')->is_valid_number, '愛媛県松山市鴨之池');
ok($zip->set_number('7992467')->is_valid_number, '愛媛県松山市磯河内');
ok($zip->set_number('7992468')->is_valid_number, '愛媛県松山市小川');
ok($zip->set_number('7992469')->is_valid_number, '愛媛県松山市光洋台');
ok($zip->set_number('7992649')->is_valid_number, '愛媛県松山市東大栗町');
ok($zip->set_number('7992651')->is_valid_number, '愛媛県松山市堀江町');
ok($zip->set_number('7992652')->is_valid_number, '愛媛県松山市福角町');
ok($zip->set_number('7992653')->is_valid_number, '愛媛県松山市権現町');
ok($zip->set_number('7992654')->is_valid_number, '愛媛県松山市内宮町');
ok($zip->set_number('7992655')->is_valid_number, '愛媛県松山市馬木町');
ok($zip->set_number('7992656')->is_valid_number, '愛媛県松山市和気町');
ok($zip->set_number('7992661')->is_valid_number, '愛媛県松山市勝岡町');
ok($zip->set_number('7992662')->is_valid_number, '愛媛県松山市太山寺町');
ok($zip->set_number('7993100')->is_valid_number, '愛媛県伊予市以下に掲載がない場合');
ok($zip->set_number('7993101')->is_valid_number, '愛媛県伊予市八倉');
ok($zip->set_number('7993102')->is_valid_number, '愛媛県伊予市宮下');
ok($zip->set_number('7993103')->is_valid_number, '愛媛県伊予市上野');
ok($zip->set_number('7993104')->is_valid_number, '愛媛県伊予市上三谷');
ok($zip->set_number('7993105')->is_valid_number, '愛媛県伊予市下三谷');
ok($zip->set_number('7993111')->is_valid_number, '愛媛県伊予市下吾川');
ok($zip->set_number('7993112')->is_valid_number, '愛媛県伊予市上吾川');
ok($zip->set_number('7993113')->is_valid_number, '愛媛県伊予市米湊');
ok($zip->set_number('7993114')->is_valid_number, '愛媛県伊予市灘町');
ok($zip->set_number('7993115')->is_valid_number, '愛媛県伊予市湊町');
ok($zip->set_number('7993121')->is_valid_number, '愛媛県伊予市稲荷');
ok($zip->set_number('7993122')->is_valid_number, '愛媛県伊予市市場');
ok($zip->set_number('7993123')->is_valid_number, '愛媛県伊予市中村');
ok($zip->set_number('7993124')->is_valid_number, '愛媛県伊予市三秋');
ok($zip->set_number('7993125')->is_valid_number, '愛媛県伊予市森');
ok($zip->set_number('7993126')->is_valid_number, '愛媛県伊予市本郡');
ok($zip->set_number('7993127')->is_valid_number, '愛媛県伊予市尾崎');
ok($zip->set_number('7993128')->is_valid_number, '愛媛県伊予市三島町');
ok($zip->set_number('7993131')->is_valid_number, '愛媛県伊予市大平');
ok($zip->set_number('7993132')->is_valid_number, '愛媛県伊予市平岡');
ok($zip->set_number('7993133')->is_valid_number, '愛媛県伊予市下唐川');
ok($zip->set_number('7993134')->is_valid_number, '愛媛県伊予市上唐川');
ok($zip->set_number('7993135')->is_valid_number, '愛媛県伊予市両沢');
ok($zip->set_number('7993136')->is_valid_number, '愛媛県伊予市鵜崎');
ok($zip->set_number('7993201')->is_valid_number, '愛媛県伊予市双海町高野川');
ok($zip->set_number('7993202')->is_valid_number, '愛媛県伊予市双海町上灘');
ok($zip->set_number('7993207')->is_valid_number, '愛媛県伊予市双海町高岸');
ok($zip->set_number('7993311')->is_valid_number, '愛媛県伊予市双海町大久保');
ok($zip->set_number('7993312')->is_valid_number, '愛媛県伊予市双海町串(その他)');
ok($zip->set_number('7993313')->is_valid_number, '愛媛県伊予市双海町串(上浜)');
ok($zip->set_number('7993314')->is_valid_number, '愛媛県伊予市双海町串(下浜)');
ok($zip->set_number('7993401')->is_valid_number, '愛媛県大洲市長浜甲');
ok($zip->set_number('7993402')->is_valid_number, '愛媛県大洲市長浜乙');
ok($zip->set_number('7993403')->is_valid_number, '愛媛県大洲市長浜町仁久甲');
ok($zip->set_number('7993404')->is_valid_number, '愛媛県大洲市長浜町沖浦甲');
ok($zip->set_number('7993405')->is_valid_number, '愛媛県大洲市長浜町沖浦乙');
ok($zip->set_number('7993406')->is_valid_number, '愛媛県大洲市長浜町沖浦丙');
ok($zip->set_number('7993407')->is_valid_number, '愛媛県大洲市長浜町黒田甲');
ok($zip->set_number('7993411')->is_valid_number, '愛媛県大洲市長浜町今坊甲');
ok($zip->set_number('7993412')->is_valid_number, '愛媛県大洲市長浜町晴海');
ok($zip->set_number('7993413')->is_valid_number, '愛媛県大洲市長浜町拓海');
ok($zip->set_number('7993421')->is_valid_number, '愛媛県大洲市戒川甲');
ok($zip->set_number('7993422')->is_valid_number, '愛媛県大洲市長浜町大越甲');
ok($zip->set_number('7993431')->is_valid_number, '愛媛県大洲市白滝甲');
ok($zip->set_number('7993432')->is_valid_number, '愛媛県大洲市柴甲');
ok($zip->set_number('7993433')->is_valid_number, '愛媛県大洲市柴乙');
ok($zip->set_number('7993441')->is_valid_number, '愛媛県大洲市長浜町下須戒甲');
ok($zip->set_number('7993442')->is_valid_number, '愛媛県大洲市長浜町穂積甲');
ok($zip->set_number('7993443')->is_valid_number, '愛媛県大洲市長浜町穂積乙');
ok($zip->set_number('7993444')->is_valid_number, '愛媛県大洲市長浜町上老松甲');
ok($zip->set_number('7993451')->is_valid_number, '愛媛県大洲市長浜町須沢丙');
ok($zip->set_number('7993452')->is_valid_number, '愛媛県大洲市長浜町櫛生甲');
ok($zip->set_number('7993453')->is_valid_number, '愛媛県大洲市長浜町櫛生乙');
ok($zip->set_number('7993454')->is_valid_number, '愛媛県大洲市長浜町櫛生丙');
ok($zip->set_number('7993455')->is_valid_number, '愛媛県大洲市長浜町出海甲');
ok($zip->set_number('7993456')->is_valid_number, '愛媛県大洲市長浜町出海乙');
ok($zip->set_number('7993461')->is_valid_number, '愛媛県大洲市豊茂甲');
ok($zip->set_number('7993462')->is_valid_number, '愛媛県大洲市豊茂乙');
ok($zip->set_number('7993463')->is_valid_number, '愛媛県大洲市豊茂丙');
ok($zip->set_number('7993464')->is_valid_number, '愛媛県大洲市豊茂丁');
ok($zip->set_number('7993470')->is_valid_number, '愛媛県大洲市長浜町青島');
ok($zip->set_number('7993701')->is_valid_number, '愛媛県宇和島市吉田町北小路');
ok($zip->set_number('7993702')->is_valid_number, '愛媛県宇和島市吉田町西小路');
ok($zip->set_number('7993703')->is_valid_number, '愛媛県宇和島市吉田町東小路');
ok($zip->set_number('7993704')->is_valid_number, '愛媛県宇和島市吉田町魚棚');
ok($zip->set_number('7993705')->is_valid_number, '愛媛県宇和島市吉田町本町');
ok($zip->set_number('7993706')->is_valid_number, '愛媛県宇和島市吉田町裡町');
ok($zip->set_number('7993707')->is_valid_number, '愛媛県宇和島市吉田町鶴間(御殿内)');
ok($zip->set_number('7993710')->is_valid_number, '愛媛県宇和島市吉田町立間尻');
ok($zip->set_number('7993720')->is_valid_number, '愛媛県宇和島市吉田町知永');
ok($zip->set_number('7993730')->is_valid_number, '愛媛県宇和島市吉田町立間');
ok($zip->set_number('7993741')->is_valid_number, '愛媛県宇和島市吉田町白浦');
ok($zip->set_number('7993742')->is_valid_number, '愛媛県宇和島市吉田町法花津');
ok($zip->set_number('7993743')->is_valid_number, '愛媛県宇和島市吉田町深浦');
ok($zip->set_number('7993751')->is_valid_number, '愛媛県宇和島市吉田町沖村');
ok($zip->set_number('7993752')->is_valid_number, '愛媛県宇和島市吉田町河内');
ok($zip->set_number('7993761')->is_valid_number, '愛媛県宇和島市吉田町鶴間(その他)');
ok($zip->set_number('7993762')->is_valid_number, '愛媛県宇和島市吉田町鶴間(鶴間団地)');
ok($zip->set_number('7993763')->is_valid_number, '愛媛県宇和島市吉田町浅川');
ok($zip->set_number('7993771')->is_valid_number, '愛媛県宇和島市吉田町南君');
ok($zip->set_number('7993772')->is_valid_number, '愛媛県宇和島市吉田町奥浦');
ok($zip->set_number('8000000')->is_valid_number, '福岡県北九州市門司区以下に掲載がない場合');
ok($zip->set_number('8000001')->is_valid_number, '福岡県北九州市門司区風師(4丁目)');
ok($zip->set_number('8000002')->is_valid_number, '福岡県北九州市門司区二タ松町');
ok($zip->set_number('8000003')->is_valid_number, '福岡県北九州市門司区片上町');
ok($zip->set_number('8000004')->is_valid_number, '福岡県北九州市門司区北川町');
ok($zip->set_number('8000005')->is_valid_number, '福岡県北九州市門司区羽山');
ok($zip->set_number('8000006')->is_valid_number, '福岡県北九州市門司区矢筈町');
ok($zip->set_number('8000007')->is_valid_number, '福岡県北九州市門司区小森江');
ok($zip->set_number('8000008')->is_valid_number, '福岡県北九州市門司区葛葉(2、3丁目)');
ok($zip->set_number('8000011')->is_valid_number, '福岡県北九州市門司区奥田');
ok($zip->set_number('8000012')->is_valid_number, '福岡県北九州市門司区松崎町');
ok($zip->set_number('8000013')->is_valid_number, '福岡県北九州市門司区城山町');
ok($zip->set_number('8000014')->is_valid_number, '福岡県北九州市門司区大里');
ok($zip->set_number('8000015')->is_valid_number, '福岡県北九州市門司区寺内');
ok($zip->set_number('8000016')->is_valid_number, '福岡県北九州市門司区上二十町');
ok($zip->set_number('8000017')->is_valid_number, '福岡県北九州市門司区永黒');
ok($zip->set_number('8000018')->is_valid_number, '福岡県北九州市門司区大里桜ケ丘');
ok($zip->set_number('8000021')->is_valid_number, '福岡県北九州市門司区南本町');
ok($zip->set_number('8000022')->is_valid_number, '福岡県北九州市門司区大里東');
ok($zip->set_number('8000023')->is_valid_number, '福岡県北九州市門司区中二十町');
ok($zip->set_number('8000024')->is_valid_number, '福岡県北九州市門司区大里戸ノ上');
ok($zip->set_number('8000025')->is_valid_number, '福岡県北九州市門司区柳町');
ok($zip->set_number('8000026')->is_valid_number, '福岡県北九州市門司区梅ノ木町');
ok($zip->set_number('8000027')->is_valid_number, '福岡県北九州市門司区黄金町');
ok($zip->set_number('8000028')->is_valid_number, '福岡県北九州市門司区下二十町');
ok($zip->set_number('8000029')->is_valid_number, '福岡県北九州市門司区大里東口');
ok($zip->set_number('8000030')->is_valid_number, '福岡県北九州市門司区桃山台');
ok($zip->set_number('8000031')->is_valid_number, '福岡県北九州市門司区高田');
ok($zip->set_number('8000032')->is_valid_number, '福岡県北九州市門司区不老町');
ok($zip->set_number('8000033')->is_valid_number, '福岡県北九州市門司区大里桃山町');
ok($zip->set_number('8000034')->is_valid_number, '福岡県北九州市門司区小松町');
ok($zip->set_number('8000035')->is_valid_number, '福岡県北九州市門司区別院');
ok($zip->set_number('8000036')->is_valid_number, '福岡県北九州市門司区柳原町');
ok($zip->set_number('8000037')->is_valid_number, '福岡県北九州市門司区原町別院');
ok($zip->set_number('8000038')->is_valid_number, '福岡県北九州市門司区大里原町');
ok($zip->set_number('8000039')->is_valid_number, '福岡県北九州市門司区中町');
ok($zip->set_number('8000041')->is_valid_number, '福岡県北九州市門司区泉ケ丘');
ok($zip->set_number('8000042')->is_valid_number, '福岡県北九州市門司区上馬寄');
ok($zip->set_number('8000043')->is_valid_number, '福岡県北九州市門司区緑ケ丘');
ok($zip->set_number('8000044')->is_valid_number, '福岡県北九州市門司区上藤松');
ok($zip->set_number('8000045')->is_valid_number, '福岡県北九州市門司区青葉台');
ok($zip->set_number('8000046')->is_valid_number, '福岡県北九州市門司区光町');
ok($zip->set_number('8000047')->is_valid_number, '福岡県北九州市門司区藤松');
ok($zip->set_number('8000048')->is_valid_number, '福岡県北九州市門司区稲積');
ok($zip->set_number('8000051')->is_valid_number, '福岡県北九州市門司区下馬寄');
ok($zip->set_number('8000052')->is_valid_number, '福岡県北九州市門司区東馬寄');
ok($zip->set_number('8000053')->is_valid_number, '福岡県北九州市門司区新原町');
ok($zip->set_number('8000054')->is_valid_number, '福岡県北九州市門司区社ノ木');
ok($zip->set_number('8000055')->is_valid_number, '福岡県北九州市門司区東新町');
ok($zip->set_number('8000056')->is_valid_number, '福岡県北九州市門司区西新町');
ok($zip->set_number('8000057')->is_valid_number, '福岡県北九州市門司区大里新町');
ok($zip->set_number('8000061')->is_valid_number, '福岡県北九州市門司区片上海岸');
ok($zip->set_number('8000062')->is_valid_number, '福岡県北九州市門司区大里元町');
ok($zip->set_number('8000063')->is_valid_number, '福岡県北九州市門司区大里本町');
ok($zip->set_number('8000064')->is_valid_number, '福岡県北九州市門司区松原');
ok($zip->set_number('8000101')->is_valid_number, '福岡県北九州市門司区伊川');
ok($zip->set_number('8000102')->is_valid_number, '福岡県北九州市門司区猿喰');
ok($zip->set_number('8000111')->is_valid_number, '福岡県北九州市門司区今津');
ok($zip->set_number('8000112')->is_valid_number, '福岡県北九州市門司区畑');
ok($zip->set_number('8000113')->is_valid_number, '福岡県北九州市門司区新門司北');
ok($zip->set_number('8000114')->is_valid_number, '福岡県北九州市門司区吉志');
ok($zip->set_number('8000115')->is_valid_number, '福岡県北九州市門司区新門司');
ok($zip->set_number('8000116')->is_valid_number, '福岡県北九州市門司区恒見町');
ok($zip->set_number('8000117')->is_valid_number, '福岡県北九州市門司区恒見');
ok($zip->set_number('8000118')->is_valid_number, '福岡県北九州市門司区吉志新町');
ok($zip->set_number('8000201')->is_valid_number, '福岡県北九州市小倉南区上吉田');
ok($zip->set_number('8000202')->is_valid_number, '福岡県北九州市小倉南区吉田');
ok($zip->set_number('8000203')->is_valid_number, '福岡県北九州市小倉南区下吉田');
ok($zip->set_number('8000204')->is_valid_number, '福岡県北九州市小倉南区中吉田');
ok($zip->set_number('8000205')->is_valid_number, '福岡県北九州市小倉南区沼南町');
ok($zip->set_number('8000206')->is_valid_number, '福岡県北九州市小倉南区葛原東');
ok($zip->set_number('8000207')->is_valid_number, '福岡県北九州市小倉南区沼緑町');
ok($zip->set_number('8000208')->is_valid_number, '福岡県北九州市小倉南区沼本町');
ok($zip->set_number('8000209')->is_valid_number, '福岡県北九州市小倉南区沼');
ok($zip->set_number('8000210')->is_valid_number, '福岡県北九州市小倉南区吉田にれの木坂');
ok($zip->set_number('8000211')->is_valid_number, '福岡県北九州市小倉南区新曽根');
ok($zip->set_number('8000212')->is_valid_number, '福岡県北九州市小倉南区曽根');
ok($zip->set_number('8000213')->is_valid_number, '福岡県北九州市小倉南区中曽根東');
ok($zip->set_number('8000214')->is_valid_number, '福岡県北九州市小倉南区曽根新田');
ok($zip->set_number('8000215')->is_valid_number, '福岡県北九州市小倉南区上曽根新町');
ok($zip->set_number('8000216')->is_valid_number, '福岡県北九州市小倉南区中曽根新町');
ok($zip->set_number('8000217')->is_valid_number, '福岡県北九州市小倉南区下曽根');
ok($zip->set_number('8000218')->is_valid_number, '福岡県北九州市小倉南区沼新町');
ok($zip->set_number('8000219')->is_valid_number, '福岡県北九州市小倉南区曽根新田北');
ok($zip->set_number('8000220')->is_valid_number, '福岡県北九州市小倉南区曽根新田南');
ok($zip->set_number('8000221')->is_valid_number, '福岡県北九州市小倉南区下曽根新町');
ok($zip->set_number('8000222')->is_valid_number, '福岡県北九州市小倉南区中曽根');
ok($zip->set_number('8000223')->is_valid_number, '福岡県北九州市小倉南区上曽根');
ok($zip->set_number('8000224')->is_valid_number, '福岡県北九州市小倉南区東貫');
ok($zip->set_number('8000225')->is_valid_number, '福岡県北九州市小倉南区田原');
ok($zip->set_number('8000226')->is_valid_number, '福岡県北九州市小倉南区田原新町');
ok($zip->set_number('8000227')->is_valid_number, '福岡県北九州市小倉南区津田新町');
ok($zip->set_number('8000228')->is_valid_number, '福岡県北九州市小倉南区長野(丁目)');
ok($zip->set_number('8000229')->is_valid_number, '福岡県北九州市小倉南区曽根北町');
ok($zip->set_number('8000231')->is_valid_number, '福岡県北九州市小倉南区朽網');
ok($zip->set_number('8000232')->is_valid_number, '福岡県北九州市小倉南区朽網東');
ok($zip->set_number('8000233')->is_valid_number, '福岡県北九州市小倉南区朽網西');
ok($zip->set_number('8000234')->is_valid_number, '福岡県北九州市小倉南区貫弥生が丘');
ok($zip->set_number('8000235')->is_valid_number, '福岡県北九州市小倉南区中貫本町');
ok($zip->set_number('8000236')->is_valid_number, '福岡県北九州市小倉南区下貫');
ok($zip->set_number('8000237')->is_valid_number, '福岡県北九州市小倉南区中貫');
ok($zip->set_number('8000241')->is_valid_number, '福岡県北九州市小倉南区長野本町');
ok($zip->set_number('8000242')->is_valid_number, '福岡県北九州市小倉南区津田');
ok($zip->set_number('8000243')->is_valid_number, '福岡県北九州市小倉南区西貫');
ok($zip->set_number('8000244')->is_valid_number, '福岡県北九州市小倉南区上貫');
ok($zip->set_number('8000245')->is_valid_number, '福岡県北九州市小倉南区貫');
ok($zip->set_number('8000246')->is_valid_number, '福岡県北九州市小倉南区長野(番地)');
ok($zip->set_number('8000247')->is_valid_number, '福岡県北九州市小倉南区長野東町');
ok($zip->set_number('8000248')->is_valid_number, '福岡県北九州市小倉南区津田南町');
ok($zip->set_number('8000251')->is_valid_number, '福岡県北九州市小倉南区葛原');
ok($zip->set_number('8000252')->is_valid_number, '福岡県北九州市小倉南区葛原高松');
ok($zip->set_number('8000253')->is_valid_number, '福岡県北九州市小倉南区葛原本町');
ok($zip->set_number('8000254')->is_valid_number, '福岡県北九州市小倉南区葛原元町');
ok($zip->set_number('8000255')->is_valid_number, '福岡県北九州市小倉南区上葛原');
ok($zip->set_number('8000256')->is_valid_number, '福岡県北九州市小倉南区湯川新町');
ok($zip->set_number('8000257')->is_valid_number, '福岡県北九州市小倉南区湯川');
ok($zip->set_number('8000258')->is_valid_number, '福岡県北九州市小倉南区安部山');
ok($zip->set_number('8000300')->is_valid_number, '福岡県京都郡苅田町以下に掲載がない場合');
ok($zip->set_number('8000301')->is_valid_number, '福岡県京都郡苅田町松原町');
ok($zip->set_number('8000302')->is_valid_number, '福岡県京都郡苅田町若久町');
ok($zip->set_number('8000303')->is_valid_number, '福岡県京都郡苅田町松山');
ok($zip->set_number('8000304')->is_valid_number, '福岡県京都郡苅田町鳥越町');
ok($zip->set_number('8000305')->is_valid_number, '福岡県京都郡苅田町空港南町');
ok($zip->set_number('8000306')->is_valid_number, '福岡県北九州市小倉南区空港北町');
ok($zip->set_number('8000307')->is_valid_number, '福岡県京都郡苅田町新松山');
ok($zip->set_number('8000311')->is_valid_number, '福岡県京都郡苅田町長浜町');
ok($zip->set_number('8000312')->is_valid_number, '福岡県京都郡苅田町殿川町');
ok($zip->set_number('8000313')->is_valid_number, '福岡県京都郡苅田町磯浜町');
ok($zip->set_number('8000314')->is_valid_number, '福岡県京都郡苅田町幸町');
ok($zip->set_number('8000315')->is_valid_number, '福岡県京都郡苅田町港町');
ok($zip->set_number('8000321')->is_valid_number, '福岡県京都郡苅田町新浜町');
ok($zip->set_number('8000322')->is_valid_number, '福岡県京都郡苅田町二崎');
ok($zip->set_number('8000323')->is_valid_number, '福岡県京都郡苅田町与原');
ok($zip->set_number('8000324')->is_valid_number, '福岡県京都郡苅田町浜町');
ok($zip->set_number('8000331')->is_valid_number, '福岡県京都郡苅田町岡崎');
ok($zip->set_number('8000332')->is_valid_number, '福岡県京都郡苅田町鋤崎');
ok($zip->set_number('8000333')->is_valid_number, '福岡県京都郡苅田町黒添');
ok($zip->set_number('8000334')->is_valid_number, '福岡県京都郡苅田町法正寺');
ok($zip->set_number('8000335')->is_valid_number, '福岡県京都郡苅田町谷');
ok($zip->set_number('8000336')->is_valid_number, '福岡県京都郡苅田町山口');
ok($zip->set_number('8000337')->is_valid_number, '福岡県京都郡苅田町稲光');
ok($zip->set_number('8000338')->is_valid_number, '福岡県京都郡苅田町葛川');
ok($zip->set_number('8000341')->is_valid_number, '福岡県京都郡苅田町下新津');
ok($zip->set_number('8000342')->is_valid_number, '福岡県京都郡苅田町下片島');
ok($zip->set_number('8000343')->is_valid_number, '福岡県京都郡苅田町上片島');
ok($zip->set_number('8000344')->is_valid_number, '福岡県京都郡苅田町新津');
ok($zip->set_number('8000345')->is_valid_number, '福岡県京都郡苅田町小波瀬');
ok($zip->set_number('8000351')->is_valid_number, '福岡県京都郡苅田町京町');
ok($zip->set_number('8000352')->is_valid_number, '福岡県京都郡苅田町富久町');
ok($zip->set_number('8000353')->is_valid_number, '福岡県京都郡苅田町尾倉');
ok($zip->set_number('8000354')->is_valid_number, '福岡県京都郡苅田町集');
ok($zip->set_number('8000355')->is_valid_number, '福岡県京都郡苅田町南原');
ok($zip->set_number('8000356')->is_valid_number, '福岡県京都郡苅田町近衛ケ丘');
ok($zip->set_number('8000357')->is_valid_number, '福岡県京都郡苅田町桜ケ丘');
ok($zip->set_number('8000361')->is_valid_number, '福岡県京都郡苅田町神田町');
ok($zip->set_number('8000362')->is_valid_number, '福岡県京都郡苅田町馬場');
ok($zip->set_number('8000363')->is_valid_number, '福岡県京都郡苅田町光国');
ok($zip->set_number('8000364')->is_valid_number, '福岡県京都郡苅田町提');
ok($zip->set_number('8000365')->is_valid_number, '福岡県京都郡苅田町苅田');
ok($zip->set_number('8000366')->is_valid_number, '福岡県京都郡苅田町雨窪');
ok($zip->set_number('8010801')->is_valid_number, '福岡県北九州市門司区風師(1~3丁目)');
ok($zip->set_number('8010802')->is_valid_number, '福岡県北九州市門司区白野江');
ok($zip->set_number('8010803')->is_valid_number, '福岡県北九州市門司区田野浦');
ok($zip->set_number('8010804')->is_valid_number, '福岡県北九州市門司区田野浦海岸');
ok($zip->set_number('8010805')->is_valid_number, '福岡県北九州市門司区太刀浦海岸');
ok($zip->set_number('8010808')->is_valid_number, '福岡県北九州市門司区葛葉(1丁目)');
ok($zip->set_number('8010811')->is_valid_number, '福岡県北九州市門司区大積');
ok($zip->set_number('8010812')->is_valid_number, '福岡県北九州市門司区喜多久');
ok($zip->set_number('8010813')->is_valid_number, '福岡県北九州市門司区柄杓田');
ok($zip->set_number('8010814')->is_valid_number, '福岡県北九州市門司区柄杓田町');
ok($zip->set_number('8010821')->is_valid_number, '福岡県北九州市門司区黒川');
ok($zip->set_number('8010822')->is_valid_number, '福岡県北九州市門司区高砂町');
ok($zip->set_number('8010823')->is_valid_number, '福岡県北九州市門司区春日町');
ok($zip->set_number('8010824')->is_valid_number, '福岡県北九州市門司区丸山吉野町');
ok($zip->set_number('8010825')->is_valid_number, '福岡県北九州市門司区黒川西');
ok($zip->set_number('8010826')->is_valid_number, '福岡県北九州市門司区黒川東');
ok($zip->set_number('8010831')->is_valid_number, '福岡県北九州市門司区丸山');
ok($zip->set_number('8010832')->is_valid_number, '福岡県北九州市門司区元清滝');
ok($zip->set_number('8010833')->is_valid_number, '福岡県北九州市門司区清滝');
ok($zip->set_number('8010834')->is_valid_number, '福岡県北九州市門司区本町');
ok($zip->set_number('8010841')->is_valid_number, '福岡県北九州市門司区西海岸');
ok($zip->set_number('8010842')->is_valid_number, '福岡県北九州市門司区広石');
ok($zip->set_number('8010851')->is_valid_number, '福岡県北九州市門司区東本町');
ok($zip->set_number('8010852')->is_valid_number, '福岡県北九州市門司区港町');
ok($zip->set_number('8010853')->is_valid_number, '福岡県北九州市門司区東港町');
ok($zip->set_number('8010854')->is_valid_number, '福岡県北九州市門司区旧門司');
ok($zip->set_number('8010855')->is_valid_number, '福岡県北九州市門司区門司');
ok($zip->set_number('8010856')->is_valid_number, '福岡県北九州市門司区浜町');
ok($zip->set_number('8010861')->is_valid_number, '福岡県北九州市門司区長谷');
ok($zip->set_number('8010862')->is_valid_number, '福岡県北九州市門司区錦町');
ok($zip->set_number('8010863')->is_valid_number, '福岡県北九州市門司区栄町');
ok($zip->set_number('8010864')->is_valid_number, '福岡県北九州市門司区老松町');
ok($zip->set_number('8010865')->is_valid_number, '福岡県北九州市門司区庄司町');
ok($zip->set_number('8010871')->is_valid_number, '福岡県北九州市門司区上本町');
ok($zip->set_number('8010872')->is_valid_number, '福岡県北九州市門司区谷町');
ok($zip->set_number('8010873')->is_valid_number, '福岡県北九州市門司区東門司');
ok($zip->set_number('8010874')->is_valid_number, '福岡県北九州市門司区畑田町');
ok($zip->set_number('8010875')->is_valid_number, '福岡県北九州市門司区法師庵');
ok($zip->set_number('8010876')->is_valid_number, '福岡県北九州市門司区花月園');
ok($zip->set_number('8010881')->is_valid_number, '福岡県北九州市門司区鳴竹');
ok($zip->set_number('8010882')->is_valid_number, '福岡県北九州市門司区清見');
ok($zip->set_number('8010883')->is_valid_number, '福岡県北九州市門司区大久保');
ok($zip->set_number('8010884')->is_valid_number, '福岡県北九州市門司区瀬戸町');
ok($zip->set_number('8010885')->is_valid_number, '福岡県北九州市門司区新開');
ok($zip->set_number('8010886')->is_valid_number, '福岡県北九州市門司区清見佐夜町');
ok($zip->set_number('8020000')->is_valid_number, '福岡県北九州市小倉北区以下に掲載がない場合');
ok($zip->set_number('8020000')->is_valid_number, '福岡県北九州市小倉南区以下に掲載がない場合');
ok($zip->set_number('8020001')->is_valid_number, '福岡県北九州市小倉北区浅野');
ok($zip->set_number('8020002')->is_valid_number, '福岡県北九州市小倉北区京町');
ok($zip->set_number('8020003')->is_valid_number, '福岡県北九州市小倉北区米町');
ok($zip->set_number('8020004')->is_valid_number, '福岡県北九州市小倉北区鍛冶町');
ok($zip->set_number('8020005')->is_valid_number, '福岡県北九州市小倉北区堺町');
ok($zip->set_number('8020006')->is_valid_number, '福岡県北九州市小倉北区魚町');
ok($zip->set_number('8020007')->is_valid_number, '福岡県北九州市小倉北区船場町');
ok($zip->set_number('8020008')->is_valid_number, '福岡県北九州市小倉北区船頭町');
ok($zip->set_number('8020011')->is_valid_number, '福岡県北九州市小倉北区重住');
ok($zip->set_number('8020012')->is_valid_number, '福岡県北九州市小倉北区末広');
ok($zip->set_number('8020013')->is_valid_number, '福岡県北九州市小倉北区長浜町');
ok($zip->set_number('8020014')->is_valid_number, '福岡県北九州市小倉北区砂津');
ok($zip->set_number('8020015')->is_valid_number, '福岡県北九州市小倉北区大田町');
ok($zip->set_number('8020016')->is_valid_number, '福岡県北九州市小倉北区宇佐町');
ok($zip->set_number('8020017')->is_valid_number, '福岡県北九州市小倉北区明和町');
ok($zip->set_number('8020018')->is_valid_number, '福岡県北九州市小倉北区中津口');
ok($zip->set_number('8020021')->is_valid_number, '福岡県北九州市小倉北区高浜');
ok($zip->set_number('8020022')->is_valid_number, '福岡県北九州市小倉北区上富野');
ok($zip->set_number('8020023')->is_valid_number, '福岡県北九州市小倉北区下富野');
ok($zip->set_number('8020024')->is_valid_number, '福岡県北九州市小倉北区山門町');
ok($zip->set_number('8020025')->is_valid_number, '福岡県北九州市小倉北区寿山町');
ok($zip->set_number('8020026')->is_valid_number, '福岡県北九州市小倉北区大畠');
ok($zip->set_number('8020031')->is_valid_number, '福岡県北九州市小倉北区赤坂海岸');
ok($zip->set_number('8020032')->is_valid_number, '福岡県北九州市小倉北区赤坂');
ok($zip->set_number('8020033')->is_valid_number, '福岡県北九州市小倉北区富野台');
ok($zip->set_number('8020034')->is_valid_number, '福岡県北九州市小倉北区須賀町');
ok($zip->set_number('8020035')->is_valid_number, '福岡県北九州市小倉北区常盤町');
ok($zip->set_number('8020036')->is_valid_number, '福岡県北九州市小倉北区富野');
ok($zip->set_number('8020037')->is_valid_number, '福岡県北九州市小倉北区小文字');
ok($zip->set_number('8020038')->is_valid_number, '福岡県北九州市小倉北区神幸町');
ok($zip->set_number('8020041')->is_valid_number, '福岡県北九州市小倉北区妙見町');
ok($zip->set_number('8020042')->is_valid_number, '福岡県北九州市小倉北区足立');
ok($zip->set_number('8020043')->is_valid_number, '福岡県北九州市小倉北区足原');
ok($zip->set_number('8020044')->is_valid_number, '福岡県北九州市小倉北区熊本');
ok($zip->set_number('8020045')->is_valid_number, '福岡県北九州市小倉北区神岳');
ok($zip->set_number('8020051')->is_valid_number, '福岡県北九州市小倉北区黒原');
ok($zip->set_number('8020052')->is_valid_number, '福岡県北九州市小倉北区霧ケ丘');
ok($zip->set_number('8020053')->is_valid_number, '福岡県北九州市小倉北区高坊');
ok($zip->set_number('8020054')->is_valid_number, '福岡県北九州市小倉北区東城野町');
ok($zip->set_number('8020055')->is_valid_number, '福岡県北九州市小倉北区城野団地');
ok($zip->set_number('8020056')->is_valid_number, '福岡県北九州市小倉北区黒住町');
ok($zip->set_number('8020061')->is_valid_number, '福岡県北九州市小倉北区三郎丸');
ok($zip->set_number('8020062')->is_valid_number, '福岡県北九州市小倉北区片野新町');
ok($zip->set_number('8020063')->is_valid_number, '福岡県北九州市小倉北区若富士町');
ok($zip->set_number('8020064')->is_valid_number, '福岡県北九州市小倉北区片野');
ok($zip->set_number('8020065')->is_valid_number, '福岡県北九州市小倉北区三萩野');
ok($zip->set_number('8020066')->is_valid_number, '福岡県北九州市小倉北区萩崎町');
ok($zip->set_number('8020071')->is_valid_number, '福岡県北九州市小倉北区黄金');
ok($zip->set_number('8020072')->is_valid_number, '福岡県北九州市小倉北区東篠崎');
ok($zip->set_number('8020073')->is_valid_number, '福岡県北九州市小倉北区貴船町');
ok($zip->set_number('8020074')->is_valid_number, '福岡県北九州市小倉北区白銀');
ok($zip->set_number('8020075')->is_valid_number, '福岡県北九州市小倉北区昭和町');
ok($zip->set_number('8020076')->is_valid_number, '福岡県北九州市小倉北区中島');
ok($zip->set_number('8020077')->is_valid_number, '福岡県北九州市小倉北区馬借');
ok($zip->set_number('8020081')->is_valid_number, '福岡県北九州市小倉北区紺屋町');
ok($zip->set_number('8020082')->is_valid_number, '福岡県北九州市小倉北区古船場町');
ok($zip->set_number('8020083')->is_valid_number, '福岡県北九州市小倉北区江南町');
ok($zip->set_number('8020084')->is_valid_number, '福岡県北九州市小倉北区香春口');
ok($zip->set_number('8020085')->is_valid_number, '福岡県北九州市小倉北区吉野町');
ok($zip->set_number('8020091')->is_valid_number, '福岡県北九州市小倉北区藍島');
ok($zip->set_number('8020092')->is_valid_number, '福岡県北九州市小倉北区馬島');
ok($zip->set_number('8020801')->is_valid_number, '福岡県北九州市小倉南区富士見');
ok($zip->set_number('8020802')->is_valid_number, '福岡県北九州市小倉南区城野');
ok($zip->set_number('8020803')->is_valid_number, '福岡県北九州市小倉南区春ケ丘');
ok($zip->set_number('8020804')->is_valid_number, '福岡県北九州市小倉南区下城野');
ok($zip->set_number('8020805')->is_valid_number, '福岡県北九州市小倉南区八幡町');
ok($zip->set_number('8020811')->is_valid_number, '福岡県北九州市小倉南区重住');
ok($zip->set_number('8020812')->is_valid_number, '福岡県北九州市小倉南区西水町');
ok($zip->set_number('8020813')->is_valid_number, '福岡県北九州市小倉南区東水町');
ok($zip->set_number('8020814')->is_valid_number, '福岡県北九州市小倉南区蜷田若園');
ok($zip->set_number('8020815')->is_valid_number, '福岡県北九州市小倉南区南若園町');
ok($zip->set_number('8020816')->is_valid_number, '福岡県北九州市小倉南区若園');
ok($zip->set_number('8020821')->is_valid_number, '福岡県北九州市小倉南区横代北町');
ok($zip->set_number('8020822')->is_valid_number, '福岡県北九州市小倉南区横代東町');
ok($zip->set_number('8020823')->is_valid_number, '福岡県北九州市小倉南区舞ケ丘');
ok($zip->set_number('8020824')->is_valid_number, '福岡県北九州市小倉南区横代');
ok($zip->set_number('8020825')->is_valid_number, '福岡県北九州市小倉南区横代葉山');
ok($zip->set_number('8020826')->is_valid_number, '福岡県北九州市小倉南区横代南町');
ok($zip->set_number('8020831')->is_valid_number, '福岡県北九州市小倉南区八重洲町');
ok($zip->set_number('8020832')->is_valid_number, '福岡県北九州市小倉南区下石田');
ok($zip->set_number('8020833')->is_valid_number, '福岡県北九州市小倉南区上石田');
ok($zip->set_number('8020834')->is_valid_number, '福岡県北九州市小倉南区隠蓑');
ok($zip->set_number('8020835')->is_valid_number, '福岡県北九州市小倉南区堀越');
ok($zip->set_number('8020836')->is_valid_number, '福岡県北九州市小倉南区石田南');
ok($zip->set_number('8020837')->is_valid_number, '福岡県北九州市小倉南区葉山町');
ok($zip->set_number('8020838')->is_valid_number, '福岡県北九州市小倉南区石田町');
ok($zip->set_number('8020841')->is_valid_number, '福岡県北九州市小倉南区北方');
ok($zip->set_number('8020842')->is_valid_number, '福岡県北九州市小倉南区日の出町');
ok($zip->set_number('8020971')->is_valid_number, '福岡県北九州市小倉南区守恒本町');
ok($zip->set_number('8020972')->is_valid_number, '福岡県北九州市小倉南区守恒');
ok($zip->set_number('8020973')->is_valid_number, '福岡県北九州市小倉南区星和台');
ok($zip->set_number('8020974')->is_valid_number, '福岡県北九州市小倉南区徳力');
ok($zip->set_number('8020975')->is_valid_number, '福岡県北九州市小倉南区徳力団地');
ok($zip->set_number('8020976')->is_valid_number, '福岡県北九州市小倉南区南方');
ok($zip->set_number('8020977')->is_valid_number, '福岡県北九州市小倉南区下南方');
ok($zip->set_number('8020978')->is_valid_number, '福岡県北九州市小倉南区蒲生');
ok($zip->set_number('8020979')->is_valid_number, '福岡県北九州市小倉南区徳力新町');
ok($zip->set_number('8020981')->is_valid_number, '福岡県北九州市小倉南区企救丘');
ok($zip->set_number('8020982')->is_valid_number, '福岡県北九州市小倉南区山手');
ok($zip->set_number('8020983')->is_valid_number, '福岡県北九州市小倉南区志徳');
ok($zip->set_number('8020984')->is_valid_number, '福岡県北九州市小倉南区志井公園');
ok($zip->set_number('8020985')->is_valid_number, '福岡県北九州市小倉南区志井');
ok($zip->set_number('8020986')->is_valid_number, '福岡県北九州市小倉南区志井鷹羽台');
ok($zip->set_number('8030180')->is_valid_number, '福岡県北九州市小倉南区平尾台');
ok($zip->set_number('8030181')->is_valid_number, '福岡県北九州市小倉南区呼野');
ok($zip->set_number('8030182')->is_valid_number, '福岡県北九州市小倉南区小森');
ok($zip->set_number('8030183')->is_valid_number, '福岡県北九州市小倉南区市丸');
ok($zip->set_number('8030184')->is_valid_number, '福岡県北九州市小倉南区木下');
ok($zip->set_number('8030185')->is_valid_number, '福岡県北九州市小倉南区石原町');
ok($zip->set_number('8030186')->is_valid_number, '福岡県北九州市小倉南区新道寺');
ok($zip->set_number('8030187')->is_valid_number, '福岡県北九州市小倉南区母原');
ok($zip->set_number('8030188')->is_valid_number, '福岡県北九州市小倉南区母原(紫水団地)');
ok($zip->set_number('8030189')->is_valid_number, '福岡県北九州市小倉南区井手浦');
ok($zip->set_number('8030261')->is_valid_number, '福岡県北九州市小倉南区合馬');
ok($zip->set_number('8030262')->is_valid_number, '福岡県北九州市小倉南区田代');
ok($zip->set_number('8030263')->is_valid_number, '福岡県北九州市小倉南区辻三');
ok($zip->set_number('8030264')->is_valid_number, '福岡県北九州市小倉南区山本');
ok($zip->set_number('8030265')->is_valid_number, '福岡県北九州市小倉南区春吉');
ok($zip->set_number('8030266')->is_valid_number, '福岡県北九州市小倉南区道原');
ok($zip->set_number('8030267')->is_valid_number, '福岡県北九州市小倉南区頂吉');
ok($zip->set_number('8030268')->is_valid_number, '福岡県北九州市小倉南区高津尾');
ok($zip->set_number('8030271')->is_valid_number, '福岡県北九州市小倉南区長行');
ok($zip->set_number('8030272')->is_valid_number, '福岡県北九州市小倉南区長行西');
ok($zip->set_number('8030273')->is_valid_number, '福岡県北九州市小倉南区長行東');
ok($zip->set_number('8030274')->is_valid_number, '福岡県北九州市小倉南区長尾');
ok($zip->set_number('8030275')->is_valid_number, '福岡県北九州市小倉南区高野');
ok($zip->set_number('8030276')->is_valid_number, '福岡県北九州市小倉南区徳吉');
ok($zip->set_number('8030277')->is_valid_number, '福岡県北九州市小倉南区徳吉東');
ok($zip->set_number('8030278')->is_valid_number, '福岡県北九州市小倉南区徳吉西');
ok($zip->set_number('8030279')->is_valid_number, '福岡県北九州市小倉南区徳吉南');
ok($zip->set_number('8030801')->is_valid_number, '福岡県北九州市小倉北区西港町');
ok($zip->set_number('8030802')->is_valid_number, '福岡県北九州市小倉北区東港');
ok($zip->set_number('8030803')->is_valid_number, '福岡県北九州市小倉北区許斐町');
ok($zip->set_number('8030804')->is_valid_number, '福岡県北九州市小倉北区中井浜');
ok($zip->set_number('8030805')->is_valid_number, '福岡県北九州市小倉北区親和町');
ok($zip->set_number('8030811')->is_valid_number, '福岡県北九州市小倉北区大門');
ok($zip->set_number('8030812')->is_valid_number, '福岡県北九州市小倉北区室町');
ok($zip->set_number('8030813')->is_valid_number, '福岡県北九州市小倉北区城内');
ok($zip->set_number('8030814')->is_valid_number, '福岡県北九州市小倉北区大手町');
ok($zip->set_number('8030815')->is_valid_number, '福岡県北九州市小倉北区原町');
ok($zip->set_number('8030816')->is_valid_number, '福岡県北九州市小倉北区金田');
ok($zip->set_number('8030817')->is_valid_number, '福岡県北九州市小倉北区田町');
ok($zip->set_number('8030818')->is_valid_number, '福岡県北九州市小倉北区竪町');
ok($zip->set_number('8030821')->is_valid_number, '福岡県北九州市小倉北区鋳物師町');
ok($zip->set_number('8030822')->is_valid_number, '福岡県北九州市小倉北区青葉');
ok($zip->set_number('8030823')->is_valid_number, '福岡県北九州市小倉北区菜園場');
ok($zip->set_number('8030824')->is_valid_number, '福岡県北九州市小倉北区板櫃町');
ok($zip->set_number('8030825')->is_valid_number, '福岡県北九州市小倉北区白萩町');
ok($zip->set_number('8030826')->is_valid_number, '福岡県北九州市小倉北区高峰町');
ok($zip->set_number('8030827')->is_valid_number, '福岡県北九州市小倉北区緑ケ丘');
ok($zip->set_number('8030828')->is_valid_number, '福岡県北九州市小倉北区愛宕');
ok($zip->set_number('8030831')->is_valid_number, '福岡県北九州市小倉北区日明');
ok($zip->set_number('8030832')->is_valid_number, '福岡県北九州市小倉北区平松町');
ok($zip->set_number('8030833')->is_valid_number, '福岡県北九州市小倉北区朝日ケ丘');
ok($zip->set_number('8030834')->is_valid_number, '福岡県北九州市小倉北区都');
ok($zip->set_number('8030835')->is_valid_number, '福岡県北九州市小倉北区井堀');
ok($zip->set_number('8030836')->is_valid_number, '福岡県北九州市小倉北区中井');
ok($zip->set_number('8030837')->is_valid_number, '福岡県北九州市小倉北区中井口');
ok($zip->set_number('8030838')->is_valid_number, '福岡県北九州市小倉北区高見台');
ok($zip->set_number('8030841')->is_valid_number, '福岡県北九州市小倉北区清水');
ok($zip->set_number('8030842')->is_valid_number, '福岡県北九州市小倉北区泉台');
ok($zip->set_number('8030843')->is_valid_number, '福岡県北九州市小倉北区金鶏町');
ok($zip->set_number('8030844')->is_valid_number, '福岡県北九州市小倉北区真鶴');
ok($zip->set_number('8030845')->is_valid_number, '福岡県北九州市小倉北区上到津');
ok($zip->set_number('8030846')->is_valid_number, '福岡県北九州市小倉北区下到津');
ok($zip->set_number('8030851')->is_valid_number, '福岡県北九州市小倉北区木町');
ok($zip->set_number('8030852')->is_valid_number, '福岡県北九州市小倉北区新高田');
ok($zip->set_number('8030853')->is_valid_number, '福岡県北九州市小倉北区高尾');
ok($zip->set_number('8030854')->is_valid_number, '福岡県北九州市小倉北区皿山町');
ok($zip->set_number('8030855')->is_valid_number, '福岡県北九州市小倉北区竪林町');
ok($zip->set_number('8030856')->is_valid_number, '福岡県北九州市小倉北区弁天町');
ok($zip->set_number('8030861')->is_valid_number, '福岡県北九州市小倉北区篠崎');
ok($zip->set_number('8030862')->is_valid_number, '福岡県北九州市小倉北区今町');
ok($zip->set_number('8030863')->is_valid_number, '福岡県北九州市小倉北区南丘');
ok($zip->set_number('8030864')->is_valid_number, '福岡県北九州市小倉北区熊谷');
ok($zip->set_number('8030865')->is_valid_number, '福岡県北九州市小倉北区山田町');
ok($zip->set_number('8040000')->is_valid_number, '福岡県北九州市戸畑区以下に掲載がない場合');
ok($zip->set_number('8040001')->is_valid_number, '福岡県北九州市戸畑区飛幡町');
ok($zip->set_number('8040002')->is_valid_number, '福岡県北九州市戸畑区中原(先の浜)');
ok($zip->set_number('8040003')->is_valid_number, '福岡県北九州市戸畑区中原新町');
ok($zip->set_number('8040004')->is_valid_number, '福岡県北九州市戸畑区戸畑');
ok($zip->set_number('8040011')->is_valid_number, '福岡県北九州市戸畑区中原西');
ok($zip->set_number('8040012')->is_valid_number, '福岡県北九州市戸畑区中原東');
ok($zip->set_number('8040013')->is_valid_number, '福岡県北九州市戸畑区境川');
ok($zip->set_number('8040014')->is_valid_number, '福岡県北九州市戸畑区土取町');
ok($zip->set_number('8040015')->is_valid_number, '福岡県北九州市戸畑区仙水町');
ok($zip->set_number('8040021')->is_valid_number, '福岡県北九州市戸畑区一枝');
ok($zip->set_number('8040022')->is_valid_number, '福岡県北九州市戸畑区金比羅町');
ok($zip->set_number('8040023')->is_valid_number, '福岡県北九州市戸畑区東鞘ケ谷町');
ok($zip->set_number('8040024')->is_valid_number, '福岡県北九州市戸畑区西鞘ケ谷町');
ok($zip->set_number('8040025')->is_valid_number, '福岡県北九州市戸畑区福柳木');
ok($zip->set_number('8040031')->is_valid_number, '福岡県北九州市戸畑区東大谷');
ok($zip->set_number('8040032')->is_valid_number, '福岡県北九州市戸畑区西大谷');
ok($zip->set_number('8040033')->is_valid_number, '福岡県北九州市戸畑区椎ノ木町');
ok($zip->set_number('8040041')->is_valid_number, '福岡県北九州市戸畑区天籟寺');
ok($zip->set_number('8040042')->is_valid_number, '福岡県北九州市戸畑区夜宮');
ok($zip->set_number('8040043')->is_valid_number, '福岡県北九州市戸畑区観音寺町');
ok($zip->set_number('8040044')->is_valid_number, '福岡県北九州市戸畑区菅原');
ok($zip->set_number('8040051')->is_valid_number, '福岡県北九州市戸畑区高峰');
ok($zip->set_number('8040052')->is_valid_number, '福岡県北九州市戸畑区丸町');
ok($zip->set_number('8040053')->is_valid_number, '福岡県北九州市戸畑区牧山');
ok($zip->set_number('8040054')->is_valid_number, '福岡県北九州市戸畑区牧山新町');
ok($zip->set_number('8040061')->is_valid_number, '福岡県北九州市戸畑区中本町');
ok($zip->set_number('8040062')->is_valid_number, '福岡県北九州市戸畑区浅生');
ok($zip->set_number('8040063')->is_valid_number, '福岡県北九州市戸畑区正津町');
ok($zip->set_number('8040064')->is_valid_number, '福岡県北九州市戸畑区沖台');
ok($zip->set_number('8040065')->is_valid_number, '福岡県北九州市戸畑区新川町');
ok($zip->set_number('8040066')->is_valid_number, '福岡県北九州市戸畑区初音町');
ok($zip->set_number('8040067')->is_valid_number, '福岡県北九州市戸畑区汐井町');
ok($zip->set_number('8040071')->is_valid_number, '福岡県北九州市戸畑区川代');
ok($zip->set_number('8040072')->is_valid_number, '福岡県北九州市戸畑区元宮町');
ok($zip->set_number('8040073')->is_valid_number, '福岡県北九州市戸畑区明治町');
ok($zip->set_number('8040074')->is_valid_number, '福岡県北九州市戸畑区南鳥旗町');
ok($zip->set_number('8040075')->is_valid_number, '福岡県北九州市戸畑区北鳥旗町');
ok($zip->set_number('8040076')->is_valid_number, '福岡県北九州市戸畑区銀座');
ok($zip->set_number('8040077')->is_valid_number, '福岡県北九州市戸畑区牧山海岸');
ok($zip->set_number('8040081')->is_valid_number, '福岡県北九州市戸畑区千防');
ok($zip->set_number('8040082')->is_valid_number, '福岡県北九州市戸畑区新池');
ok($zip->set_number('8040083')->is_valid_number, '福岡県北九州市戸畑区旭町');
ok($zip->set_number('8040084')->is_valid_number, '福岡県北九州市戸畑区幸町');
ok($zip->set_number('8040091')->is_valid_number, '福岡県北九州市戸畑区三六町');
ok($zip->set_number('8040092')->is_valid_number, '福岡県北九州市戸畑区小芝');
ok($zip->set_number('8040093')->is_valid_number, '福岡県北九州市戸畑区沢見');
ok($zip->set_number('8040094')->is_valid_number, '福岡県北九州市戸畑区天神');
ok($zip->set_number('8050000')->is_valid_number, '福岡県北九州市八幡東区以下に掲載がない場合');
ok($zip->set_number('8050001')->is_valid_number, '福岡県北九州市八幡東区荒手');
ok($zip->set_number('8050002')->is_valid_number, '福岡県北九州市八幡東区枝光');
ok($zip->set_number('8050003')->is_valid_number, '福岡県北九州市八幡東区大宮町');
ok($zip->set_number('8050004')->is_valid_number, '福岡県北九州市八幡東区日の出');
ok($zip->set_number('8050005')->is_valid_number, '福岡県北九州市八幡東区藤見町');
ok($zip->set_number('8050006')->is_valid_number, '福岡県北九州市八幡東区諏訪');
ok($zip->set_number('8050007')->is_valid_number, '福岡県北九州市八幡東区白川町');
ok($zip->set_number('8050008')->is_valid_number, '福岡県北九州市八幡東区枝光本町');
ok($zip->set_number('8050009')->is_valid_number, '福岡県北九州市八幡東区宮田町');
ok($zip->set_number('8050011')->is_valid_number, '福岡県北九州市八幡東区八王寺町');
ok($zip->set_number('8050012')->is_valid_number, '福岡県北九州市八幡東区川淵町');
ok($zip->set_number('8050013')->is_valid_number, '福岡県北九州市八幡東区昭和');
ok($zip->set_number('8050014')->is_valid_number, '福岡県北九州市八幡東区茶屋町');
ok($zip->set_number('8050015')->is_valid_number, '福岡県北九州市八幡東区荒生田');
ok($zip->set_number('8050016')->is_valid_number, '福岡県北九州市八幡東区高見');
ok($zip->set_number('8050017')->is_valid_number, '福岡県北九州市八幡東区山王');
ok($zip->set_number('8050018')->is_valid_number, '福岡県北九州市八幡東区上本町');
ok($zip->set_number('8050019')->is_valid_number, '福岡県北九州市八幡東区中央');
ok($zip->set_number('8050021')->is_valid_number, '福岡県北九州市八幡東区石坪町');
ok($zip->set_number('8050022')->is_valid_number, '福岡県北九州市八幡東区竹下町');
ok($zip->set_number('8050023')->is_valid_number, '福岡県北九州市八幡東区宮の町');
ok($zip->set_number('8050024')->is_valid_number, '福岡県北九州市八幡東区中畑');
ok($zip->set_number('8050025')->is_valid_number, '福岡県北九州市八幡東区中尾');
ok($zip->set_number('8050026')->is_valid_number, '福岡県北九州市八幡東区東山');
ok($zip->set_number('8050027')->is_valid_number, '福岡県北九州市八幡東区東鉄町');
ok($zip->set_number('8050031')->is_valid_number, '福岡県北九州市八幡東区槻田');
ok($zip->set_number('8050032')->is_valid_number, '福岡県北九州市八幡東区松尾町');
ok($zip->set_number('8050033')->is_valid_number, '福岡県北九州市八幡東区山路松尾町');
ok($zip->set_number('8050034')->is_valid_number, '福岡県北九州市八幡東区清田');
ok($zip->set_number('8050035')->is_valid_number, '福岡県北九州市八幡東区山路');
ok($zip->set_number('8050036')->is_valid_number, '福岡県北九州市八幡東区小熊野');
ok($zip->set_number('8050037')->is_valid_number, '福岡県北九州市八幡東区猪倉町');
ok($zip->set_number('8050038')->is_valid_number, '福岡県北九州市八幡東区大平町');
ok($zip->set_number('8050041')->is_valid_number, '福岡県北九州市八幡東区祝町');
ok($zip->set_number('8050042')->is_valid_number, '福岡県北九州市八幡東区羽衣町');
ok($zip->set_number('8050043')->is_valid_number, '福岡県北九州市八幡東区勝山');
ok($zip->set_number('8050044')->is_valid_number, '福岡県北九州市八幡東区豊町');
ok($zip->set_number('8050045')->is_valid_number, '福岡県北九州市八幡東区河内');
ok($zip->set_number('8050046')->is_valid_number, '福岡県北九州市八幡東区田代');
ok($zip->set_number('8050047')->is_valid_number, '福岡県北九州市八幡東区景勝町');
ok($zip->set_number('8050048')->is_valid_number, '福岡県北九州市八幡東区大蔵');
ok($zip->set_number('8050049')->is_valid_number, '福岡県北九州市八幡東区末広町');
ok($zip->set_number('8050050')->is_valid_number, '福岡県北九州市八幡東区春の町');
ok($zip->set_number('8050051')->is_valid_number, '福岡県北九州市八幡東区東丸山町');
ok($zip->set_number('8050052')->is_valid_number, '福岡県北九州市八幡東区西丸山町');
ok($zip->set_number('8050053')->is_valid_number, '福岡県北九州市八幡東区大谷');
ok($zip->set_number('8050054')->is_valid_number, '福岡県北九州市八幡東区天神町');
ok($zip->set_number('8050055')->is_valid_number, '福岡県北九州市八幡東区神山町');
ok($zip->set_number('8050056')->is_valid_number, '福岡県北九州市八幡東区帆柱');
ok($zip->set_number('8050057')->is_valid_number, '福岡県北九州市八幡東区尾倉(大字)');
ok($zip->set_number('8050058')->is_valid_number, '福岡県北九州市八幡東区前田(大字)');
ok($zip->set_number('8050059')->is_valid_number, '福岡県北九州市八幡東区尾倉(丁目)');
ok($zip->set_number('8050061')->is_valid_number, '福岡県北九州市八幡東区西本町');
ok($zip->set_number('8050062')->is_valid_number, '福岡県北九州市八幡東区平野');
ok($zip->set_number('8050063')->is_valid_number, '福岡県北九州市八幡東区東台良町');
ok($zip->set_number('8050064')->is_valid_number, '福岡県北九州市八幡東区西台良町');
ok($zip->set_number('8050065')->is_valid_number, '福岡県北九州市八幡東区花尾町');
ok($zip->set_number('8050066')->is_valid_number, '福岡県北九州市八幡東区祇園原町');
ok($zip->set_number('8050067')->is_valid_number, '福岡県北九州市八幡東区祇園');
ok($zip->set_number('8050068')->is_valid_number, '福岡県北九州市八幡東区桃園');
ok($zip->set_number('8050069')->is_valid_number, '福岡県北九州市八幡東区前田(丁目)');
ok($zip->set_number('8050071')->is_valid_number, '福岡県北九州市八幡東区東田');
ok($zip->set_number('8060000')->is_valid_number, '福岡県北九州市八幡西区以下に掲載がない場合');
ok($zip->set_number('8060001')->is_valid_number, '福岡県北九州市八幡西区築地町');
ok($zip->set_number('8060002')->is_valid_number, '福岡県北九州市八幡西区東浜町');
ok($zip->set_number('8060003')->is_valid_number, '福岡県北九州市八幡西区田町');
ok($zip->set_number('8060004')->is_valid_number, '福岡県北九州市八幡西区黒崎城石');
ok($zip->set_number('8060005')->is_valid_number, '福岡県北九州市八幡西区舟町');
ok($zip->set_number('8060006')->is_valid_number, '福岡県北九州市八幡西区屋敷');
ok($zip->set_number('8060011')->is_valid_number, '福岡県北九州市八幡西区紅梅');
ok($zip->set_number('8060012')->is_valid_number, '福岡県北九州市八幡西区陣山');
ok($zip->set_number('8060013')->is_valid_number, '福岡県北九州市八幡西区清納');
ok($zip->set_number('8060014')->is_valid_number, '福岡県北九州市八幡西区東川頭町');
ok($zip->set_number('8060015')->is_valid_number, '福岡県北九州市八幡西区元城町');
ok($zip->set_number('8060016')->is_valid_number, '福岡県北九州市八幡西区河桃町');
ok($zip->set_number('8060017')->is_valid_number, '福岡県北九州市八幡西区西川頭町');
ok($zip->set_number('8060018')->is_valid_number, '福岡県北九州市八幡西区平尾町');
ok($zip->set_number('8060021')->is_valid_number, '福岡県北九州市八幡西区黒崎');
ok($zip->set_number('8060022')->is_valid_number, '福岡県北九州市八幡西区藤田');
ok($zip->set_number('8060023')->is_valid_number, '福岡県北九州市八幡西区八千代町');
ok($zip->set_number('8060024')->is_valid_number, '福岡県北九州市八幡西区南八千代町');
ok($zip->set_number('8060025')->is_valid_number, '福岡県北九州市八幡西区東神原町');
ok($zip->set_number('8060026')->is_valid_number, '福岡県北九州市八幡西区西神原町');
ok($zip->set_number('8060027')->is_valid_number, '福岡県北九州市八幡西区菅原町');
ok($zip->set_number('8060028')->is_valid_number, '福岡県北九州市八幡西区熊手');
ok($zip->set_number('8060030')->is_valid_number, '福岡県北九州市八幡西区山寺町');
ok($zip->set_number('8060031')->is_valid_number, '福岡県北九州市八幡西区熊西');
ok($zip->set_number('8060032')->is_valid_number, '福岡県北九州市八幡西区筒井町');
ok($zip->set_number('8060033')->is_valid_number, '福岡県北九州市八幡西区岡田町');
ok($zip->set_number('8060034')->is_valid_number, '福岡県北九州市八幡西区岸の浦');
ok($zip->set_number('8060035')->is_valid_number, '福岡県北九州市八幡西区東曲里町');
ok($zip->set_number('8060036')->is_valid_number, '福岡県北九州市八幡西区西曲里町');
ok($zip->set_number('8060037')->is_valid_number, '福岡県北九州市八幡西区東王子町');
ok($zip->set_number('8060038')->is_valid_number, '福岡県北九州市八幡西区南王子町');
ok($zip->set_number('8060039')->is_valid_number, '福岡県北九州市八幡西区西王子町');
ok($zip->set_number('8060041')->is_valid_number, '福岡県北九州市八幡西区皇后崎町');
ok($zip->set_number('8060042')->is_valid_number, '福岡県北九州市八幡西区桜ケ丘町');
ok($zip->set_number('8060043')->is_valid_number, '福岡県北九州市八幡西区青山');
ok($zip->set_number('8060044')->is_valid_number, '福岡県北九州市八幡西区相生町');
ok($zip->set_number('8060045')->is_valid_number, '福岡県北九州市八幡西区竹末');
ok($zip->set_number('8060046')->is_valid_number, '福岡県北九州市八幡西区森下町');
ok($zip->set_number('8060047')->is_valid_number, '福岡県北九州市八幡西区鷹の巣');
ok($zip->set_number('8060048')->is_valid_number, '福岡県北九州市八幡西区樋口町');
ok($zip->set_number('8060049')->is_valid_number, '福岡県北九州市八幡西区穴生');
ok($zip->set_number('8060051')->is_valid_number, '福岡県北九州市八幡西区東鳴水');
ok($zip->set_number('8060052')->is_valid_number, '福岡県北九州市八幡西区鳴水町');
ok($zip->set_number('8060053')->is_valid_number, '福岡県北九州市八幡西区大畑町');
ok($zip->set_number('8060054')->is_valid_number, '福岡県北九州市八幡西区西鳴水');
ok($zip->set_number('8060055')->is_valid_number, '福岡県北九州市八幡西区幸神');
ok($zip->set_number('8060056')->is_valid_number, '福岡県北九州市八幡西区小鷺田町');
ok($zip->set_number('8060057')->is_valid_number, '福岡県北九州市八幡西区鉄王');
ok($zip->set_number('8060058')->is_valid_number, '福岡県北九州市八幡西区鉄竜');
ok($zip->set_number('8060059')->is_valid_number, '福岡県北九州市八幡西区萩原');
ok($zip->set_number('8060061')->is_valid_number, '福岡県北九州市八幡西区京良城町');
ok($zip->set_number('8060062')->is_valid_number, '福岡県北九州市八幡西区別当町');
ok($zip->set_number('8060063')->is_valid_number, '福岡県北九州市八幡西区市瀬');
ok($zip->set_number('8060064')->is_valid_number, '福岡県北九州市八幡西区割子川');
ok($zip->set_number('8060065')->is_valid_number, '福岡県北九州市八幡西区養福寺町');
ok($zip->set_number('8060066')->is_valid_number, '福岡県北九州市八幡西区若葉');
ok($zip->set_number('8060067')->is_valid_number, '福岡県北九州市八幡西区引野');
ok($zip->set_number('8060068')->is_valid_number, '福岡県北九州市八幡西区別所町');
ok($zip->set_number('8060069')->is_valid_number, '福岡県北九州市八幡西区茶売町');
ok($zip->set_number('8070000')->is_valid_number, '福岡県遠賀郡水巻町以下に掲載がない場合');
ok($zip->set_number('8070001')->is_valid_number, '福岡県遠賀郡水巻町猪熊');
ok($zip->set_number('8070002')->is_valid_number, '福岡県遠賀郡水巻町樋口');
ok($zip->set_number('8070003')->is_valid_number, '福岡県遠賀郡水巻町おかの台');
ok($zip->set_number('8070004')->is_valid_number, '福岡県遠賀郡水巻町樋口東');
ok($zip->set_number('8070005')->is_valid_number, '福岡県遠賀郡水巻町高松');
ok($zip->set_number('8070006')->is_valid_number, '福岡県遠賀郡水巻町梅ノ木団地');
ok($zip->set_number('8070007')->is_valid_number, '福岡県遠賀郡水巻町牟田');
ok($zip->set_number('8070011')->is_valid_number, '福岡県遠賀郡水巻町緑ケ丘');
ok($zip->set_number('8070012')->is_valid_number, '福岡県遠賀郡水巻町古賀');
ok($zip->set_number('8070021')->is_valid_number, '福岡県遠賀郡水巻町頃末');
ok($zip->set_number('8070022')->is_valid_number, '福岡県遠賀郡水巻町頃末北');
ok($zip->set_number('8070023')->is_valid_number, '福岡県遠賀郡水巻町中央');
ok($zip->set_number('8070024')->is_valid_number, '福岡県遠賀郡水巻町高尾');
ok($zip->set_number('8070025')->is_valid_number, '福岡県遠賀郡水巻町頃末南');
ok($zip->set_number('8070031')->is_valid_number, '福岡県遠賀郡水巻町えぶり');
ok($zip->set_number('8070041')->is_valid_number, '福岡県遠賀郡水巻町宮尾台');
ok($zip->set_number('8070042')->is_valid_number, '福岡県遠賀郡水巻町吉田');
ok($zip->set_number('8070042')->is_valid_number, '福岡県遠賀郡水巻町吉田団地');
ok($zip->set_number('8070043')->is_valid_number, '福岡県遠賀郡水巻町下二');
ok($zip->set_number('8070044')->is_valid_number, '福岡県遠賀郡水巻町美吉野');
ok($zip->set_number('8070045')->is_valid_number, '福岡県遠賀郡水巻町吉田東');
ok($zip->set_number('8070046')->is_valid_number, '福岡県遠賀郡水巻町吉田西');
ok($zip->set_number('8070047')->is_valid_number, '福岡県遠賀郡水巻町鯉口');
ok($zip->set_number('8070048')->is_valid_number, '福岡県遠賀郡水巻町吉田南');
ok($zip->set_number('8070051')->is_valid_number, '福岡県遠賀郡水巻町立屋敷');
ok($zip->set_number('8070052')->is_valid_number, '福岡県遠賀郡水巻町下二西');
ok($zip->set_number('8070053')->is_valid_number, '福岡県遠賀郡水巻町下二東');
ok($zip->set_number('8070054')->is_valid_number, '福岡県遠賀郡水巻町二東');
ok($zip->set_number('8070055')->is_valid_number, '福岡県遠賀郡水巻町二西');
ok($zip->set_number('8070056')->is_valid_number, '福岡県遠賀郡水巻町伊左座');
ok($zip->set_number('8070071')->is_valid_number, '福岡県北九州市八幡西区上の原');
ok($zip->set_number('8070072')->is_valid_number, '福岡県北九州市八幡西区上上津役');
ok($zip->set_number('8070073')->is_valid_number, '福岡県北九州市八幡西区町上津役東');
ok($zip->set_number('8070074')->is_valid_number, '福岡県北九州市八幡西区町上津役西');
ok($zip->set_number('8070075')->is_valid_number, '福岡県北九州市八幡西区下上津役');
ok($zip->set_number('8070076')->is_valid_number, '福岡県北九州市八幡西区下上津役元町');
ok($zip->set_number('8070077')->is_valid_number, '福岡県北九州市八幡西区沖田');
ok($zip->set_number('8070078')->is_valid_number, '福岡県北九州市八幡西区中の原');
ok($zip->set_number('8070081')->is_valid_number, '福岡県北九州市八幡西区小嶺');
ok($zip->set_number('8070082')->is_valid_number, '福岡県北九州市八幡西区小嶺台');
ok($zip->set_number('8070083')->is_valid_number, '福岡県北九州市八幡西区大平');
ok($zip->set_number('8070084')->is_valid_number, '福岡県北九州市八幡西区大平台');
ok($zip->set_number('8070085')->is_valid_number, '福岡県北九州市八幡西区塔野');
ok($zip->set_number('8070100')->is_valid_number, '福岡県遠賀郡芦屋町以下に掲載がない場合');
ok($zip->set_number('8070101')->is_valid_number, '福岡県遠賀郡芦屋町幸町');
ok($zip->set_number('8070102')->is_valid_number, '福岡県遠賀郡芦屋町西浜町');
ok($zip->set_number('8070111')->is_valid_number, '福岡県遠賀郡芦屋町白浜町');
ok($zip->set_number('8070112')->is_valid_number, '福岡県遠賀郡芦屋町正門町');
ok($zip->set_number('8070113')->is_valid_number, '福岡県遠賀郡芦屋町中ノ浜');
ok($zip->set_number('8070121')->is_valid_number, '福岡県遠賀郡芦屋町船頭町');
ok($zip->set_number('8070122')->is_valid_number, '福岡県遠賀郡芦屋町高浜町');
ok($zip->set_number('8070123')->is_valid_number, '福岡県遠賀郡芦屋町祇園町');
ok($zip->set_number('8070131')->is_valid_number, '福岡県遠賀郡芦屋町緑ケ丘');
ok($zip->set_number('8070132')->is_valid_number, '福岡県遠賀郡芦屋町浜口町');
ok($zip->set_number('8070133')->is_valid_number, '福岡県遠賀郡芦屋町芦屋');
ok($zip->set_number('8070141')->is_valid_number, '福岡県遠賀郡芦屋町山鹿');
ok($zip->set_number('8070142')->is_valid_number, '福岡県遠賀郡芦屋町江川台');
ok($zip->set_number('8070143')->is_valid_number, '福岡県遠賀郡芦屋町花美坂');
ok($zip->set_number('8070801')->is_valid_number, '福岡県北九州市八幡西区本城');
ok($zip->set_number('8070802')->is_valid_number, '福岡県北九州市八幡西区力丸町');
ok($zip->set_number('8070803')->is_valid_number, '福岡県北九州市八幡西区千代ケ崎');
ok($zip->set_number('8070804')->is_valid_number, '福岡県北九州市八幡西区医生ケ丘');
ok($zip->set_number('8070805')->is_valid_number, '福岡県北九州市八幡西区光貞台');
ok($zip->set_number('8070806')->is_valid_number, '福岡県北九州市八幡西区御開');
ok($zip->set_number('8070807')->is_valid_number, '福岡県北九州市八幡西区本城学研台');
ok($zip->set_number('8070811')->is_valid_number, '福岡県北九州市八幡西区洞北町');
ok($zip->set_number('8070812')->is_valid_number, '福岡県北九州市八幡西区洞南町');
ok($zip->set_number('8070813')->is_valid_number, '福岡県北九州市八幡西区夕原町');
ok($zip->set_number('8070814')->is_valid_number, '福岡県北九州市八幡西区貴船台');
ok($zip->set_number('8070815')->is_valid_number, '福岡県北九州市八幡西区本城東');
ok($zip->set_number('8070821')->is_valid_number, '福岡県北九州市八幡西区陣原');
ok($zip->set_number('8070822')->is_valid_number, '福岡県北九州市八幡西区瀬板');
ok($zip->set_number('8070823')->is_valid_number, '福岡県北九州市八幡西区中須');
ok($zip->set_number('8070824')->is_valid_number, '福岡県北九州市八幡西区光明');
ok($zip->set_number('8070825')->is_valid_number, '福岡県北九州市八幡西区折尾(丁目)');
ok($zip->set_number('8070826')->is_valid_number, '福岡県北九州市八幡西区丸尾町');
ok($zip->set_number('8070827')->is_valid_number, '福岡県北九州市八幡西区楠木');
ok($zip->set_number('8070828')->is_valid_number, '福岡県北九州市八幡西区友田');
ok($zip->set_number('8070829')->is_valid_number, '福岡県北九州市八幡西区星和町');
ok($zip->set_number('8070831')->is_valid_number, '福岡県北九州市八幡西区則松');
ok($zip->set_number('8070832')->is_valid_number, '福岡県北九州市八幡西区東筑');
ok($zip->set_number('8070833')->is_valid_number, '福岡県北九州市八幡西区南鷹見町');
ok($zip->set_number('8070834')->is_valid_number, '福岡県北九州市八幡西区北鷹見町');
ok($zip->set_number('8070835')->is_valid_number, '福岡県北九州市八幡西区東折尾町');
ok($zip->set_number('8070836')->is_valid_number, '福岡県北九州市八幡西区長崎町');
ok($zip->set_number('8070837')->is_valid_number, '福岡県北九州市八幡西区則松東');
ok($zip->set_number('8070841')->is_valid_number, '福岡県北九州市八幡西区的場町');
ok($zip->set_number('8070842')->is_valid_number, '福岡県北九州市八幡西区永犬丸東町');
ok($zip->set_number('8070843')->is_valid_number, '福岡県北九州市八幡西区三ケ森');
ok($zip->set_number('8070844')->is_valid_number, '福岡県北九州市八幡西区春日台');
ok($zip->set_number('8070845')->is_valid_number, '福岡県北九州市八幡西区永犬丸南町');
ok($zip->set_number('8070846')->is_valid_number, '福岡県北九州市八幡西区里中');
ok($zip->set_number('8070847')->is_valid_number, '福岡県北九州市八幡西区美原町');
ok($zip->set_number('8070851')->is_valid_number, '福岡県北九州市八幡西区永犬丸');
ok($zip->set_number('8070852')->is_valid_number, '福岡県北九州市八幡西区永犬丸西町');
ok($zip->set_number('8070853')->is_valid_number, '福岡県北九州市八幡西区鷹見台');
ok($zip->set_number('8070854')->is_valid_number, '福岡県北九州市八幡西区泉ケ浦');
ok($zip->set_number('8070855')->is_valid_number, '福岡県北九州市八幡西区松寿山');
ok($zip->set_number('8070856')->is_valid_number, '福岡県北九州市八幡西区八枝');
ok($zip->set_number('8070857')->is_valid_number, '福岡県北九州市八幡西区北筑');
ok($zip->set_number('8070861')->is_valid_number, '福岡県北九州市八幡西区堀川町');
ok($zip->set_number('8070862')->is_valid_number, '福岡県北九州市八幡西区西折尾町');
ok($zip->set_number('8070863')->is_valid_number, '福岡県北九州市八幡西区大膳');
ok($zip->set_number('8070864')->is_valid_number, '福岡県北九州市八幡西区折尾(番地)');
ok($zip->set_number('8070865')->is_valid_number, '福岡県北九州市八幡西区美吉野町');
ok($zip->set_number('8070866')->is_valid_number, '福岡県北九州市八幡西区日吉台');
ok($zip->set_number('8070867')->is_valid_number, '福岡県北九州市八幡西区自由ケ丘');
ok($zip->set_number('8070868')->is_valid_number, '福岡県北九州市八幡西区さつき台');
ok($zip->set_number('8070871')->is_valid_number, '福岡県北九州市八幡西区浅川学園台');
ok($zip->set_number('8070872')->is_valid_number, '福岡県北九州市八幡西区浅川(丁目)');
ok($zip->set_number('8070873')->is_valid_number, '福岡県北九州市八幡西区藤原');
ok($zip->set_number('8070874')->is_valid_number, '福岡県北九州市八幡西区大浦');
ok($zip->set_number('8070875')->is_valid_number, '福岡県北九州市八幡西区浅川台');
ok($zip->set_number('8070876')->is_valid_number, '福岡県北九州市八幡西区浅川日の峯');
ok($zip->set_number('8070877')->is_valid_number, '福岡県北九州市八幡西区浅川(番地)');
ok($zip->set_number('8070878')->is_valid_number, '福岡県北九州市八幡西区三ツ頭');
ok($zip->set_number('8070879')->is_valid_number, '福岡県北九州市八幡西区浅川町');
ok($zip->set_number('8071101')->is_valid_number, '福岡県北九州市八幡西区上香月');
ok($zip->set_number('8071102')->is_valid_number, '福岡県北九州市八幡西区香月中央');
ok($zip->set_number('8071103')->is_valid_number, '福岡県北九州市八幡西区香月西');
ok($zip->set_number('8071111')->is_valid_number, '福岡県北九州市八幡西区船越');
ok($zip->set_number('8071112')->is_valid_number, '福岡県北九州市八幡西区千代');
ok($zip->set_number('8071113')->is_valid_number, '福岡県北九州市八幡西区白岩町');
ok($zip->set_number('8071114')->is_valid_number, '福岡県北九州市八幡西区吉祥寺町');
ok($zip->set_number('8071115')->is_valid_number, '福岡県北九州市八幡西区椋枝');
ok($zip->set_number('8071121')->is_valid_number, '福岡県北九州市八幡西区石坂');
ok($zip->set_number('8071122')->is_valid_number, '福岡県北九州市八幡西区東石坂町');
ok($zip->set_number('8071123')->is_valid_number, '福岡県北九州市八幡西区下畑町');
ok($zip->set_number('8071124')->is_valid_number, '福岡県北九州市八幡西区畑');
ok($zip->set_number('8071125')->is_valid_number, '福岡県北九州市八幡西区池田');
ok($zip->set_number('8071131')->is_valid_number, '福岡県北九州市八幡西区馬場山東');
ok($zip->set_number('8071132')->is_valid_number, '福岡県北九州市八幡西区馬場山西');
ok($zip->set_number('8071133')->is_valid_number, '福岡県北九州市八幡西区馬場山緑');
ok($zip->set_number('8071134')->is_valid_number, '福岡県北九州市八幡西区茶屋の原');
ok($zip->set_number('8071135')->is_valid_number, '福岡県北九州市八幡西区馬場山原');
ok($zip->set_number('8071136')->is_valid_number, '福岡県北九州市八幡西区馬場山');
ok($zip->set_number('8071141')->is_valid_number, '福岡県北九州市八幡西区楠橋上方');
ok($zip->set_number('8071142')->is_valid_number, '福岡県北九州市八幡西区楠橋東');
ok($zip->set_number('8071143')->is_valid_number, '福岡県北九州市八幡西区楠橋南');
ok($zip->set_number('8071144')->is_valid_number, '福岡県北九州市八幡西区真名子');
ok($zip->set_number('8071145')->is_valid_number, '福岡県北九州市八幡西区楠橋西');
ok($zip->set_number('8071146')->is_valid_number, '福岡県北九州市八幡西区楠橋下方');
ok($zip->set_number('8071151')->is_valid_number, '福岡県北九州市八幡西区楠橋');
ok($zip->set_number('8071152')->is_valid_number, '福岡県北九州市八幡西区高江');
ok($zip->set_number('8071153')->is_valid_number, '福岡県北九州市八幡西区岩崎');
ok($zip->set_number('8071154')->is_valid_number, '福岡県北九州市八幡西区楠北');
ok($zip->set_number('8071261')->is_valid_number, '福岡県北九州市八幡西区木屋瀬');
ok($zip->set_number('8071262')->is_valid_number, '福岡県北九州市八幡西区野面');
ok($zip->set_number('8071263')->is_valid_number, '福岡県北九州市八幡西区金剛');
ok($zip->set_number('8071264')->is_valid_number, '福岡県北九州市八幡西区星ケ丘');
ok($zip->set_number('8071265')->is_valid_number, '福岡県北九州市八幡西区笹田');
ok($zip->set_number('8071266')->is_valid_number, '福岡県北九州市八幡西区木屋瀬東');
ok($zip->set_number('8071300')->is_valid_number, '福岡県鞍手郡鞍手町以下に掲載がない場合');
ok($zip->set_number('8071301')->is_valid_number, '福岡県鞍手郡鞍手町猪倉');
ok($zip->set_number('8071302')->is_valid_number, '福岡県鞍手郡鞍手町上木月');
ok($zip->set_number('8071303')->is_valid_number, '福岡県鞍手郡鞍手町木月');
ok($zip->set_number('8071304')->is_valid_number, '福岡県鞍手郡鞍手町永谷');
ok($zip->set_number('8071305')->is_valid_number, '福岡県鞍手郡鞍手町新延');
ok($zip->set_number('8071306')->is_valid_number, '福岡県鞍手郡鞍手町古門');
ok($zip->set_number('8071307')->is_valid_number, '福岡県鞍手郡鞍手町室木');
ok($zip->set_number('8071308')->is_valid_number, '福岡県鞍手郡鞍手町八尋');
ok($zip->set_number('8071311')->is_valid_number, '福岡県鞍手郡鞍手町小牧');
ok($zip->set_number('8071312')->is_valid_number, '福岡県鞍手郡鞍手町中山');
ok($zip->set_number('8071313')->is_valid_number, '福岡県鞍手郡鞍手町新北');
ok($zip->set_number('8071314')->is_valid_number, '福岡県鞍手郡鞍手町長谷');
ok($zip->set_number('8071315')->is_valid_number, '福岡県鞍手郡鞍手町弥生');
ok($zip->set_number('8080000')->is_valid_number, '福岡県北九州市若松区以下に掲載がない場合');
ok($zip->set_number('8080001')->is_valid_number, '福岡県北九州市若松区小石本村町');
ok($zip->set_number('8080002')->is_valid_number, '福岡県北九州市若松区向洋町');
ok($zip->set_number('8080003')->is_valid_number, '福岡県北九州市若松区赤崎町');
ok($zip->set_number('8080004')->is_valid_number, '福岡県北九州市若松区西小石町');
ok($zip->set_number('8080005')->is_valid_number, '福岡県北九州市若松区下原町');
ok($zip->set_number('8080006')->is_valid_number, '福岡県北九州市若松区宮前町');
ok($zip->set_number('8080007')->is_valid_number, '福岡県北九州市若松区小石');
ok($zip->set_number('8080008')->is_valid_number, '福岡県北九州市若松区小竹(1~1953、3006~3008番地、相川、鬼ケ坂、唐木、');
ok($zip->set_number('8080008')->is_valid_number, '福岡県北九州市若松区椿、脇ノ浦)');
ok($zip->set_number('8080011')->is_valid_number, '福岡県北九州市若松区響南町');
ok($zip->set_number('8080012')->is_valid_number, '福岡県北九州市若松区深町');
ok($zip->set_number('8080013')->is_valid_number, '福岡県北九州市若松区波打町');
ok($zip->set_number('8080014')->is_valid_number, '福岡県北九州市若松区栄盛川町');
ok($zip->set_number('8080015')->is_valid_number, '福岡県北九州市若松区上原町');
ok($zip->set_number('8080016')->is_valid_number, '福岡県北九州市若松区原町');
ok($zip->set_number('8080017')->is_valid_number, '福岡県北九州市若松区東小石町');
ok($zip->set_number('8080021')->is_valid_number, '福岡県北九州市若松区響町');
ok($zip->set_number('8080022')->is_valid_number, '福岡県北九州市若松区安瀬');
ok($zip->set_number('8080023')->is_valid_number, '福岡県北九州市若松区北浜');
ok($zip->set_number('8080024')->is_valid_number, '福岡県北九州市若松区浜町');
ok($zip->set_number('8080025')->is_valid_number, '福岡県北九州市若松区中川町');
ok($zip->set_number('8080026')->is_valid_number, '福岡県北九州市若松区桜町');
ok($zip->set_number('8080027')->is_valid_number, '福岡県北九州市若松区北湊町');
ok($zip->set_number('8080031')->is_valid_number, '福岡県北九州市若松区西園町');
ok($zip->set_number('8080032')->is_valid_number, '福岡県北九州市若松区老松');
ok($zip->set_number('8080033')->is_valid_number, '福岡県北九州市若松区大井戸町');
ok($zip->set_number('8080034')->is_valid_number, '福岡県北九州市若松区本町');
ok($zip->set_number('8080035')->is_valid_number, '福岡県北九州市若松区白山');
ok($zip->set_number('8080036')->is_valid_number, '福岡県北九州市若松区山手町');
ok($zip->set_number('8080041')->is_valid_number, '福岡県北九州市若松区迫田町');
ok($zip->set_number('8080042')->is_valid_number, '福岡県北九州市若松区棚田町');
ok($zip->set_number('8080043')->is_valid_number, '福岡県北九州市若松区西畑町');
ok($zip->set_number('8080044')->is_valid_number, '福岡県北九州市若松区東畑町');
ok($zip->set_number('8080045')->is_valid_number, '福岡県北九州市若松区山ノ堂町');
ok($zip->set_number('8080046')->is_valid_number, '福岡県北九州市若松区小糸町');
ok($zip->set_number('8080047')->is_valid_number, '福岡県北九州市若松区中畑町');
ok($zip->set_number('8080051')->is_valid_number, '福岡県北九州市若松区大谷町');
ok($zip->set_number('8080052')->is_valid_number, '福岡県北九州市若松区新大谷町');
ok($zip->set_number('8080053')->is_valid_number, '福岡県北九州市若松区修多羅');
ok($zip->set_number('8080054')->is_valid_number, '福岡県北九州市若松区久岐の浜');
ok($zip->set_number('8080055')->is_valid_number, '福岡県北九州市若松区畑谷町');
ok($zip->set_number('8080061')->is_valid_number, '福岡県北九州市若松区大池町');
ok($zip->set_number('8080062')->is_valid_number, '福岡県北九州市若松区古前');
ok($zip->set_number('8080063')->is_valid_number, '福岡県北九州市若松区和田町');
ok($zip->set_number('8080064')->is_valid_number, '福岡県北九州市若松区宮丸');
ok($zip->set_number('8080065')->is_valid_number, '福岡県北九州市若松区藤木');
ok($zip->set_number('8080066')->is_valid_number, '福岡県北九州市若松区くきのうみ中央');
ok($zip->set_number('8080071')->is_valid_number, '福岡県北九州市若松区今光');
ok($zip->set_number('8080072')->is_valid_number, '福岡県北九州市若松区百合野町');
ok($zip->set_number('8080073')->is_valid_number, '福岡県北九州市若松区赤島町');
ok($zip->set_number('8080074')->is_valid_number, '福岡県北九州市若松区藤ノ木');
ok($zip->set_number('8080075')->is_valid_number, '福岡県北九州市若松区赤岩町(その他)');
ok($zip->set_number('8080076')->is_valid_number, '福岡県北九州市若松区童子丸');
ok($zip->set_number('8080077')->is_valid_number, '福岡県北九州市若松区用勺町');
ok($zip->set_number('8080101')->is_valid_number, '福岡県北九州市若松区西天神町');
ok($zip->set_number('8080102')->is_valid_number, '福岡県北九州市若松区東二島');
ok($zip->set_number('8080103')->is_valid_number, '福岡県北九州市若松区二島');
ok($zip->set_number('8080104')->is_valid_number, '福岡県北九州市若松区畠田');
ok($zip->set_number('8080105')->is_valid_number, '福岡県北九州市若松区鴨生田');
ok($zip->set_number('8080106')->is_valid_number, '福岡県北九州市若松区片山');
ok($zip->set_number('8080108')->is_valid_number, '福岡県北九州市若松区小竹(その他)');
ok($zip->set_number('8080109')->is_valid_number, '福岡県北九州市若松区南二島');
ok($zip->set_number('8080111')->is_valid_number, '福岡県北九州市若松区柳崎町');
ok($zip->set_number('8080112')->is_valid_number, '福岡県北九州市若松区頓田');
ok($zip->set_number('8080113')->is_valid_number, '福岡県北九州市若松区払川');
ok($zip->set_number('8080121')->is_valid_number, '福岡県北九州市若松区竹並');
ok($zip->set_number('8080122')->is_valid_number, '福岡県北九州市若松区蜑住');
ok($zip->set_number('8080123')->is_valid_number, '福岡県北九州市若松区有毛');
ok($zip->set_number('8080124')->is_valid_number, '福岡県北九州市若松区安屋');
ok($zip->set_number('8080131')->is_valid_number, '福岡県北九州市若松区塩屋');
ok($zip->set_number('8080132')->is_valid_number, '福岡県北九州市若松区小敷');
ok($zip->set_number('8080133')->is_valid_number, '福岡県北九州市若松区大鳥居');
ok($zip->set_number('8080134')->is_valid_number, '福岡県北九州市若松区乙丸');
ok($zip->set_number('8080135')->is_valid_number, '福岡県北九州市若松区ひびきの');
ok($zip->set_number('8080136')->is_valid_number, '福岡県北九州市若松区花野路');
ok($zip->set_number('8080137')->is_valid_number, '福岡県北九州市若松区ひびきの南');
ok($zip->set_number('8080138')->is_valid_number, '福岡県北九州市若松区ひびきの北');
ok($zip->set_number('8080139')->is_valid_number, '福岡県北九州市若松区小敷ひびきの');
ok($zip->set_number('8080141')->is_valid_number, '福岡県北九州市若松区青葉台東');
ok($zip->set_number('8080142')->is_valid_number, '福岡県北九州市若松区青葉台南');
ok($zip->set_number('8080143')->is_valid_number, '福岡県北九州市若松区青葉台西');
ok($zip->set_number('8080144')->is_valid_number, '福岡県北九州市若松区高須東');
ok($zip->set_number('8080145')->is_valid_number, '福岡県北九州市若松区高須南');
ok($zip->set_number('8080146')->is_valid_number, '福岡県北九州市若松区高須西');
ok($zip->set_number('8080147')->is_valid_number, '福岡県北九州市若松区高須北');
ok($zip->set_number('8080148')->is_valid_number, '福岡県北九州市若松区高須');
ok($zip->set_number('8080175')->is_valid_number, '福岡県北九州市若松区赤岩町(10~12番地)');
ok($zip->set_number('8090000')->is_valid_number, '福岡県中間市以下に掲載がない場合');
ok($zip->set_number('8090001')->is_valid_number, '福岡県中間市垣生');
ok($zip->set_number('8090002')->is_valid_number, '福岡県中間市中底井野');
ok($zip->set_number('8090003')->is_valid_number, '福岡県中間市上底井野');
ok($zip->set_number('8090004')->is_valid_number, '福岡県中間市下大隈');
ok($zip->set_number('8090011')->is_valid_number, '福岡県中間市岩瀬');
ok($zip->set_number('8090012')->is_valid_number, '福岡県中間市下蓮花寺');
ok($zip->set_number('8090013')->is_valid_number, '福岡県中間市上蓮花寺');
ok($zip->set_number('8090014')->is_valid_number, '福岡県中間市蓮花寺');
ok($zip->set_number('8090015')->is_valid_number, '福岡県中間市太賀');
ok($zip->set_number('8090016')->is_valid_number, '福岡県中間市星ケ丘');
ok($zip->set_number('8090017')->is_valid_number, '福岡県中間市桜台');
ok($zip->set_number('8090018')->is_valid_number, '福岡県中間市通谷');
ok($zip->set_number('8090019')->is_valid_number, '福岡県中間市東中間');
ok($zip->set_number('8090021')->is_valid_number, '福岡県中間市朝霧');
ok($zip->set_number('8090022')->is_valid_number, '福岡県中間市鍋山町');
ok($zip->set_number('8090023')->is_valid_number, '福岡県中間市扇ケ浦');
ok($zip->set_number('8090024')->is_valid_number, '福岡県中間市池田');
ok($zip->set_number('8090025')->is_valid_number, '福岡県中間市深坂');
ok($zip->set_number('8090026')->is_valid_number, '福岡県中間市大辻町');
ok($zip->set_number('8090027')->is_valid_number, '福岡県中間市七重町');
ok($zip->set_number('8090028')->is_valid_number, '福岡県中間市弥生');
ok($zip->set_number('8090030')->is_valid_number, '福岡県中間市中央');
ok($zip->set_number('8090031')->is_valid_number, '福岡県中間市小田ケ浦');
ok($zip->set_number('8090032')->is_valid_number, '福岡県中間市中尾');
ok($zip->set_number('8090033')->is_valid_number, '福岡県中間市土手ノ内');
ok($zip->set_number('8090034')->is_valid_number, '福岡県中間市中間');
ok($zip->set_number('8090035')->is_valid_number, '福岡県中間市松ケ岡');
ok($zip->set_number('8090036')->is_valid_number, '福岡県中間市長津');
ok($zip->set_number('8090037')->is_valid_number, '福岡県中間市中鶴');
ok($zip->set_number('8090038')->is_valid_number, '福岡県中間市浄花町');
ok($zip->set_number('8090039')->is_valid_number, '福岡県中間市大根土');
ok($zip->set_number('8090041')->is_valid_number, '福岡県中間市岩瀬西町');
ok($zip->set_number('8100000')->is_valid_number, '福岡県福岡市中央区以下に掲載がない場合');
ok($zip->set_number('8100001')->is_valid_number, '福岡県福岡市中央区天神');
ok($zip->set_number('8100002')->is_valid_number, '福岡県福岡市中央区西中洲');
ok($zip->set_number('8100003')->is_valid_number, '福岡県福岡市中央区春吉');
ok($zip->set_number('8100004')->is_valid_number, '福岡県福岡市中央区渡辺通');
ok($zip->set_number('8100005')->is_valid_number, '福岡県福岡市中央区清川');
ok($zip->set_number('8100011')->is_valid_number, '福岡県福岡市中央区高砂');
ok($zip->set_number('8100012')->is_valid_number, '福岡県福岡市中央区白金');
ok($zip->set_number('8100013')->is_valid_number, '福岡県福岡市中央区大宮');
ok($zip->set_number('8100014')->is_valid_number, '福岡県福岡市中央区平尾');
ok($zip->set_number('8100015')->is_valid_number, '福岡県福岡市中央区那の川');
ok($zip->set_number('8100016')->is_valid_number, '福岡県福岡市中央区平和');
ok($zip->set_number('8100017')->is_valid_number, '福岡県福岡市中央区平丘町');
ok($zip->set_number('8100018')->is_valid_number, '福岡県福岡市中央区山荘通');
ok($zip->set_number('8100021')->is_valid_number, '福岡県福岡市中央区今泉');
ok($zip->set_number('8100022')->is_valid_number, '福岡県福岡市中央区薬院');
ok($zip->set_number('8100023')->is_valid_number, '福岡県福岡市中央区警固');
ok($zip->set_number('8100024')->is_valid_number, '福岡県福岡市中央区桜坂');
ok($zip->set_number('8100025')->is_valid_number, '福岡県福岡市中央区薬院伊福町');
ok($zip->set_number('8100026')->is_valid_number, '福岡県福岡市中央区古小烏町');
ok($zip->set_number('8100027')->is_valid_number, '福岡県福岡市中央区御所ケ谷');
ok($zip->set_number('8100028')->is_valid_number, '福岡県福岡市中央区浄水通');
ok($zip->set_number('8100029')->is_valid_number, '福岡県福岡市中央区平尾浄水町');
ok($zip->set_number('8100031')->is_valid_number, '福岡県福岡市中央区谷');
ok($zip->set_number('8100032')->is_valid_number, '福岡県福岡市中央区輝国');
ok($zip->set_number('8100033')->is_valid_number, '福岡県福岡市中央区小笹');
ok($zip->set_number('8100034')->is_valid_number, '福岡県福岡市中央区笹丘');
ok($zip->set_number('8100035')->is_valid_number, '福岡県福岡市中央区梅光園');
ok($zip->set_number('8100036')->is_valid_number, '福岡県福岡市中央区梅光園団地');
ok($zip->set_number('8100037')->is_valid_number, '福岡県福岡市中央区南公園');
ok($zip->set_number('8100041')->is_valid_number, '福岡県福岡市中央区大名');
ok($zip->set_number('8100042')->is_valid_number, '福岡県福岡市中央区赤坂');
ok($zip->set_number('8100043')->is_valid_number, '福岡県福岡市中央区城内');
ok($zip->set_number('8100044')->is_valid_number, '福岡県福岡市中央区六本松');
ok($zip->set_number('8100045')->is_valid_number, '福岡県福岡市中央区草香江');
ok($zip->set_number('8100051')->is_valid_number, '福岡県福岡市中央区大濠公園');
ok($zip->set_number('8100052')->is_valid_number, '福岡県福岡市中央区大濠');
ok($zip->set_number('8100053')->is_valid_number, '福岡県福岡市中央区鳥飼');
ok($zip->set_number('8100054')->is_valid_number, '福岡県福岡市中央区今川');
ok($zip->set_number('8100055')->is_valid_number, '福岡県福岡市中央区黒門');
ok($zip->set_number('8100061')->is_valid_number, '福岡県福岡市中央区西公園');
ok($zip->set_number('8100062')->is_valid_number, '福岡県福岡市中央区荒戸');
ok($zip->set_number('8100063')->is_valid_number, '福岡県福岡市中央区唐人町');
ok($zip->set_number('8100064')->is_valid_number, '福岡県福岡市中央区地行');
ok($zip->set_number('8100065')->is_valid_number, '福岡県福岡市中央区地行浜');
ok($zip->set_number('8100066')->is_valid_number, '福岡県福岡市中央区福浜');
ok($zip->set_number('8100067')->is_valid_number, '福岡県福岡市中央区伊崎');
ok($zip->set_number('8100071')->is_valid_number, '福岡県福岡市中央区那の津');
ok($zip->set_number('8100072')->is_valid_number, '福岡県福岡市中央区長浜');
ok($zip->set_number('8100073')->is_valid_number, '福岡県福岡市中央区舞鶴');
ok($zip->set_number('8100074')->is_valid_number, '福岡県福岡市中央区大手門');
ok($zip->set_number('8100075')->is_valid_number, '福岡県福岡市中央区港');
ok($zip->set_number('8100076')->is_valid_number, '福岡県福岡市中央区荒津');
ok($zip->set_number('8100801')->is_valid_number, '福岡県福岡市博多区中洲');
ok($zip->set_number('8100802')->is_valid_number, '福岡県福岡市博多区中洲中島町');
ok($zip->set_number('8110100')->is_valid_number, '福岡県糟屋郡新宮町以下に掲載がない場合');
ok($zip->set_number('8110101')->is_valid_number, '福岡県糟屋郡新宮町原上');
ok($zip->set_number('8110102')->is_valid_number, '福岡県糟屋郡新宮町立花口');
ok($zip->set_number('8110103')->is_valid_number, '福岡県糟屋郡新宮町花立花');
ok($zip->set_number('8110104')->is_valid_number, '福岡県糟屋郡新宮町的野');
ok($zip->set_number('8110110')->is_valid_number, '福岡県糟屋郡新宮町夜臼');
ok($zip->set_number('8110111')->is_valid_number, '福岡県糟屋郡新宮町三代');
ok($zip->set_number('8110112')->is_valid_number, '福岡県糟屋郡新宮町下府');
ok($zip->set_number('8110113')->is_valid_number, '福岡県糟屋郡新宮町桜山手');
ok($zip->set_number('8110114')->is_valid_number, '福岡県糟屋郡新宮町湊坂');
ok($zip->set_number('8110115')->is_valid_number, '福岡県糟屋郡新宮町新宮');
ok($zip->set_number('8110116')->is_valid_number, '福岡県糟屋郡新宮町湊');
ok($zip->set_number('8110117')->is_valid_number, '福岡県糟屋郡新宮町上府');
ok($zip->set_number('8110118')->is_valid_number, '福岡県糟屋郡新宮町相島');
ok($zip->set_number('8110119')->is_valid_number, '福岡県糟屋郡新宮町緑ケ浜');
ok($zip->set_number('8110120')->is_valid_number, '福岡県糟屋郡新宮町中央駅前');
ok($zip->set_number('8110121')->is_valid_number, '福岡県糟屋郡新宮町美咲');
ok($zip->set_number('8110122')->is_valid_number, '福岡県糟屋郡新宮町杜の宮');
ok($zip->set_number('8110123')->is_valid_number, '福岡県糟屋郡新宮町上府北');
ok($zip->set_number('8110124')->is_valid_number, '福岡県糟屋郡新宮町新宮東');
ok($zip->set_number('8110125')->is_valid_number, '福岡県糟屋郡新宮町三代西');
ok($zip->set_number('8110201')->is_valid_number, '福岡県福岡市東区三苫');
ok($zip->set_number('8110202')->is_valid_number, '福岡県福岡市東区和白');
ok($zip->set_number('8110203')->is_valid_number, '福岡県福岡市東区塩浜');
ok($zip->set_number('8110204')->is_valid_number, '福岡県福岡市東区奈多');
ok($zip->set_number('8110205')->is_valid_number, '福岡県福岡市東区奈多団地');
ok($zip->set_number('8110206')->is_valid_number, '福岡県福岡市東区雁の巣');
ok($zip->set_number('8110211')->is_valid_number, '福岡県福岡市東区美和台新町');
ok($zip->set_number('8110212')->is_valid_number, '福岡県福岡市東区美和台');
ok($zip->set_number('8110213')->is_valid_number, '福岡県福岡市東区和白丘');
ok($zip->set_number('8110214')->is_valid_number, '福岡県福岡市東区和白東');
ok($zip->set_number('8110215')->is_valid_number, '福岡県福岡市東区高美台');
ok($zip->set_number('8110216')->is_valid_number, '福岡県福岡市東区上和白');
ok($zip->set_number('8110321')->is_valid_number, '福岡県福岡市東区西戸崎');
ok($zip->set_number('8110322')->is_valid_number, '福岡県福岡市東区大岳');
ok($zip->set_number('8110323')->is_valid_number, '福岡県福岡市東区志賀島');
ok($zip->set_number('8110324')->is_valid_number, '福岡県福岡市東区弘');
ok($zip->set_number('8110325')->is_valid_number, '福岡県福岡市東区勝馬');
ok($zip->set_number('8111101')->is_valid_number, '福岡県福岡市早良区重留');
ok($zip->set_number('8111102')->is_valid_number, '福岡県福岡市早良区東入部');
ok($zip->set_number('8111103')->is_valid_number, '福岡県福岡市早良区四箇');
ok($zip->set_number('8111111')->is_valid_number, '福岡県福岡市早良区脇山');
ok($zip->set_number('8111112')->is_valid_number, '福岡県福岡市早良区小笠木');
ok($zip->set_number('8111113')->is_valid_number, '福岡県福岡市早良区板屋');
ok($zip->set_number('8111114')->is_valid_number, '福岡県福岡市早良区椎原');
ok($zip->set_number('8111121')->is_valid_number, '福岡県福岡市早良区西入部');
ok($zip->set_number('8111122')->is_valid_number, '福岡県福岡市早良区早良');
ok($zip->set_number('8111123')->is_valid_number, '福岡県福岡市早良区内野');
ok($zip->set_number('8111124')->is_valid_number, '福岡県福岡市早良区金武');
ok($zip->set_number('8111131')->is_valid_number, '福岡県福岡市早良区西');
ok($zip->set_number('8111132')->is_valid_number, '福岡県福岡市早良区石釜');
ok($zip->set_number('8111133')->is_valid_number, '福岡県福岡市早良区曲渕');
ok($zip->set_number('8111134')->is_valid_number, '福岡県福岡市早良区飯場');
ok($zip->set_number('8111200')->is_valid_number, '福岡県那珂川市以下に掲載がない場合');
ok($zip->set_number('8111201')->is_valid_number, '福岡県那珂川市片縄');
ok($zip->set_number('8111202')->is_valid_number, '福岡県那珂川市片縄西');
ok($zip->set_number('8111203')->is_valid_number, '福岡県那珂川市片縄北');
ok($zip->set_number('8111204')->is_valid_number, '福岡県那珂川市片縄東');
ok($zip->set_number('8111211')->is_valid_number, '福岡県那珂川市今光');
ok($zip->set_number('8111213')->is_valid_number, '福岡県那珂川市中原');
ok($zip->set_number('8111214')->is_valid_number, '福岡県那珂川市中原東');
ok($zip->set_number('8111215')->is_valid_number, '福岡県那珂川市松原');
ok($zip->set_number('8111216')->is_valid_number, '福岡県那珂川市観晴が丘');
ok($zip->set_number('8111221')->is_valid_number, '福岡県那珂川市王塚台');
ok($zip->set_number('8111222')->is_valid_number, '福岡県那珂川市下梶原');
ok($zip->set_number('8111223')->is_valid_number, '福岡県那珂川市上梶原');
ok($zip->set_number('8111224')->is_valid_number, '福岡県那珂川市安徳');
ok($zip->set_number('8111231')->is_valid_number, '福岡県那珂川市不入道');
ok($zip->set_number('8111232')->is_valid_number, '福岡県那珂川市埋金');
ok($zip->set_number('8111233')->is_valid_number, '福岡県那珂川市市ノ瀬');
ok($zip->set_number('8111234')->is_valid_number, '福岡県那珂川市五ケ山');
ok($zip->set_number('8111235')->is_valid_number, '福岡県那珂川市成竹');
ok($zip->set_number('8111236')->is_valid_number, '福岡県那珂川市南面里');
ok($zip->set_number('8111241')->is_valid_number, '福岡県那珂川市後野');
ok($zip->set_number('8111242')->is_valid_number, '福岡県那珂川市西隈');
ok($zip->set_number('8111243')->is_valid_number, '福岡県那珂川市東隈');
ok($zip->set_number('8111244')->is_valid_number, '福岡県那珂川市山田');
ok($zip->set_number('8111245')->is_valid_number, '福岡県那珂川市別所');
ok($zip->set_number('8111246')->is_valid_number, '福岡県那珂川市西畑');
ok($zip->set_number('8111251')->is_valid_number, '福岡県那珂川市松木');
ok($zip->set_number('8111252')->is_valid_number, '福岡県那珂川市五郎丸');
ok($zip->set_number('8111253')->is_valid_number, '福岡県那珂川市仲');
ok($zip->set_number('8111254')->is_valid_number, '福岡県那珂川市道善');
ok($zip->set_number('8111255')->is_valid_number, '福岡県那珂川市恵子');
ok($zip->set_number('8111256')->is_valid_number, '福岡県那珂川市仲丸');
ok($zip->set_number('8111302')->is_valid_number, '福岡県福岡市南区井尻');
ok($zip->set_number('8111303')->is_valid_number, '福岡県福岡市南区折立町');
ok($zip->set_number('8111311')->is_valid_number, '福岡県福岡市南区横手');
ok($zip->set_number('8111312')->is_valid_number, '福岡県福岡市南区横手南町');
ok($zip->set_number('8111313')->is_valid_number, '福岡県福岡市南区曰佐');
ok($zip->set_number('8111314')->is_valid_number, '福岡県福岡市南区的場');
ok($zip->set_number('8111321')->is_valid_number, '福岡県福岡市南区柳瀬');
ok($zip->set_number('8111322')->is_valid_number, '福岡県福岡市南区弥永団地');
ok($zip->set_number('8111323')->is_valid_number, '福岡県福岡市南区弥永');
ok($zip->set_number('8111324')->is_valid_number, '福岡県福岡市南区警弥郷');
ok($zip->set_number('8111343')->is_valid_number, '福岡県福岡市南区和田');
ok($zip->set_number('8111344')->is_valid_number, '福岡県福岡市南区三宅');
ok($zip->set_number('8111345')->is_valid_number, '福岡県福岡市南区向新町');
ok($zip->set_number('8111346')->is_valid_number, '福岡県福岡市南区老司');
ok($zip->set_number('8111347')->is_valid_number, '福岡県福岡市南区野多目');
ok($zip->set_number('8111351')->is_valid_number, '福岡県福岡市南区屋形原');
ok($zip->set_number('8111352')->is_valid_number, '福岡県福岡市南区鶴田');
ok($zip->set_number('8111353')->is_valid_number, '福岡県福岡市南区柏原');
ok($zip->set_number('8111354')->is_valid_number, '福岡県福岡市南区大平寺');
ok($zip->set_number('8111355')->is_valid_number, '福岡県福岡市南区桧原');
ok($zip->set_number('8111356')->is_valid_number, '福岡県福岡市南区花畑');
ok($zip->set_number('8111361')->is_valid_number, '福岡県福岡市南区西長住');
ok($zip->set_number('8111362')->is_valid_number, '福岡県福岡市南区長住');
ok($zip->set_number('8111364')->is_valid_number, '福岡県福岡市南区中尾');
ok($zip->set_number('8111365')->is_valid_number, '福岡県福岡市南区皿山');
ok($zip->set_number('8112100')->is_valid_number, '福岡県糟屋郡宇美町以下に掲載がない場合');
ok($zip->set_number('8112100')->is_valid_number, '福岡県糟屋郡須惠町以下に掲載がない場合');
ok($zip->set_number('8112101')->is_valid_number, '福岡県糟屋郡宇美町宇美');
ok($zip->set_number('8112102')->is_valid_number, '福岡県糟屋郡宇美町炭焼');
ok($zip->set_number('8112103')->is_valid_number, '福岡県糟屋郡宇美町四王寺坂');
ok($zip->set_number('8112104')->is_valid_number, '福岡県糟屋郡宇美町井野');
ok($zip->set_number('8112105')->is_valid_number, '福岡県糟屋郡宇美町四王寺');
ok($zip->set_number('8112106')->is_valid_number, '福岡県糟屋郡宇美町ひばりが丘');
ok($zip->set_number('8112107')->is_valid_number, '福岡県糟屋郡宇美町とびたけ');
ok($zip->set_number('8112108')->is_valid_number, '福岡県糟屋郡宇美町ゆりが丘');
ok($zip->set_number('8112109')->is_valid_number, '福岡県糟屋郡宇美町桜原');
ok($zip->set_number('8112111')->is_valid_number, '福岡県糟屋郡須惠町新原');
ok($zip->set_number('8112112')->is_valid_number, '福岡県糟屋郡須惠町植木');
ok($zip->set_number('8112113')->is_valid_number, '福岡県糟屋郡須惠町須惠');
ok($zip->set_number('8112114')->is_valid_number, '福岡県糟屋郡須惠町上須惠');
ok($zip->set_number('8112115')->is_valid_number, '福岡県糟屋郡須惠町佐谷');
ok($zip->set_number('8112121')->is_valid_number, '福岡県糟屋郡宇美町平和');
ok($zip->set_number('8112122')->is_valid_number, '福岡県糟屋郡宇美町明神坂');
ok($zip->set_number('8112123')->is_valid_number, '福岡県糟屋郡宇美町光正寺');
ok($zip->set_number('8112124')->is_valid_number, '福岡県糟屋郡宇美町若草');
ok($zip->set_number('8112125')->is_valid_number, '福岡県糟屋郡宇美町宇美東');
ok($zip->set_number('8112126')->is_valid_number, '福岡県糟屋郡宇美町障子岳南');
ok($zip->set_number('8112127')->is_valid_number, '福岡県糟屋郡宇美町障子岳');
ok($zip->set_number('8112128')->is_valid_number, '福岡県糟屋郡宇美町宇美中央');
ok($zip->set_number('8112129')->is_valid_number, '福岡県糟屋郡宇美町神武原');
ok($zip->set_number('8112131')->is_valid_number, '福岡県糟屋郡宇美町貴船');
ok($zip->set_number('8112132')->is_valid_number, '福岡県糟屋郡宇美町原田');
ok($zip->set_number('8112200')->is_valid_number, '福岡県糟屋郡志免町以下に掲載がない場合');
ok($zip->set_number('8112201')->is_valid_number, '福岡県糟屋郡志免町桜丘');
ok($zip->set_number('8112202')->is_valid_number, '福岡県糟屋郡志免町志免');
ok($zip->set_number('8112203')->is_valid_number, '福岡県糟屋郡志免町石橋台');
ok($zip->set_number('8112204')->is_valid_number, '福岡県糟屋郡志免町田富');
ok($zip->set_number('8112205')->is_valid_number, '福岡県糟屋郡志免町別府');
ok($zip->set_number('8112206')->is_valid_number, '福岡県糟屋郡志免町御手洗');
ok($zip->set_number('8112207')->is_valid_number, '福岡県糟屋郡志免町南里');
ok($zip->set_number('8112208')->is_valid_number, '福岡県糟屋郡志免町吉原');
ok($zip->set_number('8112209')->is_valid_number, '福岡県糟屋郡志免町王子');
ok($zip->set_number('8112221')->is_valid_number, '福岡県糟屋郡須惠町旅石');
ok($zip->set_number('8112231')->is_valid_number, '福岡県糟屋郡志免町別府東');
ok($zip->set_number('8112232')->is_valid_number, '福岡県糟屋郡志免町別府西');
ok($zip->set_number('8112233')->is_valid_number, '福岡県糟屋郡志免町別府北');
ok($zip->set_number('8112241')->is_valid_number, '福岡県糟屋郡志免町東公園台');
ok($zip->set_number('8112242')->is_valid_number, '福岡県糟屋郡志免町松ケ丘');
ok($zip->set_number('8112243')->is_valid_number, '福岡県糟屋郡志免町志免東');
ok($zip->set_number('8112244')->is_valid_number, '福岡県糟屋郡志免町志免中央');
ok($zip->set_number('8112245')->is_valid_number, '福岡県糟屋郡志免町片峰');
ok($zip->set_number('8112246')->is_valid_number, '福岡県糟屋郡志免町片峰中央');
ok($zip->set_number('8112247')->is_valid_number, '福岡県糟屋郡志免町向ケ丘');
ok($zip->set_number('8112248')->is_valid_number, '福岡県糟屋郡志免町坂瀬');
ok($zip->set_number('8112300')->is_valid_number, '福岡県糟屋郡粕屋町以下に掲載がない場合');
ok($zip->set_number('8112301')->is_valid_number, '福岡県糟屋郡粕屋町上大隈');
ok($zip->set_number('8112302')->is_valid_number, '福岡県糟屋郡粕屋町大隈');
ok($zip->set_number('8112303')->is_valid_number, '福岡県糟屋郡粕屋町酒殿');
ok($zip->set_number('8112304')->is_valid_number, '福岡県糟屋郡粕屋町仲原');
ok($zip->set_number('8112305')->is_valid_number, '福岡県糟屋郡粕屋町柚須');
ok($zip->set_number('8112306')->is_valid_number, '福岡県糟屋郡粕屋町阿恵');
ok($zip->set_number('8112307')->is_valid_number, '福岡県糟屋郡粕屋町原町');
ok($zip->set_number('8112308')->is_valid_number, '福岡県糟屋郡粕屋町内橋');
ok($zip->set_number('8112309')->is_valid_number, '福岡県糟屋郡粕屋町駕与丁');
ok($zip->set_number('8112310')->is_valid_number, '福岡県糟屋郡粕屋町花ヶ浦');
ok($zip->set_number('8112311')->is_valid_number, '福岡県糟屋郡粕屋町長者原');
ok($zip->set_number('8112312')->is_valid_number, '福岡県糟屋郡粕屋町戸原');
ok($zip->set_number('8112313')->is_valid_number, '福岡県糟屋郡粕屋町江辻');
ok($zip->set_number('8112314')->is_valid_number, '福岡県糟屋郡粕屋町若宮');
ok($zip->set_number('8112315')->is_valid_number, '福岡県糟屋郡粕屋町甲仲原');
ok($zip->set_number('8112316')->is_valid_number, '福岡県糟屋郡粕屋町長者原西');
ok($zip->set_number('8112317')->is_valid_number, '福岡県糟屋郡粕屋町長者原東');
ok($zip->set_number('8112318')->is_valid_number, '福岡県糟屋郡粕屋町戸原東');
ok($zip->set_number('8112319')->is_valid_number, '福岡県糟屋郡粕屋町戸原西');
ok($zip->set_number('8112320')->is_valid_number, '福岡県糟屋郡粕屋町内橋東');
ok($zip->set_number('8112321')->is_valid_number, '福岡県糟屋郡粕屋町内橋西(その他)');
ok($zip->set_number('8112322')->is_valid_number, '福岡県糟屋郡粕屋町戸原北');
ok($zip->set_number('8112400')->is_valid_number, '福岡県糟屋郡篠栗町以下に掲載がない場合');
ok($zip->set_number('8112401')->is_valid_number, '福岡県糟屋郡篠栗町高田');
ok($zip->set_number('8112402')->is_valid_number, '福岡県糟屋郡篠栗町金出');
ok($zip->set_number('8112403')->is_valid_number, '福岡県糟屋郡篠栗町萩尾');
ok($zip->set_number('8112404')->is_valid_number, '福岡県糟屋郡篠栗町内住');
ok($zip->set_number('8112405')->is_valid_number, '福岡県糟屋郡篠栗町篠栗');
ok($zip->set_number('8112411')->is_valid_number, '福岡県糟屋郡篠栗町若杉');
ok($zip->set_number('8112412')->is_valid_number, '福岡県糟屋郡篠栗町乙犬');
ok($zip->set_number('8112413')->is_valid_number, '福岡県糟屋郡篠栗町尾仲');
ok($zip->set_number('8112414')->is_valid_number, '福岡県糟屋郡篠栗町和田');
ok($zip->set_number('8112415')->is_valid_number, '福岡県糟屋郡篠栗町津波黒');
ok($zip->set_number('8112416')->is_valid_number, '福岡県糟屋郡篠栗町田中');
ok($zip->set_number('8112417')->is_valid_number, '福岡県糟屋郡篠栗町中央');
ok($zip->set_number('8112418')->is_valid_number, '福岡県糟屋郡篠栗町彩り台');
ok($zip->set_number('8112500')->is_valid_number, '福岡県糟屋郡久山町以下に掲載がない場合');
ok($zip->set_number('8112501')->is_valid_number, '福岡県糟屋郡久山町久原');
ok($zip->set_number('8112502')->is_valid_number, '福岡県糟屋郡久山町山田');
ok($zip->set_number('8112503')->is_valid_number, '福岡県糟屋郡久山町猪野');
ok($zip->set_number('8113100')->is_valid_number, '福岡県古賀市以下に掲載がない場合');
ok($zip->set_number('8113101')->is_valid_number, '福岡県古賀市天神');
ok($zip->set_number('8113102')->is_valid_number, '福岡県古賀市駅東');
ok($zip->set_number('8113103')->is_valid_number, '福岡県古賀市中央');
ok($zip->set_number('8113104')->is_valid_number, '福岡県古賀市花鶴丘');
ok($zip->set_number('8113105')->is_valid_number, '福岡県古賀市鹿部');
ok($zip->set_number('8113106')->is_valid_number, '福岡県古賀市日吉');
ok($zip->set_number('8113107')->is_valid_number, '福岡県古賀市美明');
ok($zip->set_number('8113111')->is_valid_number, '福岡県古賀市花見南');
ok($zip->set_number('8113112')->is_valid_number, '福岡県古賀市花見東');
ok($zip->set_number('8113113')->is_valid_number, '福岡県古賀市千鳥');
ok($zip->set_number('8113114')->is_valid_number, '福岡県古賀市舞の里');
ok($zip->set_number('8113115')->is_valid_number, '福岡県古賀市久保');
ok($zip->set_number('8113116')->is_valid_number, '福岡県古賀市庄');
ok($zip->set_number('8113117')->is_valid_number, '福岡県古賀市今の庄');
ok($zip->set_number('8113118')->is_valid_number, '福岡県古賀市新久保');
ok($zip->set_number('8113119')->is_valid_number, '福岡県古賀市美郷');
ok($zip->set_number('8113121')->is_valid_number, '福岡県古賀市筵内');
ok($zip->set_number('8113122')->is_valid_number, '福岡県古賀市薦野');
ok($zip->set_number('8113123')->is_valid_number, '福岡県古賀市米多比');
ok($zip->set_number('8113124')->is_valid_number, '福岡県古賀市薬王寺');
ok($zip->set_number('8113125')->is_valid_number, '福岡県古賀市谷山');
ok($zip->set_number('8113126')->is_valid_number, '福岡県古賀市小山田');
ok($zip->set_number('8113127')->is_valid_number, '福岡県古賀市新原');
ok($zip->set_number('8113128')->is_valid_number, '福岡県古賀市玄望園');
ok($zip->set_number('8113131')->is_valid_number, '福岡県古賀市今在家');
ok($zip->set_number('8113132')->is_valid_number, '福岡県古賀市川原');
ok($zip->set_number('8113133')->is_valid_number, '福岡県古賀市青柳町');
ok($zip->set_number('8113134')->is_valid_number, '福岡県古賀市青柳');
ok($zip->set_number('8113135')->is_valid_number, '福岡県古賀市小竹');
ok($zip->set_number('8113136')->is_valid_number, '福岡県古賀市糸ケ浦');
ok($zip->set_number('8113137')->is_valid_number, '福岡県古賀市古賀');
ok($zip->set_number('8113200')->is_valid_number, '福岡県福津市以下に掲載がない場合');
ok($zip->set_number('8113201')->is_valid_number, '福岡県福津市八並');
ok($zip->set_number('8113202')->is_valid_number, '福岡県福津市畦町');
ok($zip->set_number('8113203')->is_valid_number, '福岡県福津市本木');
ok($zip->set_number('8113204')->is_valid_number, '福岡県福津市舎利蔵');
ok($zip->set_number('8113205')->is_valid_number, '福岡県福津市内殿');
ok($zip->set_number('8113206')->is_valid_number, '福岡県福津市久末');
ok($zip->set_number('8113207')->is_valid_number, '福岡県福津市上西郷');
ok($zip->set_number('8113208')->is_valid_number, '福岡県福津市福間駅東');
ok($zip->set_number('8113209')->is_valid_number, '福岡県福津市日蒔野');
ok($zip->set_number('8113211')->is_valid_number, '福岡県福津市有弥の里');
ok($zip->set_number('8113212')->is_valid_number, '福岡県福津市福間南');
ok($zip->set_number('8113213')->is_valid_number, '福岡県福津市福津市の次に番地がくる場合');
ok($zip->set_number('8113214')->is_valid_number, '福岡県福津市花見が丘');
ok($zip->set_number('8113215')->is_valid_number, '福岡県福津市花見の里');
ok($zip->set_number('8113216')->is_valid_number, '福岡県福津市花見が浜');
ok($zip->set_number('8113217')->is_valid_number, '福岡県福津市中央');
ok($zip->set_number('8113218')->is_valid_number, '福岡県福津市手光南');
ok($zip->set_number('8113219')->is_valid_number, '福岡県福津市西福間');
ok($zip->set_number('8113220')->is_valid_number, '福岡県福津市あけぼの');
ok($zip->set_number('8113221')->is_valid_number, '福岡県福津市若木台');
ok($zip->set_number('8113222')->is_valid_number, '福岡県福津市津丸');
ok($zip->set_number('8113223')->is_valid_number, '福岡県福津市光陽台');
ok($zip->set_number('8113224')->is_valid_number, '福岡県福津市手光');
ok($zip->set_number('8113225')->is_valid_number, '福岡県福津市東福間');
ok($zip->set_number('8113226')->is_valid_number, '福岡県福津市小竹');
ok($zip->set_number('8113227')->is_valid_number, '福岡県福津市高平');
ok($zip->set_number('8113228')->is_valid_number, '福岡県福津市光陽台南');
ok($zip->set_number('8113229')->is_valid_number, '福岡県福津市桜川');
ok($zip->set_number('8113301')->is_valid_number, '福岡県福津市在自');
ok($zip->set_number('8113302')->is_valid_number, '福岡県福津市大石');
ok($zip->set_number('8113303')->is_valid_number, '福岡県福津市須多田');
ok($zip->set_number('8113304')->is_valid_number, '福岡県福津市津屋崎');
ok($zip->set_number('8113305')->is_valid_number, '福岡県福津市宮司');
ok($zip->set_number('8113306')->is_valid_number, '福岡県福津市生家');
ok($zip->set_number('8113307')->is_valid_number, '福岡県福津市渡');
ok($zip->set_number('8113308')->is_valid_number, '福岡県福津市星ケ丘');
ok($zip->set_number('8113309')->is_valid_number, '福岡県福津市宮司元町');
ok($zip->set_number('8113311')->is_valid_number, '福岡県福津市宮司浜');
ok($zip->set_number('8113312')->is_valid_number, '福岡県福津市宮司ヶ丘');
ok($zip->set_number('8113400')->is_valid_number, '福岡県宗像市以下に掲載がない場合');
ok($zip->set_number('8113401')->is_valid_number, '福岡県宗像市池浦');
ok($zip->set_number('8113402')->is_valid_number, '福岡県宗像市河東');
ok($zip->set_number('8113403')->is_valid_number, '福岡県宗像市ひかりケ丘');
ok($zip->set_number('8113404')->is_valid_number, '福岡県宗像市城西ケ丘');
ok($zip->set_number('8113405')->is_valid_number, '福岡県宗像市須恵');
ok($zip->set_number('8113406')->is_valid_number, '福岡県宗像市稲元');
ok($zip->set_number('8113407')->is_valid_number, '福岡県宗像市天平台');
ok($zip->set_number('8113408')->is_valid_number, '福岡県宗像市樟陽台');
ok($zip->set_number('8113411')->is_valid_number, '福岡県宗像市山田');
ok($zip->set_number('8113412')->is_valid_number, '福岡県宗像市平等寺');
ok($zip->set_number('8113413')->is_valid_number, '福岡県宗像市曲(その他)');
ok($zip->set_number('8113414')->is_valid_number, '福岡県宗像市光岡');
ok($zip->set_number('8113415')->is_valid_number, '福岡県宗像市朝野');
ok($zip->set_number('8113416')->is_valid_number, '福岡県宗像市宮田');
ok($zip->set_number('8113421')->is_valid_number, '福岡県宗像市大穂');
ok($zip->set_number('8113422')->is_valid_number, '福岡県宗像市王丸');
ok($zip->set_number('8113423')->is_valid_number, '福岡県宗像市野坂');
ok($zip->set_number('8113424')->is_valid_number, '福岡県宗像市原町');
ok($zip->set_number('8113425')->is_valid_number, '福岡県宗像市日の里');
ok($zip->set_number('8113430')->is_valid_number, '福岡県宗像市平井');
ok($zip->set_number('8113431')->is_valid_number, '福岡県宗像市田熊');
ok($zip->set_number('8113432')->is_valid_number, '福岡県宗像市大井');
ok($zip->set_number('8113433')->is_valid_number, '福岡県宗像市大井台');
ok($zip->set_number('8113434')->is_valid_number, '福岡県宗像市村山田');
ok($zip->set_number('8113435')->is_valid_number, '福岡県宗像市用山');
ok($zip->set_number('8113436')->is_valid_number, '福岡県宗像市東郷');
ok($zip->set_number('8113437')->is_valid_number, '福岡県宗像市久原');
ok($zip->set_number('8113438')->is_valid_number, '福岡県宗像市和歌美台');
ok($zip->set_number('8113439')->is_valid_number, '福岡県宗像市三倉');
ok($zip->set_number('8113440')->is_valid_number, '福岡県宗像市大井南');
ok($zip->set_number('8113501')->is_valid_number, '福岡県宗像市神湊');
ok($zip->set_number('8113502')->is_valid_number, '福岡県宗像市江口');
ok($zip->set_number('8113503')->is_valid_number, '福岡県宗像市牟田尻');
ok($zip->set_number('8113504')->is_valid_number, '福岡県宗像市深田');
ok($zip->set_number('8113505')->is_valid_number, '福岡県宗像市田島');
ok($zip->set_number('8113506')->is_valid_number, '福岡県宗像市吉田');
ok($zip->set_number('8113507')->is_valid_number, '福岡県宗像市多禮');
ok($zip->set_number('8113511')->is_valid_number, '福岡県宗像市地島');
ok($zip->set_number('8113512')->is_valid_number, '福岡県宗像市鐘崎');
ok($zip->set_number('8113513')->is_valid_number, '福岡県宗像市上八');
ok($zip->set_number('8113514')->is_valid_number, '福岡県宗像市田野');
ok($zip->set_number('8113515')->is_valid_number, '福岡県宗像市池田');
ok($zip->set_number('8113516')->is_valid_number, '福岡県宗像市公園通り');
ok($zip->set_number('8113521')->is_valid_number, '福岡県福津市勝浦');
ok($zip->set_number('8113522')->is_valid_number, '福岡県福津市奴山');
ok($zip->set_number('8113701')->is_valid_number, '福岡県宗像市大島');
ok($zip->set_number('8114113')->is_valid_number, '福岡県宗像市曲(25、35)');
ok($zip->set_number('8114141')->is_valid_number, '福岡県宗像市大谷');
ok($zip->set_number('8114142')->is_valid_number, '福岡県宗像市泉ケ丘');
ok($zip->set_number('8114143')->is_valid_number, '福岡県宗像市三郎丸');
ok($zip->set_number('8114145')->is_valid_number, '福岡県宗像市陵厳寺');
ok($zip->set_number('8114146')->is_valid_number, '福岡県宗像市赤間');
ok($zip->set_number('8114147')->is_valid_number, '福岡県宗像市石丸');
ok($zip->set_number('8114148')->is_valid_number, '福岡県宗像市赤間文教町');
ok($zip->set_number('8114151')->is_valid_number, '福岡県宗像市城南ケ丘');
ok($zip->set_number('8114152')->is_valid_number, '福岡県宗像市武丸');
ok($zip->set_number('8114153')->is_valid_number, '福岡県宗像市吉留');
ok($zip->set_number('8114154')->is_valid_number, '福岡県宗像市冨地原');
ok($zip->set_number('8114155')->is_valid_number, '福岡県宗像市名残');
ok($zip->set_number('8114156')->is_valid_number, '福岡県宗像市自由ケ丘南');
ok($zip->set_number('8114157')->is_valid_number, '福岡県宗像市アスティ');
ok($zip->set_number('8114161')->is_valid_number, '福岡県宗像市朝町');
ok($zip->set_number('8114162')->is_valid_number, '福岡県宗像市青葉台');
ok($zip->set_number('8114163')->is_valid_number, '福岡県宗像市自由ケ丘');
ok($zip->set_number('8114164')->is_valid_number, '福岡県宗像市徳重');
ok($zip->set_number('8114165')->is_valid_number, '福岡県宗像市広陵台');
ok($zip->set_number('8114166')->is_valid_number, '福岡県宗像市桜');
ok($zip->set_number('8114171')->is_valid_number, '福岡県宗像市葉山');
ok($zip->set_number('8114172')->is_valid_number, '福岡県宗像市緑町');
ok($zip->set_number('8114173')->is_valid_number, '福岡県宗像市栄町');
ok($zip->set_number('8114174')->is_valid_number, '福岡県宗像市自由ケ丘西町');
ok($zip->set_number('8114175')->is_valid_number, '福岡県宗像市田久');
ok($zip->set_number('8114176')->is_valid_number, '福岡県宗像市赤間ケ丘');
ok($zip->set_number('8114177')->is_valid_number, '福岡県宗像市桜美台');
ok($zip->set_number('8114181')->is_valid_number, '福岡県宗像市城山ニュータウン');
ok($zip->set_number('8114182')->is_valid_number, '福岡県宗像市城ケ谷');
ok($zip->set_number('8114183')->is_valid_number, '福岡県宗像市土穴');
ok($zip->set_number('8114184')->is_valid_number, '福岡県宗像市くりえいと');
ok($zip->set_number('8114185')->is_valid_number, '福岡県宗像市赤間駅前');
ok($zip->set_number('8114200')->is_valid_number, '福岡県遠賀郡岡垣町以下に掲載がない場合');
ok($zip->set_number('8114201')->is_valid_number, '福岡県遠賀郡岡垣町波津');
ok($zip->set_number('8114202')->is_valid_number, '福岡県遠賀郡岡垣町原');
ok($zip->set_number('8114203')->is_valid_number, '福岡県遠賀郡岡垣町内浦');
ok($zip->set_number('8114204')->is_valid_number, '福岡県遠賀郡岡垣町手野');
ok($zip->set_number('8114205')->is_valid_number, '福岡県遠賀郡岡垣町三吉');
ok($zip->set_number('8114211')->is_valid_number, '福岡県遠賀郡岡垣町吉木');
ok($zip->set_number('8114212')->is_valid_number, '福岡県遠賀郡岡垣町黒山');
ok($zip->set_number('8114213')->is_valid_number, '福岡県遠賀郡岡垣町糠塚');
ok($zip->set_number('8114214')->is_valid_number, '福岡県遠賀郡岡垣町松ケ台');
ok($zip->set_number('8114215')->is_valid_number, '福岡県遠賀郡岡垣町旭台');
ok($zip->set_number('8114216')->is_valid_number, '福岡県遠賀郡岡垣町旭南');
ok($zip->set_number('8114217')->is_valid_number, '福岡県遠賀郡岡垣町桜台');
ok($zip->set_number('8114218')->is_valid_number, '福岡県遠賀郡岡垣町中央台');
ok($zip->set_number('8114220')->is_valid_number, '福岡県遠賀郡岡垣町東山田');
ok($zip->set_number('8114221')->is_valid_number, '福岡県遠賀郡岡垣町山田');
ok($zip->set_number('8114222')->is_valid_number, '福岡県遠賀郡岡垣町戸切');
ok($zip->set_number('8114223')->is_valid_number, '福岡県遠賀郡岡垣町山田峠');
ok($zip->set_number('8114224')->is_valid_number, '福岡県遠賀郡岡垣町鍋田');
ok($zip->set_number('8114225')->is_valid_number, '福岡県遠賀郡岡垣町東高陽');
ok($zip->set_number('8114226')->is_valid_number, '福岡県遠賀郡岡垣町南高陽');
ok($zip->set_number('8114227')->is_valid_number, '福岡県遠賀郡岡垣町高陽台');
ok($zip->set_number('8114228')->is_valid_number, '福岡県遠賀郡岡垣町東松原');
ok($zip->set_number('8114229')->is_valid_number, '福岡県遠賀郡岡垣町百合ケ丘');
ok($zip->set_number('8114231')->is_valid_number, '福岡県遠賀郡岡垣町海老津');
ok($zip->set_number('8114232')->is_valid_number, '福岡県遠賀郡岡垣町上畑');
ok($zip->set_number('8114233')->is_valid_number, '福岡県遠賀郡岡垣町野間');
ok($zip->set_number('8114234')->is_valid_number, '福岡県遠賀郡岡垣町高倉');
ok($zip->set_number('8114235')->is_valid_number, '福岡県遠賀郡岡垣町公園通り');
ok($zip->set_number('8114236')->is_valid_number, '福岡県遠賀郡岡垣町海老津駅前');
ok($zip->set_number('8114237')->is_valid_number, '福岡県遠賀郡岡垣町東高倉');
ok($zip->set_number('8114238')->is_valid_number, '福岡県遠賀郡岡垣町海老津駅南');
ok($zip->set_number('8114239')->is_valid_number, '福岡県遠賀郡岡垣町野間南');
ok($zip->set_number('8114241')->is_valid_number, '福岡県遠賀郡岡垣町吉木東');
ok($zip->set_number('8114242')->is_valid_number, '福岡県遠賀郡岡垣町吉木西');
ok($zip->set_number('8114300')->is_valid_number, '福岡県遠賀郡遠賀町以下に掲載がない場合');
ok($zip->set_number('8114301')->is_valid_number, '福岡県遠賀郡遠賀町島津');
ok($zip->set_number('8114302')->is_valid_number, '福岡県遠賀郡遠賀町広渡');
ok($zip->set_number('8114303')->is_valid_number, '福岡県遠賀郡遠賀町今古賀');
ok($zip->set_number('8114304')->is_valid_number, '福岡県遠賀郡遠賀町若松');
ok($zip->set_number('8114305')->is_valid_number, '福岡県遠賀郡遠賀町松の本');
ok($zip->set_number('8114306')->is_valid_number, '福岡県遠賀郡遠賀町旧停');
ok($zip->set_number('8114307')->is_valid_number, '福岡県遠賀郡遠賀町遠賀川');
ok($zip->set_number('8114311')->is_valid_number, '福岡県遠賀郡遠賀町老良');
ok($zip->set_number('8114312')->is_valid_number, '福岡県遠賀郡遠賀町浅木');
ok($zip->set_number('8114313')->is_valid_number, '福岡県遠賀郡遠賀町木守');
ok($zip->set_number('8114321')->is_valid_number, '福岡県遠賀郡遠賀町虫生津');
ok($zip->set_number('8114322')->is_valid_number, '福岡県遠賀郡遠賀町芙蓉');
ok($zip->set_number('8114323')->is_valid_number, '福岡県遠賀郡遠賀町若葉台');
ok($zip->set_number('8114324')->is_valid_number, '福岡県遠賀郡遠賀町虫生津南');
ok($zip->set_number('8114331')->is_valid_number, '福岡県遠賀郡遠賀町別府');
ok($zip->set_number('8114332')->is_valid_number, '福岡県遠賀郡遠賀町上別府');
ok($zip->set_number('8114333')->is_valid_number, '福岡県遠賀郡遠賀町島門');
ok($zip->set_number('8114334')->is_valid_number, '福岡県遠賀郡遠賀町蓮角');
ok($zip->set_number('8114341')->is_valid_number, '福岡県遠賀郡遠賀町鬼津');
ok($zip->set_number('8114342')->is_valid_number, '福岡県遠賀郡遠賀町尾崎');
ok($zip->set_number('8114343')->is_valid_number, '福岡県遠賀郡遠賀町田園');
ok($zip->set_number('8115100')->is_valid_number, '長崎県壱岐市以下に掲載がない場合');
ok($zip->set_number('8115101')->is_valid_number, '長崎県壱岐市郷ノ浦町長峰本村触');
ok($zip->set_number('8115102')->is_valid_number, '長崎県壱岐市郷ノ浦町長峰東触');
ok($zip->set_number('8115103')->is_valid_number, '長崎県壱岐市郷ノ浦町新田触');
ok($zip->set_number('8115104')->is_valid_number, '長崎県壱岐市郷ノ浦町里触');
ok($zip->set_number('8115105')->is_valid_number, '長崎県壱岐市郷ノ浦町小牧西触');
ok($zip->set_number('8115106')->is_valid_number, '長崎県壱岐市郷ノ浦町小牧東触');
ok($zip->set_number('8115107')->is_valid_number, '長崎県壱岐市郷ノ浦町有安触');
ok($zip->set_number('8115111')->is_valid_number, '長崎県壱岐市郷ノ浦町半城本村触');
ok($zip->set_number('8115112')->is_valid_number, '長崎県壱岐市郷ノ浦町大浦触');
ok($zip->set_number('8115113')->is_valid_number, '長崎県壱岐市郷ノ浦町牛方触');
ok($zip->set_number('8115114')->is_valid_number, '長崎県壱岐市郷ノ浦町柳田触');
ok($zip->set_number('8115115')->is_valid_number, '長崎県壱岐市郷ノ浦町木田触');
ok($zip->set_number('8115116')->is_valid_number, '長崎県壱岐市郷ノ浦町物部本村触');
ok($zip->set_number('8115117')->is_valid_number, '長崎県壱岐市郷ノ浦町田中触');
ok($zip->set_number('8115121')->is_valid_number, '長崎県壱岐市郷ノ浦町平人触');
ok($zip->set_number('8115122')->is_valid_number, '長崎県壱岐市郷ノ浦町大原触');
ok($zip->set_number('8115123')->is_valid_number, '長崎県壱岐市郷ノ浦町釘山触');
ok($zip->set_number('8115124')->is_valid_number, '長崎県壱岐市郷ノ浦町志原南触');
ok($zip->set_number('8115125')->is_valid_number, '長崎県壱岐市郷ノ浦町志原西触');
ok($zip->set_number('8115131')->is_valid_number, '長崎県壱岐市郷ノ浦町永田触');
ok($zip->set_number('8115132')->is_valid_number, '長崎県壱岐市郷ノ浦町東触');
ok($zip->set_number('8115133')->is_valid_number, '長崎県壱岐市郷ノ浦町本村触');
ok($zip->set_number('8115134')->is_valid_number, '長崎県壱岐市郷ノ浦町庄触');
ok($zip->set_number('8115135')->is_valid_number, '長崎県壱岐市郷ノ浦町郷ノ浦');
ok($zip->set_number('8115136')->is_valid_number, '長崎県壱岐市郷ノ浦町片原触');
ok($zip->set_number('8115141')->is_valid_number, '長崎県壱岐市郷ノ浦町若松触');
ok($zip->set_number('8115142')->is_valid_number, '長崎県壱岐市郷ノ浦町坪触');
ok($zip->set_number('8115143')->is_valid_number, '長崎県壱岐市郷ノ浦町初山西触');
ok($zip->set_number('8115144')->is_valid_number, '長崎県壱岐市郷ノ浦町初山東触');
ok($zip->set_number('8115151')->is_valid_number, '長崎県壱岐市郷ノ浦町渡良浦');
ok($zip->set_number('8115152')->is_valid_number, '長崎県壱岐市郷ノ浦町渡良南触');
ok($zip->set_number('8115153')->is_valid_number, '長崎県壱岐市郷ノ浦町渡良西触');
ok($zip->set_number('8115154')->is_valid_number, '長崎県壱岐市郷ノ浦町渡良東触');
ok($zip->set_number('8115155')->is_valid_number, '長崎県壱岐市郷ノ浦町麦谷触');
ok($zip->set_number('8115161')->is_valid_number, '長崎県壱岐市郷ノ浦町大島');
ok($zip->set_number('8115162')->is_valid_number, '長崎県壱岐市郷ノ浦町長島');
ok($zip->set_number('8115163')->is_valid_number, '長崎県壱岐市郷ノ浦町原島');
ok($zip->set_number('8115201')->is_valid_number, '長崎県壱岐市石田町山崎触');
ok($zip->set_number('8115202')->is_valid_number, '長崎県壱岐市石田町筒城仲触');
ok($zip->set_number('8115203')->is_valid_number, '長崎県壱岐市石田町筒城東触');
ok($zip->set_number('8115204')->is_valid_number, '長崎県壱岐市石田町筒城西触');
ok($zip->set_number('8115211')->is_valid_number, '長崎県壱岐市石田町石田東触');
ok($zip->set_number('8115212')->is_valid_number, '長崎県壱岐市石田町本村触');
ok($zip->set_number('8115213')->is_valid_number, '長崎県壱岐市石田町南触');
ok($zip->set_number('8115214')->is_valid_number, '長崎県壱岐市石田町印通寺浦');
ok($zip->set_number('8115215')->is_valid_number, '長崎県壱岐市石田町石田西触');
ok($zip->set_number('8115221')->is_valid_number, '長崎県壱岐市石田町池田東触');
ok($zip->set_number('8115222')->is_valid_number, '長崎県壱岐市石田町池田仲触');
ok($zip->set_number('8115223')->is_valid_number, '長崎県壱岐市石田町久喜触');
ok($zip->set_number('8115224')->is_valid_number, '長崎県壱岐市石田町池田西触');
ok($zip->set_number('8115225')->is_valid_number, '長崎県壱岐市石田町湯岳興触');
ok($zip->set_number('8115226')->is_valid_number, '長崎県壱岐市石田町湯岳射手吉触');
ok($zip->set_number('8115301')->is_valid_number, '長崎県壱岐市芦辺町芦辺浦');
ok($zip->set_number('8115311')->is_valid_number, '長崎県壱岐市芦辺町諸吉本村触');
ok($zip->set_number('8115312')->is_valid_number, '長崎県壱岐市芦辺町諸吉南触');
ok($zip->set_number('8115313')->is_valid_number, '長崎県壱岐市芦辺町諸吉仲触');
ok($zip->set_number('8115314')->is_valid_number, '長崎県壱岐市芦辺町諸吉東触');
ok($zip->set_number('8115315')->is_valid_number, '長崎県壱岐市芦辺町諸吉二亦触');
ok($zip->set_number('8115316')->is_valid_number, '長崎県壱岐市芦辺町諸吉大石触');
ok($zip->set_number('8115321')->is_valid_number, '長崎県壱岐市芦辺町深江栄触');
ok($zip->set_number('8115322')->is_valid_number, '長崎県壱岐市芦辺町深江鶴亀触');
ok($zip->set_number('8115323')->is_valid_number, '長崎県壱岐市芦辺町深江平触');
ok($zip->set_number('8115324')->is_valid_number, '長崎県壱岐市芦辺町深江東触');
ok($zip->set_number('8115325')->is_valid_number, '長崎県壱岐市芦辺町深江南触');
ok($zip->set_number('8115326')->is_valid_number, '長崎県壱岐市芦辺町深江本村触');
ok($zip->set_number('8115461')->is_valid_number, '長崎県壱岐市芦辺町瀬戸浦');
ok($zip->set_number('8115462')->is_valid_number, '長崎県壱岐市芦辺町箱崎大左右触');
ok($zip->set_number('8115463')->is_valid_number, '長崎県壱岐市芦辺町箱崎中山触');
ok($zip->set_number('8115464')->is_valid_number, '長崎県壱岐市芦辺町箱崎谷江触');
ok($zip->set_number('8115465')->is_valid_number, '長崎県壱岐市芦辺町箱崎釘ノ尾触');
ok($zip->set_number('8115466')->is_valid_number, '長崎県壱岐市芦辺町箱崎本村触');
ok($zip->set_number('8115467')->is_valid_number, '長崎県壱岐市芦辺町箱崎江角触');
ok($zip->set_number('8115468')->is_valid_number, '長崎県壱岐市芦辺町箱崎諸津触');
ok($zip->set_number('8115501')->is_valid_number, '長崎県壱岐市勝本町勝本浦');
ok($zip->set_number('8115511')->is_valid_number, '長崎県壱岐市勝本町仲触');
ok($zip->set_number('8115512')->is_valid_number, '長崎県壱岐市勝本町東触');
ok($zip->set_number('8115513')->is_valid_number, '長崎県壱岐市勝本町北触');
ok($zip->set_number('8115521')->is_valid_number, '長崎県壱岐市勝本町西戸触');
ok($zip->set_number('8115522')->is_valid_number, '長崎県壱岐市勝本町新城東触');
ok($zip->set_number('8115523')->is_valid_number, '長崎県壱岐市勝本町片山触');
ok($zip->set_number('8115531')->is_valid_number, '長崎県壱岐市勝本町坂本触');
ok($zip->set_number('8115532')->is_valid_number, '長崎県壱岐市勝本町大久保触');
ok($zip->set_number('8115533')->is_valid_number, '長崎県壱岐市勝本町新城西触');
ok($zip->set_number('8115541')->is_valid_number, '長崎県壱岐市勝本町本宮西触');
ok($zip->set_number('8115542')->is_valid_number, '長崎県壱岐市勝本町本宮東触');
ok($zip->set_number('8115543')->is_valid_number, '長崎県壱岐市勝本町上場触');
ok($zip->set_number('8115544')->is_valid_number, '長崎県壱岐市勝本町布気触');
ok($zip->set_number('8115545')->is_valid_number, '長崎県壱岐市勝本町本宮南触');
ok($zip->set_number('8115546')->is_valid_number, '長崎県壱岐市勝本町本宮仲触');
ok($zip->set_number('8115551')->is_valid_number, '長崎県壱岐市勝本町湯本浦');
ok($zip->set_number('8115552')->is_valid_number, '長崎県壱岐市勝本町百合畑触');
ok($zip->set_number('8115553')->is_valid_number, '長崎県壱岐市勝本町立石東触');
ok($zip->set_number('8115554')->is_valid_number, '長崎県壱岐市勝本町立石仲触');
ok($zip->set_number('8115555')->is_valid_number, '長崎県壱岐市勝本町立石南触');
ok($zip->set_number('8115556')->is_valid_number, '長崎県壱岐市勝本町立石西触');
ok($zip->set_number('8115731')->is_valid_number, '長崎県壱岐市芦辺町国分当田触');
ok($zip->set_number('8115732')->is_valid_number, '長崎県壱岐市芦辺町国分東触');
ok($zip->set_number('8115733')->is_valid_number, '長崎県壱岐市芦辺町国分川迎触');
ok($zip->set_number('8115734')->is_valid_number, '長崎県壱岐市芦辺町国分本村触');
ok($zip->set_number('8115741')->is_valid_number, '長崎県壱岐市芦辺町住吉山信触');
ok($zip->set_number('8115742')->is_valid_number, '長崎県壱岐市芦辺町住吉東触');
ok($zip->set_number('8115743')->is_valid_number, '長崎県壱岐市芦辺町住吉前触');
ok($zip->set_number('8115744')->is_valid_number, '長崎県壱岐市芦辺町住吉後触');
ok($zip->set_number('8115751')->is_valid_number, '長崎県壱岐市芦辺町中野郷仲触');
ok($zip->set_number('8115752')->is_valid_number, '長崎県壱岐市芦辺町中野郷東触');
ok($zip->set_number('8115753')->is_valid_number, '長崎県壱岐市芦辺町湯岳本村触');
ok($zip->set_number('8115754')->is_valid_number, '長崎県壱岐市芦辺町湯岳今坂触');
ok($zip->set_number('8115755')->is_valid_number, '長崎県壱岐市芦辺町湯岳興触');
ok($zip->set_number('8115756')->is_valid_number, '長崎県壱岐市芦辺町中野郷本村触');
ok($zip->set_number('8115757')->is_valid_number, '長崎県壱岐市芦辺町中野郷西触');
ok($zip->set_number('8120000')->is_valid_number, '福岡県福岡市博多区以下に掲載がない場合');
ok($zip->set_number('8120001')->is_valid_number, '福岡県福岡市博多区大井');
ok($zip->set_number('8120002')->is_valid_number, '福岡県福岡市博多区空港前');
ok($zip->set_number('8120003')->is_valid_number, '福岡県福岡市博多区下臼井');
ok($zip->set_number('8120004')->is_valid_number, '福岡県福岡市博多区榎田');
ok($zip->set_number('8120005')->is_valid_number, '福岡県福岡市博多区上臼井');
ok($zip->set_number('8120006')->is_valid_number, '福岡県福岡市博多区上牟田');
ok($zip->set_number('8120007')->is_valid_number, '福岡県福岡市博多区東比恵');
ok($zip->set_number('8120008')->is_valid_number, '福岡県福岡市博多区東光');
ok($zip->set_number('8120011')->is_valid_number, '福岡県福岡市博多区博多駅前');
ok($zip->set_number('8120012')->is_valid_number, '福岡県福岡市博多区博多駅中央街');
ok($zip->set_number('8120013')->is_valid_number, '福岡県福岡市博多区博多駅東');
ok($zip->set_number('8120014')->is_valid_number, '福岡県福岡市博多区比恵町');
ok($zip->set_number('8120015')->is_valid_number, '福岡県福岡市博多区山王');
ok($zip->set_number('8120016')->is_valid_number, '福岡県福岡市博多区博多駅南');
ok($zip->set_number('8120017')->is_valid_number, '福岡県福岡市博多区美野島');
ok($zip->set_number('8120018')->is_valid_number, '福岡県福岡市博多区住吉');
ok($zip->set_number('8120020')->is_valid_number, '福岡県福岡市博多区対馬小路');
ok($zip->set_number('8120021')->is_valid_number, '福岡県福岡市博多区築港本町');
ok($zip->set_number('8120022')->is_valid_number, '福岡県福岡市博多区神屋町');
ok($zip->set_number('8120023')->is_valid_number, '福岡県福岡市博多区奈良屋町');
ok($zip->set_number('8120024')->is_valid_number, '福岡県福岡市博多区綱場町');
ok($zip->set_number('8120025')->is_valid_number, '福岡県福岡市博多区店屋町');
ok($zip->set_number('8120026')->is_valid_number, '福岡県福岡市博多区上川端町');
ok($zip->set_number('8120027')->is_valid_number, '福岡県福岡市博多区下川端町');
ok($zip->set_number('8120028')->is_valid_number, '福岡県福岡市博多区須崎町');
ok($zip->set_number('8120029')->is_valid_number, '福岡県福岡市博多区古門戸町');
ok($zip->set_number('8120031')->is_valid_number, '福岡県福岡市博多区沖浜町');
ok($zip->set_number('8120032')->is_valid_number, '福岡県福岡市博多区石城町');
ok($zip->set_number('8120033')->is_valid_number, '福岡県福岡市博多区大博町');
ok($zip->set_number('8120034')->is_valid_number, '福岡県福岡市博多区下呉服町');
ok($zip->set_number('8120035')->is_valid_number, '福岡県福岡市博多区中呉服町');
ok($zip->set_number('8120036')->is_valid_number, '福岡県福岡市博多区上呉服町');
ok($zip->set_number('8120037')->is_valid_number, '福岡県福岡市博多区御供所町');
ok($zip->set_number('8120038')->is_valid_number, '福岡県福岡市博多区祇園町');
ok($zip->set_number('8120039')->is_valid_number, '福岡県福岡市博多区冷泉町');
ok($zip->set_number('8120041')->is_valid_number, '福岡県福岡市博多区吉塚');
ok($zip->set_number('8120042')->is_valid_number, '福岡県福岡市博多区豊');
ok($zip->set_number('8120043')->is_valid_number, '福岡県福岡市博多区堅粕');
ok($zip->set_number('8120044')->is_valid_number, '福岡県福岡市博多区千代');
ok($zip->set_number('8120045')->is_valid_number, '福岡県福岡市博多区東公園');
ok($zip->set_number('8120046')->is_valid_number, '福岡県福岡市博多区吉塚本町');
ok($zip->set_number('8120051')->is_valid_number, '福岡県福岡市東区箱崎ふ頭');
ok($zip->set_number('8120052')->is_valid_number, '福岡県福岡市東区貝塚団地');
ok($zip->set_number('8120053')->is_valid_number, '福岡県福岡市東区箱崎');
ok($zip->set_number('8120054')->is_valid_number, '福岡県福岡市東区馬出');
ok($zip->set_number('8120055')->is_valid_number, '福岡県福岡市東区東浜');
ok($zip->set_number('8120061')->is_valid_number, '福岡県福岡市東区筥松');
ok($zip->set_number('8120062')->is_valid_number, '福岡県福岡市東区松島(1、2丁目)');
ok($zip->set_number('8120063')->is_valid_number, '福岡県福岡市東区原田');
ok($zip->set_number('8120064')->is_valid_number, '福岡県福岡市東区松田');
ok($zip->set_number('8120065')->is_valid_number, '福岡県福岡市東区二又瀬新町');
ok($zip->set_number('8120066')->is_valid_number, '福岡県福岡市東区二又瀬');
ok($zip->set_number('8120067')->is_valid_number, '福岡県福岡市東区筥松新町');
ok($zip->set_number('8120068')->is_valid_number, '福岡県福岡市東区社領');
ok($zip->set_number('8120069')->is_valid_number, '福岡県福岡市東区郷口町');
ok($zip->set_number('8120851')->is_valid_number, '福岡県福岡市博多区青木');
ok($zip->set_number('8120852')->is_valid_number, '福岡県福岡市博多区東平尾公園');
ok($zip->set_number('8120853')->is_valid_number, '福岡県福岡市博多区東平尾');
ok($zip->set_number('8120854')->is_valid_number, '福岡県福岡市博多区東月隈');
ok($zip->set_number('8120855')->is_valid_number, '福岡県福岡市博多区下月隈');
ok($zip->set_number('8120857')->is_valid_number, '福岡県福岡市博多区西月隈');
ok($zip->set_number('8120858')->is_valid_number, '福岡県福岡市博多区月隈');
ok($zip->set_number('8120861')->is_valid_number, '福岡県福岡市博多区浦田');
ok($zip->set_number('8120862')->is_valid_number, '福岡県福岡市博多区立花寺');
ok($zip->set_number('8120863')->is_valid_number, '福岡県福岡市博多区金の隈');
ok($zip->set_number('8120871')->is_valid_number, '福岡県福岡市博多区東雲町');
ok($zip->set_number('8120872')->is_valid_number, '福岡県福岡市博多区春町');
ok($zip->set_number('8120873')->is_valid_number, '福岡県福岡市博多区西春町');
ok($zip->set_number('8120874')->is_valid_number, '福岡県福岡市博多区光丘町');
ok($zip->set_number('8120875')->is_valid_number, '福岡県福岡市博多区新和町');
ok($zip->set_number('8120876')->is_valid_number, '福岡県福岡市博多区昭南町');
ok($zip->set_number('8120877')->is_valid_number, '福岡県福岡市博多区元町');
ok($zip->set_number('8120878')->is_valid_number, '福岡県福岡市博多区竹丘町');
ok($zip->set_number('8120879')->is_valid_number, '福岡県福岡市博多区銀天町');
ok($zip->set_number('8120881')->is_valid_number, '福岡県福岡市博多区井相田');
ok($zip->set_number('8120882')->is_valid_number, '福岡県福岡市博多区麦野');
ok($zip->set_number('8120883')->is_valid_number, '福岡県福岡市博多区南本町');
ok($zip->set_number('8120884')->is_valid_number, '福岡県福岡市博多区寿町');
ok($zip->set_number('8120885')->is_valid_number, '福岡県福岡市博多区相生町');
ok($zip->set_number('8120886')->is_valid_number, '福岡県福岡市博多区南八幡町');
ok($zip->set_number('8120887')->is_valid_number, '福岡県福岡市博多区三筑');
ok($zip->set_number('8120888')->is_valid_number, '福岡県福岡市博多区板付');
ok($zip->set_number('8120891')->is_valid_number, '福岡県福岡市博多区雀居');
ok($zip->set_number('8120892')->is_valid_number, '福岡県福岡市博多区東那珂');
ok($zip->set_number('8120893')->is_valid_number, '福岡県福岡市博多区那珂');
ok($zip->set_number('8120894')->is_valid_number, '福岡県福岡市博多区諸岡');
ok($zip->set_number('8120895')->is_valid_number, '福岡県福岡市博多区竹下');
ok($zip->set_number('8120896')->is_valid_number, '福岡県福岡市博多区東光寺町');
ok($zip->set_number('8120897')->is_valid_number, '福岡県福岡市博多区半道橋');
ok($zip->set_number('8130000')->is_valid_number, '福岡県福岡市東区以下に掲載がない場合');
ok($zip->set_number('8130001')->is_valid_number, '福岡県福岡市東区唐原');
ok($zip->set_number('8130002')->is_valid_number, '福岡県福岡市東区下原');
ok($zip->set_number('8130003')->is_valid_number, '福岡県福岡市東区香住ヶ丘');
ok($zip->set_number('8130004')->is_valid_number, '福岡県福岡市東区松香台');
ok($zip->set_number('8130005')->is_valid_number, '福岡県福岡市東区御島崎');
ok($zip->set_number('8130008')->is_valid_number, '福岡県糟屋郡粕屋町内橋西(3丁目11番5~8号「多の津団地」)');
ok($zip->set_number('8130011')->is_valid_number, '福岡県福岡市東区香椎');
ok($zip->set_number('8130012')->is_valid_number, '福岡県福岡市東区香椎駅東');
ok($zip->set_number('8130013')->is_valid_number, '福岡県福岡市東区香椎駅前');
ok($zip->set_number('8130014')->is_valid_number, '福岡県福岡市東区香椎台');
ok($zip->set_number('8130015')->is_valid_number, '福岡県福岡市東区香椎団地');
ok($zip->set_number('8130016')->is_valid_number, '福岡県福岡市東区香椎浜');
ok($zip->set_number('8130017')->is_valid_number, '福岡県福岡市東区香椎照葉');
ok($zip->set_number('8130018')->is_valid_number, '福岡県福岡市東区香椎浜ふ頭');
ok($zip->set_number('8130019')->is_valid_number, '福岡県福岡市東区みなと香椎');
ok($zip->set_number('8130021')->is_valid_number, '福岡県福岡市東区みどりが丘');
ok($zip->set_number('8130023')->is_valid_number, '福岡県福岡市東区蒲田');
ok($zip->set_number('8130024')->is_valid_number, '福岡県福岡市東区名子');
ok($zip->set_number('8130025')->is_valid_number, '福岡県福岡市東区青葉');
ok($zip->set_number('8130031')->is_valid_number, '福岡県福岡市東区八田');
ok($zip->set_number('8130032')->is_valid_number, '福岡県福岡市東区土井');
ok($zip->set_number('8130033')->is_valid_number, '福岡県福岡市東区多々良');
ok($zip->set_number('8130034')->is_valid_number, '福岡県福岡市東区多の津');
ok($zip->set_number('8130035')->is_valid_number, '福岡県福岡市東区松崎');
ok($zip->set_number('8130036')->is_valid_number, '福岡県福岡市東区若宮');
ok($zip->set_number('8130041')->is_valid_number, '福岡県福岡市東区水谷');
ok($zip->set_number('8130042')->is_valid_number, '福岡県福岡市東区舞松原');
ok($zip->set_number('8130043')->is_valid_number, '福岡県福岡市東区名島');
ok($zip->set_number('8130044')->is_valid_number, '福岡県福岡市東区千早');
ok($zip->set_number('8130045')->is_valid_number, '福岡県福岡市東区城浜団地');
ok($zip->set_number('8130062')->is_valid_number, '福岡県福岡市東区松島(3~6丁目)');
ok($zip->set_number('8140000')->is_valid_number, '福岡県福岡市早良区以下に掲載がない場合');
ok($zip->set_number('8140001')->is_valid_number, '福岡県福岡市早良区百道浜');
ok($zip->set_number('8140002')->is_valid_number, '福岡県福岡市早良区西新');
ok($zip->set_number('8140003')->is_valid_number, '福岡県福岡市早良区城西');
ok($zip->set_number('8140004')->is_valid_number, '福岡県福岡市早良区曙');
ok($zip->set_number('8140005')->is_valid_number, '福岡県福岡市早良区祖原');
ok($zip->set_number('8140006')->is_valid_number, '福岡県福岡市早良区百道');
ok($zip->set_number('8140011')->is_valid_number, '福岡県福岡市早良区高取');
ok($zip->set_number('8140012')->is_valid_number, '福岡県福岡市早良区昭代');
ok($zip->set_number('8140013')->is_valid_number, '福岡県福岡市早良区藤崎');
ok($zip->set_number('8140014')->is_valid_number, '福岡県福岡市早良区弥生');
ok($zip->set_number('8140015')->is_valid_number, '福岡県福岡市早良区室見');
ok($zip->set_number('8140021')->is_valid_number, '福岡県福岡市早良区荒江');
ok($zip->set_number('8140022')->is_valid_number, '福岡県福岡市早良区原');
ok($zip->set_number('8140023')->is_valid_number, '福岡県福岡市早良区原団地');
ok($zip->set_number('8140031')->is_valid_number, '福岡県福岡市早良区南庄');
ok($zip->set_number('8140032')->is_valid_number, '福岡県福岡市早良区小田部');
ok($zip->set_number('8140033')->is_valid_number, '福岡県福岡市早良区有田');
ok($zip->set_number('8140034')->is_valid_number, '福岡県福岡市早良区有田団地');
ok($zip->set_number('8140035')->is_valid_number, '福岡県福岡市早良区室住団地');
ok($zip->set_number('8140100')->is_valid_number, '福岡県福岡市城南区以下に掲載がない場合');
ok($zip->set_number('8140101')->is_valid_number, '福岡県福岡市城南区荒江');
ok($zip->set_number('8140102')->is_valid_number, '福岡県福岡市城南区荒江団地');
ok($zip->set_number('8140103')->is_valid_number, '福岡県福岡市城南区鳥飼');
ok($zip->set_number('8140104')->is_valid_number, '福岡県福岡市城南区別府');
ok($zip->set_number('8140105')->is_valid_number, '福岡県福岡市城南区城西団地');
ok($zip->set_number('8140106')->is_valid_number, '福岡県福岡市城南区別府団地');
ok($zip->set_number('8140111')->is_valid_number, '福岡県福岡市城南区茶山');
ok($zip->set_number('8140112')->is_valid_number, '福岡県福岡市城南区友丘');
ok($zip->set_number('8140113')->is_valid_number, '福岡県福岡市城南区田島');
ok($zip->set_number('8140114')->is_valid_number, '福岡県福岡市城南区金山団地');
ok($zip->set_number('8140121')->is_valid_number, '福岡県福岡市城南区神松寺');
ok($zip->set_number('8140122')->is_valid_number, '福岡県福岡市城南区友泉亭');
ok($zip->set_number('8140123')->is_valid_number, '福岡県福岡市城南区長尾');
ok($zip->set_number('8140131')->is_valid_number, '福岡県福岡市城南区松山');
ok($zip->set_number('8140132')->is_valid_number, '福岡県福岡市城南区干隈');
ok($zip->set_number('8140133')->is_valid_number, '福岡県福岡市城南区七隈');
ok($zip->set_number('8140134')->is_valid_number, '福岡県福岡市城南区飯倉');
ok($zip->set_number('8140141')->is_valid_number, '福岡県福岡市城南区西片江');
ok($zip->set_number('8140142')->is_valid_number, '福岡県福岡市城南区片江');
ok($zip->set_number('8140143')->is_valid_number, '福岡県福岡市城南区南片江');
ok($zip->set_number('8140144')->is_valid_number, '福岡県福岡市城南区梅林');
ok($zip->set_number('8140151')->is_valid_number, '福岡県福岡市城南区堤');
ok($zip->set_number('8140152')->is_valid_number, '福岡県福岡市城南区堤団地');
ok($zip->set_number('8140153')->is_valid_number, '福岡県福岡市城南区樋井川');
ok($zip->set_number('8140154')->is_valid_number, '福岡県福岡市城南区宝台団地');
ok($zip->set_number('8140155')->is_valid_number, '福岡県福岡市城南区東油山');
ok($zip->set_number('8140161')->is_valid_number, '福岡県福岡市早良区飯倉');
ok($zip->set_number('8140162')->is_valid_number, '福岡県福岡市早良区星の原団地');
ok($zip->set_number('8140163')->is_valid_number, '福岡県福岡市早良区干隈');
ok($zip->set_number('8140164')->is_valid_number, '福岡県福岡市早良区賀茂');
ok($zip->set_number('8140165')->is_valid_number, '福岡県福岡市早良区次郎丸');
ok($zip->set_number('8140171')->is_valid_number, '福岡県福岡市早良区野芥');
ok($zip->set_number('8140172')->is_valid_number, '福岡県福岡市早良区梅林');
ok($zip->set_number('8140173')->is_valid_number, '福岡県福岡市早良区西油山');
ok($zip->set_number('8140174')->is_valid_number, '福岡県福岡市早良区田隈');
ok($zip->set_number('8140175')->is_valid_number, '福岡県福岡市早良区田村');
ok($zip->set_number('8140176')->is_valid_number, '福岡県福岡市早良区四箇田団地');
ok($zip->set_number('8140177')->is_valid_number, '福岡県福岡市早良区田');
ok($zip->set_number('8150000')->is_valid_number, '福岡県福岡市南区以下に掲載がない場合');
ok($zip->set_number('8150001')->is_valid_number, '福岡県福岡市南区五十川');
ok($zip->set_number('8150004')->is_valid_number, '福岡県福岡市南区高木');
ok($zip->set_number('8150031')->is_valid_number, '福岡県福岡市南区清水');
ok($zip->set_number('8150032')->is_valid_number, '福岡県福岡市南区塩原');
ok($zip->set_number('8150033')->is_valid_number, '福岡県福岡市南区大橋');
ok($zip->set_number('8150034')->is_valid_number, '福岡県福岡市南区南大橋');
ok($zip->set_number('8150035')->is_valid_number, '福岡県福岡市南区向野');
ok($zip->set_number('8150036')->is_valid_number, '福岡県福岡市南区筑紫丘');
ok($zip->set_number('8150037')->is_valid_number, '福岡県福岡市南区玉川町');
ok($zip->set_number('8150038')->is_valid_number, '福岡県福岡市南区大橋団地');
ok($zip->set_number('8150041')->is_valid_number, '福岡県福岡市南区野間');
ok($zip->set_number('8150042')->is_valid_number, '福岡県福岡市南区若久');
ok($zip->set_number('8150048')->is_valid_number, '福岡県福岡市南区若久団地');
ok($zip->set_number('8150063')->is_valid_number, '福岡県福岡市南区柳河内');
ok($zip->set_number('8150071')->is_valid_number, '福岡県福岡市南区平和');
ok($zip->set_number('8150072')->is_valid_number, '福岡県福岡市南区多賀');
ok($zip->set_number('8150073')->is_valid_number, '福岡県福岡市南区大池');
ok($zip->set_number('8150074')->is_valid_number, '福岡県福岡市南区寺塚');
ok($zip->set_number('8150075')->is_valid_number, '福岡県福岡市南区長丘');
ok($zip->set_number('8150081')->is_valid_number, '福岡県福岡市南区那の川');
ok($zip->set_number('8150082')->is_valid_number, '福岡県福岡市南区大楠');
ok($zip->set_number('8150083')->is_valid_number, '福岡県福岡市南区高宮');
ok($zip->set_number('8150084')->is_valid_number, '福岡県福岡市南区市崎');
ok($zip->set_number('8160000')->is_valid_number, '福岡県春日市以下に掲載がない場合');
ok($zip->set_number('8160000')->is_valid_number, '福岡県大野城市以下に掲載がない場合');
ok($zip->set_number('8160801')->is_valid_number, '福岡県春日市春日原東町');
ok($zip->set_number('8160802')->is_valid_number, '福岡県春日市春日原北町');
ok($zip->set_number('8160803')->is_valid_number, '福岡県春日市春日原南町');
ok($zip->set_number('8160804')->is_valid_number, '福岡県春日市原町');
ok($zip->set_number('8160805')->is_valid_number, '福岡県春日市千歳町');
ok($zip->set_number('8160806')->is_valid_number, '福岡県春日市光町');
ok($zip->set_number('8160807')->is_valid_number, '福岡県春日市宝町');
ok($zip->set_number('8160811')->is_valid_number, '福岡県春日市春日公園');
ok($zip->set_number('8160812')->is_valid_number, '福岡県春日市平田台');
ok($zip->set_number('8160813')->is_valid_number, '福岡県春日市惣利');
ok($zip->set_number('8160814')->is_valid_number, '福岡県春日市春日');
ok($zip->set_number('8160821')->is_valid_number, '福岡県春日市若葉台東');
ok($zip->set_number('8160822')->is_valid_number, '福岡県春日市ちくし台');
ok($zip->set_number('8160823')->is_valid_number, '福岡県春日市若葉台西');
ok($zip->set_number('8160824')->is_valid_number, '福岡県春日市小倉');
ok($zip->set_number('8160825')->is_valid_number, '福岡県春日市伯玄町');
ok($zip->set_number('8160826')->is_valid_number, '福岡県春日市小倉東');
ok($zip->set_number('8160831')->is_valid_number, '福岡県春日市大谷');
ok($zip->set_number('8160832')->is_valid_number, '福岡県春日市紅葉ケ丘西');
ok($zip->set_number('8160833')->is_valid_number, '福岡県春日市紅葉ケ丘東');
ok($zip->set_number('8160841')->is_valid_number, '福岡県春日市塚原台');
ok($zip->set_number('8160842')->is_valid_number, '福岡県春日市下白水');
ok($zip->set_number('8160843')->is_valid_number, '福岡県春日市松ケ丘');
ok($zip->set_number('8160844')->is_valid_number, '福岡県春日市上白水');
ok($zip->set_number('8160845')->is_valid_number, '福岡県春日市白水ケ丘');
ok($zip->set_number('8160846')->is_valid_number, '福岡県春日市下白水南');
ok($zip->set_number('8160847')->is_valid_number, '福岡県春日市大土居');
ok($zip->set_number('8160848')->is_valid_number, '福岡県春日市白水池');
ok($zip->set_number('8160849')->is_valid_number, '福岡県春日市星見ヶ丘');
ok($zip->set_number('8160851')->is_valid_number, '福岡県春日市昇町');
ok($zip->set_number('8160852')->is_valid_number, '福岡県春日市一の谷');
ok($zip->set_number('8160853')->is_valid_number, '福岡県春日市泉');
ok($zip->set_number('8160854')->is_valid_number, '福岡県春日市下白水北');
ok($zip->set_number('8160855')->is_valid_number, '福岡県春日市天神山');
ok($zip->set_number('8160861')->is_valid_number, '福岡県春日市岡本');
ok($zip->set_number('8160862')->is_valid_number, '福岡県春日市弥生');
ok($zip->set_number('8160863')->is_valid_number, '福岡県春日市須玖南');
ok($zip->set_number('8160864')->is_valid_number, '福岡県春日市須玖北');
ok($zip->set_number('8160871')->is_valid_number, '福岡県春日市須玖');
ok($zip->set_number('8160872')->is_valid_number, '福岡県春日市桜ケ丘');
ok($zip->set_number('8160873')->is_valid_number, '福岡県春日市日の出町');
ok($zip->set_number('8160874')->is_valid_number, '福岡県春日市大和町');
ok($zip->set_number('8160901')->is_valid_number, '福岡県大野城市乙金東');
ok($zip->set_number('8160902')->is_valid_number, '福岡県大野城市乙金');
ok($zip->set_number('8160903')->is_valid_number, '福岡県大野城市乙金台');
ok($zip->set_number('8160904')->is_valid_number, '福岡県大野城市大池');
ok($zip->set_number('8160905')->is_valid_number, '福岡県大野城市川久保');
ok($zip->set_number('8160906')->is_valid_number, '福岡県大野城市中');
ok($zip->set_number('8160911')->is_valid_number, '福岡県大野城市大城');
ok($zip->set_number('8160912')->is_valid_number, '福岡県大野城市御笠川');
ok($zip->set_number('8160921')->is_valid_number, '福岡県大野城市仲畑');
ok($zip->set_number('8160922')->is_valid_number, '福岡県大野城市山田');
ok($zip->set_number('8160923')->is_valid_number, '福岡県大野城市雑餉隈町');
ok($zip->set_number('8160924')->is_valid_number, '福岡県大野城市栄町');
ok($zip->set_number('8160931')->is_valid_number, '福岡県大野城市筒井');
ok($zip->set_number('8160932')->is_valid_number, '福岡県大野城市瓦田');
ok($zip->set_number('8160933')->is_valid_number, '福岡県大野城市瑞穂町');
ok($zip->set_number('8160934')->is_valid_number, '福岡県大野城市曙町');
ok($zip->set_number('8160935')->is_valid_number, '福岡県大野城市錦町');
ok($zip->set_number('8160941')->is_valid_number, '福岡県大野城市東大利');
ok($zip->set_number('8160942')->is_valid_number, '福岡県大野城市中央');
ok($zip->set_number('8160943')->is_valid_number, '福岡県大野城市白木原');
ok($zip->set_number('8160951')->is_valid_number, '福岡県大野城市下大利団地');
ok($zip->set_number('8160952')->is_valid_number, '福岡県大野城市下大利');
ok($zip->set_number('8160953')->is_valid_number, '福岡県大野城市旭ケ丘');
ok($zip->set_number('8160954')->is_valid_number, '福岡県大野城市紫台');
ok($zip->set_number('8160955')->is_valid_number, '福岡県大野城市上大利');
ok($zip->set_number('8160956')->is_valid_number, '福岡県大野城市南大利');
ok($zip->set_number('8160961')->is_valid_number, '福岡県大野城市緑ケ丘');
ok($zip->set_number('8160962')->is_valid_number, '福岡県大野城市つつじケ丘');
ok($zip->set_number('8160963')->is_valid_number, '福岡県大野城市宮野台');
ok($zip->set_number('8160964')->is_valid_number, '福岡県大野城市南ケ丘');
ok($zip->set_number('8160971')->is_valid_number, '福岡県大野城市牛頸');
ok($zip->set_number('8160972')->is_valid_number, '福岡県大野城市平野台');
ok($zip->set_number('8160973')->is_valid_number, '福岡県大野城市横峰');
ok($zip->set_number('8160981')->is_valid_number, '福岡県大野城市若草');
ok($zip->set_number('8160982')->is_valid_number, '福岡県大野城市畑ケ坂');
ok($zip->set_number('8160983')->is_valid_number, '福岡県大野城市月の浦');
ok($zip->set_number('8170000')->is_valid_number, '長崎県対馬市以下に掲載がない場合');
ok($zip->set_number('8170001')->is_valid_number, '長崎県対馬市厳原町小浦');
ok($zip->set_number('8170002')->is_valid_number, '長崎県対馬市厳原町曲');
ok($zip->set_number('8170003')->is_valid_number, '長崎県対馬市厳原町南室');
ok($zip->set_number('8170005')->is_valid_number, '長崎県対馬市厳原町桟原');
ok($zip->set_number('8170006')->is_valid_number, '長崎県対馬市厳原町北里');
ok($zip->set_number('8170011')->is_valid_number, '長崎県対馬市厳原町宮谷');
ok($zip->set_number('8170012')->is_valid_number, '長崎県対馬市厳原町日吉');
ok($zip->set_number('8170013')->is_valid_number, '長崎県対馬市厳原町中村');
ok($zip->set_number('8170014')->is_valid_number, '長崎県対馬市厳原町天道茂');
ok($zip->set_number('8170015')->is_valid_number, '長崎県対馬市厳原町西里');
ok($zip->set_number('8170016')->is_valid_number, '長崎県対馬市厳原町東里');
ok($zip->set_number('8170021')->is_valid_number, '長崎県対馬市厳原町今屋敷');
ok($zip->set_number('8170022')->is_valid_number, '長崎県対馬市厳原町国分');
ok($zip->set_number('8170023')->is_valid_number, '長崎県対馬市厳原町田渕');
ok($zip->set_number('8170024')->is_valid_number, '長崎県対馬市厳原町大手橋');
ok($zip->set_number('8170031')->is_valid_number, '長崎県対馬市厳原町久田道');
ok($zip->set_number('8170032')->is_valid_number, '長崎県対馬市厳原町久田');
ok($zip->set_number('8170033')->is_valid_number, '長崎県対馬市厳原町尾浦');
ok($zip->set_number('8170034')->is_valid_number, '長崎県対馬市厳原町安神');
ok($zip->set_number('8170035')->is_valid_number, '長崎県対馬市厳原町久和');
ok($zip->set_number('8170151')->is_valid_number, '長崎県対馬市厳原町与良内院');
ok($zip->set_number('8170152')->is_valid_number, '長崎県対馬市厳原町豆酘内院');
ok($zip->set_number('8170153')->is_valid_number, '長崎県対馬市厳原町浅藻');
ok($zip->set_number('8170154')->is_valid_number, '長崎県対馬市厳原町豆酘');
ok($zip->set_number('8170155')->is_valid_number, '長崎県対馬市厳原町豆酘瀬');
ok($zip->set_number('8170156')->is_valid_number, '長崎県対馬市厳原町佐須瀬');
ok($zip->set_number('8170157')->is_valid_number, '長崎県対馬市厳原町内山');
ok($zip->set_number('8170241')->is_valid_number, '長崎県対馬市厳原町阿連');
ok($zip->set_number('8170242')->is_valid_number, '長崎県対馬市厳原町下原');
ok($zip->set_number('8170243')->is_valid_number, '長崎県対馬市厳原町樫根');
ok($zip->set_number('8170244')->is_valid_number, '長崎県対馬市厳原町久根浜');
ok($zip->set_number('8170245')->is_valid_number, '長崎県対馬市厳原町久根田舎');
ok($zip->set_number('8170246')->is_valid_number, '長崎県対馬市厳原町上槻');
ok($zip->set_number('8170247')->is_valid_number, '長崎県対馬市厳原町椎根');
ok($zip->set_number('8170248')->is_valid_number, '長崎県対馬市厳原町小茂田');
ok($zip->set_number('8170321')->is_valid_number, '長崎県対馬市美津島町洲藻');
ok($zip->set_number('8170322')->is_valid_number, '長崎県対馬市美津島町鶏知');
ok($zip->set_number('8170323')->is_valid_number, '長崎県対馬市美津島町大船越');
ok($zip->set_number('8170324')->is_valid_number, '長崎県対馬市美津島町久須保');
ok($zip->set_number('8170325')->is_valid_number, '長崎県対馬市美津島町緒方');
ok($zip->set_number('8170326')->is_valid_number, '長崎県対馬市美津島町根緒');
ok($zip->set_number('8170431')->is_valid_number, '長崎県対馬市美津島町尾崎');
ok($zip->set_number('8170432')->is_valid_number, '長崎県対馬市美津島町今里');
ok($zip->set_number('8170433')->is_valid_number, '長崎県対馬市美津島町加志');
ok($zip->set_number('8170434')->is_valid_number, '長崎県対馬市美津島町吹崎');
ok($zip->set_number('8170435')->is_valid_number, '長崎県対馬市美津島町箕形');
ok($zip->set_number('8170511')->is_valid_number, '長崎県対馬市美津島町竹敷');
ok($zip->set_number('8170512')->is_valid_number, '長崎県対馬市美津島町黒瀬');
ok($zip->set_number('8170513')->is_valid_number, '長崎県対馬市美津島町昼ケ浦');
ok($zip->set_number('8170514')->is_valid_number, '長崎県対馬市美津島町島山');
ok($zip->set_number('8171101')->is_valid_number, '長崎県対馬市美津島町小船越');
ok($zip->set_number('8171102')->is_valid_number, '長崎県対馬市美津島町芦浦');
ok($zip->set_number('8171103')->is_valid_number, '長崎県対馬市美津島町賀谷');
ok($zip->set_number('8171104')->is_valid_number, '長崎県対馬市美津島町濃部');
ok($zip->set_number('8171105')->is_valid_number, '長崎県対馬市美津島町大山');
ok($zip->set_number('8171106')->is_valid_number, '長崎県対馬市美津島町犬吠');
ok($zip->set_number('8171107')->is_valid_number, '長崎県対馬市美津島町鴨居瀬');
ok($zip->set_number('8171201')->is_valid_number, '長崎県対馬市豊玉町仁位');
ok($zip->set_number('8171202')->is_valid_number, '長崎県対馬市豊玉町和板');
ok($zip->set_number('8171212')->is_valid_number, '長崎県対馬市豊玉町曽');
ok($zip->set_number('8171213')->is_valid_number, '長崎県対馬市豊玉町千尋藻');
ok($zip->set_number('8171214')->is_valid_number, '長崎県対馬市豊玉町鑓川');
ok($zip->set_number('8171223')->is_valid_number, '長崎県対馬市豊玉町横浦');
ok($zip->set_number('8171231')->is_valid_number, '長崎県対馬市豊玉町糸瀬');
ok($zip->set_number('8171232')->is_valid_number, '長崎県対馬市豊玉町嵯峨');
ok($zip->set_number('8171233')->is_valid_number, '長崎県対馬市豊玉町貝鮒');
ok($zip->set_number('8171234')->is_valid_number, '長崎県対馬市豊玉町佐志賀');
ok($zip->set_number('8171241')->is_valid_number, '長崎県対馬市豊玉町貝口');
ok($zip->set_number('8171245')->is_valid_number, '長崎県対馬市豊玉町唐洲');
ok($zip->set_number('8171246')->is_valid_number, '長崎県対馬市豊玉町廻');
ok($zip->set_number('8171251')->is_valid_number, '長崎県対馬市豊玉町田');
ok($zip->set_number('8171252')->is_valid_number, '長崎県対馬市豊玉町大綱');
ok($zip->set_number('8171253')->is_valid_number, '長崎県対馬市豊玉町卯麦');
ok($zip->set_number('8171254')->is_valid_number, '長崎県対馬市豊玉町佐保');
ok($zip->set_number('8171255')->is_valid_number, '長崎県対馬市豊玉町志多浦');
ok($zip->set_number('8171256')->is_valid_number, '長崎県対馬市豊玉町小綱');
ok($zip->set_number('8171257')->is_valid_number, '長崎県対馬市豊玉町銘');
ok($zip->set_number('8171301')->is_valid_number, '長崎県対馬市峰町三根');
ok($zip->set_number('8171302')->is_valid_number, '長崎県対馬市峰町狩尾');
ok($zip->set_number('8171303')->is_valid_number, '長崎県対馬市峰町木坂');
ok($zip->set_number('8171304')->is_valid_number, '長崎県対馬市峰町青海');
ok($zip->set_number('8171305')->is_valid_number, '長崎県対馬市峰町津柳');
ok($zip->set_number('8171306')->is_valid_number, '長崎県対馬市峰町吉田');
ok($zip->set_number('8171307')->is_valid_number, '長崎県対馬市峰町賀佐');
ok($zip->set_number('8171411')->is_valid_number, '長崎県対馬市峰町櫛');
ok($zip->set_number('8171412')->is_valid_number, '長崎県対馬市峰町佐賀');
ok($zip->set_number('8171413')->is_valid_number, '長崎県対馬市峰町志多賀');
ok($zip->set_number('8171511')->is_valid_number, '長崎県対馬市上県町鹿見');
ok($zip->set_number('8171512')->is_valid_number, '長崎県対馬市上県町久原');
ok($zip->set_number('8171513')->is_valid_number, '長崎県対馬市上県町女連');
ok($zip->set_number('8171521')->is_valid_number, '長崎県対馬市上県町飼所');
ok($zip->set_number('8171522')->is_valid_number, '長崎県対馬市上県町樫滝');
ok($zip->set_number('8171523')->is_valid_number, '長崎県対馬市上県町瀬田');
ok($zip->set_number('8171524')->is_valid_number, '長崎県対馬市上県町犬ケ浦');
ok($zip->set_number('8171525')->is_valid_number, '長崎県対馬市上県町御園');
ok($zip->set_number('8171531')->is_valid_number, '長崎県対馬市上県町越高');
ok($zip->set_number('8171532')->is_valid_number, '長崎県対馬市上県町伊奈');
ok($zip->set_number('8171533')->is_valid_number, '長崎県対馬市上県町志多留');
ok($zip->set_number('8171601')->is_valid_number, '長崎県対馬市上県町西津屋');
ok($zip->set_number('8171602')->is_valid_number, '長崎県対馬市上県町佐須奈');
ok($zip->set_number('8171603')->is_valid_number, '長崎県対馬市上県町佐護');
ok($zip->set_number('8171701')->is_valid_number, '長崎県対馬市上対馬町比田勝');
ok($zip->set_number('8171702')->is_valid_number, '長崎県対馬市上対馬町古里');
ok($zip->set_number('8171703')->is_valid_number, '長崎県対馬市上対馬町西泊');
ok($zip->set_number('8171704')->is_valid_number, '長崎県対馬市上対馬町網代');
ok($zip->set_number('8171711')->is_valid_number, '長崎県対馬市上対馬町冨浦');
ok($zip->set_number('8171712')->is_valid_number, '長崎県対馬市上対馬町唐舟志');
ok($zip->set_number('8171713')->is_valid_number, '長崎県対馬市上対馬町浜久須');
ok($zip->set_number('8171714')->is_valid_number, '長崎県対馬市上対馬町玖須');
ok($zip->set_number('8171715')->is_valid_number, '長崎県対馬市上対馬町大増');
ok($zip->set_number('8171721')->is_valid_number, '長崎県対馬市上対馬町河内');
ok($zip->set_number('8171722')->is_valid_number, '長崎県対馬市上対馬町大浦');
ok($zip->set_number('8171723')->is_valid_number, '長崎県対馬市上対馬町鰐浦');
ok($zip->set_number('8171724')->is_valid_number, '長崎県対馬市上対馬町豊');
ok($zip->set_number('8171725')->is_valid_number, '長崎県対馬市上対馬町泉');
ok($zip->set_number('8172241')->is_valid_number, '長崎県対馬市上対馬町小鹿');
ok($zip->set_number('8172242')->is_valid_number, '長崎県対馬市上対馬町一重');
ok($zip->set_number('8172243')->is_valid_number, '長崎県対馬市上対馬町芦見');
ok($zip->set_number('8172331')->is_valid_number, '長崎県対馬市上対馬町琴');
ok($zip->set_number('8172332')->is_valid_number, '長崎県対馬市上対馬町五根緒');
ok($zip->set_number('8172333')->is_valid_number, '長崎県対馬市上対馬町舟志');
ok($zip->set_number('8180000')->is_valid_number, '福岡県筑紫野市以下に掲載がない場合');
ok($zip->set_number('8180001')->is_valid_number, '福岡県筑紫野市柚須原');
ok($zip->set_number('8180002')->is_valid_number, '福岡県筑紫野市香園');
ok($zip->set_number('8180003')->is_valid_number, '福岡県筑紫野市山家');
ok($zip->set_number('8180004')->is_valid_number, '福岡県筑紫野市吉木');
ok($zip->set_number('8180005')->is_valid_number, '福岡県筑紫野市原');
ok($zip->set_number('8180006')->is_valid_number, '福岡県筑紫野市大石');
ok($zip->set_number('8180007')->is_valid_number, '福岡県筑紫野市本道寺');
ok($zip->set_number('8180011')->is_valid_number, '福岡県筑紫野市阿志岐');
ok($zip->set_number('8180012')->is_valid_number, '福岡県筑紫野市天山');
ok($zip->set_number('8180013')->is_valid_number, '福岡県筑紫野市岡田');
ok($zip->set_number('8180014')->is_valid_number, '福岡県筑紫野市牛島');
ok($zip->set_number('8180021')->is_valid_number, '福岡県筑紫野市下見');
ok($zip->set_number('8180022')->is_valid_number, '福岡県筑紫野市筑紫駅前通');
ok($zip->set_number('8180023')->is_valid_number, '福岡県筑紫野市若江');
ok($zip->set_number('8180024')->is_valid_number, '福岡県筑紫野市原田');
ok($zip->set_number('8180025')->is_valid_number, '福岡県筑紫野市筑紫');
ok($zip->set_number('8180026')->is_valid_number, '福岡県筑紫野市美咲');
ok($zip->set_number('8180031')->is_valid_number, '福岡県筑紫野市隈');
ok($zip->set_number('8180032')->is_valid_number, '福岡県筑紫野市西小田');
ok($zip->set_number('8180034')->is_valid_number, '福岡県筑紫野市美しが丘南');
ok($zip->set_number('8180035')->is_valid_number, '福岡県筑紫野市美しが丘北');
ok($zip->set_number('8180036')->is_valid_number, '福岡県筑紫野市光が丘');
ok($zip->set_number('8180041')->is_valid_number, '福岡県筑紫野市上古賀');
ok($zip->set_number('8180042')->is_valid_number, '福岡県筑紫野市立明寺');
ok($zip->set_number('8180043')->is_valid_number, '福岡県筑紫野市むさしケ丘');
ok($zip->set_number('8180044')->is_valid_number, '福岡県筑紫野市萩原');
ok($zip->set_number('8180045')->is_valid_number, '福岡県筑紫野市平等寺');
ok($zip->set_number('8180046')->is_valid_number, '福岡県筑紫野市山口');
ok($zip->set_number('8180047')->is_valid_number, '福岡県筑紫野市古賀');
ok($zip->set_number('8180052')->is_valid_number, '福岡県筑紫野市武藏');
ok($zip->set_number('8180053')->is_valid_number, '福岡県筑紫野市天拝坂');
ok($zip->set_number('8180054')->is_valid_number, '福岡県筑紫野市杉塚');
ok($zip->set_number('8180056')->is_valid_number, '福岡県筑紫野市二日市北');
ok($zip->set_number('8180057')->is_valid_number, '福岡県筑紫野市二日市南');
ok($zip->set_number('8180058')->is_valid_number, '福岡県筑紫野市湯町');
ok($zip->set_number('8180059')->is_valid_number, '福岡県筑紫野市塔原東');
ok($zip->set_number('8180061')->is_valid_number, '福岡県筑紫野市紫');
ok($zip->set_number('8180063')->is_valid_number, '福岡県筑紫野市桜台');
ok($zip->set_number('8180064')->is_valid_number, '福岡県筑紫野市常松');
ok($zip->set_number('8180065')->is_valid_number, '福岡県筑紫野市諸田');
ok($zip->set_number('8180066')->is_valid_number, '福岡県筑紫野市永岡');
ok($zip->set_number('8180067')->is_valid_number, '福岡県筑紫野市俗明院');
ok($zip->set_number('8180068')->is_valid_number, '福岡県筑紫野市石崎');
ok($zip->set_number('8180071')->is_valid_number, '福岡県筑紫野市二日市西');
ok($zip->set_number('8180072')->is_valid_number, '福岡県筑紫野市二日市中央');
ok($zip->set_number('8180073')->is_valid_number, '福岡県筑紫野市塔原西');
ok($zip->set_number('8180074')->is_valid_number, '福岡県筑紫野市塔原南');
ok($zip->set_number('8180081')->is_valid_number, '福岡県筑紫野市針摺東');
ok($zip->set_number('8180082')->is_valid_number, '福岡県筑紫野市針摺南');
ok($zip->set_number('8180083')->is_valid_number, '福岡県筑紫野市針摺中央');
ok($zip->set_number('8180084')->is_valid_number, '福岡県筑紫野市針摺西');
ok($zip->set_number('8180085')->is_valid_number, '福岡県筑紫野市針摺北');
ok($zip->set_number('8180100')->is_valid_number, '福岡県太宰府市以下に掲載がない場合');
ok($zip->set_number('8180101')->is_valid_number, '福岡県太宰府市観世音寺');
ok($zip->set_number('8180102')->is_valid_number, '福岡県太宰府市白川');
ok($zip->set_number('8180103')->is_valid_number, '福岡県太宰府市朱雀');
ok($zip->set_number('8180104')->is_valid_number, '福岡県太宰府市通古賀');
ok($zip->set_number('8180105')->is_valid_number, '福岡県太宰府市都府楼南');
ok($zip->set_number('8180110')->is_valid_number, '福岡県太宰府市御笠');
ok($zip->set_number('8180111')->is_valid_number, '福岡県太宰府市三条');
ok($zip->set_number('8180114')->is_valid_number, '福岡県太宰府市北谷');
ok($zip->set_number('8180115')->is_valid_number, '福岡県太宰府市内山');
ok($zip->set_number('8180117')->is_valid_number, '福岡県太宰府市宰府');
ok($zip->set_number('8180118')->is_valid_number, '福岡県太宰府市石坂');
ok($zip->set_number('8180119')->is_valid_number, '福岡県太宰府市連歌屋');
ok($zip->set_number('8180121')->is_valid_number, '福岡県太宰府市青山');
ok($zip->set_number('8180122')->is_valid_number, '福岡県太宰府市高雄');
ok($zip->set_number('8180123')->is_valid_number, '福岡県太宰府市梅ケ丘');
ok($zip->set_number('8180124')->is_valid_number, '福岡県太宰府市梅香苑');
ok($zip->set_number('8180125')->is_valid_number, '福岡県太宰府市五条');
ok($zip->set_number('8180131')->is_valid_number, '福岡県太宰府市水城');
ok($zip->set_number('8180132')->is_valid_number, '福岡県太宰府市国分');
ok($zip->set_number('8180133')->is_valid_number, '福岡県太宰府市坂本');
ok($zip->set_number('8180134')->is_valid_number, '福岡県太宰府市大佐野');
ok($zip->set_number('8180135')->is_valid_number, '福岡県太宰府市向佐野');
ok($zip->set_number('8180136')->is_valid_number, '福岡県太宰府市長浦台');
ok($zip->set_number('8180137')->is_valid_number, '福岡県太宰府市青葉台');
ok($zip->set_number('8180138')->is_valid_number, '福岡県太宰府市吉松');
ok($zip->set_number('8180139')->is_valid_number, '福岡県太宰府市宰都');
ok($zip->set_number('8190000')->is_valid_number, '福岡県福岡市西区以下に掲載がない場合');
ok($zip->set_number('8190001')->is_valid_number, '福岡県福岡市西区小戸');
ok($zip->set_number('8190002')->is_valid_number, '福岡県福岡市西区姪の浜');
ok($zip->set_number('8190005')->is_valid_number, '福岡県福岡市西区内浜');
ok($zip->set_number('8190006')->is_valid_number, '福岡県福岡市西区姪浜駅南');
ok($zip->set_number('8190007')->is_valid_number, '福岡県福岡市西区愛宕南');
ok($zip->set_number('8190011')->is_valid_number, '福岡県福岡市西区小呂島');
ok($zip->set_number('8190012')->is_valid_number, '福岡県福岡市西区能古');
ok($zip->set_number('8190013')->is_valid_number, '福岡県福岡市西区愛宕浜');
ok($zip->set_number('8190014')->is_valid_number, '福岡県福岡市西区豊浜');
ok($zip->set_number('8190015')->is_valid_number, '福岡県福岡市西区愛宕');
ok($zip->set_number('8190021')->is_valid_number, '福岡県福岡市西区大町団地');
ok($zip->set_number('8190022')->is_valid_number, '福岡県福岡市西区福重');
ok($zip->set_number('8190023')->is_valid_number, '福岡県福岡市西区福重団地');
ok($zip->set_number('8190024')->is_valid_number, '福岡県福岡市西区十郎川団地');
ok($zip->set_number('8190025')->is_valid_number, '福岡県福岡市西区石丸');
ok($zip->set_number('8190030')->is_valid_number, '福岡県福岡市西区室見が丘');
ok($zip->set_number('8190031')->is_valid_number, '福岡県福岡市西区橋本(丁目)');
ok($zip->set_number('8190032')->is_valid_number, '福岡県福岡市西区戸切');
ok($zip->set_number('8190033')->is_valid_number, '福岡県福岡市西区橋本(大字)');
ok($zip->set_number('8190034')->is_valid_number, '福岡県福岡市西区田');
ok($zip->set_number('8190035')->is_valid_number, '福岡県福岡市西区金武');
ok($zip->set_number('8190036')->is_valid_number, '福岡県福岡市西区吉武');
ok($zip->set_number('8190037')->is_valid_number, '福岡県福岡市西区飯盛');
ok($zip->set_number('8190038')->is_valid_number, '福岡県福岡市西区羽根戸');
ok($zip->set_number('8190039')->is_valid_number, '福岡県福岡市西区西入部');
ok($zip->set_number('8190041')->is_valid_number, '福岡県福岡市西区拾六町');
ok($zip->set_number('8190042')->is_valid_number, '福岡県福岡市西区壱岐団地');
ok($zip->set_number('8190043')->is_valid_number, '福岡県福岡市西区野方');
ok($zip->set_number('8190044')->is_valid_number, '福岡県福岡市西区生松台');
ok($zip->set_number('8190045')->is_valid_number, '福岡県福岡市西区拾六町団地');
ok($zip->set_number('8190046')->is_valid_number, '福岡県福岡市西区西の丘');
ok($zip->set_number('8190051')->is_valid_number, '福岡県福岡市西区下山門団地');
ok($zip->set_number('8190052')->is_valid_number, '福岡県福岡市西区下山門');
ok($zip->set_number('8190053')->is_valid_number, '福岡県福岡市西区城の原団地');
ok($zip->set_number('8190054')->is_valid_number, '福岡県福岡市西区上山門');
ok($zip->set_number('8190055')->is_valid_number, '福岡県福岡市西区生の松原');
ok($zip->set_number('8190161')->is_valid_number, '福岡県福岡市西区今宿東');
ok($zip->set_number('8190162')->is_valid_number, '福岡県福岡市西区今宿青木');
ok($zip->set_number('8190163')->is_valid_number, '福岡県福岡市西区今宿上ノ原');
ok($zip->set_number('8190164')->is_valid_number, '福岡県福岡市西区今宿町');
ok($zip->set_number('8190165')->is_valid_number, '福岡県福岡市西区今津');
ok($zip->set_number('8190166')->is_valid_number, '福岡県福岡市西区横浜(1~2丁目)');
ok($zip->set_number('8190167')->is_valid_number, '福岡県福岡市西区今宿');
ok($zip->set_number('8190168')->is_valid_number, '福岡県福岡市西区今宿駅前');
ok($zip->set_number('8190169')->is_valid_number, '福岡県福岡市西区今宿西');
ok($zip->set_number('8190201')->is_valid_number, '福岡県福岡市西区宮浦');
ok($zip->set_number('8190202')->is_valid_number, '福岡県福岡市西区西浦');
ok($zip->set_number('8190203')->is_valid_number, '福岡県福岡市西区小田');
ok($zip->set_number('8190204')->is_valid_number, '福岡県福岡市西区草場');
ok($zip->set_number('8190205')->is_valid_number, '福岡県福岡市西区玄界島');
ok($zip->set_number('8190366')->is_valid_number, '福岡県福岡市西区横浜(3丁目)');
ok($zip->set_number('8190367')->is_valid_number, '福岡県福岡市西区西都');
ok($zip->set_number('8190370')->is_valid_number, '福岡県福岡市西区丸川');
ok($zip->set_number('8190371')->is_valid_number, '福岡県福岡市西区飯氏');
ok($zip->set_number('8190372')->is_valid_number, '福岡県福岡市西区宇田川原');
ok($zip->set_number('8190373')->is_valid_number, '福岡県福岡市西区周船寺');
ok($zip->set_number('8190374')->is_valid_number, '福岡県福岡市西区千里');
ok($zip->set_number('8190375')->is_valid_number, '福岡県福岡市西区徳永');
ok($zip->set_number('8190376')->is_valid_number, '福岡県福岡市西区女原');
ok($zip->set_number('8190377')->is_valid_number, '福岡県福岡市西区女原北');
ok($zip->set_number('8190378')->is_valid_number, '福岡県福岡市西区徳永北');
ok($zip->set_number('8190379')->is_valid_number, '福岡県福岡市西区北原');
ok($zip->set_number('8190380')->is_valid_number, '福岡県福岡市西区田尻東');
ok($zip->set_number('8190381')->is_valid_number, '福岡県福岡市西区泉');
ok($zip->set_number('8190382')->is_valid_number, '福岡県福岡市西区桑原');
ok($zip->set_number('8190383')->is_valid_number, '福岡県福岡市西区田尻');
ok($zip->set_number('8190384')->is_valid_number, '福岡県福岡市西区太郎丸');
ok($zip->set_number('8190385')->is_valid_number, '福岡県福岡市西区元岡');
ok($zip->set_number('8190386')->is_valid_number, '福岡県福岡市西区元浜');
ok($zip->set_number('8190387')->is_valid_number, '福岡県福岡市西区富士見');
ok($zip->set_number('8190388')->is_valid_number, '福岡県福岡市西区九大新町');
ok($zip->set_number('8190389')->is_valid_number, '福岡県福岡市西区学園通');
ok($zip->set_number('8191100')->is_valid_number, '福岡県糸島市以下に掲載がない場合');
ok($zip->set_number('8191101')->is_valid_number, '福岡県糸島市板持');
ok($zip->set_number('8191102')->is_valid_number, '福岡県糸島市高田');
ok($zip->set_number('8191103')->is_valid_number, '福岡県糸島市池田');
ok($zip->set_number('8191104')->is_valid_number, '福岡県糸島市波多江');
ok($zip->set_number('8191105')->is_valid_number, '福岡県糸島市潤');
ok($zip->set_number('8191106')->is_valid_number, '福岡県糸島市志登');
ok($zip->set_number('8191107')->is_valid_number, '福岡県糸島市波多江駅北');
ok($zip->set_number('8191108')->is_valid_number, '福岡県糸島市波多江駅南');
ok($zip->set_number('8191111')->is_valid_number, '福岡県糸島市泊');
ok($zip->set_number('8191112')->is_valid_number, '福岡県糸島市浦志');
ok($zip->set_number('8191113')->is_valid_number, '福岡県糸島市前原');
ok($zip->set_number('8191114')->is_valid_number, '福岡県糸島市新田');
ok($zip->set_number('8191115')->is_valid_number, '福岡県糸島市油比');
ok($zip->set_number('8191116')->is_valid_number, '福岡県糸島市前原中央');
ok($zip->set_number('8191117')->is_valid_number, '福岡県糸島市前原西');
ok($zip->set_number('8191118')->is_valid_number, '福岡県糸島市前原北');
ok($zip->set_number('8191119')->is_valid_number, '福岡県糸島市前原東');
ok($zip->set_number('8191120')->is_valid_number, '福岡県糸島市神在東');
ok($zip->set_number('8191121')->is_valid_number, '福岡県糸島市荻浦');
ok($zip->set_number('8191122')->is_valid_number, '福岡県糸島市東');
ok($zip->set_number('8191123')->is_valid_number, '福岡県糸島市神在');
ok($zip->set_number('8191124')->is_valid_number, '福岡県糸島市加布里');
ok($zip->set_number('8191125')->is_valid_number, '福岡県糸島市千早新田');
ok($zip->set_number('8191126')->is_valid_number, '福岡県糸島市岩本');
ok($zip->set_number('8191127')->is_valid_number, '福岡県糸島市有田中央');
ok($zip->set_number('8191128')->is_valid_number, '福岡県糸島市篠原東');
ok($zip->set_number('8191129')->is_valid_number, '福岡県糸島市篠原西');
ok($zip->set_number('8191130')->is_valid_number, '福岡県糸島市伊都の杜');
ok($zip->set_number('8191131')->is_valid_number, '福岡県糸島市篠原');
ok($zip->set_number('8191132')->is_valid_number, '福岡県糸島市有田');
ok($zip->set_number('8191133')->is_valid_number, '福岡県糸島市富');
ok($zip->set_number('8191134')->is_valid_number, '福岡県糸島市多久');
ok($zip->set_number('8191135')->is_valid_number, '福岡県糸島市大浦');
ok($zip->set_number('8191136')->is_valid_number, '福岡県糸島市美咲が丘');
ok($zip->set_number('8191137')->is_valid_number, '福岡県糸島市南風台');
ok($zip->set_number('8191138')->is_valid_number, '福岡県糸島市前原駅南');
ok($zip->set_number('8191139')->is_valid_number, '福岡県糸島市前原南');
ok($zip->set_number('8191141')->is_valid_number, '福岡県糸島市蔵持');
ok($zip->set_number('8191142')->is_valid_number, '福岡県糸島市八島');
ok($zip->set_number('8191143')->is_valid_number, '福岡県糸島市高上');
ok($zip->set_number('8191144')->is_valid_number, '福岡県糸島市山北');
ok($zip->set_number('8191145')->is_valid_number, '福岡県糸島市雷山');
ok($zip->set_number('8191146')->is_valid_number, '福岡県糸島市三坂');
ok($zip->set_number('8191147')->is_valid_number, '福岡県糸島市香力');
ok($zip->set_number('8191148')->is_valid_number, '福岡県糸島市神在西');
ok($zip->set_number('8191149')->is_valid_number, '福岡県糸島市千早新田西');
ok($zip->set_number('8191151')->is_valid_number, '福岡県糸島市本');
ok($zip->set_number('8191152')->is_valid_number, '福岡県糸島市飯原');
ok($zip->set_number('8191153')->is_valid_number, '福岡県糸島市長野');
ok($zip->set_number('8191154')->is_valid_number, '福岡県糸島市白糸');
ok($zip->set_number('8191155')->is_valid_number, '福岡県糸島市川付');
ok($zip->set_number('8191156')->is_valid_number, '福岡県糸島市瀬戸');
ok($zip->set_number('8191301')->is_valid_number, '福岡県糸島市志摩井田原');
ok($zip->set_number('8191302')->is_valid_number, '福岡県糸島市志摩吉田');
ok($zip->set_number('8191303')->is_valid_number, '福岡県糸島市志摩野北');
ok($zip->set_number('8191304')->is_valid_number, '福岡県糸島市志摩桜井');
ok($zip->set_number('8191305')->is_valid_number, '福岡県糸島市志摩馬場');
ok($zip->set_number('8191306')->is_valid_number, '福岡県糸島市志摩松隈');
ok($zip->set_number('8191311')->is_valid_number, '福岡県糸島市志摩津和崎');
ok($zip->set_number('8191312')->is_valid_number, '福岡県糸島市志摩初');
ok($zip->set_number('8191313')->is_valid_number, '福岡県糸島市志摩稲留');
ok($zip->set_number('8191314')->is_valid_number, '福岡県糸島市志摩師吉');
ok($zip->set_number('8191315')->is_valid_number, '福岡県糸島市志摩稲葉');
ok($zip->set_number('8191321')->is_valid_number, '福岡県糸島市志摩小富士');
ok($zip->set_number('8191322')->is_valid_number, '福岡県糸島市志摩御床');
ok($zip->set_number('8191323')->is_valid_number, '福岡県糸島市志摩小金丸');
ok($zip->set_number('8191324')->is_valid_number, '福岡県糸島市志摩東貝塚');
ok($zip->set_number('8191325')->is_valid_number, '福岡県糸島市志摩西貝塚');
ok($zip->set_number('8191331')->is_valid_number, '福岡県糸島市志摩久家');
ok($zip->set_number('8191332')->is_valid_number, '福岡県糸島市志摩船越');
ok($zip->set_number('8191333')->is_valid_number, '福岡県糸島市志摩新町');
ok($zip->set_number('8191334')->is_valid_number, '福岡県糸島市志摩岐志');
ok($zip->set_number('8191335')->is_valid_number, '福岡県糸島市志摩芥屋');
ok($zip->set_number('8191336')->is_valid_number, '福岡県糸島市志摩姫島');
ok($zip->set_number('8191561')->is_valid_number, '福岡県糸島市曽根');
ok($zip->set_number('8191562')->is_valid_number, '福岡県糸島市井田');
ok($zip->set_number('8191563')->is_valid_number, '福岡県糸島市高来寺');
ok($zip->set_number('8191564')->is_valid_number, '福岡県糸島市大門');
ok($zip->set_number('8191571')->is_valid_number, '福岡県糸島市高祖');
ok($zip->set_number('8191572')->is_valid_number, '福岡県糸島市末永');
ok($zip->set_number('8191573')->is_valid_number, '福岡県糸島市王丸');
ok($zip->set_number('8191574')->is_valid_number, '福岡県糸島市川原');
ok($zip->set_number('8191575')->is_valid_number, '福岡県糸島市西堂');
ok($zip->set_number('8191581')->is_valid_number, '福岡県糸島市瑞梅寺');
ok($zip->set_number('8191582')->is_valid_number, '福岡県糸島市井原');
ok($zip->set_number('8191583')->is_valid_number, '福岡県糸島市三雲');
ok($zip->set_number('8191601')->is_valid_number, '福岡県糸島市二丈深江');
ok($zip->set_number('8191611')->is_valid_number, '福岡県糸島市二丈片山');
ok($zip->set_number('8191612')->is_valid_number, '福岡県糸島市二丈松末(下松末)');
ok($zip->set_number('8191613')->is_valid_number, '福岡県糸島市二丈松末(その他)');
ok($zip->set_number('8191614')->is_valid_number, '福岡県糸島市二丈浜窪');
ok($zip->set_number('8191615')->is_valid_number, '福岡県糸島市二丈田中');
ok($zip->set_number('8191616')->is_valid_number, '福岡県糸島市二丈武');
ok($zip->set_number('8191621')->is_valid_number, '福岡県糸島市二丈上深江');
ok($zip->set_number('8191622')->is_valid_number, '福岡県糸島市二丈一貴山');
ok($zip->set_number('8191623')->is_valid_number, '福岡県糸島市二丈石崎');
ok($zip->set_number('8191624')->is_valid_number, '福岡県糸島市二丈満吉');
ok($zip->set_number('8191625')->is_valid_number, '福岡県糸島市二丈長石');
ok($zip->set_number('8191626')->is_valid_number, '福岡県糸島市二丈波呂');
ok($zip->set_number('8191627')->is_valid_number, '福岡県糸島市二丈松国');
ok($zip->set_number('8191631')->is_valid_number, '福岡県糸島市二丈福井');
ok($zip->set_number('8191641')->is_valid_number, '福岡県糸島市二丈吉井');
ok($zip->set_number('8191642')->is_valid_number, '福岡県糸島市二丈鹿家');
ok($zip->set_number('8200000')->is_valid_number, '福岡県飯塚市以下に掲載がない場合');
ok($zip->set_number('8200001')->is_valid_number, '福岡県飯塚市鯰田');
ok($zip->set_number('8200002')->is_valid_number, '福岡県飯塚市川島');
ok($zip->set_number('8200003')->is_valid_number, '福岡県飯塚市立岩');
ok($zip->set_number('8200004')->is_valid_number, '福岡県飯塚市新立岩');
ok($zip->set_number('8200005')->is_valid_number, '福岡県飯塚市新飯塚');
ok($zip->set_number('8200011')->is_valid_number, '福岡県飯塚市柏の森');
ok($zip->set_number('8200012')->is_valid_number, '福岡県飯塚市下三緒');
ok($zip->set_number('8200013')->is_valid_number, '福岡県飯塚市上三緒');
ok($zip->set_number('8200014')->is_valid_number, '福岡県飯塚市鶴三緒');
ok($zip->set_number('8200015')->is_valid_number, '福岡県飯塚市菰田');
ok($zip->set_number('8200016')->is_valid_number, '福岡県飯塚市菰田東');
ok($zip->set_number('8200017')->is_valid_number, '福岡県飯塚市菰田西');
ok($zip->set_number('8200018')->is_valid_number, '福岡県飯塚市芳雄町');
ok($zip->set_number('8200021')->is_valid_number, '福岡県飯塚市潤野');
ok($zip->set_number('8200022')->is_valid_number, '福岡県飯塚市明星寺');
ok($zip->set_number('8200031')->is_valid_number, '福岡県飯塚市西徳前');
ok($zip->set_number('8200032')->is_valid_number, '福岡県飯塚市東徳前');
ok($zip->set_number('8200033')->is_valid_number, '福岡県飯塚市徳前');
ok($zip->set_number('8200040')->is_valid_number, '福岡県飯塚市吉原町');
ok($zip->set_number('8200041')->is_valid_number, '福岡県飯塚市飯塚');
ok($zip->set_number('8200042')->is_valid_number, '福岡県飯塚市本町');
ok($zip->set_number('8200043')->is_valid_number, '福岡県飯塚市西町');
ok($zip->set_number('8200044')->is_valid_number, '福岡県飯塚市横田');
ok($zip->set_number('8200045')->is_valid_number, '福岡県飯塚市花瀬');
ok($zip->set_number('8200046')->is_valid_number, '福岡県飯塚市大日寺');
ok($zip->set_number('8200047')->is_valid_number, '福岡県飯塚市八木山');
ok($zip->set_number('8200048')->is_valid_number, '福岡県飯塚市蓮台寺');
ok($zip->set_number('8200049')->is_valid_number, '福岡県飯塚市建花寺');
ok($zip->set_number('8200051')->is_valid_number, '福岡県飯塚市庄司');
ok($zip->set_number('8200052')->is_valid_number, '福岡県飯塚市相田');
ok($zip->set_number('8200053')->is_valid_number, '福岡県飯塚市伊岐須');
ok($zip->set_number('8200054')->is_valid_number, '福岡県飯塚市伊川');
ok($zip->set_number('8200061')->is_valid_number, '福岡県飯塚市吉北');
ok($zip->set_number('8200062')->is_valid_number, '福岡県飯塚市目尾');
ok($zip->set_number('8200063')->is_valid_number, '福岡県飯塚市柳橋');
ok($zip->set_number('8200064')->is_valid_number, '福岡県飯塚市津島');
ok($zip->set_number('8200065')->is_valid_number, '福岡県飯塚市中');
ok($zip->set_number('8200066')->is_valid_number, '福岡県飯塚市幸袋');
ok($zip->set_number('8200067')->is_valid_number, '福岡県飯塚市川津');
ok($zip->set_number('8200068')->is_valid_number, '福岡県飯塚市片島');
ok($zip->set_number('8200069')->is_valid_number, '福岡県飯塚市宮町');
ok($zip->set_number('8200070')->is_valid_number, '福岡県飯塚市堀池');
ok($zip->set_number('8200071')->is_valid_number, '福岡県飯塚市忠隈');
ok($zip->set_number('8200072')->is_valid_number, '福岡県飯塚市南尾');
ok($zip->set_number('8200073')->is_valid_number, '福岡県飯塚市平恒');
ok($zip->set_number('8200074')->is_valid_number, '福岡県飯塚市楽市');
ok($zip->set_number('8200075')->is_valid_number, '福岡県飯塚市天道');
ok($zip->set_number('8200076')->is_valid_number, '福岡県飯塚市太郎丸');
ok($zip->set_number('8200077')->is_valid_number, '福岡県飯塚市椋本');
ok($zip->set_number('8200078')->is_valid_number, '福岡県飯塚市久保白');
ok($zip->set_number('8200079')->is_valid_number, '福岡県飯塚市高田');
ok($zip->set_number('8200081')->is_valid_number, '福岡県飯塚市枝国');
ok($zip->set_number('8200082')->is_valid_number, '福岡県飯塚市若菜');
ok($zip->set_number('8200083')->is_valid_number, '福岡県飯塚市秋松');
ok($zip->set_number('8200084')->is_valid_number, '福岡県飯塚市椿');
ok($zip->set_number('8200085')->is_valid_number, '福岡県飯塚市安恒');
ok($zip->set_number('8200086')->is_valid_number, '福岡県飯塚市津原');
ok($zip->set_number('8200087')->is_valid_number, '福岡県飯塚市舎利蔵');
ok($zip->set_number('8200088')->is_valid_number, '福岡県飯塚市弁分');
ok($zip->set_number('8200089')->is_valid_number, '福岡県飯塚市小正');
ok($zip->set_number('8200101')->is_valid_number, '福岡県飯塚市綱分');
ok($zip->set_number('8200102')->is_valid_number, '福岡県飯塚市山倉');
ok($zip->set_number('8200103')->is_valid_number, '福岡県飯塚市入水');
ok($zip->set_number('8200104')->is_valid_number, '福岡県飯塚市高倉');
ok($zip->set_number('8200105')->is_valid_number, '福岡県飯塚市筒野');
ok($zip->set_number('8200106')->is_valid_number, '福岡県飯塚市赤坂');
ok($zip->set_number('8200111')->is_valid_number, '福岡県飯塚市有安');
ok($zip->set_number('8200112')->is_valid_number, '福岡県飯塚市有井');
ok($zip->set_number('8200113')->is_valid_number, '福岡県飯塚市庄内元吉');
ok($zip->set_number('8200114')->is_valid_number, '福岡県飯塚市大門');
ok($zip->set_number('8200115')->is_valid_number, '福岡県飯塚市仁保');
ok($zip->set_number('8200116')->is_valid_number, '福岡県飯塚市多田');
ok($zip->set_number('8200200')->is_valid_number, '福岡県嘉麻市以下に掲載がない場合');
ok($zip->set_number('8200201')->is_valid_number, '福岡県嘉麻市漆生');
ok($zip->set_number('8200202')->is_valid_number, '福岡県嘉麻市山野');
ok($zip->set_number('8200203')->is_valid_number, '福岡県嘉麻市平');
ok($zip->set_number('8200204')->is_valid_number, '福岡県嘉麻市稲築才田');
ok($zip->set_number('8200205')->is_valid_number, '福岡県嘉麻市岩崎');
ok($zip->set_number('8200206')->is_valid_number, '福岡県嘉麻市鴨生');
ok($zip->set_number('8200207')->is_valid_number, '福岡県嘉麻市口春');
ok($zip->set_number('8200301')->is_valid_number, '福岡県嘉麻市牛隈');
ok($zip->set_number('8200302')->is_valid_number, '福岡県嘉麻市大隈町(その他)');
ok($zip->set_number('8200303')->is_valid_number, '福岡県嘉麻市中益');
ok($zip->set_number('8200304')->is_valid_number, '福岡県嘉麻市大隈(その他)');
ok($zip->set_number('8200305')->is_valid_number, '福岡県嘉麻市貞月');
ok($zip->set_number('8200306')->is_valid_number, '福岡県嘉麻市上西郷');
ok($zip->set_number('8200311')->is_valid_number, '福岡県嘉麻市上');
ok($zip->set_number('8200312')->is_valid_number, '福岡県嘉麻市宮吉');
ok($zip->set_number('8200313')->is_valid_number, '福岡県嘉麻市桑野');
ok($zip->set_number('8200314')->is_valid_number, '福岡県嘉麻市小野谷');
ok($zip->set_number('8200321')->is_valid_number, '福岡県嘉麻市馬見');
ok($zip->set_number('8200322')->is_valid_number, '福岡県嘉麻市屏');
ok($zip->set_number('8200323')->is_valid_number, '福岡県嘉麻市椎木');
ok($zip->set_number('8200331')->is_valid_number, '福岡県嘉麻市芥田');
ok($zip->set_number('8200332')->is_valid_number, '福岡県嘉麻市千手');
ok($zip->set_number('8200333')->is_valid_number, '福岡県嘉麻市大力');
ok($zip->set_number('8200334')->is_valid_number, '福岡県嘉麻市泉河内');
ok($zip->set_number('8200335')->is_valid_number, '福岡県嘉麻市東畑');
ok($zip->set_number('8200336')->is_valid_number, '福岡県嘉麻市嘉穂才田');
ok($zip->set_number('8200337')->is_valid_number, '福岡県嘉麻市九郎原');
ok($zip->set_number('8200501')->is_valid_number, '福岡県嘉麻市飯田');
ok($zip->set_number('8200502')->is_valid_number, '福岡県嘉麻市上臼井');
ok($zip->set_number('8200503')->is_valid_number, '福岡県嘉麻市光代');
ok($zip->set_number('8200504')->is_valid_number, '福岡県嘉麻市下臼井');
ok($zip->set_number('8200505')->is_valid_number, '福岡県嘉麻市西郷');
ok($zip->set_number('8200506')->is_valid_number, '福岡県嘉麻市平山');
ok($zip->set_number('8200600')->is_valid_number, '福岡県嘉穂郡桂川町以下に掲載がない場合');
ok($zip->set_number('8200601')->is_valid_number, '福岡県嘉穂郡桂川町内山田');
ok($zip->set_number('8200602')->is_valid_number, '福岡県嘉穂郡桂川町九郎丸');
ok($zip->set_number('8200603')->is_valid_number, '福岡県嘉穂郡桂川町寿命');
ok($zip->set_number('8200604')->is_valid_number, '福岡県嘉穂郡桂川町瀬戸');
ok($zip->set_number('8200605')->is_valid_number, '福岡県嘉穂郡桂川町中屋');
ok($zip->set_number('8200606')->is_valid_number, '福岡県嘉穂郡桂川町土居');
ok($zip->set_number('8200607')->is_valid_number, '福岡県嘉穂郡桂川町土師');
ok($zip->set_number('8200608')->is_valid_number, '福岡県嘉穂郡桂川町豆田');
ok($zip->set_number('8200609')->is_valid_number, '福岡県嘉穂郡桂川町吉隈');
ok($zip->set_number('8200701')->is_valid_number, '福岡県飯塚市長尾');
ok($zip->set_number('8200702')->is_valid_number, '福岡県飯塚市平塚');
ok($zip->set_number('8200703')->is_valid_number, '福岡県飯塚市北古賀');
ok($zip->set_number('8200704')->is_valid_number, '福岡県飯塚市阿恵');
ok($zip->set_number('8200705')->is_valid_number, '福岡県飯塚市筑穂元吉');
ok($zip->set_number('8200706')->is_valid_number, '福岡県飯塚市内野');
ok($zip->set_number('8200707')->is_valid_number, '福岡県飯塚市桑曲');
ok($zip->set_number('8200708')->is_valid_number, '福岡県飯塚市弥山');
ok($zip->set_number('8200709')->is_valid_number, '福岡県飯塚市馬敷');
ok($zip->set_number('8200711')->is_valid_number, '福岡県飯塚市山口');
ok($zip->set_number('8200712')->is_valid_number, '福岡県飯塚市大分');
ok($zip->set_number('8200713')->is_valid_number, '福岡県飯塚市内住');
ok($zip->set_number('8201100')->is_valid_number, '福岡県鞍手郡小竹町以下に掲載がない場合');
ok($zip->set_number('8201101')->is_valid_number, '福岡県鞍手郡小竹町御徳');
ok($zip->set_number('8201102')->is_valid_number, '福岡県鞍手郡小竹町赤地');
ok($zip->set_number('8201103')->is_valid_number, '福岡県鞍手郡小竹町勝野');
ok($zip->set_number('8201104')->is_valid_number, '福岡県鞍手郡小竹町新多');
ok($zip->set_number('8201105')->is_valid_number, '福岡県鞍手郡小竹町新山崎');
ok($zip->set_number('8201106')->is_valid_number, '福岡県鞍手郡小竹町南良津');
ok($zip->set_number('8201111')->is_valid_number, '福岡県飯塚市勢田');
ok($zip->set_number('8201112')->is_valid_number, '福岡県飯塚市鹿毛馬');
ok($zip->set_number('8201113')->is_valid_number, '福岡県飯塚市佐與');
ok($zip->set_number('8201114')->is_valid_number, '福岡県飯塚市口原');
ok($zip->set_number('8210002')->is_valid_number, '福岡県嘉麻市大隈町(猪之鼻)');
ok($zip->set_number('8210004')->is_valid_number, '福岡県嘉麻市大隈(1~11番地)');
ok($zip->set_number('8210011')->is_valid_number, '福岡県嘉麻市下山田');
ok($zip->set_number('8210012')->is_valid_number, '福岡県嘉麻市上山田');
ok($zip->set_number('8210013')->is_valid_number, '福岡県嘉麻市熊ケ畑');
ok($zip->set_number('8210014')->is_valid_number, '福岡県嘉麻市猪国');
ok($zip->set_number('8220000')->is_valid_number, '福岡県直方市以下に掲載がない場合');
ok($zip->set_number('8220001')->is_valid_number, '福岡県直方市感田');
ok($zip->set_number('8220002')->is_valid_number, '福岡県直方市頓野');
ok($zip->set_number('8220003')->is_valid_number, '福岡県直方市上頓野');
ok($zip->set_number('8220004')->is_valid_number, '福岡県直方市畑');
ok($zip->set_number('8220005')->is_valid_number, '福岡県直方市永満寺');
ok($zip->set_number('8220006')->is_valid_number, '福岡県直方市上境');
ok($zip->set_number('8220007')->is_valid_number, '福岡県直方市下境');
ok($zip->set_number('8220008')->is_valid_number, '福岡県直方市湯野原');
ok($zip->set_number('8220011')->is_valid_number, '福岡県直方市中泉');
ok($zip->set_number('8220012')->is_valid_number, '福岡県直方市赤地');
ok($zip->set_number('8220013')->is_valid_number, '福岡県直方市溝堀');
ok($zip->set_number('8220014')->is_valid_number, '福岡県直方市丸山町');
ok($zip->set_number('8220015')->is_valid_number, '福岡県直方市新町');
ok($zip->set_number('8220016')->is_valid_number, '福岡県直方市直方');
ok($zip->set_number('8220017')->is_valid_number, '福岡県直方市殿町');
ok($zip->set_number('8220021')->is_valid_number, '福岡県直方市新知町');
ok($zip->set_number('8220022')->is_valid_number, '福岡県直方市知古');
ok($zip->set_number('8220023')->is_valid_number, '福岡県直方市神正町');
ok($zip->set_number('8220024')->is_valid_number, '福岡県直方市須崎町');
ok($zip->set_number('8220025')->is_valid_number, '福岡県直方市日吉町');
ok($zip->set_number('8220026')->is_valid_number, '福岡県直方市津田町');
ok($zip->set_number('8220027')->is_valid_number, '福岡県直方市古町');
ok($zip->set_number('8220031')->is_valid_number, '福岡県直方市植木');
ok($zip->set_number('8220032')->is_valid_number, '福岡県直方市下新入');
ok($zip->set_number('8220033')->is_valid_number, '福岡県直方市上新入');
ok($zip->set_number('8220034')->is_valid_number, '福岡県直方市山部');
ok($zip->set_number('8220101')->is_valid_number, '福岡県宮若市福丸');
ok($zip->set_number('8220111')->is_valid_number, '福岡県宮若市金丸');
ok($zip->set_number('8220112')->is_valid_number, '福岡県宮若市原田');
ok($zip->set_number('8220113')->is_valid_number, '福岡県宮若市金生');
ok($zip->set_number('8220121')->is_valid_number, '福岡県宮若市湯原');
ok($zip->set_number('8220122')->is_valid_number, '福岡県宮若市下');
ok($zip->set_number('8220123')->is_valid_number, '福岡県宮若市三ケ畑');
ok($zip->set_number('8220124')->is_valid_number, '福岡県宮若市縁山畑');
ok($zip->set_number('8220131')->is_valid_number, '福岡県宮若市乙野');
ok($zip->set_number('8220132')->is_valid_number, '福岡県宮若市小伏');
ok($zip->set_number('8220133')->is_valid_number, '福岡県宮若市脇田');
ok($zip->set_number('8220134')->is_valid_number, '福岡県宮若市犬鳴');
ok($zip->set_number('8220141')->is_valid_number, '福岡県宮若市平');
ok($zip->set_number('8220142')->is_valid_number, '福岡県宮若市竹原');
ok($zip->set_number('8220143')->is_valid_number, '福岡県宮若市高野');
ok($zip->set_number('8220144')->is_valid_number, '福岡県宮若市稲光');
ok($zip->set_number('8220145')->is_valid_number, '福岡県宮若市宮永');
ok($zip->set_number('8220146')->is_valid_number, '福岡県宮若市黒丸');
ok($zip->set_number('8220151')->is_valid_number, '福岡県宮若市水原');
ok($zip->set_number('8220152')->is_valid_number, '福岡県宮若市沼口');
ok($zip->set_number('8220153')->is_valid_number, '福岡県宮若市山口');
ok($zip->set_number('8221101')->is_valid_number, '福岡県田川郡福智町赤池');
ok($zip->set_number('8221102')->is_valid_number, '福岡県田川郡福智町上野');
ok($zip->set_number('8221103')->is_valid_number, '福岡県田川郡福智町市場');
ok($zip->set_number('8221200')->is_valid_number, '福岡県田川郡福智町以下に掲載がない場合');
ok($zip->set_number('8221201')->is_valid_number, '福岡県田川郡福智町金田');
ok($zip->set_number('8221202')->is_valid_number, '福岡県田川郡福智町神崎');
ok($zip->set_number('8221211')->is_valid_number, '福岡県田川郡福智町伊方');
ok($zip->set_number('8221212')->is_valid_number, '福岡県田川郡福智町弁城');
ok($zip->set_number('8221300')->is_valid_number, '福岡県田川郡糸田町以下に掲載がない場合');
ok($zip->set_number('8221301')->is_valid_number, '福岡県田川郡糸田町堀川');
ok($zip->set_number('8221302')->is_valid_number, '福岡県田川郡糸田町大熊');
ok($zip->set_number('8221303')->is_valid_number, '福岡県田川郡糸田町桃山');
ok($zip->set_number('8221304')->is_valid_number, '福岡県田川郡糸田町自由ケ丘');
ok($zip->set_number('8221305')->is_valid_number, '福岡県田川郡糸田町宮床団地');
ok($zip->set_number('8221306')->is_valid_number, '福岡県田川郡糸田町貴船');
ok($zip->set_number('8221307')->is_valid_number, '福岡県田川郡糸田町宮床');
ok($zip->set_number('8221311')->is_valid_number, '福岡県田川郡糸田町北区');
ok($zip->set_number('8221312')->is_valid_number, '福岡県田川郡糸田町下糸田');
ok($zip->set_number('8221313')->is_valid_number, '福岡県田川郡糸田町打越');
ok($zip->set_number('8221314')->is_valid_number, '福岡県田川郡糸田町中糸田');
ok($zip->set_number('8221315')->is_valid_number, '福岡県田川郡糸田町宮川二');
ok($zip->set_number('8221316')->is_valid_number, '福岡県田川郡糸田町上糸田');
ok($zip->set_number('8221317')->is_valid_number, '福岡県田川郡糸田町宮川一');
ok($zip->set_number('8221318')->is_valid_number, '福岡県田川郡糸田町原');
ok($zip->set_number('8221321')->is_valid_number, '福岡県田川郡糸田町宮谷');
ok($zip->set_number('8221322')->is_valid_number, '福岡県田川郡糸田町西部');
ok($zip->set_number('8221323')->is_valid_number, '福岡県田川郡糸田町真岡');
ok($zip->set_number('8221324')->is_valid_number, '福岡県田川郡糸田町旭ケ丘');
ok($zip->set_number('8221325')->is_valid_number, '福岡県田川郡糸田町南糸田');
ok($zip->set_number('8221326')->is_valid_number, '福岡県田川郡糸田町鼡ケ池');
ok($zip->set_number('8221400')->is_valid_number, '福岡県田川郡香春町以下に掲載がない場合');
ok($zip->set_number('8221401')->is_valid_number, '福岡県田川郡香春町採銅所');
ok($zip->set_number('8221402')->is_valid_number, '福岡県田川郡香春町鏡山');
ok($zip->set_number('8221403')->is_valid_number, '福岡県田川郡香春町高野');
ok($zip->set_number('8221404')->is_valid_number, '福岡県田川郡香春町柿下');
ok($zip->set_number('8221405')->is_valid_number, '福岡県田川郡香春町中津原');
ok($zip->set_number('8221406')->is_valid_number, '福岡県田川郡香春町香春');
ok($zip->set_number('8230000')->is_valid_number, '福岡県宮若市以下に掲載がない場合');
ok($zip->set_number('8230001')->is_valid_number, '福岡県宮若市龍徳');
ok($zip->set_number('8230002')->is_valid_number, '福岡県宮若市鶴田');
ok($zip->set_number('8230003')->is_valid_number, '福岡県宮若市本城');
ok($zip->set_number('8230004')->is_valid_number, '福岡県宮若市磯光');
ok($zip->set_number('8230005')->is_valid_number, '福岡県宮若市上大隈');
ok($zip->set_number('8230011')->is_valid_number, '福岡県宮若市宮田');
ok($zip->set_number('8230012')->is_valid_number, '福岡県宮若市長井鶴');
ok($zip->set_number('8230013')->is_valid_number, '福岡県宮若市芹田');
ok($zip->set_number('8230014')->is_valid_number, '福岡県宮若市下有木');
ok($zip->set_number('8230015')->is_valid_number, '福岡県宮若市上有木');
ok($zip->set_number('8230016')->is_valid_number, '福岡県宮若市四郎丸');
ok($zip->set_number('8230017')->is_valid_number, '福岡県宮若市倉久');
ok($zip->set_number('8240000')->is_valid_number, '福岡県行橋市以下に掲載がない場合');
ok($zip->set_number('8240001')->is_valid_number, '福岡県行橋市行事');
ok($zip->set_number('8240002')->is_valid_number, '福岡県行橋市東大橋');
ok($zip->set_number('8240003')->is_valid_number, '福岡県行橋市大橋');
ok($zip->set_number('8240004')->is_valid_number, '福岡県行橋市金屋');
ok($zip->set_number('8240005')->is_valid_number, '福岡県行橋市中央');
ok($zip->set_number('8240006')->is_valid_number, '福岡県行橋市門樋町');
ok($zip->set_number('8240007')->is_valid_number, '福岡県行橋市神田町');
ok($zip->set_number('8240008')->is_valid_number, '福岡県行橋市宮市町');
ok($zip->set_number('8240011')->is_valid_number, '福岡県行橋市蓑島');
ok($zip->set_number('8240012')->is_valid_number, '福岡県行橋市文久');
ok($zip->set_number('8240013')->is_valid_number, '福岡県行橋市沓尾');
ok($zip->set_number('8240014')->is_valid_number, '福岡県行橋市長井');
ok($zip->set_number('8240015')->is_valid_number, '福岡県行橋市元永');
ok($zip->set_number('8240016')->is_valid_number, '福岡県行橋市津留');
ok($zip->set_number('8240017')->is_valid_number, '福岡県行橋市真菰');
ok($zip->set_number('8240018')->is_valid_number, '福岡県行橋市今井');
ok($zip->set_number('8240021')->is_valid_number, '福岡県行橋市馬場');
ok($zip->set_number('8240022')->is_valid_number, '福岡県行橋市稲童');
ok($zip->set_number('8240023')->is_valid_number, '福岡県行橋市松原');
ok($zip->set_number('8240024')->is_valid_number, '福岡県行橋市袋迫');
ok($zip->set_number('8240025')->is_valid_number, '福岡県行橋市東徳永');
ok($zip->set_number('8240026')->is_valid_number, '福岡県行橋市道場寺');
ok($zip->set_number('8240027')->is_valid_number, '福岡県行橋市高瀬');
ok($zip->set_number('8240028')->is_valid_number, '福岡県行橋市辻垣');
ok($zip->set_number('8240031')->is_valid_number, '福岡県行橋市西宮市');
ok($zip->set_number('8240032')->is_valid_number, '福岡県行橋市南大橋');
ok($zip->set_number('8240033')->is_valid_number, '福岡県行橋市北泉');
ok($zip->set_number('8240034')->is_valid_number, '福岡県行橋市泉中央');
ok($zip->set_number('8240035')->is_valid_number, '福岡県行橋市東泉');
ok($zip->set_number('8240036')->is_valid_number, '福岡県行橋市南泉');
ok($zip->set_number('8240037')->is_valid_number, '福岡県行橋市矢留');
ok($zip->set_number('8240038')->is_valid_number, '福岡県行橋市西泉');
ok($zip->set_number('8240041')->is_valid_number, '福岡県行橋市大野井');
ok($zip->set_number('8240042')->is_valid_number, '福岡県行橋市寺畔');
ok($zip->set_number('8240043')->is_valid_number, '福岡県行橋市流末');
ok($zip->set_number('8240044')->is_valid_number, '福岡県行橋市天生田');
ok($zip->set_number('8240045')->is_valid_number, '福岡県行橋市大谷');
ok($zip->set_number('8240046')->is_valid_number, '福岡県行橋市西谷');
ok($zip->set_number('8240047')->is_valid_number, '福岡県行橋市津積');
ok($zip->set_number('8240048')->is_valid_number, '福岡県行橋市宝山');
ok($zip->set_number('8240049')->is_valid_number, '福岡県行橋市福原');
ok($zip->set_number('8240051')->is_valid_number, '福岡県行橋市下検地');
ok($zip->set_number('8240052')->is_valid_number, '福岡県行橋市上検地');
ok($zip->set_number('8240053')->is_valid_number, '福岡県行橋市中川');
ok($zip->set_number('8240054')->is_valid_number, '福岡県行橋市下稗田');
ok($zip->set_number('8240055')->is_valid_number, '福岡県行橋市上稗田');
ok($zip->set_number('8240056')->is_valid_number, '福岡県行橋市前田');
ok($zip->set_number('8240057')->is_valid_number, '福岡県行橋市宮の杜');
ok($zip->set_number('8240058')->is_valid_number, '福岡県行橋市長木');
ok($zip->set_number('8240061')->is_valid_number, '福岡県行橋市草野');
ok($zip->set_number('8240062')->is_valid_number, '福岡県行橋市下津熊');
ok($zip->set_number('8240063')->is_valid_number, '福岡県行橋市中津熊');
ok($zip->set_number('8240064')->is_valid_number, '福岡県行橋市上津熊');
ok($zip->set_number('8240065')->is_valid_number, '福岡県行橋市長音寺');
ok($zip->set_number('8240066')->is_valid_number, '福岡県行橋市吉国');
ok($zip->set_number('8240067')->is_valid_number, '福岡県行橋市二塚');
ok($zip->set_number('8240068')->is_valid_number, '福岡県行橋市延永');
ok($zip->set_number('8240071')->is_valid_number, '福岡県行橋市徳永');
ok($zip->set_number('8240072')->is_valid_number, '福岡県行橋市須磨園');
ok($zip->set_number('8240073')->is_valid_number, '福岡県行橋市福丸');
ok($zip->set_number('8240074')->is_valid_number, '福岡県行橋市常松');
ok($zip->set_number('8240075')->is_valid_number, '福岡県行橋市長尾');
ok($zip->set_number('8240076')->is_valid_number, '福岡県行橋市下崎');
ok($zip->set_number('8240077')->is_valid_number, '福岡県行橋市入覚');
ok($zip->set_number('8240078')->is_valid_number, '福岡県行橋市高来');
ok($zip->set_number('8240079')->is_valid_number, '福岡県行橋市矢山');
ok($zip->set_number('8240101')->is_valid_number, '福岡県京都郡みやこ町徳永');
ok($zip->set_number('8240102')->is_valid_number, '福岡県京都郡みやこ町呰見');
ok($zip->set_number('8240103')->is_valid_number, '福岡県京都郡みやこ町下原');
ok($zip->set_number('8240104')->is_valid_number, '福岡県京都郡みやこ町綾野');
ok($zip->set_number('8240105')->is_valid_number, '福岡県京都郡みやこ町徳政');
ok($zip->set_number('8240106')->is_valid_number, '福岡県京都郡みやこ町有久');
ok($zip->set_number('8240107')->is_valid_number, '福岡県京都郡みやこ町田中');
ok($zip->set_number('8240111')->is_valid_number, '福岡県京都郡みやこ町上坂');
ok($zip->set_number('8240112')->is_valid_number, '福岡県京都郡みやこ町上原');
ok($zip->set_number('8240113')->is_valid_number, '福岡県京都郡みやこ町吉岡');
ok($zip->set_number('8240114')->is_valid_number, '福岡県京都郡みやこ町節丸');
ok($zip->set_number('8240115')->is_valid_number, '福岡県京都郡みやこ町光冨');
ok($zip->set_number('8240121')->is_valid_number, '福岡県京都郡みやこ町豊津');
ok($zip->set_number('8240122')->is_valid_number, '福岡県京都郡みやこ町彦徳');
ok($zip->set_number('8240123')->is_valid_number, '福岡県京都郡みやこ町国分');
ok($zip->set_number('8240124')->is_valid_number, '福岡県京都郡みやこ町惣社');
ok($zip->set_number('8240125')->is_valid_number, '福岡県京都郡みやこ町国作');
ok($zip->set_number('8240201')->is_valid_number, '福岡県京都郡みやこ町犀川下高屋');
ok($zip->set_number('8240202')->is_valid_number, '福岡県京都郡みやこ町犀川上高屋');
ok($zip->set_number('8240203')->is_valid_number, '福岡県京都郡みやこ町犀川続命院');
ok($zip->set_number('8240204')->is_valid_number, '福岡県京都郡みやこ町犀川末江');
ok($zip->set_number('8240205')->is_valid_number, '福岡県京都郡みやこ町犀川久富');
ok($zip->set_number('8240206')->is_valid_number, '福岡県京都郡みやこ町犀川八ツ溝');
ok($zip->set_number('8240207')->is_valid_number, '福岡県京都郡みやこ町蔵持');
ok($zip->set_number('8240211')->is_valid_number, '福岡県京都郡みやこ町今里');
ok($zip->set_number('8240212')->is_valid_number, '福岡県京都郡みやこ町犀川大熊');
ok($zip->set_number('8240213')->is_valid_number, '福岡県京都郡みやこ町犀川喜多良');
ok($zip->set_number('8240214')->is_valid_number, '福岡県京都郡みやこ町犀川鐙畑');
ok($zip->set_number('8240215')->is_valid_number, '福岡県京都郡みやこ町犀川生立');
ok($zip->set_number('8240216')->is_valid_number, '福岡県京都郡みやこ町犀川谷口');
ok($zip->set_number('8240217')->is_valid_number, '福岡県京都郡みやこ町犀川古川');
ok($zip->set_number('8240221')->is_valid_number, '福岡県京都郡みやこ町犀川山鹿');
ok($zip->set_number('8240222')->is_valid_number, '福岡県京都郡みやこ町犀川大村');
ok($zip->set_number('8240223')->is_valid_number, '福岡県京都郡みやこ町犀川柳瀬');
ok($zip->set_number('8240224')->is_valid_number, '福岡県京都郡みやこ町犀川崎山');
ok($zip->set_number('8240225')->is_valid_number, '福岡県京都郡みやこ町犀川大坂');
ok($zip->set_number('8240226')->is_valid_number, '福岡県京都郡みやこ町松坂');
ok($zip->set_number('8240231')->is_valid_number, '福岡県京都郡みやこ町犀川本庄');
ok($zip->set_number('8240232')->is_valid_number, '福岡県京都郡みやこ町桜台');
ok($zip->set_number('8240233')->is_valid_number, '福岡県京都郡みやこ町犀川花熊');
ok($zip->set_number('8240234')->is_valid_number, '福岡県京都郡みやこ町下高屋団地');
ok($zip->set_number('8240235')->is_valid_number, '福岡県京都郡みやこ町犀川木山');
ok($zip->set_number('8240241')->is_valid_number, '福岡県京都郡みやこ町犀川内垣');
ok($zip->set_number('8240242')->is_valid_number, '福岡県京都郡みやこ町犀川犬丸');
ok($zip->set_number('8240243')->is_valid_number, '福岡県京都郡みやこ町犀川木井馬場');
ok($zip->set_number('8240244')->is_valid_number, '福岡県京都郡みやこ町犀川横瀬');
ok($zip->set_number('8240251')->is_valid_number, '福岡県京都郡みやこ町犀川下伊良原');
ok($zip->set_number('8240252')->is_valid_number, '福岡県京都郡みやこ町犀川上伊良原');
ok($zip->set_number('8240253')->is_valid_number, '福岡県京都郡みやこ町犀川帆柱');
ok($zip->set_number('8240254')->is_valid_number, '福岡県京都郡みやこ町犀川扇谷');
ok($zip->set_number('8240400')->is_valid_number, '福岡県田川郡赤村以下に掲載がない場合');
ok($zip->set_number('8240411')->is_valid_number, '福岡県田川郡添田町津野');
ok($zip->set_number('8240431')->is_valid_number, '福岡県田川郡赤村赤');
ok($zip->set_number('8240432')->is_valid_number, '福岡県田川郡赤村内田');
ok($zip->set_number('8240500')->is_valid_number, '福岡県田川郡大任町以下に掲載がない場合');
ok($zip->set_number('8240511')->is_valid_number, '福岡県田川郡大任町今任原');
ok($zip->set_number('8240512')->is_valid_number, '福岡県田川郡大任町大行事');
ok($zip->set_number('8240600')->is_valid_number, '福岡県田川郡添田町以下に掲載がない場合');
ok($zip->set_number('8240601')->is_valid_number, '福岡県田川郡添田町庄');
ok($zip->set_number('8240602')->is_valid_number, '福岡県田川郡添田町添田');
ok($zip->set_number('8240603')->is_valid_number, '福岡県田川郡添田町中元寺');
ok($zip->set_number('8240604')->is_valid_number, '福岡県田川郡添田町野田');
ok($zip->set_number('8240721')->is_valid_number, '福岡県田川郡添田町英彦山');
ok($zip->set_number('8240722')->is_valid_number, '福岡県田川郡添田町落合');
ok($zip->set_number('8240723')->is_valid_number, '福岡県田川郡添田町桝田');
ok($zip->set_number('8240800')->is_valid_number, '福岡県京都郡みやこ町以下に掲載がない場合');
ok($zip->set_number('8240801')->is_valid_number, '福岡県京都郡みやこ町勝山大久保');
ok($zip->set_number('8240802')->is_valid_number, '福岡県京都郡みやこ町勝山松田');
ok($zip->set_number('8240811')->is_valid_number, '福岡県京都郡みやこ町勝山箕田');
ok($zip->set_number('8240812')->is_valid_number, '福岡県京都郡みやこ町勝山長川');
ok($zip->set_number('8240813')->is_valid_number, '福岡県京都郡みやこ町勝山宮原');
ok($zip->set_number('8240814')->is_valid_number, '福岡県京都郡みやこ町勝山浦河内');
ok($zip->set_number('8240815')->is_valid_number, '福岡県京都郡みやこ町勝山上矢山');
ok($zip->set_number('8240816')->is_valid_number, '福岡県京都郡みやこ町勝山矢山');
ok($zip->set_number('8240817')->is_valid_number, '福岡県京都郡みやこ町勝山岩熊');
ok($zip->set_number('8240818')->is_valid_number, '福岡県京都郡みやこ町勝山池田');
ok($zip->set_number('8240821')->is_valid_number, '福岡県京都郡みやこ町勝山上田');
ok($zip->set_number('8240822')->is_valid_number, '福岡県京都郡みやこ町勝山黒田');
ok($zip->set_number('8250000')->is_valid_number, '福岡県田川市以下に掲載がない場合');
ok($zip->set_number('8250001')->is_valid_number, '福岡県田川市伊加利');
ok($zip->set_number('8250002')->is_valid_number, '福岡県田川市伊田');
ok($zip->set_number('8250003')->is_valid_number, '福岡県田川市白鳥町');
ok($zip->set_number('8250004')->is_valid_number, '福岡県田川市夏吉');
ok($zip->set_number('8250005')->is_valid_number, '福岡県田川市糒');
ok($zip->set_number('8250011')->is_valid_number, '福岡県田川市栄町');
ok($zip->set_number('8250012')->is_valid_number, '福岡県田川市日の出町');
ok($zip->set_number('8250013')->is_valid_number, '福岡県田川市中央町');
ok($zip->set_number('8250014')->is_valid_number, '福岡県田川市魚町');
ok($zip->set_number('8250015')->is_valid_number, '福岡県田川市伊田町');
ok($zip->set_number('8250016')->is_valid_number, '福岡県田川市新町');
ok($zip->set_number('8250017')->is_valid_number, '福岡県田川市寿町');
ok($zip->set_number('8250018')->is_valid_number, '福岡県田川市番田町');
ok($zip->set_number('8260002')->is_valid_number, '福岡県田川郡川崎町池尻(上原、小倉畔)');
ok($zip->set_number('8260021')->is_valid_number, '福岡県田川市桜町');
ok($zip->set_number('8260022')->is_valid_number, '福岡県田川市本町');
ok($zip->set_number('8260023')->is_valid_number, '福岡県田川市上本町');
ok($zip->set_number('8260024')->is_valid_number, '福岡県田川市西本町');
ok($zip->set_number('8260025')->is_valid_number, '福岡県田川市大黒町');
ok($zip->set_number('8260026')->is_valid_number, '福岡県田川市春日町');
ok($zip->set_number('8260027')->is_valid_number, '福岡県田川市宮尾町');
ok($zip->set_number('8260031')->is_valid_number, '福岡県田川市千代町');
ok($zip->set_number('8260032')->is_valid_number, '福岡県田川市平松町');
ok($zip->set_number('8260033')->is_valid_number, '福岡県田川市丸山町');
ok($zip->set_number('8260041')->is_valid_number, '福岡県田川市弓削田(角銅原、野上、船尾、見立、文字山)');
ok($zip->set_number('8260042')->is_valid_number, '福岡県田川市川宮(大藪、新生町、高住町、平岡)');
ok($zip->set_number('8260043')->is_valid_number, '福岡県田川市奈良(青葉町、大浦、会社町、霞ケ丘、後藤寺西団地、後藤寺東団地、希望ケ丘、');
ok($zip->set_number('8260043')->is_valid_number, '福岡県田川市松の木、三井後藤寺、緑町、月見ケ丘)');
ok($zip->set_number('8260044')->is_valid_number, '福岡県田川市位登(猪位金4~7区、清美町)');
ok($zip->set_number('8260045')->is_valid_number, '福岡県田川市猪国(猪位金1~3区)');
ok($zip->set_number('8270000')->is_valid_number, '福岡県田川郡川崎町以下に掲載がない場合');
ok($zip->set_number('8270001')->is_valid_number, '福岡県田川郡川崎町安眞木');
ok($zip->set_number('8270002')->is_valid_number, '福岡県田川郡川崎町池尻(その他)');
ok($zip->set_number('8270003')->is_valid_number, '福岡県田川郡川崎町川崎');
ok($zip->set_number('8270004')->is_valid_number, '福岡県田川郡川崎町田原');
ok($zip->set_number('8280000')->is_valid_number, '福岡県豊前市以下に掲載がない場合');
ok($zip->set_number('8280001')->is_valid_number, '福岡県豊前市畠中');
ok($zip->set_number('8280002')->is_valid_number, '福岡県豊前市松江');
ok($zip->set_number('8280003')->is_valid_number, '福岡県豊前市中村');
ok($zip->set_number('8280004')->is_valid_number, '福岡県豊前市馬場');
ok($zip->set_number('8280005')->is_valid_number, '福岡県豊前市畑');
ok($zip->set_number('8280011')->is_valid_number, '福岡県豊前市四郎丸');
ok($zip->set_number('8280012')->is_valid_number, '福岡県豊前市鳥越');
ok($zip->set_number('8280013')->is_valid_number, '福岡県豊前市川内');
ok($zip->set_number('8280021')->is_valid_number, '福岡県豊前市八屋');
ok($zip->set_number('8280022')->is_valid_number, '福岡県豊前市宇島');
ok($zip->set_number('8280023')->is_valid_number, '福岡県豊前市沓川');
ok($zip->set_number('8280024')->is_valid_number, '福岡県豊前市久松');
ok($zip->set_number('8280025')->is_valid_number, '福岡県豊前市恒富');
ok($zip->set_number('8280026')->is_valid_number, '福岡県豊前市清水町');
ok($zip->set_number('8280027')->is_valid_number, '福岡県豊前市赤熊');
ok($zip->set_number('8280028')->is_valid_number, '福岡県豊前市青豊');
ok($zip->set_number('8280031')->is_valid_number, '福岡県豊前市三毛門');
ok($zip->set_number('8280032')->is_valid_number, '福岡県豊前市三楽');
ok($zip->set_number('8280033')->is_valid_number, '福岡県豊前市六郎');
ok($zip->set_number('8280034')->is_valid_number, '福岡県豊前市森久');
ok($zip->set_number('8280035')->is_valid_number, '福岡県豊前市市丸');
ok($zip->set_number('8280036')->is_valid_number, '福岡県豊前市小犬丸');
ok($zip->set_number('8280041')->is_valid_number, '福岡県豊前市梶屋');
ok($zip->set_number('8280042')->is_valid_number, '福岡県豊前市堀立');
ok($zip->set_number('8280043')->is_valid_number, '福岡県豊前市岸井');
ok($zip->set_number('8280044')->is_valid_number, '福岡県豊前市小石原');
ok($zip->set_number('8280045')->is_valid_number, '福岡県豊前市皆毛');
ok($zip->set_number('8280046')->is_valid_number, '福岡県豊前市高田');
ok($zip->set_number('8280047')->is_valid_number, '福岡県豊前市広瀬');
ok($zip->set_number('8280048')->is_valid_number, '福岡県豊前市久路土');
ok($zip->set_number('8280049')->is_valid_number, '福岡県豊前市鬼木');
ok($zip->set_number('8280051')->is_valid_number, '福岡県豊前市吉木');
ok($zip->set_number('8280052')->is_valid_number, '福岡県豊前市塔田');
ok($zip->set_number('8280053')->is_valid_number, '福岡県豊前市千束');
ok($zip->set_number('8280054')->is_valid_number, '福岡県豊前市永久');
ok($zip->set_number('8280055')->is_valid_number, '福岡県豊前市河原田');
ok($zip->set_number('8280056')->is_valid_number, '福岡県豊前市薬師寺');
ok($zip->set_number('8280061')->is_valid_number, '福岡県豊前市荒堀');
ok($zip->set_number('8280062')->is_valid_number, '福岡県豊前市今市');
ok($zip->set_number('8280063')->is_valid_number, '福岡県豊前市野田');
ok($zip->set_number('8280064')->is_valid_number, '福岡県豊前市大西');
ok($zip->set_number('8280065')->is_valid_number, '福岡県豊前市青畑');
ok($zip->set_number('8280066')->is_valid_number, '福岡県豊前市大村');
ok($zip->set_number('8280071')->is_valid_number, '福岡県豊前市山内');
ok($zip->set_number('8280072')->is_valid_number, '福岡県豊前市才尾');
ok($zip->set_number('8280073')->is_valid_number, '福岡県豊前市挾間');
ok($zip->set_number('8280074')->is_valid_number, '福岡県豊前市下河内');
ok($zip->set_number('8280075')->is_valid_number, '福岡県豊前市下川底');
ok($zip->set_number('8280076')->is_valid_number, '福岡県豊前市中川底');
ok($zip->set_number('8280077')->is_valid_number, '福岡県豊前市上川底');
ok($zip->set_number('8280081')->is_valid_number, '福岡県豊前市天和');
ok($zip->set_number('8280082')->is_valid_number, '福岡県豊前市大河内');
ok($zip->set_number('8280083')->is_valid_number, '福岡県豊前市岩屋');
ok($zip->set_number('8280084')->is_valid_number, '福岡県豊前市篠瀬');
ok($zip->set_number('8280085')->is_valid_number, '福岡県豊前市鳥井畑');
ok($zip->set_number('8280086')->is_valid_number, '福岡県豊前市求菩提');
ok($zip->set_number('8290100')->is_valid_number, '福岡県築上郡築上町以下に掲載がない場合');
ok($zip->set_number('8290101')->is_valid_number, '福岡県築上郡築上町東築城');
ok($zip->set_number('8290102')->is_valid_number, '福岡県築上郡築上町築城');
ok($zip->set_number('8290103')->is_valid_number, '福岡県築上郡築上町広末');
ok($zip->set_number('8290104')->is_valid_number, '福岡県築上郡築上町小山田');
ok($zip->set_number('8290105')->is_valid_number, '福岡県築上郡築上町上別府');
ok($zip->set_number('8290106')->is_valid_number, '福岡県築上郡築上町船迫');
ok($zip->set_number('8290107')->is_valid_number, '福岡県築上郡築上町弓の師');
ok($zip->set_number('8290108')->is_valid_number, '福岡県築上郡築上町下別府');
ok($zip->set_number('8290111')->is_valid_number, '福岡県築上郡築上町安武');
ok($zip->set_number('8290112')->is_valid_number, '福岡県築上郡築上町赤幡');
ok($zip->set_number('8290113')->is_valid_number, '福岡県築上郡築上町下香楽');
ok($zip->set_number('8290114')->is_valid_number, '福岡県築上郡築上町上香楽');
ok($zip->set_number('8290115')->is_valid_number, '福岡県築上郡築上町上深野');
ok($zip->set_number('8290116')->is_valid_number, '福岡県築上郡築上町下深野');
ok($zip->set_number('8290117')->is_valid_number, '福岡県築上郡築上町袈裟丸');
ok($zip->set_number('8290121')->is_valid_number, '福岡県築上郡築上町松丸');
ok($zip->set_number('8290122')->is_valid_number, '福岡県築上郡築上町伝法寺');
ok($zip->set_number('8290123')->is_valid_number, '福岡県築上郡築上町本庄');
ok($zip->set_number('8290124')->is_valid_number, '福岡県築上郡築上町櫟原');
ok($zip->set_number('8290125')->is_valid_number, '福岡県築上郡築上町寒田');
ok($zip->set_number('8290151')->is_valid_number, '福岡県築上郡築上町西八田(航空自衛隊築城基地)');
ok($zip->set_number('8290301')->is_valid_number, '福岡県築上郡築上町椎田');
ok($zip->set_number('8290302')->is_valid_number, '福岡県築上郡築上町臼田');
ok($zip->set_number('8290303')->is_valid_number, '福岡県築上郡築上町山本');
ok($zip->set_number('8290304')->is_valid_number, '福岡県築上郡築上町小原');
ok($zip->set_number('8290305')->is_valid_number, '福岡県築上郡築上町真如寺');
ok($zip->set_number('8290311')->is_valid_number, '福岡県築上郡築上町湊');
ok($zip->set_number('8290312')->is_valid_number, '福岡県築上郡築上町石堂');
ok($zip->set_number('8290313')->is_valid_number, '福岡県築上郡築上町有安');
ok($zip->set_number('8290314')->is_valid_number, '福岡県築上郡築上町上ノ河内');
ok($zip->set_number('8290315')->is_valid_number, '福岡県築上郡築上町上り松');
ok($zip->set_number('8290321')->is_valid_number, '福岡県築上郡築上町坂本');
ok($zip->set_number('8290322')->is_valid_number, '福岡県築上郡築上町日奈古');
ok($zip->set_number('8290323')->is_valid_number, '福岡県築上郡築上町極楽寺');
ok($zip->set_number('8290331')->is_valid_number, '福岡県築上郡築上町高塚');
ok($zip->set_number('8290332')->is_valid_number, '福岡県築上郡築上町越路');
ok($zip->set_number('8290333')->is_valid_number, '福岡県築上郡築上町水原');
ok($zip->set_number('8290334')->is_valid_number, '福岡県築上郡築上町奈古');
ok($zip->set_number('8290335')->is_valid_number, '福岡県築上郡築上町岩丸');
ok($zip->set_number('8290341')->is_valid_number, '福岡県築上郡築上町宇留津');
ok($zip->set_number('8290342')->is_valid_number, '福岡県築上郡築上町東八田');
ok($zip->set_number('8290343')->is_valid_number, '福岡県築上郡築上町西八田(その他)');
ok($zip->set_number('8300001')->is_valid_number, '福岡県久留米市小森野');
ok($zip->set_number('8300002')->is_valid_number, '福岡県久留米市高野');
ok($zip->set_number('8300003')->is_valid_number, '福岡県久留米市東櫛原町');
ok($zip->set_number('8300004')->is_valid_number, '福岡県久留米市南薫町');
ok($zip->set_number('8300005')->is_valid_number, '福岡県久留米市通外町');
ok($zip->set_number('8300006')->is_valid_number, '福岡県久留米市南薫西町');
ok($zip->set_number('8300011')->is_valid_number, '福岡県久留米市旭町');
ok($zip->set_number('8300012')->is_valid_number, '福岡県久留米市日ノ出町');
ok($zip->set_number('8300013')->is_valid_number, '福岡県久留米市櫛原町');
ok($zip->set_number('8300014')->is_valid_number, '福岡県久留米市寺町');
ok($zip->set_number('8300015')->is_valid_number, '福岡県久留米市螢川町');
ok($zip->set_number('8300016')->is_valid_number, '福岡県久留米市通東町');
ok($zip->set_number('8300017')->is_valid_number, '福岡県久留米市日吉町');
ok($zip->set_number('8300018')->is_valid_number, '福岡県久留米市通町');
ok($zip->set_number('8300019')->is_valid_number, '福岡県久留米市小森野町');
ok($zip->set_number('8300021')->is_valid_number, '福岡県久留米市篠山町');
ok($zip->set_number('8300022')->is_valid_number, '福岡県久留米市城南町');
ok($zip->set_number('8300023')->is_valid_number, '福岡県久留米市中央町');
ok($zip->set_number('8300024')->is_valid_number, '福岡県久留米市縄手町');
ok($zip->set_number('8300025')->is_valid_number, '福岡県久留米市瀬下町');
ok($zip->set_number('8300026')->is_valid_number, '福岡県久留米市長門石町');
ok($zip->set_number('8300027')->is_valid_number, '福岡県久留米市長門石');
ok($zip->set_number('8300028')->is_valid_number, '福岡県久留米市京町');
ok($zip->set_number('8300029')->is_valid_number, '福岡県久留米市洗町');
ok($zip->set_number('8300031')->is_valid_number, '福岡県久留米市六ツ門町');
ok($zip->set_number('8300032')->is_valid_number, '福岡県久留米市東町');
ok($zip->set_number('8300033')->is_valid_number, '福岡県久留米市天神町');
ok($zip->set_number('8300034')->is_valid_number, '福岡県久留米市大手町');
ok($zip->set_number('8300035')->is_valid_number, '福岡県久留米市東和町');
ok($zip->set_number('8300036')->is_valid_number, '福岡県久留米市篠原町');
ok($zip->set_number('8300037')->is_valid_number, '福岡県久留米市諏訪野町');
ok($zip->set_number('8300038')->is_valid_number, '福岡県久留米市西町');
ok($zip->set_number('8300039')->is_valid_number, '福岡県久留米市花畑');
ok($zip->set_number('8300041')->is_valid_number, '福岡県久留米市白山町');
ok($zip->set_number('8300042')->is_valid_number, '福岡県久留米市荘島町');
ok($zip->set_number('8300043')->is_valid_number, '福岡県久留米市松ケ枝町');
ok($zip->set_number('8300044')->is_valid_number, '福岡県久留米市本町');
ok($zip->set_number('8300045')->is_valid_number, '福岡県久留米市小頭町');
ok($zip->set_number('8300046')->is_valid_number, '福岡県久留米市原古賀町');
ok($zip->set_number('8300047')->is_valid_number, '福岡県久留米市津福本町');
ok($zip->set_number('8300048')->is_valid_number, '福岡県久留米市梅満町');
ok($zip->set_number('8300049')->is_valid_number, '福岡県久留米市大石町');
ok($zip->set_number('8300051')->is_valid_number, '福岡県久留米市南');
ok($zip->set_number('8300052')->is_valid_number, '福岡県久留米市上津町');
ok($zip->set_number('8300053')->is_valid_number, '福岡県久留米市藤山町');
ok($zip->set_number('8300054')->is_valid_number, '福岡県久留米市藤光町');
ok($zip->set_number('8300055')->is_valid_number, '福岡県久留米市上津');
ok($zip->set_number('8300056')->is_valid_number, '福岡県久留米市本山');
ok($zip->set_number('8300057')->is_valid_number, '福岡県久留米市藤光');
ok($zip->set_number('8300058')->is_valid_number, '福岡県久留米市野伏間');
ok($zip->set_number('8300059')->is_valid_number, '福岡県久留米市江戸屋敷');
ok($zip->set_number('8300061')->is_valid_number, '福岡県久留米市津福今町');
ok($zip->set_number('8300062')->is_valid_number, '福岡県久留米市荒木町白口');
ok($zip->set_number('8300063')->is_valid_number, '福岡県久留米市荒木町荒木');
ok($zip->set_number('8300064')->is_valid_number, '福岡県久留米市荒木町藤田');
ok($zip->set_number('8300065')->is_valid_number, '福岡県久留米市荒木町今');
ok($zip->set_number('8300066')->is_valid_number, '福岡県久留米市荒木町下荒木');
ok($zip->set_number('8300070')->is_valid_number, '福岡県久留米市大善寺南');
ok($zip->set_number('8300071')->is_valid_number, '福岡県久留米市安武町武島');
ok($zip->set_number('8300072')->is_valid_number, '福岡県久留米市安武町安武本');
ok($zip->set_number('8300073')->is_valid_number, '福岡県久留米市大善寺町宮本');
ok($zip->set_number('8300074')->is_valid_number, '福岡県久留米市大善寺町夜明');
ok($zip->set_number('8300075')->is_valid_number, '福岡県久留米市大善寺町黒田');
ok($zip->set_number('8300076')->is_valid_number, '福岡県久留米市大善寺町藤吉');
ok($zip->set_number('8300077')->is_valid_number, '福岡県久留米市大善寺町中津');
ok($zip->set_number('8300078')->is_valid_number, '福岡県久留米市安武町住吉');
ok($zip->set_number('8300079')->is_valid_number, '福岡県久留米市大善寺大橋');
ok($zip->set_number('8300101')->is_valid_number, '福岡県久留米市三潴町早津崎');
ok($zip->set_number('8300102')->is_valid_number, '福岡県久留米市三潴町田川');
ok($zip->set_number('8300103')->is_valid_number, '福岡県久留米市三潴町高三潴');
ok($zip->set_number('8300104')->is_valid_number, '福岡県久留米市三潴町原田');
ok($zip->set_number('8300105')->is_valid_number, '福岡県久留米市三潴町草場');
ok($zip->set_number('8300111')->is_valid_number, '福岡県久留米市三潴町西牟田');
ok($zip->set_number('8300112')->is_valid_number, '福岡県久留米市三潴町玉満');
ok($zip->set_number('8300113')->is_valid_number, '福岡県久留米市三潴町生岩');
ok($zip->set_number('8300114')->is_valid_number, '福岡県久留米市三潴町福光');
ok($zip->set_number('8300115')->is_valid_number, '福岡県久留米市三潴町壱町原');
ok($zip->set_number('8300116')->is_valid_number, '福岡県久留米市三潴町清松');
ok($zip->set_number('8300201')->is_valid_number, '福岡県久留米市城島町芦塚');
ok($zip->set_number('8300202')->is_valid_number, '福岡県久留米市城島町下田');
ok($zip->set_number('8300203')->is_valid_number, '福岡県久留米市城島町浜');
ok($zip->set_number('8300204')->is_valid_number, '福岡県久留米市城島町内野');
ok($zip->set_number('8300205')->is_valid_number, '福岡県久留米市城島町大依');
ok($zip->set_number('8300206')->is_valid_number, '福岡県久留米市城島町六町原');
ok($zip->set_number('8300207')->is_valid_number, '福岡県久留米市城島町城島');
ok($zip->set_number('8300211')->is_valid_number, '福岡県久留米市城島町楢津');
ok($zip->set_number('8300212')->is_valid_number, '福岡県久留米市城島町江上上');
ok($zip->set_number('8300213')->is_valid_number, '福岡県久留米市城島町江上');
ok($zip->set_number('8300214')->is_valid_number, '福岡県久留米市城島町江上本');
ok($zip->set_number('8300215')->is_valid_number, '福岡県久留米市城島町原中牟田');
ok($zip->set_number('8300216')->is_valid_number, '福岡県久留米市城島町江島');
ok($zip->set_number('8300221')->is_valid_number, '福岡県久留米市城島町浮島');
ok($zip->set_number('8300222')->is_valid_number, '福岡県久留米市城島町青木島');
ok($zip->set_number('8300223')->is_valid_number, '福岡県久留米市城島町四郎丸');
ok($zip->set_number('8300224')->is_valid_number, '福岡県久留米市城島町上青木');
ok($zip->set_number('8300225')->is_valid_number, '福岡県久留米市城島町下青木');
ok($zip->set_number('8300226')->is_valid_number, '福岡県久留米市城島町西青木');
ok($zip->set_number('8300400')->is_valid_number, '福岡県三潴郡大木町以下に掲載がない場合');
ok($zip->set_number('8300401')->is_valid_number, '福岡県三潴郡大木町笹渕');
ok($zip->set_number('8300402')->is_valid_number, '福岡県三潴郡大木町福土');
ok($zip->set_number('8300403')->is_valid_number, '福岡県三潴郡大木町大角');
ok($zip->set_number('8300404')->is_valid_number, '福岡県三潴郡大木町上白垣');
ok($zip->set_number('8300405')->is_valid_number, '福岡県三潴郡大木町横溝');
ok($zip->set_number('8300406')->is_valid_number, '福岡県三潴郡大木町前牟田');
ok($zip->set_number('8300411')->is_valid_number, '福岡県三潴郡大木町蛭池');
ok($zip->set_number('8300412')->is_valid_number, '福岡県三潴郡大木町侍島');
ok($zip->set_number('8300413')->is_valid_number, '福岡県三潴郡大木町上牟田口');
ok($zip->set_number('8300414')->is_valid_number, '福岡県三潴郡大木町上木佐木');
ok($zip->set_number('8300415')->is_valid_number, '福岡県三潴郡大木町絵下古賀');
ok($zip->set_number('8300416')->is_valid_number, '福岡県三潴郡大木町八町牟田');
ok($zip->set_number('8300417')->is_valid_number, '福岡県三潴郡大木町上八院');
ok($zip->set_number('8300421')->is_valid_number, '福岡県三潴郡大木町奥牟田');
ok($zip->set_number('8300422')->is_valid_number, '福岡県三潴郡大木町高橋');
ok($zip->set_number('8300423')->is_valid_number, '福岡県三潴郡大木町大藪');
ok($zip->set_number('8300424')->is_valid_number, '福岡県三潴郡大木町三八松');
ok($zip->set_number('8300425')->is_valid_number, '福岡県三潴郡大木町筏溝');
ok($zip->set_number('8301101')->is_valid_number, '福岡県久留米市北野町中川');
ok($zip->set_number('8301102')->is_valid_number, '福岡県久留米市北野町八重亀');
ok($zip->set_number('8301103')->is_valid_number, '福岡県久留米市北野町金島');
ok($zip->set_number('8301104')->is_valid_number, '福岡県久留米市北野町大城');
ok($zip->set_number('8301105')->is_valid_number, '福岡県久留米市北野町中島');
ok($zip->set_number('8301106')->is_valid_number, '福岡県久留米市北野町仁王丸');
ok($zip->set_number('8301107')->is_valid_number, '福岡県久留米市北野町塚島');
ok($zip->set_number('8301111')->is_valid_number, '福岡県久留米市北野町千代島');
ok($zip->set_number('8301112')->is_valid_number, '福岡県久留米市北野町陣屋');
ok($zip->set_number('8301113')->is_valid_number, '福岡県久留米市北野町中');
ok($zip->set_number('8301114')->is_valid_number, '福岡県久留米市北野町高良');
ok($zip->set_number('8301115')->is_valid_number, '福岡県久留米市北野町鳥巣');
ok($zip->set_number('8301116')->is_valid_number, '福岡県久留米市北野町石崎');
ok($zip->set_number('8301117')->is_valid_number, '福岡県久留米市北野町上弓削');
ok($zip->set_number('8301121')->is_valid_number, '福岡県久留米市北野町十郎丸');
ok($zip->set_number('8301122')->is_valid_number, '福岡県久留米市北野町今山');
ok($zip->set_number('8301123')->is_valid_number, '福岡県久留米市北野町冨多');
ok($zip->set_number('8301124')->is_valid_number, '福岡県久留米市北野町乙吉');
ok($zip->set_number('8301125')->is_valid_number, '福岡県久留米市北野町乙丸');
ok($zip->set_number('8301126')->is_valid_number, '福岡県久留米市北野町稲数');
ok($zip->set_number('8301127')->is_valid_number, '福岡県久留米市北野町赤司');
ok($zip->set_number('8301200')->is_valid_number, '福岡県三井郡大刀洗町以下に掲載がない場合');
ok($zip->set_number('8301201')->is_valid_number, '福岡県三井郡大刀洗町冨多');
ok($zip->set_number('8301202')->is_valid_number, '福岡県三井郡大刀洗町菅野');
ok($zip->set_number('8301203')->is_valid_number, '福岡県三井郡大刀洗町三川');
ok($zip->set_number('8301204')->is_valid_number, '福岡県三井郡大刀洗町西原');
ok($zip->set_number('8301205')->is_valid_number, '福岡県三井郡大刀洗町守部');
ok($zip->set_number('8301206')->is_valid_number, '福岡県三井郡大刀洗町中川');
ok($zip->set_number('8301211')->is_valid_number, '福岡県三井郡大刀洗町本郷');
ok($zip->set_number('8301212')->is_valid_number, '福岡県三井郡大刀洗町甲条');
ok($zip->set_number('8301213')->is_valid_number, '福岡県三井郡大刀洗町春日');
ok($zip->set_number('8301214')->is_valid_number, '福岡県三井郡大刀洗町栄田');
ok($zip->set_number('8301221')->is_valid_number, '福岡県三井郡大刀洗町高樋');
ok($zip->set_number('8301222')->is_valid_number, '福岡県三井郡大刀洗町上高橋');
ok($zip->set_number('8301223')->is_valid_number, '福岡県三井郡大刀洗町今');
ok($zip->set_number('8301224')->is_valid_number, '福岡県三井郡大刀洗町鵜木');
ok($zip->set_number('8301225')->is_valid_number, '福岡県三井郡大刀洗町下高橋');
ok($zip->set_number('8301226')->is_valid_number, '福岡県三井郡大刀洗町山隈');
ok($zip->set_number('8310000')->is_valid_number, '福岡県大川市以下に掲載がない場合');
ok($zip->set_number('8310001')->is_valid_number, '福岡県大川市下青木');
ok($zip->set_number('8310002')->is_valid_number, '福岡県大川市下林');
ok($zip->set_number('8310003')->is_valid_number, '福岡県大川市諸富');
ok($zip->set_number('8310004')->is_valid_number, '福岡県大川市榎津');
ok($zip->set_number('8310005')->is_valid_number, '福岡県大川市向島');
ok($zip->set_number('8310006')->is_valid_number, '福岡県大川市中古賀');
ok($zip->set_number('8310007')->is_valid_number, '福岡県大川市道海島');
ok($zip->set_number('8310008')->is_valid_number, '福岡県大川市鐘ケ江');
ok($zip->set_number('8310011')->is_valid_number, '福岡県大川市下白垣');
ok($zip->set_number('8310012')->is_valid_number, '福岡県大川市上白垣');
ok($zip->set_number('8310013')->is_valid_number, '福岡県大川市中八院');
ok($zip->set_number('8310014')->is_valid_number, '福岡県大川市中木室');
ok($zip->set_number('8310015')->is_valid_number, '福岡県大川市本木室');
ok($zip->set_number('8310016')->is_valid_number, '福岡県大川市酒見');
ok($zip->set_number('8310017')->is_valid_number, '福岡県大川市下八院');
ok($zip->set_number('8310021')->is_valid_number, '福岡県大川市大橋');
ok($zip->set_number('8310022')->is_valid_number, '福岡県大川市下木佐木');
ok($zip->set_number('8310023')->is_valid_number, '福岡県大川市下牟田口');
ok($zip->set_number('8310024')->is_valid_number, '福岡県大川市鬼古賀');
ok($zip->set_number('8310025')->is_valid_number, '福岡県大川市坂井');
ok($zip->set_number('8310026')->is_valid_number, '福岡県大川市三丸');
ok($zip->set_number('8310027')->is_valid_number, '福岡県大川市荻島');
ok($zip->set_number('8310028')->is_valid_number, '福岡県大川市郷原');
ok($zip->set_number('8310031')->is_valid_number, '福岡県大川市上巻');
ok($zip->set_number('8310032')->is_valid_number, '福岡県大川市北古賀');
ok($zip->set_number('8310033')->is_valid_number, '福岡県大川市幡保');
ok($zip->set_number('8310034')->is_valid_number, '福岡県大川市一木');
ok($zip->set_number('8310035')->is_valid_number, '福岡県大川市津');
ok($zip->set_number('8310041')->is_valid_number, '福岡県大川市小保');
ok($zip->set_number('8310042')->is_valid_number, '福岡県大川市九網');
ok($zip->set_number('8310043')->is_valid_number, '福岡県大川市新田');
ok($zip->set_number('8310044')->is_valid_number, '福岡県大川市紅粉屋');
ok($zip->set_number('8310045')->is_valid_number, '福岡県大川市大野島');
ok($zip->set_number('8320000')->is_valid_number, '福岡県柳川市以下に掲載がない場合');
ok($zip->set_number('8320001')->is_valid_number, '福岡県柳川市蒲生');
ok($zip->set_number('8320002')->is_valid_number, '福岡県柳川市高島');
ok($zip->set_number('8320003')->is_valid_number, '福岡県柳川市立石');
ok($zip->set_number('8320004')->is_valid_number, '福岡県柳川市矢加部');
ok($zip->set_number('8320005')->is_valid_number, '福岡県柳川市西蒲池');
ok($zip->set_number('8320006')->is_valid_number, '福岡県柳川市東蒲池');
ok($zip->set_number('8320007')->is_valid_number, '福岡県柳川市金納');
ok($zip->set_number('8320011')->is_valid_number, '福岡県柳川市保加町');
ok($zip->set_number('8320012')->is_valid_number, '福岡県柳川市中町');
ok($zip->set_number('8320013')->is_valid_number, '福岡県柳川市上町');
ok($zip->set_number('8320014')->is_valid_number, '福岡県柳川市八百屋町');
ok($zip->set_number('8320015')->is_valid_number, '福岡県柳川市西魚屋町');
ok($zip->set_number('8320016')->is_valid_number, '福岡県柳川市蟹町');
ok($zip->set_number('8320017')->is_valid_number, '福岡県柳川市材木町');
ok($zip->set_number('8320018')->is_valid_number, '福岡県柳川市本船津町');
ok($zip->set_number('8320021')->is_valid_number, '福岡県柳川市隅町');
ok($zip->set_number('8320022')->is_valid_number, '福岡県柳川市旭町');
ok($zip->set_number('8320023')->is_valid_number, '福岡県柳川市京町');
ok($zip->set_number('8320024')->is_valid_number, '福岡県柳川市辻町');
ok($zip->set_number('8320025')->is_valid_number, '福岡県柳川市恵美須町');
ok($zip->set_number('8320026')->is_valid_number, '福岡県柳川市曙町');
ok($zip->set_number('8320027')->is_valid_number, '福岡県柳川市横山町');
ok($zip->set_number('8320028')->is_valid_number, '福岡県柳川市常盤町');
ok($zip->set_number('8320029')->is_valid_number, '福岡県柳川市八軒町');
ok($zip->set_number('8320031')->is_valid_number, '福岡県柳川市椿原町');
ok($zip->set_number('8320032')->is_valid_number, '福岡県柳川市新町');
ok($zip->set_number('8320033')->is_valid_number, '福岡県柳川市南長柄町');
ok($zip->set_number('8320034')->is_valid_number, '福岡県柳川市北長柄町');
ok($zip->set_number('8320035')->is_valid_number, '福岡県柳川市東魚屋町');
ok($zip->set_number('8320036')->is_valid_number, '福岡県柳川市小道具町');
ok($zip->set_number('8320037')->is_valid_number, '福岡県柳川市細工町');
ok($zip->set_number('8320041')->is_valid_number, '福岡県柳川市片原町');
ok($zip->set_number('8320042')->is_valid_number, '福岡県柳川市一新町');
ok($zip->set_number('8320043')->is_valid_number, '福岡県柳川市出来町');
ok($zip->set_number('8320044')->is_valid_number, '福岡県柳川市袋町');
ok($zip->set_number('8320045')->is_valid_number, '福岡県柳川市本町');
ok($zip->set_number('8320046')->is_valid_number, '福岡県柳川市奥州町');
ok($zip->set_number('8320050')->is_valid_number, '福岡県柳川市矢留町');
ok($zip->set_number('8320051')->is_valid_number, '福岡県柳川市佃町');
ok($zip->set_number('8320052')->is_valid_number, '福岡県柳川市橋本町');
ok($zip->set_number('8320053')->is_valid_number, '福岡県柳川市大浜町');
ok($zip->set_number('8320054')->is_valid_number, '福岡県柳川市有明町');
ok($zip->set_number('8320055')->is_valid_number, '福岡県柳川市吉富町');
ok($zip->set_number('8320056')->is_valid_number, '福岡県柳川市矢留本町');
ok($zip->set_number('8320057')->is_valid_number, '福岡県柳川市弥四郎町');
ok($zip->set_number('8320058')->is_valid_number, '福岡県柳川市上宮永町');
ok($zip->set_number('8320059')->is_valid_number, '福岡県柳川市下宮永町');
ok($zip->set_number('8320061')->is_valid_number, '福岡県柳川市本城町');
ok($zip->set_number('8320062')->is_valid_number, '福岡県柳川市城南町');
ok($zip->set_number('8320063')->is_valid_number, '福岡県柳川市茂庵町');
ok($zip->set_number('8320064')->is_valid_number, '福岡県柳川市宮永町');
ok($zip->set_number('8320065')->is_valid_number, '福岡県柳川市沖端町');
ok($zip->set_number('8320066')->is_valid_number, '福岡県柳川市稲荷町');
ok($zip->set_number('8320067')->is_valid_number, '福岡県柳川市鬼童町');
ok($zip->set_number('8320068')->is_valid_number, '福岡県柳川市城隅町');
ok($zip->set_number('8320069')->is_valid_number, '福岡県柳川市新外町');
ok($zip->set_number('8320071')->is_valid_number, '福岡県柳川市新船津町');
ok($zip->set_number('8320072')->is_valid_number, '福岡県柳川市糀屋町');
ok($zip->set_number('8320073')->is_valid_number, '福岡県柳川市鍛冶屋町');
ok($zip->set_number('8320074')->is_valid_number, '福岡県柳川市元町');
ok($zip->set_number('8320075')->is_valid_number, '福岡県柳川市柳町');
ok($zip->set_number('8320076')->is_valid_number, '福岡県柳川市坂本町');
ok($zip->set_number('8320077')->is_valid_number, '福岡県柳川市筑紫町');
ok($zip->set_number('8320081')->is_valid_number, '福岡県柳川市西浜武');
ok($zip->set_number('8320082')->is_valid_number, '福岡県柳川市古賀');
ok($zip->set_number('8320083')->is_valid_number, '福岡県柳川市南浜武');
ok($zip->set_number('8320084')->is_valid_number, '福岡県柳川市昭南町');
ok($zip->set_number('8320085')->is_valid_number, '福岡県柳川市吉原');
ok($zip->set_number('8320086')->is_valid_number, '福岡県柳川市久々原');
ok($zip->set_number('8320087')->is_valid_number, '福岡県柳川市七ツ家');
ok($zip->set_number('8320088')->is_valid_number, '福岡県柳川市間');
ok($zip->set_number('8320089')->is_valid_number, '福岡県柳川市田脇');
ok($zip->set_number('8320801')->is_valid_number, '福岡県柳川市三橋町起田');
ok($zip->set_number('8320802')->is_valid_number, '福岡県柳川市三橋町吉開');
ok($zip->set_number('8320803')->is_valid_number, '福岡県柳川市三橋町新村');
ok($zip->set_number('8320804')->is_valid_number, '福岡県柳川市三橋町木元');
ok($zip->set_number('8320805')->is_valid_number, '福岡県柳川市三橋町磯鳥');
ok($zip->set_number('8320806')->is_valid_number, '福岡県柳川市三橋町柳河');
ok($zip->set_number('8320807')->is_valid_number, '福岡県柳川市三橋町枝光');
ok($zip->set_number('8320811')->is_valid_number, '福岡県柳川市三橋町中山');
ok($zip->set_number('8320812')->is_valid_number, '福岡県柳川市三橋町五拾町');
ok($zip->set_number('8320813')->is_valid_number, '福岡県柳川市三橋町棚町');
ok($zip->set_number('8320814')->is_valid_number, '福岡県柳川市三橋町垂見');
ok($zip->set_number('8320815')->is_valid_number, '福岡県柳川市三橋町白鳥');
ok($zip->set_number('8320816')->is_valid_number, '福岡県柳川市三橋町久末');
ok($zip->set_number('8320821')->is_valid_number, '福岡県柳川市三橋町百町');
ok($zip->set_number('8320822')->is_valid_number, '福岡県柳川市三橋町下百町');
ok($zip->set_number('8320823')->is_valid_number, '福岡県柳川市三橋町今古賀');
ok($zip->set_number('8320824')->is_valid_number, '福岡県柳川市三橋町藤吉');
ok($zip->set_number('8320825')->is_valid_number, '福岡県柳川市三橋町江曲');
ok($zip->set_number('8320826')->is_valid_number, '福岡県柳川市三橋町高畑');
ok($zip->set_number('8320827')->is_valid_number, '福岡県柳川市三橋町蒲船津');
ok($zip->set_number('8320828')->is_valid_number, '福岡県柳川市三橋町正行');
ok($zip->set_number('8330000')->is_valid_number, '福岡県筑後市以下に掲載がない場合');
ok($zip->set_number('8330001')->is_valid_number, '福岡県筑後市一条');
ok($zip->set_number('8330002')->is_valid_number, '福岡県筑後市前津');
ok($zip->set_number('8330003')->is_valid_number, '福岡県筑後市羽犬塚');
ok($zip->set_number('8330004')->is_valid_number, '福岡県筑後市徳久');
ok($zip->set_number('8330005')->is_valid_number, '福岡県筑後市長浜');
ok($zip->set_number('8330006')->is_valid_number, '福岡県筑後市新溝');
ok($zip->set_number('8330007')->is_valid_number, '福岡県筑後市鶴田');
ok($zip->set_number('8330011')->is_valid_number, '福岡県筑後市久恵');
ok($zip->set_number('8330012')->is_valid_number, '福岡県筑後市溝口');
ok($zip->set_number('8330013')->is_valid_number, '福岡県筑後市北長田');
ok($zip->set_number('8330014')->is_valid_number, '福岡県筑後市尾島');
ok($zip->set_number('8330015')->is_valid_number, '福岡県筑後市津島');
ok($zip->set_number('8330016')->is_valid_number, '福岡県筑後市常用');
ok($zip->set_number('8330017')->is_valid_number, '福岡県筑後市志');
ok($zip->set_number('8330021')->is_valid_number, '福岡県筑後市下妻');
ok($zip->set_number('8330022')->is_valid_number, '福岡県筑後市富安');
ok($zip->set_number('8330023')->is_valid_number, '福岡県筑後市馬間田');
ok($zip->set_number('8330024')->is_valid_number, '福岡県筑後市中牟田');
ok($zip->set_number('8330025')->is_valid_number, '福岡県筑後市中折地');
ok($zip->set_number('8330026')->is_valid_number, '福岡県筑後市折地');
ok($zip->set_number('8330027')->is_valid_number, '福岡県筑後市水田');
ok($zip->set_number('8330031')->is_valid_number, '福岡県筑後市山ノ井');
ok($zip->set_number('8330032')->is_valid_number, '福岡県筑後市野町');
ok($zip->set_number('8330033')->is_valid_number, '福岡県筑後市上北島');
ok($zip->set_number('8330034')->is_valid_number, '福岡県筑後市下北島');
ok($zip->set_number('8330035')->is_valid_number, '福岡県筑後市古島');
ok($zip->set_number('8330036')->is_valid_number, '福岡県筑後市井田');
ok($zip->set_number('8330037')->is_valid_number, '福岡県筑後市島田');
ok($zip->set_number('8330041')->is_valid_number, '福岡県筑後市和泉');
ok($zip->set_number('8330042')->is_valid_number, '福岡県筑後市長崎');
ok($zip->set_number('8330043')->is_valid_number, '福岡県筑後市庄島');
ok($zip->set_number('8330044')->is_valid_number, '福岡県筑後市富久');
ok($zip->set_number('8330045')->is_valid_number, '福岡県筑後市四ケ所');
ok($zip->set_number('8330046')->is_valid_number, '福岡県筑後市江口');
ok($zip->set_number('8330047')->is_valid_number, '福岡県筑後市若菜');
ok($zip->set_number('8330051')->is_valid_number, '福岡県筑後市富重');
ok($zip->set_number('8330052')->is_valid_number, '福岡県筑後市高江');
ok($zip->set_number('8330053')->is_valid_number, '福岡県筑後市西牟田');
ok($zip->set_number('8330054')->is_valid_number, '福岡県筑後市蔵数');
ok($zip->set_number('8330055')->is_valid_number, '福岡県筑後市熊野');
ok($zip->set_number('8330056')->is_valid_number, '福岡県筑後市久富');
ok($zip->set_number('8340000')->is_valid_number, '福岡県八女市以下に掲載がない場合');
ok($zip->set_number('8340001')->is_valid_number, '福岡県八女市宅間田');
ok($zip->set_number('8340002')->is_valid_number, '福岡県八女市黒土');
ok($zip->set_number('8340003')->is_valid_number, '福岡県八女市平田');
ok($zip->set_number('8340004')->is_valid_number, '福岡県八女市納楚');
ok($zip->set_number('8340005')->is_valid_number, '福岡県八女市大島');
ok($zip->set_number('8340006')->is_valid_number, '福岡県八女市吉田');
ok($zip->set_number('8340011')->is_valid_number, '福岡県八女市長野');
ok($zip->set_number('8340012')->is_valid_number, '福岡県八女市山内');
ok($zip->set_number('8340013')->is_valid_number, '福岡県八女市大籠');
ok($zip->set_number('8340014')->is_valid_number, '福岡県八女市忠見');
ok($zip->set_number('8340015')->is_valid_number, '福岡県八女市本');
ok($zip->set_number('8340016')->is_valid_number, '福岡県八女市豊福');
ok($zip->set_number('8340021')->is_valid_number, '福岡県八女市北田形');
ok($zip->set_number('8340022')->is_valid_number, '福岡県八女市柳島');
ok($zip->set_number('8340023')->is_valid_number, '福岡県八女市馬場');
ok($zip->set_number('8340024')->is_valid_number, '福岡県八女市津江');
ok($zip->set_number('8340025')->is_valid_number, '福岡県八女市祈祷院');
ok($zip->set_number('8340026')->is_valid_number, '福岡県八女市井延');
ok($zip->set_number('8340031')->is_valid_number, '福岡県八女市本町');
ok($zip->set_number('8340032')->is_valid_number, '福岡県八女市宮野');
ok($zip->set_number('8340033')->is_valid_number, '福岡県八女市柳瀬');
ok($zip->set_number('8340034')->is_valid_number, '福岡県八女市高塚');
ok($zip->set_number('8340041')->is_valid_number, '福岡県八女市緒玉');
ok($zip->set_number('8340042')->is_valid_number, '福岡県八女市酒井田');
ok($zip->set_number('8340043')->is_valid_number, '福岡県八女市光');
ok($zip->set_number('8340044')->is_valid_number, '福岡県八女市矢原');
ok($zip->set_number('8340045')->is_valid_number, '福岡県八女市平');
ok($zip->set_number('8340046')->is_valid_number, '福岡県八女市国武');
ok($zip->set_number('8340047')->is_valid_number, '福岡県八女市稲富');
ok($zip->set_number('8340051')->is_valid_number, '福岡県八女市立野');
ok($zip->set_number('8340052')->is_valid_number, '福岡県八女市新庄');
ok($zip->set_number('8340053')->is_valid_number, '福岡県八女市川犬');
ok($zip->set_number('8340054')->is_valid_number, '福岡県八女市前古賀');
ok($zip->set_number('8340055')->is_valid_number, '福岡県八女市鵜池');
ok($zip->set_number('8340061')->is_valid_number, '福岡県八女市今福');
ok($zip->set_number('8340062')->is_valid_number, '福岡県八女市岩崎');
ok($zip->set_number('8340063')->is_valid_number, '福岡県八女市本村');
ok($zip->set_number('8340064')->is_valid_number, '福岡県八女市蒲原');
ok($zip->set_number('8340065')->is_valid_number, '福岡県八女市亀甲');
ok($zip->set_number('8340066')->is_valid_number, '福岡県八女市室岡');
ok($zip->set_number('8340067')->is_valid_number, '福岡県八女市龍ケ原');
ok($zip->set_number('8340071')->is_valid_number, '福岡県八女市立花町田形');
ok($zip->set_number('8340072')->is_valid_number, '福岡県八女市立花町遠久谷');
ok($zip->set_number('8340073')->is_valid_number, '福岡県八女市立花町下辺春');
ok($zip->set_number('8340074')->is_valid_number, '福岡県八女市立花町谷川');
ok($zip->set_number('8340075')->is_valid_number, '福岡県八女市立花町原島');
ok($zip->set_number('8340081')->is_valid_number, '福岡県八女市立花町山崎');
ok($zip->set_number('8340082')->is_valid_number, '福岡県八女市立花町兼松');
ok($zip->set_number('8340083')->is_valid_number, '福岡県八女市立花町上辺春');
ok($zip->set_number('8340084')->is_valid_number, '福岡県八女市立花町白木');
ok($zip->set_number('8340085')->is_valid_number, '福岡県八女市立花町北山');
ok($zip->set_number('8340100')->is_valid_number, '福岡県八女郡広川町以下に掲載がない場合');
ok($zip->set_number('8340101')->is_valid_number, '福岡県八女郡広川町小椎尾');
ok($zip->set_number('8340102')->is_valid_number, '福岡県八女郡広川町水原');
ok($zip->set_number('8340103')->is_valid_number, '福岡県八女郡広川町六田');
ok($zip->set_number('8340104')->is_valid_number, '福岡県八女郡広川町吉常');
ok($zip->set_number('8340105')->is_valid_number, '福岡県八女郡広川町長延');
ok($zip->set_number('8340111')->is_valid_number, '福岡県八女郡広川町日吉');
ok($zip->set_number('8340112')->is_valid_number, '福岡県八女郡広川町久泉');
ok($zip->set_number('8340113')->is_valid_number, '福岡県八女郡広川町川上');
ok($zip->set_number('8340114')->is_valid_number, '福岡県八女郡広川町太田');
ok($zip->set_number('8340115')->is_valid_number, '福岡県八女郡広川町新代');
ok($zip->set_number('8340121')->is_valid_number, '福岡県八女郡広川町広川');
ok($zip->set_number('8340122')->is_valid_number, '福岡県八女郡広川町一條');
ok($zip->set_number('8340123')->is_valid_number, '福岡県八女郡広川町藤田');
ok($zip->set_number('8340201')->is_valid_number, '福岡県八女市星野村');
ok($zip->set_number('8341101')->is_valid_number, '福岡県八女市上陽町上横山');
ok($zip->set_number('8341102')->is_valid_number, '福岡県八女市上陽町北川内');
ok($zip->set_number('8341103')->is_valid_number, '福岡県八女市上陽町久木原');
ok($zip->set_number('8341104')->is_valid_number, '福岡県八女市上陽町下横山');
ok($zip->set_number('8341201')->is_valid_number, '福岡県八女市黒木町北大淵');
ok($zip->set_number('8341202')->is_valid_number, '福岡県八女市黒木町大淵');
ok($zip->set_number('8341203')->is_valid_number, '福岡県八女市黒木町北木屋');
ok($zip->set_number('8341204')->is_valid_number, '福岡県八女市黒木町木屋');
ok($zip->set_number('8341205')->is_valid_number, '福岡県八女市黒木町田代');
ok($zip->set_number('8341211')->is_valid_number, '福岡県八女市黒木町土窪');
ok($zip->set_number('8341212')->is_valid_number, '福岡県八女市黒木町鹿子生');
ok($zip->set_number('8341213')->is_valid_number, '福岡県八女市黒木町本分');
ok($zip->set_number('8341214')->is_valid_number, '福岡県八女市黒木町田本');
ok($zip->set_number('8341215')->is_valid_number, '福岡県八女市黒木町湯辺田');
ok($zip->set_number('8341216')->is_valid_number, '福岡県八女市黒木町桑原');
ok($zip->set_number('8341217')->is_valid_number, '福岡県八女市黒木町黒木');
ok($zip->set_number('8341221')->is_valid_number, '福岡県八女市黒木町今');
ok($zip->set_number('8341222')->is_valid_number, '福岡県八女市黒木町笠原');
ok($zip->set_number('8341401')->is_valid_number, '福岡県八女市矢部村北矢部');
ok($zip->set_number('8341402')->is_valid_number, '福岡県八女市矢部村矢部');
ok($zip->set_number('8350000')->is_valid_number, '福岡県みやま市以下に掲載がない場合');
ok($zip->set_number('8350001')->is_valid_number, '福岡県みやま市瀬高町廣瀬');
ok($zip->set_number('8350002')->is_valid_number, '福岡県みやま市瀬高町小田');
ok($zip->set_number('8350003')->is_valid_number, '福岡県みやま市瀬高町本吉');
ok($zip->set_number('8350004')->is_valid_number, '福岡県みやま市瀬高町山門');
ok($zip->set_number('8350005')->is_valid_number, '福岡県みやま市瀬高町大草');
ok($zip->set_number('8350006')->is_valid_number, '福岡県みやま市瀬高町坂田');
ok($zip->set_number('8350007')->is_valid_number, '福岡県みやま市瀬高町長田');
ok($zip->set_number('8350011')->is_valid_number, '福岡県みやま市瀬高町松田');
ok($zip->set_number('8350012')->is_valid_number, '福岡県みやま市瀬高町大廣園');
ok($zip->set_number('8350013')->is_valid_number, '福岡県みやま市瀬高町太神');
ok($zip->set_number('8350014')->is_valid_number, '福岡県みやま市瀬高町河内');
ok($zip->set_number('8350015')->is_valid_number, '福岡県みやま市瀬高町泰仙寺');
ok($zip->set_number('8350016')->is_valid_number, '福岡県みやま市瀬高町濱田');
ok($zip->set_number('8350017')->is_valid_number, '福岡県みやま市瀬高町東津留');
ok($zip->set_number('8350018')->is_valid_number, '福岡県みやま市瀬高町高柳');
ok($zip->set_number('8350019')->is_valid_number, '福岡県みやま市瀬高町大江');
ok($zip->set_number('8350021')->is_valid_number, '福岡県みやま市瀬高町本郷');
ok($zip->set_number('8350022')->is_valid_number, '福岡県みやま市瀬高町文廣');
ok($zip->set_number('8350023')->is_valid_number, '福岡県みやま市瀬高町小川');
ok($zip->set_number('8350024')->is_valid_number, '福岡県みやま市瀬高町下庄');
ok($zip->set_number('8350025')->is_valid_number, '福岡県みやま市瀬高町上庄');
ok($zip->set_number('8350101')->is_valid_number, '福岡県みやま市山川町立山');
ok($zip->set_number('8350102')->is_valid_number, '福岡県みやま市山川町尾野');
ok($zip->set_number('8350103')->is_valid_number, '福岡県みやま市山川町清水');
ok($zip->set_number('8350104')->is_valid_number, '福岡県みやま市山川町河原内');
ok($zip->set_number('8350111')->is_valid_number, '福岡県みやま市山川町真弓');
ok($zip->set_number('8350112')->is_valid_number, '福岡県みやま市山川町北関');
ok($zip->set_number('8350113')->is_valid_number, '福岡県みやま市山川町重冨');
ok($zip->set_number('8350114')->is_valid_number, '福岡県みやま市山川町甲田');
ok($zip->set_number('8350115')->is_valid_number, '福岡県みやま市山川町原町');
ok($zip->set_number('8350131')->is_valid_number, '福岡県みやま市高田町舞鶴');
ok($zip->set_number('8350132')->is_valid_number, '福岡県みやま市高田町亀谷');
ok($zip->set_number('8350133')->is_valid_number, '福岡県みやま市高田町田浦');
ok($zip->set_number('8350134')->is_valid_number, '福岡県みやま市高田町飯江');
ok($zip->set_number('8350135')->is_valid_number, '福岡県みやま市高田町竹飯');
ok($zip->set_number('8350136')->is_valid_number, '福岡県みやま市高田町海津');
ok($zip->set_number('8360000')->is_valid_number, '福岡県大牟田市以下に掲載がない場合');
ok($zip->set_number('8360001')->is_valid_number, '福岡県大牟田市昭和開');
ok($zip->set_number('8360002')->is_valid_number, '福岡県大牟田市岬');
ok($zip->set_number('8360003')->is_valid_number, '福岡県大牟田市唐船');
ok($zip->set_number('8360004')->is_valid_number, '福岡県大牟田市手鎌');
ok($zip->set_number('8360005')->is_valid_number, '福岡県大牟田市椿黒町');
ok($zip->set_number('8360006')->is_valid_number, '福岡県大牟田市大黒町');
ok($zip->set_number('8360007')->is_valid_number, '福岡県大牟田市城町');
ok($zip->set_number('8360011')->is_valid_number, '福岡県大牟田市健老町');
ok($zip->set_number('8360012')->is_valid_number, '福岡県大牟田市明治町');
ok($zip->set_number('8360013')->is_valid_number, '福岡県大牟田市中町');
ok($zip->set_number('8360014')->is_valid_number, '福岡県大牟田市恵比須町');
ok($zip->set_number('8360015')->is_valid_number, '福岡県大牟田市天神町');
ok($zip->set_number('8360016')->is_valid_number, '福岡県大牟田市北磯町');
ok($zip->set_number('8360017')->is_valid_number, '福岡県大牟田市新開町');
ok($zip->set_number('8360021')->is_valid_number, '福岡県大牟田市浜町');
ok($zip->set_number('8360022')->is_valid_number, '福岡県大牟田市港町');
ok($zip->set_number('8360023')->is_valid_number, '福岡県大牟田市中島町');
ok($zip->set_number('8360024')->is_valid_number, '福岡県大牟田市住吉町');
ok($zip->set_number('8360025')->is_valid_number, '福岡県大牟田市中友町');
ok($zip->set_number('8360026')->is_valid_number, '福岡県大牟田市浜田町');
ok($zip->set_number('8360027')->is_valid_number, '福岡県大牟田市西浜田町');
ok($zip->set_number('8360031')->is_valid_number, '福岡県大牟田市西新町');
ok($zip->set_number('8360032')->is_valid_number, '福岡県大牟田市新地町');
ok($zip->set_number('8360033')->is_valid_number, '福岡県大牟田市松原町');
ok($zip->set_number('8360034')->is_valid_number, '福岡県大牟田市小浜町');
ok($zip->set_number('8360035')->is_valid_number, '福岡県大牟田市千代町');
ok($zip->set_number('8360036')->is_valid_number, '福岡県大牟田市小川町');
ok($zip->set_number('8360037')->is_valid_number, '福岡県大牟田市岬町');
ok($zip->set_number('8360041')->is_valid_number, '福岡県大牟田市新栄町');
ok($zip->set_number('8360042')->is_valid_number, '福岡県大牟田市栄町');
ok($zip->set_number('8360043')->is_valid_number, '福岡県大牟田市橋口町');
ok($zip->set_number('8360044')->is_valid_number, '福岡県大牟田市古町');
ok($zip->set_number('8360045')->is_valid_number, '福岡県大牟田市久保田町');
ok($zip->set_number('8360046')->is_valid_number, '福岡県大牟田市本町');
ok($zip->set_number('8360047')->is_valid_number, '福岡県大牟田市大正町');
ok($zip->set_number('8360051')->is_valid_number, '福岡県大牟田市諏訪町');
ok($zip->set_number('8360052')->is_valid_number, '福岡県大牟田市白金町');
ok($zip->set_number('8360053')->is_valid_number, '福岡県大牟田市山下町');
ok($zip->set_number('8360054')->is_valid_number, '福岡県大牟田市天領町');
ok($zip->set_number('8360055')->is_valid_number, '福岡県大牟田市樋口町');
ok($zip->set_number('8360056')->is_valid_number, '福岡県大牟田市姫島町');
ok($zip->set_number('8360057')->is_valid_number, '福岡県大牟田市汐屋町');
ok($zip->set_number('8360061')->is_valid_number, '福岡県大牟田市新港町');
ok($zip->set_number('8360062')->is_valid_number, '福岡県大牟田市西港町');
ok($zip->set_number('8360063')->is_valid_number, '福岡県大牟田市入船町');
ok($zip->set_number('8360064')->is_valid_number, '福岡県大牟田市高砂町');
ok($zip->set_number('8360065')->is_valid_number, '福岡県大牟田市三川町');
ok($zip->set_number('8360066')->is_valid_number, '福岡県大牟田市浪花町');
ok($zip->set_number('8360067')->is_valid_number, '福岡県大牟田市四山町');
ok($zip->set_number('8360071')->is_valid_number, '福岡県大牟田市加納町');
ok($zip->set_number('8360072')->is_valid_number, '福岡県大牟田市上屋敷町');
ok($zip->set_number('8360073')->is_valid_number, '福岡県大牟田市船津町');
ok($zip->set_number('8360074')->is_valid_number, '福岡県大牟田市藤田町');
ok($zip->set_number('8360075')->is_valid_number, '福岡県大牟田市南船津町');
ok($zip->set_number('8360076')->is_valid_number, '福岡県大牟田市三里町');
ok($zip->set_number('8360077')->is_valid_number, '福岡県大牟田市早米来町');
ok($zip->set_number('8360081')->is_valid_number, '福岡県大牟田市田端町');
ok($zip->set_number('8360082')->is_valid_number, '福岡県大牟田市片平町');
ok($zip->set_number('8360083')->is_valid_number, '福岡県大牟田市長田町');
ok($zip->set_number('8360084')->is_valid_number, '福岡県大牟田市馬場町');
ok($zip->set_number('8360085')->is_valid_number, '福岡県大牟田市一部町');
ok($zip->set_number('8360086')->is_valid_number, '福岡県大牟田市馬込町');
ok($zip->set_number('8360087')->is_valid_number, '福岡県大牟田市飯田町');
ok($zip->set_number('8360091')->is_valid_number, '福岡県大牟田市沖田町');
ok($zip->set_number('8360092')->is_valid_number, '福岡県大牟田市桜町');
ok($zip->set_number('8360093')->is_valid_number, '福岡県大牟田市神田町');
ok($zip->set_number('8360094')->is_valid_number, '福岡県大牟田市臼井町');
ok($zip->set_number('8360095')->is_valid_number, '福岡県大牟田市野添町');
ok($zip->set_number('8360096')->is_valid_number, '福岡県大牟田市萩尾町');
ok($zip->set_number('8360097')->is_valid_number, '福岡県大牟田市東萩尾町');
ok($zip->set_number('8360801')->is_valid_number, '福岡県大牟田市柿園町');
ok($zip->set_number('8360802')->is_valid_number, '福岡県大牟田市日出町');
ok($zip->set_number('8360803')->is_valid_number, '福岡県大牟田市鳥塚町');
ok($zip->set_number('8360804')->is_valid_number, '福岡県大牟田市長溝町');
ok($zip->set_number('8360805')->is_valid_number, '福岡県大牟田市通町');
ok($zip->set_number('8360806')->is_valid_number, '福岡県大牟田市東新町');
ok($zip->set_number('8360807')->is_valid_number, '福岡県大牟田市旭町');
ok($zip->set_number('8360811')->is_valid_number, '福岡県大牟田市八尻町');
ok($zip->set_number('8360812')->is_valid_number, '福岡県大牟田市亀甲町');
ok($zip->set_number('8360813')->is_valid_number, '福岡県大牟田市平原町');
ok($zip->set_number('8360814')->is_valid_number, '福岡県大牟田市龍湖瀬町');
ok($zip->set_number('8360815')->is_valid_number, '福岡県大牟田市瓦町');
ok($zip->set_number('8360816')->is_valid_number, '福岡県大牟田市八本町');
ok($zip->set_number('8360817')->is_valid_number, '福岡県大牟田市浅牟田町');
ok($zip->set_number('8360821')->is_valid_number, '福岡県大牟田市東泉町');
ok($zip->set_number('8360822')->is_valid_number, '福岡県大牟田市稲荷町');
ok($zip->set_number('8360823')->is_valid_number, '福岡県大牟田市亀谷町');
ok($zip->set_number('8360824')->is_valid_number, '福岡県大牟田市大浦町');
ok($zip->set_number('8360825')->is_valid_number, '福岡県大牟田市三坑町');
ok($zip->set_number('8360826')->is_valid_number, '福岡県大牟田市焼石町');
ok($zip->set_number('8360827')->is_valid_number, '福岡県大牟田市東宮浦町');
ok($zip->set_number('8360831')->is_valid_number, '福岡県大牟田市泉町');
ok($zip->set_number('8360832')->is_valid_number, '福岡県大牟田市常盤町');
ok($zip->set_number('8360833')->is_valid_number, '福岡県大牟田市山上町');
ok($zip->set_number('8360834')->is_valid_number, '福岡県大牟田市一本町');
ok($zip->set_number('8360835')->is_valid_number, '福岡県大牟田市西宮浦町');
ok($zip->set_number('8360836')->is_valid_number, '福岡県大牟田市左古町');
ok($zip->set_number('8360837')->is_valid_number, '福岡県大牟田市谷町');
ok($zip->set_number('8360841')->is_valid_number, '福岡県大牟田市築町');
ok($zip->set_number('8360842')->is_valid_number, '福岡県大牟田市有明町');
ok($zip->set_number('8360843')->is_valid_number, '福岡県大牟田市不知火町');
ok($zip->set_number('8360844')->is_valid_number, '福岡県大牟田市浄真町');
ok($zip->set_number('8360845')->is_valid_number, '福岡県大牟田市正山町');
ok($zip->set_number('8360846')->is_valid_number, '福岡県大牟田市右京町');
ok($zip->set_number('8360847')->is_valid_number, '福岡県大牟田市八江町');
ok($zip->set_number('8360851')->is_valid_number, '福岡県大牟田市笹林町');
ok($zip->set_number('8360852')->is_valid_number, '福岡県大牟田市曙町');
ok($zip->set_number('8360853')->is_valid_number, '福岡県大牟田市上町');
ok($zip->set_number('8360854')->is_valid_number, '福岡県大牟田市出雲町');
ok($zip->set_number('8360855')->is_valid_number, '福岡県大牟田市松浦町');
ok($zip->set_number('8360856')->is_valid_number, '福岡県大牟田市宮坂町');
ok($zip->set_number('8360857')->is_valid_number, '福岡県大牟田市宮山町');
ok($zip->set_number('8360861')->is_valid_number, '福岡県大牟田市宝坂町');
ok($zip->set_number('8360862')->is_valid_number, '福岡県大牟田市原山町');
ok($zip->set_number('8360863')->is_valid_number, '福岡県大牟田市一浦町');
ok($zip->set_number('8360864')->is_valid_number, '福岡県大牟田市真道寺町');
ok($zip->set_number('8360865')->is_valid_number, '福岡県大牟田市七浦町');
ok($zip->set_number('8360866')->is_valid_number, '福岡県大牟田市上官町');
ok($zip->set_number('8360867')->is_valid_number, '福岡県大牟田市花園町');
ok($zip->set_number('8360871')->is_valid_number, '福岡県大牟田市昭和町');
ok($zip->set_number('8360872')->is_valid_number, '福岡県大牟田市黄金町');
ok($zip->set_number('8360873')->is_valid_number, '福岡県大牟田市駛馬町');
ok($zip->set_number('8360874')->is_valid_number, '福岡県大牟田市末広町');
ok($zip->set_number('8360875')->is_valid_number, '福岡県大牟田市宮原町');
ok($zip->set_number('8360876')->is_valid_number, '福岡県大牟田市若宮町');
ok($zip->set_number('8360877')->is_valid_number, '福岡県大牟田市延命寺町');
ok($zip->set_number('8360881')->is_valid_number, '福岡県大牟田市米生町');
ok($zip->set_number('8360882')->is_valid_number, '福岡県大牟田市臼井新町');
ok($zip->set_number('8360883')->is_valid_number, '福岡県大牟田市馬渡町');
ok($zip->set_number('8360884')->is_valid_number, '福岡県大牟田市笹原町');
ok($zip->set_number('8360885')->is_valid_number, '福岡県大牟田市下池町');
ok($zip->set_number('8360886')->is_valid_number, '福岡県大牟田市勝立');
ok($zip->set_number('8360891')->is_valid_number, '福岡県大牟田市合成町');
ok($zip->set_number('8360892')->is_valid_number, '福岡県大牟田市早鐘町');
ok($zip->set_number('8360893')->is_valid_number, '福岡県大牟田市櫟野');
ok($zip->set_number('8360894')->is_valid_number, '福岡県大牟田市教楽来');
ok($zip->set_number('8360895')->is_valid_number, '福岡県大牟田市新勝立町');
ok($zip->set_number('8360896')->is_valid_number, '福岡県大牟田市天道町');
ok($zip->set_number('8360897')->is_valid_number, '福岡県大牟田市青葉町');
ok($zip->set_number('8370901')->is_valid_number, '福岡県大牟田市四ケ');
ok($zip->set_number('8370902')->is_valid_number, '福岡県大牟田市上内');
ok($zip->set_number('8370903')->is_valid_number, '福岡県大牟田市宮崎');
ok($zip->set_number('8370904')->is_valid_number, '福岡県大牟田市吉野');
ok($zip->set_number('8370905')->is_valid_number, '福岡県大牟田市甘木');
ok($zip->set_number('8370906')->is_valid_number, '福岡県大牟田市倉永');
ok($zip->set_number('8370907')->is_valid_number, '福岡県大牟田市四箇新町');
ok($zip->set_number('8370910')->is_valid_number, '福岡県大牟田市岩本新町');
ok($zip->set_number('8370911')->is_valid_number, '福岡県大牟田市橘');
ok($zip->set_number('8370912')->is_valid_number, '福岡県大牟田市白銀');
ok($zip->set_number('8370913')->is_valid_number, '福岡県大牟田市岩本');
ok($zip->set_number('8370914')->is_valid_number, '福岡県大牟田市宮部');
ok($zip->set_number('8370915')->is_valid_number, '福岡県大牟田市久福木');
ok($zip->set_number('8370916')->is_valid_number, '福岡県大牟田市田隈');
ok($zip->set_number('8370917')->is_valid_number, '福岡県大牟田市草木');
ok($zip->set_number('8370921')->is_valid_number, '福岡県大牟田市三池');
ok($zip->set_number('8370922')->is_valid_number, '福岡県大牟田市今山');
ok($zip->set_number('8370923')->is_valid_number, '福岡県大牟田市新町');
ok($zip->set_number('8370924')->is_valid_number, '福岡県大牟田市歴木');
ok($zip->set_number('8370925')->is_valid_number, '福岡県大牟田市白川');
ok($zip->set_number('8370926')->is_valid_number, '福岡県大牟田市上白川町');
ok($zip->set_number('8370927')->is_valid_number, '福岡県大牟田市中白川町');
ok($zip->set_number('8370928')->is_valid_number, '福岡県大牟田市下白川町');
ok($zip->set_number('8380000')->is_valid_number, '福岡県朝倉市以下に掲載がない場合');
ok($zip->set_number('8380000')->is_valid_number, '福岡県朝倉郡筑前町以下に掲載がない場合');
ok($zip->set_number('8380001')->is_valid_number, '福岡県朝倉市秋月');
ok($zip->set_number('8380002')->is_valid_number, '福岡県朝倉市長谷山');
ok($zip->set_number('8380003')->is_valid_number, '福岡県朝倉市楢原');
ok($zip->set_number('8380004')->is_valid_number, '福岡県朝倉市隈江');
ok($zip->set_number('8380005')->is_valid_number, '福岡県朝倉市甘水');
ok($zip->set_number('8380011')->is_valid_number, '福岡県朝倉市秋月野鳥');
ok($zip->set_number('8380012')->is_valid_number, '福岡県朝倉市江川');
ok($zip->set_number('8380013')->is_valid_number, '福岡県朝倉市田代');
ok($zip->set_number('8380014')->is_valid_number, '福岡県朝倉市山見');
ok($zip->set_number('8380015')->is_valid_number, '福岡県朝倉市持丸');
ok($zip->set_number('8380016')->is_valid_number, '福岡県朝倉市下渕');
ok($zip->set_number('8380017')->is_valid_number, '福岡県朝倉市千手');
ok($zip->set_number('8380018')->is_valid_number, '福岡県朝倉市日向石');
ok($zip->set_number('8380019')->is_valid_number, '福岡県朝倉市上秋月');
ok($zip->set_number('8380020')->is_valid_number, '福岡県朝倉市美奈宜の杜');
ok($zip->set_number('8380021')->is_valid_number, '福岡県朝倉市矢野竹');
ok($zip->set_number('8380022')->is_valid_number, '福岡県朝倉市城');
ok($zip->set_number('8380023')->is_valid_number, '福岡県朝倉市三奈木');
ok($zip->set_number('8380024')->is_valid_number, '福岡県朝倉市牛鶴');
ok($zip->set_number('8380025')->is_valid_number, '福岡県朝倉市相窪');
ok($zip->set_number('8380026')->is_valid_number, '福岡県朝倉市柿原');
ok($zip->set_number('8380027')->is_valid_number, '福岡県朝倉市板屋');
ok($zip->set_number('8380028')->is_valid_number, '福岡県朝倉市屋形原');
ok($zip->set_number('8380029')->is_valid_number, '福岡県朝倉市荷原');
ok($zip->set_number('8380031')->is_valid_number, '福岡県朝倉市屋永');
ok($zip->set_number('8380032')->is_valid_number, '福岡県朝倉市中島田');
ok($zip->set_number('8380033')->is_valid_number, '福岡県朝倉市田島');
ok($zip->set_number('8380034')->is_valid_number, '福岡県朝倉市福光');
ok($zip->set_number('8380035')->is_valid_number, '福岡県朝倉市中');
ok($zip->set_number('8380036')->is_valid_number, '福岡県朝倉市片延');
ok($zip->set_number('8380037')->is_valid_number, '福岡県朝倉市林田');
ok($zip->set_number('8380038')->is_valid_number, '福岡県朝倉市鵜木');
ok($zip->set_number('8380039')->is_valid_number, '福岡県朝倉市桑原');
ok($zip->set_number('8380041')->is_valid_number, '福岡県朝倉市鎌崎');
ok($zip->set_number('8380042')->is_valid_number, '福岡県朝倉市上畑');
ok($zip->set_number('8380043')->is_valid_number, '福岡県朝倉市長田');
ok($zip->set_number('8380044')->is_valid_number, '福岡県朝倉市八重津');
ok($zip->set_number('8380045')->is_valid_number, '福岡県朝倉市白鳥');
ok($zip->set_number('8380046')->is_valid_number, '福岡県朝倉市倉吉');
ok($zip->set_number('8380047')->is_valid_number, '福岡県朝倉市徳渕');
ok($zip->set_number('8380048')->is_valid_number, '福岡県朝倉市金丸');
ok($zip->set_number('8380051')->is_valid_number, '福岡県朝倉市小田');
ok($zip->set_number('8380052')->is_valid_number, '福岡県朝倉市小隈');
ok($zip->set_number('8380053')->is_valid_number, '福岡県朝倉市中寒水');
ok($zip->set_number('8380054')->is_valid_number, '福岡県朝倉市草水');
ok($zip->set_number('8380055')->is_valid_number, '福岡県朝倉市下浦');
ok($zip->set_number('8380056')->is_valid_number, '福岡県朝倉市中原');
ok($zip->set_number('8380057')->is_valid_number, '福岡県朝倉市上浦');
ok($zip->set_number('8380058')->is_valid_number, '福岡県朝倉市馬田');
ok($zip->set_number('8380059')->is_valid_number, '福岡県朝倉市平塚');
ok($zip->set_number('8380061')->is_valid_number, '福岡県朝倉市菩提寺');
ok($zip->set_number('8380062')->is_valid_number, '福岡県朝倉市堤');
ok($zip->set_number('8380063')->is_valid_number, '福岡県朝倉市古賀');
ok($zip->set_number('8380064')->is_valid_number, '福岡県朝倉市頓田');
ok($zip->set_number('8380065')->is_valid_number, '福岡県朝倉市一木');
ok($zip->set_number('8380066')->is_valid_number, '福岡県朝倉市千代丸');
ok($zip->set_number('8380067')->is_valid_number, '福岡県朝倉市牛木');
ok($zip->set_number('8380068')->is_valid_number, '福岡県朝倉市甘木');
ok($zip->set_number('8380069')->is_valid_number, '福岡県朝倉市来春');
ok($zip->set_number('8380071')->is_valid_number, '福岡県朝倉市佐田');
ok($zip->set_number('8380072')->is_valid_number, '福岡県朝倉市黒川');
ok($zip->set_number('8380100')->is_valid_number, '福岡県小郡市以下に掲載がない場合');
ok($zip->set_number('8380101')->is_valid_number, '福岡県小郡市美鈴が丘');
ok($zip->set_number('8380102')->is_valid_number, '福岡県小郡市津古');
ok($zip->set_number('8380103')->is_valid_number, '福岡県小郡市三国が丘');
ok($zip->set_number('8380104')->is_valid_number, '福岡県小郡市乙隈');
ok($zip->set_number('8380105')->is_valid_number, '福岡県小郡市横隈');
ok($zip->set_number('8380106')->is_valid_number, '福岡県小郡市三沢');
ok($zip->set_number('8380107')->is_valid_number, '福岡県小郡市希みが丘');
ok($zip->set_number('8380108')->is_valid_number, '福岡県小郡市美鈴の杜');
ok($zip->set_number('8380109')->is_valid_number, '福岡県小郡市あすみ');
ok($zip->set_number('8380111')->is_valid_number, '福岡県小郡市吹上');
ok($zip->set_number('8380112')->is_valid_number, '福岡県小郡市干潟');
ok($zip->set_number('8380113')->is_valid_number, '福岡県小郡市山隈');
ok($zip->set_number('8380114')->is_valid_number, '福岡県小郡市井上');
ok($zip->set_number('8380115')->is_valid_number, '福岡県小郡市大保');
ok($zip->set_number('8380116')->is_valid_number, '福岡県小郡市力武');
ok($zip->set_number('8380121')->is_valid_number, '福岡県小郡市上岩田');
ok($zip->set_number('8380122')->is_valid_number, '福岡県小郡市松崎');
ok($zip->set_number('8380123')->is_valid_number, '福岡県小郡市下岩田');
ok($zip->set_number('8380124')->is_valid_number, '福岡県小郡市古飯');
ok($zip->set_number('8380125')->is_valid_number, '福岡県小郡市二タ');
ok($zip->set_number('8380126')->is_valid_number, '福岡県小郡市二森');
ok($zip->set_number('8380127')->is_valid_number, '福岡県小郡市大崎');
ok($zip->set_number('8380128')->is_valid_number, '福岡県小郡市稲吉');
ok($zip->set_number('8380131')->is_valid_number, '福岡県小郡市平方');
ok($zip->set_number('8380132')->is_valid_number, '福岡県小郡市光行');
ok($zip->set_number('8380133')->is_valid_number, '福岡県小郡市八坂');
ok($zip->set_number('8380134')->is_valid_number, '福岡県小郡市下西鰺坂');
ok($zip->set_number('8380135')->is_valid_number, '福岡県小郡市赤川');
ok($zip->set_number('8380136')->is_valid_number, '福岡県小郡市上西鰺坂');
ok($zip->set_number('8380137')->is_valid_number, '福岡県小郡市福童');
ok($zip->set_number('8380138')->is_valid_number, '福岡県小郡市寺福童');
ok($zip->set_number('8380141')->is_valid_number, '福岡県小郡市小郡');
ok($zip->set_number('8380142')->is_valid_number, '福岡県小郡市大板井');
ok($zip->set_number('8380143')->is_valid_number, '福岡県小郡市小板井');
ok($zip->set_number('8380144')->is_valid_number, '福岡県小郡市祇園');
ok($zip->set_number('8380201')->is_valid_number, '福岡県朝倉郡筑前町櫛木');
ok($zip->set_number('8380202')->is_valid_number, '福岡県朝倉郡筑前町三箇山');
ok($zip->set_number('8380203')->is_valid_number, '福岡県朝倉郡筑前町畑嶋');
ok($zip->set_number('8380204')->is_valid_number, '福岡県朝倉郡筑前町長者町');
ok($zip->set_number('8380205')->is_valid_number, '福岡県朝倉郡筑前町三並');
ok($zip->set_number('8380206')->is_valid_number, '福岡県朝倉郡筑前町曽根田');
ok($zip->set_number('8380207')->is_valid_number, '福岡県朝倉郡筑前町三牟田');
ok($zip->set_number('8380211')->is_valid_number, '福岡県朝倉郡筑前町下高場');
ok($zip->set_number('8380212')->is_valid_number, '福岡県朝倉郡筑前町四三嶋');
ok($zip->set_number('8380213')->is_valid_number, '福岡県朝倉郡筑前町安野');
ok($zip->set_number('8380214')->is_valid_number, '福岡県朝倉郡筑前町東小田');
ok($zip->set_number('8380215')->is_valid_number, '福岡県朝倉郡筑前町篠隈');
ok($zip->set_number('8380221')->is_valid_number, '福岡県朝倉郡筑前町吹田');
ok($zip->set_number('8380222')->is_valid_number, '福岡県朝倉郡筑前町赤坂');
ok($zip->set_number('8380223')->is_valid_number, '福岡県朝倉郡筑前町砥上');
ok($zip->set_number('8380224')->is_valid_number, '福岡県朝倉郡筑前町松延');
ok($zip->set_number('8380225')->is_valid_number, '福岡県朝倉郡筑前町石櫃');
ok($zip->set_number('8380226')->is_valid_number, '福岡県朝倉郡筑前町中牟田');
ok($zip->set_number('8380227')->is_valid_number, '福岡県朝倉郡筑前町朝日');
ok($zip->set_number('8380228')->is_valid_number, '福岡県朝倉郡筑前町二');
ok($zip->set_number('8380801')->is_valid_number, '福岡県朝倉郡筑前町栗田');
ok($zip->set_number('8380802')->is_valid_number, '福岡県朝倉郡筑前町久光');
ok($zip->set_number('8380803')->is_valid_number, '福岡県朝倉郡筑前町当所');
ok($zip->set_number('8380804')->is_valid_number, '福岡県朝倉郡筑前町森山');
ok($zip->set_number('8380811')->is_valid_number, '福岡県朝倉郡筑前町弥永');
ok($zip->set_number('8380812')->is_valid_number, '福岡県朝倉郡筑前町大塚');
ok($zip->set_number('8380813')->is_valid_number, '福岡県朝倉郡筑前町依井');
ok($zip->set_number('8380814')->is_valid_number, '福岡県朝倉郡筑前町高田');
ok($zip->set_number('8380815')->is_valid_number, '福岡県朝倉郡筑前町野町');
ok($zip->set_number('8380816')->is_valid_number, '福岡県朝倉郡筑前町新町');
ok($zip->set_number('8380817')->is_valid_number, '福岡県朝倉郡筑前町朝園');
ok($zip->set_number('8380821')->is_valid_number, '福岡県朝倉郡筑前町上高場');
ok($zip->set_number('8380822')->is_valid_number, '福岡県朝倉郡筑前町高上');
ok($zip->set_number('8380823')->is_valid_number, '福岡県朝倉郡筑前町山隈');
ok($zip->set_number('8380824')->is_valid_number, '福岡県朝倉郡筑前町原地蔵');
ok($zip->set_number('8380825')->is_valid_number, '福岡県朝倉郡筑前町大久保');
ok($zip->set_number('8381301')->is_valid_number, '福岡県朝倉市烏集院');
ok($zip->set_number('8381302')->is_valid_number, '福岡県朝倉市宮野');
ok($zip->set_number('8381303')->is_valid_number, '福岡県朝倉市比良松');
ok($zip->set_number('8381304')->is_valid_number, '福岡県朝倉市須川');
ok($zip->set_number('8381305')->is_valid_number, '福岡県朝倉市菱野');
ok($zip->set_number('8381306')->is_valid_number, '福岡県朝倉市山田');
ok($zip->set_number('8381307')->is_valid_number, '福岡県朝倉市古毛');
ok($zip->set_number('8381311')->is_valid_number, '福岡県朝倉市多々連');
ok($zip->set_number('8381312')->is_valid_number, '福岡県朝倉市田中');
ok($zip->set_number('8381313')->is_valid_number, '福岡県朝倉市上寺');
ok($zip->set_number('8381314')->is_valid_number, '福岡県朝倉市長渕');
ok($zip->set_number('8381315')->is_valid_number, '福岡県朝倉市入地');
ok($zip->set_number('8381316')->is_valid_number, '福岡県朝倉市大庭');
ok($zip->set_number('8381317')->is_valid_number, '福岡県朝倉市石成');
ok($zip->set_number('8381501')->is_valid_number, '福岡県朝倉市杷木赤谷');
ok($zip->set_number('8381502')->is_valid_number, '福岡県朝倉市杷木松末');
ok($zip->set_number('8381503')->is_valid_number, '福岡県朝倉市杷木大山');
ok($zip->set_number('8381504')->is_valid_number, '福岡県朝倉市杷木星丸');
ok($zip->set_number('8381505')->is_valid_number, '福岡県朝倉市杷木穂坂');
ok($zip->set_number('8381506')->is_valid_number, '福岡県朝倉市杷木林田');
ok($zip->set_number('8381507')->is_valid_number, '福岡県朝倉市杷木白木');
ok($zip->set_number('8381511')->is_valid_number, '福岡県朝倉市杷木池田');
ok($zip->set_number('8381512')->is_valid_number, '福岡県朝倉市杷木寒水');
ok($zip->set_number('8381513')->is_valid_number, '福岡県朝倉市杷木古賀');
ok($zip->set_number('8381514')->is_valid_number, '福岡県朝倉市杷木久喜宮');
ok($zip->set_number('8381515')->is_valid_number, '福岡県朝倉市杷木若市');
ok($zip->set_number('8381521')->is_valid_number, '福岡県朝倉市杷木志波');
ok($zip->set_number('8381601')->is_valid_number, '福岡県朝倉郡東峰村小石原');
ok($zip->set_number('8381602')->is_valid_number, '福岡県朝倉郡東峰村小石原鼓');
ok($zip->set_number('8381700')->is_valid_number, '福岡県朝倉郡東峰村以下に掲載がない場合');
ok($zip->set_number('8381701')->is_valid_number, '福岡県朝倉郡東峰村宝珠山');
ok($zip->set_number('8381702')->is_valid_number, '福岡県朝倉郡東峰村福井');
ok($zip->set_number('8390000')->is_valid_number, '福岡県久留米市以下に掲載がない場合');
ok($zip->set_number('8390201')->is_valid_number, '福岡県みやま市高田町昭和開');
ok($zip->set_number('8390202')->is_valid_number, '福岡県みやま市高田町永治');
ok($zip->set_number('8390203')->is_valid_number, '福岡県みやま市高田町黒崎開');
ok($zip->set_number('8390204')->is_valid_number, '福岡県みやま市高田町北新開');
ok($zip->set_number('8390205')->is_valid_number, '福岡県みやま市高田町南新開');
ok($zip->set_number('8390211')->is_valid_number, '福岡県みやま市高田町徳島');
ok($zip->set_number('8390212')->is_valid_number, '福岡県みやま市高田町江浦町');
ok($zip->set_number('8390213')->is_valid_number, '福岡県みやま市高田町江浦');
ok($zip->set_number('8390214')->is_valid_number, '福岡県みやま市高田町今福');
ok($zip->set_number('8390215')->is_valid_number, '福岡県みやま市高田町濃施');
ok($zip->set_number('8390221')->is_valid_number, '福岡県みやま市高田町下楠田');
ok($zip->set_number('8390222')->is_valid_number, '福岡県みやま市高田町原');
ok($zip->set_number('8390223')->is_valid_number, '福岡県みやま市高田町岩津');
ok($zip->set_number('8390224')->is_valid_number, '福岡県みやま市高田町田尻');
ok($zip->set_number('8390225')->is_valid_number, '福岡県みやま市高田町上楠田');
ok($zip->set_number('8390241')->is_valid_number, '福岡県柳川市大和町徳益');
ok($zip->set_number('8390242')->is_valid_number, '福岡県柳川市大和町豊原');
ok($zip->set_number('8390243')->is_valid_number, '福岡県柳川市大和町塩塚');
ok($zip->set_number('8390244')->is_valid_number, '福岡県柳川市大和町六合');
ok($zip->set_number('8390251')->is_valid_number, '福岡県柳川市大和町明野');
ok($zip->set_number('8390252')->is_valid_number, '福岡県柳川市大和町栄');
ok($zip->set_number('8390253')->is_valid_number, '福岡県柳川市大和町鷹ノ尾');
ok($zip->set_number('8390254')->is_valid_number, '福岡県柳川市大和町中島');
ok($zip->set_number('8390261')->is_valid_number, '福岡県柳川市大和町皿垣開');
ok($zip->set_number('8390262')->is_valid_number, '福岡県柳川市大和町永田開');
ok($zip->set_number('8390263')->is_valid_number, '福岡県柳川市大和町大坪');
ok($zip->set_number('8390264')->is_valid_number, '福岡県柳川市大和町谷垣');
ok($zip->set_number('8390801')->is_valid_number, '福岡県久留米市宮ノ陣');
ok($zip->set_number('8390802')->is_valid_number, '福岡県久留米市宮ノ陣町五郎丸');
ok($zip->set_number('8390803')->is_valid_number, '福岡県久留米市宮ノ陣町大杜');
ok($zip->set_number('8390804')->is_valid_number, '福岡県久留米市宮ノ陣町若松');
ok($zip->set_number('8390805')->is_valid_number, '福岡県久留米市宮ノ陣町八丁島');
ok($zip->set_number('8390806')->is_valid_number, '福岡県久留米市東合川干出町');
ok($zip->set_number('8390807')->is_valid_number, '福岡県久留米市東合川町');
ok($zip->set_number('8390808')->is_valid_number, '福岡県久留米市東合川新町');
ok($zip->set_number('8390809')->is_valid_number, '福岡県久留米市東合川');
ok($zip->set_number('8390811')->is_valid_number, '福岡県久留米市山川神代');
ok($zip->set_number('8390812')->is_valid_number, '福岡県久留米市山川安居野');
ok($zip->set_number('8390813')->is_valid_number, '福岡県久留米市山川市ノ上町');
ok($zip->set_number('8390814')->is_valid_number, '福岡県久留米市山川追分');
ok($zip->set_number('8390815')->is_valid_number, '福岡県久留米市山川沓形町');
ok($zip->set_number('8390816')->is_valid_number, '福岡県久留米市山川野口町');
ok($zip->set_number('8390817')->is_valid_number, '福岡県久留米市山川町');
ok($zip->set_number('8390821')->is_valid_number, '福岡県久留米市太郎原町');
ok($zip->set_number('8390822')->is_valid_number, '福岡県久留米市善導寺町木塚');
ok($zip->set_number('8390823')->is_valid_number, '福岡県久留米市善導寺町与田');
ok($zip->set_number('8390824')->is_valid_number, '福岡県久留米市善導寺町飯田');
ok($zip->set_number('8390825')->is_valid_number, '福岡県久留米市善導寺町島');
ok($zip->set_number('8390826')->is_valid_number, '福岡県久留米市山本町耳納');
ok($zip->set_number('8390827')->is_valid_number, '福岡県久留米市山本町豊田');
ok($zip->set_number('8390831')->is_valid_number, '福岡県久留米市大橋町蜷川');
ok($zip->set_number('8390832')->is_valid_number, '福岡県久留米市大橋町合楽');
ok($zip->set_number('8390833')->is_valid_number, '福岡県久留米市大橋町常持');
ok($zip->set_number('8390834')->is_valid_number, '福岡県久留米市草野町紅桃林');
ok($zip->set_number('8390835')->is_valid_number, '福岡県久留米市草野町草野');
ok($zip->set_number('8390836')->is_valid_number, '福岡県久留米市草野町吉木');
ok($zip->set_number('8390837')->is_valid_number, '福岡県久留米市草野町矢作');
ok($zip->set_number('8390841')->is_valid_number, '福岡県久留米市御井旗崎');
ok($zip->set_number('8390842')->is_valid_number, '福岡県久留米市御井朝妻');
ok($zip->set_number('8390843')->is_valid_number, '福岡県久留米市朝妻町');
ok($zip->set_number('8390851')->is_valid_number, '福岡県久留米市御井町');
ok($zip->set_number('8390852')->is_valid_number, '福岡県久留米市高良内町');
ok($zip->set_number('8390853')->is_valid_number, '福岡県久留米市青峰');
ok($zip->set_number('8390861')->is_valid_number, '福岡県久留米市合川町');
ok($zip->set_number('8390862')->is_valid_number, '福岡県久留米市野中町');
ok($zip->set_number('8390863')->is_valid_number, '福岡県久留米市国分町');
ok($zip->set_number('8390864')->is_valid_number, '福岡県久留米市百年公園');
ok($zip->set_number('8390865')->is_valid_number, '福岡県久留米市新合川');
ok($zip->set_number('8391201')->is_valid_number, '福岡県久留米市田主丸町長栖');
ok($zip->set_number('8391202')->is_valid_number, '福岡県久留米市田主丸町鷹取');
ok($zip->set_number('8391203')->is_valid_number, '福岡県久留米市田主丸町秋成');
ok($zip->set_number('8391204')->is_valid_number, '福岡県久留米市田主丸町殖木');
ok($zip->set_number('8391205')->is_valid_number, '福岡県久留米市田主丸町船越');
ok($zip->set_number('8391206')->is_valid_number, '福岡県久留米市田主丸町吉本');
ok($zip->set_number('8391211')->is_valid_number, '福岡県久留米市田主丸町森部');
ok($zip->set_number('8391212')->is_valid_number, '福岡県久留米市田主丸町石垣');
ok($zip->set_number('8391213')->is_valid_number, '福岡県久留米市田主丸町益生田');
ok($zip->set_number('8391214')->is_valid_number, '福岡県久留米市田主丸町地徳');
ok($zip->set_number('8391215')->is_valid_number, '福岡県久留米市田主丸町竹野');
ok($zip->set_number('8391216')->is_valid_number, '福岡県久留米市田主丸町中尾');
ok($zip->set_number('8391221')->is_valid_number, '福岡県久留米市田主丸町上原');
ok($zip->set_number('8391222')->is_valid_number, '福岡県久留米市田主丸町志塚島');
ok($zip->set_number('8391223')->is_valid_number, '福岡県久留米市田主丸町以真恵');
ok($zip->set_number('8391224')->is_valid_number, '福岡県久留米市田主丸町牧');
ok($zip->set_number('8391225')->is_valid_number, '福岡県久留米市田主丸町菅原');
ok($zip->set_number('8391226')->is_valid_number, '福岡県久留米市田主丸町八幡');
ok($zip->set_number('8391227')->is_valid_number, '福岡県久留米市田主丸町朝森');
ok($zip->set_number('8391228')->is_valid_number, '福岡県久留米市田主丸町恵利');
ok($zip->set_number('8391231')->is_valid_number, '福岡県久留米市田主丸町野田');
ok($zip->set_number('8391232')->is_valid_number, '福岡県久留米市田主丸町常盤');
ok($zip->set_number('8391233')->is_valid_number, '福岡県久留米市田主丸町田主丸');
ok($zip->set_number('8391234')->is_valid_number, '福岡県久留米市田主丸町豊城');
ok($zip->set_number('8391301')->is_valid_number, '福岡県うきは市吉井町桜井');
ok($zip->set_number('8391302')->is_valid_number, '福岡県うきは市吉井町徳丸');
ok($zip->set_number('8391303')->is_valid_number, '福岡県うきは市吉井町宮田');
ok($zip->set_number('8391304')->is_valid_number, '福岡県うきは市吉井町千年');
ok($zip->set_number('8391305')->is_valid_number, '福岡県うきは市吉井町福永');
ok($zip->set_number('8391306')->is_valid_number, '福岡県うきは市吉井町新治');
ok($zip->set_number('8391307')->is_valid_number, '福岡県うきは市吉井町橘田');
ok($zip->set_number('8391308')->is_valid_number, '福岡県うきは市吉井町八和田');
ok($zip->set_number('8391311')->is_valid_number, '福岡県うきは市吉井町若宮');
ok($zip->set_number('8391312')->is_valid_number, '福岡県うきは市吉井町清瀬');
ok($zip->set_number('8391321')->is_valid_number, '福岡県うきは市吉井町');
ok($zip->set_number('8391331')->is_valid_number, '福岡県うきは市吉井町屋部');
ok($zip->set_number('8391332')->is_valid_number, '福岡県うきは市吉井町福益');
ok($zip->set_number('8391333')->is_valid_number, '福岡県うきは市吉井町富永');
ok($zip->set_number('8391341')->is_valid_number, '福岡県うきは市吉井町江南');
ok($zip->set_number('8391342')->is_valid_number, '福岡県うきは市吉井町生葉');
ok($zip->set_number('8391343')->is_valid_number, '福岡県うきは市吉井町鷹取');
ok($zip->set_number('8391344')->is_valid_number, '福岡県うきは市吉井町長栖');
ok($zip->set_number('8391400')->is_valid_number, '福岡県うきは市以下に掲載がない場合');
ok($zip->set_number('8391401')->is_valid_number, '福岡県うきは市浮羽町朝田');
ok($zip->set_number('8391402')->is_valid_number, '福岡県うきは市浮羽町浮羽');
ok($zip->set_number('8391403')->is_valid_number, '福岡県うきは市浮羽町東隈上');
ok($zip->set_number('8391404')->is_valid_number, '福岡県うきは市浮羽町西隈上');
ok($zip->set_number('8391405')->is_valid_number, '福岡県うきは市浮羽町古川');
ok($zip->set_number('8391406')->is_valid_number, '福岡県うきは市浮羽町高見');
ok($zip->set_number('8391407')->is_valid_number, '福岡県うきは市浮羽町三春');
ok($zip->set_number('8391408')->is_valid_number, '福岡県うきは市浮羽町山北');
ok($zip->set_number('8391411')->is_valid_number, '福岡県うきは市浮羽町流川');
ok($zip->set_number('8391412')->is_valid_number, '福岡県うきは市浮羽町小塩');
ok($zip->set_number('8391413')->is_valid_number, '福岡県うきは市浮羽町新川');
ok($zip->set_number('8391414')->is_valid_number, '福岡県うきは市浮羽町田篭');
ok($zip->set_number('8391415')->is_valid_number, '福岡県うきは市浮羽町妹川');
ok($zip->set_number('8391421')->is_valid_number, '大分県日田市前津江町柚木(1~800番地、千蔵木、塔ノ本、仁田原、本村)');
ok($zip->set_number('8400001')->is_valid_number, '佐賀県佐賀市巨勢町修理田');
ok($zip->set_number('8400002')->is_valid_number, '佐賀県佐賀市蓮池町見島');
ok($zip->set_number('8400003')->is_valid_number, '佐賀県佐賀市蓮池町古賀');
ok($zip->set_number('8400004')->is_valid_number, '佐賀県佐賀市蓮池町小松');
ok($zip->set_number('8400005')->is_valid_number, '佐賀県佐賀市蓮池町蓮池');
ok($zip->set_number('8400006')->is_valid_number, '佐賀県佐賀市巨勢町東西');
ok($zip->set_number('8400007')->is_valid_number, '佐賀県佐賀市巨勢町高尾');
ok($zip->set_number('8400008')->is_valid_number, '佐賀県佐賀市巨勢町牛島');
ok($zip->set_number('8400011')->is_valid_number, '佐賀県佐賀市北川副町江上');
ok($zip->set_number('8400012')->is_valid_number, '佐賀県佐賀市北川副町光法');
ok($zip->set_number('8400013')->is_valid_number, '佐賀県佐賀市北川副町新郷');
ok($zip->set_number('8400015')->is_valid_number, '佐賀県佐賀市木原');
ok($zip->set_number('8400016')->is_valid_number, '佐賀県佐賀市南佐賀');
ok($zip->set_number('8400017')->is_valid_number, '佐賀県佐賀市新郷本町');
ok($zip->set_number('8400021')->is_valid_number, '佐賀県佐賀市鬼丸町');
ok($zip->set_number('8400022')->is_valid_number, '佐賀県佐賀市中の館町');
ok($zip->set_number('8400023')->is_valid_number, '佐賀県佐賀市本庄町袋');
ok($zip->set_number('8400024')->is_valid_number, '佐賀県佐賀市本庄町末次');
ok($zip->set_number('8400025')->is_valid_number, '佐賀県佐賀市本庄町鹿子');
ok($zip->set_number('8400026')->is_valid_number, '佐賀県佐賀市本庄町正里');
ok($zip->set_number('8400027')->is_valid_number, '佐賀県佐賀市本庄町本庄');
ok($zip->set_number('8400031')->is_valid_number, '佐賀県佐賀市下田町');
ok($zip->set_number('8400032')->is_valid_number, '佐賀県佐賀市末広');
ok($zip->set_number('8400033')->is_valid_number, '佐賀県佐賀市光');
ok($zip->set_number('8400034')->is_valid_number, '佐賀県佐賀市西与賀町厘外');
ok($zip->set_number('8400035')->is_valid_number, '佐賀県佐賀市西与賀町今津');
ok($zip->set_number('8400036')->is_valid_number, '佐賀県佐賀市西与賀町高太郎');
ok($zip->set_number('8400037')->is_valid_number, '佐賀県佐賀市西与賀町相応津');
ok($zip->set_number('8400041')->is_valid_number, '佐賀県佐賀市城内');
ok($zip->set_number('8400042')->is_valid_number, '佐賀県佐賀市赤松町');
ok($zip->set_number('8400043')->is_valid_number, '佐賀県佐賀市精町');
ok($zip->set_number('8400044')->is_valid_number, '佐賀県佐賀市道祖元町');
ok($zip->set_number('8400045')->is_valid_number, '佐賀県佐賀市西田代');
ok($zip->set_number('8400046')->is_valid_number, '佐賀県佐賀市西魚町');
ok($zip->set_number('8400047')->is_valid_number, '佐賀県佐賀市与賀町');
ok($zip->set_number('8400051')->is_valid_number, '佐賀県佐賀市田代');
ok($zip->set_number('8400052')->is_valid_number, '佐賀県佐賀市今宿町');
ok($zip->set_number('8400053')->is_valid_number, '佐賀県佐賀市朝日町');
ok($zip->set_number('8400054')->is_valid_number, '佐賀県佐賀市水ケ江');
ok($zip->set_number('8400055')->is_valid_number, '佐賀県佐賀市材木');
ok($zip->set_number('8400056')->is_valid_number, '佐賀県佐賀市紺屋町');
ok($zip->set_number('8400201')->is_valid_number, '佐賀県佐賀市大和町尼寺');
ok($zip->set_number('8400202')->is_valid_number, '佐賀県佐賀市大和町久池井');
ok($zip->set_number('8400203')->is_valid_number, '佐賀県佐賀市大和町梅野');
ok($zip->set_number('8400204')->is_valid_number, '佐賀県佐賀市大和町松瀬');
ok($zip->set_number('8400205')->is_valid_number, '佐賀県佐賀市大和町名尾');
ok($zip->set_number('8400211')->is_valid_number, '佐賀県佐賀市大和町東山田');
ok($zip->set_number('8400212')->is_valid_number, '佐賀県佐賀市大和町池上');
ok($zip->set_number('8400213')->is_valid_number, '佐賀県佐賀市大和町久留間');
ok($zip->set_number('8400214')->is_valid_number, '佐賀県佐賀市大和町川上');
ok($zip->set_number('8400215')->is_valid_number, '佐賀県佐賀市大和町八反原');
ok($zip->set_number('8400501')->is_valid_number, '佐賀県佐賀市富士町古湯');
ok($zip->set_number('8400502')->is_valid_number, '佐賀県佐賀市富士町杉山');
ok($zip->set_number('8400503')->is_valid_number, '佐賀県佐賀市富士町市川');
ok($zip->set_number('8400504')->is_valid_number, '佐賀県佐賀市富士町苣木');
ok($zip->set_number('8400511')->is_valid_number, '佐賀県佐賀市富士町鎌原');
ok($zip->set_number('8400512')->is_valid_number, '佐賀県佐賀市富士町上熊川');
ok($zip->set_number('8400513')->is_valid_number, '佐賀県佐賀市富士町下熊川');
ok($zip->set_number('8400514')->is_valid_number, '佐賀県佐賀市富士町内野');
ok($zip->set_number('8400515')->is_valid_number, '佐賀県佐賀市富士町松瀬');
ok($zip->set_number('8400516')->is_valid_number, '佐賀県佐賀市富士町梅野');
ok($zip->set_number('8400521')->is_valid_number, '佐賀県佐賀市富士町小副川');
ok($zip->set_number('8400522')->is_valid_number, '佐賀県佐賀市富士町畑瀬');
ok($zip->set_number('8400531')->is_valid_number, '佐賀県佐賀市富士町栗並');
ok($zip->set_number('8400532')->is_valid_number, '佐賀県佐賀市富士町大野');
ok($zip->set_number('8400533')->is_valid_number, '佐賀県佐賀市富士町大串');
ok($zip->set_number('8400534')->is_valid_number, '佐賀県佐賀市富士町中原');
ok($zip->set_number('8400535')->is_valid_number, '佐賀県佐賀市富士町下無津呂');
ok($zip->set_number('8400536')->is_valid_number, '佐賀県佐賀市富士町上無津呂');
ok($zip->set_number('8400537')->is_valid_number, '佐賀県佐賀市富士町麻那古');
ok($zip->set_number('8400541')->is_valid_number, '佐賀県佐賀市富士町関屋');
ok($zip->set_number('8400542')->is_valid_number, '佐賀県佐賀市富士町藤瀬');
ok($zip->set_number('8400543')->is_valid_number, '佐賀県佐賀市富士町古場');
ok($zip->set_number('8400544')->is_valid_number, '佐賀県佐賀市富士町下合瀬');
ok($zip->set_number('8400545')->is_valid_number, '佐賀県佐賀市富士町上合瀬');
ok($zip->set_number('8400801')->is_valid_number, '佐賀県佐賀市駅前中央');
ok($zip->set_number('8400802')->is_valid_number, '佐賀県佐賀市大財北町');
ok($zip->set_number('8400803')->is_valid_number, '佐賀県佐賀市栄町');
ok($zip->set_number('8400804')->is_valid_number, '佐賀県佐賀市神野東');
ok($zip->set_number('8400805')->is_valid_number, '佐賀県佐賀市神野西');
ok($zip->set_number('8400806')->is_valid_number, '佐賀県佐賀市神園');
ok($zip->set_number('8400811')->is_valid_number, '佐賀県佐賀市大財');
ok($zip->set_number('8400812')->is_valid_number, '佐賀県佐賀市愛敬町');
ok($zip->set_number('8400813')->is_valid_number, '佐賀県佐賀市唐人');
ok($zip->set_number('8400814')->is_valid_number, '佐賀県佐賀市成章町');
ok($zip->set_number('8400815')->is_valid_number, '佐賀県佐賀市天神');
ok($zip->set_number('8400816')->is_valid_number, '佐賀県佐賀市駅南本町');
ok($zip->set_number('8400821')->is_valid_number, '佐賀県佐賀市東佐賀町');
ok($zip->set_number('8400822')->is_valid_number, '佐賀県佐賀市高木町');
ok($zip->set_number('8400823')->is_valid_number, '佐賀県佐賀市柳町');
ok($zip->set_number('8400824')->is_valid_number, '佐賀県佐賀市呉服元町');
ok($zip->set_number('8400825')->is_valid_number, '佐賀県佐賀市中央本町');
ok($zip->set_number('8400826')->is_valid_number, '佐賀県佐賀市白山');
ok($zip->set_number('8400831')->is_valid_number, '佐賀県佐賀市松原');
ok($zip->set_number('8400832')->is_valid_number, '佐賀県佐賀市堀川町');
ok($zip->set_number('8400833')->is_valid_number, '佐賀県佐賀市中の小路');
ok($zip->set_number('8400834')->is_valid_number, '佐賀県佐賀市八幡小路');
ok($zip->set_number('8400841')->is_valid_number, '佐賀県佐賀市緑小路');
ok($zip->set_number('8400842')->is_valid_number, '佐賀県佐賀市多布施');
ok($zip->set_number('8400843')->is_valid_number, '佐賀県佐賀市川原町');
ok($zip->set_number('8400844')->is_valid_number, '佐賀県佐賀市伊勢町');
ok($zip->set_number('8400845')->is_valid_number, '佐賀県佐賀市六座町');
ok($zip->set_number('8400850')->is_valid_number, '佐賀県佐賀市新栄東');
ok($zip->set_number('8400851')->is_valid_number, '佐賀県佐賀市天祐');
ok($zip->set_number('8400852')->is_valid_number, '佐賀県佐賀市中折町');
ok($zip->set_number('8400853')->is_valid_number, '佐賀県佐賀市長瀬町');
ok($zip->set_number('8400854')->is_valid_number, '佐賀県佐賀市八戸');
ok($zip->set_number('8400855')->is_valid_number, '佐賀県佐賀市昭栄町');
ok($zip->set_number('8400856')->is_valid_number, '佐賀県佐賀市新生町');
ok($zip->set_number('8400857')->is_valid_number, '佐賀県佐賀市鍋島町八戸');
ok($zip->set_number('8400858')->is_valid_number, '佐賀県佐賀市天祐団地');
ok($zip->set_number('8400859')->is_valid_number, '佐賀県佐賀市新栄西');
ok($zip->set_number('8400861')->is_valid_number, '佐賀県佐賀市嘉瀬町中原');
ok($zip->set_number('8400862')->is_valid_number, '佐賀県佐賀市嘉瀬町扇町');
ok($zip->set_number('8400863')->is_valid_number, '佐賀県佐賀市嘉瀬町十五');
ok($zip->set_number('8400864')->is_valid_number, '佐賀県佐賀市嘉瀬町荻野');
ok($zip->set_number('8401101')->is_valid_number, '佐賀県三養基郡みやき町西島');
ok($zip->set_number('8401102')->is_valid_number, '佐賀県三養基郡みやき町天建寺');
ok($zip->set_number('8401103')->is_valid_number, '佐賀県三養基郡みやき町坂口');
ok($zip->set_number('8401104')->is_valid_number, '佐賀県三養基郡みやき町東津');
ok($zip->set_number('8401105')->is_valid_number, '佐賀県三養基郡みやき町寄人');
ok($zip->set_number('8401106')->is_valid_number, '佐賀県三養基郡みやき町市武');
ok($zip->set_number('8402101')->is_valid_number, '佐賀県佐賀市諸富町大堂');
ok($zip->set_number('8402102')->is_valid_number, '佐賀県佐賀市諸富町為重');
ok($zip->set_number('8402103')->is_valid_number, '佐賀県佐賀市諸富町寺井津');
ok($zip->set_number('8402104')->is_valid_number, '佐賀県佐賀市諸富町徳富');
ok($zip->set_number('8402105')->is_valid_number, '佐賀県佐賀市諸富町諸富津');
ok($zip->set_number('8402106')->is_valid_number, '佐賀県佐賀市諸富町山領');
ok($zip->set_number('8402201')->is_valid_number, '佐賀県佐賀市川副町福富');
ok($zip->set_number('8402202')->is_valid_number, '佐賀県佐賀市川副町早津江津');
ok($zip->set_number('8402203')->is_valid_number, '佐賀県佐賀市川副町早津江');
ok($zip->set_number('8402204')->is_valid_number, '佐賀県佐賀市川副町西古賀');
ok($zip->set_number('8402205')->is_valid_number, '佐賀県佐賀市川副町南里');
ok($zip->set_number('8402211')->is_valid_number, '佐賀県佐賀市川副町大詫間');
ok($zip->set_number('8402212')->is_valid_number, '佐賀県佐賀市川副町犬井道');
ok($zip->set_number('8402213')->is_valid_number, '佐賀県佐賀市川副町鹿江');
ok($zip->set_number('8402214')->is_valid_number, '佐賀県佐賀市川副町小々森');
ok($zip->set_number('8402221')->is_valid_number, '佐賀県佐賀市東与賀町下古賀');
ok($zip->set_number('8402222')->is_valid_number, '佐賀県佐賀市東与賀町田中');
ok($zip->set_number('8402223')->is_valid_number, '佐賀県佐賀市東与賀町飯盛');
ok($zip->set_number('8410000')->is_valid_number, '佐賀県鳥栖市以下に掲載がない場合');
ok($zip->set_number('8410001')->is_valid_number, '佐賀県鳥栖市今町');
ok($zip->set_number('8410002')->is_valid_number, '佐賀県鳥栖市柚比町');
ok($zip->set_number('8410003')->is_valid_number, '佐賀県鳥栖市加藤田町');
ok($zip->set_number('8410004')->is_valid_number, '佐賀県鳥栖市神辺町');
ok($zip->set_number('8410005')->is_valid_number, '佐賀県鳥栖市弥生が丘');
ok($zip->set_number('8410011')->is_valid_number, '佐賀県鳥栖市永吉町');
ok($zip->set_number('8410012')->is_valid_number, '佐賀県鳥栖市田代昌町');
ok($zip->set_number('8410013')->is_valid_number, '佐賀県鳥栖市田代新町');
ok($zip->set_number('8410014')->is_valid_number, '佐賀県鳥栖市桜町');
ok($zip->set_number('8410015')->is_valid_number, '佐賀県鳥栖市田代上町');
ok($zip->set_number('8410016')->is_valid_number, '佐賀県鳥栖市田代外町');
ok($zip->set_number('8410017')->is_valid_number, '佐賀県鳥栖市田代大官町');
ok($zip->set_number('8410018')->is_valid_number, '佐賀県鳥栖市田代本町');
ok($zip->set_number('8410021')->is_valid_number, '佐賀県鳥栖市幡崎町');
ok($zip->set_number('8410022')->is_valid_number, '佐賀県鳥栖市飯田町');
ok($zip->set_number('8410023')->is_valid_number, '佐賀県鳥栖市姫方町');
ok($zip->set_number('8410024')->is_valid_number, '佐賀県鳥栖市原町');
ok($zip->set_number('8410025')->is_valid_number, '佐賀県鳥栖市曽根崎町');
ok($zip->set_number('8410026')->is_valid_number, '佐賀県鳥栖市本鳥栖町');
ok($zip->set_number('8410027')->is_valid_number, '佐賀県鳥栖市松原町');
ok($zip->set_number('8410031')->is_valid_number, '佐賀県鳥栖市鎗田町');
ok($zip->set_number('8410032')->is_valid_number, '佐賀県鳥栖市大正町');
ok($zip->set_number('8410033')->is_valid_number, '佐賀県鳥栖市本通町');
ok($zip->set_number('8410034')->is_valid_number, '佐賀県鳥栖市京町');
ok($zip->set_number('8410035')->is_valid_number, '佐賀県鳥栖市東町');
ok($zip->set_number('8410036')->is_valid_number, '佐賀県鳥栖市秋葉町');
ok($zip->set_number('8410037')->is_valid_number, '佐賀県鳥栖市本町');
ok($zip->set_number('8410038')->is_valid_number, '佐賀県鳥栖市古野町');
ok($zip->set_number('8410039')->is_valid_number, '佐賀県鳥栖市土井町');
ok($zip->set_number('8410041')->is_valid_number, '佐賀県鳥栖市酒井東町');
ok($zip->set_number('8410042')->is_valid_number, '佐賀県鳥栖市酒井西町');
ok($zip->set_number('8410043')->is_valid_number, '佐賀県鳥栖市水屋町');
ok($zip->set_number('8410044')->is_valid_number, '佐賀県鳥栖市高田町');
ok($zip->set_number('8410045')->is_valid_number, '佐賀県鳥栖市安楽寺町');
ok($zip->set_number('8410046')->is_valid_number, '佐賀県鳥栖市真木町');
ok($zip->set_number('8410047')->is_valid_number, '佐賀県鳥栖市今泉町');
ok($zip->set_number('8410048')->is_valid_number, '佐賀県鳥栖市藤木町');
ok($zip->set_number('8410051')->is_valid_number, '佐賀県鳥栖市元町');
ok($zip->set_number('8410052')->is_valid_number, '佐賀県鳥栖市宿町');
ok($zip->set_number('8410053')->is_valid_number, '佐賀県鳥栖市布津原町');
ok($zip->set_number('8410054')->is_valid_number, '佐賀県鳥栖市蔵上町');
ok($zip->set_number('8410055')->is_valid_number, '佐賀県鳥栖市養父町');
ok($zip->set_number('8410056')->is_valid_number, '佐賀県鳥栖市蔵上');
ok($zip->set_number('8410061')->is_valid_number, '佐賀県鳥栖市轟木町');
ok($zip->set_number('8410062')->is_valid_number, '佐賀県鳥栖市幸津町');
ok($zip->set_number('8410063')->is_valid_number, '佐賀県鳥栖市下野町');
ok($zip->set_number('8410064')->is_valid_number, '佐賀県鳥栖市三島町');
ok($zip->set_number('8410065')->is_valid_number, '佐賀県鳥栖市前田町');
ok($zip->set_number('8410066')->is_valid_number, '佐賀県鳥栖市儀徳町');
ok($zip->set_number('8410067')->is_valid_number, '佐賀県鳥栖市西田町');
ok($zip->set_number('8410068')->is_valid_number, '佐賀県鳥栖市あさひ新町');
ok($zip->set_number('8410071')->is_valid_number, '佐賀県鳥栖市原古賀町');
ok($zip->set_number('8410072')->is_valid_number, '佐賀県鳥栖市村田町');
ok($zip->set_number('8410073')->is_valid_number, '佐賀県鳥栖市江島町');
ok($zip->set_number('8410074')->is_valid_number, '佐賀県鳥栖市西新町');
ok($zip->set_number('8410075')->is_valid_number, '佐賀県鳥栖市立石町');
ok($zip->set_number('8410076')->is_valid_number, '佐賀県鳥栖市平田町');
ok($zip->set_number('8410081')->is_valid_number, '佐賀県鳥栖市萱方町');
ok($zip->set_number('8410082')->is_valid_number, '佐賀県鳥栖市浅井町');
ok($zip->set_number('8410083')->is_valid_number, '佐賀県鳥栖市古賀町');
ok($zip->set_number('8410084')->is_valid_number, '佐賀県鳥栖市山浦町');
ok($zip->set_number('8410085')->is_valid_number, '佐賀県鳥栖市山都町');
ok($zip->set_number('8410086')->is_valid_number, '佐賀県鳥栖市牛原町');
ok($zip->set_number('8410087')->is_valid_number, '佐賀県鳥栖市河内町');
ok($zip->set_number('8410088')->is_valid_number, '佐賀県鳥栖市桜ケ丘町');
ok($zip->set_number('8410089')->is_valid_number, '佐賀県鳥栖市虹ケ丘町');
ok($zip->set_number('8410200')->is_valid_number, '佐賀県三養基郡基山町以下に掲載がない場合');
ok($zip->set_number('8410201')->is_valid_number, '佐賀県三養基郡基山町小倉');
ok($zip->set_number('8410202')->is_valid_number, '佐賀県三養基郡基山町長野');
ok($zip->set_number('8410203')->is_valid_number, '佐賀県三養基郡基山町園部');
ok($zip->set_number('8410204')->is_valid_number, '佐賀県三養基郡基山町宮浦');
ok($zip->set_number('8410205')->is_valid_number, '佐賀県三養基郡基山町けやき台');
ok($zip->set_number('8420000')->is_valid_number, '佐賀県神埼市以下に掲載がない場合');
ok($zip->set_number('8420000')->is_valid_number, '佐賀県神埼郡吉野ヶ里町以下に掲載がない場合');
ok($zip->set_number('8420001')->is_valid_number, '佐賀県神埼市神埼町神埼');
ok($zip->set_number('8420002')->is_valid_number, '佐賀県神埼市神埼町田道ケ里');
ok($zip->set_number('8420003')->is_valid_number, '佐賀県神埼市神埼町本堀');
ok($zip->set_number('8420004')->is_valid_number, '佐賀県神埼市神埼町永歌');
ok($zip->set_number('8420005')->is_valid_number, '佐賀県神埼市神埼町西小津ケ里');
ok($zip->set_number('8420006')->is_valid_number, '佐賀県神埼市神埼町枝ケ里');
ok($zip->set_number('8420007')->is_valid_number, '佐賀県神埼市神埼町鶴(3000番地以降)');
ok($zip->set_number('8420011')->is_valid_number, '佐賀県神埼市神埼町竹');
ok($zip->set_number('8420012')->is_valid_number, '佐賀県神埼市神埼町横武');
ok($zip->set_number('8420013')->is_valid_number, '佐賀県神埼市神埼町本告牟田');
ok($zip->set_number('8420014')->is_valid_number, '佐賀県神埼市神埼町姉川');
ok($zip->set_number('8420015')->is_valid_number, '佐賀県神埼市神埼町尾崎');
ok($zip->set_number('8420031')->is_valid_number, '佐賀県神埼郡吉野ヶ里町吉田');
ok($zip->set_number('8420032')->is_valid_number, '佐賀県神埼郡吉野ヶ里町立野');
ok($zip->set_number('8420033')->is_valid_number, '佐賀県神埼郡吉野ヶ里町豆田');
ok($zip->set_number('8420034')->is_valid_number, '佐賀県神埼郡吉野ヶ里町箱川');
ok($zip->set_number('8420035')->is_valid_number, '佐賀県神埼郡吉野ヶ里町田手');
ok($zip->set_number('8420051')->is_valid_number, '佐賀県神埼市千代田町黒井');
ok($zip->set_number('8420052')->is_valid_number, '佐賀県神埼市千代田町姉');
ok($zip->set_number('8420053')->is_valid_number, '佐賀県神埼市千代田町直鳥');
ok($zip->set_number('8420054')->is_valid_number, '佐賀県神埼市千代田町餘江');
ok($zip->set_number('8420055')->is_valid_number, '佐賀県神埼市千代田町下西');
ok($zip->set_number('8420056')->is_valid_number, '佐賀県神埼市千代田町境原');
ok($zip->set_number('8420061')->is_valid_number, '佐賀県神埼市千代田町詫田');
ok($zip->set_number('8420062')->is_valid_number, '佐賀県神埼市千代田町柳島');
ok($zip->set_number('8420063')->is_valid_number, '佐賀県神埼市千代田町迎島');
ok($zip->set_number('8420064')->is_valid_number, '佐賀県神埼市千代田町渡瀬');
ok($zip->set_number('8420065')->is_valid_number, '佐賀県神埼市千代田町崎村');
ok($zip->set_number('8420066')->is_valid_number, '佐賀県神埼市千代田町用作');
ok($zip->set_number('8420067')->is_valid_number, '佐賀県神埼市千代田町嘉納');
ok($zip->set_number('8420068')->is_valid_number, '佐賀県神埼市千代田町下板');
ok($zip->set_number('8420101')->is_valid_number, '佐賀県神埼郡吉野ヶ里町松隈');
ok($zip->set_number('8420102')->is_valid_number, '佐賀県神埼郡吉野ヶ里町石動');
ok($zip->set_number('8420103')->is_valid_number, '佐賀県神埼郡吉野ヶ里町大曲');
ok($zip->set_number('8420104')->is_valid_number, '佐賀県神埼郡吉野ヶ里町三津');
ok($zip->set_number('8420107')->is_valid_number, '佐賀県神埼市神埼町鶴(1~2999番地)');
ok($zip->set_number('8420121')->is_valid_number, '佐賀県神埼市神埼町志波屋');
ok($zip->set_number('8420122')->is_valid_number, '佐賀県神埼市神埼町城原');
ok($zip->set_number('8420123')->is_valid_number, '佐賀県神埼市神埼町的');
ok($zip->set_number('8420201')->is_valid_number, '佐賀県神埼市脊振町広滝');
ok($zip->set_number('8420202')->is_valid_number, '佐賀県神埼市脊振町鹿路');
ok($zip->set_number('8420203')->is_valid_number, '佐賀県神埼市脊振町服巻');
ok($zip->set_number('8420301')->is_valid_number, '佐賀県佐賀市三瀬村三瀬');
ok($zip->set_number('8420302')->is_valid_number, '佐賀県佐賀市三瀬村藤原');
ok($zip->set_number('8420303')->is_valid_number, '佐賀県佐賀市三瀬村杠');
ok($zip->set_number('8430000')->is_valid_number, '佐賀県武雄市以下に掲載がない場合');
ok($zip->set_number('8430001')->is_valid_number, '佐賀県武雄市朝日町甘久');
ok($zip->set_number('8430002')->is_valid_number, '佐賀県武雄市朝日町中野');
ok($zip->set_number('8430003')->is_valid_number, '佐賀県武雄市朝日町芦原');
ok($zip->set_number('8430011')->is_valid_number, '佐賀県武雄市橘町芦原');
ok($zip->set_number('8430012')->is_valid_number, '佐賀県武雄市橘町片白');
ok($zip->set_number('8430013')->is_valid_number, '佐賀県武雄市橘町大日');
ok($zip->set_number('8430014')->is_valid_number, '佐賀県武雄市橘町永島');
ok($zip->set_number('8430021')->is_valid_number, '佐賀県武雄市武雄町永島');
ok($zip->set_number('8430022')->is_valid_number, '佐賀県武雄市武雄町武雄');
ok($zip->set_number('8430023')->is_valid_number, '佐賀県武雄市武雄町昭和');
ok($zip->set_number('8430024')->is_valid_number, '佐賀県武雄市武雄町富岡');
ok($zip->set_number('8430151')->is_valid_number, '佐賀県武雄市若木町川古');
ok($zip->set_number('8430152')->is_valid_number, '佐賀県武雄市若木町本部');
ok($zip->set_number('8430153')->is_valid_number, '佐賀県武雄市若木町桃川');
ok($zip->set_number('8430231')->is_valid_number, '佐賀県武雄市西川登町小田志');
ok($zip->set_number('8430232')->is_valid_number, '佐賀県武雄市西川登町神六');
ok($zip->set_number('8430233')->is_valid_number, '佐賀県武雄市東川登町永野');
ok($zip->set_number('8430234')->is_valid_number, '佐賀県武雄市東川登町袴野');
ok($zip->set_number('8430300')->is_valid_number, '佐賀県嬉野市以下に掲載がない場合');
ok($zip->set_number('8430301')->is_valid_number, '佐賀県嬉野市嬉野町下宿');
ok($zip->set_number('8430302')->is_valid_number, '佐賀県嬉野市嬉野町下野');
ok($zip->set_number('8430303')->is_valid_number, '佐賀県嬉野市嬉野町吉田');
ok($zip->set_number('8430304')->is_valid_number, '佐賀県嬉野市嬉野町岩屋川内');
ok($zip->set_number('8430305')->is_valid_number, '佐賀県嬉野市嬉野町不動山');
ok($zip->set_number('8440000')->is_valid_number, '佐賀県西松浦郡有田町以下に掲載がない場合');
ok($zip->set_number('8440001')->is_valid_number, '佐賀県西松浦郡有田町泉山');
ok($zip->set_number('8440002')->is_valid_number, '佐賀県西松浦郡有田町中樽');
ok($zip->set_number('8440003')->is_valid_number, '佐賀県西松浦郡有田町上幸平');
ok($zip->set_number('8440004')->is_valid_number, '佐賀県西松浦郡有田町大樽');
ok($zip->set_number('8440005')->is_valid_number, '佐賀県西松浦郡有田町幸平');
ok($zip->set_number('8440006')->is_valid_number, '佐賀県西松浦郡有田町赤絵町');
ok($zip->set_number('8440007')->is_valid_number, '佐賀県西松浦郡有田町白川');
ok($zip->set_number('8440008')->is_valid_number, '佐賀県西松浦郡有田町稗古場');
ok($zip->set_number('8440009')->is_valid_number, '佐賀県西松浦郡有田町中の原');
ok($zip->set_number('8440011')->is_valid_number, '佐賀県西松浦郡有田町岩谷川内');
ok($zip->set_number('8440012')->is_valid_number, '佐賀県西松浦郡有田町桑古場');
ok($zip->set_number('8440013')->is_valid_number, '佐賀県西松浦郡有田町大野');
ok($zip->set_number('8440014')->is_valid_number, '佐賀県西松浦郡有田町戸矢');
ok($zip->set_number('8440015')->is_valid_number, '佐賀県西松浦郡有田町古木場');
ok($zip->set_number('8440016')->is_valid_number, '佐賀県西松浦郡有田町境野');
ok($zip->set_number('8440017')->is_valid_number, '佐賀県西松浦郡有田町戸杓');
ok($zip->set_number('8440018')->is_valid_number, '佐賀県西松浦郡有田町本町');
ok($zip->set_number('8440021')->is_valid_number, '佐賀県西松浦郡有田町応法');
ok($zip->set_number('8440022')->is_valid_number, '佐賀県西松浦郡有田町黒牟田');
ok($zip->set_number('8440023')->is_valid_number, '佐賀県西松浦郡有田町丸尾');
ok($zip->set_number('8440024')->is_valid_number, '佐賀県西松浦郡有田町赤坂');
ok($zip->set_number('8440025')->is_valid_number, '佐賀県西松浦郡有田町外尾山');
ok($zip->set_number('8440026')->is_valid_number, '佐賀県西松浦郡有田町外尾町');
ok($zip->set_number('8440027')->is_valid_number, '佐賀県西松浦郡有田町南原');
ok($zip->set_number('8440028')->is_valid_number, '佐賀県西松浦郡有田町南山');
ok($zip->set_number('8450000')->is_valid_number, '佐賀県小城市以下に掲載がない場合');
ok($zip->set_number('8450001')->is_valid_number, '佐賀県小城市小城町');
ok($zip->set_number('8450002')->is_valid_number, '佐賀県小城市小城町畑田');
ok($zip->set_number('8450003')->is_valid_number, '佐賀県小城市小城町岩蔵');
ok($zip->set_number('8450004')->is_valid_number, '佐賀県小城市小城町松尾');
ok($zip->set_number('8450005')->is_valid_number, '佐賀県小城市小城町東新町');
ok($zip->set_number('8450011')->is_valid_number, '佐賀県小城市小城町船田');
ok($zip->set_number('8450012')->is_valid_number, '佐賀県小城市小城町池上');
ok($zip->set_number('8450013')->is_valid_number, '佐賀県小城市小城町栗原');
ok($zip->set_number('8450014')->is_valid_number, '佐賀県小城市小城町晴気');
ok($zip->set_number('8450021')->is_valid_number, '佐賀県小城市三日月町長神田');
ok($zip->set_number('8450022')->is_valid_number, '佐賀県小城市三日月町久米');
ok($zip->set_number('8450023')->is_valid_number, '佐賀県小城市三日月町織島');
ok($zip->set_number('8450024')->is_valid_number, '佐賀県小城市三日月町道辺');
ok($zip->set_number('8450025')->is_valid_number, '佐賀県小城市三日月町三ケ島');
ok($zip->set_number('8450031')->is_valid_number, '佐賀県小城市三日月町堀江');
ok($zip->set_number('8450032')->is_valid_number, '佐賀県小城市三日月町金田');
ok($zip->set_number('8450033')->is_valid_number, '佐賀県小城市三日月町樋口');
ok($zip->set_number('8450034')->is_valid_number, '佐賀県小城市三日月町甲柳原');
ok($zip->set_number('8450035')->is_valid_number, '佐賀県小城市三日月町石木');
ok($zip->set_number('8460000')->is_valid_number, '佐賀県多久市以下に掲載がない場合');
ok($zip->set_number('8460001')->is_valid_number, '佐賀県多久市北多久町');
ok($zip->set_number('8460002')->is_valid_number, '佐賀県多久市北多久町小侍');
ok($zip->set_number('8460003')->is_valid_number, '佐賀県多久市北多久町多久原');
ok($zip->set_number('8460004')->is_valid_number, '佐賀県多久市北多久町中多久');
ok($zip->set_number('8460005')->is_valid_number, '佐賀県多久市北多久町砂原');
ok($zip->set_number('8460006')->is_valid_number, '佐賀県多久市北多久町莇原');
ok($zip->set_number('8460007')->is_valid_number, '佐賀県多久市北多久町メイプルタウン');
ok($zip->set_number('8460011')->is_valid_number, '佐賀県多久市東多久町');
ok($zip->set_number('8460012')->is_valid_number, '佐賀県多久市東多久町別府');
ok($zip->set_number('8460013')->is_valid_number, '佐賀県多久市東多久町古賀');
ok($zip->set_number('8460014')->is_valid_number, '佐賀県多久市東多久町納所');
ok($zip->set_number('8460021')->is_valid_number, '佐賀県多久市南多久町');
ok($zip->set_number('8460022')->is_valid_number, '佐賀県多久市南多久町泉町');
ok($zip->set_number('8460023')->is_valid_number, '佐賀県多久市南多久町長尾');
ok($zip->set_number('8460024')->is_valid_number, '佐賀県多久市南多久町下多久');
ok($zip->set_number('8460025')->is_valid_number, '佐賀県多久市南多久町花祭');
ok($zip->set_number('8460031')->is_valid_number, '佐賀県多久市多久町');
ok($zip->set_number('8460041')->is_valid_number, '佐賀県多久市西多久町');
ok($zip->set_number('8470000')->is_valid_number, '佐賀県唐津市以下に掲載がない場合');
ok($zip->set_number('8470001')->is_valid_number, '佐賀県唐津市双水');
ok($zip->set_number('8470002')->is_valid_number, '佐賀県唐津市山本');
ok($zip->set_number('8470003')->is_valid_number, '佐賀県唐津市橋本');
ok($zip->set_number('8470004')->is_valid_number, '佐賀県唐津市養母田');
ok($zip->set_number('8470005')->is_valid_number, '佐賀県唐津市養母田鬼塚');
ok($zip->set_number('8470011')->is_valid_number, '佐賀県唐津市栄町');
ok($zip->set_number('8470012')->is_valid_number, '佐賀県唐津市大名小路');
ok($zip->set_number('8470013')->is_valid_number, '佐賀県唐津市南城内');
ok($zip->set_number('8470014')->is_valid_number, '佐賀県唐津市西城内');
ok($zip->set_number('8470015')->is_valid_number, '佐賀県唐津市北城内');
ok($zip->set_number('8470016')->is_valid_number, '佐賀県唐津市東城内');
ok($zip->set_number('8470017')->is_valid_number, '佐賀県唐津市東唐津');
ok($zip->set_number('8470021')->is_valid_number, '佐賀県唐津市松南町');
ok($zip->set_number('8470022')->is_valid_number, '佐賀県唐津市鏡');
ok($zip->set_number('8470023')->is_valid_number, '佐賀県唐津市半田');
ok($zip->set_number('8470024')->is_valid_number, '佐賀県唐津市東宇木');
ok($zip->set_number('8470025')->is_valid_number, '佐賀県唐津市宇木');
ok($zip->set_number('8470026')->is_valid_number, '佐賀県唐津市柏崎');
ok($zip->set_number('8470027')->is_valid_number, '佐賀県唐津市高島');
ok($zip->set_number('8470028')->is_valid_number, '佐賀県唐津市鏡新開');
ok($zip->set_number('8470031')->is_valid_number, '佐賀県唐津市原');
ok($zip->set_number('8470032')->is_valid_number, '佐賀県唐津市夕日');
ok($zip->set_number('8470033')->is_valid_number, '佐賀県唐津市久里');
ok($zip->set_number('8470034')->is_valid_number, '佐賀県唐津市中原');
ok($zip->set_number('8470041')->is_valid_number, '佐賀県唐津市千代田町');
ok($zip->set_number('8470042')->is_valid_number, '佐賀県唐津市魚屋町');
ok($zip->set_number('8470043')->is_valid_number, '佐賀県唐津市新興町(東新興町)');
ok($zip->set_number('8470044')->is_valid_number, '佐賀県唐津市木綿町');
ok($zip->set_number('8470045')->is_valid_number, '佐賀県唐津市京町');
ok($zip->set_number('8470046')->is_valid_number, '佐賀県唐津市高砂町');
ok($zip->set_number('8470047')->is_valid_number, '佐賀県唐津市本町');
ok($zip->set_number('8470051')->is_valid_number, '佐賀県唐津市中町');
ok($zip->set_number('8470052')->is_valid_number, '佐賀県唐津市呉服町');
ok($zip->set_number('8470053')->is_valid_number, '佐賀県唐津市紺屋町');
ok($zip->set_number('8470054')->is_valid_number, '佐賀県唐津市米屋町');
ok($zip->set_number('8470055')->is_valid_number, '佐賀県唐津市刀町');
ok($zip->set_number('8470056')->is_valid_number, '佐賀県唐津市坊主町');
ok($zip->set_number('8470061')->is_valid_number, '佐賀県唐津市材木町');
ok($zip->set_number('8470062')->is_valid_number, '佐賀県唐津市船宮町');
ok($zip->set_number('8470063')->is_valid_number, '佐賀県唐津市東町');
ok($zip->set_number('8470064')->is_valid_number, '佐賀県唐津市元石町');
ok($zip->set_number('8470065')->is_valid_number, '佐賀県唐津市水主町');
ok($zip->set_number('8470066')->is_valid_number, '佐賀県唐津市大石町');
ok($zip->set_number('8470067')->is_valid_number, '佐賀県唐津市十人町');
ok($zip->set_number('8470071')->is_valid_number, '佐賀県唐津市和多田海士町');
ok($zip->set_number('8470072')->is_valid_number, '佐賀県唐津市和多田百人町');
ok($zip->set_number('8470073')->is_valid_number, '佐賀県唐津市和多田東百人町');
ok($zip->set_number('8470074')->is_valid_number, '佐賀県唐津市和多田先石');
ok($zip->set_number('8470075')->is_valid_number, '佐賀県唐津市和多田用尺');
ok($zip->set_number('8470081')->is_valid_number, '佐賀県唐津市和多田南先石');
ok($zip->set_number('8470082')->is_valid_number, '佐賀県唐津市和多田天満町');
ok($zip->set_number('8470083')->is_valid_number, '佐賀県唐津市和多田大土井');
ok($zip->set_number('8470084')->is_valid_number, '佐賀県唐津市和多田西山');
ok($zip->set_number('8470085')->is_valid_number, '佐賀県唐津市和多田本村');
ok($zip->set_number('8470101')->is_valid_number, '佐賀県唐津市中瀬通');
ok($zip->set_number('8470102')->is_valid_number, '佐賀県唐津市八幡町');
ok($zip->set_number('8470103')->is_valid_number, '佐賀県唐津市橋本町');
ok($zip->set_number('8470104')->is_valid_number, '佐賀県唐津市桜町');
ok($zip->set_number('8470111')->is_valid_number, '佐賀県唐津市佐志');
ok($zip->set_number('8470112')->is_valid_number, '佐賀県唐津市佐志南');
ok($zip->set_number('8470113')->is_valid_number, '佐賀県唐津市佐志中里');
ok($zip->set_number('8470114')->is_valid_number, '佐賀県唐津市佐志中通');
ok($zip->set_number('8470115')->is_valid_number, '佐賀県唐津市佐志浜町');
ok($zip->set_number('8470121')->is_valid_number, '佐賀県唐津市鳩川');
ok($zip->set_number('8470122')->is_valid_number, '佐賀県唐津市唐房');
ok($zip->set_number('8470123')->is_valid_number, '佐賀県唐津市枝去木');
ok($zip->set_number('8470124')->is_valid_number, '佐賀県唐津市浦');
ok($zip->set_number('8470131')->is_valid_number, '佐賀県唐津市神集島');
ok($zip->set_number('8470132')->is_valid_number, '佐賀県唐津市相賀');
ok($zip->set_number('8470133')->is_valid_number, '佐賀県唐津市湊町');
ok($zip->set_number('8470134')->is_valid_number, '佐賀県唐津市中里');
ok($zip->set_number('8470135')->is_valid_number, '佐賀県唐津市屋形石');
ok($zip->set_number('8470136')->is_valid_number, '佐賀県唐津市横野');
ok($zip->set_number('8470301')->is_valid_number, '佐賀県唐津市呼子町大友');
ok($zip->set_number('8470302')->is_valid_number, '佐賀県唐津市呼子町小友');
ok($zip->set_number('8470303')->is_valid_number, '佐賀県唐津市呼子町呼子');
ok($zip->set_number('8470304')->is_valid_number, '佐賀県唐津市呼子町殿ノ浦');
ok($zip->set_number('8470305')->is_valid_number, '佐賀県唐津市呼子町加部島');
ok($zip->set_number('8470306')->is_valid_number, '佐賀県唐津市呼子町小川島');
ok($zip->set_number('8470311')->is_valid_number, '佐賀県唐津市鎮西町丸田');
ok($zip->set_number('8470312')->is_valid_number, '佐賀県唐津市鎮西町赤木');
ok($zip->set_number('8470313')->is_valid_number, '佐賀県唐津市鎮西町塩鶴');
ok($zip->set_number('8470314')->is_valid_number, '佐賀県唐津市鎮西町菖蒲');
ok($zip->set_number('8470315')->is_valid_number, '佐賀県唐津市鎮西町八床');
ok($zip->set_number('8470316')->is_valid_number, '佐賀県唐津市鎮西町中野');
ok($zip->set_number('8470317')->is_valid_number, '佐賀県唐津市鎮西町加唐島');
ok($zip->set_number('8470321')->is_valid_number, '佐賀県唐津市鎮西町横竹');
ok($zip->set_number('8470322')->is_valid_number, '佐賀県唐津市鎮西町打上');
ok($zip->set_number('8470323')->is_valid_number, '佐賀県唐津市鎮西町岩野');
ok($zip->set_number('8470324')->is_valid_number, '佐賀県唐津市鎮西町高野');
ok($zip->set_number('8470325')->is_valid_number, '佐賀県唐津市鎮西町加倉');
ok($zip->set_number('8470326')->is_valid_number, '佐賀県唐津市鎮西町早田');
ok($zip->set_number('8470327')->is_valid_number, '佐賀県唐津市鎮西町石室');
ok($zip->set_number('8470401')->is_valid_number, '佐賀県唐津市鎮西町名護屋');
ok($zip->set_number('8470402')->is_valid_number, '佐賀県唐津市鎮西町野元');
ok($zip->set_number('8470403')->is_valid_number, '佐賀県唐津市鎮西町串');
ok($zip->set_number('8470404')->is_valid_number, '佐賀県唐津市鎮西町波戸');
ok($zip->set_number('8470405')->is_valid_number, '佐賀県唐津市鎮西町馬渡島');
ok($zip->set_number('8470406')->is_valid_number, '佐賀県唐津市鎮西町松島');
ok($zip->set_number('8470801')->is_valid_number, '佐賀県唐津市東山');
ok($zip->set_number('8470802')->is_valid_number, '佐賀県唐津市梨川内');
ok($zip->set_number('8470803')->is_valid_number, '佐賀県唐津市大良');
ok($zip->set_number('8470804')->is_valid_number, '佐賀県唐津市後川内');
ok($zip->set_number('8470811')->is_valid_number, '佐賀県唐津市八百屋町');
ok($zip->set_number('8470812')->is_valid_number, '佐賀県唐津市平野町');
ok($zip->set_number('8470813')->is_valid_number, '佐賀県唐津市新町');
ok($zip->set_number('8470814')->is_valid_number, '佐賀県唐津市弓鷹町');
ok($zip->set_number('8470815')->is_valid_number, '佐賀県唐津市西寺町');
ok($zip->set_number('8470816')->is_valid_number, '佐賀県唐津市新興町(西新興町)');
ok($zip->set_number('8470817')->is_valid_number, '佐賀県唐津市熊原町');
ok($zip->set_number('8470821')->is_valid_number, '佐賀県唐津市町田');
ok($zip->set_number('8470822')->is_valid_number, '佐賀県唐津市長谷');
ok($zip->set_number('8470823')->is_valid_number, '佐賀県唐津市旭が丘');
ok($zip->set_number('8470824')->is_valid_number, '佐賀県唐津市神田');
ok($zip->set_number('8470825')->is_valid_number, '佐賀県唐津市見借');
ok($zip->set_number('8470831')->is_valid_number, '佐賀県唐津市千々賀');
ok($zip->set_number('8470832')->is_valid_number, '佐賀県唐津市石志');
ok($zip->set_number('8470833')->is_valid_number, '佐賀県唐津市畑島');
ok($zip->set_number('8470834')->is_valid_number, '佐賀県唐津市山田');
ok($zip->set_number('8470841')->is_valid_number, '佐賀県唐津市朝日町');
ok($zip->set_number('8470842')->is_valid_number, '佐賀県唐津市山下町');
ok($zip->set_number('8470843')->is_valid_number, '佐賀県唐津市桜馬場');
ok($zip->set_number('8470844')->is_valid_number, '佐賀県唐津市菜畑');
ok($zip->set_number('8470851')->is_valid_number, '佐賀県唐津市富士見町');
ok($zip->set_number('8470852')->is_valid_number, '佐賀県唐津市元旗町');
ok($zip->set_number('8470853')->is_valid_number, '佐賀県唐津市江川町');
ok($zip->set_number('8470854')->is_valid_number, '佐賀県唐津市西旗町');
ok($zip->set_number('8470855')->is_valid_number, '佐賀県唐津市西浜町');
ok($zip->set_number('8470861')->is_valid_number, '佐賀県唐津市二タ子');
ok($zip->set_number('8470862')->is_valid_number, '佐賀県唐津市中山町');
ok($zip->set_number('8470863')->is_valid_number, '佐賀県唐津市妙見町');
ok($zip->set_number('8470871')->is_valid_number, '佐賀県唐津市東大島町');
ok($zip->set_number('8470872')->is_valid_number, '佐賀県唐津市西大島町');
ok($zip->set_number('8470873')->is_valid_number, '佐賀県唐津市海岸通');
ok($zip->set_number('8470874')->is_valid_number, '佐賀県唐津市藤崎通');
ok($zip->set_number('8470875')->is_valid_number, '佐賀県唐津市西唐津');
ok($zip->set_number('8470876')->is_valid_number, '佐賀県唐津市南富士見町');
ok($zip->set_number('8470881')->is_valid_number, '佐賀県唐津市竹木場');
ok($zip->set_number('8470882')->is_valid_number, '佐賀県唐津市菅牟田');
ok($zip->set_number('8470883')->is_valid_number, '佐賀県唐津市重河内');
ok($zip->set_number('8470884')->is_valid_number, '佐賀県唐津市熊ノ峰');
ok($zip->set_number('8470885')->is_valid_number, '佐賀県唐津市唐川');
ok($zip->set_number('8471101')->is_valid_number, '佐賀県唐津市七山荒川');
ok($zip->set_number('8471102')->is_valid_number, '佐賀県唐津市七山馬川');
ok($zip->set_number('8471103')->is_valid_number, '佐賀県唐津市七山池原');
ok($zip->set_number('8471104')->is_valid_number, '佐賀県唐津市七山木浦');
ok($zip->set_number('8471105')->is_valid_number, '佐賀県唐津市七山仁部');
ok($zip->set_number('8471106')->is_valid_number, '佐賀県唐津市七山滝川');
ok($zip->set_number('8471107')->is_valid_number, '佐賀県唐津市七山藤川');
ok($zip->set_number('8471108')->is_valid_number, '佐賀県唐津市七山白木');
ok($zip->set_number('8471201')->is_valid_number, '佐賀県唐津市北波多徳須恵');
ok($zip->set_number('8471202')->is_valid_number, '佐賀県唐津市北波多田中');
ok($zip->set_number('8471203')->is_valid_number, '佐賀県唐津市北波多山彦');
ok($zip->set_number('8471211')->is_valid_number, '佐賀県唐津市北波多岸山');
ok($zip->set_number('8471212')->is_valid_number, '佐賀県唐津市北波多大杉');
ok($zip->set_number('8471213')->is_valid_number, '佐賀県唐津市北波多竹有');
ok($zip->set_number('8471214')->is_valid_number, '佐賀県唐津市北波多稗田');
ok($zip->set_number('8471221')->is_valid_number, '佐賀県唐津市北波多上平野');
ok($zip->set_number('8471222')->is_valid_number, '佐賀県唐津市北波多成渕');
ok($zip->set_number('8471223')->is_valid_number, '佐賀県唐津市北波多下平野');
ok($zip->set_number('8471224')->is_valid_number, '佐賀県唐津市北波多行合野');
ok($zip->set_number('8471225')->is_valid_number, '佐賀県唐津市北波多志気');
ok($zip->set_number('8471400')->is_valid_number, '佐賀県東松浦郡玄海町以下に掲載がない場合');
ok($zip->set_number('8471401')->is_valid_number, '佐賀県東松浦郡玄海町小加倉');
ok($zip->set_number('8471402')->is_valid_number, '佐賀県東松浦郡玄海町有浦下');
ok($zip->set_number('8471403')->is_valid_number, '佐賀県東松浦郡玄海町有浦上');
ok($zip->set_number('8471404')->is_valid_number, '佐賀県東松浦郡玄海町長倉');
ok($zip->set_number('8471405')->is_valid_number, '佐賀県東松浦郡玄海町藤平');
ok($zip->set_number('8471411')->is_valid_number, '佐賀県東松浦郡玄海町轟木');
ok($zip->set_number('8471412')->is_valid_number, '佐賀県東松浦郡玄海町田代');
ok($zip->set_number('8471413')->is_valid_number, '佐賀県東松浦郡玄海町大鳥');
ok($zip->set_number('8471414')->is_valid_number, '佐賀県東松浦郡玄海町湯野尾');
ok($zip->set_number('8471415')->is_valid_number, '佐賀県東松浦郡玄海町座川内');
ok($zip->set_number('8471416')->is_valid_number, '佐賀県東松浦郡玄海町牟形');
ok($zip->set_number('8471421')->is_valid_number, '佐賀県東松浦郡玄海町諸浦');
ok($zip->set_number('8471422')->is_valid_number, '佐賀県東松浦郡玄海町新田');
ok($zip->set_number('8471423')->is_valid_number, '佐賀県東松浦郡玄海町石田');
ok($zip->set_number('8471424')->is_valid_number, '佐賀県東松浦郡玄海町栄');
ok($zip->set_number('8471425')->is_valid_number, '佐賀県東松浦郡玄海町花の木');
ok($zip->set_number('8471431')->is_valid_number, '佐賀県東松浦郡玄海町普恩寺');
ok($zip->set_number('8471432')->is_valid_number, '佐賀県東松浦郡玄海町平尾');
ok($zip->set_number('8471433')->is_valid_number, '佐賀県東松浦郡玄海町浜野浦');
ok($zip->set_number('8471434')->is_valid_number, '佐賀県東松浦郡玄海町大薗');
ok($zip->set_number('8471435')->is_valid_number, '佐賀県東松浦郡玄海町仮屋');
ok($zip->set_number('8471441')->is_valid_number, '佐賀県東松浦郡玄海町今村');
ok($zip->set_number('8471442')->is_valid_number, '佐賀県東松浦郡玄海町値賀川内');
ok($zip->set_number('8471443')->is_valid_number, '佐賀県東松浦郡玄海町仮立');
ok($zip->set_number('8471444')->is_valid_number, '佐賀県東松浦郡玄海町中通');
ok($zip->set_number('8471445')->is_valid_number, '佐賀県東松浦郡玄海町下宮');
ok($zip->set_number('8471446')->is_valid_number, '佐賀県東松浦郡玄海町外津');
ok($zip->set_number('8471501')->is_valid_number, '佐賀県唐津市肥前町切木');
ok($zip->set_number('8471502')->is_valid_number, '佐賀県唐津市肥前町赤坂');
ok($zip->set_number('8471503')->is_valid_number, '佐賀県唐津市肥前町湯野浦');
ok($zip->set_number('8471504')->is_valid_number, '佐賀県唐津市肥前町中浦');
ok($zip->set_number('8471505')->is_valid_number, '佐賀県唐津市肥前町杉野浦');
ok($zip->set_number('8471506')->is_valid_number, '佐賀県唐津市肥前町大浦');
ok($zip->set_number('8471507')->is_valid_number, '佐賀県唐津市肥前町満越');
ok($zip->set_number('8471511')->is_valid_number, '佐賀県唐津市肥前町新木場');
ok($zip->set_number('8471512')->is_valid_number, '佐賀県唐津市肥前町梅崎');
ok($zip->set_number('8471513')->is_valid_number, '佐賀県唐津市肥前町寺浦');
ok($zip->set_number('8471514')->is_valid_number, '佐賀県唐津市肥前町仁田野尾');
ok($zip->set_number('8471515')->is_valid_number, '佐賀県唐津市肥前町万賀里川');
ok($zip->set_number('8471516')->is_valid_number, '佐賀県唐津市肥前町瓜ケ坂');
ok($zip->set_number('8471517')->is_valid_number, '佐賀県唐津市肥前町上ケ倉');
ok($zip->set_number('8471521')->is_valid_number, '佐賀県唐津市肥前町田野');
ok($zip->set_number('8471522')->is_valid_number, '佐賀県唐津市肥前町犬頭');
ok($zip->set_number('8471523')->is_valid_number, '佐賀県唐津市肥前町星賀');
ok($zip->set_number('8471524')->is_valid_number, '佐賀県唐津市肥前町向島');
ok($zip->set_number('8471525')->is_valid_number, '佐賀県唐津市肥前町納所');
ok($zip->set_number('8471526')->is_valid_number, '佐賀県唐津市肥前町入野');
ok($zip->set_number('8471527')->is_valid_number, '佐賀県唐津市肥前町鶴牧');
ok($zip->set_number('8480000')->is_valid_number, '佐賀県伊万里市以下に掲載がない場合');
ok($zip->set_number('8480001')->is_valid_number, '佐賀県伊万里市南波多町重橋');
ok($zip->set_number('8480002')->is_valid_number, '佐賀県伊万里市南波多町谷口');
ok($zip->set_number('8480003')->is_valid_number, '佐賀県伊万里市南波多町古里');
ok($zip->set_number('8480004')->is_valid_number, '佐賀県伊万里市南波多町水留');
ok($zip->set_number('8480005')->is_valid_number, '佐賀県伊万里市南波多町大曲');
ok($zip->set_number('8480006')->is_valid_number, '佐賀県伊万里市南波多町高瀬');
ok($zip->set_number('8480007')->is_valid_number, '佐賀県伊万里市南波多町井手野');
ok($zip->set_number('8480011')->is_valid_number, '佐賀県伊万里市南波多町大川原');
ok($zip->set_number('8480012')->is_valid_number, '佐賀県伊万里市南波多町古川');
ok($zip->set_number('8480013')->is_valid_number, '佐賀県伊万里市南波多町笠椎');
ok($zip->set_number('8480014')->is_valid_number, '佐賀県伊万里市南波多町小麦原');
ok($zip->set_number('8480015')->is_valid_number, '佐賀県伊万里市南波多町府招');
ok($zip->set_number('8480016')->is_valid_number, '佐賀県伊万里市南波多町原屋敷');
ok($zip->set_number('8480021')->is_valid_number, '佐賀県伊万里市大坪町甲');
ok($zip->set_number('8480022')->is_valid_number, '佐賀県伊万里市大坪町乙');
ok($zip->set_number('8480023')->is_valid_number, '佐賀県伊万里市大坪町丙');
ok($zip->set_number('8480024')->is_valid_number, '佐賀県伊万里市大川内町甲');
ok($zip->set_number('8480025')->is_valid_number, '佐賀県伊万里市大川内町乙');
ok($zip->set_number('8480026')->is_valid_number, '佐賀県伊万里市大川内町丙');
ok($zip->set_number('8480027')->is_valid_number, '佐賀県伊万里市立花町');
ok($zip->set_number('8480028')->is_valid_number, '佐賀県伊万里市脇田町');
ok($zip->set_number('8480031')->is_valid_number, '佐賀県伊万里市二里町八谷搦');
ok($zip->set_number('8480032')->is_valid_number, '佐賀県伊万里市二里町大里甲');
ok($zip->set_number('8480033')->is_valid_number, '佐賀県伊万里市二里町中里乙');
ok($zip->set_number('8480034')->is_valid_number, '佐賀県伊万里市二里町中里甲');
ok($zip->set_number('8480035')->is_valid_number, '佐賀県伊万里市二里町大里乙');
ok($zip->set_number('8480041')->is_valid_number, '佐賀県伊万里市新天町');
ok($zip->set_number('8480042')->is_valid_number, '佐賀県伊万里市蓮池町');
ok($zip->set_number('8480043')->is_valid_number, '佐賀県伊万里市瀬戸町');
ok($zip->set_number('8480044')->is_valid_number, '佐賀県伊万里市木須町');
ok($zip->set_number('8480045')->is_valid_number, '佐賀県伊万里市松島町');
ok($zip->set_number('8480046')->is_valid_number, '佐賀県伊万里市伊万里町乙');
ok($zip->set_number('8480047')->is_valid_number, '佐賀県伊万里市伊万里町甲');
ok($zip->set_number('8480101')->is_valid_number, '佐賀県伊万里市波多津町辻');
ok($zip->set_number('8480102')->is_valid_number, '佐賀県伊万里市波多津町畑津');
ok($zip->set_number('8480103')->is_valid_number, '佐賀県伊万里市波多津町内野');
ok($zip->set_number('8480104')->is_valid_number, '佐賀県伊万里市波多津町煤屋');
ok($zip->set_number('8480105')->is_valid_number, '佐賀県伊万里市波多津町馬蛤潟');
ok($zip->set_number('8480111')->is_valid_number, '佐賀県伊万里市波多津町木場');
ok($zip->set_number('8480112')->is_valid_number, '佐賀県伊万里市波多津町田代');
ok($zip->set_number('8480113')->is_valid_number, '佐賀県伊万里市波多津町板木');
ok($zip->set_number('8480114')->is_valid_number, '佐賀県伊万里市波多津町津留主屋');
ok($zip->set_number('8480115')->is_valid_number, '佐賀県伊万里市波多津町中山');
ok($zip->set_number('8480116')->is_valid_number, '佐賀県伊万里市波多津町井野尾');
ok($zip->set_number('8480117')->is_valid_number, '佐賀県伊万里市波多津町筒井');
ok($zip->set_number('8480121')->is_valid_number, '佐賀県伊万里市黒川町塩屋');
ok($zip->set_number('8480122')->is_valid_number, '佐賀県伊万里市黒川町福田');
ok($zip->set_number('8480123')->is_valid_number, '佐賀県伊万里市黒川町大黒川');
ok($zip->set_number('8480124')->is_valid_number, '佐賀県伊万里市黒川町(名村団地)');
ok($zip->set_number('8480125')->is_valid_number, '佐賀県伊万里市黒川町小黒川');
ok($zip->set_number('8480131')->is_valid_number, '佐賀県伊万里市黒川町畑川内');
ok($zip->set_number('8480132')->is_valid_number, '佐賀県伊万里市黒川町長尾');
ok($zip->set_number('8480133')->is_valid_number, '佐賀県伊万里市黒川町真手野');
ok($zip->set_number('8480134')->is_valid_number, '佐賀県伊万里市黒川町花房');
ok($zip->set_number('8480141')->is_valid_number, '佐賀県伊万里市黒川町清水');
ok($zip->set_number('8480142')->is_valid_number, '佐賀県伊万里市黒川町立目');
ok($zip->set_number('8480143')->is_valid_number, '佐賀県伊万里市黒川町牟田');
ok($zip->set_number('8480144')->is_valid_number, '佐賀県伊万里市黒川町横野');
ok($zip->set_number('8480145')->is_valid_number, '佐賀県伊万里市黒川町椿原');
ok($zip->set_number('8480146')->is_valid_number, '佐賀県伊万里市黒川町黒塩');
ok($zip->set_number('8480401')->is_valid_number, '長崎県松浦市福島町喜内瀬免');
ok($zip->set_number('8480402')->is_valid_number, '長崎県松浦市福島町端免');
ok($zip->set_number('8480403')->is_valid_number, '長崎県松浦市福島町塩浜免');
ok($zip->set_number('8480404')->is_valid_number, '長崎県松浦市福島町浅谷免');
ok($zip->set_number('8480405')->is_valid_number, '長崎県松浦市福島町土谷免');
ok($zip->set_number('8480406')->is_valid_number, '長崎県松浦市福島町原免');
ok($zip->set_number('8480407')->is_valid_number, '長崎県松浦市福島町鍋串免');
ok($zip->set_number('8480408')->is_valid_number, '長崎県松浦市福島町里免');
ok($zip->set_number('8490000')->is_valid_number, '佐賀県佐賀市以下に掲載がない場合');
ok($zip->set_number('8490100')->is_valid_number, '佐賀県三養基郡上峰町以下に掲載がない場合');
ok($zip->set_number('8490100')->is_valid_number, '佐賀県三養基郡みやき町以下に掲載がない場合');
ok($zip->set_number('8490101')->is_valid_number, '佐賀県三養基郡みやき町原古賀');
ok($zip->set_number('8490102')->is_valid_number, '佐賀県三養基郡みやき町簑原');
ok($zip->set_number('8490111')->is_valid_number, '佐賀県三養基郡みやき町白壁');
ok($zip->set_number('8490112')->is_valid_number, '佐賀県三養基郡みやき町江口');
ok($zip->set_number('8490113')->is_valid_number, '佐賀県三養基郡みやき町東尾');
ok($zip->set_number('8490114')->is_valid_number, '佐賀県三養基郡みやき町中津隈');
ok($zip->set_number('8490121')->is_valid_number, '佐賀県三養基郡上峰町江迎');
ok($zip->set_number('8490122')->is_valid_number, '佐賀県三養基郡上峰町前牟田');
ok($zip->set_number('8490123')->is_valid_number, '佐賀県三養基郡上峰町坊所');
ok($zip->set_number('8490124')->is_valid_number, '佐賀県三養基郡上峰町堤');
ok($zip->set_number('8490201')->is_valid_number, '佐賀県佐賀市久保田町徳万');
ok($zip->set_number('8490202')->is_valid_number, '佐賀県佐賀市久保田町久富');
ok($zip->set_number('8490203')->is_valid_number, '佐賀県佐賀市久保田町新田');
ok($zip->set_number('8490204')->is_valid_number, '佐賀県佐賀市久保田町久保田');
ok($zip->set_number('8490205')->is_valid_number, '佐賀県佐賀市久保田町江戸');
ok($zip->set_number('8490301')->is_valid_number, '佐賀県小城市牛津町乙柳');
ok($zip->set_number('8490302')->is_valid_number, '佐賀県小城市牛津町柿樋瀬');
ok($zip->set_number('8490303')->is_valid_number, '佐賀県小城市牛津町牛津');
ok($zip->set_number('8490304')->is_valid_number, '佐賀県小城市牛津町下砥川');
ok($zip->set_number('8490305')->is_valid_number, '佐賀県小城市牛津町上砥川');
ok($zip->set_number('8490306')->is_valid_number, '佐賀県小城市牛津町勝');
ok($zip->set_number('8490311')->is_valid_number, '佐賀県小城市芦刈町芦溝');
ok($zip->set_number('8490312')->is_valid_number, '佐賀県小城市芦刈町下古賀');
ok($zip->set_number('8490313')->is_valid_number, '佐賀県小城市芦刈町永田');
ok($zip->set_number('8490314')->is_valid_number, '佐賀県小城市芦刈町三王崎');
ok($zip->set_number('8490315')->is_valid_number, '佐賀県小城市芦刈町浜枝川');
ok($zip->set_number('8490316')->is_valid_number, '佐賀県小城市芦刈町道免');
ok($zip->set_number('8490401')->is_valid_number, '佐賀県杵島郡白石町福富');
ok($zip->set_number('8490402')->is_valid_number, '佐賀県杵島郡白石町福富下分');
ok($zip->set_number('8490403')->is_valid_number, '佐賀県杵島郡白石町八平');
ok($zip->set_number('8490500')->is_valid_number, '佐賀県杵島郡江北町以下に掲載がない場合');
ok($zip->set_number('8490501')->is_valid_number, '佐賀県杵島郡江北町山口');
ok($zip->set_number('8490502')->is_valid_number, '佐賀県杵島郡江北町佐留志');
ok($zip->set_number('8490503')->is_valid_number, '佐賀県杵島郡江北町惣領分');
ok($zip->set_number('8490504')->is_valid_number, '佐賀県杵島郡江北町八町');
ok($zip->set_number('8490505')->is_valid_number, '佐賀県杵島郡江北町下小田');
ok($zip->set_number('8490506')->is_valid_number, '佐賀県杵島郡江北町上小田');
ok($zip->set_number('8490901')->is_valid_number, '佐賀県佐賀市久保泉町川久保');
ok($zip->set_number('8490902')->is_valid_number, '佐賀県佐賀市久保泉町上和泉');
ok($zip->set_number('8490903')->is_valid_number, '佐賀県佐賀市久保泉町下和泉');
ok($zip->set_number('8490904')->is_valid_number, '佐賀県佐賀市金立町薬師丸');
ok($zip->set_number('8490905')->is_valid_number, '佐賀県佐賀市金立町千布');
ok($zip->set_number('8490906')->is_valid_number, '佐賀県佐賀市金立町金立');
ok($zip->set_number('8490911')->is_valid_number, '佐賀県佐賀市兵庫町若宮');
ok($zip->set_number('8490912')->is_valid_number, '佐賀県佐賀市兵庫町瓦町');
ok($zip->set_number('8490913')->is_valid_number, '佐賀県佐賀市兵庫町渕');
ok($zip->set_number('8490914')->is_valid_number, '佐賀県佐賀市兵庫町西渕');
ok($zip->set_number('8490915')->is_valid_number, '佐賀県佐賀市兵庫町藤木');
ok($zip->set_number('8490916')->is_valid_number, '佐賀県佐賀市高木瀬町東高木');
ok($zip->set_number('8490917')->is_valid_number, '佐賀県佐賀市高木瀬町長瀬');
ok($zip->set_number('8490918')->is_valid_number, '佐賀県佐賀市兵庫南');
ok($zip->set_number('8490919')->is_valid_number, '佐賀県佐賀市兵庫北');
ok($zip->set_number('8490921')->is_valid_number, '佐賀県佐賀市高木瀬西');
ok($zip->set_number('8490922')->is_valid_number, '佐賀県佐賀市高木瀬東');
ok($zip->set_number('8490923')->is_valid_number, '佐賀県佐賀市日の出');
ok($zip->set_number('8490924')->is_valid_number, '佐賀県佐賀市新中町');
ok($zip->set_number('8490925')->is_valid_number, '佐賀県佐賀市八丁畷町');
ok($zip->set_number('8490926')->is_valid_number, '佐賀県佐賀市若宮');
ok($zip->set_number('8490927')->is_valid_number, '佐賀県佐賀市高木瀬団地');
ok($zip->set_number('8490928')->is_valid_number, '佐賀県佐賀市若楠');
ok($zip->set_number('8490931')->is_valid_number, '佐賀県佐賀市鍋島町蛎久');
ok($zip->set_number('8490932')->is_valid_number, '佐賀県佐賀市鍋島町八戸溝');
ok($zip->set_number('8490933')->is_valid_number, '佐賀県佐賀市卸本町');
ok($zip->set_number('8490934')->is_valid_number, '佐賀県佐賀市開成');
ok($zip->set_number('8490935')->is_valid_number, '佐賀県佐賀市八戸溝');
ok($zip->set_number('8490936')->is_valid_number, '佐賀県佐賀市鍋島町森田');
ok($zip->set_number('8490937')->is_valid_number, '佐賀県佐賀市鍋島');
ok($zip->set_number('8490938')->is_valid_number, '佐賀県佐賀市鍋島町鍋島');
ok($zip->set_number('8491100')->is_valid_number, '佐賀県杵島郡白石町以下に掲載がない場合');
ok($zip->set_number('8491101')->is_valid_number, '佐賀県杵島郡白石町今泉');
ok($zip->set_number('8491102')->is_valid_number, '佐賀県杵島郡白石町大渡');
ok($zip->set_number('8491103')->is_valid_number, '佐賀県杵島郡白石町築切');
ok($zip->set_number('8491104')->is_valid_number, '佐賀県杵島郡白石町堤');
ok($zip->set_number('8491105')->is_valid_number, '佐賀県杵島郡白石町遠江');
ok($zip->set_number('8491106')->is_valid_number, '佐賀県杵島郡白石町廿治');
ok($zip->set_number('8491111')->is_valid_number, '佐賀県杵島郡白石町東郷');
ok($zip->set_number('8491112')->is_valid_number, '佐賀県杵島郡白石町福田');
ok($zip->set_number('8491113')->is_valid_number, '佐賀県杵島郡白石町福吉');
ok($zip->set_number('8491114')->is_valid_number, '佐賀県杵島郡白石町馬洗');
ok($zip->set_number('8491115')->is_valid_number, '佐賀県杵島郡白石町湯崎');
ok($zip->set_number('8491116')->is_valid_number, '佐賀県杵島郡白石町横手');
ok($zip->set_number('8491201')->is_valid_number, '佐賀県杵島郡白石町牛屋');
ok($zip->set_number('8491202')->is_valid_number, '佐賀県杵島郡白石町新明');
ok($zip->set_number('8491203')->is_valid_number, '佐賀県杵島郡白石町戸ケ里');
ok($zip->set_number('8491204')->is_valid_number, '佐賀県杵島郡白石町坂田');
ok($zip->set_number('8491205')->is_valid_number, '佐賀県杵島郡白石町田野上');
ok($zip->set_number('8491206')->is_valid_number, '佐賀県杵島郡白石町辺田');
ok($zip->set_number('8491207')->is_valid_number, '佐賀県杵島郡白石町深浦');
ok($zip->set_number('8491208')->is_valid_number, '佐賀県杵島郡白石町新開');
ok($zip->set_number('8491221')->is_valid_number, '佐賀県杵島郡白石町新拓');
ok($zip->set_number('8491300')->is_valid_number, '佐賀県鹿島市以下に掲載がない場合');
ok($zip->set_number('8491301')->is_valid_number, '佐賀県鹿島市常広');
ok($zip->set_number('8491302')->is_valid_number, '佐賀県鹿島市井手');
ok($zip->set_number('8491303')->is_valid_number, '佐賀県鹿島市森');
ok($zip->set_number('8491304')->is_valid_number, '佐賀県鹿島市中村');
ok($zip->set_number('8491311')->is_valid_number, '佐賀県鹿島市高津原');
ok($zip->set_number('8491312')->is_valid_number, '佐賀県鹿島市納富分');
ok($zip->set_number('8491313')->is_valid_number, '佐賀県鹿島市重ノ木');
ok($zip->set_number('8491314')->is_valid_number, '佐賀県鹿島市山浦');
ok($zip->set_number('8491315')->is_valid_number, '佐賀県鹿島市三河内');
ok($zip->set_number('8491321')->is_valid_number, '佐賀県鹿島市古枝');
ok($zip->set_number('8491322')->is_valid_number, '佐賀県鹿島市浜町');
ok($zip->set_number('8491323')->is_valid_number, '佐賀県鹿島市音成');
ok($zip->set_number('8491324')->is_valid_number, '佐賀県鹿島市飯田');
ok($zip->set_number('8491401')->is_valid_number, '佐賀県嬉野市塩田町久間甲');
ok($zip->set_number('8491402')->is_valid_number, '佐賀県嬉野市塩田町久間乙');
ok($zip->set_number('8491403')->is_valid_number, '佐賀県嬉野市塩田町久間丙');
ok($zip->set_number('8491404')->is_valid_number, '佐賀県嬉野市塩田町久間丁');
ok($zip->set_number('8491411')->is_valid_number, '佐賀県嬉野市塩田町馬場下甲');
ok($zip->set_number('8491412')->is_valid_number, '佐賀県嬉野市塩田町馬場下乙');
ok($zip->set_number('8491413')->is_valid_number, '佐賀県嬉野市塩田町馬場下丙');
ok($zip->set_number('8491414')->is_valid_number, '佐賀県嬉野市塩田町大草野甲');
ok($zip->set_number('8491415')->is_valid_number, '佐賀県嬉野市塩田町大草野丙');
ok($zip->set_number('8491416')->is_valid_number, '佐賀県嬉野市塩田町大草野乙');
ok($zip->set_number('8491421')->is_valid_number, '佐賀県嬉野市塩田町真崎');
ok($zip->set_number('8491422')->is_valid_number, '佐賀県嬉野市塩田町谷所甲');
ok($zip->set_number('8491423')->is_valid_number, '佐賀県嬉野市塩田町谷所乙');
ok($zip->set_number('8491424')->is_valid_number, '佐賀県嬉野市塩田町谷所丙');
ok($zip->set_number('8491425')->is_valid_number, '佐賀県嬉野市塩田町五町田甲');
ok($zip->set_number('8491426')->is_valid_number, '佐賀県嬉野市塩田町五町田乙');
ok($zip->set_number('8491600')->is_valid_number, '佐賀県藤津郡太良町以下に掲載がない場合');
ok($zip->set_number('8491601')->is_valid_number, '佐賀県藤津郡太良町伊福甲');
ok($zip->set_number('8491602')->is_valid_number, '佐賀県藤津郡太良町多良');
ok($zip->set_number('8491603')->is_valid_number, '佐賀県藤津郡太良町糸岐');
ok($zip->set_number('8491611')->is_valid_number, '佐賀県藤津郡太良町大浦戊');
ok($zip->set_number('8491612')->is_valid_number, '佐賀県藤津郡太良町大浦丁');
ok($zip->set_number('8491613')->is_valid_number, '佐賀県藤津郡太良町大浦丙');
ok($zip->set_number('8491614')->is_valid_number, '佐賀県藤津郡太良町大浦甲');
ok($zip->set_number('8491615')->is_valid_number, '佐賀県藤津郡太良町大浦乙');
ok($zip->set_number('8491616')->is_valid_number, '佐賀県藤津郡太良町大浦己');
ok($zip->set_number('8492100')->is_valid_number, '佐賀県杵島郡大町町以下に掲載がない場合');
ok($zip->set_number('8492101')->is_valid_number, '佐賀県杵島郡大町町大町');
ok($zip->set_number('8492102')->is_valid_number, '佐賀県杵島郡大町町福母');
ok($zip->set_number('8492201')->is_valid_number, '佐賀県武雄市北方町志久');
ok($zip->set_number('8492202')->is_valid_number, '佐賀県武雄市北方町大渡');
ok($zip->set_number('8492203')->is_valid_number, '佐賀県武雄市北方町芦原');
ok($zip->set_number('8492204')->is_valid_number, '佐賀県武雄市北方町大崎');
ok($zip->set_number('8492301')->is_valid_number, '佐賀県武雄市山内町犬走');
ok($zip->set_number('8492302')->is_valid_number, '佐賀県武雄市山内町鳥海');
ok($zip->set_number('8492303')->is_valid_number, '佐賀県武雄市山内町三間坂');
ok($zip->set_number('8492304')->is_valid_number, '佐賀県武雄市山内町大野');
ok($zip->set_number('8492305')->is_valid_number, '佐賀県武雄市山内町宮野');
ok($zip->set_number('8492341')->is_valid_number, '佐賀県武雄市武内町梅野');
ok($zip->set_number('8492342')->is_valid_number, '佐賀県武雄市武内町真手野');
ok($zip->set_number('8493101')->is_valid_number, '佐賀県唐津市厳木町天川');
ok($zip->set_number('8493102')->is_valid_number, '佐賀県唐津市厳木町鳥越');
ok($zip->set_number('8493103')->is_valid_number, '佐賀県唐津市厳木町広川');
ok($zip->set_number('8493104')->is_valid_number, '佐賀県唐津市厳木町星領');
ok($zip->set_number('8493111')->is_valid_number, '佐賀県唐津市厳木町広瀬');
ok($zip->set_number('8493112')->is_valid_number, '佐賀県唐津市厳木町中島');
ok($zip->set_number('8493113')->is_valid_number, '佐賀県唐津市厳木町牧瀬');
ok($zip->set_number('8493114')->is_valid_number, '佐賀県唐津市厳木町浦川内');
ok($zip->set_number('8493115')->is_valid_number, '佐賀県唐津市厳木町平之');
ok($zip->set_number('8493121')->is_valid_number, '佐賀県唐津市厳木町瀬戸木場');
ok($zip->set_number('8493122')->is_valid_number, '佐賀県唐津市厳木町浪瀬');
ok($zip->set_number('8493123')->is_valid_number, '佐賀県唐津市厳木町岩屋');
ok($zip->set_number('8493131')->is_valid_number, '佐賀県唐津市厳木町厳木');
ok($zip->set_number('8493132')->is_valid_number, '佐賀県唐津市厳木町うつぼ木');
ok($zip->set_number('8493133')->is_valid_number, '佐賀県唐津市厳木町本山');
ok($zip->set_number('8493201')->is_valid_number, '佐賀県唐津市相知町相知');
ok($zip->set_number('8493202')->is_valid_number, '佐賀県唐津市相知町平山下');
ok($zip->set_number('8493203')->is_valid_number, '佐賀県唐津市相知町平山上');
ok($zip->set_number('8493211')->is_valid_number, '佐賀県唐津市相知町千束');
ok($zip->set_number('8493212')->is_valid_number, '佐賀県唐津市相知町横枕');
ok($zip->set_number('8493213')->is_valid_number, '佐賀県唐津市相知町湯屋');
ok($zip->set_number('8493214')->is_valid_number, '佐賀県唐津市相知町田頭');
ok($zip->set_number('8493215')->is_valid_number, '佐賀県唐津市相知町楠');
ok($zip->set_number('8493216')->is_valid_number, '佐賀県唐津市相知町町切');
ok($zip->set_number('8493217')->is_valid_number, '佐賀県唐津市相知町長部田');
ok($zip->set_number('8493218')->is_valid_number, '佐賀県唐津市相知町中山');
ok($zip->set_number('8493219')->is_valid_number, '佐賀県唐津市相知町鷹取');
ok($zip->set_number('8493221')->is_valid_number, '佐賀県唐津市相知町大野');
ok($zip->set_number('8493222')->is_valid_number, '佐賀県唐津市相知町黒岩');
ok($zip->set_number('8493223')->is_valid_number, '佐賀県唐津市相知町伊岐佐');
ok($zip->set_number('8493224')->is_valid_number, '佐賀県唐津市相知町山崎');
ok($zip->set_number('8493231')->is_valid_number, '佐賀県唐津市相知町牟田部');
ok($zip->set_number('8493232')->is_valid_number, '佐賀県唐津市相知町久保');
ok($zip->set_number('8493233')->is_valid_number, '佐賀県唐津市相知町佐里');
ok($zip->set_number('8494141')->is_valid_number, '佐賀県西松浦郡有田町二ノ瀬');
ok($zip->set_number('8494142')->is_valid_number, '佐賀県西松浦郡有田町山谷牧');
ok($zip->set_number('8494143')->is_valid_number, '佐賀県西松浦郡有田町下山谷');
ok($zip->set_number('8494144')->is_valid_number, '佐賀県西松浦郡有田町上山谷');
ok($zip->set_number('8494145')->is_valid_number, '佐賀県西松浦郡有田町山谷切口');
ok($zip->set_number('8494146')->is_valid_number, '佐賀県西松浦郡有田町岳');
ok($zip->set_number('8494151')->is_valid_number, '佐賀県西松浦郡有田町広瀬山');
ok($zip->set_number('8494152')->is_valid_number, '佐賀県西松浦郡有田町広瀬');
ok($zip->set_number('8494153')->is_valid_number, '佐賀県西松浦郡有田町立部');
ok($zip->set_number('8494154')->is_valid_number, '佐賀県西松浦郡有田町大木宿');
ok($zip->set_number('8494155')->is_valid_number, '佐賀県西松浦郡有田町山本');
ok($zip->set_number('8494156')->is_valid_number, '佐賀県西松浦郡有田町桑木原');
ok($zip->set_number('8494161')->is_valid_number, '佐賀県西松浦郡有田町蔵宿');
ok($zip->set_number('8494162')->is_valid_number, '佐賀県西松浦郡有田町上内野');
ok($zip->set_number('8494163')->is_valid_number, '佐賀県西松浦郡有田町下内野');
ok($zip->set_number('8494164')->is_valid_number, '佐賀県西松浦郡有田町仏ノ原');
ok($zip->set_number('8494165')->is_valid_number, '佐賀県西松浦郡有田町黒川');
ok($zip->set_number('8494166')->is_valid_number, '佐賀県西松浦郡有田町北ノ川内');
ok($zip->set_number('8494171')->is_valid_number, '佐賀県西松浦郡有田町代々木');
ok($zip->set_number('8494172')->is_valid_number, '佐賀県西松浦郡有田町下本');
ok($zip->set_number('8494173')->is_valid_number, '佐賀県西松浦郡有田町舞原');
ok($zip->set_number('8494174')->is_valid_number, '佐賀県西松浦郡有田町上本');
ok($zip->set_number('8494175')->is_valid_number, '佐賀県西松浦郡有田町楠木原');
ok($zip->set_number('8494176')->is_valid_number, '佐賀県西松浦郡有田町原明');
ok($zip->set_number('8494251')->is_valid_number, '佐賀県伊万里市山代町楠久');
ok($zip->set_number('8494252')->is_valid_number, '佐賀県伊万里市山代町楠久津');
ok($zip->set_number('8494253')->is_valid_number, '佐賀県伊万里市山代町峰');
ok($zip->set_number('8494254')->is_valid_number, '佐賀県伊万里市山代町城');
ok($zip->set_number('8494255')->is_valid_number, '佐賀県伊万里市山代町福川内');
ok($zip->set_number('8494256')->is_valid_number, '佐賀県伊万里市山代町久原');
ok($zip->set_number('8494261')->is_valid_number, '佐賀県伊万里市山代町立岩');
ok($zip->set_number('8494262')->is_valid_number, '佐賀県伊万里市山代町西分');
ok($zip->set_number('8494263')->is_valid_number, '佐賀県伊万里市山代町西大久保');
ok($zip->set_number('8494264')->is_valid_number, '佐賀県伊万里市山代町東分');
ok($zip->set_number('8494271')->is_valid_number, '佐賀県伊万里市東山代町長浜');
ok($zip->set_number('8494272')->is_valid_number, '佐賀県伊万里市東山代町日尾');
ok($zip->set_number('8494273')->is_valid_number, '佐賀県伊万里市東山代町天神');
ok($zip->set_number('8494274')->is_valid_number, '佐賀県伊万里市東山代町脇野');
ok($zip->set_number('8494281')->is_valid_number, '佐賀県伊万里市東山代町大久保');
ok($zip->set_number('8494282')->is_valid_number, '佐賀県伊万里市東山代町里');
ok($zip->set_number('8494283')->is_valid_number, '佐賀県伊万里市東山代町東大久保');
ok($zip->set_number('8494284')->is_valid_number, '佐賀県伊万里市東山代町浦川内');
ok($zip->set_number('8494285')->is_valid_number, '佐賀県伊万里市東山代町滝川内');
ok($zip->set_number('8494286')->is_valid_number, '佐賀県伊万里市東山代町川内野');
ok($zip->set_number('8495101')->is_valid_number, '佐賀県唐津市浜玉町岡口');
ok($zip->set_number('8495102')->is_valid_number, '佐賀県唐津市浜玉町五反田');
ok($zip->set_number('8495103')->is_valid_number, '佐賀県唐津市浜玉町大江');
ok($zip->set_number('8495104')->is_valid_number, '佐賀県唐津市浜玉町渕上');
ok($zip->set_number('8495105')->is_valid_number, '佐賀県唐津市浜玉町谷口');
ok($zip->set_number('8495111')->is_valid_number, '佐賀県唐津市浜玉町南山');
ok($zip->set_number('8495112')->is_valid_number, '佐賀県唐津市浜玉町平原');
ok($zip->set_number('8495113')->is_valid_number, '佐賀県唐津市浜玉町鳥巣');
ok($zip->set_number('8495121')->is_valid_number, '佐賀県唐津市浜玉町横田上');
ok($zip->set_number('8495122')->is_valid_number, '佐賀県唐津市浜玉町横田下');
ok($zip->set_number('8495123')->is_valid_number, '佐賀県唐津市浜玉町東山田');
ok($zip->set_number('8495124')->is_valid_number, '佐賀県唐津市浜玉町山瀬');
ok($zip->set_number('8495131')->is_valid_number, '佐賀県唐津市浜玉町浜崎');
ok($zip->set_number('8495251')->is_valid_number, '佐賀県伊万里市大川町大川野');
ok($zip->set_number('8495252')->is_valid_number, '佐賀県伊万里市大川町川西');
ok($zip->set_number('8495253')->is_valid_number, '佐賀県伊万里市大川町駒鳴');
ok($zip->set_number('8495254')->is_valid_number, '佐賀県伊万里市大川町立川');
ok($zip->set_number('8495255')->is_valid_number, '佐賀県伊万里市大川町山口');
ok($zip->set_number('8495256')->is_valid_number, '佐賀県伊万里市大川町東田代');
ok($zip->set_number('8495257')->is_valid_number, '佐賀県伊万里市大川町川原');
ok($zip->set_number('8495261')->is_valid_number, '佐賀県伊万里市松浦町桃川');
ok($zip->set_number('8495262')->is_valid_number, '佐賀県伊万里市松浦町中野原');
ok($zip->set_number('8495263')->is_valid_number, '佐賀県伊万里市松浦町山形');
ok($zip->set_number('8495264')->is_valid_number, '佐賀県伊万里市松浦町提川');
ok($zip->set_number('8500000')->is_valid_number, '長崎県長崎市以下に掲載がない場合');
ok($zip->set_number('8500001')->is_valid_number, '長崎県長崎市西山');
ok($zip->set_number('8500002')->is_valid_number, '長崎県長崎市木場町');
ok($zip->set_number('8500003')->is_valid_number, '長崎県長崎市片淵');
ok($zip->set_number('8500004')->is_valid_number, '長崎県長崎市下西山町');
ok($zip->set_number('8500005')->is_valid_number, '長崎県長崎市西山本町');
ok($zip->set_number('8500006')->is_valid_number, '長崎県長崎市上西山町');
ok($zip->set_number('8500007')->is_valid_number, '長崎県長崎市立山');
ok($zip->set_number('8500011')->is_valid_number, '長崎県長崎市鳴滝');
ok($zip->set_number('8500012')->is_valid_number, '長崎県長崎市本河内');
ok($zip->set_number('8500013')->is_valid_number, '長崎県長崎市中川');
ok($zip->set_number('8500014')->is_valid_number, '長崎県長崎市新中川町');
ok($zip->set_number('8500015')->is_valid_number, '長崎県長崎市桜馬場');
ok($zip->set_number('8500016')->is_valid_number, '長崎県長崎市夫婦川町');
ok($zip->set_number('8500017')->is_valid_number, '長崎県長崎市新大工町');
ok($zip->set_number('8500018')->is_valid_number, '長崎県長崎市伊勢町');
ok($zip->set_number('8500021')->is_valid_number, '長崎県長崎市炉粕町');
ok($zip->set_number('8500022')->is_valid_number, '長崎県長崎市馬町');
ok($zip->set_number('8500023')->is_valid_number, '長崎県長崎市出来大工町');
ok($zip->set_number('8500024')->is_valid_number, '長崎県長崎市大井手町');
ok($zip->set_number('8500025')->is_valid_number, '長崎県長崎市今博多町');
ok($zip->set_number('8500026')->is_valid_number, '長崎県長崎市古町');
ok($zip->set_number('8500027')->is_valid_number, '長崎県長崎市桶屋町');
ok($zip->set_number('8500028')->is_valid_number, '長崎県長崎市勝山町');
ok($zip->set_number('8500029')->is_valid_number, '長崎県長崎市八百屋町');
ok($zip->set_number('8500031')->is_valid_number, '長崎県長崎市桜町');
ok($zip->set_number('8500032')->is_valid_number, '長崎県長崎市興善町');
ok($zip->set_number('8500033')->is_valid_number, '長崎県長崎市万才町');
ok($zip->set_number('8500034')->is_valid_number, '長崎県長崎市樺島町');
ok($zip->set_number('8500035')->is_valid_number, '長崎県長崎市元船町');
ok($zip->set_number('8500036')->is_valid_number, '長崎県長崎市五島町');
ok($zip->set_number('8500037')->is_valid_number, '長崎県長崎市金屋町');
ok($zip->set_number('8500041')->is_valid_number, '長崎県長崎市浜平');
ok($zip->set_number('8500042')->is_valid_number, '長崎県長崎市御船蔵町');
ok($zip->set_number('8500043')->is_valid_number, '長崎県長崎市八千代町');
ok($zip->set_number('8500044')->is_valid_number, '長崎県長崎市天神町');
ok($zip->set_number('8500045')->is_valid_number, '長崎県長崎市宝町');
ok($zip->set_number('8500046')->is_valid_number, '長崎県長崎市幸町');
ok($zip->set_number('8500047')->is_valid_number, '長崎県長崎市銭座町');
ok($zip->set_number('8500048')->is_valid_number, '長崎県長崎市上銭座町');
ok($zip->set_number('8500051')->is_valid_number, '長崎県長崎市西坂町');
ok($zip->set_number('8500052')->is_valid_number, '長崎県長崎市筑後町');
ok($zip->set_number('8500053')->is_valid_number, '長崎県長崎市玉園町');
ok($zip->set_number('8500054')->is_valid_number, '長崎県長崎市上町');
ok($zip->set_number('8500055')->is_valid_number, '長崎県長崎市中町');
ok($zip->set_number('8500056')->is_valid_number, '長崎県長崎市恵美須町');
ok($zip->set_number('8500057')->is_valid_number, '長崎県長崎市大黒町');
ok($zip->set_number('8500058')->is_valid_number, '長崎県長崎市尾上町');
ok($zip->set_number('8500061')->is_valid_number, '長崎県長崎市水の浦町');
ok($zip->set_number('8500062')->is_valid_number, '長崎県長崎市大谷町');
ok($zip->set_number('8500063')->is_valid_number, '長崎県長崎市飽の浦町');
ok($zip->set_number('8500064')->is_valid_number, '長崎県長崎市秋月町');
ok($zip->set_number('8500065')->is_valid_number, '長崎県長崎市入船町');
ok($zip->set_number('8500066')->is_valid_number, '長崎県長崎市大浜町');
ok($zip->set_number('8500067')->is_valid_number, '長崎県長崎市小浦町');
ok($zip->set_number('8500068')->is_valid_number, '長崎県長崎市福田本町');
ok($zip->set_number('8500071')->is_valid_number, '長崎県長崎市塩浜町');
ok($zip->set_number('8500072')->is_valid_number, '長崎県長崎市岩瀬道町');
ok($zip->set_number('8500073')->is_valid_number, '長崎県長崎市東立神町');
ok($zip->set_number('8500074')->is_valid_number, '長崎県長崎市西立神町');
ok($zip->set_number('8500075')->is_valid_number, '長崎県長崎市西泊町');
ok($zip->set_number('8500076')->is_valid_number, '長崎県長崎市木鉢町');
ok($zip->set_number('8500077')->is_valid_number, '長崎県長崎市小瀬戸町');
ok($zip->set_number('8500078')->is_valid_number, '長崎県長崎市神ノ島町');
ok($zip->set_number('8500079')->is_valid_number, '長崎県長崎市みなと坂');
ok($zip->set_number('8500801')->is_valid_number, '長崎県長崎市八幡町');
ok($zip->set_number('8500802')->is_valid_number, '長崎県長崎市伊良林');
ok($zip->set_number('8500803')->is_valid_number, '長崎県長崎市風頭町');
ok($zip->set_number('8500804')->is_valid_number, '長崎県長崎市彦見町');
ok($zip->set_number('8500811')->is_valid_number, '長崎県長崎市矢の平');
ok($zip->set_number('8500812')->is_valid_number, '長崎県長崎市白木町');
ok($zip->set_number('8500813')->is_valid_number, '長崎県長崎市八つ尾町');
ok($zip->set_number('8500821')->is_valid_number, '長崎県長崎市高平町');
ok($zip->set_number('8500822')->is_valid_number, '長崎県長崎市愛宕');
ok($zip->set_number('8500823')->is_valid_number, '長崎県長崎市弥生町');
ok($zip->set_number('8500824')->is_valid_number, '長崎県長崎市三景台町');
ok($zip->set_number('8500831')->is_valid_number, '長崎県長崎市鍛冶屋町');
ok($zip->set_number('8500832')->is_valid_number, '長崎県長崎市油屋町');
ok($zip->set_number('8500833')->is_valid_number, '長崎県長崎市東小島町');
ok($zip->set_number('8500834')->is_valid_number, '長崎県長崎市上小島');
ok($zip->set_number('8500835')->is_valid_number, '長崎県長崎市桜木町');
ok($zip->set_number('8500836')->is_valid_number, '長崎県長崎市中小島');
ok($zip->set_number('8500837')->is_valid_number, '長崎県長崎市西小島');
ok($zip->set_number('8500841')->is_valid_number, '長崎県長崎市銅座町');
ok($zip->set_number('8500842')->is_valid_number, '長崎県長崎市新地町');
ok($zip->set_number('8500843')->is_valid_number, '長崎県長崎市常盤町');
ok($zip->set_number('8500851')->is_valid_number, '長崎県長崎市古川町');
ok($zip->set_number('8500852')->is_valid_number, '長崎県長崎市万屋町');
ok($zip->set_number('8500853')->is_valid_number, '長崎県長崎市浜町');
ok($zip->set_number('8500854')->is_valid_number, '長崎県長崎市銀屋町');
ok($zip->set_number('8500855')->is_valid_number, '長崎県長崎市東古川町');
ok($zip->set_number('8500861')->is_valid_number, '長崎県長崎市江戸町');
ok($zip->set_number('8500862')->is_valid_number, '長崎県長崎市出島町');
ok($zip->set_number('8500871')->is_valid_number, '長崎県長崎市麹屋町');
ok($zip->set_number('8500872')->is_valid_number, '長崎県長崎市寺町');
ok($zip->set_number('8500873')->is_valid_number, '長崎県長崎市諏訪町');
ok($zip->set_number('8500874')->is_valid_number, '長崎県長崎市魚の町');
ok($zip->set_number('8500875')->is_valid_number, '長崎県長崎市栄町');
ok($zip->set_number('8500876')->is_valid_number, '長崎県長崎市賑町');
ok($zip->set_number('8500877')->is_valid_number, '長崎県長崎市築町');
ok($zip->set_number('8500901')->is_valid_number, '長崎県長崎市本石灰町');
ok($zip->set_number('8500902')->is_valid_number, '長崎県長崎市丸山町');
ok($zip->set_number('8500903')->is_valid_number, '長崎県長崎市寄合町');
ok($zip->set_number('8500904')->is_valid_number, '長崎県長崎市船大工町');
ok($zip->set_number('8500905')->is_valid_number, '長崎県長崎市籠町');
ok($zip->set_number('8500906')->is_valid_number, '長崎県長崎市館内町');
ok($zip->set_number('8500907')->is_valid_number, '長崎県長崎市稲田町');
ok($zip->set_number('8500908')->is_valid_number, '長崎県長崎市十人町');
ok($zip->set_number('8500909')->is_valid_number, '長崎県長崎市梅香崎町');
ok($zip->set_number('8500911')->is_valid_number, '長崎県長崎市東山手町');
ok($zip->set_number('8500912')->is_valid_number, '長崎県長崎市中新町');
ok($zip->set_number('8500913')->is_valid_number, '長崎県長崎市元町');
ok($zip->set_number('8500914')->is_valid_number, '長崎県長崎市日の出町');
ok($zip->set_number('8500915')->is_valid_number, '長崎県長崎市東山町');
ok($zip->set_number('8500916')->is_valid_number, '長崎県長崎市大浦東町');
ok($zip->set_number('8500917')->is_valid_number, '長崎県長崎市下町');
ok($zip->set_number('8500918')->is_valid_number, '長崎県長崎市大浦町');
ok($zip->set_number('8500921')->is_valid_number, '長崎県長崎市松が枝町');
ok($zip->set_number('8500922')->is_valid_number, '長崎県長崎市相生町');
ok($zip->set_number('8500923')->is_valid_number, '長崎県長崎市上田町');
ok($zip->set_number('8500924')->is_valid_number, '長崎県長崎市出雲');
ok($zip->set_number('8500931')->is_valid_number, '長崎県長崎市南山手町');
ok($zip->set_number('8500932')->is_valid_number, '長崎県長崎市東琴平');
ok($zip->set_number('8500933')->is_valid_number, '長崎県長崎市西琴平町');
ok($zip->set_number('8500934')->is_valid_number, '長崎県長崎市小菅町');
ok($zip->set_number('8500935')->is_valid_number, '長崎県長崎市古河町');
ok($zip->set_number('8500936')->is_valid_number, '長崎県長崎市浪の平町');
ok($zip->set_number('8500937')->is_valid_number, '長崎県長崎市小曽根町');
ok($zip->set_number('8500941')->is_valid_number, '長崎県長崎市高丘');
ok($zip->set_number('8500942')->is_valid_number, '長崎県長崎市南町');
ok($zip->set_number('8500943')->is_valid_number, '長崎県長崎市南が丘町');
ok($zip->set_number('8500944')->is_valid_number, '長崎県長崎市八景町');
ok($zip->set_number('8500945')->is_valid_number, '長崎県長崎市星取');
ok($zip->set_number('8500946')->is_valid_number, '長崎県長崎市川上町');
ok($zip->set_number('8500947')->is_valid_number, '長崎県長崎市椎の木町');
ok($zip->set_number('8500951')->is_valid_number, '長崎県長崎市国分町');
ok($zip->set_number('8500952')->is_valid_number, '長崎県長崎市戸町');
ok($zip->set_number('8500953')->is_valid_number, '長崎県長崎市上戸町');
ok($zip->set_number('8500954')->is_valid_number, '長崎県長崎市新戸町');
ok($zip->set_number('8500961')->is_valid_number, '長崎県長崎市小ケ倉町');
ok($zip->set_number('8500962')->is_valid_number, '長崎県長崎市新小が倉');
ok($zip->set_number('8500963')->is_valid_number, '長崎県長崎市ダイヤランド');
ok($zip->set_number('8500964')->is_valid_number, '長崎県長崎市大山町');
ok($zip->set_number('8500971')->is_valid_number, '長崎県長崎市磯道町');
ok($zip->set_number('8500972')->is_valid_number, '長崎県長崎市古道町');
ok($zip->set_number('8500973')->is_valid_number, '長崎県長崎市鹿尾町');
ok($zip->set_number('8500974')->is_valid_number, '長崎県長崎市京太郎町');
ok($zip->set_number('8500975')->is_valid_number, '長崎県長崎市三和町');
ok($zip->set_number('8500976')->is_valid_number, '長崎県長崎市毛井首町');
ok($zip->set_number('8500977')->is_valid_number, '長崎県長崎市土井首町');
ok($zip->set_number('8500981')->is_valid_number, '長崎県長崎市草住町');
ok($zip->set_number('8500982')->is_valid_number, '長崎県長崎市柳田町');
ok($zip->set_number('8500983')->is_valid_number, '長崎県長崎市米山町');
ok($zip->set_number('8500984')->is_valid_number, '長崎県長崎市鶴見台');
ok($zip->set_number('8500985')->is_valid_number, '長崎県長崎市平瀬町');
ok($zip->set_number('8500991')->is_valid_number, '長崎県長崎市末石町');
ok($zip->set_number('8500992')->is_valid_number, '長崎県長崎市江川町');
ok($zip->set_number('8500993')->is_valid_number, '長崎県長崎市八郎岳町');
ok($zip->set_number('8500994')->is_valid_number, '長崎県長崎市竿浦町');
ok($zip->set_number('8500995')->is_valid_number, '長崎県長崎市平山町');
ok($zip->set_number('8500996')->is_valid_number, '長崎県長崎市平山台');
ok($zip->set_number('8510101')->is_valid_number, '長崎県長崎市古賀町');
ok($zip->set_number('8510102')->is_valid_number, '長崎県長崎市つつじが丘');
ok($zip->set_number('8510103')->is_valid_number, '長崎県長崎市中里町');
ok($zip->set_number('8510104')->is_valid_number, '長崎県長崎市船石町');
ok($zip->set_number('8510111')->is_valid_number, '長崎県長崎市上戸石町');
ok($zip->set_number('8510112')->is_valid_number, '長崎県長崎市川内町');
ok($zip->set_number('8510113')->is_valid_number, '長崎県長崎市戸石町');
ok($zip->set_number('8510114')->is_valid_number, '長崎県長崎市牧島町');
ok($zip->set_number('8510115')->is_valid_number, '長崎県長崎市かき道');
ok($zip->set_number('8510116')->is_valid_number, '長崎県長崎市東町');
ok($zip->set_number('8510121')->is_valid_number, '長崎県長崎市宿町');
ok($zip->set_number('8510122')->is_valid_number, '長崎県長崎市界');
ok($zip->set_number('8510123')->is_valid_number, '長崎県長崎市網場町');
ok($zip->set_number('8510124')->is_valid_number, '長崎県長崎市春日町');
ok($zip->set_number('8510125')->is_valid_number, '長崎県長崎市潮見町');
ok($zip->set_number('8510126')->is_valid_number, '長崎県長崎市芒塚町');
ok($zip->set_number('8510131')->is_valid_number, '長崎県長崎市松原町');
ok($zip->set_number('8510132')->is_valid_number, '長崎県長崎市鶴の尾町');
ok($zip->set_number('8510133')->is_valid_number, '長崎県長崎市矢上町');
ok($zip->set_number('8510134')->is_valid_number, '長崎県長崎市田中町');
ok($zip->set_number('8510135')->is_valid_number, '長崎県長崎市現川町');
ok($zip->set_number('8510136')->is_valid_number, '長崎県長崎市平間町');
ok($zip->set_number('8510137')->is_valid_number, '長崎県長崎市高城台');
ok($zip->set_number('8510241')->is_valid_number, '長崎県長崎市茂木町');
ok($zip->set_number('8510242')->is_valid_number, '長崎県長崎市北浦町');
ok($zip->set_number('8510243')->is_valid_number, '長崎県長崎市宮摺町');
ok($zip->set_number('8510244')->is_valid_number, '長崎県長崎市大崎町');
ok($zip->set_number('8510245')->is_valid_number, '長崎県長崎市千々町');
ok($zip->set_number('8510251')->is_valid_number, '長崎県長崎市田上');
ok($zip->set_number('8510252')->is_valid_number, '長崎県長崎市田手原町');
ok($zip->set_number('8510253')->is_valid_number, '長崎県長崎市早坂町');
ok($zip->set_number('8510254')->is_valid_number, '長崎県長崎市飯香浦町');
ok($zip->set_number('8510255')->is_valid_number, '長崎県長崎市太田尾町');
ok($zip->set_number('8510301')->is_valid_number, '長崎県長崎市深堀町');
ok($zip->set_number('8510302')->is_valid_number, '長崎県長崎市大籠町');
ok($zip->set_number('8510310')->is_valid_number, '長崎県長崎市香焼町');
ok($zip->set_number('8510401')->is_valid_number, '長崎県長崎市蚊焼町');
ok($zip->set_number('8510402')->is_valid_number, '長崎県長崎市晴海台町');
ok($zip->set_number('8510403')->is_valid_number, '長崎県長崎市布巻町');
ok($zip->set_number('8510404')->is_valid_number, '長崎県長崎市藤田尾町');
ok($zip->set_number('8510405')->is_valid_number, '長崎県長崎市為石町');
ok($zip->set_number('8510406')->is_valid_number, '長崎県長崎市椿が丘町');
ok($zip->set_number('8510407')->is_valid_number, '長崎県長崎市川原町');
ok($zip->set_number('8510408')->is_valid_number, '長崎県長崎市宮崎町');
ok($zip->set_number('8510501')->is_valid_number, '長崎県長崎市黒浜町');
ok($zip->set_number('8510502')->is_valid_number, '長崎県長崎市以下宿町');
ok($zip->set_number('8510503')->is_valid_number, '長崎県長崎市高浜町');
ok($zip->set_number('8510504')->is_valid_number, '長崎県長崎市南越町');
ok($zip->set_number('8510505')->is_valid_number, '長崎県長崎市野母町');
ok($zip->set_number('8510506')->is_valid_number, '長崎県長崎市脇岬町');
ok($zip->set_number('8510507')->is_valid_number, '長崎県長崎市野母崎樺島町');
ok($zip->set_number('8511121')->is_valid_number, '長崎県長崎市見崎町');
ok($zip->set_number('8511122')->is_valid_number, '長崎県長崎市相川町');
ok($zip->set_number('8511123')->is_valid_number, '長崎県長崎市四杖町');
ok($zip->set_number('8511124')->is_valid_number, '長崎県長崎市牧野町');
ok($zip->set_number('8511125')->is_valid_number, '長崎県長崎市園田町');
ok($zip->set_number('8511131')->is_valid_number, '長崎県長崎市上浦町');
ok($zip->set_number('8511132')->is_valid_number, '長崎県長崎市小江原');
ok($zip->set_number('8511133')->is_valid_number, '長崎県長崎市小江町');
ok($zip->set_number('8511134')->is_valid_number, '長崎県長崎市柿泊町');
ok($zip->set_number('8511135')->is_valid_number, '長崎県長崎市手熊町');
ok($zip->set_number('8511136')->is_valid_number, '長崎県長崎市向町');
ok($zip->set_number('8511137')->is_valid_number, '長崎県長崎市式見町');
ok($zip->set_number('8511201')->is_valid_number, '長崎県長崎市伊王島町');
ok($zip->set_number('8511315')->is_valid_number, '長崎県長崎市高島町');
ok($zip->set_number('8512100')->is_valid_number, '長崎県西彼杵郡長与町以下に掲載がない場合');
ok($zip->set_number('8512100')->is_valid_number, '長崎県西彼杵郡時津町以下に掲載がない場合');
ok($zip->set_number('8512101')->is_valid_number, '長崎県西彼杵郡時津町西時津郷');
ok($zip->set_number('8512102')->is_valid_number, '長崎県西彼杵郡時津町浜田郷');
ok($zip->set_number('8512103')->is_valid_number, '長崎県西彼杵郡時津町元村郷');
ok($zip->set_number('8512104')->is_valid_number, '長崎県西彼杵郡時津町野田郷');
ok($zip->set_number('8512105')->is_valid_number, '長崎県西彼杵郡時津町浦郷');
ok($zip->set_number('8512106')->is_valid_number, '長崎県西彼杵郡時津町左底郷');
ok($zip->set_number('8512107')->is_valid_number, '長崎県西彼杵郡時津町久留里郷');
ok($zip->set_number('8512108')->is_valid_number, '長崎県西彼杵郡時津町日並郷');
ok($zip->set_number('8512111')->is_valid_number, '長崎県西彼杵郡時津町子々川郷');
ok($zip->set_number('8512121')->is_valid_number, '長崎県西彼杵郡長与町岡郷');
ok($zip->set_number('8512122')->is_valid_number, '長崎県西彼杵郡長与町本川内郷');
ok($zip->set_number('8512123')->is_valid_number, '長崎県西彼杵郡長与町平木場郷');
ok($zip->set_number('8512124')->is_valid_number, '長崎県西彼杵郡長与町丸田郷');
ok($zip->set_number('8512125')->is_valid_number, '長崎県西彼杵郡長与町三根郷');
ok($zip->set_number('8512126')->is_valid_number, '長崎県西彼杵郡長与町吉無田郷');
ok($zip->set_number('8512127')->is_valid_number, '長崎県西彼杵郡長与町高田郷');
ok($zip->set_number('8512128')->is_valid_number, '長崎県西彼杵郡長与町嬉里郷');
ok($zip->set_number('8512129')->is_valid_number, '長崎県西彼杵郡長与町斉藤郷');
ok($zip->set_number('8512130')->is_valid_number, '長崎県西彼杵郡長与町まなび野');
ok($zip->set_number('8512131')->is_valid_number, '長崎県西彼杵郡長与町北陽台');
ok($zip->set_number('8512201')->is_valid_number, '長崎県長崎市畦町');
ok($zip->set_number('8512202')->is_valid_number, '長崎県長崎市樫山町');
ok($zip->set_number('8512203')->is_valid_number, '長崎県長崎市三重田町');
ok($zip->set_number('8512204')->is_valid_number, '長崎県長崎市三重町');
ok($zip->set_number('8512205')->is_valid_number, '長崎県長崎市松崎町');
ok($zip->set_number('8512206')->is_valid_number, '長崎県長崎市三京町');
ok($zip->set_number('8512207')->is_valid_number, '長崎県長崎市さくらの里');
ok($zip->set_number('8512211')->is_valid_number, '長崎県長崎市京泊');
ok($zip->set_number('8512212')->is_valid_number, '長崎県長崎市畝刈町');
ok($zip->set_number('8512213')->is_valid_number, '長崎県長崎市多以良町');
ok($zip->set_number('8512214')->is_valid_number, '長崎県長崎市鳴見町');
ok($zip->set_number('8512215')->is_valid_number, '長崎県長崎市鳴見台');
ok($zip->set_number('8512216')->is_valid_number, '長崎県長崎市豊洋台');
ok($zip->set_number('8512321')->is_valid_number, '長崎県長崎市赤首町');
ok($zip->set_number('8512322')->is_valid_number, '長崎県長崎市西出津町');
ok($zip->set_number('8512323')->is_valid_number, '長崎県長崎市新牧野町');
ok($zip->set_number('8512324')->is_valid_number, '長崎県長崎市上黒崎町');
ok($zip->set_number('8512325')->is_valid_number, '長崎県長崎市永田町');
ok($zip->set_number('8512326')->is_valid_number, '長崎県長崎市下黒崎町');
ok($zip->set_number('8512327')->is_valid_number, '長崎県長崎市東出津町');
ok($zip->set_number('8512401')->is_valid_number, '長崎県長崎市神浦口福町');
ok($zip->set_number('8512403')->is_valid_number, '長崎県長崎市神浦江川町');
ok($zip->set_number('8512404')->is_valid_number, '長崎県長崎市神浦丸尾町');
ok($zip->set_number('8512405')->is_valid_number, '長崎県長崎市神浦向町');
ok($zip->set_number('8512411')->is_valid_number, '長崎県長崎市神浦扇山町');
ok($zip->set_number('8512413')->is_valid_number, '長崎県長崎市神浦夏井町');
ok($zip->set_number('8512421')->is_valid_number, '長崎県長崎市神浦北大中尾町');
ok($zip->set_number('8512422')->is_valid_number, '長崎県長崎市神浦上大中尾町');
ok($zip->set_number('8512423')->is_valid_number, '長崎県長崎市神浦下大中尾町');
ok($zip->set_number('8512424')->is_valid_number, '長崎県長崎市神浦上道徳町');
ok($zip->set_number('8512425')->is_valid_number, '長崎県長崎市神浦下道徳町');
ok($zip->set_number('8512426')->is_valid_number, '長崎県長崎市上大野町');
ok($zip->set_number('8512427')->is_valid_number, '長崎県長崎市下大野町');
ok($zip->set_number('8513101')->is_valid_number, '長崎県長崎市西海町');
ok($zip->set_number('8513102')->is_valid_number, '長崎県長崎市琴海村松町');
ok($zip->set_number('8513103')->is_valid_number, '長崎県長崎市琴海戸根町');
ok($zip->set_number('8513211')->is_valid_number, '長崎県長崎市琴海戸根原町');
ok($zip->set_number('8513212')->is_valid_number, '長崎県長崎市長浦町');
ok($zip->set_number('8513213')->is_valid_number, '長崎県長崎市琴海形上町');
ok($zip->set_number('8513214')->is_valid_number, '長崎県長崎市琴海大平町');
ok($zip->set_number('8513215')->is_valid_number, '長崎県長崎市琴海尾戸町');
ok($zip->set_number('8513301')->is_valid_number, '長崎県西海市西彼町宮浦郷');
ok($zip->set_number('8513302')->is_valid_number, '長崎県西海市西彼町中山郷');
ok($zip->set_number('8513303')->is_valid_number, '長崎県西海市西彼町亀浦郷');
ok($zip->set_number('8513304')->is_valid_number, '長崎県西海市西彼町上岳郷');
ok($zip->set_number('8513305')->is_valid_number, '長崎県西海市西彼町喰場郷');
ok($zip->set_number('8513306')->is_valid_number, '長崎県西海市西彼町鳥加郷(川山)');
ok($zip->set_number('8513311')->is_valid_number, '長崎県西海市西彼町下岳郷');
ok($zip->set_number('8513312')->is_valid_number, '長崎県西海市西彼町白崎郷');
ok($zip->set_number('8513313')->is_valid_number, '長崎県西海市西彼町風早郷');
ok($zip->set_number('8513314')->is_valid_number, '長崎県西海市西彼町白似田郷');
ok($zip->set_number('8513315')->is_valid_number, '長崎県西海市西彼町平原郷');
ok($zip->set_number('8513406')->is_valid_number, '長崎県西海市西彼町鳥加郷(その他)');
ok($zip->set_number('8513421')->is_valid_number, '長崎県西海市西彼町伊ノ浦郷');
ok($zip->set_number('8513422')->is_valid_number, '長崎県西海市西彼町小迎郷');
ok($zip->set_number('8513423')->is_valid_number, '長崎県西海市西彼町八木原郷');
ok($zip->set_number('8513424')->is_valid_number, '長崎県西海市西彼町大串郷');
ok($zip->set_number('8513425')->is_valid_number, '長崎県西海市西彼町平山郷');
ok($zip->set_number('8513500')->is_valid_number, '長崎県西海市以下に掲載がない場合');
ok($zip->set_number('8513501')->is_valid_number, '長崎県西海市西海町丹納郷');
ok($zip->set_number('8513502')->is_valid_number, '長崎県西海市西海町川内郷');
ok($zip->set_number('8513503')->is_valid_number, '長崎県西海市西海町太田原郷');
ok($zip->set_number('8513504')->is_valid_number, '長崎県西海市西海町木場郷');
ok($zip->set_number('8513505')->is_valid_number, '長崎県西海市西海町太田和郷');
ok($zip->set_number('8513506')->is_valid_number, '長崎県西海市西海町黒口郷');
ok($zip->set_number('8513507')->is_valid_number, '長崎県西海市西海町天久保郷');
ok($zip->set_number('8513508')->is_valid_number, '長崎県西海市西海町面高郷');
ok($zip->set_number('8513509')->is_valid_number, '長崎県西海市西海町横瀬郷');
ok($zip->set_number('8513511')->is_valid_number, '長崎県西海市西海町水浦郷');
ok($zip->set_number('8528001')->is_valid_number, '長崎県長崎市光町');
ok($zip->set_number('8528002')->is_valid_number, '長崎県長崎市弁天町');
ok($zip->set_number('8528003')->is_valid_number, '長崎県長崎市旭町');
ok($zip->set_number('8528004')->is_valid_number, '長崎県長崎市丸尾町');
ok($zip->set_number('8528005')->is_valid_number, '長崎県長崎市大鳥町');
ok($zip->set_number('8528006')->is_valid_number, '長崎県長崎市平戸小屋町');
ok($zip->set_number('8528007')->is_valid_number, '長崎県長崎市江の浦町');
ok($zip->set_number('8528008')->is_valid_number, '長崎県長崎市曙町');
ok($zip->set_number('8528011')->is_valid_number, '長崎県長崎市稲佐町');
ok($zip->set_number('8528012')->is_valid_number, '長崎県長崎市淵町');
ok($zip->set_number('8528013')->is_valid_number, '長崎県長崎市梁川町');
ok($zip->set_number('8528014')->is_valid_number, '長崎県長崎市竹の久保町');
ok($zip->set_number('8528015')->is_valid_number, '長崎県長崎市春木町');
ok($zip->set_number('8528016')->is_valid_number, '長崎県長崎市宝栄町');
ok($zip->set_number('8528017')->is_valid_number, '長崎県長崎市岩見町');
ok($zip->set_number('8528021')->is_valid_number, '長崎県長崎市城山町');
ok($zip->set_number('8528022')->is_valid_number, '長崎県長崎市富士見町');
ok($zip->set_number('8528023')->is_valid_number, '長崎県長崎市若草町');
ok($zip->set_number('8528024')->is_valid_number, '長崎県長崎市花園町');
ok($zip->set_number('8528025')->is_valid_number, '長崎県長崎市立岩町');
ok($zip->set_number('8528026')->is_valid_number, '長崎県長崎市金堀町');
ok($zip->set_number('8528027')->is_valid_number, '長崎県長崎市城山台');
ok($zip->set_number('8528031')->is_valid_number, '長崎県長崎市三芳町');
ok($zip->set_number('8528032')->is_valid_number, '長崎県長崎市江里町');
ok($zip->set_number('8528033')->is_valid_number, '長崎県長崎市緑が丘町');
ok($zip->set_number('8528034')->is_valid_number, '長崎県長崎市城栄町');
ok($zip->set_number('8528035')->is_valid_number, '長崎県長崎市油木町');
ok($zip->set_number('8528036')->is_valid_number, '長崎県長崎市青山町');
ok($zip->set_number('8528041')->is_valid_number, '長崎県長崎市清水町');
ok($zip->set_number('8528042')->is_valid_number, '長崎県長崎市白鳥町');
ok($zip->set_number('8528043')->is_valid_number, '長崎県長崎市西町');
ok($zip->set_number('8528044')->is_valid_number, '長崎県長崎市音無町');
ok($zip->set_number('8528045')->is_valid_number, '長崎県長崎市錦');
ok($zip->set_number('8528046')->is_valid_number, '長崎県長崎市柳谷町');
ok($zip->set_number('8528047')->is_valid_number, '長崎県長崎市若竹町');
ok($zip->set_number('8528051')->is_valid_number, '長崎県長崎市西北町');
ok($zip->set_number('8528052')->is_valid_number, '長崎県長崎市岩屋町');
ok($zip->set_number('8528053')->is_valid_number, '長崎県長崎市葉山');
ok($zip->set_number('8528054')->is_valid_number, '長崎県長崎市エミネント葉山町');
ok($zip->set_number('8528055')->is_valid_number, '長崎県長崎市虹が丘町');
ok($zip->set_number('8528056')->is_valid_number, '長崎県長崎市大宮町');
ok($zip->set_number('8528061')->is_valid_number, '長崎県長崎市滑石');
ok($zip->set_number('8528062')->is_valid_number, '長崎県長崎市大園町');
ok($zip->set_number('8528063')->is_valid_number, '長崎県長崎市北栄町');
ok($zip->set_number('8528064')->is_valid_number, '長崎県長崎市北陽町');
ok($zip->set_number('8528065')->is_valid_number, '長崎県長崎市横尾');
ok($zip->set_number('8528101')->is_valid_number, '長崎県長崎市江平');
ok($zip->set_number('8528102')->is_valid_number, '長崎県長崎市坂本');
ok($zip->set_number('8528103')->is_valid_number, '長崎県長崎市緑町');
ok($zip->set_number('8528104')->is_valid_number, '長崎県長崎市茂里町');
ok($zip->set_number('8528105')->is_valid_number, '長崎県長崎市目覚町');
ok($zip->set_number('8528106')->is_valid_number, '長崎県長崎市岩川町');
ok($zip->set_number('8528107')->is_valid_number, '長崎県長崎市浜口町');
ok($zip->set_number('8528108')->is_valid_number, '長崎県長崎市川口町');
ok($zip->set_number('8528111')->is_valid_number, '長崎県長崎市高尾町');
ok($zip->set_number('8528112')->is_valid_number, '長崎県長崎市本尾町');
ok($zip->set_number('8528113')->is_valid_number, '長崎県長崎市上野町');
ok($zip->set_number('8528114')->is_valid_number, '長崎県長崎市橋口町');
ok($zip->set_number('8528115')->is_valid_number, '長崎県長崎市岡町');
ok($zip->set_number('8528116')->is_valid_number, '長崎県長崎市平和町');
ok($zip->set_number('8528117')->is_valid_number, '長崎県長崎市平野町');
ok($zip->set_number('8528118')->is_valid_number, '長崎県長崎市松山町');
ok($zip->set_number('8528121')->is_valid_number, '長崎県長崎市三川町');
ok($zip->set_number('8528122')->is_valid_number, '長崎県長崎市西山台');
ok($zip->set_number('8528123')->is_valid_number, '長崎県長崎市三原');
ok($zip->set_number('8528124')->is_valid_number, '長崎県長崎市辻町');
ok($zip->set_number('8528125')->is_valid_number, '長崎県長崎市小峰町');
ok($zip->set_number('8528126')->is_valid_number, '長崎県長崎市石神町');
ok($zip->set_number('8528127')->is_valid_number, '長崎県長崎市大手');
ok($zip->set_number('8528131')->is_valid_number, '長崎県長崎市文教町');
ok($zip->set_number('8528132')->is_valid_number, '長崎県長崎市扇町');
ok($zip->set_number('8528133')->is_valid_number, '長崎県長崎市本原町');
ok($zip->set_number('8528134')->is_valid_number, '長崎県長崎市大橋町');
ok($zip->set_number('8528135')->is_valid_number, '長崎県長崎市千歳町');
ok($zip->set_number('8528136')->is_valid_number, '長崎県長崎市家野町');
ok($zip->set_number('8528137')->is_valid_number, '長崎県長崎市若葉町');
ok($zip->set_number('8528141')->is_valid_number, '長崎県長崎市畦別当町');
ok($zip->set_number('8528142')->is_valid_number, '長崎県長崎市三ツ山町');
ok($zip->set_number('8528143')->is_valid_number, '長崎県長崎市川平町');
ok($zip->set_number('8528144')->is_valid_number, '長崎県長崎市女の都');
ok($zip->set_number('8528145')->is_valid_number, '長崎県長崎市昭和');
ok($zip->set_number('8528146')->is_valid_number, '長崎県長崎市けやき台町');
ok($zip->set_number('8528151')->is_valid_number, '長崎県長崎市泉');
ok($zip->set_number('8528152')->is_valid_number, '長崎県長崎市住吉台町');
ok($zip->set_number('8528153')->is_valid_number, '長崎県長崎市花丘町');
ok($zip->set_number('8528154')->is_valid_number, '長崎県長崎市住吉町');
ok($zip->set_number('8528155')->is_valid_number, '長崎県長崎市中園町');
ok($zip->set_number('8528156')->is_valid_number, '長崎県長崎市赤迫');
ok($zip->set_number('8528157')->is_valid_number, '長崎県長崎市泉町');
ok($zip->set_number('8530000')->is_valid_number, '長崎県五島市以下に掲載がない場合');
ok($zip->set_number('8530001')->is_valid_number, '長崎県五島市栄町');
ok($zip->set_number('8530002')->is_valid_number, '長崎県五島市中央町');
ok($zip->set_number('8530003')->is_valid_number, '長崎県五島市錦町');
ok($zip->set_number('8530004')->is_valid_number, '長崎県五島市幸町');
ok($zip->set_number('8530005')->is_valid_number, '長崎県五島市末広町');
ok($zip->set_number('8530006')->is_valid_number, '長崎県五島市江川町');
ok($zip->set_number('8530007')->is_valid_number, '長崎県五島市福江町');
ok($zip->set_number('8530011')->is_valid_number, '長崎県五島市下大津町');
ok($zip->set_number('8530012')->is_valid_number, '長崎県五島市長手町');
ok($zip->set_number('8530013')->is_valid_number, '長崎県五島市上大津町');
ok($zip->set_number('8530014')->is_valid_number, '長崎県五島市三尾野町');
ok($zip->set_number('8530015')->is_valid_number, '長崎県五島市東浜町');
ok($zip->set_number('8530016')->is_valid_number, '長崎県五島市紺屋町');
ok($zip->set_number('8530017')->is_valid_number, '長崎県五島市武家屋敷');
ok($zip->set_number('8530018')->is_valid_number, '長崎県五島市池田町');
ok($zip->set_number('8530021')->is_valid_number, '長崎県五島市下崎山町');
ok($zip->set_number('8530022')->is_valid_number, '長崎県五島市向町');
ok($zip->set_number('8530023')->is_valid_number, '長崎県五島市上崎山町');
ok($zip->set_number('8530024')->is_valid_number, '長崎県五島市野々切町');
ok($zip->set_number('8530025')->is_valid_number, '長崎県五島市小泊町');
ok($zip->set_number('8530026')->is_valid_number, '長崎県五島市浜町');
ok($zip->set_number('8530027')->is_valid_number, '長崎県五島市増田町');
ok($zip->set_number('8530031')->is_valid_number, '長崎県五島市吉久木町');
ok($zip->set_number('8530032')->is_valid_number, '長崎県五島市大荒町');
ok($zip->set_number('8530033')->is_valid_number, '長崎県五島市木場町');
ok($zip->set_number('8530041')->is_valid_number, '長崎県五島市籠淵町');
ok($zip->set_number('8530042')->is_valid_number, '長崎県五島市吉田町');
ok($zip->set_number('8530043')->is_valid_number, '長崎県五島市高田町');
ok($zip->set_number('8530044')->is_valid_number, '長崎県五島市堤町');
ok($zip->set_number('8530051')->is_valid_number, '長崎県五島市平蔵町');
ok($zip->set_number('8530052')->is_valid_number, '長崎県五島市松山町');
ok($zip->set_number('8530053')->is_valid_number, '長崎県五島市奥浦町');
ok($zip->set_number('8530054')->is_valid_number, '長崎県五島市戸岐町');
ok($zip->set_number('8530061')->is_valid_number, '長崎県五島市黄島町');
ok($zip->set_number('8530062')->is_valid_number, '長崎県五島市赤島町');
ok($zip->set_number('8530063')->is_valid_number, '長崎県五島市新港町');
ok($zip->set_number('8530064')->is_valid_number, '長崎県五島市三尾野');
ok($zip->set_number('8530065')->is_valid_number, '長崎県五島市坂の上');
ok($zip->set_number('8530066')->is_valid_number, '長崎県五島市大円寺町');
ok($zip->set_number('8530201')->is_valid_number, '長崎県五島市富江町富江');
ok($zip->set_number('8530202')->is_valid_number, '長崎県五島市富江町松尾');
ok($zip->set_number('8530203')->is_valid_number, '長崎県五島市富江町田尾');
ok($zip->set_number('8530204')->is_valid_number, '長崎県五島市富江町繁敷');
ok($zip->set_number('8530205')->is_valid_number, '長崎県五島市富江町狩立');
ok($zip->set_number('8530206')->is_valid_number, '長崎県五島市富江町山手');
ok($zip->set_number('8530207')->is_valid_number, '長崎県五島市富江町長峰');
ok($zip->set_number('8530208')->is_valid_number, '長崎県五島市富江町黒島');
ok($zip->set_number('8530211')->is_valid_number, '長崎県五島市富江町黒瀬');
ok($zip->set_number('8530212')->is_valid_number, '長崎県五島市富江町山下');
ok($zip->set_number('8530213')->is_valid_number, '長崎県五島市富江町岳');
ok($zip->set_number('8530214')->is_valid_number, '長崎県五島市富江町土取');
ok($zip->set_number('8530215')->is_valid_number, '長崎県五島市富江町職人');
ok($zip->set_number('8530311')->is_valid_number, '長崎県五島市岐宿町二本楠');
ok($zip->set_number('8530312')->is_valid_number, '長崎県五島市岐宿町中嶽');
ok($zip->set_number('8530313')->is_valid_number, '長崎県五島市岐宿町松山');
ok($zip->set_number('8530411')->is_valid_number, '長崎県五島市玉之浦町玉之浦');
ok($zip->set_number('8530412')->is_valid_number, '長崎県五島市玉之浦町立谷');
ok($zip->set_number('8530413')->is_valid_number, '長崎県五島市玉之浦町大宝');
ok($zip->set_number('8530501')->is_valid_number, '長崎県五島市玉之浦町荒川');
ok($zip->set_number('8530502')->is_valid_number, '長崎県五島市玉之浦町幾久山');
ok($zip->set_number('8530503')->is_valid_number, '長崎県五島市玉之浦町小川');
ok($zip->set_number('8530504')->is_valid_number, '長崎県五島市玉之浦町丹奈');
ok($zip->set_number('8530505')->is_valid_number, '長崎県五島市玉之浦町中須');
ok($zip->set_number('8530506')->is_valid_number, '長崎県五島市玉之浦町上の平');
ok($zip->set_number('8530507')->is_valid_number, '長崎県五島市玉之浦町頓泊');
ok($zip->set_number('8530508')->is_valid_number, '長崎県五島市玉之浦町布浦');
ok($zip->set_number('8530601')->is_valid_number, '長崎県五島市三井楽町濱ノ畔');
ok($zip->set_number('8530602')->is_valid_number, '長崎県五島市三井楽町大川');
ok($zip->set_number('8530603')->is_valid_number, '長崎県五島市三井楽町柏');
ok($zip->set_number('8530604')->is_valid_number, '長崎県五島市三井楽町貝津');
ok($zip->set_number('8530605')->is_valid_number, '長崎県五島市三井楽町濱窄');
ok($zip->set_number('8530606')->is_valid_number, '長崎県五島市三井楽町丑ノ浦');
ok($zip->set_number('8530607')->is_valid_number, '長崎県五島市三井楽町嶽');
ok($zip->set_number('8530608')->is_valid_number, '長崎県五島市三井楽町波砂間');
ok($zip->set_number('8530609')->is_valid_number, '長崎県五島市三井楽町渕ノ元');
ok($zip->set_number('8530611')->is_valid_number, '長崎県五島市三井楽町嵯峨島');
ok($zip->set_number('8530612')->is_valid_number, '長崎県五島市三井楽町高崎');
ok($zip->set_number('8530613')->is_valid_number, '長崎県五島市三井楽町塩水');
ok($zip->set_number('8530701')->is_valid_number, '長崎県五島市岐宿町岐宿');
ok($zip->set_number('8530702')->is_valid_number, '長崎県五島市岐宿町川原');
ok($zip->set_number('8530703')->is_valid_number, '長崎県五島市岐宿町楠原');
ok($zip->set_number('8530704')->is_valid_number, '長崎県五島市岐宿町河務');
ok($zip->set_number('8530705')->is_valid_number, '長崎県五島市岐宿町戸岐ノ首');
ok($zip->set_number('8530706')->is_valid_number, '長崎県五島市岐宿町唐船ノ浦');
ok($zip->set_number('8532171')->is_valid_number, '長崎県五島市久賀町');
ok($zip->set_number('8532172')->is_valid_number, '長崎県五島市蕨町');
ok($zip->set_number('8532173')->is_valid_number, '長崎県五島市田ノ浦町');
ok($zip->set_number('8532174')->is_valid_number, '長崎県五島市猪之木町');
ok($zip->set_number('8532201')->is_valid_number, '長崎県五島市奈留町浦');
ok($zip->set_number('8532202')->is_valid_number, '長崎県五島市奈留町大串');
ok($zip->set_number('8532203')->is_valid_number, '長崎県五島市奈留町泊');
ok($zip->set_number('8532204')->is_valid_number, '長崎県五島市奈留町船廻');
ok($zip->set_number('8532301')->is_valid_number, '長崎県南松浦郡新上五島町若松郷');
ok($zip->set_number('8532302')->is_valid_number, '長崎県南松浦郡新上五島町桐古里郷');
ok($zip->set_number('8532303')->is_valid_number, '長崎県南松浦郡新上五島町宿ノ浦郷');
ok($zip->set_number('8532304')->is_valid_number, '長崎県南松浦郡新上五島町荒川郷');
ok($zip->set_number('8532305')->is_valid_number, '長崎県南松浦郡新上五島町西神ノ浦郷');
ok($zip->set_number('8532311')->is_valid_number, '長崎県南松浦郡新上五島町榊ノ浦郷');
ok($zip->set_number('8532312')->is_valid_number, '長崎県南松浦郡新上五島町日島郷');
ok($zip->set_number('8532313')->is_valid_number, '長崎県南松浦郡新上五島町有福郷');
ok($zip->set_number('8532314')->is_valid_number, '長崎県南松浦郡新上五島町漁生浦郷');
ok($zip->set_number('8532315')->is_valid_number, '長崎県南松浦郡新上五島町間伏郷');
ok($zip->set_number('8532481')->is_valid_number, '長崎県五島市伊福貴町');
ok($zip->set_number('8532482')->is_valid_number, '長崎県五島市本窯町');
ok($zip->set_number('8533101')->is_valid_number, '長崎県南松浦郡新上五島町奈良尾郷');
ok($zip->set_number('8533102')->is_valid_number, '長崎県南松浦郡新上五島町岩瀬浦郷');
ok($zip->set_number('8533321')->is_valid_number, '長崎県南松浦郡新上五島町鯛ノ浦郷');
ok($zip->set_number('8533322')->is_valid_number, '長崎県南松浦郡新上五島町阿瀬津郷');
ok($zip->set_number('8533323')->is_valid_number, '長崎県南松浦郡新上五島町東神ノ浦郷');
ok($zip->set_number('8540000')->is_valid_number, '長崎県諫早市以下に掲載がない場合');
ok($zip->set_number('8540001')->is_valid_number, '長崎県諫早市福田町');
ok($zip->set_number('8540002')->is_valid_number, '長崎県諫早市日の出町');
ok($zip->set_number('8540003')->is_valid_number, '長崎県諫早市泉町');
ok($zip->set_number('8540004')->is_valid_number, '長崎県諫早市金谷町');
ok($zip->set_number('8540005')->is_valid_number, '長崎県諫早市城見町');
ok($zip->set_number('8540006')->is_valid_number, '長崎県諫早市天満町');
ok($zip->set_number('8540007')->is_valid_number, '長崎県諫早市目代町');
ok($zip->set_number('8540011')->is_valid_number, '長崎県諫早市八天町');
ok($zip->set_number('8540012')->is_valid_number, '長崎県諫早市本町');
ok($zip->set_number('8540013')->is_valid_number, '長崎県諫早市栄町');
ok($zip->set_number('8540014')->is_valid_number, '長崎県諫早市東小路町');
ok($zip->set_number('8540015')->is_valid_number, '長崎県諫早市西小路町');
ok($zip->set_number('8540016')->is_valid_number, '長崎県諫早市高城町');
ok($zip->set_number('8540021')->is_valid_number, '長崎県諫早市仲沖町');
ok($zip->set_number('8540022')->is_valid_number, '長崎県諫早市幸町');
ok($zip->set_number('8540023')->is_valid_number, '長崎県諫早市厚生町');
ok($zip->set_number('8540024')->is_valid_number, '長崎県諫早市上町');
ok($zip->set_number('8540025')->is_valid_number, '長崎県諫早市八坂町');
ok($zip->set_number('8540026')->is_valid_number, '長崎県諫早市東本町');
ok($zip->set_number('8540027')->is_valid_number, '長崎県諫早市旭町');
ok($zip->set_number('8540031')->is_valid_number, '長崎県諫早市小野島町');
ok($zip->set_number('8540032')->is_valid_number, '長崎県諫早市赤崎町');
ok($zip->set_number('8540033')->is_valid_number, '長崎県諫早市黒崎町');
ok($zip->set_number('8540034')->is_valid_number, '長崎県諫早市小野町');
ok($zip->set_number('8540035')->is_valid_number, '長崎県諫早市宗方町');
ok($zip->set_number('8540036')->is_valid_number, '長崎県諫早市長野町');
ok($zip->set_number('8540037')->is_valid_number, '長崎県諫早市川内町');
ok($zip->set_number('8540038')->is_valid_number, '長崎県諫早市中央干拓');
ok($zip->set_number('8540041')->is_valid_number, '長崎県諫早市船越町');
ok($zip->set_number('8540042')->is_valid_number, '長崎県諫早市上野町');
ok($zip->set_number('8540043')->is_valid_number, '長崎県諫早市立石町');
ok($zip->set_number('8540044')->is_valid_number, '長崎県諫早市西郷町');
ok($zip->set_number('8540045')->is_valid_number, '長崎県諫早市新道町');
ok($zip->set_number('8540046')->is_valid_number, '長崎県諫早市原口町');
ok($zip->set_number('8540047')->is_valid_number, '長崎県諫早市野中町');
ok($zip->set_number('8540051')->is_valid_number, '長崎県諫早市鷲崎町');
ok($zip->set_number('8540052')->is_valid_number, '長崎県諫早市川床町');
ok($zip->set_number('8540053')->is_valid_number, '長崎県諫早市小川町');
ok($zip->set_number('8540054')->is_valid_number, '長崎県諫早市小ケ倉町');
ok($zip->set_number('8540055')->is_valid_number, '長崎県諫早市栗面町');
ok($zip->set_number('8540056')->is_valid_number, '長崎県諫早市土師野尾町');
ok($zip->set_number('8540057')->is_valid_number, '長崎県諫早市平山町');
ok($zip->set_number('8540061')->is_valid_number, '長崎県諫早市宇都町');
ok($zip->set_number('8540062')->is_valid_number, '長崎県諫早市小船越町');
ok($zip->set_number('8540063')->is_valid_number, '長崎県諫早市貝津町');
ok($zip->set_number('8540064')->is_valid_number, '長崎県諫早市若葉町');
ok($zip->set_number('8540065')->is_valid_number, '長崎県諫早市津久葉町');
ok($zip->set_number('8540066')->is_valid_number, '長崎県諫早市久山町');
ok($zip->set_number('8540067')->is_valid_number, '長崎県諫早市久山台');
ok($zip->set_number('8540068')->is_valid_number, '長崎県諫早市青葉台');
ok($zip->set_number('8540069')->is_valid_number, '長崎県諫早市貝津ヶ丘');
ok($zip->set_number('8540071')->is_valid_number, '長崎県諫早市永昌東町');
ok($zip->set_number('8540072')->is_valid_number, '長崎県諫早市永昌町');
ok($zip->set_number('8540073')->is_valid_number, '長崎県諫早市中尾町');
ok($zip->set_number('8540074')->is_valid_number, '長崎県諫早市山川町');
ok($zip->set_number('8540075')->is_valid_number, '長崎県諫早市馬渡町');
ok($zip->set_number('8540076')->is_valid_number, '長崎県諫早市堂崎町');
ok($zip->set_number('8540077')->is_valid_number, '長崎県諫早市白岩町');
ok($zip->set_number('8540081')->is_valid_number, '長崎県諫早市栄田町');
ok($zip->set_number('8540082')->is_valid_number, '長崎県諫早市西栄田町');
ok($zip->set_number('8540083')->is_valid_number, '長崎県諫早市津水町');
ok($zip->set_number('8540084')->is_valid_number, '長崎県諫早市真崎町');
ok($zip->set_number('8540085')->is_valid_number, '長崎県諫早市破籠井町');
ok($zip->set_number('8540086')->is_valid_number, '長崎県諫早市堀の内町');
ok($zip->set_number('8540087')->is_valid_number, '長崎県諫早市大さこ町');
ok($zip->set_number('8540091')->is_valid_number, '長崎県諫早市富川町');
ok($zip->set_number('8540092')->is_valid_number, '長崎県諫早市湯野尾町');
ok($zip->set_number('8540093')->is_valid_number, '長崎県諫早市本野町');
ok($zip->set_number('8540094')->is_valid_number, '長崎県諫早市本明町');
ok($zip->set_number('8540095')->is_valid_number, '長崎県諫早市上大渡野町');
ok($zip->set_number('8540096')->is_valid_number, '長崎県諫早市下大渡野町');
ok($zip->set_number('8540121')->is_valid_number, '長崎県諫早市有喜町');
ok($zip->set_number('8540122')->is_valid_number, '長崎県諫早市鶴田町');
ok($zip->set_number('8540123')->is_valid_number, '長崎県諫早市天神町');
ok($zip->set_number('8540124')->is_valid_number, '長崎県諫早市中通町');
ok($zip->set_number('8540125')->is_valid_number, '長崎県諫早市早見町');
ok($zip->set_number('8540126')->is_valid_number, '長崎県諫早市松里町');
ok($zip->set_number('8540201')->is_valid_number, '長崎県諫早市森山町下井牟田');
ok($zip->set_number('8540202')->is_valid_number, '長崎県諫早市森山町慶師野');
ok($zip->set_number('8540203')->is_valid_number, '長崎県諫早市森山町本村');
ok($zip->set_number('8540204')->is_valid_number, '長崎県諫早市森山町田尻');
ok($zip->set_number('8540205')->is_valid_number, '長崎県諫早市森山町杉谷');
ok($zip->set_number('8540206')->is_valid_number, '長崎県諫早市森山町唐比北');
ok($zip->set_number('8540207')->is_valid_number, '長崎県諫早市森山町唐比東');
ok($zip->set_number('8540208')->is_valid_number, '長崎県諫早市森山町唐比西');
ok($zip->set_number('8540209')->is_valid_number, '長崎県諫早市森山町上井牟田');
ok($zip->set_number('8540301')->is_valid_number, '長崎県雲仙市愛野町甲');
ok($zip->set_number('8540302')->is_valid_number, '長崎県雲仙市愛野町乙');
ok($zip->set_number('8540401')->is_valid_number, '長崎県雲仙市千々石町甲');
ok($zip->set_number('8540402')->is_valid_number, '長崎県雲仙市千々石町乙');
ok($zip->set_number('8540403')->is_valid_number, '長崎県雲仙市千々石町丙');
ok($zip->set_number('8540404')->is_valid_number, '長崎県雲仙市千々石町丁');
ok($zip->set_number('8540405')->is_valid_number, '長崎県雲仙市千々石町戊');
ok($zip->set_number('8540406')->is_valid_number, '長崎県雲仙市千々石町己');
ok($zip->set_number('8540407')->is_valid_number, '長崎県雲仙市千々石町庚');
ok($zip->set_number('8540500')->is_valid_number, '長崎県雲仙市以下に掲載がない場合');
ok($zip->set_number('8540501')->is_valid_number, '長崎県雲仙市小浜町大亀');
ok($zip->set_number('8540502')->is_valid_number, '長崎県雲仙市小浜町山畑');
ok($zip->set_number('8540503')->is_valid_number, '長崎県雲仙市小浜町飛子');
ok($zip->set_number('8540504')->is_valid_number, '長崎県雲仙市小浜町金浜');
ok($zip->set_number('8540505')->is_valid_number, '長崎県雲仙市小浜町木場');
ok($zip->set_number('8540511')->is_valid_number, '長崎県雲仙市小浜町南木指');
ok($zip->set_number('8540512')->is_valid_number, '長崎県雲仙市小浜町北木指');
ok($zip->set_number('8540513')->is_valid_number, '長崎県雲仙市小浜町南本町');
ok($zip->set_number('8540514')->is_valid_number, '長崎県雲仙市小浜町北本町');
ok($zip->set_number('8540515')->is_valid_number, '長崎県雲仙市小浜町北野');
ok($zip->set_number('8540516')->is_valid_number, '長崎県雲仙市小浜町富津');
ok($zip->set_number('8540517')->is_valid_number, '長崎県雲仙市小浜町マリーナ');
ok($zip->set_number('8540621')->is_valid_number, '長崎県雲仙市小浜町雲仙');
ok($zip->set_number('8540701')->is_valid_number, '長崎県雲仙市南串山町甲');
ok($zip->set_number('8540702')->is_valid_number, '長崎県雲仙市南串山町乙');
ok($zip->set_number('8540703')->is_valid_number, '長崎県雲仙市南串山町丙');
ok($zip->set_number('8541101')->is_valid_number, '長崎県諫早市飯盛町野中');
ok($zip->set_number('8541102')->is_valid_number, '長崎県諫早市飯盛町山口');
ok($zip->set_number('8541103')->is_valid_number, '長崎県諫早市飯盛町中山');
ok($zip->set_number('8541104')->is_valid_number, '長崎県諫早市飯盛町上原');
ok($zip->set_number('8541105')->is_valid_number, '長崎県諫早市飯盛町後田');
ok($zip->set_number('8541111')->is_valid_number, '長崎県諫早市飯盛町平古場');
ok($zip->set_number('8541112')->is_valid_number, '長崎県諫早市飯盛町開');
ok($zip->set_number('8541113')->is_valid_number, '長崎県諫早市飯盛町下釜');
ok($zip->set_number('8541114')->is_valid_number, '長崎県諫早市飯盛町久保');
ok($zip->set_number('8541121')->is_valid_number, '長崎県諫早市飯盛町古場');
ok($zip->set_number('8541122')->is_valid_number, '長崎県諫早市飯盛町佐田');
ok($zip->set_number('8541123')->is_valid_number, '長崎県諫早市飯盛町里');
ok($zip->set_number('8541124')->is_valid_number, '長崎県諫早市飯盛町川下');
ok($zip->set_number('8541125')->is_valid_number, '長崎県諫早市飯盛町池下');
ok($zip->set_number('8550000')->is_valid_number, '長崎県島原市以下に掲載がない場合');
ok($zip->set_number('8550001')->is_valid_number, '長崎県島原市中野町');
ok($zip->set_number('8550002')->is_valid_number, '長崎県島原市洗切町');
ok($zip->set_number('8550003')->is_valid_number, '長崎県島原市三会町');
ok($zip->set_number('8550004')->is_valid_number, '長崎県島原市亀の甲町');
ok($zip->set_number('8550005')->is_valid_number, '長崎県島原市中原町');
ok($zip->set_number('8550006')->is_valid_number, '長崎県島原市寺中町');
ok($zip->set_number('8550007')->is_valid_number, '長崎県島原市津吹町');
ok($zip->set_number('8550008')->is_valid_number, '長崎県島原市原口町');
ok($zip->set_number('8550011')->is_valid_number, '長崎県島原市御手水町');
ok($zip->set_number('8550012')->is_valid_number, '長崎県島原市大手原町');
ok($zip->set_number('8550013')->is_valid_number, '長崎県島原市稗田町');
ok($zip->set_number('8550014')->is_valid_number, '長崎県島原市下宮町');
ok($zip->set_number('8550015')->is_valid_number, '長崎県島原市出平町');
ok($zip->set_number('8550016')->is_valid_number, '長崎県島原市山寺町');
ok($zip->set_number('8550017')->is_valid_number, '長崎県島原市江里町');
ok($zip->set_number('8550018')->is_valid_number, '長崎県島原市西町');
ok($zip->set_number('8550021')->is_valid_number, '長崎県島原市油堀町');
ok($zip->set_number('8550022')->is_valid_number, '長崎県島原市長貫町');
ok($zip->set_number('8550023')->is_valid_number, '長崎県島原市出の川町');
ok($zip->set_number('8550024')->is_valid_number, '長崎県島原市広高野町');
ok($zip->set_number('8550025')->is_valid_number, '長崎県島原市立野町');
ok($zip->set_number('8550026')->is_valid_number, '長崎県島原市礫石原町');
ok($zip->set_number('8550031')->is_valid_number, '長崎県島原市前浜町');
ok($zip->set_number('8550032')->is_valid_number, '長崎県島原市北門町');
ok($zip->set_number('8550033')->is_valid_number, '長崎県島原市新馬場町');
ok($zip->set_number('8550034')->is_valid_number, '長崎県島原市田町');
ok($zip->set_number('8550035')->is_valid_number, '長崎県島原市先魁町');
ok($zip->set_number('8550036')->is_valid_number, '長崎県島原市城内');
ok($zip->set_number('8550038')->is_valid_number, '長崎県島原市島原市の次に番地がくる場合');
ok($zip->set_number('8550041')->is_valid_number, '長崎県島原市宮の町');
ok($zip->set_number('8550042')->is_valid_number, '長崎県島原市片町');
ok($zip->set_number('8550043')->is_valid_number, '長崎県島原市新田町');
ok($zip->set_number('8550044')->is_valid_number, '長崎県島原市中町');
ok($zip->set_number('8550045')->is_valid_number, '長崎県島原市上の町');
ok($zip->set_number('8550046')->is_valid_number, '長崎県島原市今川町');
ok($zip->set_number('8550051')->is_valid_number, '長崎県島原市桜門町');
ok($zip->set_number('8550052')->is_valid_number, '長崎県島原市下の丁');
ok($zip->set_number('8550053')->is_valid_number, '長崎県島原市城西中の丁');
ok($zip->set_number('8550054')->is_valid_number, '長崎県島原市古丁');
ok($zip->set_number('8550055')->is_valid_number, '長崎県島原市下新丁');
ok($zip->set_number('8550056')->is_valid_number, '長崎県島原市浦の川');
ok($zip->set_number('8550057')->is_valid_number, '長崎県島原市新建');
ok($zip->set_number('8550058')->is_valid_number, '長崎県島原市北原町');
ok($zip->set_number('8550059')->is_valid_number, '長崎県島原市江戸丁');
ok($zip->set_number('8550061')->is_valid_number, '長崎県島原市中尾町');
ok($zip->set_number('8550062')->is_valid_number, '長崎県島原市本町');
ok($zip->set_number('8550063')->is_valid_number, '長崎県島原市原町');
ok($zip->set_number('8550064')->is_valid_number, '長崎県島原市柏野町');
ok($zip->set_number('8550065')->is_valid_number, '長崎県島原市南柏野町');
ok($zip->set_number('8550066')->is_valid_number, '長崎県島原市柿の木町');
ok($zip->set_number('8550067')->is_valid_number, '長崎県島原市上新丁');
ok($zip->set_number('8550068')->is_valid_number, '長崎県島原市杉山町');
ok($zip->set_number('8550071')->is_valid_number, '長崎県島原市宇土町');
ok($zip->set_number('8550072')->is_valid_number, '長崎県島原市六ツ木町');
ok($zip->set_number('8550073')->is_valid_number, '長崎県島原市本光寺町');
ok($zip->set_number('8550074')->is_valid_number, '長崎県島原市城見町');
ok($zip->set_number('8550075')->is_valid_number, '長崎県島原市下折橋町');
ok($zip->set_number('8550076')->is_valid_number, '長崎県島原市上折橋町');
ok($zip->set_number('8550077')->is_valid_number, '長崎県島原市南千本木町');
ok($zip->set_number('8550078')->is_valid_number, '長崎県島原市北千本木町');
ok($zip->set_number('8550801')->is_valid_number, '長崎県島原市高島');
ok($zip->set_number('8550802')->is_valid_number, '長崎県島原市弁天町');
ok($zip->set_number('8550803')->is_valid_number, '長崎県島原市新町');
ok($zip->set_number('8550804')->is_valid_number, '長崎県島原市万町');
ok($zip->set_number('8550805')->is_valid_number, '長崎県島原市堀町');
ok($zip->set_number('8550806')->is_valid_number, '長崎県島原市中堀町');
ok($zip->set_number('8550807')->is_valid_number, '長崎県島原市白土町');
ok($zip->set_number('8550808')->is_valid_number, '長崎県島原市加美町');
ok($zip->set_number('8550809')->is_valid_number, '長崎県島原市桜町');
ok($zip->set_number('8550811')->is_valid_number, '長崎県島原市白土桃山');
ok($zip->set_number('8550812')->is_valid_number, '長崎県島原市霊南');
ok($zip->set_number('8550813')->is_valid_number, '長崎県島原市有馬船津町');
ok($zip->set_number('8550814')->is_valid_number, '長崎県島原市津町');
ok($zip->set_number('8550815')->is_valid_number, '長崎県島原市元船津町');
ok($zip->set_number('8550816')->is_valid_number, '長崎県島原市蛭子町');
ok($zip->set_number('8550817')->is_valid_number, '長崎県島原市浦田');
ok($zip->set_number('8550821')->is_valid_number, '長崎県島原市湊新地町');
ok($zip->set_number('8550822')->is_valid_number, '長崎県島原市中組町');
ok($zip->set_number('8550823')->is_valid_number, '長崎県島原市湊町');
ok($zip->set_number('8550824')->is_valid_number, '長崎県島原市白山町');
ok($zip->set_number('8550825')->is_valid_number, '長崎県島原市広馬場町');
ok($zip->set_number('8550831')->is_valid_number, '長崎県島原市湊道');
ok($zip->set_number('8550832')->is_valid_number, '長崎県島原市坂上町');
ok($zip->set_number('8550833')->is_valid_number, '長崎県島原市坂下町');
ok($zip->set_number('8550834')->is_valid_number, '長崎県島原市八幡町');
ok($zip->set_number('8550835')->is_valid_number, '長崎県島原市西八幡町');
ok($zip->set_number('8550836')->is_valid_number, '長崎県島原市湖南町');
ok($zip->set_number('8550841')->is_valid_number, '長崎県島原市崩山町');
ok($zip->set_number('8550842')->is_valid_number, '長崎県島原市栄町');
ok($zip->set_number('8550843')->is_valid_number, '長崎県島原市新山');
ok($zip->set_number('8550851')->is_valid_number, '長崎県島原市萩原');
ok($zip->set_number('8550852')->is_valid_number, '長崎県島原市寺町');
ok($zip->set_number('8550853')->is_valid_number, '長崎県島原市上の原');
ok($zip->set_number('8550854')->is_valid_number, '長崎県島原市萩が丘');
ok($zip->set_number('8550855')->is_valid_number, '長崎県島原市青葉町');
ok($zip->set_number('8550856')->is_valid_number, '長崎県島原市小山町');
ok($zip->set_number('8550861')->is_valid_number, '長崎県島原市下川尻町');
ok($zip->set_number('8550862')->is_valid_number, '長崎県島原市新湊');
ok($zip->set_number('8550863')->is_valid_number, '長崎県島原市親和町');
ok($zip->set_number('8550864')->is_valid_number, '長崎県島原市秩父が浦町');
ok($zip->set_number('8550865')->is_valid_number, '長崎県島原市船泊町');
ok($zip->set_number('8550866')->is_valid_number, '長崎県島原市南下川尻町');
ok($zip->set_number('8550867')->is_valid_number, '長崎県島原市緑町');
ok($zip->set_number('8550871')->is_valid_number, '長崎県島原市南崩山町');
ok($zip->set_number('8550872')->is_valid_number, '長崎県島原市梅園町');
ok($zip->set_number('8550873')->is_valid_number, '長崎県島原市北安徳町');
ok($zip->set_number('8550874')->is_valid_number, '長崎県島原市鎌田町');
ok($zip->set_number('8550875')->is_valid_number, '長崎県島原市中安徳町');
ok($zip->set_number('8550876')->is_valid_number, '長崎県島原市南安徳町');
ok($zip->set_number('8550877')->is_valid_number, '長崎県島原市浜の町');
ok($zip->set_number('8550878')->is_valid_number, '長崎県島原市大下町');
ok($zip->set_number('8550879')->is_valid_number, '長崎県島原市平成町');
ok($zip->set_number('8550881')->is_valid_number, '長崎県島原市門内町');
ok($zip->set_number('8550882')->is_valid_number, '長崎県島原市札の元町');
ok($zip->set_number('8550883')->is_valid_number, '長崎県島原市天神元町');
ok($zip->set_number('8550884')->is_valid_number, '長崎県島原市仁田町');
ok($zip->set_number('8550885')->is_valid_number, '長崎県島原市白谷町');
ok($zip->set_number('8550886')->is_valid_number, '長崎県島原市北上木場町');
ok($zip->set_number('8550887')->is_valid_number, '長崎県島原市南上木場町');
ok($zip->set_number('8560000')->is_valid_number, '長崎県大村市以下に掲載がない場合');
ok($zip->set_number('8560001')->is_valid_number, '長崎県大村市武留路町');
ok($zip->set_number('8560002')->is_valid_number, '長崎県大村市東野岳町');
ok($zip->set_number('8560003')->is_valid_number, '長崎県大村市野岳町');
ok($zip->set_number('8560004')->is_valid_number, '長崎県大村市立福寺町');
ok($zip->set_number('8560005')->is_valid_number, '長崎県大村市弥勒寺町');
ok($zip->set_number('8560006')->is_valid_number, '長崎県大村市福重町');
ok($zip->set_number('8560007')->is_valid_number, '長崎県大村市草場町');
ok($zip->set_number('8560008')->is_valid_number, '長崎県大村市松原');
ok($zip->set_number('8560009')->is_valid_number, '長崎県大村市松原本町');
ok($zip->set_number('8560011')->is_valid_number, '長崎県大村市重井田町');
ok($zip->set_number('8560012')->is_valid_number, '長崎県大村市黒木町');
ok($zip->set_number('8560013')->is_valid_number, '長崎県大村市中岳町');
ok($zip->set_number('8560014')->is_valid_number, '長崎県大村市田下町');
ok($zip->set_number('8560015')->is_valid_number, '長崎県大村市宮代町');
ok($zip->set_number('8560016')->is_valid_number, '長崎県大村市原町');
ok($zip->set_number('8560017')->is_valid_number, '長崎県大村市荒瀬町');
ok($zip->set_number('8560018')->is_valid_number, '長崎県大村市今富町');
ok($zip->set_number('8560019')->is_valid_number, '長崎県大村市野田町');
ok($zip->set_number('8560020')->is_valid_number, '長崎県大村市小路口本町');
ok($zip->set_number('8560021')->is_valid_number, '長崎県大村市鬼橋町');
ok($zip->set_number('8560022')->is_valid_number, '長崎県大村市雄ケ原町');
ok($zip->set_number('8560023')->is_valid_number, '長崎県大村市上諏訪町');
ok($zip->set_number('8560024')->is_valid_number, '長崎県大村市諏訪');
ok($zip->set_number('8560025')->is_valid_number, '長崎県大村市小路口町');
ok($zip->set_number('8560026')->is_valid_number, '長崎県大村市池田');
ok($zip->set_number('8560027')->is_valid_number, '長崎県大村市植松');
ok($zip->set_number('8560028')->is_valid_number, '長崎県大村市坂口町');
ok($zip->set_number('8560029')->is_valid_number, '長崎県大村市池田新町');
ok($zip->set_number('8560031')->is_valid_number, '長崎県大村市三城町');
ok($zip->set_number('8560032')->is_valid_number, '長崎県大村市東大村');
ok($zip->set_number('8560033')->is_valid_number, '長崎県大村市荒平町');
ok($zip->set_number('8560034')->is_valid_number, '長崎県大村市水計町');
ok($zip->set_number('8560035')->is_valid_number, '長崎県大村市武部町');
ok($zip->set_number('8560041')->is_valid_number, '長崎県大村市徳泉川内町');
ok($zip->set_number('8560042')->is_valid_number, '長崎県大村市平町');
ok($zip->set_number('8560043')->is_valid_number, '長崎県大村市小川内町');
ok($zip->set_number('8560044')->is_valid_number, '長崎県大村市岩松町');
ok($zip->set_number('8560045')->is_valid_number, '長崎県大村市向木場町');
ok($zip->set_number('8560046')->is_valid_number, '長崎県大村市木場');
ok($zip->set_number('8560047')->is_valid_number, '長崎県大村市須田ノ木町');
ok($zip->set_number('8560048')->is_valid_number, '長崎県大村市赤佐古町');
ok($zip->set_number('8560801')->is_valid_number, '長崎県大村市寿古町');
ok($zip->set_number('8560802')->is_valid_number, '長崎県大村市皆同町');
ok($zip->set_number('8560803')->is_valid_number, '長崎県大村市竹松町');
ok($zip->set_number('8560804')->is_valid_number, '長崎県大村市大川田町');
ok($zip->set_number('8560805')->is_valid_number, '長崎県大村市竹松本町');
ok($zip->set_number('8560806')->is_valid_number, '長崎県大村市富の原');
ok($zip->set_number('8560807')->is_valid_number, '長崎県大村市宮小路');
ok($zip->set_number('8560808')->is_valid_number, '長崎県大村市黒丸町');
ok($zip->set_number('8560809')->is_valid_number, '長崎県大村市沖田町');
ok($zip->set_number('8560811')->is_valid_number, '長崎県大村市原口町');
ok($zip->set_number('8560812')->is_valid_number, '長崎県大村市桜馬場');
ok($zip->set_number('8560813')->is_valid_number, '長崎県大村市西大村本町');
ok($zip->set_number('8560814')->is_valid_number, '長崎県大村市松並');
ok($zip->set_number('8560815')->is_valid_number, '長崎県大村市森園町');
ok($zip->set_number('8560816')->is_valid_number, '長崎県大村市箕島町');
ok($zip->set_number('8560817')->is_valid_number, '長崎県大村市古賀島町');
ok($zip->set_number('8560818')->is_valid_number, '長崎県大村市今津町');
ok($zip->set_number('8560820')->is_valid_number, '長崎県大村市協和町');
ok($zip->set_number('8560821')->is_valid_number, '長崎県大村市西乾馬場町');
ok($zip->set_number('8560822')->is_valid_number, '長崎県大村市古町');
ok($zip->set_number('8560823')->is_valid_number, '長崎県大村市乾馬場町');
ok($zip->set_number('8560824')->is_valid_number, '長崎県大村市水田町');
ok($zip->set_number('8560825')->is_valid_number, '長崎県大村市西三城町');
ok($zip->set_number('8560826')->is_valid_number, '長崎県大村市東三城町');
ok($zip->set_number('8560827')->is_valid_number, '長崎県大村市水主町');
ok($zip->set_number('8560828')->is_valid_number, '長崎県大村市杭出津');
ok($zip->set_number('8560829')->is_valid_number, '長崎県大村市松山町');
ok($zip->set_number('8560831')->is_valid_number, '長崎県大村市東本町');
ok($zip->set_number('8560832')->is_valid_number, '長崎県大村市本町');
ok($zip->set_number('8560833')->is_valid_number, '長崎県大村市片町');
ok($zip->set_number('8560834')->is_valid_number, '長崎県大村市玖島');
ok($zip->set_number('8560835')->is_valid_number, '長崎県大村市久原');
ok($zip->set_number('8560836')->is_valid_number, '長崎県大村市幸町');
ok($zip->set_number('8560837')->is_valid_number, '長崎県大村市西本町');
ok($zip->set_number('8560841')->is_valid_number, '長崎県大村市陰平町');
ok($zip->set_number('8560842')->is_valid_number, '長崎県大村市中里町');
ok($zip->set_number('8560843')->is_valid_number, '長崎県大村市今村町');
ok($zip->set_number('8560844')->is_valid_number, '長崎県大村市溝陸町');
ok($zip->set_number('8560845')->is_valid_number, '長崎県大村市大里町');
ok($zip->set_number('8560846')->is_valid_number, '長崎県大村市日泊町');
ok($zip->set_number('8560847')->is_valid_number, '長崎県大村市西部町');
ok($zip->set_number('8570000')->is_valid_number, '長崎県佐世保市以下に掲載がない場合');
ok($zip->set_number('8570001')->is_valid_number, '長崎県佐世保市烏帽子町');
ok($zip->set_number('8570011')->is_valid_number, '長崎県佐世保市春日町');
ok($zip->set_number('8570012')->is_valid_number, '長崎県佐世保市桜木町');
ok($zip->set_number('8570013')->is_valid_number, '長崎県佐世保市赤木町');
ok($zip->set_number('8570014')->is_valid_number, '長崎県佐世保市田代町');
ok($zip->set_number('8570015')->is_valid_number, '長崎県佐世保市松山町');
ok($zip->set_number('8570016')->is_valid_number, '長崎県佐世保市俵町');
ok($zip->set_number('8570017')->is_valid_number, '長崎県佐世保市梅田町');
ok($zip->set_number('8570018')->is_valid_number, '長崎県佐世保市横尾町');
ok($zip->set_number('8570021')->is_valid_number, '長崎県佐世保市折橋町');
ok($zip->set_number('8570022')->is_valid_number, '長崎県佐世保市山手町');
ok($zip->set_number('8570023')->is_valid_number, '長崎県佐世保市名切町');
ok($zip->set_number('8570024')->is_valid_number, '長崎県佐世保市花園町');
ok($zip->set_number('8570025')->is_valid_number, '長崎県佐世保市熊野町');
ok($zip->set_number('8570026')->is_valid_number, '長崎県佐世保市宮地町');
ok($zip->set_number('8570027')->is_valid_number, '長崎県佐世保市谷郷町');
ok($zip->set_number('8570028')->is_valid_number, '長崎県佐世保市八幡町');
ok($zip->set_number('8570031')->is_valid_number, '長崎県佐世保市保立町');
ok($zip->set_number('8570032')->is_valid_number, '長崎県佐世保市宮田町');
ok($zip->set_number('8570033')->is_valid_number, '長崎県佐世保市城山町');
ok($zip->set_number('8570034')->is_valid_number, '長崎県佐世保市万徳町');
ok($zip->set_number('8570035')->is_valid_number, '長崎県佐世保市福田町');
ok($zip->set_number('8570036')->is_valid_number, '長崎県佐世保市清水町');
ok($zip->set_number('8570037')->is_valid_number, '長崎県佐世保市石坂町');
ok($zip->set_number('8570038')->is_valid_number, '長崎県佐世保市中通町');
ok($zip->set_number('8570040')->is_valid_number, '長崎県佐世保市比良町');
ok($zip->set_number('8570041')->is_valid_number, '長崎県佐世保市木場田町');
ok($zip->set_number('8570042')->is_valid_number, '長崎県佐世保市高砂町');
ok($zip->set_number('8570043')->is_valid_number, '長崎県佐世保市天満町');
ok($zip->set_number('8570044')->is_valid_number, '長崎県佐世保市相生町');
ok($zip->set_number('8570045')->is_valid_number, '長崎県佐世保市園田町');
ok($zip->set_number('8570046')->is_valid_number, '長崎県佐世保市長尾町');
ok($zip->set_number('8570047')->is_valid_number, '長崎県佐世保市矢岳町');
ok($zip->set_number('8570048')->is_valid_number, '長崎県佐世保市西大久保町');
ok($zip->set_number('8570049')->is_valid_number, '長崎県佐世保市東大久保町');
ok($zip->set_number('8570051')->is_valid_number, '長崎県佐世保市浜田町');
ok($zip->set_number('8570052')->is_valid_number, '長崎県佐世保市松浦町');
ok($zip->set_number('8570053')->is_valid_number, '長崎県佐世保市常盤町');
ok($zip->set_number('8570054')->is_valid_number, '長崎県佐世保市栄町');
ok($zip->set_number('8570055')->is_valid_number, '長崎県佐世保市湊町');
ok($zip->set_number('8570056')->is_valid_number, '長崎県佐世保市平瀬町');
ok($zip->set_number('8570057')->is_valid_number, '長崎県佐世保市泉町');
ok($zip->set_number('8570058')->is_valid_number, '長崎県佐世保市上町');
ok($zip->set_number('8570059')->is_valid_number, '長崎県佐世保市元町');
ok($zip->set_number('8570061')->is_valid_number, '長崎県佐世保市今福町');
ok($zip->set_number('8570062')->is_valid_number, '長崎県佐世保市金比良町');
ok($zip->set_number('8570063')->is_valid_number, '長崎県佐世保市立神町');
ok($zip->set_number('8570064')->is_valid_number, '長崎県佐世保市赤崎町');
ok($zip->set_number('8570065')->is_valid_number, '長崎県佐世保市小野町(1200~1499番地)');
ok($zip->set_number('8570066')->is_valid_number, '長崎県佐世保市小島町');
ok($zip->set_number('8570067')->is_valid_number, '長崎県佐世保市神島町');
ok($zip->set_number('8570068')->is_valid_number, '長崎県佐世保市御船町');
ok($zip->set_number('8570069')->is_valid_number, '長崎県佐世保市鵜渡越町');
ok($zip->set_number('8570071')->is_valid_number, '長崎県長崎市池島町');
ok($zip->set_number('8570101')->is_valid_number, '長崎県佐世保市知見寺町');
ok($zip->set_number('8570102')->is_valid_number, '長崎県佐世保市松瀬町');
ok($zip->set_number('8570103')->is_valid_number, '長崎県佐世保市原分町');
ok($zip->set_number('8570104')->is_valid_number, '長崎県佐世保市楠木町');
ok($zip->set_number('8570105')->is_valid_number, '長崎県佐世保市白仁田町');
ok($zip->set_number('8570106')->is_valid_number, '長崎県佐世保市菰田町');
ok($zip->set_number('8570111')->is_valid_number, '長崎県佐世保市筒井町');
ok($zip->set_number('8570112')->is_valid_number, '長崎県佐世保市柚木町');
ok($zip->set_number('8570113')->is_valid_number, '長崎県佐世保市下宇戸町');
ok($zip->set_number('8570114')->is_valid_number, '長崎県佐世保市小舟町');
ok($zip->set_number('8570115')->is_valid_number, '長崎県佐世保市柚木元町');
ok($zip->set_number('8570121')->is_valid_number, '長崎県佐世保市潜木町');
ok($zip->set_number('8570122')->is_valid_number, '長崎県佐世保市里美町');
ok($zip->set_number('8570123')->is_valid_number, '長崎県佐世保市川谷町');
ok($zip->set_number('8570124')->is_valid_number, '長崎県佐世保市戸ケ倉町');
ok($zip->set_number('8570125')->is_valid_number, '長崎県佐世保市高花町');
ok($zip->set_number('8570126')->is_valid_number, '長崎県佐世保市上柚木町');
ok($zip->set_number('8570131')->is_valid_number, '長崎県佐世保市大野町');
ok($zip->set_number('8570132')->is_valid_number, '長崎県佐世保市松原町');
ok($zip->set_number('8570133')->is_valid_number, '長崎県佐世保市矢峰町');
ok($zip->set_number('8570134')->is_valid_number, '長崎県佐世保市瀬戸越');
ok($zip->set_number('8570135')->is_valid_number, '長崎県佐世保市瀬戸越町');
ok($zip->set_number('8570136')->is_valid_number, '長崎県佐世保市田原町');
ok($zip->set_number('8570141')->is_valid_number, '長崎県佐世保市十文野町');
ok($zip->set_number('8570142')->is_valid_number, '長崎県佐世保市野中町');
ok($zip->set_number('8570143')->is_valid_number, '長崎県佐世保市吉岡町');
ok($zip->set_number('8570144')->is_valid_number, '長崎県佐世保市皆瀬町');
ok($zip->set_number('8570145')->is_valid_number, '長崎県佐世保市牧の地町');
ok($zip->set_number('8570146')->is_valid_number, '長崎県佐世保市小川内町');
ok($zip->set_number('8570300')->is_valid_number, '長崎県北松浦郡佐々町以下に掲載がない場合');
ok($zip->set_number('8570311')->is_valid_number, '長崎県北松浦郡佐々町本田原免');
ok($zip->set_number('8570312')->is_valid_number, '長崎県北松浦郡佐々町市場免');
ok($zip->set_number('8570313')->is_valid_number, '長崎県北松浦郡佐々町鴨川免');
ok($zip->set_number('8570314')->is_valid_number, '長崎県北松浦郡佐々町古川免');
ok($zip->set_number('8570315')->is_valid_number, '長崎県北松浦郡佐々町志方免');
ok($zip->set_number('8570321')->is_valid_number, '長崎県北松浦郡佐々町市瀬免');
ok($zip->set_number('8570322')->is_valid_number, '長崎県北松浦郡佐々町松瀬免');
ok($zip->set_number('8570323')->is_valid_number, '長崎県北松浦郡佐々町江里免');
ok($zip->set_number('8570324')->is_valid_number, '長崎県北松浦郡佐々町大茂免');
ok($zip->set_number('8570331')->is_valid_number, '長崎県北松浦郡佐々町野寄免');
ok($zip->set_number('8570332')->is_valid_number, '長崎県北松浦郡佐々町栗林免');
ok($zip->set_number('8570333')->is_valid_number, '長崎県北松浦郡佐々町中川原免');
ok($zip->set_number('8570334')->is_valid_number, '長崎県北松浦郡佐々町石木場免');
ok($zip->set_number('8570335')->is_valid_number, '長崎県北松浦郡佐々町皆瀬免');
ok($zip->set_number('8570336')->is_valid_number, '長崎県北松浦郡佐々町神田免');
ok($zip->set_number('8570337')->is_valid_number, '長崎県北松浦郡佐々町八口免');
ok($zip->set_number('8570338')->is_valid_number, '長崎県北松浦郡佐々町角山免');
ok($zip->set_number('8570341')->is_valid_number, '長崎県北松浦郡佐々町羽須和免');
ok($zip->set_number('8570342')->is_valid_number, '長崎県北松浦郡佐々町平野免');
ok($zip->set_number('8570343')->is_valid_number, '長崎県北松浦郡佐々町木場免');
ok($zip->set_number('8570344')->is_valid_number, '長崎県北松浦郡佐々町迎木場免');
ok($zip->set_number('8570351')->is_valid_number, '長崎県北松浦郡佐々町須崎免');
ok($zip->set_number('8570352')->is_valid_number, '長崎県北松浦郡佐々町口石免');
ok($zip->set_number('8570353')->is_valid_number, '長崎県北松浦郡佐々町沖田免');
ok($zip->set_number('8570361')->is_valid_number, '長崎県北松浦郡佐々町小浦免');
ok($zip->set_number('8570401')->is_valid_number, '長崎県佐世保市小佐々町黒石');
ok($zip->set_number('8570402')->is_valid_number, '長崎県佐世保市小佐々町小坂');
ok($zip->set_number('8570403')->is_valid_number, '長崎県佐世保市小佐々町臼ノ浦');
ok($zip->set_number('8570404')->is_valid_number, '長崎県佐世保市小佐々町田原');
ok($zip->set_number('8570405')->is_valid_number, '長崎県佐世保市小佐々町葛籠');
ok($zip->set_number('8570406')->is_valid_number, '長崎県佐世保市小佐々町平原');
ok($zip->set_number('8570411')->is_valid_number, '長崎県佐世保市小佐々町岳ノ木場');
ok($zip->set_number('8570412')->is_valid_number, '長崎県佐世保市小佐々町西川内');
ok($zip->set_number('8570413')->is_valid_number, '長崎県佐世保市小佐々町楠泊');
ok($zip->set_number('8570414')->is_valid_number, '長崎県佐世保市小佐々町矢岳');
ok($zip->set_number('8570431')->is_valid_number, '長崎県佐世保市浅子町');
ok($zip->set_number('8570801')->is_valid_number, '長崎県佐世保市祇園町');
ok($zip->set_number('8570802')->is_valid_number, '長崎県佐世保市高天町');
ok($zip->set_number('8570803')->is_valid_number, '長崎県佐世保市勝富町');
ok($zip->set_number('8570804')->is_valid_number, '長崎県佐世保市松川町');
ok($zip->set_number('8570805')->is_valid_number, '長崎県佐世保市光月町');
ok($zip->set_number('8570806')->is_valid_number, '長崎県佐世保市島瀬町');
ok($zip->set_number('8570811')->is_valid_number, '長崎県佐世保市高梨町');
ok($zip->set_number('8570812')->is_valid_number, '長崎県佐世保市須佐町');
ok($zip->set_number('8570813')->is_valid_number, '長崎県佐世保市小佐世保町');
ok($zip->set_number('8570821')->is_valid_number, '長崎県佐世保市白木町');
ok($zip->set_number('8570822')->is_valid_number, '長崎県佐世保市山祇町');
ok($zip->set_number('8570831')->is_valid_number, '長崎県佐世保市須田尾町');
ok($zip->set_number('8570832')->is_valid_number, '長崎県佐世保市藤原町');
ok($zip->set_number('8570833')->is_valid_number, '長崎県佐世保市若葉町');
ok($zip->set_number('8570834')->is_valid_number, '長崎県佐世保市潮見町');
ok($zip->set_number('8570841')->is_valid_number, '長崎県佐世保市大宮町');
ok($zip->set_number('8570842')->is_valid_number, '長崎県佐世保市東山町');
ok($zip->set_number('8570843')->is_valid_number, '長崎県佐世保市大黒町');
ok($zip->set_number('8570851')->is_valid_number, '長崎県佐世保市稲荷町');
ok($zip->set_number('8570852')->is_valid_number, '長崎県佐世保市干尽町');
ok($zip->set_number('8570853')->is_valid_number, '長崎県佐世保市前畑町');
ok($zip->set_number('8570854')->is_valid_number, '長崎県佐世保市福石町');
ok($zip->set_number('8570855')->is_valid_number, '長崎県佐世保市新港町');
ok($zip->set_number('8570861')->is_valid_number, '長崎県佐世保市峰坂町');
ok($zip->set_number('8570862')->is_valid_number, '長崎県佐世保市白南風町');
ok($zip->set_number('8570863')->is_valid_number, '長崎県佐世保市三浦町');
ok($zip->set_number('8570864')->is_valid_number, '長崎県佐世保市戸尾町');
ok($zip->set_number('8570871')->is_valid_number, '長崎県佐世保市本島町');
ok($zip->set_number('8570872')->is_valid_number, '長崎県佐世保市上京町');
ok($zip->set_number('8570873')->is_valid_number, '長崎県佐世保市宮崎町');
ok($zip->set_number('8570874')->is_valid_number, '長崎県佐世保市京坪町');
ok($zip->set_number('8570875')->is_valid_number, '長崎県佐世保市下京町');
ok($zip->set_number('8570876')->is_valid_number, '長崎県佐世保市塩浜町');
ok($zip->set_number('8570877')->is_valid_number, '長崎県佐世保市万津町');
ok($zip->set_number('8570878')->is_valid_number, '長崎県佐世保市山県町');
ok($zip->set_number('8570879')->is_valid_number, '長崎県佐世保市島地町');
ok($zip->set_number('8571151')->is_valid_number, '長崎県佐世保市日宇町');
ok($zip->set_number('8571152')->is_valid_number, '長崎県佐世保市黒髪町');
ok($zip->set_number('8571153')->is_valid_number, '長崎県佐世保市もみじが丘町');
ok($zip->set_number('8571161')->is_valid_number, '長崎県佐世保市大塔町');
ok($zip->set_number('8571162')->is_valid_number, '長崎県佐世保市卸本町');
ok($zip->set_number('8571163')->is_valid_number, '長崎県佐世保市大岳台町');
ok($zip->set_number('8571164')->is_valid_number, '長崎県佐世保市白岳町');
ok($zip->set_number('8571165')->is_valid_number, '長崎県佐世保市大和町');
ok($zip->set_number('8571166')->is_valid_number, '長崎県佐世保市木風町');
ok($zip->set_number('8571167')->is_valid_number, '長崎県佐世保市ひうみ町');
ok($zip->set_number('8571171')->is_valid_number, '長崎県佐世保市沖新町');
ok($zip->set_number('8571172')->is_valid_number, '長崎県佐世保市東浜町');
ok($zip->set_number('8571173')->is_valid_number, '長崎県佐世保市十郎新町');
ok($zip->set_number('8571174')->is_valid_number, '長崎県佐世保市天神');
ok($zip->set_number('8571175')->is_valid_number, '長崎県佐世保市天神町');
ok($zip->set_number('8571176')->is_valid_number, '長崎県佐世保市崎辺町');
ok($zip->set_number('8571231')->is_valid_number, '長崎県佐世保市船越町');
ok($zip->set_number('8571232')->is_valid_number, '長崎県佐世保市下船越町');
ok($zip->set_number('8571233')->is_valid_number, '長崎県佐世保市庵浦町');
ok($zip->set_number('8571234')->is_valid_number, '長崎県佐世保市野崎町');
ok($zip->set_number('8571235')->is_valid_number, '長崎県佐世保市俵ケ浦町');
ok($zip->set_number('8572221')->is_valid_number, '長崎県西海市西海町中浦南郷');
ok($zip->set_number('8572222')->is_valid_number, '長崎県西海市西海町中浦北郷');
ok($zip->set_number('8572223')->is_valid_number, '長崎県西海市西海町七釜郷');
ok($zip->set_number('8572301')->is_valid_number, '長崎県西海市大瀬戸町瀬戸板浦郷');
ok($zip->set_number('8572302')->is_valid_number, '長崎県西海市大瀬戸町瀬戸樫浦郷');
ok($zip->set_number('8572303')->is_valid_number, '長崎県西海市大瀬戸町瀬戸西濱郷');
ok($zip->set_number('8572304')->is_valid_number, '長崎県西海市大瀬戸町瀬戸下山郷');
ok($zip->set_number('8572305')->is_valid_number, '長崎県西海市大瀬戸町瀬戸羽出川郷');
ok($zip->set_number('8572306')->is_valid_number, '長崎県西海市大瀬戸町瀬戸東濱郷');
ok($zip->set_number('8572307')->is_valid_number, '長崎県西海市大瀬戸町瀬戸福島郷');
ok($zip->set_number('8572311')->is_valid_number, '長崎県西海市大瀬戸町多以良外郷');
ok($zip->set_number('8572312')->is_valid_number, '長崎県西海市大瀬戸町多以良内郷');
ok($zip->set_number('8572321')->is_valid_number, '長崎県西海市大瀬戸町雪浦幸物郷');
ok($zip->set_number('8572322')->is_valid_number, '長崎県西海市大瀬戸町雪浦久良木郷');
ok($zip->set_number('8572323')->is_valid_number, '長崎県西海市大瀬戸町雪浦河通郷');
ok($zip->set_number('8572324')->is_valid_number, '長崎県西海市大瀬戸町雪浦奥浦郷');
ok($zip->set_number('8572325')->is_valid_number, '長崎県西海市大瀬戸町雪浦小松郷');
ok($zip->set_number('8572326')->is_valid_number, '長崎県西海市大瀬戸町雪浦下郷');
ok($zip->set_number('8572327')->is_valid_number, '長崎県西海市大瀬戸町雪浦上郷');
ok($zip->set_number('8572328')->is_valid_number, '長崎県西海市大瀬戸町雪浦下釜郷');
ok($zip->set_number('8572401')->is_valid_number, '長崎県西海市大島町黒瀬');
ok($zip->set_number('8572402')->is_valid_number, '長崎県西海市大島町内浦地区');
ok($zip->set_number('8572403')->is_valid_number, '長崎県西海市大島町馬込');
ok($zip->set_number('8572405')->is_valid_number, '長崎県西海市大島町中央地区');
ok($zip->set_number('8572411')->is_valid_number, '長崎県西海市大島町寺島');
ok($zip->set_number('8572412')->is_valid_number, '長崎県西海市大島町真砂');
ok($zip->set_number('8572413')->is_valid_number, '長崎県西海市大島町間瀬');
ok($zip->set_number('8572417')->is_valid_number, '長崎県西海市大島町百合が丘');
ok($zip->set_number('8572418')->is_valid_number, '長崎県西海市大島町徳万');
ok($zip->set_number('8572419')->is_valid_number, '長崎県西海市大島町蛤');
ok($zip->set_number('8572421')->is_valid_number, '長崎県西海市大島町中戸');
ok($zip->set_number('8572422')->is_valid_number, '長崎県西海市大島町太田尾');
ok($zip->set_number('8572423')->is_valid_number, '長崎県西海市大島町塔尾');
ok($zip->set_number('8572424')->is_valid_number, '長崎県西海市大島町塩田');
ok($zip->set_number('8572425')->is_valid_number, '長崎県西海市大島町田浦');
ok($zip->set_number('8572426')->is_valid_number, '長崎県西海市大島町大島');
ok($zip->set_number('8572427')->is_valid_number, '長崎県西海市大島町の次に番地がくる場合');
ok($zip->set_number('8572531')->is_valid_number, '長崎県西海市大瀬戸町松島内郷');
ok($zip->set_number('8572532')->is_valid_number, '長崎県西海市大瀬戸町松島外郷');
ok($zip->set_number('8573101')->is_valid_number, '長崎県西海市崎戸町蠣浦郷');
ok($zip->set_number('8573102')->is_valid_number, '長崎県西海市崎戸町本郷');
ok($zip->set_number('8573103')->is_valid_number, '長崎県西海市崎戸町江島');
ok($zip->set_number('8573271')->is_valid_number, '長崎県佐世保市黒島町');
ok($zip->set_number('8573311')->is_valid_number, '長崎県西海市崎戸町平島');
ok($zip->set_number('8574101')->is_valid_number, '長崎県南松浦郡新上五島町赤尾郷');
ok($zip->set_number('8574102')->is_valid_number, '長崎県南松浦郡新上五島町友住郷');
ok($zip->set_number('8574103')->is_valid_number, '長崎県南松浦郡新上五島町江ノ浜郷');
ok($zip->set_number('8574211')->is_valid_number, '長崎県南松浦郡新上五島町有川郷');
ok($zip->set_number('8574212')->is_valid_number, '長崎県南松浦郡新上五島町小河原郷');
ok($zip->set_number('8574213')->is_valid_number, '長崎県南松浦郡新上五島町太田郷');
ok($zip->set_number('8574214')->is_valid_number, '長崎県南松浦郡新上五島町七目郷');
ok($zip->set_number('8574400')->is_valid_number, '長崎県南松浦郡新上五島町以下に掲載がない場合');
ok($zip->set_number('8574401')->is_valid_number, '長崎県南松浦郡新上五島町網上郷');
ok($zip->set_number('8574402')->is_valid_number, '長崎県南松浦郡新上五島町奈摩郷');
ok($zip->set_number('8574404')->is_valid_number, '長崎県南松浦郡新上五島町青方郷');
ok($zip->set_number('8574405')->is_valid_number, '長崎県南松浦郡新上五島町船崎郷');
ok($zip->set_number('8574411')->is_valid_number, '長崎県南松浦郡新上五島町相河郷');
ok($zip->set_number('8574412')->is_valid_number, '長崎県南松浦郡新上五島町三日ノ浦郷');
ok($zip->set_number('8574413')->is_valid_number, '長崎県南松浦郡新上五島町今里郷');
ok($zip->set_number('8574414')->is_valid_number, '長崎県南松浦郡新上五島町飯ノ瀬戸郷');
ok($zip->set_number('8574415')->is_valid_number, '長崎県南松浦郡新上五島町続浜ノ浦郷');
ok($zip->set_number('8574416')->is_valid_number, '長崎県南松浦郡新上五島町道土井郷');
ok($zip->set_number('8574511')->is_valid_number, '長崎県南松浦郡新上五島町浦桑郷');
ok($zip->set_number('8574512')->is_valid_number, '長崎県南松浦郡新上五島町榎津郷');
ok($zip->set_number('8574513')->is_valid_number, '長崎県南松浦郡新上五島町丸尾郷');
ok($zip->set_number('8574514')->is_valid_number, '長崎県南松浦郡新上五島町似首郷');
ok($zip->set_number('8574601')->is_valid_number, '長崎県南松浦郡新上五島町小串郷');
ok($zip->set_number('8574602')->is_valid_number, '長崎県南松浦郡新上五島町曽根郷');
ok($zip->set_number('8574603')->is_valid_number, '長崎県南松浦郡新上五島町立串郷');
ok($zip->set_number('8574604')->is_valid_number, '長崎県南松浦郡新上五島町津和崎郷');
ok($zip->set_number('8574700')->is_valid_number, '長崎県北松浦郡小値賀町以下に掲載がない場合');
ok($zip->set_number('8574701')->is_valid_number, '長崎県北松浦郡小値賀町笛吹郷');
ok($zip->set_number('8574702')->is_valid_number, '長崎県北松浦郡小値賀町前方郷');
ok($zip->set_number('8574703')->is_valid_number, '長崎県北松浦郡小値賀町中村郷');
ok($zip->set_number('8574704')->is_valid_number, '長崎県北松浦郡小値賀町柳郷');
ok($zip->set_number('8574705')->is_valid_number, '長崎県北松浦郡小値賀町浜津郷');
ok($zip->set_number('8574706')->is_valid_number, '長崎県北松浦郡小値賀町黒島郷');
ok($zip->set_number('8574707')->is_valid_number, '長崎県北松浦郡小値賀町班島郷');
ok($zip->set_number('8574708')->is_valid_number, '長崎県北松浦郡小値賀町大島郷');
ok($zip->set_number('8574709')->is_valid_number, '長崎県北松浦郡小値賀町野崎郷');
ok($zip->set_number('8574711')->is_valid_number, '長崎県北松浦郡小値賀町納島郷');
ok($zip->set_number('8574712')->is_valid_number, '長崎県北松浦郡小値賀町六島郷');
ok($zip->set_number('8574811')->is_valid_number, '長崎県佐世保市宇久町神浦');
ok($zip->set_number('8574812')->is_valid_number, '長崎県佐世保市宇久町小浜');
ok($zip->set_number('8574813')->is_valid_number, '長崎県佐世保市宇久町飯良');
ok($zip->set_number('8574814')->is_valid_number, '長崎県佐世保市宇久町本飯良');
ok($zip->set_number('8574815')->is_valid_number, '長崎県佐世保市宇久町大久保');
ok($zip->set_number('8574816')->is_valid_number, '長崎県佐世保市宇久町寺島');
ok($zip->set_number('8574901')->is_valid_number, '長崎県佐世保市宇久町平');
ok($zip->set_number('8574902')->is_valid_number, '長崎県佐世保市宇久町野方');
ok($zip->set_number('8574903')->is_valid_number, '長崎県佐世保市宇久町太田江');
ok($zip->set_number('8574904')->is_valid_number, '長崎県佐世保市宇久町木場');
ok($zip->set_number('8580901')->is_valid_number, '長崎県佐世保市岳野町');
ok($zip->set_number('8580902')->is_valid_number, '長崎県佐世保市踊石町');
ok($zip->set_number('8580903')->is_valid_number, '長崎県佐世保市上本山町');
ok($zip->set_number('8580904')->is_valid_number, '長崎県佐世保市中里町');
ok($zip->set_number('8580905')->is_valid_number, '長崎県佐世保市下本山町');
ok($zip->set_number('8580906')->is_valid_number, '長崎県佐世保市八の久保町');
ok($zip->set_number('8580907')->is_valid_number, '長崎県佐世保市棚方町');
ok($zip->set_number('8580908')->is_valid_number, '長崎県佐世保市光町');
ok($zip->set_number('8580911')->is_valid_number, '長崎県佐世保市竹辺町');
ok($zip->set_number('8580912')->is_valid_number, '長崎県佐世保市母ケ浦町');
ok($zip->set_number('8580913')->is_valid_number, '長崎県佐世保市新田町');
ok($zip->set_number('8580914')->is_valid_number, '長崎県佐世保市川下町');
ok($zip->set_number('8580915')->is_valid_number, '長崎県佐世保市上相浦町');
ok($zip->set_number('8580916')->is_valid_number, '長崎県佐世保市木宮町');
ok($zip->set_number('8580917')->is_valid_number, '長崎県佐世保市愛宕町');
ok($zip->set_number('8580918')->is_valid_number, '長崎県佐世保市相浦町');
ok($zip->set_number('8580921')->is_valid_number, '長崎県佐世保市長坂町');
ok($zip->set_number('8580922')->is_valid_number, '長崎県佐世保市鹿子前町');
ok($zip->set_number('8580923')->is_valid_number, '長崎県佐世保市日野町');
ok($zip->set_number('8580924')->is_valid_number, '長崎県佐世保市星和台町');
ok($zip->set_number('8580925')->is_valid_number, '長崎県佐世保市椎木町');
ok($zip->set_number('8580926')->is_valid_number, '長崎県佐世保市大潟町');
ok($zip->set_number('8580931')->is_valid_number, '長崎県佐世保市高島町');
ok($zip->set_number('8580965')->is_valid_number, '長崎県佐世保市小野町(その他)');
ok($zip->set_number('8590101')->is_valid_number, '長崎県諫早市高来町大戸');
ok($zip->set_number('8590102')->is_valid_number, '長崎県諫早市高来町折山');
ok($zip->set_number('8590103')->is_valid_number, '長崎県諫早市高来町古場');
ok($zip->set_number('8590104')->is_valid_number, '長崎県諫早市高来町建山');
ok($zip->set_number('8590105')->is_valid_number, '長崎県諫早市高来町船津');
ok($zip->set_number('8590106')->is_valid_number, '長崎県諫早市高来町冨地戸');
ok($zip->set_number('8590111')->is_valid_number, '長崎県諫早市高来町上与');
ok($zip->set_number('8590112')->is_valid_number, '長崎県諫早市高来町小船津');
ok($zip->set_number('8590113')->is_valid_number, '長崎県諫早市高来町下与');
ok($zip->set_number('8590114')->is_valid_number, '長崎県諫早市高来町西平原');
ok($zip->set_number('8590115')->is_valid_number, '長崎県諫早市高来町西尾');
ok($zip->set_number('8590116')->is_valid_number, '長崎県諫早市高来町平田');
ok($zip->set_number('8590117')->is_valid_number, '長崎県諫早市高来町峰');
ok($zip->set_number('8590121')->is_valid_number, '長崎県諫早市高来町泉');
ok($zip->set_number('8590122')->is_valid_number, '長崎県諫早市高来町黒崎');
ok($zip->set_number('8590123')->is_valid_number, '長崎県諫早市高来町小峰');
ok($zip->set_number('8590124')->is_valid_number, '長崎県諫早市高来町里');
ok($zip->set_number('8590125')->is_valid_number, '長崎県諫早市高来町善住寺');
ok($zip->set_number('8590126')->is_valid_number, '長崎県諫早市高来町法川');
ok($zip->set_number('8590127')->is_valid_number, '長崎県諫早市高来町町名');
ok($zip->set_number('8590131')->is_valid_number, '長崎県諫早市高来町神津倉');
ok($zip->set_number('8590132')->is_valid_number, '長崎県諫早市高来町三部壱');
ok($zip->set_number('8590133')->is_valid_number, '長崎県諫早市高来町東平原');
ok($zip->set_number('8590141')->is_valid_number, '長崎県諫早市高来町汲水');
ok($zip->set_number('8590142')->is_valid_number, '長崎県諫早市高来町黒新田');
ok($zip->set_number('8590143')->is_valid_number, '長崎県諫早市高来町坂元');
ok($zip->set_number('8590144')->is_valid_number, '長崎県諫早市高来町溝口');
ok($zip->set_number('8590145')->is_valid_number, '長崎県諫早市高来町山道');
ok($zip->set_number('8590146')->is_valid_number, '長崎県諫早市高来町金崎');
ok($zip->set_number('8590147')->is_valid_number, '長崎県諫早市高来町水ノ浦');
ok($zip->set_number('8590151')->is_valid_number, '長崎県諫早市小長井町打越');
ok($zip->set_number('8590152')->is_valid_number, '長崎県諫早市小長井町大搦');
ok($zip->set_number('8590153')->is_valid_number, '長崎県諫早市小長井町大峰');
ok($zip->set_number('8590154')->is_valid_number, '長崎県諫早市小長井町川内');
ok($zip->set_number('8590161')->is_valid_number, '長崎県諫早市小長井町古場');
ok($zip->set_number('8590162')->is_valid_number, '長崎県諫早市小長井町新田原');
ok($zip->set_number('8590163')->is_valid_number, '長崎県諫早市小長井町田原');
ok($zip->set_number('8590164')->is_valid_number, '長崎県諫早市小長井町牧');
ok($zip->set_number('8590165')->is_valid_number, '長崎県諫早市小長井町小川原浦');
ok($zip->set_number('8590166')->is_valid_number, '長崎県諫早市小長井町井崎');
ok($zip->set_number('8590167')->is_valid_number, '長崎県諫早市小長井町遠竹');
ok($zip->set_number('8590171')->is_valid_number, '長崎県諫早市高来町小江干拓');
ok($zip->set_number('8590301')->is_valid_number, '長崎県諫早市長田町');
ok($zip->set_number('8590302')->is_valid_number, '長崎県諫早市正久寺町');
ok($zip->set_number('8590303')->is_valid_number, '長崎県諫早市高天町');
ok($zip->set_number('8590304')->is_valid_number, '長崎県諫早市白浜町');
ok($zip->set_number('8590305')->is_valid_number, '長崎県諫早市猿崎町');
ok($zip->set_number('8590306')->is_valid_number, '長崎県諫早市白原町');
ok($zip->set_number('8590307')->is_valid_number, '長崎県諫早市白木峰町');
ok($zip->set_number('8590311')->is_valid_number, '長崎県諫早市小豆崎町');
ok($zip->set_number('8590312')->is_valid_number, '長崎県諫早市西里町');
ok($zip->set_number('8590313')->is_valid_number, '長崎県諫早市中田町');
ok($zip->set_number('8590314')->is_valid_number, '長崎県諫早市御手水町');
ok($zip->set_number('8590315')->is_valid_number, '長崎県諫早市大場町');
ok($zip->set_number('8590401')->is_valid_number, '長崎県諫早市多良見町化屋');
ok($zip->set_number('8590402')->is_valid_number, '長崎県諫早市多良見町囲');
ok($zip->set_number('8590403')->is_valid_number, '長崎県諫早市多良見町市布');
ok($zip->set_number('8590404')->is_valid_number, '長崎県諫早市多良見町西川内');
ok($zip->set_number('8590405')->is_valid_number, '長崎県諫早市多良見町中里');
ok($zip->set_number('8590406')->is_valid_number, '長崎県諫早市多良見町木床');
ok($zip->set_number('8590407')->is_valid_number, '長崎県諫早市多良見町シーサイド');
ok($zip->set_number('8590411')->is_valid_number, '長崎県諫早市多良見町東園');
ok($zip->set_number('8590412')->is_valid_number, '長崎県諫早市多良見町西園');
ok($zip->set_number('8590413')->is_valid_number, '長崎県諫早市多良見町野副');
ok($zip->set_number('8590414')->is_valid_number, '長崎県諫早市多良見町元釜');
ok($zip->set_number('8590415')->is_valid_number, '長崎県諫早市多良見町山川内');
ok($zip->set_number('8590416')->is_valid_number, '長崎県諫早市多良見町野川内');
ok($zip->set_number('8590417')->is_valid_number, '長崎県諫早市多良見町舟津');
ok($zip->set_number('8590418')->is_valid_number, '長崎県諫早市多良見町佐瀬');
ok($zip->set_number('8591101')->is_valid_number, '長崎県雲仙市吾妻町本村名');
ok($zip->set_number('8591102')->is_valid_number, '長崎県雲仙市吾妻町木場名');
ok($zip->set_number('8591103')->is_valid_number, '長崎県雲仙市吾妻町平江名');
ok($zip->set_number('8591104')->is_valid_number, '長崎県雲仙市吾妻町古城名');
ok($zip->set_number('8591105')->is_valid_number, '長崎県雲仙市吾妻町田之平名');
ok($zip->set_number('8591106')->is_valid_number, '長崎県雲仙市吾妻町大木場名');
ok($zip->set_number('8591107')->is_valid_number, '長崎県雲仙市吾妻町牛口名');
ok($zip->set_number('8591111')->is_valid_number, '長崎県雲仙市吾妻町馬場名');
ok($zip->set_number('8591112')->is_valid_number, '長崎県雲仙市吾妻町栗林名');
ok($zip->set_number('8591113')->is_valid_number, '長崎県雲仙市吾妻町布江名');
ok($zip->set_number('8591114')->is_valid_number, '長崎県雲仙市吾妻町川床名');
ok($zip->set_number('8591115')->is_valid_number, '長崎県雲仙市吾妻町永中名');
ok($zip->set_number('8591116')->is_valid_number, '長崎県雲仙市吾妻町阿母名');
ok($zip->set_number('8591201')->is_valid_number, '長崎県雲仙市瑞穂町西郷庚');
ok($zip->set_number('8591202')->is_valid_number, '長崎県雲仙市瑞穂町西郷甲');
ok($zip->set_number('8591203')->is_valid_number, '長崎県雲仙市瑞穂町西郷乙');
ok($zip->set_number('8591204')->is_valid_number, '長崎県雲仙市瑞穂町西郷丙');
ok($zip->set_number('8591205')->is_valid_number, '長崎県雲仙市瑞穂町西郷丁');
ok($zip->set_number('8591206')->is_valid_number, '長崎県雲仙市瑞穂町西郷辛');
ok($zip->set_number('8591211')->is_valid_number, '長崎県雲仙市瑞穂町西郷戊');
ok($zip->set_number('8591212')->is_valid_number, '長崎県雲仙市瑞穂町西郷己');
ok($zip->set_number('8591213')->is_valid_number, '長崎県雲仙市瑞穂町伊福甲');
ok($zip->set_number('8591214')->is_valid_number, '長崎県雲仙市瑞穂町伊福乙');
ok($zip->set_number('8591215')->is_valid_number, '長崎県雲仙市瑞穂町古部甲');
ok($zip->set_number('8591216')->is_valid_number, '長崎県雲仙市瑞穂町古部乙');
ok($zip->set_number('8591301')->is_valid_number, '長崎県雲仙市国見町神代甲');
ok($zip->set_number('8591302')->is_valid_number, '長崎県雲仙市国見町神代乙');
ok($zip->set_number('8591303')->is_valid_number, '長崎県雲仙市国見町神代丙');
ok($zip->set_number('8591304')->is_valid_number, '長崎県雲仙市国見町神代丁');
ok($zip->set_number('8591305')->is_valid_number, '長崎県雲仙市国見町神代戊');
ok($zip->set_number('8591306')->is_valid_number, '長崎県雲仙市国見町神代己');
ok($zip->set_number('8591307')->is_valid_number, '長崎県雲仙市国見町神代庚');
ok($zip->set_number('8591308')->is_valid_number, '長崎県雲仙市国見町神代辛');
ok($zip->set_number('8591311')->is_valid_number, '長崎県雲仙市国見町土黒甲');
ok($zip->set_number('8591312')->is_valid_number, '長崎県雲仙市国見町土黒乙');
ok($zip->set_number('8591313')->is_valid_number, '長崎県雲仙市国見町土黒丙');
ok($zip->set_number('8591314')->is_valid_number, '長崎県雲仙市国見町土黒丁');
ok($zip->set_number('8591315')->is_valid_number, '長崎県雲仙市国見町土黒戊');
ok($zip->set_number('8591316')->is_valid_number, '長崎県雲仙市国見町土黒己');
ok($zip->set_number('8591317')->is_valid_number, '長崎県雲仙市国見町土黒庚');
ok($zip->set_number('8591321')->is_valid_number, '長崎県雲仙市国見町多比良甲');
ok($zip->set_number('8591322')->is_valid_number, '長崎県雲仙市国見町多比良乙');
ok($zip->set_number('8591323')->is_valid_number, '長崎県雲仙市国見町多比良丙');
ok($zip->set_number('8591324')->is_valid_number, '長崎県雲仙市国見町多比良丁');
ok($zip->set_number('8591325')->is_valid_number, '長崎県雲仙市国見町多比良戊');
ok($zip->set_number('8591401')->is_valid_number, '長崎県島原市有明町湯江甲');
ok($zip->set_number('8591402')->is_valid_number, '長崎県島原市有明町湯江乙');
ok($zip->set_number('8591403')->is_valid_number, '長崎県島原市有明町湯江丙');
ok($zip->set_number('8591404')->is_valid_number, '長崎県島原市有明町湯江丁');
ok($zip->set_number('8591411')->is_valid_number, '長崎県島原市有明町大三東甲');
ok($zip->set_number('8591412')->is_valid_number, '長崎県島原市有明町大三東乙');
ok($zip->set_number('8591413')->is_valid_number, '長崎県島原市有明町大三東丙');
ok($zip->set_number('8591414')->is_valid_number, '長崎県島原市有明町大三東丁');
ok($zip->set_number('8591415')->is_valid_number, '長崎県島原市有明町大三東戊');
ok($zip->set_number('8591501')->is_valid_number, '長崎県南島原市深江町甲');
ok($zip->set_number('8591502')->is_valid_number, '長崎県南島原市深江町乙');
ok($zip->set_number('8591503')->is_valid_number, '長崎県南島原市深江町丙');
ok($zip->set_number('8591504')->is_valid_number, '長崎県南島原市深江町丁');
ok($zip->set_number('8591505')->is_valid_number, '長崎県南島原市深江町戊');
ok($zip->set_number('8592111')->is_valid_number, '長崎県南島原市布津町甲');
ok($zip->set_number('8592112')->is_valid_number, '長崎県南島原市布津町乙');
ok($zip->set_number('8592113')->is_valid_number, '長崎県南島原市布津町丙');
ok($zip->set_number('8592121')->is_valid_number, '長崎県南島原市有家町石田');
ok($zip->set_number('8592122')->is_valid_number, '長崎県南島原市有家町大苑');
ok($zip->set_number('8592123')->is_valid_number, '長崎県南島原市有家町原尾');
ok($zip->set_number('8592201')->is_valid_number, '長崎県南島原市有家町久保');
ok($zip->set_number('8592202')->is_valid_number, '長崎県南島原市有家町山川');
ok($zip->set_number('8592203')->is_valid_number, '長崎県南島原市有家町尾上');
ok($zip->set_number('8592204')->is_valid_number, '長崎県南島原市有家町蒲河');
ok($zip->set_number('8592205')->is_valid_number, '長崎県南島原市有家町小川');
ok($zip->set_number('8592206')->is_valid_number, '長崎県南島原市有家町中須川');
ok($zip->set_number('8592211')->is_valid_number, '長崎県南島原市西有家町里坊');
ok($zip->set_number('8592212')->is_valid_number, '長崎県南島原市西有家町須川');
ok($zip->set_number('8592213')->is_valid_number, '長崎県南島原市西有家町見岳');
ok($zip->set_number('8592214')->is_valid_number, '長崎県南島原市西有家町慈恩寺');
ok($zip->set_number('8592215')->is_valid_number, '長崎県南島原市西有家町長野');
ok($zip->set_number('8592216')->is_valid_number, '長崎県南島原市西有家町龍石');
ok($zip->set_number('8592301')->is_valid_number, '長崎県南島原市北有馬町甲');
ok($zip->set_number('8592302')->is_valid_number, '長崎県南島原市北有馬町乙');
ok($zip->set_number('8592303')->is_valid_number, '長崎県南島原市北有馬町丙');
ok($zip->set_number('8592304')->is_valid_number, '長崎県南島原市北有馬町丁');
ok($zip->set_number('8592305')->is_valid_number, '長崎県南島原市北有馬町戊');
ok($zip->set_number('8592306')->is_valid_number, '長崎県南島原市北有馬町己');
ok($zip->set_number('8592316')->is_valid_number, '長崎県南島原市南有馬町己(古園轟河)');
ok($zip->set_number('8592411')->is_valid_number, '長崎県南島原市南有馬町甲');
ok($zip->set_number('8592412')->is_valid_number, '長崎県南島原市南有馬町乙');
ok($zip->set_number('8592413')->is_valid_number, '長崎県南島原市南有馬町丙');
ok($zip->set_number('8592414')->is_valid_number, '長崎県南島原市南有馬町丁');
ok($zip->set_number('8592415')->is_valid_number, '長崎県南島原市南有馬町戊');
ok($zip->set_number('8592416')->is_valid_number, '長崎県南島原市南有馬町己(その他)');
ok($zip->set_number('8592501')->is_valid_number, '長崎県南島原市口之津町乙');
ok($zip->set_number('8592502')->is_valid_number, '長崎県南島原市口之津町甲');
ok($zip->set_number('8592503')->is_valid_number, '長崎県南島原市口之津町丁');
ok($zip->set_number('8592504')->is_valid_number, '長崎県南島原市口之津町丙');
ok($zip->set_number('8592600')->is_valid_number, '長崎県南島原市以下に掲載がない場合');
ok($zip->set_number('8592601')->is_valid_number, '長崎県南島原市加津佐町己');
ok($zip->set_number('8592602')->is_valid_number, '長崎県南島原市加津佐町戊');
ok($zip->set_number('8592603')->is_valid_number, '長崎県南島原市加津佐町丁');
ok($zip->set_number('8592604')->is_valid_number, '長崎県南島原市加津佐町丙');
ok($zip->set_number('8592605')->is_valid_number, '長崎県南島原市加津佐町乙');
ok($zip->set_number('8592606')->is_valid_number, '長崎県南島原市加津佐町甲');
ok($zip->set_number('8593151')->is_valid_number, '長崎県佐世保市三川内本町');
ok($zip->set_number('8593152')->is_valid_number, '長崎県佐世保市新行江町');
ok($zip->set_number('8593153')->is_valid_number, '長崎県佐世保市三川内新町');
ok($zip->set_number('8593154')->is_valid_number, '長崎県佐世保市塩浸町');
ok($zip->set_number('8593155')->is_valid_number, '長崎県佐世保市三川内町');
ok($zip->set_number('8593156')->is_valid_number, '長崎県佐世保市下の原町');
ok($zip->set_number('8593157')->is_valid_number, '長崎県佐世保市桑木場町');
ok($zip->set_number('8593158')->is_valid_number, '長崎県佐世保市新替町');
ok($zip->set_number('8593161')->is_valid_number, '長崎県佐世保市口の尾町');
ok($zip->set_number('8593162')->is_valid_number, '長崎県佐世保市吉福町');
ok($zip->set_number('8593163')->is_valid_number, '長崎県佐世保市横手町');
ok($zip->set_number('8593164')->is_valid_number, '長崎県佐世保市心野町');
ok($zip->set_number('8593165')->is_valid_number, '長崎県佐世保市江永町');
ok($zip->set_number('8593166')->is_valid_number, '長崎県佐世保市木原町');
ok($zip->set_number('8593201')->is_valid_number, '長崎県佐世保市平松町');
ok($zip->set_number('8593202')->is_valid_number, '長崎県佐世保市上原町');
ok($zip->set_number('8593203')->is_valid_number, '長崎県佐世保市陣の内町');
ok($zip->set_number('8593204')->is_valid_number, '長崎県佐世保市若竹台町');
ok($zip->set_number('8593205')->is_valid_number, '長崎県佐世保市田の浦町');
ok($zip->set_number('8593211')->is_valid_number, '長崎県佐世保市早苗町');
ok($zip->set_number('8593212')->is_valid_number, '長崎県佐世保市花高');
ok($zip->set_number('8593213')->is_valid_number, '長崎県佐世保市権常寺町');
ok($zip->set_number('8593214')->is_valid_number, '長崎県佐世保市権常寺');
ok($zip->set_number('8593215')->is_valid_number, '長崎県佐世保市早岐');
ok($zip->set_number('8593216')->is_valid_number, '長崎県佐世保市勝海町');
ok($zip->set_number('8593221')->is_valid_number, '長崎県佐世保市中原町');
ok($zip->set_number('8593222')->is_valid_number, '長崎県佐世保市広田町');
ok($zip->set_number('8593223')->is_valid_number, '長崎県佐世保市広田');
ok($zip->set_number('8593224')->is_valid_number, '長崎県佐世保市重尾町');
ok($zip->set_number('8593225')->is_valid_number, '長崎県佐世保市浦川内町');
ok($zip->set_number('8593226')->is_valid_number, '長崎県佐世保市崎岡町');
ok($zip->set_number('8593231')->is_valid_number, '長崎県佐世保市瀬道町');
ok($zip->set_number('8593232')->is_valid_number, '長崎県佐世保市萩坂町');
ok($zip->set_number('8593233')->is_valid_number, '長崎県佐世保市奥山町');
ok($zip->set_number('8593234')->is_valid_number, '長崎県佐世保市長畑町');
ok($zip->set_number('8593235')->is_valid_number, '長崎県佐世保市宮津町');
ok($zip->set_number('8593236')->is_valid_number, '長崎県佐世保市南風崎町');
ok($zip->set_number('8593237')->is_valid_number, '長崎県佐世保市城間町');
ok($zip->set_number('8593241')->is_valid_number, '長崎県佐世保市有福町');
ok($zip->set_number('8593242')->is_valid_number, '長崎県佐世保市指方町');
ok($zip->set_number('8593243')->is_valid_number, '長崎県佐世保市ハウステンボス町');
ok($zip->set_number('8593244')->is_valid_number, '長崎県佐世保市江上町');
ok($zip->set_number('8593451')->is_valid_number, '長崎県佐世保市針尾東町');
ok($zip->set_number('8593452')->is_valid_number, '長崎県佐世保市針尾中町');
ok($zip->set_number('8593453')->is_valid_number, '長崎県佐世保市針尾西町');
ok($zip->set_number('8593454')->is_valid_number, '長崎県佐世保市針尾北町');
ok($zip->set_number('8593600')->is_valid_number, '長崎県東彼杵郡川棚町以下に掲載がない場合');
ok($zip->set_number('8593601')->is_valid_number, '長崎県東彼杵郡川棚町猪乗川内郷');
ok($zip->set_number('8593602')->is_valid_number, '長崎県東彼杵郡川棚町木場郷');
ok($zip->set_number('8593603')->is_valid_number, '長崎県東彼杵郡川棚町岩屋郷');
ok($zip->set_number('8593604')->is_valid_number, '長崎県東彼杵郡川棚町石木郷');
ok($zip->set_number('8593605')->is_valid_number, '長崎県東彼杵郡川棚町百津郷');
ok($zip->set_number('8593606')->is_valid_number, '長崎県東彼杵郡川棚町小音琴郷');
ok($zip->set_number('8593607')->is_valid_number, '長崎県東彼杵郡川棚町城山町');
ok($zip->set_number('8593608')->is_valid_number, '長崎県東彼杵郡川棚町栄町');
ok($zip->set_number('8593611')->is_valid_number, '長崎県東彼杵郡川棚町中山郷');
ok($zip->set_number('8593612')->is_valid_number, '長崎県東彼杵郡川棚町五反田郷');
ok($zip->set_number('8593613')->is_valid_number, '長崎県東彼杵郡川棚町上組郷');
ok($zip->set_number('8593614')->is_valid_number, '長崎県東彼杵郡川棚町中組郷');
ok($zip->set_number('8593615')->is_valid_number, '長崎県東彼杵郡川棚町下組郷');
ok($zip->set_number('8593616')->is_valid_number, '長崎県東彼杵郡川棚町白石郷');
ok($zip->set_number('8593617')->is_valid_number, '長崎県東彼杵郡川棚町三越郷');
ok($zip->set_number('8593618')->is_valid_number, '長崎県東彼杵郡川棚町小串郷');
ok($zip->set_number('8593619')->is_valid_number, '長崎県東彼杵郡川棚町新谷郷');
ok($zip->set_number('8593700')->is_valid_number, '長崎県東彼杵郡波佐見町以下に掲載がない場合');
ok($zip->set_number('8593701')->is_valid_number, '長崎県東彼杵郡波佐見町折敷瀬郷');
ok($zip->set_number('8593702')->is_valid_number, '長崎県東彼杵郡波佐見町湯無田郷');
ok($zip->set_number('8593703')->is_valid_number, '長崎県東彼杵郡波佐見町野々川郷');
ok($zip->set_number('8593704')->is_valid_number, '長崎県東彼杵郡波佐見町小樽郷');
ok($zip->set_number('8593705')->is_valid_number, '長崎県東彼杵郡波佐見町永尾郷');
ok($zip->set_number('8593706')->is_valid_number, '長崎県東彼杵郡波佐見町三股郷');
ok($zip->set_number('8593711')->is_valid_number, '長崎県東彼杵郡波佐見町井石郷');
ok($zip->set_number('8593712')->is_valid_number, '長崎県東彼杵郡波佐見町中尾郷');
ok($zip->set_number('8593713')->is_valid_number, '長崎県東彼杵郡波佐見町鬼木郷');
ok($zip->set_number('8593714')->is_valid_number, '長崎県東彼杵郡波佐見町金屋郷');
ok($zip->set_number('8593715')->is_valid_number, '長崎県東彼杵郡波佐見町宿郷');
ok($zip->set_number('8593716')->is_valid_number, '長崎県東彼杵郡波佐見町田ノ頭郷');
ok($zip->set_number('8593721')->is_valid_number, '長崎県東彼杵郡波佐見町川内郷');
ok($zip->set_number('8593722')->is_valid_number, '長崎県東彼杵郡波佐見町岳辺田郷');
ok($zip->set_number('8593723')->is_valid_number, '長崎県東彼杵郡波佐見町平野郷');
ok($zip->set_number('8593724')->is_valid_number, '長崎県東彼杵郡波佐見町志折郷');
ok($zip->set_number('8593725')->is_valid_number, '長崎県東彼杵郡波佐見町長野郷');
ok($zip->set_number('8593726')->is_valid_number, '長崎県東彼杵郡波佐見町稗木場郷');
ok($zip->set_number('8593727')->is_valid_number, '長崎県東彼杵郡波佐見町皿山郷');
ok($zip->set_number('8593728')->is_valid_number, '長崎県東彼杵郡波佐見町村木郷');
ok($zip->set_number('8593800')->is_valid_number, '長崎県東彼杵郡東彼杵町以下に掲載がない場合');
ok($zip->set_number('8593801')->is_valid_number, '長崎県東彼杵郡東彼杵町中尾郷');
ok($zip->set_number('8593802')->is_valid_number, '長崎県東彼杵郡東彼杵町坂本郷');
ok($zip->set_number('8593803')->is_valid_number, '長崎県東彼杵郡東彼杵町菅無田郷');
ok($zip->set_number('8593804')->is_valid_number, '長崎県東彼杵郡東彼杵町法音寺郷');
ok($zip->set_number('8593805')->is_valid_number, '長崎県東彼杵郡東彼杵町川内郷');
ok($zip->set_number('8593806')->is_valid_number, '長崎県東彼杵郡東彼杵町三根郷');
ok($zip->set_number('8593807')->is_valid_number, '長崎県東彼杵郡東彼杵町彼杵宿郷');
ok($zip->set_number('8593808')->is_valid_number, '長崎県東彼杵郡東彼杵町蔵本郷');
ok($zip->set_number('8593809')->is_valid_number, '長崎県東彼杵郡東彼杵町口木田郷');
ok($zip->set_number('8593811')->is_valid_number, '長崎県東彼杵郡東彼杵町大音琴郷');
ok($zip->set_number('8593812')->is_valid_number, '長崎県東彼杵郡東彼杵町小音琴郷');
ok($zip->set_number('8593921')->is_valid_number, '長崎県東彼杵郡東彼杵町千綿宿郷');
ok($zip->set_number('8593922')->is_valid_number, '長崎県東彼杵郡東彼杵町八反田郷');
ok($zip->set_number('8593923')->is_valid_number, '長崎県東彼杵郡東彼杵町瀬戸郷');
ok($zip->set_number('8593924')->is_valid_number, '長崎県東彼杵郡東彼杵町太ノ浦郷');
ok($zip->set_number('8593925')->is_valid_number, '長崎県東彼杵郡東彼杵町中岳郷');
ok($zip->set_number('8593926')->is_valid_number, '長崎県東彼杵郡東彼杵町蕪郷');
ok($zip->set_number('8593927')->is_valid_number, '長崎県東彼杵郡東彼杵町駄地郷');
ok($zip->set_number('8593928')->is_valid_number, '長崎県東彼杵郡東彼杵町平似田郷');
ok($zip->set_number('8593929')->is_valid_number, '長崎県東彼杵郡東彼杵町里郷');
ok($zip->set_number('8593931')->is_valid_number, '長崎県東彼杵郡東彼杵町木場郷');
ok($zip->set_number('8593932')->is_valid_number, '長崎県東彼杵郡東彼杵町遠目郷');
ok($zip->set_number('8593933')->is_valid_number, '長崎県東彼杵郡東彼杵町一ッ石郷');
ok($zip->set_number('8594301')->is_valid_number, '長崎県松浦市鷹島町阿翁浦免');
ok($zip->set_number('8594302')->is_valid_number, '長崎県松浦市鷹島町阿翁免');
ok($zip->set_number('8594303')->is_valid_number, '長崎県松浦市鷹島町神崎免');
ok($zip->set_number('8594304')->is_valid_number, '長崎県松浦市鷹島町里免');
ok($zip->set_number('8594305')->is_valid_number, '長崎県松浦市鷹島町中通免');
ok($zip->set_number('8594306')->is_valid_number, '長崎県松浦市鷹島町原免');
ok($zip->set_number('8594307')->is_valid_number, '長崎県松浦市鷹島町三里免');
ok($zip->set_number('8594308')->is_valid_number, '長崎県松浦市鷹島町船唐津免');
ok($zip->set_number('8594309')->is_valid_number, '長崎県松浦市鷹島町黒島免');
ok($zip->set_number('8594500')->is_valid_number, '長崎県松浦市以下に掲載がない場合');
ok($zip->set_number('8594501')->is_valid_number, '長崎県松浦市志佐町浦免');
ok($zip->set_number('8594502')->is_valid_number, '長崎県松浦市志佐町里免');
ok($zip->set_number('8594503')->is_valid_number, '長崎県松浦市志佐町高野免');
ok($zip->set_number('8594504')->is_valid_number, '長崎県松浦市志佐町栢木免');
ok($zip->set_number('8594505')->is_valid_number, '長崎県松浦市志佐町西山免');
ok($zip->set_number('8594506')->is_valid_number, '長崎県松浦市志佐町白浜免');
ok($zip->set_number('8594507')->is_valid_number, '長崎県松浦市志佐町庄野免');
ok($zip->set_number('8594511')->is_valid_number, '長崎県松浦市志佐町赤木免');
ok($zip->set_number('8594512')->is_valid_number, '長崎県松浦市志佐町笛吹免');
ok($zip->set_number('8594513')->is_valid_number, '長崎県松浦市志佐町田ノ平免');
ok($zip->set_number('8594514')->is_valid_number, '長崎県松浦市志佐町柚木川内免');
ok($zip->set_number('8594515')->is_valid_number, '長崎県松浦市志佐町稗木場免');
ok($zip->set_number('8594516')->is_valid_number, '長崎県松浦市志佐町長野免');
ok($zip->set_number('8594517')->is_valid_number, '長崎県松浦市志佐町横辺田免');
ok($zip->set_number('8594518')->is_valid_number, '長崎県松浦市志佐町池成免');
ok($zip->set_number('8594521')->is_valid_number, '長崎県松浦市今福町北免');
ok($zip->set_number('8594522')->is_valid_number, '長崎県松浦市今福町東免');
ok($zip->set_number('8594523')->is_valid_number, '長崎県松浦市今福町滑栄免');
ok($zip->set_number('8594524')->is_valid_number, '長崎県松浦市今福町木場免');
ok($zip->set_number('8594525')->is_valid_number, '長崎県松浦市今福町寺上免');
ok($zip->set_number('8594526')->is_valid_number, '長崎県松浦市今福町坂野免');
ok($zip->set_number('8594527')->is_valid_number, '長崎県松浦市今福町仏坂免');
ok($zip->set_number('8594528')->is_valid_number, '長崎県松浦市今福町浦免');
ok($zip->set_number('8594529')->is_valid_number, '長崎県松浦市今福町飛島免');
ok($zip->set_number('8594531')->is_valid_number, '長崎県松浦市調川町平尾免');
ok($zip->set_number('8594532')->is_valid_number, '長崎県松浦市調川町中免');
ok($zip->set_number('8594533')->is_valid_number, '長崎県松浦市調川町上免');
ok($zip->set_number('8594534')->is_valid_number, '長崎県松浦市調川町白井免');
ok($zip->set_number('8594535')->is_valid_number, '長崎県松浦市調川町松山田免');
ok($zip->set_number('8594536')->is_valid_number, '長崎県松浦市調川町下免');
ok($zip->set_number('8594741')->is_valid_number, '長崎県松浦市星鹿町北久保免');
ok($zip->set_number('8594742')->is_valid_number, '長崎県松浦市星鹿町牟田免');
ok($zip->set_number('8594743')->is_valid_number, '長崎県松浦市星鹿町下田免');
ok($zip->set_number('8594744')->is_valid_number, '長崎県松浦市星鹿町岳崎免');
ok($zip->set_number('8594745')->is_valid_number, '長崎県松浦市星鹿町青島免');
ok($zip->set_number('8594751')->is_valid_number, '長崎県松浦市御厨町池田免');
ok($zip->set_number('8594752')->is_valid_number, '長崎県松浦市御厨町里免');
ok($zip->set_number('8594753')->is_valid_number, '長崎県松浦市御厨町中野免');
ok($zip->set_number('8594754')->is_valid_number, '長崎県松浦市御厨町北平免');
ok($zip->set_number('8594755')->is_valid_number, '長崎県松浦市御厨町横久保免');
ok($zip->set_number('8594756')->is_valid_number, '長崎県松浦市御厨町前田免');
ok($zip->set_number('8594757')->is_valid_number, '長崎県松浦市御厨町高野免');
ok($zip->set_number('8594758')->is_valid_number, '長崎県松浦市御厨町大崎免');
ok($zip->set_number('8594761')->is_valid_number, '長崎県松浦市御厨町相坂免');
ok($zip->set_number('8594761')->is_valid_number, '長崎県松浦市御厨町田原免');
ok($zip->set_number('8594762')->is_valid_number, '長崎県松浦市御厨町小船免');
ok($zip->set_number('8594763')->is_valid_number, '長崎県松浦市御厨町山根免');
ok($zip->set_number('8594764')->is_valid_number, '長崎県松浦市御厨町狩原免');
ok($zip->set_number('8594765')->is_valid_number, '長崎県松浦市御厨町米ノ山免');
ok($zip->set_number('8594766')->is_valid_number, '長崎県松浦市御厨町普住免');
ok($zip->set_number('8594767')->is_valid_number, '長崎県松浦市御厨町川内免');
ok($zip->set_number('8594768')->is_valid_number, '長崎県松浦市御厨町西田免');
ok($zip->set_number('8594769')->is_valid_number, '長崎県松浦市御厨町西木場免');
ok($zip->set_number('8594771')->is_valid_number, '長崎県松浦市御厨町下登木免');
ok($zip->set_number('8594772')->is_valid_number, '長崎県松浦市御厨町寺ノ尾免');
ok($zip->set_number('8594773')->is_valid_number, '長崎県松浦市御厨町上登木免');
ok($zip->set_number('8594774')->is_valid_number, '長崎県松浦市御厨町立木免');
ok($zip->set_number('8594775')->is_valid_number, '長崎県松浦市御厨町郭公尾免');
ok($zip->set_number('8594776')->is_valid_number, '長崎県松浦市御厨町木場免');
ok($zip->set_number('8594777')->is_valid_number, '長崎県松浦市御厨町板橋免');
ok($zip->set_number('8594778')->is_valid_number, '長崎県松浦市御厨町田代免');
ok($zip->set_number('8594801')->is_valid_number, '長崎県平戸市田平町岳崎免');
ok($zip->set_number('8594802')->is_valid_number, '長崎県平戸市田平町福崎免');
ok($zip->set_number('8594803')->is_valid_number, '長崎県平戸市田平町小崎免');
ok($zip->set_number('8594804')->is_valid_number, '長崎県平戸市田平町上亀免');
ok($zip->set_number('8594805')->is_valid_number, '長崎県平戸市田平町本山免');
ok($zip->set_number('8594806')->is_valid_number, '長崎県平戸市田平町下亀免');
ok($zip->set_number('8594807')->is_valid_number, '長崎県平戸市田平町里免');
ok($zip->set_number('8594811')->is_valid_number, '長崎県平戸市田平町古梶免');
ok($zip->set_number('8594812')->is_valid_number, '長崎県平戸市田平町田代免');
ok($zip->set_number('8594813')->is_valid_number, '長崎県平戸市田平町深月免');
ok($zip->set_number('8594814')->is_valid_number, '長崎県平戸市田平町以善免');
ok($zip->set_number('8594815')->is_valid_number, '長崎県平戸市田平町下寺免');
ok($zip->set_number('8594821')->is_valid_number, '長崎県平戸市田平町大久保免');
ok($zip->set_number('8594822')->is_valid_number, '長崎県平戸市田平町一関免');
ok($zip->set_number('8594823')->is_valid_number, '長崎県平戸市田平町荻田免');
ok($zip->set_number('8594824')->is_valid_number, '長崎県平戸市田平町小手田免');
ok($zip->set_number('8594825')->is_valid_number, '長崎県平戸市田平町山内免');
ok($zip->set_number('8594826')->is_valid_number, '長崎県平戸市田平町野田免');
ok($zip->set_number('8594827')->is_valid_number, '長崎県平戸市田平町横島免');
ok($zip->set_number('8595100')->is_valid_number, '長崎県平戸市以下に掲載がない場合');
ok($zip->set_number('8595101')->is_valid_number, '長崎県平戸市度島町');
ok($zip->set_number('8595102')->is_valid_number, '長崎県平戸市大久保町');
ok($zip->set_number('8595103')->is_valid_number, '長崎県平戸市田助町');
ok($zip->set_number('8595104')->is_valid_number, '長崎県平戸市崎方町');
ok($zip->set_number('8595111')->is_valid_number, '長崎県平戸市浦の町');
ok($zip->set_number('8595112')->is_valid_number, '長崎県平戸市宮の町');
ok($zip->set_number('8595113')->is_valid_number, '長崎県平戸市木引田町');
ok($zip->set_number('8595114')->is_valid_number, '長崎県平戸市築地町');
ok($zip->set_number('8595115')->is_valid_number, '長崎県平戸市新町');
ok($zip->set_number('8595116')->is_valid_number, '長崎県平戸市職人町');
ok($zip->set_number('8595117')->is_valid_number, '長崎県平戸市魚の棚町');
ok($zip->set_number('8595118')->is_valid_number, '長崎県平戸市紺屋町');
ok($zip->set_number('8595121')->is_valid_number, '長崎県平戸市岩の上町');
ok($zip->set_number('8595122')->is_valid_number, '長崎県平戸市明の川内町');
ok($zip->set_number('8595123')->is_valid_number, '長崎県平戸市大野町');
ok($zip->set_number('8595131')->is_valid_number, '長崎県平戸市大山町');
ok($zip->set_number('8595132')->is_valid_number, '長崎県平戸市川内町');
ok($zip->set_number('8595133')->is_valid_number, '長崎県平戸市中野大久保町');
ok($zip->set_number('8595134')->is_valid_number, '長崎県平戸市水垂町');
ok($zip->set_number('8595141')->is_valid_number, '長崎県平戸市山中町');
ok($zip->set_number('8595142')->is_valid_number, '長崎県平戸市主師町');
ok($zip->set_number('8595143')->is_valid_number, '長崎県平戸市坊方町');
ok($zip->set_number('8595144')->is_valid_number, '長崎県平戸市下中野町');
ok($zip->set_number('8595145')->is_valid_number, '長崎県平戸市古江町');
ok($zip->set_number('8595151')->is_valid_number, '長崎県平戸市木引町');
ok($zip->set_number('8595152')->is_valid_number, '長崎県平戸市鏡川町');
ok($zip->set_number('8595153')->is_valid_number, '長崎県平戸市戸石川町');
ok($zip->set_number('8595361')->is_valid_number, '長崎県平戸市紐差町');
ok($zip->set_number('8595362')->is_valid_number, '長崎県平戸市木ケ津町');
ok($zip->set_number('8595363')->is_valid_number, '長崎県平戸市草積町');
ok($zip->set_number('8595364')->is_valid_number, '長崎県平戸市迎紐差町');
ok($zip->set_number('8595365')->is_valid_number, '長崎県平戸市木場町');
ok($zip->set_number('8595366')->is_valid_number, '長崎県平戸市宝亀町');
ok($zip->set_number('8595371')->is_valid_number, '長崎県平戸市獅子町');
ok($zip->set_number('8595372')->is_valid_number, '長崎県平戸市高越町');
ok($zip->set_number('8595373')->is_valid_number, '長崎県平戸市春日町');
ok($zip->set_number('8595374')->is_valid_number, '長崎県平戸市深川町');
ok($zip->set_number('8595375')->is_valid_number, '長崎県平戸市朶の原町');
ok($zip->set_number('8595376')->is_valid_number, '長崎県平戸市大石脇町');
ok($zip->set_number('8595381')->is_valid_number, '長崎県平戸市根獅子町');
ok($zip->set_number('8595382')->is_valid_number, '長崎県平戸市飯良町');
ok($zip->set_number('8595383')->is_valid_number, '長崎県平戸市大川原町');
ok($zip->set_number('8595384')->is_valid_number, '長崎県平戸市赤松町');
ok($zip->set_number('8595501')->is_valid_number, '長崎県平戸市堤町');
ok($zip->set_number('8595502')->is_valid_number, '長崎県平戸市猪渡谷町');
ok($zip->set_number('8595503')->is_valid_number, '長崎県平戸市上中津良町');
ok($zip->set_number('8595504')->is_valid_number, '長崎県平戸市下中津良町');
ok($zip->set_number('8595505')->is_valid_number, '長崎県平戸市敷佐町');
ok($zip->set_number('8595511')->is_valid_number, '長崎県平戸市神船町');
ok($zip->set_number('8595512')->is_valid_number, '長崎県平戸市津吉町');
ok($zip->set_number('8595513')->is_valid_number, '長崎県平戸市辻町');
ok($zip->set_number('8595514')->is_valid_number, '長崎県平戸市無代寺町');
ok($zip->set_number('8595515')->is_valid_number, '長崎県平戸市鮎川町');
ok($zip->set_number('8595516')->is_valid_number, '長崎県平戸市大佐志町');
ok($zip->set_number('8595521')->is_valid_number, '長崎県平戸市船木町');
ok($zip->set_number('8595522')->is_valid_number, '長崎県平戸市神ノ川町');
ok($zip->set_number('8595523')->is_valid_number, '長崎県平戸市前津吉町');
ok($zip->set_number('8595524')->is_valid_number, '長崎県平戸市神上町');
ok($zip->set_number('8595525')->is_valid_number, '長崎県平戸市東中山町');
ok($zip->set_number('8595526')->is_valid_number, '長崎県平戸市西中山町');
ok($zip->set_number('8595527')->is_valid_number, '長崎県平戸市田代町');
ok($zip->set_number('8595531')->is_valid_number, '長崎県平戸市早福町');
ok($zip->set_number('8595532')->is_valid_number, '長崎県平戸市大志々伎町');
ok($zip->set_number('8595533')->is_valid_number, '長崎県平戸市志々伎町');
ok($zip->set_number('8595534')->is_valid_number, '長崎県平戸市小田町');
ok($zip->set_number('8595535')->is_valid_number, '長崎県平戸市野子町');
ok($zip->set_number('8595701')->is_valid_number, '長崎県平戸市生月町壱部');
ok($zip->set_number('8595702')->is_valid_number, '長崎県平戸市生月町壱部浦');
ok($zip->set_number('8595703')->is_valid_number, '長崎県平戸市生月町里免');
ok($zip->set_number('8595704')->is_valid_number, '長崎県平戸市生月町山田免');
ok($zip->set_number('8595705')->is_valid_number, '長崎県平戸市生月町舘浦');
ok($zip->set_number('8595706')->is_valid_number, '長崎県平戸市生月町南免');
ok($zip->set_number('8595707')->is_valid_number, '長崎県平戸市生月町御崎');
ok($zip->set_number('8595801')->is_valid_number, '長崎県平戸市大島村神浦');
ok($zip->set_number('8595802')->is_valid_number, '長崎県平戸市大島村前平');
ok($zip->set_number('8595803')->is_valid_number, '長崎県平戸市大島村西宇戸');
ok($zip->set_number('8595804')->is_valid_number, '長崎県平戸市大島村大根坂');
ok($zip->set_number('8595805')->is_valid_number, '長崎県平戸市大島村的山川内');
ok($zip->set_number('8595806')->is_valid_number, '長崎県平戸市大島村的山戸田');
ok($zip->set_number('8596101')->is_valid_number, '長崎県佐世保市江迎町長坂');
ok($zip->set_number('8596102')->is_valid_number, '長崎県佐世保市江迎町上川内');
ok($zip->set_number('8596103')->is_valid_number, '長崎県佐世保市江迎町埋立');
ok($zip->set_number('8596104')->is_valid_number, '長崎県佐世保市江迎町末橘');
ok($zip->set_number('8596105')->is_valid_number, '長崎県佐世保市江迎町梶ノ村');
ok($zip->set_number('8596106')->is_valid_number, '長崎県佐世保市江迎町北田');
ok($zip->set_number('8596111')->is_valid_number, '長崎県佐世保市江迎町飯良坂');
ok($zip->set_number('8596112')->is_valid_number, '長崎県佐世保市江迎町根引');
ok($zip->set_number('8596113')->is_valid_number, '長崎県佐世保市江迎町栗越');
ok($zip->set_number('8596114')->is_valid_number, '長崎県佐世保市江迎町箙尾');
ok($zip->set_number('8596115')->is_valid_number, '長崎県佐世保市江迎町中尾');
ok($zip->set_number('8596121')->is_valid_number, '長崎県佐世保市江迎町奥川内');
ok($zip->set_number('8596122')->is_valid_number, '長崎県佐世保市江迎町七腕');
ok($zip->set_number('8596123')->is_valid_number, '長崎県佐世保市江迎町小川内');
ok($zip->set_number('8596124')->is_valid_number, '長崎県佐世保市江迎町乱橋');
ok($zip->set_number('8596125')->is_valid_number, '長崎県佐世保市江迎町三浦');
ok($zip->set_number('8596126')->is_valid_number, '長崎県佐世保市江迎町北平');
ok($zip->set_number('8596131')->is_valid_number, '長崎県佐世保市江迎町赤坂');
ok($zip->set_number('8596132')->is_valid_number, '長崎県佐世保市江迎町志戸氏');
ok($zip->set_number('8596133')->is_valid_number, '長崎県佐世保市江迎町猪調');
ok($zip->set_number('8596134')->is_valid_number, '長崎県佐世保市江迎町田ノ元');
ok($zip->set_number('8596141')->is_valid_number, '長崎県佐世保市鹿町町新深江');
ok($zip->set_number('8596142')->is_valid_number, '長崎県佐世保市鹿町町深江');
ok($zip->set_number('8596143')->is_valid_number, '長崎県佐世保市鹿町町深江潟');
ok($zip->set_number('8596144')->is_valid_number, '長崎県佐世保市鹿町町鹿町');
ok($zip->set_number('8596145')->is_valid_number, '長崎県佐世保市鹿町町土肥ノ浦');
ok($zip->set_number('8596201')->is_valid_number, '長崎県佐世保市鹿町町大屋');
ok($zip->set_number('8596202')->is_valid_number, '長崎県佐世保市鹿町町上歌ヶ浦');
ok($zip->set_number('8596203')->is_valid_number, '長崎県佐世保市鹿町町口ノ里');
ok($zip->set_number('8596204')->is_valid_number, '長崎県佐世保市鹿町町下歌ヶ浦');
ok($zip->set_number('8596205')->is_valid_number, '長崎県佐世保市鹿町町中野');
ok($zip->set_number('8596206')->is_valid_number, '長崎県佐世保市鹿町町長串');
ok($zip->set_number('8596207')->is_valid_number, '長崎県佐世保市鹿町町船ノ村');
ok($zip->set_number('8596301')->is_valid_number, '長崎県佐世保市吉井町草ノ尾');
ok($zip->set_number('8596302')->is_valid_number, '長崎県佐世保市吉井町福井');
ok($zip->set_number('8596303')->is_valid_number, '長崎県佐世保市吉井町板樋');
ok($zip->set_number('8596304')->is_valid_number, '長崎県佐世保市吉井町梶木場');
ok($zip->set_number('8596305')->is_valid_number, '長崎県佐世保市吉井町直谷');
ok($zip->set_number('8596311')->is_valid_number, '長崎県佐世保市吉井町橋川内');
ok($zip->set_number('8596312')->is_valid_number, '長崎県佐世保市吉井町橋口');
ok($zip->set_number('8596313')->is_valid_number, '長崎県佐世保市吉井町上吉田');
ok($zip->set_number('8596314')->is_valid_number, '長崎県佐世保市吉井町田原');
ok($zip->set_number('8596315')->is_valid_number, '長崎県佐世保市吉井町下原');
ok($zip->set_number('8596316')->is_valid_number, '長崎県佐世保市吉井町乙石尾');
ok($zip->set_number('8596317')->is_valid_number, '長崎県佐世保市吉井町高峰');
ok($zip->set_number('8596321')->is_valid_number, '長崎県佐世保市吉井町前岳');
ok($zip->set_number('8596322')->is_valid_number, '長崎県佐世保市吉井町踊瀬');
ok($zip->set_number('8596323')->is_valid_number, '長崎県佐世保市吉井町春明');
ok($zip->set_number('8596324')->is_valid_number, '長崎県佐世保市吉井町吉元');
ok($zip->set_number('8596325')->is_valid_number, '長崎県佐世保市吉井町大渡');
ok($zip->set_number('8596326')->is_valid_number, '長崎県佐世保市吉井町立石');
ok($zip->set_number('8596401')->is_valid_number, '長崎県佐世保市世知原町赤木場');
ok($zip->set_number('8596402')->is_valid_number, '長崎県佐世保市世知原町岩谷口');
ok($zip->set_number('8596403')->is_valid_number, '長崎県佐世保市世知原町上野原');
ok($zip->set_number('8596404')->is_valid_number, '長崎県佐世保市世知原町太田');
ok($zip->set_number('8596405')->is_valid_number, '長崎県佐世保市世知原町開作');
ok($zip->set_number('8596406')->is_valid_number, '長崎県佐世保市世知原町木浦原');
ok($zip->set_number('8596407')->is_valid_number, '長崎県佐世保市世知原町北川内');
ok($zip->set_number('8596408')->is_valid_number, '長崎県佐世保市世知原町栗迎');
ok($zip->set_number('8596409')->is_valid_number, '長崎県佐世保市世知原町中通');
ok($zip->set_number('8596411')->is_valid_number, '長崎県佐世保市世知原町長田代');
ok($zip->set_number('8596412')->is_valid_number, '長崎県佐世保市世知原町西ノ岳');
ok($zip->set_number('8596413')->is_valid_number, '長崎県佐世保市世知原町笥瀬');
ok($zip->set_number('8596414')->is_valid_number, '長崎県佐世保市世知原町矢櫃');
ok($zip->set_number('8596415')->is_valid_number, '長崎県佐世保市世知原町槍巻');
ok($zip->set_number('8600001')->is_valid_number, '熊本県熊本市中央区千葉城町');
ok($zip->set_number('8600002')->is_valid_number, '熊本県熊本市中央区本丸');
ok($zip->set_number('8600003')->is_valid_number, '熊本県熊本市中央区古城町');
ok($zip->set_number('8600004')->is_valid_number, '熊本県熊本市中央区新町');
ok($zip->set_number('8600005')->is_valid_number, '熊本県熊本市中央区宮内');
ok($zip->set_number('8600006')->is_valid_number, '熊本県熊本市中央区段山本町');
ok($zip->set_number('8600007')->is_valid_number, '熊本県熊本市中央区古京町');
ok($zip->set_number('8600008')->is_valid_number, '熊本県熊本市中央区二の丸');
ok($zip->set_number('8600011')->is_valid_number, '熊本県熊本市中央区新鍛冶屋町');
ok($zip->set_number('8600012')->is_valid_number, '熊本県熊本市中央区紺屋今町');
ok($zip->set_number('8600013')->is_valid_number, '熊本県熊本市中央区通町');
ok($zip->set_number('8600014')->is_valid_number, '熊本県熊本市中央区慶徳堀町');
ok($zip->set_number('8600015')->is_valid_number, '熊本県熊本市中央区古川町');
ok($zip->set_number('8600016')->is_valid_number, '熊本県熊本市中央区山崎町');
ok($zip->set_number('8600017')->is_valid_number, '熊本県熊本市中央区練兵町');
ok($zip->set_number('8600018')->is_valid_number, '熊本県熊本市中央区船場町下');
ok($zip->set_number('8600019')->is_valid_number, '熊本県熊本市中央区船場町');
ok($zip->set_number('8600021')->is_valid_number, '熊本県熊本市中央区上鍛冶屋町');
ok($zip->set_number('8600022')->is_valid_number, '熊本県熊本市中央区横紺屋町');
ok($zip->set_number('8600023')->is_valid_number, '熊本県熊本市中央区河原町');
ok($zip->set_number('8600024')->is_valid_number, '熊本県熊本市中央区松原町');
ok($zip->set_number('8600025')->is_valid_number, '熊本県熊本市中央区紺屋町');
ok($zip->set_number('8600026')->is_valid_number, '熊本県熊本市中央区鍛冶屋町');
ok($zip->set_number('8600027')->is_valid_number, '熊本県熊本市中央区西唐人町');
ok($zip->set_number('8600028')->is_valid_number, '熊本県熊本市中央区中唐人町');
ok($zip->set_number('8600029')->is_valid_number, '熊本県熊本市中央区米屋町');
ok($zip->set_number('8600031')->is_valid_number, '熊本県熊本市中央区魚屋町');
ok($zip->set_number('8600032')->is_valid_number, '熊本県熊本市中央区万町');
ok($zip->set_number('8600033')->is_valid_number, '熊本県熊本市中央区紺屋阿弥陀寺町');
ok($zip->set_number('8600034')->is_valid_number, '熊本県熊本市中央区東阿弥陀寺町');
ok($zip->set_number('8600035')->is_valid_number, '熊本県熊本市中央区呉服町');
ok($zip->set_number('8600036')->is_valid_number, '熊本県熊本市中央区古大工町');
ok($zip->set_number('8600037')->is_valid_number, '熊本県熊本市中央区西阿弥陀寺町');
ok($zip->set_number('8600038')->is_valid_number, '熊本県熊本市中央区古桶屋町');
ok($zip->set_number('8600039')->is_valid_number, '熊本県熊本市中央区川端町');
ok($zip->set_number('8600041')->is_valid_number, '熊本県熊本市中央区細工町');
ok($zip->set_number('8600042')->is_valid_number, '熊本県熊本市中央区小沢町');
ok($zip->set_number('8600043')->is_valid_number, '熊本県熊本市中央区板屋町');
ok($zip->set_number('8600044')->is_valid_number, '熊本県熊本市西区谷尾崎町');
ok($zip->set_number('8600045')->is_valid_number, '熊本県熊本市西区戸坂町');
ok($zip->set_number('8600046')->is_valid_number, '熊本県熊本市中央区横手');
ok($zip->set_number('8600046')->is_valid_number, '熊本県熊本市西区横手');
ok($zip->set_number('8600047')->is_valid_number, '熊本県熊本市西区春日');
ok($zip->set_number('8600048')->is_valid_number, '熊本県熊本市西区池上町');
ok($zip->set_number('8600051')->is_valid_number, '熊本県熊本市西区二本木');
ok($zip->set_number('8600052')->is_valid_number, '熊本県熊本市西区田崎本町');
ok($zip->set_number('8600053')->is_valid_number, '熊本県熊本市西区田崎');
ok($zip->set_number('8600054')->is_valid_number, '熊本県熊本市西区八島');
ok($zip->set_number('8600055')->is_valid_number, '熊本県熊本市西区蓮台寺');
ok($zip->set_number('8600056')->is_valid_number, '熊本県熊本市西区新土河原');
ok($zip->set_number('8600057')->is_valid_number, '熊本県熊本市西区八島町');
ok($zip->set_number('8600058')->is_valid_number, '熊本県熊本市西区田崎町');
ok($zip->set_number('8600059')->is_valid_number, '熊本県熊本市西区野中');
ok($zip->set_number('8600061')->is_valid_number, '熊本県熊本市西区上高橋');
ok($zip->set_number('8600062')->is_valid_number, '熊本県熊本市西区高橋町');
ok($zip->set_number('8600063')->is_valid_number, '熊本県熊本市西区城山上代町');
ok($zip->set_number('8600064')->is_valid_number, '熊本県熊本市西区城山半田');
ok($zip->set_number('8600065')->is_valid_number, '熊本県熊本市西区城山薬師');
ok($zip->set_number('8600066')->is_valid_number, '熊本県熊本市西区城山下代');
ok($zip->set_number('8600067')->is_valid_number, '熊本県熊本市西区城山大塘');
ok($zip->set_number('8600068')->is_valid_number, '熊本県熊本市西区上代');
ok($zip->set_number('8600071')->is_valid_number, '熊本県熊本市西区池亀町');
ok($zip->set_number('8600072')->is_valid_number, '熊本県熊本市西区花園');
ok($zip->set_number('8600073')->is_valid_number, '熊本県熊本市中央区島崎');
ok($zip->set_number('8600073')->is_valid_number, '熊本県熊本市西区島崎');
ok($zip->set_number('8600074')->is_valid_number, '熊本県熊本市西区出町');
ok($zip->set_number('8600075')->is_valid_number, '熊本県熊本市西区稗田町');
ok($zip->set_number('8600076')->is_valid_number, '熊本県熊本市中央区壺川');
ok($zip->set_number('8600077')->is_valid_number, '熊本県熊本市中央区内坪井町');
ok($zip->set_number('8600078')->is_valid_number, '熊本県熊本市中央区京町');
ok($zip->set_number('8600079')->is_valid_number, '熊本県熊本市西区上熊本');
ok($zip->set_number('8600081')->is_valid_number, '熊本県熊本市中央区京町本丁');
ok($zip->set_number('8600081')->is_valid_number, '熊本県熊本市西区京町本丁');
ok($zip->set_number('8600082')->is_valid_number, '熊本県熊本市西区池田');
ok($zip->set_number('8600082')->is_valid_number, '熊本県熊本市北区池田');
ok($zip->set_number('8600083')->is_valid_number, '熊本県熊本市北区大窪');
ok($zip->set_number('8600084')->is_valid_number, '熊本県熊本市北区山室');
ok($zip->set_number('8600085')->is_valid_number, '熊本県熊本市北区高平');
ok($zip->set_number('8600086')->is_valid_number, '熊本県熊本市北区打越町');
ok($zip->set_number('8600087')->is_valid_number, '熊本県熊本市北区清水町打越');
ok($zip->set_number('8600088')->is_valid_number, '熊本県熊本市西区津浦町');
ok($zip->set_number('8600088')->is_valid_number, '熊本県熊本市北区津浦町');
ok($zip->set_number('8600801')->is_valid_number, '熊本県熊本市中央区安政町');
ok($zip->set_number('8600802')->is_valid_number, '熊本県熊本市中央区中央街');
ok($zip->set_number('8600803')->is_valid_number, '熊本県熊本市中央区新市街');
ok($zip->set_number('8600804')->is_valid_number, '熊本県熊本市中央区辛島町');
ok($zip->set_number('8600805')->is_valid_number, '熊本県熊本市中央区桜町');
ok($zip->set_number('8600806')->is_valid_number, '熊本県熊本市中央区花畑町');
ok($zip->set_number('8600807')->is_valid_number, '熊本県熊本市中央区下通');
ok($zip->set_number('8600808')->is_valid_number, '熊本県熊本市中央区手取本町');
ok($zip->set_number('8600811')->is_valid_number, '熊本県熊本市中央区本荘');
ok($zip->set_number('8600812')->is_valid_number, '熊本県熊本市中央区南熊本');
ok($zip->set_number('8600813')->is_valid_number, '熊本県熊本市中央区琴平');
ok($zip->set_number('8600814')->is_valid_number, '熊本県熊本市中央区琴平本町');
ok($zip->set_number('8600815')->is_valid_number, '熊本県熊本市中央区春竹町');
ok($zip->set_number('8600816')->is_valid_number, '熊本県熊本市中央区本荘町');
ok($zip->set_number('8600817')->is_valid_number, '熊本県熊本市中央区迎町');
ok($zip->set_number('8600818')->is_valid_number, '熊本県熊本市中央区弥生町');
ok($zip->set_number('8600821')->is_valid_number, '熊本県熊本市中央区本山');
ok($zip->set_number('8600822')->is_valid_number, '熊本県熊本市中央区本山町');
ok($zip->set_number('8600823')->is_valid_number, '熊本県熊本市中央区世安町');
ok($zip->set_number('8600824')->is_valid_number, '熊本県熊本市中央区十禅寺');
ok($zip->set_number('8600824')->is_valid_number, '熊本県熊本市南区十禅寺');
ok($zip->set_number('8600826')->is_valid_number, '熊本県熊本市南区平田');
ok($zip->set_number('8600827')->is_valid_number, '熊本県熊本市中央区世安');
ok($zip->set_number('8600831')->is_valid_number, '熊本県熊本市中央区八王寺町');
ok($zip->set_number('8600831')->is_valid_number, '熊本県熊本市南区八王寺町');
ok($zip->set_number('8600832')->is_valid_number, '熊本県熊本市中央区萩原町');
ok($zip->set_number('8600833')->is_valid_number, '熊本県熊本市中央区平成');
ok($zip->set_number('8600833')->is_valid_number, '熊本県熊本市南区平成');
ok($zip->set_number('8600834')->is_valid_number, '熊本県熊本市南区江越');
ok($zip->set_number('8600841')->is_valid_number, '熊本県熊本市中央区井川淵町');
ok($zip->set_number('8600842')->is_valid_number, '熊本県熊本市中央区南千反畑町');
ok($zip->set_number('8600843')->is_valid_number, '熊本県熊本市中央区草葉町');
ok($zip->set_number('8600844')->is_valid_number, '熊本県熊本市中央区水道町');
ok($zip->set_number('8600845')->is_valid_number, '熊本県熊本市中央区上通町');
ok($zip->set_number('8600846')->is_valid_number, '熊本県熊本市中央区城東町');
ok($zip->set_number('8600847')->is_valid_number, '熊本県熊本市中央区上林町');
ok($zip->set_number('8600848')->is_valid_number, '熊本県熊本市中央区南坪井町');
ok($zip->set_number('8600851')->is_valid_number, '熊本県熊本市中央区子飼本町');
ok($zip->set_number('8600852')->is_valid_number, '熊本県熊本市中央区薬園町');
ok($zip->set_number('8600853')->is_valid_number, '熊本県熊本市中央区西子飼町');
ok($zip->set_number('8600854')->is_valid_number, '熊本県熊本市中央区東子飼町');
ok($zip->set_number('8600855')->is_valid_number, '熊本県熊本市中央区北千反畑町');
ok($zip->set_number('8600856')->is_valid_number, '熊本県熊本市中央区妙体寺町');
ok($zip->set_number('8600861')->is_valid_number, '熊本県熊本市北区黒髪町坪井');
ok($zip->set_number('8600862')->is_valid_number, '熊本県熊本市中央区黒髪');
ok($zip->set_number('8600862')->is_valid_number, '熊本県熊本市北区黒髪');
ok($zip->set_number('8600863')->is_valid_number, '熊本県熊本市中央区坪井');
ok($zip->set_number('8610000')->is_valid_number, '熊本県熊本市中央区以下に掲載がない場合');
ok($zip->set_number('8610000')->is_valid_number, '熊本県熊本市東区以下に掲載がない場合');
ok($zip->set_number('8610000')->is_valid_number, '熊本県熊本市西区以下に掲載がない場合');
ok($zip->set_number('8610000')->is_valid_number, '熊本県熊本市南区以下に掲載がない場合');
ok($zip->set_number('8610000')->is_valid_number, '熊本県熊本市北区以下に掲載がない場合');
ok($zip->set_number('8610101')->is_valid_number, '熊本県熊本市北区植木町山本');
ok($zip->set_number('8610102')->is_valid_number, '熊本県熊本市北区植木町内');
ok($zip->set_number('8610103')->is_valid_number, '熊本県熊本市北区植木町清水');
ok($zip->set_number('8610104')->is_valid_number, '熊本県熊本市北区植木町今藤');
ok($zip->set_number('8610105')->is_valid_number, '熊本県熊本市北区植木町味取');
ok($zip->set_number('8610106')->is_valid_number, '熊本県熊本市北区植木町豊田');
ok($zip->set_number('8610111')->is_valid_number, '熊本県熊本市北区植木町宮原');
ok($zip->set_number('8610112')->is_valid_number, '熊本県熊本市北区植木町田底');
ok($zip->set_number('8610113')->is_valid_number, '熊本県熊本市北区植木町伊知坊');
ok($zip->set_number('8610114')->is_valid_number, '熊本県熊本市北区植木町舟島');
ok($zip->set_number('8610115')->is_valid_number, '熊本県熊本市北区植木町米塚');
ok($zip->set_number('8610116')->is_valid_number, '熊本県熊本市北区植木町色出');
ok($zip->set_number('8610117')->is_valid_number, '熊本県熊本市北区植木町正清');
ok($zip->set_number('8610121')->is_valid_number, '熊本県熊本市北区植木町平井');
ok($zip->set_number('8610122')->is_valid_number, '熊本県熊本市北区植木町古閑');
ok($zip->set_number('8610123')->is_valid_number, '熊本県熊本市北区植木町有泉');
ok($zip->set_number('8610124')->is_valid_number, '熊本県熊本市北区植木町石川');
ok($zip->set_number('8610125')->is_valid_number, '熊本県熊本市北区植木町小野');
ok($zip->set_number('8610126')->is_valid_number, '熊本県熊本市北区植木町大井');
ok($zip->set_number('8610127')->is_valid_number, '熊本県熊本市北区植木町亀甲');
ok($zip->set_number('8610131')->is_valid_number, '熊本県熊本市北区植木町広住');
ok($zip->set_number('8610132')->is_valid_number, '熊本県熊本市北区植木町植木');
ok($zip->set_number('8610133')->is_valid_number, '熊本県熊本市北区植木町滴水');
ok($zip->set_number('8610134')->is_valid_number, '熊本県熊本市北区植木町舞尾');
ok($zip->set_number('8610135')->is_valid_number, '熊本県熊本市北区植木町一木');
ok($zip->set_number('8610136')->is_valid_number, '熊本県熊本市北区植木町岩野');
ok($zip->set_number('8610141')->is_valid_number, '熊本県熊本市北区植木町投刀塚');
ok($zip->set_number('8610142')->is_valid_number, '熊本県熊本市北区植木町鐙田');
ok($zip->set_number('8610143')->is_valid_number, '熊本県熊本市北区植木町大和');
ok($zip->set_number('8610144')->is_valid_number, '熊本県熊本市北区植木町平野');
ok($zip->set_number('8610145')->is_valid_number, '熊本県熊本市北区植木町荻迫');
ok($zip->set_number('8610146')->is_valid_number, '熊本県熊本市北区植木町辺田野');
ok($zip->set_number('8610151')->is_valid_number, '熊本県熊本市北区植木町木留');
ok($zip->set_number('8610152')->is_valid_number, '熊本県熊本市北区植木町上古閑');
ok($zip->set_number('8610153')->is_valid_number, '熊本県熊本市北区植木町円台寺');
ok($zip->set_number('8610154')->is_valid_number, '熊本県熊本市北区植木町那知');
ok($zip->set_number('8610155')->is_valid_number, '熊本県熊本市北区植木町轟');
ok($zip->set_number('8610156')->is_valid_number, '熊本県熊本市北区植木町後古閑');
ok($zip->set_number('8610161')->is_valid_number, '熊本県熊本市北区植木町鞍掛');
ok($zip->set_number('8610162')->is_valid_number, '熊本県熊本市北区植木町富応');
ok($zip->set_number('8610163')->is_valid_number, '熊本県熊本市北区植木町豊岡');
ok($zip->set_number('8610164')->is_valid_number, '熊本県熊本市北区植木町鈴麦');
ok($zip->set_number('8610165')->is_valid_number, '熊本県熊本市北区植木町平原');
ok($zip->set_number('8610301')->is_valid_number, '熊本県山鹿市鹿本町庄');
ok($zip->set_number('8610302')->is_valid_number, '熊本県山鹿市鹿本町津袋');
ok($zip->set_number('8610303')->is_valid_number, '熊本県山鹿市鹿本町高橋');
ok($zip->set_number('8610304')->is_valid_number, '熊本県山鹿市鹿本町御宇田');
ok($zip->set_number('8610311')->is_valid_number, '熊本県山鹿市鹿本町石渕');
ok($zip->set_number('8610312')->is_valid_number, '熊本県山鹿市鹿本町梶屋');
ok($zip->set_number('8610313')->is_valid_number, '熊本県山鹿市鹿本町中富');
ok($zip->set_number('8610314')->is_valid_number, '熊本県山鹿市鹿本町中川');
ok($zip->set_number('8610315')->is_valid_number, '熊本県山鹿市鹿本町小嶋');
ok($zip->set_number('8610316')->is_valid_number, '熊本県山鹿市鹿本町下高橋');
ok($zip->set_number('8610321')->is_valid_number, '熊本県山鹿市鹿本町分田');
ok($zip->set_number('8610322')->is_valid_number, '熊本県山鹿市鹿本町中分田');
ok($zip->set_number('8610323')->is_valid_number, '熊本県山鹿市鹿本町下分田');
ok($zip->set_number('8610324')->is_valid_number, '熊本県山鹿市鹿本町小柳');
ok($zip->set_number('8610331')->is_valid_number, '熊本県山鹿市鹿本町来民');
ok($zip->set_number('8610381')->is_valid_number, '熊本県山鹿市藤井');
ok($zip->set_number('8610382')->is_valid_number, '熊本県山鹿市方保田');
ok($zip->set_number('8610401')->is_valid_number, '熊本県山鹿市菊鹿町長');
ok($zip->set_number('8610402')->is_valid_number, '熊本県山鹿市菊鹿町太田');
ok($zip->set_number('8610403')->is_valid_number, '熊本県山鹿市菊鹿町五郎丸');
ok($zip->set_number('8610404')->is_valid_number, '熊本県山鹿市菊鹿町上永野');
ok($zip->set_number('8610405')->is_valid_number, '熊本県山鹿市菊鹿町下永野');
ok($zip->set_number('8610406')->is_valid_number, '熊本県山鹿市菊鹿町下内田');
ok($zip->set_number('8610411')->is_valid_number, '熊本県山鹿市菊鹿町山内');
ok($zip->set_number('8610412')->is_valid_number, '熊本県山鹿市菊鹿町相良');
ok($zip->set_number('8610413')->is_valid_number, '熊本県山鹿市菊鹿町矢谷');
ok($zip->set_number('8610414')->is_valid_number, '熊本県山鹿市菊鹿町上内田');
ok($zip->set_number('8610421')->is_valid_number, '熊本県山鹿市菊鹿町阿佐古');
ok($zip->set_number('8610422')->is_valid_number, '熊本県山鹿市菊鹿町宮原');
ok($zip->set_number('8610423')->is_valid_number, '熊本県山鹿市菊鹿町池永');
ok($zip->set_number('8610424')->is_valid_number, '熊本県山鹿市菊鹿町松尾');
ok($zip->set_number('8610425')->is_valid_number, '熊本県山鹿市菊鹿町米原');
ok($zip->set_number('8610426')->is_valid_number, '熊本県山鹿市菊鹿町木野');
ok($zip->set_number('8610500')->is_valid_number, '熊本県山鹿市以下に掲載がない場合');
ok($zip->set_number('8610501')->is_valid_number, '熊本県山鹿市山鹿');
ok($zip->set_number('8610511')->is_valid_number, '熊本県山鹿市熊入町');
ok($zip->set_number('8610512')->is_valid_number, '熊本県山鹿市泉町');
ok($zip->set_number('8610513')->is_valid_number, '熊本県山鹿市宗方');
ok($zip->set_number('8610514')->is_valid_number, '熊本県山鹿市新町');
ok($zip->set_number('8610515')->is_valid_number, '熊本県山鹿市昭和町');
ok($zip->set_number('8610516')->is_valid_number, '熊本県山鹿市中央通');
ok($zip->set_number('8610517')->is_valid_number, '熊本県山鹿市大橋通');
ok($zip->set_number('8610518')->is_valid_number, '熊本県山鹿市宗方通');
ok($zip->set_number('8610519')->is_valid_number, '熊本県山鹿市川端町');
ok($zip->set_number('8610521')->is_valid_number, '熊本県山鹿市小坂');
ok($zip->set_number('8610522')->is_valid_number, '熊本県山鹿市久原');
ok($zip->set_number('8610523')->is_valid_number, '熊本県山鹿市蒲生');
ok($zip->set_number('8610524')->is_valid_number, '熊本県山鹿市上吉田');
ok($zip->set_number('8610525')->is_valid_number, '熊本県山鹿市名塚');
ok($zip->set_number('8610526')->is_valid_number, '熊本県山鹿市下吉田');
ok($zip->set_number('8610527')->is_valid_number, '熊本県山鹿市寺島');
ok($zip->set_number('8610531')->is_valid_number, '熊本県山鹿市中');
ok($zip->set_number('8610532')->is_valid_number, '熊本県山鹿市鹿校通');
ok($zip->set_number('8610533')->is_valid_number, '熊本県山鹿市古閑');
ok($zip->set_number('8610534')->is_valid_number, '熊本県山鹿市長坂');
ok($zip->set_number('8610535')->is_valid_number, '熊本県山鹿市南島');
ok($zip->set_number('8610541')->is_valid_number, '熊本県山鹿市鍋田');
ok($zip->set_number('8610542')->is_valid_number, '熊本県山鹿市志々岐');
ok($zip->set_number('8610543')->is_valid_number, '熊本県山鹿市小原');
ok($zip->set_number('8610544')->is_valid_number, '熊本県山鹿市保多田');
ok($zip->set_number('8610545')->is_valid_number, '熊本県山鹿市西牧');
ok($zip->set_number('8610546')->is_valid_number, '熊本県山鹿市坂田');
ok($zip->set_number('8610547')->is_valid_number, '熊本県山鹿市麻生野');
ok($zip->set_number('8610548')->is_valid_number, '熊本県山鹿市椿井');
ok($zip->set_number('8610551')->is_valid_number, '熊本県山鹿市津留');
ok($zip->set_number('8610552')->is_valid_number, '熊本県山鹿市杉');
ok($zip->set_number('8610553')->is_valid_number, '熊本県山鹿市石');
ok($zip->set_number('8610554')->is_valid_number, '熊本県山鹿市城');
ok($zip->set_number('8610555')->is_valid_number, '熊本県山鹿市小群');
ok($zip->set_number('8610556')->is_valid_number, '熊本県山鹿市平山');
ok($zip->set_number('8610561')->is_valid_number, '熊本県山鹿市鹿央町岩原');
ok($zip->set_number('8610562')->is_valid_number, '熊本県山鹿市鹿央町持松');
ok($zip->set_number('8610563')->is_valid_number, '熊本県山鹿市鹿央町千田');
ok($zip->set_number('8610564')->is_valid_number, '熊本県山鹿市鹿央町広');
ok($zip->set_number('8610565')->is_valid_number, '熊本県山鹿市鹿央町合里');
ok($zip->set_number('8610571')->is_valid_number, '熊本県山鹿市鹿央町北谷');
ok($zip->set_number('8610572')->is_valid_number, '熊本県山鹿市鹿央町仁王堂');
ok($zip->set_number('8610573')->is_valid_number, '熊本県山鹿市鹿央町霜野');
ok($zip->set_number('8610574')->is_valid_number, '熊本県山鹿市鹿央町梅木谷');
ok($zip->set_number('8610575')->is_valid_number, '熊本県山鹿市鹿央町中浦');
ok($zip->set_number('8610576')->is_valid_number, '熊本県山鹿市鹿央町大浦');
ok($zip->set_number('8610601')->is_valid_number, '熊本県山鹿市鹿北町四丁');
ok($zip->set_number('8610602')->is_valid_number, '熊本県山鹿市鹿北町芋生');
ok($zip->set_number('8610603')->is_valid_number, '熊本県山鹿市鹿北町岩野');
ok($zip->set_number('8610604')->is_valid_number, '熊本県山鹿市鹿北町椎持');
ok($zip->set_number('8610605')->is_valid_number, '熊本県山鹿市鹿北町多久');
ok($zip->set_number('8610800')->is_valid_number, '熊本県玉名郡南関町以下に掲載がない場合');
ok($zip->set_number('8610801')->is_valid_number, '熊本県玉名郡南関町関外目');
ok($zip->set_number('8610802')->is_valid_number, '熊本県玉名郡南関町関東');
ok($zip->set_number('8610803')->is_valid_number, '熊本県玉名郡南関町関町');
ok($zip->set_number('8610804')->is_valid_number, '熊本県玉名郡南関町関村');
ok($zip->set_number('8610805')->is_valid_number, '熊本県玉名郡南関町関下');
ok($zip->set_number('8610811')->is_valid_number, '熊本県玉名郡南関町小原');
ok($zip->set_number('8610812')->is_valid_number, '熊本県玉名郡南関町相谷');
ok($zip->set_number('8610813')->is_valid_number, '熊本県玉名郡南関町肥猪町');
ok($zip->set_number('8610814')->is_valid_number, '熊本県玉名郡南関町肥猪');
ok($zip->set_number('8610815')->is_valid_number, '熊本県玉名郡南関町豊永');
ok($zip->set_number('8610821')->is_valid_number, '熊本県玉名郡南関町下坂下');
ok($zip->set_number('8610822')->is_valid_number, '熊本県玉名郡南関町上坂下');
ok($zip->set_number('8610823')->is_valid_number, '熊本県玉名郡南関町四ツ原');
ok($zip->set_number('8610831')->is_valid_number, '熊本県玉名郡南関町細永');
ok($zip->set_number('8610832')->is_valid_number, '熊本県玉名郡南関町今');
ok($zip->set_number('8610833')->is_valid_number, '熊本県玉名郡南関町高久野');
ok($zip->set_number('8610834')->is_valid_number, '熊本県玉名郡南関町宮尾');
ok($zip->set_number('8610835')->is_valid_number, '熊本県玉名郡南関町長山');
ok($zip->set_number('8610836')->is_valid_number, '熊本県玉名郡南関町久重');
ok($zip->set_number('8610837')->is_valid_number, '熊本県玉名郡南関町上長田');
ok($zip->set_number('8610901')->is_valid_number, '熊本県玉名郡和水町上和仁');
ok($zip->set_number('8610902')->is_valid_number, '熊本県玉名郡和水町中和仁');
ok($zip->set_number('8610903')->is_valid_number, '熊本県玉名郡和水町和仁');
ok($zip->set_number('8610904')->is_valid_number, '熊本県玉名郡和水町東吉地');
ok($zip->set_number('8610905')->is_valid_number, '熊本県玉名郡和水町中林');
ok($zip->set_number('8610906')->is_valid_number, '熊本県玉名郡和水町西吉地');
ok($zip->set_number('8610911')->is_valid_number, '熊本県玉名郡和水町上十町');
ok($zip->set_number('8610912')->is_valid_number, '熊本県玉名郡和水町中十町');
ok($zip->set_number('8610913')->is_valid_number, '熊本県玉名郡和水町板楠');
ok($zip->set_number('8610914')->is_valid_number, '熊本県玉名郡和水町上板楠');
ok($zip->set_number('8610915')->is_valid_number, '熊本県玉名郡和水町山十町');
ok($zip->set_number('8610921')->is_valid_number, '熊本県玉名郡和水町津田');
ok($zip->set_number('8610922')->is_valid_number, '熊本県玉名郡和水町岩');
ok($zip->set_number('8610923')->is_valid_number, '熊本県玉名郡和水町平野');
ok($zip->set_number('8610924')->is_valid_number, '熊本県玉名郡和水町大田黒');
ok($zip->set_number('8610925')->is_valid_number, '熊本県玉名郡和水町野田');
ok($zip->set_number('8611100')->is_valid_number, '熊本県合志市以下に掲載がない場合');
ok($zip->set_number('8611101')->is_valid_number, '熊本県合志市合生');
ok($zip->set_number('8611102')->is_valid_number, '熊本県合志市須屋');
ok($zip->set_number('8611103')->is_valid_number, '熊本県合志市野々島');
ok($zip->set_number('8611104')->is_valid_number, '熊本県合志市御代志');
ok($zip->set_number('8611105')->is_valid_number, '熊本県合志市上生');
ok($zip->set_number('8611111')->is_valid_number, '熊本県合志市上庄');
ok($zip->set_number('8611112')->is_valid_number, '熊本県合志市幾久富');
ok($zip->set_number('8611113')->is_valid_number, '熊本県合志市栄');
ok($zip->set_number('8611114')->is_valid_number, '熊本県合志市竹迫');
ok($zip->set_number('8611115')->is_valid_number, '熊本県合志市豊岡');
ok($zip->set_number('8611116')->is_valid_number, '熊本県合志市福原');
ok($zip->set_number('8611201')->is_valid_number, '熊本県菊池市泗水町吉富');
ok($zip->set_number('8611202')->is_valid_number, '熊本県菊池市泗水町富納');
ok($zip->set_number('8611203')->is_valid_number, '熊本県菊池市泗水町住吉');
ok($zip->set_number('8611204')->is_valid_number, '熊本県菊池市泗水町永');
ok($zip->set_number('8611205')->is_valid_number, '熊本県菊池市泗水町福本');
ok($zip->set_number('8611211')->is_valid_number, '熊本県菊池市泗水町亀尾');
ok($zip->set_number('8611212')->is_valid_number, '熊本県菊池市泗水町豊水');
ok($zip->set_number('8611213')->is_valid_number, '熊本県菊池市泗水町南田島');
ok($zip->set_number('8611214')->is_valid_number, '熊本県菊池市泗水町田島');
ok($zip->set_number('8611300')->is_valid_number, '熊本県菊池市以下に掲載がない場合');
ok($zip->set_number('8611301')->is_valid_number, '熊本県菊池市木庭');
ok($zip->set_number('8611302')->is_valid_number, '熊本県菊池市下河原');
ok($zip->set_number('8611303')->is_valid_number, '熊本県菊池市今');
ok($zip->set_number('8611304')->is_valid_number, '熊本県菊池市深川');
ok($zip->set_number('8611305')->is_valid_number, '熊本県菊池市北宮');
ok($zip->set_number('8611306')->is_valid_number, '熊本県菊池市大琳寺');
ok($zip->set_number('8611307')->is_valid_number, '熊本県菊池市片角');
ok($zip->set_number('8611308')->is_valid_number, '熊本県菊池市亘');
ok($zip->set_number('8611309')->is_valid_number, '熊本県菊池市藤田');
ok($zip->set_number('8611311')->is_valid_number, '熊本県菊池市赤星');
ok($zip->set_number('8611312')->is_valid_number, '熊本県菊池市森北');
ok($zip->set_number('8611313')->is_valid_number, '熊本県菊池市出田');
ok($zip->set_number('8611314')->is_valid_number, '熊本県菊池市広瀬');
ok($zip->set_number('8611315')->is_valid_number, '熊本県菊池市木柑子');
ok($zip->set_number('8611316')->is_valid_number, '熊本県菊池市長田');
ok($zip->set_number('8611317')->is_valid_number, '熊本県菊池市村田');
ok($zip->set_number('8611321')->is_valid_number, '熊本県菊池市稗方');
ok($zip->set_number('8611322')->is_valid_number, '熊本県菊池市玉祥寺');
ok($zip->set_number('8611323')->is_valid_number, '熊本県菊池市西寺');
ok($zip->set_number('8611324')->is_valid_number, '熊本県菊池市野間口');
ok($zip->set_number('8611325')->is_valid_number, '熊本県菊池市袈裟尾');
ok($zip->set_number('8611326')->is_valid_number, '熊本県菊池市木野');
ok($zip->set_number('8611331')->is_valid_number, '熊本県菊池市隈府');
ok($zip->set_number('8611341')->is_valid_number, '熊本県菊池市七城町清水');
ok($zip->set_number('8611342')->is_valid_number, '熊本県菊池市七城町亀尾');
ok($zip->set_number('8611343')->is_valid_number, '熊本県菊池市七城町林原');
ok($zip->set_number('8611344')->is_valid_number, '熊本県菊池市七城町蘇崎');
ok($zip->set_number('8611345')->is_valid_number, '熊本県菊池市七城町小野崎');
ok($zip->set_number('8611346')->is_valid_number, '熊本県菊池市七城町橋田');
ok($zip->set_number('8611351')->is_valid_number, '熊本県菊池市七城町砂田');
ok($zip->set_number('8611352')->is_valid_number, '熊本県菊池市七城町新古閑');
ok($zip->set_number('8611353')->is_valid_number, '熊本県菊池市七城町甲佐町');
ok($zip->set_number('8611354')->is_valid_number, '熊本県菊池市七城町菰入');
ok($zip->set_number('8611355')->is_valid_number, '熊本県菊池市七城町高島');
ok($zip->set_number('8611356')->is_valid_number, '熊本県菊池市七城町加恵');
ok($zip->set_number('8611357')->is_valid_number, '熊本県菊池市七城町高田');
ok($zip->set_number('8611361')->is_valid_number, '熊本県菊池市七城町水次');
ok($zip->set_number('8611362')->is_valid_number, '熊本県菊池市七城町山崎');
ok($zip->set_number('8611363')->is_valid_number, '熊本県菊池市七城町荒牧');
ok($zip->set_number('8611364')->is_valid_number, '熊本県菊池市七城町辺田');
ok($zip->set_number('8611365')->is_valid_number, '熊本県菊池市七城町台');
ok($zip->set_number('8611366')->is_valid_number, '熊本県菊池市七城町瀬戸口');
ok($zip->set_number('8611367')->is_valid_number, '熊本県菊池市七城町流川');
ok($zip->set_number('8611368')->is_valid_number, '熊本県菊池市七城町岡田');
ok($zip->set_number('8611441')->is_valid_number, '熊本県菊池市原');
ok($zip->set_number('8611442')->is_valid_number, '熊本県菊池市四町分');
ok($zip->set_number('8611671')->is_valid_number, '熊本県菊池市班蛇口');
ok($zip->set_number('8611672')->is_valid_number, '熊本県菊池市龍門');
ok($zip->set_number('8611673')->is_valid_number, '熊本県菊池市小木');
ok($zip->set_number('8611681')->is_valid_number, '熊本県菊池市雪野');
ok($zip->set_number('8611682')->is_valid_number, '熊本県菊池市重味');
ok($zip->set_number('8611683')->is_valid_number, '熊本県菊池市大平');
ok($zip->set_number('8611684')->is_valid_number, '熊本県菊池市豊間');
ok($zip->set_number('8611685')->is_valid_number, '熊本県菊池市西迫間');
ok($zip->set_number('8611686')->is_valid_number, '熊本県菊池市市野瀬');
ok($zip->set_number('8612101')->is_valid_number, '熊本県熊本市東区桜木');
ok($zip->set_number('8612102')->is_valid_number, '熊本県熊本市東区沼山津');
ok($zip->set_number('8612103')->is_valid_number, '熊本県熊本市東区若葉(4~6丁目)');
ok($zip->set_number('8612104')->is_valid_number, '熊本県熊本市東区秋津');
ok($zip->set_number('8612105')->is_valid_number, '熊本県熊本市東区秋津町秋田');
ok($zip->set_number('8612106')->is_valid_number, '熊本県熊本市東区東野');
ok($zip->set_number('8612107')->is_valid_number, '熊本県熊本市東区秋津新町');
ok($zip->set_number('8612108')->is_valid_number, '熊本県熊本市東区昭和町');
ok($zip->set_number('8612118')->is_valid_number, '熊本県熊本市東区花立(1~4丁目)');
ok($zip->set_number('8612200')->is_valid_number, '熊本県上益城郡益城町以下に掲載がない場合');
ok($zip->set_number('8612201')->is_valid_number, '熊本県上益城郡益城町寺中');
ok($zip->set_number('8612202')->is_valid_number, '熊本県上益城郡益城町田原');
ok($zip->set_number('8612203')->is_valid_number, '熊本県上益城郡益城町上陳');
ok($zip->set_number('8612204')->is_valid_number, '熊本県上益城郡益城町小谷');
ok($zip->set_number('8612205')->is_valid_number, '熊本県上益城郡益城町杉堂');
ok($zip->set_number('8612206')->is_valid_number, '熊本県上益城郡益城町下陳');
ok($zip->set_number('8612211')->is_valid_number, '熊本県上益城郡益城町福原');
ok($zip->set_number('8612212')->is_valid_number, '熊本県上益城郡益城町平田');
ok($zip->set_number('8612221')->is_valid_number, '熊本県上益城郡益城町赤井');
ok($zip->set_number('8612222')->is_valid_number, '熊本県上益城郡益城町砥川');
ok($zip->set_number('8612223')->is_valid_number, '熊本県上益城郡益城町小池');
ok($zip->set_number('8612224')->is_valid_number, '熊本県上益城郡益城町島田');
ok($zip->set_number('8612231')->is_valid_number, '熊本県上益城郡益城町安永');
ok($zip->set_number('8612232')->is_valid_number, '熊本県上益城郡益城町馬水');
ok($zip->set_number('8612233')->is_valid_number, '熊本県上益城郡益城町惣領');
ok($zip->set_number('8612234')->is_valid_number, '熊本県上益城郡益城町古閑');
ok($zip->set_number('8612235')->is_valid_number, '熊本県上益城郡益城町福富');
ok($zip->set_number('8612236')->is_valid_number, '熊本県上益城郡益城町広崎');
ok($zip->set_number('8612241')->is_valid_number, '熊本県上益城郡益城町宮園');
ok($zip->set_number('8612242')->is_valid_number, '熊本県上益城郡益城町木山');
ok($zip->set_number('8612243')->is_valid_number, '熊本県上益城郡益城町辻の城');
ok($zip->set_number('8612244')->is_valid_number, '熊本県上益城郡益城町寺迫');
ok($zip->set_number('8612400')->is_valid_number, '熊本県阿蘇郡西原村以下に掲載がない場合');
ok($zip->set_number('8612401')->is_valid_number, '熊本県阿蘇郡西原村鳥子');
ok($zip->set_number('8612402')->is_valid_number, '熊本県阿蘇郡西原村小森');
ok($zip->set_number('8612403')->is_valid_number, '熊本県阿蘇郡西原村布田');
ok($zip->set_number('8612404')->is_valid_number, '熊本県阿蘇郡西原村河原');
ok($zip->set_number('8612405')->is_valid_number, '熊本県阿蘇郡西原村宮山');
ok($zip->set_number('8613100')->is_valid_number, '熊本県上益城郡嘉島町以下に掲載がない場合');
ok($zip->set_number('8613101')->is_valid_number, '熊本県上益城郡嘉島町鯰');
ok($zip->set_number('8613102')->is_valid_number, '熊本県上益城郡嘉島町下六嘉');
ok($zip->set_number('8613103')->is_valid_number, '熊本県上益城郡嘉島町井寺');
ok($zip->set_number('8613104')->is_valid_number, '熊本県上益城郡嘉島町北甘木');
ok($zip->set_number('8613105')->is_valid_number, '熊本県上益城郡嘉島町上六嘉');
ok($zip->set_number('8613106')->is_valid_number, '熊本県上益城郡嘉島町上島');
ok($zip->set_number('8613107')->is_valid_number, '熊本県上益城郡嘉島町上仲間');
ok($zip->set_number('8613108')->is_valid_number, '熊本県上益城郡嘉島町下仲間');
ok($zip->set_number('8613109')->is_valid_number, '熊本県上益城郡嘉島町犬渕');
ok($zip->set_number('8613131')->is_valid_number, '熊本県上益城郡御船町豊秋');
ok($zip->set_number('8613200')->is_valid_number, '熊本県上益城郡御船町以下に掲載がない場合');
ok($zip->set_number('8613201')->is_valid_number, '熊本県上益城郡御船町陣');
ok($zip->set_number('8613202')->is_valid_number, '熊本県上益城郡御船町小坂');
ok($zip->set_number('8613203')->is_valid_number, '熊本県上益城郡御船町高木');
ok($zip->set_number('8613204')->is_valid_number, '熊本県上益城郡御船町木倉');
ok($zip->set_number('8613205')->is_valid_number, '熊本県上益城郡御船町滝川');
ok($zip->set_number('8613206')->is_valid_number, '熊本県上益城郡御船町辺田見');
ok($zip->set_number('8613207')->is_valid_number, '熊本県上益城郡御船町御船');
ok($zip->set_number('8613208')->is_valid_number, '熊本県上益城郡御船町滝尾');
ok($zip->set_number('8613211')->is_valid_number, '熊本県上益城郡御船町水越');
ok($zip->set_number('8613241')->is_valid_number, '熊本県上益城郡甲佐町早川');
ok($zip->set_number('8613242')->is_valid_number, '熊本県上益城郡甲佐町糸田');
ok($zip->set_number('8613243')->is_valid_number, '熊本県上益城郡甲佐町白旗');
ok($zip->set_number('8613244')->is_valid_number, '熊本県上益城郡甲佐町芝原');
ok($zip->set_number('8613245')->is_valid_number, '熊本県上益城郡甲佐町吉田');
ok($zip->set_number('8613321')->is_valid_number, '熊本県上益城郡御船町七滝(その他)');
ok($zip->set_number('8613322')->is_valid_number, '熊本県上益城郡御船町上野');
ok($zip->set_number('8613323')->is_valid_number, '熊本県上益城郡御船町田代');
ok($zip->set_number('8613421')->is_valid_number, '熊本県上益城郡御船町七滝(松ノ生)');
ok($zip->set_number('8613451')->is_valid_number, '熊本県上益城郡山都町金内');
ok($zip->set_number('8613452')->is_valid_number, '熊本県上益城郡山都町田小野');
ok($zip->set_number('8613453')->is_valid_number, '熊本県上益城郡山都町原');
ok($zip->set_number('8613454')->is_valid_number, '熊本県上益城郡山都町島木');
ok($zip->set_number('8613455')->is_valid_number, '熊本県上益城郡山都町北中島');
ok($zip->set_number('8613500')->is_valid_number, '熊本県上益城郡山都町以下に掲載がない場合');
ok($zip->set_number('8613501')->is_valid_number, '熊本県上益城郡山都町黒川');
ok($zip->set_number('8613502')->is_valid_number, '熊本県上益城郡山都町御所');
ok($zip->set_number('8613503')->is_valid_number, '熊本県上益城郡山都町下名連石');
ok($zip->set_number('8613511')->is_valid_number, '熊本県上益城郡山都町入佐');
ok($zip->set_number('8613512')->is_valid_number, '熊本県上益城郡山都町下馬尾');
ok($zip->set_number('8613513')->is_valid_number, '熊本県上益城郡山都町下市');
ok($zip->set_number('8613514')->is_valid_number, '熊本県上益城郡山都町城原');
ok($zip->set_number('8613515')->is_valid_number, '熊本県上益城郡山都町城平');
ok($zip->set_number('8613516')->is_valid_number, '熊本県上益城郡山都町千滝');
ok($zip->set_number('8613517')->is_valid_number, '熊本県上益城郡山都町畑');
ok($zip->set_number('8613518')->is_valid_number, '熊本県上益城郡山都町浜町');
ok($zip->set_number('8613521')->is_valid_number, '熊本県上益城郡山都町荒谷');
ok($zip->set_number('8613522')->is_valid_number, '熊本県上益城郡山都町白小野');
ok($zip->set_number('8613523')->is_valid_number, '熊本県上益城郡山都町勢井');
ok($zip->set_number('8613524')->is_valid_number, '熊本県上益城郡山都町藤木');
ok($zip->set_number('8613525')->is_valid_number, '熊本県上益城郡山都町牧野');
ok($zip->set_number('8613526')->is_valid_number, '熊本県上益城郡山都町万坂');
ok($zip->set_number('8613531')->is_valid_number, '熊本県上益城郡山都町葛原');
ok($zip->set_number('8613532')->is_valid_number, '熊本県上益城郡山都町猿渡');
ok($zip->set_number('8613533')->is_valid_number, '熊本県上益城郡山都町三ケ');
ok($zip->set_number('8613534')->is_valid_number, '熊本県上益城郡山都町柚木');
ok($zip->set_number('8613541')->is_valid_number, '熊本県上益城郡山都町芦屋田');
ok($zip->set_number('8613542')->is_valid_number, '熊本県上益城郡山都町市原');
ok($zip->set_number('8613543')->is_valid_number, '熊本県上益城郡山都町上寺');
ok($zip->set_number('8613544')->is_valid_number, '熊本県上益城郡山都町杉木');
ok($zip->set_number('8613545')->is_valid_number, '熊本県上益城郡山都町長田');
ok($zip->set_number('8613546')->is_valid_number, '熊本県上益城郡山都町南田');
ok($zip->set_number('8613547')->is_valid_number, '熊本県上益城郡山都町山田');
ok($zip->set_number('8613661')->is_valid_number, '熊本県上益城郡山都町長原');
ok($zip->set_number('8613662')->is_valid_number, '熊本県上益城郡山都町田吉');
ok($zip->set_number('8613663')->is_valid_number, '熊本県上益城郡山都町新小');
ok($zip->set_number('8613664')->is_valid_number, '熊本県上益城郡山都町白藤');
ok($zip->set_number('8613665')->is_valid_number, '熊本県上益城郡山都町犬飼');
ok($zip->set_number('8613671')->is_valid_number, '熊本県上益城郡山都町菅');
ok($zip->set_number('8613672')->is_valid_number, '熊本県上益城郡山都町目丸');
ok($zip->set_number('8613673')->is_valid_number, '熊本県上益城郡山都町津留');
ok($zip->set_number('8613781')->is_valid_number, '熊本県上益城郡山都町麻山');
ok($zip->set_number('8613782')->is_valid_number, '熊本県上益城郡山都町上川井野');
ok($zip->set_number('8613783')->is_valid_number, '熊本県上益城郡山都町成君');
ok($zip->set_number('8613784')->is_valid_number, '熊本県上益城郡山都町川野');
ok($zip->set_number('8613785')->is_valid_number, '熊本県上益城郡山都町田所');
ok($zip->set_number('8613786')->is_valid_number, '熊本県上益城郡山都町下川井野');
ok($zip->set_number('8613787')->is_valid_number, '熊本県上益城郡山都町野尻');
ok($zip->set_number('8613788')->is_valid_number, '熊本県上益城郡山都町小笹');
ok($zip->set_number('8613789')->is_valid_number, '熊本県上益城郡山都町男成');
ok($zip->set_number('8613801')->is_valid_number, '熊本県上益城郡山都町小峰');
ok($zip->set_number('8613802')->is_valid_number, '熊本県上益城郡山都町木原谷');
ok($zip->set_number('8613803')->is_valid_number, '熊本県上益城郡山都町小中竹');
ok($zip->set_number('8613804')->is_valid_number, '熊本県上益城郡山都町貫原');
ok($zip->set_number('8613805')->is_valid_number, '熊本県上益城郡山都町須原');
ok($zip->set_number('8613806')->is_valid_number, '熊本県上益城郡山都町米生');
ok($zip->set_number('8613811')->is_valid_number, '熊本県上益城郡山都町大平');
ok($zip->set_number('8613812')->is_valid_number, '熊本県上益城郡山都町鶴ケ田');
ok($zip->set_number('8613813')->is_valid_number, '熊本県上益城郡山都町川口');
ok($zip->set_number('8613831')->is_valid_number, '熊本県上益城郡山都町郷野原');
ok($zip->set_number('8613832')->is_valid_number, '熊本県上益城郡山都町井無田');
ok($zip->set_number('8613833')->is_valid_number, '熊本県上益城郡山都町安方');
ok($zip->set_number('8613834')->is_valid_number, '熊本県上益城郡山都町高月');
ok($zip->set_number('8613835')->is_valid_number, '熊本県上益城郡山都町仏原');
ok($zip->set_number('8613841')->is_valid_number, '熊本県上益城郡山都町仮屋');
ok($zip->set_number('8613842')->is_valid_number, '熊本県上益城郡山都町市野原');
ok($zip->set_number('8613843')->is_valid_number, '熊本県上益城郡山都町鎌野');
ok($zip->set_number('8613844')->is_valid_number, '熊本県上益城郡山都町尾野尻');
ok($zip->set_number('8613845')->is_valid_number, '熊本県上益城郡山都町緑川');
ok($zip->set_number('8613901')->is_valid_number, '熊本県上益城郡山都町馬見原');
ok($zip->set_number('8613902')->is_valid_number, '熊本県上益城郡山都町滝上');
ok($zip->set_number('8613903')->is_valid_number, '熊本県上益城郡山都町柳井原');
ok($zip->set_number('8613904')->is_valid_number, '熊本県上益城郡山都町方ケ野');
ok($zip->set_number('8613905')->is_valid_number, '熊本県上益城郡山都町大野');
ok($zip->set_number('8613906')->is_valid_number, '熊本県上益城郡山都町神ノ前');
ok($zip->set_number('8613907')->is_valid_number, '熊本県上益城郡山都町白石');
ok($zip->set_number('8613908')->is_valid_number, '熊本県上益城郡山都町長崎');
ok($zip->set_number('8613911')->is_valid_number, '熊本県上益城郡山都町菅尾');
ok($zip->set_number('8613912')->is_valid_number, '熊本県上益城郡山都町米迫');
ok($zip->set_number('8613913')->is_valid_number, '熊本県上益城郡山都町今');
ok($zip->set_number('8613914')->is_valid_number, '熊本県上益城郡山都町花上');
ok($zip->set_number('8613915')->is_valid_number, '熊本県上益城郡山都町塩出迫');
ok($zip->set_number('8613916')->is_valid_number, '熊本県上益城郡山都町塩原');
ok($zip->set_number('8613921')->is_valid_number, '熊本県上益城郡山都町八木');
ok($zip->set_number('8613922')->is_valid_number, '熊本県上益城郡山都町二瀬本');
ok($zip->set_number('8613923')->is_valid_number, '熊本県上益城郡山都町柏');
ok($zip->set_number('8613924')->is_valid_number, '熊本県上益城郡山都町二津留');
ok($zip->set_number('8613925')->is_valid_number, '熊本県上益城郡山都町上差尾');
ok($zip->set_number('8613926')->is_valid_number, '熊本県上益城郡山都町大見口');
ok($zip->set_number('8613927')->is_valid_number, '熊本県上益城郡山都町玉目');
ok($zip->set_number('8613928')->is_valid_number, '熊本県上益城郡山都町長谷');
ok($zip->set_number('8613931')->is_valid_number, '熊本県上益城郡山都町橘');
ok($zip->set_number('8613932')->is_valid_number, '熊本県上益城郡山都町下山');
ok($zip->set_number('8613933')->is_valid_number, '熊本県上益城郡山都町高辻');
ok($zip->set_number('8613934')->is_valid_number, '熊本県上益城郡山都町高畑');
ok($zip->set_number('8613935')->is_valid_number, '熊本県上益城郡山都町東竹原');
ok($zip->set_number('8613936')->is_valid_number, '熊本県上益城郡山都町柳');
ok($zip->set_number('8613937')->is_valid_number, '熊本県上益城郡山都町伊勢');
ok($zip->set_number('8614101')->is_valid_number, '熊本県熊本市南区近見');
ok($zip->set_number('8614102')->is_valid_number, '熊本県熊本市南区御幸西無田町');
ok($zip->set_number('8614103')->is_valid_number, '熊本県熊本市南区御幸笛田町');
ok($zip->set_number('8614104')->is_valid_number, '熊本県熊本市南区御幸木部町');
ok($zip->set_number('8614105')->is_valid_number, '熊本県熊本市南区元三町');
ok($zip->set_number('8614106')->is_valid_number, '熊本県熊本市南区南高江');
ok($zip->set_number('8614108')->is_valid_number, '熊本県熊本市南区幸田');
ok($zip->set_number('8614109')->is_valid_number, '熊本県熊本市南区日吉');
ok($zip->set_number('8614111')->is_valid_number, '熊本県熊本市南区合志');
ok($zip->set_number('8614112')->is_valid_number, '熊本県熊本市南区白藤');
ok($zip->set_number('8614113')->is_valid_number, '熊本県熊本市南区八幡');
ok($zip->set_number('8614114')->is_valid_number, '熊本県熊本市南区野田');
ok($zip->set_number('8614115')->is_valid_number, '熊本県熊本市南区川尻');
ok($zip->set_number('8614116')->is_valid_number, '熊本県熊本市南区中無田町');
ok($zip->set_number('8614117')->is_valid_number, '熊本県熊本市南区護藤町');
ok($zip->set_number('8614121')->is_valid_number, '熊本県熊本市南区会富町');
ok($zip->set_number('8614122')->is_valid_number, '熊本県熊本市南区美登里町');
ok($zip->set_number('8614123')->is_valid_number, '熊本県熊本市南区川口町');
ok($zip->set_number('8614124')->is_valid_number, '熊本県熊本市南区海路口町');
ok($zip->set_number('8614125')->is_valid_number, '熊本県熊本市南区奥古閑町');
ok($zip->set_number('8614126')->is_valid_number, '熊本県熊本市南区銭塘町');
ok($zip->set_number('8614127')->is_valid_number, '熊本県熊本市南区内田町');
ok($zip->set_number('8614131')->is_valid_number, '熊本県熊本市南区薄場');
ok($zip->set_number('8614131')->is_valid_number, '熊本県熊本市南区薄場町');
ok($zip->set_number('8614132')->is_valid_number, '熊本県熊本市南区上ノ郷');
ok($zip->set_number('8614133')->is_valid_number, '熊本県熊本市南区島町');
ok($zip->set_number('8614134')->is_valid_number, '熊本県熊本市南区刈草');
ok($zip->set_number('8614135')->is_valid_number, '熊本県熊本市南区鳶町');
ok($zip->set_number('8614136')->is_valid_number, '熊本県熊本市南区荒尾');
ok($zip->set_number('8614136')->is_valid_number, '熊本県熊本市南区荒尾町');
ok($zip->set_number('8614137')->is_valid_number, '熊本県熊本市南区野口');
ok($zip->set_number('8614137')->is_valid_number, '熊本県熊本市南区野口町');
ok($zip->set_number('8614141')->is_valid_number, '熊本県熊本市南区富合町御船手');
ok($zip->set_number('8614142')->is_valid_number, '熊本県熊本市南区富合町杉島');
ok($zip->set_number('8614143')->is_valid_number, '熊本県熊本市南区富合町上杉');
ok($zip->set_number('8614144')->is_valid_number, '熊本県熊本市南区富合町釈迦堂');
ok($zip->set_number('8614145')->is_valid_number, '熊本県熊本市南区富合町大町');
ok($zip->set_number('8614146')->is_valid_number, '熊本県熊本市南区富合町榎津');
ok($zip->set_number('8614147')->is_valid_number, '熊本県熊本市南区富合町廻江');
ok($zip->set_number('8614151')->is_valid_number, '熊本県熊本市南区富合町清藤');
ok($zip->set_number('8614152')->is_valid_number, '熊本県熊本市南区富合町新');
ok($zip->set_number('8614153')->is_valid_number, '熊本県熊本市南区富合町木原');
ok($zip->set_number('8614154')->is_valid_number, '熊本県熊本市南区富合町平原');
ok($zip->set_number('8614155')->is_valid_number, '熊本県熊本市南区富合町南田尻');
ok($zip->set_number('8614156')->is_valid_number, '熊本県熊本市南区富合町田尻');
ok($zip->set_number('8614157')->is_valid_number, '熊本県熊本市南区富合町古閑');
ok($zip->set_number('8614161')->is_valid_number, '熊本県熊本市南区富合町小岩瀬');
ok($zip->set_number('8614162')->is_valid_number, '熊本県熊本市南区富合町国町');
ok($zip->set_number('8614163')->is_valid_number, '熊本県熊本市南区富合町志々水');
ok($zip->set_number('8614164')->is_valid_number, '熊本県熊本市南区富合町西田尻');
ok($zip->set_number('8614165')->is_valid_number, '熊本県熊本市南区富合町硴江');
ok($zip->set_number('8614166')->is_valid_number, '熊本県熊本市南区富合町莎崎');
ok($zip->set_number('8614167')->is_valid_number, '熊本県熊本市南区富合町菰江');
ok($zip->set_number('8614171')->is_valid_number, '熊本県熊本市南区御幸西');
ok($zip->set_number('8614172')->is_valid_number, '熊本県熊本市南区御幸笛田');
ok($zip->set_number('8614173')->is_valid_number, '熊本県熊本市南区御幸木部');
ok($zip->set_number('8614201')->is_valid_number, '熊本県熊本市南区城南町坂野');
ok($zip->set_number('8614202')->is_valid_number, '熊本県熊本市南区城南町宮地');
ok($zip->set_number('8614203')->is_valid_number, '熊本県熊本市南区城南町隈庄');
ok($zip->set_number('8614204')->is_valid_number, '熊本県熊本市南区城南町下宮地');
ok($zip->set_number('8614205')->is_valid_number, '熊本県熊本市南区城南町碇');
ok($zip->set_number('8614206')->is_valid_number, '熊本県熊本市南区城南町さんさん');
ok($zip->set_number('8614211')->is_valid_number, '熊本県熊本市南区城南町今吉野');
ok($zip->set_number('8614212')->is_valid_number, '熊本県熊本市南区城南町築地');
ok($zip->set_number('8614213')->is_valid_number, '熊本県熊本市南区城南町出水');
ok($zip->set_number('8614214')->is_valid_number, '熊本県熊本市南区城南町舞原');
ok($zip->set_number('8614215')->is_valid_number, '熊本県熊本市南区城南町沈目');
ok($zip->set_number('8614221')->is_valid_number, '熊本県熊本市南区城南町陳内');
ok($zip->set_number('8614222')->is_valid_number, '熊本県熊本市南区城南町鰐瀬');
ok($zip->set_number('8614223')->is_valid_number, '熊本県熊本市南区城南町藤山');
ok($zip->set_number('8614224')->is_valid_number, '熊本県熊本市南区城南町阿高');
ok($zip->set_number('8614225')->is_valid_number, '熊本県熊本市南区城南町東阿高');
ok($zip->set_number('8614226')->is_valid_number, '熊本県熊本市南区城南町塚原');
ok($zip->set_number('8614231')->is_valid_number, '熊本県熊本市南区城南町赤見');
ok($zip->set_number('8614232')->is_valid_number, '熊本県熊本市南区城南町高');
ok($zip->set_number('8614233')->is_valid_number, '熊本県熊本市南区城南町丹生宮');
ok($zip->set_number('8614234')->is_valid_number, '熊本県熊本市南区城南町永');
ok($zip->set_number('8614235')->is_valid_number, '熊本県熊本市南区城南町千町');
ok($zip->set_number('8614236')->is_valid_number, '熊本県熊本市南区城南町島田');
ok($zip->set_number('8614237')->is_valid_number, '熊本県熊本市南区城南町六田');
ok($zip->set_number('8614301')->is_valid_number, '熊本県宇城市豊野町糸石');
ok($zip->set_number('8614302')->is_valid_number, '熊本県宇城市豊野町中間');
ok($zip->set_number('8614303')->is_valid_number, '熊本県宇城市豊野町上郷');
ok($zip->set_number('8614304')->is_valid_number, '熊本県宇城市豊野町下郷');
ok($zip->set_number('8614305')->is_valid_number, '熊本県宇城市豊野町山崎');
ok($zip->set_number('8614306')->is_valid_number, '熊本県宇城市豊野町安見');
ok($zip->set_number('8614307')->is_valid_number, '熊本県宇城市豊野町巣林');
ok($zip->set_number('8614401')->is_valid_number, '熊本県下益城郡美里町大沢水');
ok($zip->set_number('8614402')->is_valid_number, '熊本県下益城郡美里町堅志田');
ok($zip->set_number('8614403')->is_valid_number, '熊本県下益城郡美里町中郡');
ok($zip->set_number('8614404')->is_valid_number, '熊本県下益城郡美里町岩下');
ok($zip->set_number('8614405')->is_valid_number, '熊本県下益城郡美里町萱野');
ok($zip->set_number('8614406')->is_valid_number, '熊本県下益城郡美里町馬場');
ok($zip->set_number('8614407')->is_valid_number, '熊本県下益城郡美里町中小路');
ok($zip->set_number('8614411')->is_valid_number, '熊本県下益城郡美里町小筵');
ok($zip->set_number('8614412')->is_valid_number, '熊本県下益城郡美里町佐俣');
ok($zip->set_number('8614413')->is_valid_number, '熊本県下益城郡美里町岩野');
ok($zip->set_number('8614414')->is_valid_number, '熊本県下益城郡美里町椿');
ok($zip->set_number('8614415')->is_valid_number, '熊本県下益城郡美里町坂本');
ok($zip->set_number('8614416')->is_valid_number, '熊本県下益城郡美里町払川');
ok($zip->set_number('8614417')->is_valid_number, '熊本県下益城郡美里町中');
ok($zip->set_number('8614421')->is_valid_number, '熊本県下益城郡美里町原田');
ok($zip->set_number('8614422')->is_valid_number, '熊本県下益城郡美里町長尾野');
ok($zip->set_number('8614423')->is_valid_number, '熊本県下益城郡美里町松野原');
ok($zip->set_number('8614424')->is_valid_number, '熊本県下益城郡美里町小市野');
ok($zip->set_number('8614425')->is_valid_number, '熊本県下益城郡美里町木早川内');
ok($zip->set_number('8614426')->is_valid_number, '熊本県下益城郡美里町白石野');
ok($zip->set_number('8614427')->is_valid_number, '熊本県下益城郡美里町津留');
ok($zip->set_number('8614600')->is_valid_number, '熊本県上益城郡甲佐町以下に掲載がない場合');
ok($zip->set_number('8614601')->is_valid_number, '熊本県上益城郡甲佐町岩下');
ok($zip->set_number('8614602')->is_valid_number, '熊本県上益城郡甲佐町緑町');
ok($zip->set_number('8614603')->is_valid_number, '熊本県上益城郡甲佐町仁田子');
ok($zip->set_number('8614604')->is_valid_number, '熊本県上益城郡甲佐町大町');
ok($zip->set_number('8614605')->is_valid_number, '熊本県上益城郡甲佐町有安');
ok($zip->set_number('8614606')->is_valid_number, '熊本県上益城郡甲佐町横田');
ok($zip->set_number('8614607')->is_valid_number, '熊本県上益城郡甲佐町豊内');
ok($zip->set_number('8614608')->is_valid_number, '熊本県上益城郡甲佐町東寒野');
ok($zip->set_number('8614609')->is_valid_number, '熊本県上益城郡甲佐町西寒野');
ok($zip->set_number('8614611')->is_valid_number, '熊本県上益城郡甲佐町船津');
ok($zip->set_number('8614612')->is_valid_number, '熊本県上益城郡甲佐町世持');
ok($zip->set_number('8614613')->is_valid_number, '熊本県上益城郡甲佐町南三箇');
ok($zip->set_number('8614614')->is_valid_number, '熊本県上益城郡甲佐町中山');
ok($zip->set_number('8614615')->is_valid_number, '熊本県上益城郡甲佐町府領');
ok($zip->set_number('8614616')->is_valid_number, '熊本県上益城郡甲佐町田口');
ok($zip->set_number('8614617')->is_valid_number, '熊本県上益城郡甲佐町津志田');
ok($zip->set_number('8614618')->is_valid_number, '熊本県上益城郡甲佐町麻生原');
ok($zip->set_number('8614621')->is_valid_number, '熊本県上益城郡甲佐町下横田');
ok($zip->set_number('8614622')->is_valid_number, '熊本県上益城郡甲佐町上早川');
ok($zip->set_number('8614623')->is_valid_number, '熊本県上益城郡甲佐町中横田');
ok($zip->set_number('8614631')->is_valid_number, '熊本県上益城郡甲佐町上揚');
ok($zip->set_number('8614632')->is_valid_number, '熊本県上益城郡甲佐町坂谷');
ok($zip->set_number('8614633')->is_valid_number, '熊本県上益城郡甲佐町西原');
ok($zip->set_number('8614634')->is_valid_number, '熊本県上益城郡甲佐町小鹿');
ok($zip->set_number('8614635')->is_valid_number, '熊本県上益城郡甲佐町安平');
ok($zip->set_number('8614700')->is_valid_number, '熊本県下益城郡美里町以下に掲載がない場合');
ok($zip->set_number('8614701')->is_valid_number, '熊本県下益城郡美里町大井早');
ok($zip->set_number('8614702')->is_valid_number, '熊本県下益城郡美里町遠野');
ok($zip->set_number('8614703')->is_valid_number, '熊本県下益城郡美里町畝野');
ok($zip->set_number('8614704')->is_valid_number, '熊本県下益城郡美里町涌井');
ok($zip->set_number('8614705')->is_valid_number, '熊本県下益城郡美里町豊富');
ok($zip->set_number('8614706')->is_valid_number, '熊本県下益城郡美里町甲佐平');
ok($zip->set_number('8614707')->is_valid_number, '熊本県下益城郡美里町川越');
ok($zip->set_number('8614711')->is_valid_number, '熊本県下益城郡美里町洞岳');
ok($zip->set_number('8614712')->is_valid_number, '熊本県下益城郡美里町柏川');
ok($zip->set_number('8614713')->is_valid_number, '熊本県下益城郡美里町早楠');
ok($zip->set_number('8614714')->is_valid_number, '熊本県下益城郡美里町安部');
ok($zip->set_number('8614715')->is_valid_number, '熊本県下益城郡美里町清水');
ok($zip->set_number('8614716')->is_valid_number, '熊本県下益城郡美里町石野');
ok($zip->set_number('8614721')->is_valid_number, '熊本県下益城郡美里町土喰');
ok($zip->set_number('8614722')->is_valid_number, '熊本県下益城郡美里町永富');
ok($zip->set_number('8614723')->is_valid_number, '熊本県下益城郡美里町境');
ok($zip->set_number('8614725')->is_valid_number, '熊本県下益城郡美里町坂貫');
ok($zip->set_number('8614726')->is_valid_number, '熊本県下益城郡美里町大窪');
ok($zip->set_number('8614727')->is_valid_number, '熊本県下益城郡美里町原町');
ok($zip->set_number('8614731')->is_valid_number, '熊本県下益城郡美里町栗崎');
ok($zip->set_number('8614732')->is_valid_number, '熊本県下益城郡美里町三和');
ok($zip->set_number('8614733')->is_valid_number, '熊本県下益城郡美里町二和田');
ok($zip->set_number('8614734')->is_valid_number, '熊本県下益城郡美里町今');
ok($zip->set_number('8614735')->is_valid_number, '熊本県下益城郡美里町三加');
ok($zip->set_number('8614736')->is_valid_number, '熊本県下益城郡美里町名越谷');
ok($zip->set_number('8614737')->is_valid_number, '熊本県下益城郡美里町古閑');
ok($zip->set_number('8615251')->is_valid_number, '熊本県熊本市南区今町');
ok($zip->set_number('8615252')->is_valid_number, '熊本県熊本市南区土河原町');
ok($zip->set_number('8615253')->is_valid_number, '熊本県熊本市南区八分字町');
ok($zip->set_number('8615254')->is_valid_number, '熊本県熊本市南区孫代町');
ok($zip->set_number('8615255')->is_valid_number, '熊本県熊本市南区砂原町');
ok($zip->set_number('8615261')->is_valid_number, '熊本県熊本市南区無田口町');
ok($zip->set_number('8615262')->is_valid_number, '熊本県熊本市南区浜口町');
ok($zip->set_number('8615263')->is_valid_number, '熊本県熊本市南区並建町');
ok($zip->set_number('8615264')->is_valid_number, '熊本県熊本市南区白石町');
ok($zip->set_number('8615265')->is_valid_number, '熊本県熊本市南区畠口町');
ok($zip->set_number('8615271')->is_valid_number, '熊本県熊本市西区中原町');
ok($zip->set_number('8615272')->is_valid_number, '熊本県熊本市西区中島町');
ok($zip->set_number('8615273')->is_valid_number, '熊本県熊本市西区沖新町');
ok($zip->set_number('8615274')->is_valid_number, '熊本県熊本市西区新港');
ok($zip->set_number('8615280')->is_valid_number, '熊本県熊本市西区松尾');
ok($zip->set_number('8615281')->is_valid_number, '熊本県熊本市西区松尾町近津');
ok($zip->set_number('8615282')->is_valid_number, '熊本県熊本市西区松尾町平山');
ok($zip->set_number('8615284')->is_valid_number, '熊本県熊本市西区小島下町');
ok($zip->set_number('8615285')->is_valid_number, '熊本県熊本市西区小島上町');
ok($zip->set_number('8615286')->is_valid_number, '熊本県熊本市西区中松尾町');
ok($zip->set_number('8615287')->is_valid_number, '熊本県熊本市西区小島');
ok($zip->set_number('8615288')->is_valid_number, '熊本県熊本市西区西松尾町');
ok($zip->set_number('8615289')->is_valid_number, '熊本県熊本市西区上松尾町');
ok($zip->set_number('8615341')->is_valid_number, '熊本県熊本市西区河内町大多尾');
ok($zip->set_number('8615342')->is_valid_number, '熊本県熊本市西区河内町東門寺');
ok($zip->set_number('8615343')->is_valid_number, '熊本県熊本市西区河内町野出');
ok($zip->set_number('8615344')->is_valid_number, '熊本県熊本市西区河内町岳');
ok($zip->set_number('8615345')->is_valid_number, '熊本県熊本市西区河内町面木');
ok($zip->set_number('8615346')->is_valid_number, '熊本県熊本市西区河内町河内');
ok($zip->set_number('8615347')->is_valid_number, '熊本県熊本市西区河内町船津');
ok($zip->set_number('8615348')->is_valid_number, '熊本県熊本市西区河内町白浜');
ok($zip->set_number('8615401')->is_valid_number, '熊本県玉名市天水町小天');
ok($zip->set_number('8615402')->is_valid_number, '熊本県玉名市天水町立花');
ok($zip->set_number('8615403')->is_valid_number, '熊本県玉名市天水町部田見');
ok($zip->set_number('8615404')->is_valid_number, '熊本県玉名市天水町竹崎');
ok($zip->set_number('8615405')->is_valid_number, '熊本県玉名市天水町野部田');
ok($zip->set_number('8615406')->is_valid_number, '熊本県玉名市天水町尾田');
ok($zip->set_number('8615501')->is_valid_number, '熊本県熊本市北区改寄町');
ok($zip->set_number('8615502')->is_valid_number, '熊本県熊本市北区大鳥居町');
ok($zip->set_number('8615503')->is_valid_number, '熊本県熊本市北区明徳町');
ok($zip->set_number('8615504')->is_valid_number, '熊本県熊本市北区小糸山町');
ok($zip->set_number('8615511')->is_valid_number, '熊本県熊本市北区楠野町');
ok($zip->set_number('8615512')->is_valid_number, '熊本県熊本市北区梶尾町');
ok($zip->set_number('8615513')->is_valid_number, '熊本県熊本市北区鶴羽田町');
ok($zip->set_number('8615514')->is_valid_number, '熊本県熊本市北区飛田');
ok($zip->set_number('8615515')->is_valid_number, '熊本県熊本市北区四方寄町');
ok($zip->set_number('8615516')->is_valid_number, '熊本県熊本市北区西梶尾町');
ok($zip->set_number('8615517')->is_valid_number, '熊本県熊本市北区鶴羽田');
ok($zip->set_number('8615521')->is_valid_number, '熊本県熊本市北区鹿子木町');
ok($zip->set_number('8615522')->is_valid_number, '熊本県熊本市北区下硯川町');
ok($zip->set_number('8615523')->is_valid_number, '熊本県熊本市北区徳王町');
ok($zip->set_number('8615524')->is_valid_number, '熊本県熊本市北区硯川町');
ok($zip->set_number('8615525')->is_valid_number, '熊本県熊本市北区徳王');
ok($zip->set_number('8615526')->is_valid_number, '熊本県熊本市北区下硯川');
ok($zip->set_number('8615531')->is_valid_number, '熊本県熊本市北区北迫町');
ok($zip->set_number('8615532')->is_valid_number, '熊本県熊本市北区太郎迫町');
ok($zip->set_number('8615533')->is_valid_number, '熊本県熊本市北区和泉町');
ok($zip->set_number('8615534')->is_valid_number, '熊本県熊本市北区釜尾町');
ok($zip->set_number('8615535')->is_valid_number, '熊本県熊本市北区貢町');
ok($zip->set_number('8615536')->is_valid_number, '熊本県熊本市北区立福寺町');
ok($zip->set_number('8615537')->is_valid_number, '熊本県熊本市北区万楽寺町');
ok($zip->set_number('8616101')->is_valid_number, '熊本県上天草市松島町阿村');
ok($zip->set_number('8616102')->is_valid_number, '熊本県上天草市松島町合津');
ok($zip->set_number('8616103')->is_valid_number, '熊本県上天草市松島町今泉');
ok($zip->set_number('8616104')->is_valid_number, '熊本県上天草市松島町内野河内');
ok($zip->set_number('8616105')->is_valid_number, '熊本県上天草市松島町教良木');
ok($zip->set_number('8616301')->is_valid_number, '熊本県天草市栖本町打田');
ok($zip->set_number('8616302')->is_valid_number, '熊本県天草市栖本町河内');
ok($zip->set_number('8616303')->is_valid_number, '熊本県天草市栖本町馬場');
ok($zip->set_number('8616304')->is_valid_number, '熊本県天草市栖本町古江');
ok($zip->set_number('8616305')->is_valid_number, '熊本県天草市栖本町湯船原');
ok($zip->set_number('8616401')->is_valid_number, '熊本県天草市倉岳町浦');
ok($zip->set_number('8616402')->is_valid_number, '熊本県天草市倉岳町棚底');
ok($zip->set_number('8616403')->is_valid_number, '熊本県天草市倉岳町宮田');
ok($zip->set_number('8616551')->is_valid_number, '熊本県天草市下浦町');
ok($zip->set_number('8617201')->is_valid_number, '熊本県天草市有明町赤崎');
ok($zip->set_number('8617202')->is_valid_number, '熊本県天草市有明町須子');
ok($zip->set_number('8617203')->is_valid_number, '熊本県天草市有明町大浦');
ok($zip->set_number('8617204')->is_valid_number, '熊本県天草市有明町楠甫');
ok($zip->set_number('8617311')->is_valid_number, '熊本県天草市有明町上津浦');
ok($zip->set_number('8617312')->is_valid_number, '熊本県天草市有明町下津浦');
ok($zip->set_number('8617313')->is_valid_number, '熊本県天草市有明町小島子');
ok($zip->set_number('8617314')->is_valid_number, '熊本県天草市有明町大島子');
ok($zip->set_number('8618001')->is_valid_number, '熊本県熊本市北区武蔵ケ丘');
ok($zip->set_number('8618002')->is_valid_number, '熊本県熊本市北区弓削');
ok($zip->set_number('8618003')->is_valid_number, '熊本県熊本市北区楠');
ok($zip->set_number('8618005')->is_valid_number, '熊本県熊本市北区龍田陳内');
ok($zip->set_number('8618006')->is_valid_number, '熊本県熊本市北区龍田');
ok($zip->set_number('8618007')->is_valid_number, '熊本県熊本市北区龍田弓削');
ok($zip->set_number('8618010')->is_valid_number, '熊本県熊本市東区上南部');
ok($zip->set_number('8618011')->is_valid_number, '熊本県熊本市東区鹿帰瀬町');
ok($zip->set_number('8618012')->is_valid_number, '熊本県熊本市東区平山町');
ok($zip->set_number('8618013')->is_valid_number, '熊本県熊本市東区弓削町');
ok($zip->set_number('8618014')->is_valid_number, '熊本県熊本市東区石原町');
ok($zip->set_number('8618015')->is_valid_number, '熊本県熊本市東区中江町');
ok($zip->set_number('8618016')->is_valid_number, '熊本県熊本市東区吉原町');
ok($zip->set_number('8618017')->is_valid_number, '熊本県熊本市東区上南部町');
ok($zip->set_number('8618019')->is_valid_number, '熊本県熊本市東区下南部');
ok($zip->set_number('8618028')->is_valid_number, '熊本県熊本市東区新南部');
ok($zip->set_number('8618029')->is_valid_number, '熊本県熊本市東区西原');
ok($zip->set_number('8618030')->is_valid_number, '熊本県熊本市東区小山町');
ok($zip->set_number('8618031')->is_valid_number, '熊本県熊本市東区戸島町');
ok($zip->set_number('8618034')->is_valid_number, '熊本県熊本市東区八反田');
ok($zip->set_number('8618035')->is_valid_number, '熊本県熊本市東区御領');
ok($zip->set_number('8618037')->is_valid_number, '熊本県熊本市東区長嶺西');
ok($zip->set_number('8618038')->is_valid_number, '熊本県熊本市東区長嶺東');
ok($zip->set_number('8618039')->is_valid_number, '熊本県熊本市東区長嶺南');
ok($zip->set_number('8618041')->is_valid_number, '熊本県熊本市東区戸島');
ok($zip->set_number('8618042')->is_valid_number, '熊本県熊本市東区戸島本町');
ok($zip->set_number('8618043')->is_valid_number, '熊本県熊本市東区戸島西');
ok($zip->set_number('8618044')->is_valid_number, '熊本県熊本市東区神園');
ok($zip->set_number('8618045')->is_valid_number, '熊本県熊本市東区小山');
ok($zip->set_number('8618046')->is_valid_number, '熊本県熊本市東区石原');
ok($zip->set_number('8618064')->is_valid_number, '熊本県熊本市北区八景水谷');
ok($zip->set_number('8618065')->is_valid_number, '熊本県熊本市北区清水東町');
ok($zip->set_number('8618066')->is_valid_number, '熊本県熊本市北区清水亀井町');
ok($zip->set_number('8618068')->is_valid_number, '熊本県熊本市北区清水万石');
ok($zip->set_number('8618071')->is_valid_number, '熊本県熊本市北区清水町室園');
ok($zip->set_number('8618072')->is_valid_number, '熊本県熊本市中央区室園町');
ok($zip->set_number('8618072')->is_valid_number, '熊本県熊本市北区室園町');
ok($zip->set_number('8618073')->is_valid_number, '熊本県熊本市北区清水町松崎');
ok($zip->set_number('8618074')->is_valid_number, '熊本県熊本市北区清水本町');
ok($zip->set_number('8618075')->is_valid_number, '熊本県熊本市北区清水新地');
ok($zip->set_number('8618081')->is_valid_number, '熊本県熊本市北区麻生田');
ok($zip->set_number('8618082')->is_valid_number, '熊本県熊本市北区兎谷');
ok($zip->set_number('8618083')->is_valid_number, '熊本県熊本市北区楡木');
ok($zip->set_number('8618084')->is_valid_number, '熊本県熊本市北区清水岩倉');
ok($zip->set_number('8620901')->is_valid_number, '熊本県熊本市東区東町');
ok($zip->set_number('8620902')->is_valid_number, '熊本県熊本市東区東本町');
ok($zip->set_number('8620903')->is_valid_number, '熊本県熊本市東区若葉(1~3丁目)');
ok($zip->set_number('8620904')->is_valid_number, '熊本県熊本市東区栄町');
ok($zip->set_number('8620905')->is_valid_number, '熊本県熊本市東区南町');
ok($zip->set_number('8620906')->is_valid_number, '熊本県熊本市東区広木町');
ok($zip->set_number('8620907')->is_valid_number, '熊本県熊本市東区水源');
ok($zip->set_number('8620908')->is_valid_number, '熊本県熊本市東区新生');
ok($zip->set_number('8620909')->is_valid_number, '熊本県熊本市中央区湖東');
ok($zip->set_number('8620909')->is_valid_number, '熊本県熊本市東区湖東');
ok($zip->set_number('8620910')->is_valid_number, '熊本県熊本市東区健軍本町');
ok($zip->set_number('8620911')->is_valid_number, '熊本県熊本市東区健軍');
ok($zip->set_number('8620912')->is_valid_number, '熊本県熊本市東区錦ケ丘');
ok($zip->set_number('8620913')->is_valid_number, '熊本県熊本市東区尾ノ上');
ok($zip->set_number('8620914')->is_valid_number, '熊本県熊本市東区山ノ内');
ok($zip->set_number('8620915')->is_valid_number, '熊本県熊本市東区山ノ神');
ok($zip->set_number('8620916')->is_valid_number, '熊本県熊本市東区佐土原');
ok($zip->set_number('8620917')->is_valid_number, '熊本県熊本市東区榎町');
ok($zip->set_number('8620918')->is_valid_number, '熊本県熊本市東区花立(5、6丁目)');
ok($zip->set_number('8620920')->is_valid_number, '熊本県熊本市東区月出');
ok($zip->set_number('8620921')->is_valid_number, '熊本県熊本市東区新外');
ok($zip->set_number('8620922')->is_valid_number, '熊本県熊本市中央区三郎');
ok($zip->set_number('8620922')->is_valid_number, '熊本県熊本市東区三郎');
ok($zip->set_number('8620923')->is_valid_number, '熊本県熊本市中央区東京塚町');
ok($zip->set_number('8620923')->is_valid_number, '熊本県熊本市東区東京塚町');
ok($zip->set_number('8620924')->is_valid_number, '熊本県熊本市中央区帯山');
ok($zip->set_number('8620924')->is_valid_number, '熊本県熊本市東区帯山');
ok($zip->set_number('8620925')->is_valid_number, '熊本県熊本市東区保田窪本町');
ok($zip->set_number('8620926')->is_valid_number, '熊本県熊本市中央区保田窪');
ok($zip->set_number('8620926')->is_valid_number, '熊本県熊本市東区保田窪');
ok($zip->set_number('8620933')->is_valid_number, '熊本県熊本市東区小峯');
ok($zip->set_number('8620941')->is_valid_number, '熊本県熊本市中央区出水');
ok($zip->set_number('8620941')->is_valid_number, '熊本県熊本市東区出水');
ok($zip->set_number('8620942')->is_valid_number, '熊本県熊本市中央区江津');
ok($zip->set_number('8620942')->is_valid_number, '熊本県熊本市東区江津');
ok($zip->set_number('8620943')->is_valid_number, '熊本県熊本市東区画図町下江津');
ok($zip->set_number('8620944')->is_valid_number, '熊本県熊本市東区画図町上無田');
ok($zip->set_number('8620945')->is_valid_number, '熊本県熊本市東区画図町下無田');
ok($zip->set_number('8620946')->is_valid_number, '熊本県熊本市東区画図町所島');
ok($zip->set_number('8620947')->is_valid_number, '熊本県熊本市東区画図町重富');
ok($zip->set_number('8620948')->is_valid_number, '熊本県熊本市中央区国府本町');
ok($zip->set_number('8620949')->is_valid_number, '熊本県熊本市中央区国府');
ok($zip->set_number('8620950')->is_valid_number, '熊本県熊本市中央区水前寺');
ok($zip->set_number('8620951')->is_valid_number, '熊本県熊本市中央区上水前寺');
ok($zip->set_number('8620952')->is_valid_number, '熊本県熊本市東区京塚本町');
ok($zip->set_number('8620953')->is_valid_number, '熊本県熊本市中央区上京塚町');
ok($zip->set_number('8620954')->is_valid_number, '熊本県熊本市中央区神水');
ok($zip->set_number('8620955')->is_valid_number, '熊本県熊本市中央区神水本町');
ok($zip->set_number('8620955')->is_valid_number, '熊本県熊本市東区神水本町');
ok($zip->set_number('8620956')->is_valid_number, '熊本県熊本市中央区水前寺公園');
ok($zip->set_number('8620957')->is_valid_number, '熊本県熊本市中央区菅原町');
ok($zip->set_number('8620958')->is_valid_number, '熊本県熊本市中央区岡田町');
ok($zip->set_number('8620959')->is_valid_number, '熊本県熊本市中央区白山');
ok($zip->set_number('8620960')->is_valid_number, '熊本県熊本市東区下江津');
ok($zip->set_number('8620961')->is_valid_number, '熊本県熊本市東区画図東');
ok($zip->set_number('8620962')->is_valid_number, '熊本県熊本市南区田迎');
ok($zip->set_number('8620963')->is_valid_number, '熊本県熊本市南区出仲間');
ok($zip->set_number('8620965')->is_valid_number, '熊本県熊本市南区田井島');
ok($zip->set_number('8620965')->is_valid_number, '熊本県熊本市南区田迎町田井島');
ok($zip->set_number('8620966')->is_valid_number, '熊本県熊本市南区田迎町良町');
ok($zip->set_number('8620967')->is_valid_number, '熊本県熊本市南区流通団地');
ok($zip->set_number('8620968')->is_valid_number, '熊本県熊本市南区馬渡');
ok($zip->set_number('8620969')->is_valid_number, '熊本県熊本市南区良町');
ok($zip->set_number('8620970')->is_valid_number, '熊本県熊本市中央区渡鹿');
ok($zip->set_number('8620970')->is_valid_number, '熊本県熊本市東区渡鹿');
ok($zip->set_number('8620971')->is_valid_number, '熊本県熊本市中央区大江');
ok($zip->set_number('8620972')->is_valid_number, '熊本県熊本市中央区新大江');
ok($zip->set_number('8620973')->is_valid_number, '熊本県熊本市中央区大江本町');
ok($zip->set_number('8620975')->is_valid_number, '熊本県熊本市中央区新屋敷');
ok($zip->set_number('8620976')->is_valid_number, '熊本県熊本市中央区九品寺');
ok($zip->set_number('8630000')->is_valid_number, '熊本県天草市以下に掲載がない場合');
ok($zip->set_number('8630001')->is_valid_number, '熊本県天草市本渡町広瀬');
ok($zip->set_number('8630002')->is_valid_number, '熊本県天草市本渡町本戸馬場');
ok($zip->set_number('8630003')->is_valid_number, '熊本県天草市本渡町本渡');
ok($zip->set_number('8630004')->is_valid_number, '熊本県天草市本渡町本泉');
ok($zip->set_number('8630005')->is_valid_number, '熊本県天草市本町新休');
ok($zip->set_number('8630006')->is_valid_number, '熊本県天草市本町下河内');
ok($zip->set_number('8630007')->is_valid_number, '熊本県天草市本町本');
ok($zip->set_number('8630011')->is_valid_number, '熊本県天草市北浜町');
ok($zip->set_number('8630012')->is_valid_number, '熊本県天草市今釜町');
ok($zip->set_number('8630013')->is_valid_number, '熊本県天草市今釜新町');
ok($zip->set_number('8630014')->is_valid_number, '熊本県天草市東浜町');
ok($zip->set_number('8630015')->is_valid_number, '熊本県天草市大浜町');
ok($zip->set_number('8630016')->is_valid_number, '熊本県天草市城下町');
ok($zip->set_number('8630017')->is_valid_number, '熊本県天草市船之尾町');
ok($zip->set_number('8630018')->is_valid_number, '熊本県天草市浜崎町');
ok($zip->set_number('8630019')->is_valid_number, '熊本県天草市小松原町');
ok($zip->set_number('8630021')->is_valid_number, '熊本県天草市港町');
ok($zip->set_number('8630022')->is_valid_number, '熊本県天草市栄町');
ok($zip->set_number('8630023')->is_valid_number, '熊本県天草市中央新町');
ok($zip->set_number('8630024')->is_valid_number, '熊本県天草市川原町');
ok($zip->set_number('8630025')->is_valid_number, '熊本県天草市古川町');
ok($zip->set_number('8630031')->is_valid_number, '熊本県天草市南新町');
ok($zip->set_number('8630032')->is_valid_number, '熊本県天草市太田町');
ok($zip->set_number('8630033')->is_valid_number, '熊本県天草市東町');
ok($zip->set_number('8630034')->is_valid_number, '熊本県天草市浄南町');
ok($zip->set_number('8630035')->is_valid_number, '熊本県天草市山の手町');
ok($zip->set_number('8630036')->is_valid_number, '熊本県天草市川原新町');
ok($zip->set_number('8630037')->is_valid_number, '熊本県天草市諏訪町');
ok($zip->set_number('8630038')->is_valid_number, '熊本県天草市南町');
ok($zip->set_number('8630041')->is_valid_number, '熊本県天草市志柿町');
ok($zip->set_number('8630042')->is_valid_number, '熊本県天草市瀬戸町');
ok($zip->set_number('8630043')->is_valid_number, '熊本県天草市亀場町亀川');
ok($zip->set_number('8630044')->is_valid_number, '熊本県天草市楠浦町');
ok($zip->set_number('8630045')->is_valid_number, '熊本県天草市枦宇土町');
ok($zip->set_number('8630046')->is_valid_number, '熊本県天草市亀場町食場');
ok($zip->set_number('8630047')->is_valid_number, '熊本県天草市八幡町');
ok($zip->set_number('8630048')->is_valid_number, '熊本県天草市中村町');
ok($zip->set_number('8630049')->is_valid_number, '熊本県天草市北原町');
ok($zip->set_number('8630050')->is_valid_number, '熊本県天草市丸尾町');
ok($zip->set_number('8630101')->is_valid_number, '熊本県天草市新和町小宮地');
ok($zip->set_number('8630102')->is_valid_number, '熊本県天草市新和町大多尾');
ok($zip->set_number('8630103')->is_valid_number, '熊本県天草市新和町大宮地');
ok($zip->set_number('8631111')->is_valid_number, '熊本県天草市新和町碇石');
ok($zip->set_number('8631112')->is_valid_number, '熊本県天草市新和町中田');
ok($zip->set_number('8631161')->is_valid_number, '熊本県天草市宮地岳町');
ok($zip->set_number('8631201')->is_valid_number, '熊本県天草市河浦町今田');
ok($zip->set_number('8631202')->is_valid_number, '熊本県天草市河浦町河浦');
ok($zip->set_number('8631203')->is_valid_number, '熊本県天草市河浦町今富(その他)');
ok($zip->set_number('8631204')->is_valid_number, '熊本県天草市河浦町崎津(その他)');
ok($zip->set_number('8631205')->is_valid_number, '熊本県天草市天草町高浜北(4001-23、4135番地)');
ok($zip->set_number('8631211')->is_valid_number, '熊本県天草市河浦町立原');
ok($zip->set_number('8631212')->is_valid_number, '熊本県天草市河浦町宮野河内');
ok($zip->set_number('8631213')->is_valid_number, '熊本県天草市河浦町路木');
ok($zip->set_number('8631214')->is_valid_number, '熊本県天草市河浦町久留');
ok($zip->set_number('8631215')->is_valid_number, '熊本県天草市河浦町白木河内');
ok($zip->set_number('8631216')->is_valid_number, '熊本県天草市河浦町新合');
ok($zip->set_number('8631401')->is_valid_number, '熊本県天草市天草町大江向');
ok($zip->set_number('8631403')->is_valid_number, '熊本県天草市河浦町今富(1933、1939、1945、1955-4、1960、');
ok($zip->set_number('8631403')->is_valid_number, '熊本県天草市1970、1974、1976、1983、1988-3、1990-5、');
ok($zip->set_number('8631403')->is_valid_number, '熊本県天草市2003、2051)');
ok($zip->set_number('8631404')->is_valid_number, '熊本県天草市河浦町崎津(1644、1647-1、1659)');
ok($zip->set_number('8631431')->is_valid_number, '熊本県天草市二浦町早浦');
ok($zip->set_number('8631432')->is_valid_number, '熊本県天草市二浦町亀浦');
ok($zip->set_number('8631511')->is_valid_number, '熊本県天草市深海町');
ok($zip->set_number('8631721')->is_valid_number, '熊本県天草市魚貫町');
ok($zip->set_number('8631901')->is_valid_number, '熊本県天草市牛深町');
ok($zip->set_number('8631902')->is_valid_number, '熊本県天草市久玉町');
ok($zip->set_number('8632114')->is_valid_number, '熊本県天草市五和町城河原');
ok($zip->set_number('8632171')->is_valid_number, '熊本県天草市佐伊津町');
ok($zip->set_number('8632172')->is_valid_number, '熊本県天草市旭町');
ok($zip->set_number('8632201')->is_valid_number, '熊本県天草市五和町御領');
ok($zip->set_number('8632331')->is_valid_number, '熊本県天草市五和町鬼池');
ok($zip->set_number('8632421')->is_valid_number, '熊本県天草市五和町二江');
ok($zip->set_number('8632424')->is_valid_number, '熊本県天草市五和町手野');
ok($zip->set_number('8632500')->is_valid_number, '熊本県天草郡苓北町以下に掲載がない場合');
ok($zip->set_number('8632501')->is_valid_number, '熊本県天草郡苓北町坂瀬川');
ok($zip->set_number('8632502')->is_valid_number, '熊本県天草郡苓北町上津深江');
ok($zip->set_number('8632503')->is_valid_number, '熊本県天草郡苓北町志岐');
ok($zip->set_number('8632504')->is_valid_number, '熊本県天草郡苓北町年柄');
ok($zip->set_number('8632505')->is_valid_number, '熊本県天草郡苓北町内田');
ok($zip->set_number('8632506')->is_valid_number, '熊本県天草郡苓北町白木尾');
ok($zip->set_number('8632507')->is_valid_number, '熊本県天草郡苓北町富岡');
ok($zip->set_number('8632611')->is_valid_number, '熊本県天草郡苓北町都呂々');
ok($zip->set_number('8632801')->is_valid_number, '熊本県天草市天草町大江');
ok($zip->set_number('8632801')->is_valid_number, '熊本県天草市天草町大江軍浦');
ok($zip->set_number('8632802')->is_valid_number, '熊本県天草市天草町下田南');
ok($zip->set_number('8632803')->is_valid_number, '熊本県天草市天草町下田北');
ok($zip->set_number('8632804')->is_valid_number, '熊本県天草市天草町高浜南');
ok($zip->set_number('8632805')->is_valid_number, '熊本県天草市天草町高浜北(その他)');
ok($zip->set_number('8632806')->is_valid_number, '熊本県天草市天草町福連木');
ok($zip->set_number('8640000')->is_valid_number, '熊本県荒尾市以下に掲載がない場合');
ok($zip->set_number('8640001')->is_valid_number, '熊本県荒尾市原万田');
ok($zip->set_number('8640002')->is_valid_number, '熊本県荒尾市万田');
ok($zip->set_number('8640003')->is_valid_number, '熊本県荒尾市宮内出目');
ok($zip->set_number('8640004')->is_valid_number, '熊本県荒尾市宮内');
ok($zip->set_number('8640005')->is_valid_number, '熊本県荒尾市大平町');
ok($zip->set_number('8640006')->is_valid_number, '熊本県荒尾市住吉町');
ok($zip->set_number('8640011')->is_valid_number, '熊本県荒尾市下井手');
ok($zip->set_number('8640012')->is_valid_number, '熊本県荒尾市本井手');
ok($zip->set_number('8640013')->is_valid_number, '熊本県荒尾市上井手');
ok($zip->set_number('8640014')->is_valid_number, '熊本県荒尾市上平山');
ok($zip->set_number('8640015')->is_valid_number, '熊本県荒尾市平山');
ok($zip->set_number('8640021')->is_valid_number, '熊本県荒尾市一部');
ok($zip->set_number('8640022')->is_valid_number, '熊本県荒尾市桜山町');
ok($zip->set_number('8640023')->is_valid_number, '熊本県荒尾市水野');
ok($zip->set_number('8640025')->is_valid_number, '熊本県荒尾市高浜');
ok($zip->set_number('8640026')->is_valid_number, '熊本県荒尾市牛水');
ok($zip->set_number('8640027')->is_valid_number, '熊本県荒尾市蔵満');
ok($zip->set_number('8640031')->is_valid_number, '熊本県荒尾市川登(1773~1979、1981~2010、2050~2100番地)');
ok($zip->set_number('8640032')->is_valid_number, '熊本県荒尾市増永');
ok($zip->set_number('8640033')->is_valid_number, '熊本県荒尾市緑ケ丘');
ok($zip->set_number('8640041')->is_valid_number, '熊本県荒尾市荒尾');
ok($zip->set_number('8640042')->is_valid_number, '熊本県荒尾市東屋形');
ok($zip->set_number('8640051')->is_valid_number, '熊本県荒尾市大島町');
ok($zip->set_number('8640052')->is_valid_number, '熊本県荒尾市四ツ山町');
ok($zip->set_number('8640053')->is_valid_number, '熊本県荒尾市西原町');
ok($zip->set_number('8640054')->is_valid_number, '熊本県荒尾市大正町');
ok($zip->set_number('8640055')->is_valid_number, '熊本県荒尾市日の出町');
ok($zip->set_number('8640056')->is_valid_number, '熊本県荒尾市昭和町');
ok($zip->set_number('8640057')->is_valid_number, '熊本県荒尾市大島');
ok($zip->set_number('8640131')->is_valid_number, '熊本県荒尾市川登(その他)');
ok($zip->set_number('8640161')->is_valid_number, '熊本県荒尾市菰屋');
ok($zip->set_number('8640162')->is_valid_number, '熊本県荒尾市金山');
ok($zip->set_number('8640163')->is_valid_number, '熊本県荒尾市野原');
ok($zip->set_number('8640164')->is_valid_number, '熊本県荒尾市八幡台');
ok($zip->set_number('8640165')->is_valid_number, '熊本県荒尾市樺');
ok($zip->set_number('8640166')->is_valid_number, '熊本県荒尾市府本');
ok($zip->set_number('8650000')->is_valid_number, '熊本県玉名市以下に掲載がない場合');
ok($zip->set_number('8650001')->is_valid_number, '熊本県玉名市月田');
ok($zip->set_number('8650002')->is_valid_number, '熊本県玉名市箱谷');
ok($zip->set_number('8650003')->is_valid_number, '熊本県玉名市溝上');
ok($zip->set_number('8650004')->is_valid_number, '熊本県玉名市青木');
ok($zip->set_number('8650005')->is_valid_number, '熊本県玉名市玉名');
ok($zip->set_number('8650006')->is_valid_number, '熊本県玉名市両迫間');
ok($zip->set_number('8650007')->is_valid_number, '熊本県玉名市河崎');
ok($zip->set_number('8650008')->is_valid_number, '熊本県玉名市石貫');
ok($zip->set_number('8650009')->is_valid_number, '熊本県玉名市三ツ川');
ok($zip->set_number('8650011')->is_valid_number, '熊本県玉名市上小田');
ok($zip->set_number('8650012')->is_valid_number, '熊本県玉名市山部田');
ok($zip->set_number('8650013')->is_valid_number, '熊本県玉名市下');
ok($zip->set_number('8650014')->is_valid_number, '熊本県玉名市安楽寺');
ok($zip->set_number('8650015')->is_valid_number, '熊本県玉名市亀甲');
ok($zip->set_number('8650016')->is_valid_number, '熊本県玉名市岩崎');
ok($zip->set_number('8650017')->is_valid_number, '熊本県玉名市川部田');
ok($zip->set_number('8650018')->is_valid_number, '熊本県玉名市下小田');
ok($zip->set_number('8650021')->is_valid_number, '熊本県玉名市津留');
ok($zip->set_number('8650022')->is_valid_number, '熊本県玉名市寺田');
ok($zip->set_number('8650023')->is_valid_number, '熊本県玉名市大倉');
ok($zip->set_number('8650024')->is_valid_number, '熊本県玉名市永徳寺');
ok($zip->set_number('8650025')->is_valid_number, '熊本県玉名市高瀬');
ok($zip->set_number('8650026')->is_valid_number, '熊本県玉名市秋丸');
ok($zip->set_number('8650027')->is_valid_number, '熊本県玉名市向津留');
ok($zip->set_number('8650031')->is_valid_number, '熊本県玉名市田崎');
ok($zip->set_number('8650032')->is_valid_number, '熊本県玉名市北坂門田');
ok($zip->set_number('8650033')->is_valid_number, '熊本県玉名市中坂門田');
ok($zip->set_number('8650034')->is_valid_number, '熊本県玉名市南坂門田');
ok($zip->set_number('8650035')->is_valid_number, '熊本県玉名市青野');
ok($zip->set_number('8650041')->is_valid_number, '熊本県玉名市伊倉北方');
ok($zip->set_number('8650042')->is_valid_number, '熊本県玉名市宮原');
ok($zip->set_number('8650043')->is_valid_number, '熊本県玉名市横田');
ok($zip->set_number('8650044')->is_valid_number, '熊本県玉名市片諏訪');
ok($zip->set_number('8650045')->is_valid_number, '熊本県玉名市伊倉南方');
ok($zip->set_number('8650046')->is_valid_number, '熊本県玉名市北牟田');
ok($zip->set_number('8650047')->is_valid_number, '熊本県玉名市川島');
ok($zip->set_number('8650048')->is_valid_number, '熊本県玉名市小野尻');
ok($zip->set_number('8650051')->is_valid_number, '熊本県玉名市繁根木');
ok($zip->set_number('8650052')->is_valid_number, '熊本県玉名市松木');
ok($zip->set_number('8650053')->is_valid_number, '熊本県玉名市千田川原');
ok($zip->set_number('8650054')->is_valid_number, '熊本県玉名市小島');
ok($zip->set_number('8650055')->is_valid_number, '熊本県玉名市大浜町');
ok($zip->set_number('8650056')->is_valid_number, '熊本県玉名市滑石');
ok($zip->set_number('8650057')->is_valid_number, '熊本県玉名市小浜');
ok($zip->set_number('8650058')->is_valid_number, '熊本県玉名市六田');
ok($zip->set_number('8650061')->is_valid_number, '熊本県玉名市立願寺');
ok($zip->set_number('8650062')->is_valid_number, '熊本県玉名市富尾');
ok($zip->set_number('8650063')->is_valid_number, '熊本県玉名市中尾');
ok($zip->set_number('8650064')->is_valid_number, '熊本県玉名市中');
ok($zip->set_number('8650065')->is_valid_number, '熊本県玉名市築地');
ok($zip->set_number('8650066')->is_valid_number, '熊本県玉名市山田');
ok($zip->set_number('8650071')->is_valid_number, '熊本県玉名市横島町大園');
ok($zip->set_number('8650072')->is_valid_number, '熊本県玉名市横島町横島');
ok($zip->set_number('8650073')->is_valid_number, '熊本県玉名市横島町共栄');
ok($zip->set_number('8650100')->is_valid_number, '熊本県玉名郡和水町以下に掲載がない場合');
ok($zip->set_number('8650101')->is_valid_number, '熊本県玉名郡和水町江栗');
ok($zip->set_number('8650102')->is_valid_number, '熊本県玉名郡和水町久井原');
ok($zip->set_number('8650103')->is_valid_number, '熊本県玉名郡和水町長小田');
ok($zip->set_number('8650104')->is_valid_number, '熊本県玉名郡和水町内田');
ok($zip->set_number('8650111')->is_valid_number, '熊本県玉名郡和水町下津原');
ok($zip->set_number('8650112')->is_valid_number, '熊本県玉名郡和水町大屋');
ok($zip->set_number('8650113')->is_valid_number, '熊本県玉名郡和水町焼米');
ok($zip->set_number('8650114')->is_valid_number, '熊本県玉名郡和水町岩尻');
ok($zip->set_number('8650115')->is_valid_number, '熊本県玉名郡和水町久米野');
ok($zip->set_number('8650116')->is_valid_number, '熊本県玉名郡和水町竈門');
ok($zip->set_number('8650117')->is_valid_number, '熊本県玉名郡和水町志口永');
ok($zip->set_number('8650121')->is_valid_number, '熊本県玉名郡和水町榎原');
ok($zip->set_number('8650122')->is_valid_number, '熊本県玉名郡和水町高野');
ok($zip->set_number('8650123')->is_valid_number, '熊本県玉名郡和水町米渡尾');
ok($zip->set_number('8650124')->is_valid_number, '熊本県玉名郡和水町原口');
ok($zip->set_number('8650125')->is_valid_number, '熊本県玉名郡和水町藤田');
ok($zip->set_number('8650126')->is_valid_number, '熊本県玉名郡和水町前原');
ok($zip->set_number('8650131')->is_valid_number, '熊本県玉名郡和水町用木');
ok($zip->set_number('8650132')->is_valid_number, '熊本県玉名郡和水町萩原');
ok($zip->set_number('8650133')->is_valid_number, '熊本県玉名郡和水町蜻浦');
ok($zip->set_number('8650134')->is_valid_number, '熊本県玉名郡和水町日平');
ok($zip->set_number('8650135')->is_valid_number, '熊本県玉名郡和水町瀬川');
ok($zip->set_number('8650136')->is_valid_number, '熊本県玉名郡和水町江田');
ok($zip->set_number('8660000')->is_valid_number, '熊本県八代市以下に掲載がない場合');
ok($zip->set_number('8660001')->is_valid_number, '熊本県八代市郡築十二番町');
ok($zip->set_number('8660002')->is_valid_number, '熊本県八代市郡築十一番町');
ok($zip->set_number('8660003')->is_valid_number, '熊本県八代市郡築十番町');
ok($zip->set_number('8660004')->is_valid_number, '熊本県八代市郡築九番町');
ok($zip->set_number('8660005')->is_valid_number, '熊本県八代市郡築八番町');
ok($zip->set_number('8660006')->is_valid_number, '熊本県八代市郡築七番町');
ok($zip->set_number('8660007')->is_valid_number, '熊本県八代市郡築六番町');
ok($zip->set_number('8660008')->is_valid_number, '熊本県八代市郡築五番町');
ok($zip->set_number('8660011')->is_valid_number, '熊本県八代市井揚町');
ok($zip->set_number('8660012')->is_valid_number, '熊本県八代市高小原町');
ok($zip->set_number('8660013')->is_valid_number, '熊本県八代市沖町');
ok($zip->set_number('8660014')->is_valid_number, '熊本県八代市高島町');
ok($zip->set_number('8660015')->is_valid_number, '熊本県八代市築添町');
ok($zip->set_number('8660016')->is_valid_number, '熊本県八代市新地町');
ok($zip->set_number('8660017')->is_valid_number, '熊本県八代市三楽町');
ok($zip->set_number('8660021')->is_valid_number, '熊本県八代市郡築四番町');
ok($zip->set_number('8660022')->is_valid_number, '熊本県八代市郡築三番町');
ok($zip->set_number('8660023')->is_valid_number, '熊本県八代市郡築二番町');
ok($zip->set_number('8660024')->is_valid_number, '熊本県八代市郡築一番町');
ok($zip->set_number('8660031')->is_valid_number, '熊本県八代市新浜町');
ok($zip->set_number('8660032')->is_valid_number, '熊本県八代市新開町');
ok($zip->set_number('8660033')->is_valid_number, '熊本県八代市港町');
ok($zip->set_number('8660034')->is_valid_number, '熊本県八代市新港町');
ok($zip->set_number('8660035')->is_valid_number, '熊本県八代市大島町');
ok($zip->set_number('8660041')->is_valid_number, '熊本県八代市八幡町');
ok($zip->set_number('8660042')->is_valid_number, '熊本県八代市蛇籠町');
ok($zip->set_number('8660043')->is_valid_number, '熊本県八代市古城町');
ok($zip->set_number('8660044')->is_valid_number, '熊本県八代市中北町');
ok($zip->set_number('8660045')->is_valid_number, '熊本県八代市建馬町');
ok($zip->set_number('8660051')->is_valid_number, '熊本県八代市麦島東町');
ok($zip->set_number('8660052')->is_valid_number, '熊本県八代市麦島西町');
ok($zip->set_number('8660053')->is_valid_number, '熊本県八代市千反町');
ok($zip->set_number('8660054')->is_valid_number, '熊本県八代市栴檀町');
ok($zip->set_number('8660055')->is_valid_number, '熊本県八代市迎町');
ok($zip->set_number('8660061')->is_valid_number, '熊本県八代市渡町');
ok($zip->set_number('8660062')->is_valid_number, '熊本県八代市豊原中町');
ok($zip->set_number('8660063')->is_valid_number, '熊本県八代市豊原上町');
ok($zip->set_number('8660064')->is_valid_number, '熊本県八代市奈良木町');
ok($zip->set_number('8660065')->is_valid_number, '熊本県八代市豊原下町');
ok($zip->set_number('8660071')->is_valid_number, '熊本県八代市高下東町');
ok($zip->set_number('8660072')->is_valid_number, '熊本県八代市高下西町');
ok($zip->set_number('8660073')->is_valid_number, '熊本県八代市本野町');
ok($zip->set_number('8660074')->is_valid_number, '熊本県八代市平山新町');
ok($zip->set_number('8660081')->is_valid_number, '熊本県八代市植柳上町');
ok($zip->set_number('8660082')->is_valid_number, '熊本県八代市大福寺町');
ok($zip->set_number('8660083')->is_valid_number, '熊本県八代市植柳下町');
ok($zip->set_number('8660084')->is_valid_number, '熊本県八代市植柳新町');
ok($zip->set_number('8660085')->is_valid_number, '熊本県八代市植柳元町');
ok($zip->set_number('8660101')->is_valid_number, '熊本県上天草市姫戸町姫浦');
ok($zip->set_number('8660102')->is_valid_number, '熊本県上天草市姫戸町二間戸');
ok($zip->set_number('8660201')->is_valid_number, '熊本県上天草市龍ケ岳町大道');
ok($zip->set_number('8660202')->is_valid_number, '熊本県上天草市龍ケ岳町高戸');
ok($zip->set_number('8660203')->is_valid_number, '熊本県上天草市龍ケ岳町樋島');
ok($zip->set_number('8660303')->is_valid_number, '熊本県天草市御所浦町横浦');
ok($zip->set_number('8660313')->is_valid_number, '熊本県天草市御所浦町御所浦');
ok($zip->set_number('8660334')->is_valid_number, '熊本県天草市御所浦町牧島');
ok($zip->set_number('8660801')->is_valid_number, '熊本県八代市東町');
ok($zip->set_number('8660802')->is_valid_number, '熊本県八代市妙見町');
ok($zip->set_number('8660803')->is_valid_number, '熊本県八代市古麓町');
ok($zip->set_number('8660804')->is_valid_number, '熊本県八代市西宮町');
ok($zip->set_number('8660805')->is_valid_number, '熊本県八代市宮地町');
ok($zip->set_number('8660811')->is_valid_number, '熊本県八代市西片町');
ok($zip->set_number('8660812')->is_valid_number, '熊本県八代市中片町');
ok($zip->set_number('8660813')->is_valid_number, '熊本県八代市上片町');
ok($zip->set_number('8660814')->is_valid_number, '熊本県八代市東片町');
ok($zip->set_number('8660815')->is_valid_number, '熊本県八代市長田町');
ok($zip->set_number('8660821')->is_valid_number, '熊本県八代市福正町');
ok($zip->set_number('8660822')->is_valid_number, '熊本県八代市福正元町');
ok($zip->set_number('8660823')->is_valid_number, '熊本県八代市十条町');
ok($zip->set_number('8660824')->is_valid_number, '熊本県八代市上日置町');
ok($zip->set_number('8660825')->is_valid_number, '熊本県八代市井上町');
ok($zip->set_number('8660826')->is_valid_number, '熊本県八代市竹原町');
ok($zip->set_number('8660827')->is_valid_number, '熊本県八代市島田町');
ok($zip->set_number('8660831')->is_valid_number, '熊本県八代市萩原町');
ok($zip->set_number('8660832')->is_valid_number, '熊本県八代市末広町');
ok($zip->set_number('8660833')->is_valid_number, '熊本県八代市夕葉町');
ok($zip->set_number('8660834')->is_valid_number, '熊本県八代市錦町');
ok($zip->set_number('8660841')->is_valid_number, '熊本県八代市緑町');
ok($zip->set_number('8660842')->is_valid_number, '熊本県八代市若草町');
ok($zip->set_number('8660843')->is_valid_number, '熊本県八代市花園町');
ok($zip->set_number('8660844')->is_valid_number, '熊本県八代市旭中央通');
ok($zip->set_number('8660845')->is_valid_number, '熊本県八代市黄金町');
ok($zip->set_number('8660846')->is_valid_number, '熊本県八代市弥生町');
ok($zip->set_number('8660851')->is_valid_number, '熊本県八代市毘舎丸町');
ok($zip->set_number('8660852')->is_valid_number, '熊本県八代市大手町');
ok($zip->set_number('8660853')->is_valid_number, '熊本県八代市清水町');
ok($zip->set_number('8660854')->is_valid_number, '熊本県八代市新町');
ok($zip->set_number('8660855')->is_valid_number, '熊本県八代市袋町');
ok($zip->set_number('8660856')->is_valid_number, '熊本県八代市通町');
ok($zip->set_number('8660857')->is_valid_number, '熊本県八代市出町');
ok($zip->set_number('8660861')->is_valid_number, '熊本県八代市本町');
ok($zip->set_number('8660862')->is_valid_number, '熊本県八代市松江城町');
ok($zip->set_number('8660863')->is_valid_number, '熊本県八代市西松江城町');
ok($zip->set_number('8660864')->is_valid_number, '熊本県八代市塩屋町');
ok($zip->set_number('8660865')->is_valid_number, '熊本県八代市北の丸町');
ok($zip->set_number('8660866')->is_valid_number, '熊本県八代市鷹辻町');
ok($zip->set_number('8660871')->is_valid_number, '熊本県八代市田中東町');
ok($zip->set_number('8660872')->is_valid_number, '熊本県八代市田中町');
ok($zip->set_number('8660873')->is_valid_number, '熊本県八代市横手町');
ok($zip->set_number('8660874')->is_valid_number, '熊本県八代市横手本町');
ok($zip->set_number('8660875')->is_valid_number, '熊本県八代市横手新町');
ok($zip->set_number('8660876')->is_valid_number, '熊本県八代市田中西町');
ok($zip->set_number('8660877')->is_valid_number, '熊本県八代市田中北町');
ok($zip->set_number('8660881')->is_valid_number, '熊本県八代市興国町');
ok($zip->set_number('8660882')->is_valid_number, '熊本県八代市松江本町');
ok($zip->set_number('8660883')->is_valid_number, '熊本県八代市松江町');
ok($zip->set_number('8660884')->is_valid_number, '熊本県八代市松崎町');
ok($zip->set_number('8660885')->is_valid_number, '熊本県八代市永碇町');
ok($zip->set_number('8660891')->is_valid_number, '熊本県八代市古閑浜町');
ok($zip->set_number('8660892')->is_valid_number, '熊本県八代市古閑下町');
ok($zip->set_number('8660893')->is_valid_number, '熊本県八代市海士江町');
ok($zip->set_number('8660894')->is_valid_number, '熊本県八代市上野町');
ok($zip->set_number('8660895')->is_valid_number, '熊本県八代市大村町');
ok($zip->set_number('8660896')->is_valid_number, '熊本県八代市日置町');
ok($zip->set_number('8660897')->is_valid_number, '熊本県八代市古閑上町');
ok($zip->set_number('8660898')->is_valid_number, '熊本県八代市古閑中町');
ok($zip->set_number('8670000')->is_valid_number, '熊本県水俣市以下に掲載がない場合');
ok($zip->set_number('8670001')->is_valid_number, '熊本県水俣市小津奈木');
ok($zip->set_number('8670002')->is_valid_number, '熊本県水俣市初野');
ok($zip->set_number('8670003')->is_valid_number, '熊本県水俣市ひばりケ丘');
ok($zip->set_number('8670004')->is_valid_number, '熊本県水俣市わらび野');
ok($zip->set_number('8670005')->is_valid_number, '熊本県水俣市牧ノ内');
ok($zip->set_number('8670006')->is_valid_number, '熊本県水俣市白浜町');
ok($zip->set_number('8670007')->is_valid_number, '熊本県水俣市桜ケ丘');
ok($zip->set_number('8670008')->is_valid_number, '熊本県水俣市浜');
ok($zip->set_number('8670009')->is_valid_number, '熊本県水俣市大迫');
ok($zip->set_number('8670011')->is_valid_number, '熊本県水俣市陣内');
ok($zip->set_number('8670012')->is_valid_number, '熊本県水俣市古城');
ok($zip->set_number('8670013')->is_valid_number, '熊本県水俣市長野町');
ok($zip->set_number('8670014')->is_valid_number, '熊本県水俣市中鶴');
ok($zip->set_number('8670015')->is_valid_number, '熊本県水俣市深川');
ok($zip->set_number('8670016')->is_valid_number, '熊本県水俣市薄原(桜野、桜野上場、芦刈赤林)');
ok($zip->set_number('8670021')->is_valid_number, '熊本県水俣市平町');
ok($zip->set_number('8670022')->is_valid_number, '熊本県水俣市江南町');
ok($zip->set_number('8670023')->is_valid_number, '熊本県水俣市南福寺');
ok($zip->set_number('8670024')->is_valid_number, '熊本県水俣市長野');
ok($zip->set_number('8670025')->is_valid_number, '熊本県水俣市湯出');
ok($zip->set_number('8670031')->is_valid_number, '熊本県水俣市八ノ窪町');
ok($zip->set_number('8670032')->is_valid_number, '熊本県水俣市江添');
ok($zip->set_number('8670033')->is_valid_number, '熊本県水俣市長崎');
ok($zip->set_number('8670034')->is_valid_number, '熊本県水俣市袋');
ok($zip->set_number('8670035')->is_valid_number, '熊本県水俣市月浦');
ok($zip->set_number('8670036')->is_valid_number, '熊本県水俣市浦上町');
ok($zip->set_number('8670041')->is_valid_number, '熊本県水俣市天神町');
ok($zip->set_number('8670042')->is_valid_number, '熊本県水俣市大園町');
ok($zip->set_number('8670043')->is_valid_number, '熊本県水俣市大黒町');
ok($zip->set_number('8670044')->is_valid_number, '熊本県水俣市旭町');
ok($zip->set_number('8670045')->is_valid_number, '熊本県水俣市桜井町');
ok($zip->set_number('8670046')->is_valid_number, '熊本県水俣市山手町');
ok($zip->set_number('8670047')->is_valid_number, '熊本県水俣市緑ケ丘');
ok($zip->set_number('8670048')->is_valid_number, '熊本県水俣市多々良町');
ok($zip->set_number('8670049')->is_valid_number, '熊本県水俣市百間町');
ok($zip->set_number('8670051')->is_valid_number, '熊本県水俣市昭和町');
ok($zip->set_number('8670052')->is_valid_number, '熊本県水俣市港町');
ok($zip->set_number('8670053')->is_valid_number, '熊本県水俣市野口町');
ok($zip->set_number('8670054')->is_valid_number, '熊本県水俣市汐見町');
ok($zip->set_number('8670055')->is_valid_number, '熊本県水俣市明神町');
ok($zip->set_number('8670056')->is_valid_number, '熊本県水俣市梅戸町');
ok($zip->set_number('8670057')->is_valid_number, '熊本県水俣市祇園町');
ok($zip->set_number('8670058')->is_valid_number, '熊本県水俣市丸島町');
ok($zip->set_number('8670059')->is_valid_number, '熊本県水俣市栄町');
ok($zip->set_number('8670061')->is_valid_number, '熊本県水俣市八幡町');
ok($zip->set_number('8670062')->is_valid_number, '熊本県水俣市築地');
ok($zip->set_number('8670063')->is_valid_number, '熊本県水俣市洗切町');
ok($zip->set_number('8670064')->is_valid_number, '熊本県水俣市幸町');
ok($zip->set_number('8670065')->is_valid_number, '熊本県水俣市浜町');
ok($zip->set_number('8670066')->is_valid_number, '熊本県水俣市古賀町');
ok($zip->set_number('8670067')->is_valid_number, '熊本県水俣市塩浜町');
ok($zip->set_number('8670068')->is_valid_number, '熊本県水俣市浜松町');
ok($zip->set_number('8670116')->is_valid_number, '熊本県水俣市薄原(その他)');
ok($zip->set_number('8670171')->is_valid_number, '熊本県水俣市宝川内');
ok($zip->set_number('8670172')->is_valid_number, '熊本県水俣市市渡瀬');
ok($zip->set_number('8670173')->is_valid_number, '熊本県水俣市葛渡');
ok($zip->set_number('8670174')->is_valid_number, '熊本県水俣市石坂川');
ok($zip->set_number('8670281')->is_valid_number, '熊本県水俣市久木野');
ok($zip->set_number('8670282')->is_valid_number, '熊本県水俣市古里');
ok($zip->set_number('8670283')->is_valid_number, '熊本県水俣市大川');
ok($zip->set_number('8670284')->is_valid_number, '熊本県水俣市越小場');
ok($zip->set_number('8680000')->is_valid_number, '熊本県人吉市以下に掲載がない場合');
ok($zip->set_number('8680000')->is_valid_number, '熊本県球磨郡相良村以下に掲載がない場合');
ok($zip->set_number('8680000')->is_valid_number, '熊本県球磨郡山江村以下に掲載がない場合');
ok($zip->set_number('8680001')->is_valid_number, '熊本県人吉市鍛冶屋町');
ok($zip->set_number('8680002')->is_valid_number, '熊本県人吉市大工町');
ok($zip->set_number('8680003')->is_valid_number, '熊本県人吉市紺屋町');
ok($zip->set_number('8680004')->is_valid_number, '熊本県人吉市九日町');
ok($zip->set_number('8680005')->is_valid_number, '熊本県人吉市上青井町');
ok($zip->set_number('8680006')->is_valid_number, '熊本県人吉市駒井田町');
ok($zip->set_number('8680007')->is_valid_number, '熊本県人吉市下青井町');
ok($zip->set_number('8680008')->is_valid_number, '熊本県人吉市中青井町');
ok($zip->set_number('8680011')->is_valid_number, '熊本県人吉市宝来町');
ok($zip->set_number('8680012')->is_valid_number, '熊本県人吉市相良町');
ok($zip->set_number('8680013')->is_valid_number, '熊本県人吉市上薩摩瀬町');
ok($zip->set_number('8680014')->is_valid_number, '熊本県人吉市下薩摩瀬町');
ok($zip->set_number('8680015')->is_valid_number, '熊本県人吉市下城本町');
ok($zip->set_number('8680016')->is_valid_number, '熊本県人吉市城本町');
ok($zip->set_number('8680021')->is_valid_number, '熊本県人吉市鬼木町');
ok($zip->set_number('8680022')->is_valid_number, '熊本県人吉市願成寺町');
ok($zip->set_number('8680022')->is_valid_number, '熊本県人吉市北願成寺町');
ok($zip->set_number('8680023')->is_valid_number, '熊本県人吉市北泉田町');
ok($zip->set_number('8680024')->is_valid_number, '熊本県人吉市鶴田町');
ok($zip->set_number('8680025')->is_valid_number, '熊本県人吉市瓦屋町');
ok($zip->set_number('8680026')->is_valid_number, '熊本県人吉市合ノ原町');
ok($zip->set_number('8680027')->is_valid_number, '熊本県人吉市井ノ口町');
ok($zip->set_number('8680031')->is_valid_number, '熊本県人吉市南願成寺町');
ok($zip->set_number('8680032')->is_valid_number, '熊本県人吉市上新町');
ok($zip->set_number('8680033')->is_valid_number, '熊本県人吉市下新町');
ok($zip->set_number('8680034')->is_valid_number, '熊本県人吉市七日町');
ok($zip->set_number('8680035')->is_valid_number, '熊本県人吉市五日町');
ok($zip->set_number('8680036')->is_valid_number, '熊本県人吉市二日町');
ok($zip->set_number('8680037')->is_valid_number, '熊本県人吉市南泉田町');
ok($zip->set_number('8680041')->is_valid_number, '熊本県人吉市七地町');
ok($zip->set_number('8680042')->is_valid_number, '熊本県人吉市蟹作町');
ok($zip->set_number('8680043')->is_valid_number, '熊本県人吉市東間上町');
ok($zip->set_number('8680044')->is_valid_number, '熊本県人吉市東間下町');
ok($zip->set_number('8680045')->is_valid_number, '熊本県人吉市浪床町');
ok($zip->set_number('8680046')->is_valid_number, '熊本県人吉市原城町');
ok($zip->set_number('8680047')->is_valid_number, '熊本県人吉市上原町');
ok($zip->set_number('8680048')->is_valid_number, '熊本県人吉市富ケ尾町');
ok($zip->set_number('8680051')->is_valid_number, '熊本県人吉市麓町');
ok($zip->set_number('8680052')->is_valid_number, '熊本県人吉市新町');
ok($zip->set_number('8680053')->is_valid_number, '熊本県人吉市老神町');
ok($zip->set_number('8680054')->is_valid_number, '熊本県人吉市田町');
ok($zip->set_number('8680055')->is_valid_number, '熊本県人吉市南町');
ok($zip->set_number('8680056')->is_valid_number, '熊本県人吉市寺町');
ok($zip->set_number('8680057')->is_valid_number, '熊本県人吉市土手町');
ok($zip->set_number('8680058')->is_valid_number, '熊本県人吉市灰久保町');
ok($zip->set_number('8680061')->is_valid_number, '熊本県人吉市蓑野町');
ok($zip->set_number('8680062')->is_valid_number, '熊本県人吉市古仏頂町');
ok($zip->set_number('8680063')->is_valid_number, '熊本県人吉市木地屋町');
ok($zip->set_number('8680064')->is_valid_number, '熊本県人吉市東大塚町');
ok($zip->set_number('8680065')->is_valid_number, '熊本県人吉市西大塚町');
ok($zip->set_number('8680066')->is_valid_number, '熊本県人吉市田野町');
ok($zip->set_number('8680071')->is_valid_number, '熊本県人吉市西間上町');
ok($zip->set_number('8680072')->is_valid_number, '熊本県人吉市西間下町');
ok($zip->set_number('8680073')->is_valid_number, '熊本県人吉市上永野町');
ok($zip->set_number('8680074')->is_valid_number, '熊本県人吉市下永野町');
ok($zip->set_number('8680075')->is_valid_number, '熊本県人吉市矢黒町');
ok($zip->set_number('8680076')->is_valid_number, '熊本県人吉市上戸越町');
ok($zip->set_number('8680077')->is_valid_number, '熊本県人吉市下戸越町');
ok($zip->set_number('8680078')->is_valid_number, '熊本県人吉市鹿目町');
ok($zip->set_number('8680081')->is_valid_number, '熊本県人吉市上林町');
ok($zip->set_number('8680082')->is_valid_number, '熊本県人吉市中林町');
ok($zip->set_number('8680083')->is_valid_number, '熊本県人吉市下林町');
ok($zip->set_number('8680084')->is_valid_number, '熊本県人吉市温泉町');
ok($zip->set_number('8680085')->is_valid_number, '熊本県人吉市中神町');
ok($zip->set_number('8680086')->is_valid_number, '熊本県人吉市下原田町');
ok($zip->set_number('8680087')->is_valid_number, '熊本県人吉市上原田町');
ok($zip->set_number('8680091')->is_valid_number, '熊本県球磨郡山江村万江');
ok($zip->set_number('8680092')->is_valid_number, '熊本県球磨郡山江村山田');
ok($zip->set_number('8680093')->is_valid_number, '熊本県球磨郡相良村川辺');
ok($zip->set_number('8680094')->is_valid_number, '熊本県球磨郡相良村深水');
ok($zip->set_number('8680095')->is_valid_number, '熊本県球磨郡相良村柳瀬');
ok($zip->set_number('8680101')->is_valid_number, '熊本県球磨郡相良村四浦');
ok($zip->set_number('8680200')->is_valid_number, '熊本県球磨郡五木村以下に掲載がない場合');
ok($zip->set_number('8680201')->is_valid_number, '熊本県球磨郡五木村甲');
ok($zip->set_number('8680202')->is_valid_number, '熊本県球磨郡五木村乙');
ok($zip->set_number('8680203')->is_valid_number, '熊本県球磨郡五木村丙');
ok($zip->set_number('8680300')->is_valid_number, '熊本県球磨郡錦町以下に掲載がない場合');
ok($zip->set_number('8680301')->is_valid_number, '熊本県球磨郡錦町木上');
ok($zip->set_number('8680302')->is_valid_number, '熊本県球磨郡錦町一武');
ok($zip->set_number('8680303')->is_valid_number, '熊本県球磨郡錦町西');
ok($zip->set_number('8680400')->is_valid_number, '熊本県球磨郡あさぎり町以下に掲載がない場合');
ok($zip->set_number('8680408')->is_valid_number, '熊本県球磨郡あさぎり町免田東');
ok($zip->set_number('8680415')->is_valid_number, '熊本県球磨郡あさぎり町免田西');
ok($zip->set_number('8680421')->is_valid_number, '熊本県球磨郡あさぎり町上東');
ok($zip->set_number('8680422')->is_valid_number, '熊本県球磨郡あさぎり町上北');
ok($zip->set_number('8680423')->is_valid_number, '熊本県球磨郡あさぎり町上南');
ok($zip->set_number('8680424')->is_valid_number, '熊本県球磨郡あさぎり町上西');
ok($zip->set_number('8680425')->is_valid_number, '熊本県球磨郡あさぎり町皆越');
ok($zip->set_number('8680431')->is_valid_number, '熊本県球磨郡あさぎり町岡原北');
ok($zip->set_number('8680432')->is_valid_number, '熊本県球磨郡あさぎり町岡原南');
ok($zip->set_number('8680441')->is_valid_number, '熊本県球磨郡あさぎり町深田北');
ok($zip->set_number('8680442')->is_valid_number, '熊本県球磨郡あさぎり町深田東');
ok($zip->set_number('8680443')->is_valid_number, '熊本県球磨郡あさぎり町深田南');
ok($zip->set_number('8680444')->is_valid_number, '熊本県球磨郡あさぎり町深田西');
ok($zip->set_number('8680451')->is_valid_number, '熊本県球磨郡あさぎり町須恵');
ok($zip->set_number('8680500')->is_valid_number, '熊本県球磨郡多良木町以下に掲載がない場合');
ok($zip->set_number('8680501')->is_valid_number, '熊本県球磨郡多良木町多良木');
ok($zip->set_number('8680502')->is_valid_number, '熊本県球磨郡多良木町黒肥地');
ok($zip->set_number('8680503')->is_valid_number, '熊本県球磨郡多良木町久米');
ok($zip->set_number('8680504')->is_valid_number, '熊本県球磨郡多良木町奥野');
ok($zip->set_number('8680505')->is_valid_number, '熊本県球磨郡多良木町槻木');
ok($zip->set_number('8680600')->is_valid_number, '熊本県球磨郡湯前町以下に掲載がない場合');
ok($zip->set_number('8680601')->is_valid_number, '熊本県球磨郡湯前町下城');
ok($zip->set_number('8680602')->is_valid_number, '熊本県球磨郡湯前町浜川');
ok($zip->set_number('8680603')->is_valid_number, '熊本県球磨郡湯前町古城');
ok($zip->set_number('8680604')->is_valid_number, '熊本県球磨郡湯前町浅ケ野');
ok($zip->set_number('8680605')->is_valid_number, '熊本県球磨郡湯前町下染田');
ok($zip->set_number('8680606')->is_valid_number, '熊本県球磨郡湯前町中里');
ok($zip->set_number('8680607')->is_valid_number, '熊本県球磨郡湯前町下里');
ok($zip->set_number('8680611')->is_valid_number, '熊本県球磨郡湯前町植木');
ok($zip->set_number('8680612')->is_valid_number, '熊本県球磨郡湯前町上村');
ok($zip->set_number('8680613')->is_valid_number, '熊本県球磨郡湯前町田上');
ok($zip->set_number('8680614')->is_valid_number, '熊本県球磨郡湯前町馬場');
ok($zip->set_number('8680615')->is_valid_number, '熊本県球磨郡湯前町瀬戸口');
ok($zip->set_number('8680616')->is_valid_number, '熊本県球磨郡湯前町下村');
ok($zip->set_number('8680621')->is_valid_number, '熊本県球磨郡湯前町上里');
ok($zip->set_number('8680622')->is_valid_number, '熊本県球磨郡湯前町上染田');
ok($zip->set_number('8680623')->is_valid_number, '熊本県球磨郡湯前町野中田');
ok($zip->set_number('8680624')->is_valid_number, '熊本県球磨郡湯前町中猪');
ok($zip->set_number('8680625')->is_valid_number, '熊本県球磨郡湯前町上猪');
ok($zip->set_number('8680700')->is_valid_number, '熊本県球磨郡水上村以下に掲載がない場合');
ok($zip->set_number('8680701')->is_valid_number, '熊本県球磨郡水上村岩野');
ok($zip->set_number('8680702')->is_valid_number, '熊本県球磨郡水上村江代');
ok($zip->set_number('8680703')->is_valid_number, '熊本県球磨郡水上村湯山');
ok($zip->set_number('8680801')->is_valid_number, '熊本県人吉市上田代町');
ok($zip->set_number('8680802')->is_valid_number, '熊本県人吉市下田代町');
ok($zip->set_number('8680803')->is_valid_number, '熊本県人吉市大畑町');
ok($zip->set_number('8680811')->is_valid_number, '熊本県人吉市大畑麓町');
ok($zip->set_number('8680812')->is_valid_number, '熊本県人吉市大野町');
ok($zip->set_number('8680813')->is_valid_number, '熊本県人吉市矢岳町');
ok($zip->set_number('8680821')->is_valid_number, '熊本県人吉市上漆田町');
ok($zip->set_number('8680822')->is_valid_number, '熊本県人吉市下漆田町');
ok($zip->set_number('8680823')->is_valid_number, '熊本県人吉市東漆田町');
ok($zip->set_number('8680824')->is_valid_number, '熊本県人吉市赤池水無町');
ok($zip->set_number('8680825')->is_valid_number, '熊本県人吉市赤池原町');
ok($zip->set_number('8690100')->is_valid_number, '熊本県玉名郡長洲町以下に掲載がない場合');
ok($zip->set_number('8690101')->is_valid_number, '熊本県玉名郡長洲町宮野');
ok($zip->set_number('8690102')->is_valid_number, '熊本県玉名郡長洲町折崎');
ok($zip->set_number('8690103')->is_valid_number, '熊本県玉名郡長洲町腹赤');
ok($zip->set_number('8690104')->is_valid_number, '熊本県玉名郡長洲町上沖洲');
ok($zip->set_number('8690105')->is_valid_number, '熊本県玉名郡長洲町清源寺');
ok($zip->set_number('8690106')->is_valid_number, '熊本県玉名郡長洲町永塩');
ok($zip->set_number('8690111')->is_valid_number, '熊本県玉名郡長洲町名石浜');
ok($zip->set_number('8690112')->is_valid_number, '熊本県玉名郡長洲町姫ケ浦');
ok($zip->set_number('8690113')->is_valid_number, '熊本県玉名郡長洲町有明');
ok($zip->set_number('8690121')->is_valid_number, '熊本県玉名郡長洲町高浜');
ok($zip->set_number('8690122')->is_valid_number, '熊本県玉名郡長洲町梅田');
ok($zip->set_number('8690123')->is_valid_number, '熊本県玉名郡長洲町長洲');
ok($zip->set_number('8690201')->is_valid_number, '熊本県玉名市岱明町山下');
ok($zip->set_number('8690202')->is_valid_number, '熊本県玉名市岱明町高道');
ok($zip->set_number('8690203')->is_valid_number, '熊本県玉名市岱明町浜田');
ok($zip->set_number('8690211')->is_valid_number, '熊本県玉名市岱明町鍋');
ok($zip->set_number('8690212')->is_valid_number, '熊本県玉名市岱明町下沖洲');
ok($zip->set_number('8690213')->is_valid_number, '熊本県玉名市岱明町扇崎');
ok($zip->set_number('8690221')->is_valid_number, '熊本県玉名市岱明町下前原');
ok($zip->set_number('8690222')->is_valid_number, '熊本県玉名市岱明町野口');
ok($zip->set_number('8690223')->is_valid_number, '熊本県玉名市岱明町中土');
ok($zip->set_number('8690224')->is_valid_number, '熊本県玉名市岱明町大野下');
ok($zip->set_number('8690231')->is_valid_number, '熊本県玉名市岱明町庄山');
ok($zip->set_number('8690232')->is_valid_number, '熊本県玉名市岱明町上(その他)');
ok($zip->set_number('8690233')->is_valid_number, '熊本県玉名市岱明町古閑(その他)');
ok($zip->set_number('8690234')->is_valid_number, '熊本県玉名市岱明町三崎');
ok($zip->set_number('8690235')->is_valid_number, '熊本県玉名市岱明町古閑(雲雀丘)');
ok($zip->set_number('8690235')->is_valid_number, '熊本県玉名市岱明町西照寺(雲雀丘)');
ok($zip->set_number('8690235')->is_valid_number, '熊本県玉名市岱明町上(雲雀丘)');
ok($zip->set_number('8690236')->is_valid_number, '熊本県玉名市岱明町西照寺(その他)');
ok($zip->set_number('8690238')->is_valid_number, '熊本県玉名市岱明町開田');
ok($zip->set_number('8690300')->is_valid_number, '熊本県玉名郡玉東町以下に掲載がない場合');
ok($zip->set_number('8690301')->is_valid_number, '熊本県玉名郡玉東町稲佐');
ok($zip->set_number('8690302')->is_valid_number, '熊本県玉名郡玉東町山口');
ok($zip->set_number('8690303')->is_valid_number, '熊本県玉名郡玉東町木葉');
ok($zip->set_number('8690304')->is_valid_number, '熊本県玉名郡玉東町浦田');
ok($zip->set_number('8690305')->is_valid_number, '熊本県玉名郡玉東町上木葉');
ok($zip->set_number('8690311')->is_valid_number, '熊本県玉名郡玉東町二俣');
ok($zip->set_number('8690312')->is_valid_number, '熊本県玉名郡玉東町白木');
ok($zip->set_number('8690313')->is_valid_number, '熊本県玉名郡玉東町上白木');
ok($zip->set_number('8690321')->is_valid_number, '熊本県玉名郡玉東町西安寺');
ok($zip->set_number('8690322')->is_valid_number, '熊本県玉名郡玉東町原倉');
ok($zip->set_number('8690400')->is_valid_number, '熊本県宇土市以下に掲載がない場合');
ok($zip->set_number('8690401')->is_valid_number, '熊本県宇土市住吉町');
ok($zip->set_number('8690402')->is_valid_number, '熊本県宇土市笹原町');
ok($zip->set_number('8690403')->is_valid_number, '熊本県宇土市新開町');
ok($zip->set_number('8690404')->is_valid_number, '熊本県宇土市走潟町');
ok($zip->set_number('8690405')->is_valid_number, '熊本県宇土市馬之瀬町');
ok($zip->set_number('8690406')->is_valid_number, '熊本県宇土市三拾町');
ok($zip->set_number('8690407')->is_valid_number, '熊本県宇土市松原町');
ok($zip->set_number('8690408')->is_valid_number, '熊本県宇土市築籠町');
ok($zip->set_number('8690410')->is_valid_number, '熊本県宇土市花園台町');
ok($zip->set_number('8690411')->is_valid_number, '熊本県宇土市水町');
ok($zip->set_number('8690412')->is_valid_number, '熊本県宇土市岩古曽町');
ok($zip->set_number('8690413')->is_valid_number, '熊本県宇土市花園町');
ok($zip->set_number('8690414')->is_valid_number, '熊本県宇土市立岡町');
ok($zip->set_number('8690415')->is_valid_number, '熊本県宇土市古保里町');
ok($zip->set_number('8690416')->is_valid_number, '熊本県宇土市松山町');
ok($zip->set_number('8690417')->is_valid_number, '熊本県宇土市境目町');
ok($zip->set_number('8690418')->is_valid_number, '熊本県宇土市善道寺町');
ok($zip->set_number('8690419')->is_valid_number, '熊本県宇土市新松原町');
ok($zip->set_number('8690421')->is_valid_number, '熊本県宇土市南段原町');
ok($zip->set_number('8690422')->is_valid_number, '熊本県宇土市入地町');
ok($zip->set_number('8690423')->is_valid_number, '熊本県宇土市伊無田町');
ok($zip->set_number('8690424')->is_valid_number, '熊本県宇土市神馬町');
ok($zip->set_number('8690425')->is_valid_number, '熊本県宇土市栗崎町');
ok($zip->set_number('8690426')->is_valid_number, '熊本県宇土市神合町');
ok($zip->set_number('8690431')->is_valid_number, '熊本県宇土市本町');
ok($zip->set_number('8690432')->is_valid_number, '熊本県宇土市旭町');
ok($zip->set_number('8690433')->is_valid_number, '熊本県宇土市新小路町');
ok($zip->set_number('8690434')->is_valid_number, '熊本県宇土市門内町');
ok($zip->set_number('8690435')->is_valid_number, '熊本県宇土市一里木町');
ok($zip->set_number('8690436')->is_valid_number, '熊本県宇土市定府町');
ok($zip->set_number('8690441')->is_valid_number, '熊本県宇土市石小路町');
ok($zip->set_number('8690442')->is_valid_number, '熊本県宇土市城之浦町');
ok($zip->set_number('8690443')->is_valid_number, '熊本県宇土市船場町');
ok($zip->set_number('8690444')->is_valid_number, '熊本県宇土市新町');
ok($zip->set_number('8690445')->is_valid_number, '熊本県宇土市浦田町');
ok($zip->set_number('8690451')->is_valid_number, '熊本県宇土市北段原町');
ok($zip->set_number('8690452')->is_valid_number, '熊本県宇土市高柳町');
ok($zip->set_number('8690453')->is_valid_number, '熊本県宇土市栄町');
ok($zip->set_number('8690454')->is_valid_number, '熊本県宇土市古城町');
ok($zip->set_number('8690455')->is_valid_number, '熊本県宇土市椿原町');
ok($zip->set_number('8690456')->is_valid_number, '熊本県宇土市石橋町');
ok($zip->set_number('8690457')->is_valid_number, '熊本県宇土市宮庄町');
ok($zip->set_number('8690461')->is_valid_number, '熊本県宇土市網津町');
ok($zip->set_number('8690462')->is_valid_number, '熊本県宇土市城塚町');
ok($zip->set_number('8690463')->is_valid_number, '熊本県宇土市野鶴町');
ok($zip->set_number('8690464')->is_valid_number, '熊本県宇土市恵塚町');
ok($zip->set_number('8690465')->is_valid_number, '熊本県宇土市網引町');
ok($zip->set_number('8690500')->is_valid_number, '熊本県宇城市以下に掲載がない場合');
ok($zip->set_number('8690501')->is_valid_number, '熊本県宇城市松橋町松山');
ok($zip->set_number('8690502')->is_valid_number, '熊本県宇城市松橋町松橋');
ok($zip->set_number('8690503')->is_valid_number, '熊本県宇城市松橋町きらら');
ok($zip->set_number('8690511')->is_valid_number, '熊本県宇城市松橋町曲野');
ok($zip->set_number('8690512')->is_valid_number, '熊本県宇城市松橋町古保山');
ok($zip->set_number('8690513')->is_valid_number, '熊本県宇城市松橋町萩尾');
ok($zip->set_number('8690521')->is_valid_number, '熊本県宇城市松橋町浦川内');
ok($zip->set_number('8690522')->is_valid_number, '熊本県宇城市松橋町内田');
ok($zip->set_number('8690523')->is_valid_number, '熊本県宇城市松橋町竹崎');
ok($zip->set_number('8690524')->is_valid_number, '熊本県宇城市松橋町豊福');
ok($zip->set_number('8690531')->is_valid_number, '熊本県宇城市松橋町大野');
ok($zip->set_number('8690532')->is_valid_number, '熊本県宇城市松橋町久具');
ok($zip->set_number('8690533')->is_valid_number, '熊本県宇城市松橋町両仲間');
ok($zip->set_number('8690534')->is_valid_number, '熊本県宇城市松橋町西下郷');
ok($zip->set_number('8690541')->is_valid_number, '熊本県宇城市松橋町東松崎');
ok($zip->set_number('8690542')->is_valid_number, '熊本県宇城市松橋町豊崎');
ok($zip->set_number('8690543')->is_valid_number, '熊本県宇城市松橋町南豊崎');
ok($zip->set_number('8690544')->is_valid_number, '熊本県宇城市松橋町浅川');
ok($zip->set_number('8690545')->is_valid_number, '熊本県宇城市松橋町砂川');
ok($zip->set_number('8690546')->is_valid_number, '熊本県宇城市松橋町御船');
ok($zip->set_number('8690551')->is_valid_number, '熊本県宇城市不知火町御領');
ok($zip->set_number('8690552')->is_valid_number, '熊本県宇城市不知火町高良');
ok($zip->set_number('8690553')->is_valid_number, '熊本県宇城市不知火町小曽部');
ok($zip->set_number('8690554')->is_valid_number, '熊本県宇城市不知火町柏原');
ok($zip->set_number('8690561')->is_valid_number, '熊本県宇城市不知火町亀松');
ok($zip->set_number('8690562')->is_valid_number, '熊本県宇城市不知火町長崎');
ok($zip->set_number('8690563')->is_valid_number, '熊本県宇城市不知火町浦上');
ok($zip->set_number('8690601')->is_valid_number, '熊本県宇城市小川町北小野');
ok($zip->set_number('8690602')->is_valid_number, '熊本県宇城市小川町中小野');
ok($zip->set_number('8690603')->is_valid_number, '熊本県宇城市小川町南小野');
ok($zip->set_number('8690604')->is_valid_number, '熊本県宇城市小川町北部田');
ok($zip->set_number('8690605')->is_valid_number, '熊本県宇城市小川町南部田');
ok($zip->set_number('8690606')->is_valid_number, '熊本県宇城市小川町河江');
ok($zip->set_number('8690611')->is_valid_number, '熊本県宇城市小川町東海東');
ok($zip->set_number('8690612')->is_valid_number, '熊本県宇城市小川町南海東');
ok($zip->set_number('8690613')->is_valid_number, '熊本県宇城市小川町東小川');
ok($zip->set_number('8690614')->is_valid_number, '熊本県宇城市小川町南小川');
ok($zip->set_number('8690615')->is_valid_number, '熊本県宇城市小川町西海東');
ok($zip->set_number('8690616')->is_valid_number, '熊本県宇城市小川町北海東');
ok($zip->set_number('8690621')->is_valid_number, '熊本県宇城市小川町小川');
ok($zip->set_number('8690622')->is_valid_number, '熊本県宇城市小川町西北小川');
ok($zip->set_number('8690623')->is_valid_number, '熊本県宇城市小川町川尻');
ok($zip->set_number('8690624')->is_valid_number, '熊本県宇城市小川町江頭');
ok($zip->set_number('8690631')->is_valid_number, '熊本県宇城市小川町北新田');
ok($zip->set_number('8690632')->is_valid_number, '熊本県宇城市小川町南新田');
ok($zip->set_number('8690633')->is_valid_number, '熊本県宇城市小川町新田');
ok($zip->set_number('8690634')->is_valid_number, '熊本県宇城市小川町住吉');
ok($zip->set_number('8690635')->is_valid_number, '熊本県宇城市小川町不知火');
ok($zip->set_number('8690636')->is_valid_number, '熊本県宇城市小川町新田出');
ok($zip->set_number('8691100')->is_valid_number, '熊本県菊池郡菊陽町以下に掲載がない場合');
ok($zip->set_number('8691101')->is_valid_number, '熊本県菊池郡菊陽町津久礼');
ok($zip->set_number('8691102')->is_valid_number, '熊本県菊池郡菊陽町原水');
ok($zip->set_number('8691103')->is_valid_number, '熊本県菊池郡菊陽町久保田');
ok($zip->set_number('8691104')->is_valid_number, '熊本県菊池郡菊陽町戸次');
ok($zip->set_number('8691105')->is_valid_number, '熊本県菊池郡菊陽町馬場楠');
ok($zip->set_number('8691106')->is_valid_number, '熊本県菊池郡菊陽町曲手');
ok($zip->set_number('8691107')->is_valid_number, '熊本県菊池郡菊陽町辛川');
ok($zip->set_number('8691108')->is_valid_number, '熊本県菊池郡菊陽町光の森');
ok($zip->set_number('8691109')->is_valid_number, '熊本県菊池郡菊陽町新山');
ok($zip->set_number('8691110')->is_valid_number, '熊本県菊池郡菊陽町杉並台');
ok($zip->set_number('8691111')->is_valid_number, '熊本県菊池郡菊陽町武蔵ヶ丘');
ok($zip->set_number('8691112')->is_valid_number, '熊本県菊池郡菊陽町武蔵ヶ丘北');
ok($zip->set_number('8691113')->is_valid_number, '熊本県菊池郡菊陽町花立');
ok($zip->set_number('8691114')->is_valid_number, '熊本県菊池郡菊陽町向陽台');
ok($zip->set_number('8691115')->is_valid_number, '熊本県菊池郡菊陽町沖野');
ok($zip->set_number('8691200')->is_valid_number, '熊本県菊池郡大津町以下に掲載がない場合');
ok($zip->set_number('8691201')->is_valid_number, '熊本県菊池市旭志弁利');
ok($zip->set_number('8691202')->is_valid_number, '熊本県菊池市旭志麓');
ok($zip->set_number('8691203')->is_valid_number, '熊本県菊池市旭志尾足');
ok($zip->set_number('8691204')->is_valid_number, '熊本県菊池市旭志小原');
ok($zip->set_number('8691205')->is_valid_number, '熊本県菊池市旭志川辺');
ok($zip->set_number('8691206')->is_valid_number, '熊本県菊池市旭志伊坂');
ok($zip->set_number('8691207')->is_valid_number, '熊本県菊池市旭志新明');
ok($zip->set_number('8691208')->is_valid_number, '熊本県菊池市旭志伊萩');
ok($zip->set_number('8691211')->is_valid_number, '熊本県菊池郡大津町矢護川');
ok($zip->set_number('8691212')->is_valid_number, '熊本県菊池郡大津町真木');
ok($zip->set_number('8691213')->is_valid_number, '熊本県菊池郡大津町古城');
ok($zip->set_number('8691214')->is_valid_number, '熊本県菊池郡大津町瀬田');
ok($zip->set_number('8691215')->is_valid_number, '熊本県菊池郡大津町外牧');
ok($zip->set_number('8691216')->is_valid_number, '熊本県菊池郡大津町錦野');
ok($zip->set_number('8691217')->is_valid_number, '熊本県菊池郡大津町森');
ok($zip->set_number('8691218')->is_valid_number, '熊本県菊池郡大津町吹田');
ok($zip->set_number('8691219')->is_valid_number, '熊本県菊池郡大津町大林');
ok($zip->set_number('8691221')->is_valid_number, '熊本県菊池郡大津町陣内');
ok($zip->set_number('8691222')->is_valid_number, '熊本県菊池郡大津町岩坂');
ok($zip->set_number('8691223')->is_valid_number, '熊本県菊池郡大津町中島');
ok($zip->set_number('8691224')->is_valid_number, '熊本県菊池郡大津町町');
ok($zip->set_number('8691225')->is_valid_number, '熊本県菊池郡大津町下町');
ok($zip->set_number('8691226')->is_valid_number, '熊本県菊池郡大津町灰塚');
ok($zip->set_number('8691227')->is_valid_number, '熊本県菊池郡大津町新');
ok($zip->set_number('8691231')->is_valid_number, '熊本県菊池郡大津町平川');
ok($zip->set_number('8691232')->is_valid_number, '熊本県菊池郡大津町高尾野');
ok($zip->set_number('8691233')->is_valid_number, '熊本県菊池郡大津町大津');
ok($zip->set_number('8691234')->is_valid_number, '熊本県菊池郡大津町引水');
ok($zip->set_number('8691235')->is_valid_number, '熊本県菊池郡大津町室');
ok($zip->set_number('8691236')->is_valid_number, '熊本県菊池郡大津町杉水');
ok($zip->set_number('8691237')->is_valid_number, '熊本県菊池郡大津町美咲野');
ok($zip->set_number('8691400')->is_valid_number, '熊本県阿蘇郡南阿蘇村以下に掲載がない場合');
ok($zip->set_number('8691401')->is_valid_number, '熊本県阿蘇郡南阿蘇村立野');
ok($zip->set_number('8691402')->is_valid_number, '熊本県阿蘇郡南阿蘇村下野');
ok($zip->set_number('8691403')->is_valid_number, '熊本県阿蘇郡南阿蘇村長野');
ok($zip->set_number('8691404')->is_valid_number, '熊本県阿蘇郡南阿蘇村河陽');
ok($zip->set_number('8691411')->is_valid_number, '熊本県阿蘇郡南阿蘇村河陰');
ok($zip->set_number('8691412')->is_valid_number, '熊本県阿蘇郡南阿蘇村久石');
ok($zip->set_number('8691501')->is_valid_number, '熊本県阿蘇郡南阿蘇村両併');
ok($zip->set_number('8691502')->is_valid_number, '熊本県阿蘇郡南阿蘇村白川');
ok($zip->set_number('8691503')->is_valid_number, '熊本県阿蘇郡南阿蘇村吉田');
ok($zip->set_number('8691504')->is_valid_number, '熊本県阿蘇郡南阿蘇村一関');
ok($zip->set_number('8691505')->is_valid_number, '熊本県阿蘇郡南阿蘇村中松(その他)');
ok($zip->set_number('8691600')->is_valid_number, '熊本県阿蘇郡高森町以下に掲載がない場合');
ok($zip->set_number('8691601')->is_valid_number, '熊本県阿蘇郡高森町上色見');
ok($zip->set_number('8691602')->is_valid_number, '熊本県阿蘇郡高森町高森');
ok($zip->set_number('8691603')->is_valid_number, '熊本県阿蘇郡高森町色見');
ok($zip->set_number('8691811')->is_valid_number, '熊本県阿蘇郡高森町草部');
ok($zip->set_number('8691812')->is_valid_number, '熊本県阿蘇郡高森町芹口');
ok($zip->set_number('8691813')->is_valid_number, '熊本県阿蘇郡高森町菅山');
ok($zip->set_number('8691814')->is_valid_number, '熊本県阿蘇郡高森町永野原');
ok($zip->set_number('8691815')->is_valid_number, '熊本県阿蘇郡高森町下切');
ok($zip->set_number('8691821')->is_valid_number, '熊本県阿蘇郡高森町中');
ok($zip->set_number('8691822')->is_valid_number, '熊本県阿蘇郡高森町矢津田');
ok($zip->set_number('8691823')->is_valid_number, '熊本県阿蘇郡高森町津留');
ok($zip->set_number('8691824')->is_valid_number, '熊本県阿蘇郡高森町野尻');
ok($zip->set_number('8691825')->is_valid_number, '熊本県阿蘇郡高森町尾下');
ok($zip->set_number('8691826')->is_valid_number, '熊本県阿蘇郡高森町河原');
ok($zip->set_number('8692205')->is_valid_number, '熊本県阿蘇郡南阿蘇村中松(古坊中)');
ok($zip->set_number('8692221')->is_valid_number, '熊本県阿蘇市役犬原');
ok($zip->set_number('8692222')->is_valid_number, '熊本県阿蘇市西町');
ok($zip->set_number('8692223')->is_valid_number, '熊本県阿蘇市竹原');
ok($zip->set_number('8692224')->is_valid_number, '熊本県阿蘇市蔵原');
ok($zip->set_number('8692225')->is_valid_number, '熊本県阿蘇市黒川');
ok($zip->set_number('8692226')->is_valid_number, '熊本県阿蘇市乙姫');
ok($zip->set_number('8692231')->is_valid_number, '熊本県阿蘇市永草');
ok($zip->set_number('8692232')->is_valid_number, '熊本県阿蘇市赤水');
ok($zip->set_number('8692233')->is_valid_number, '熊本県阿蘇市無田');
ok($zip->set_number('8692234')->is_valid_number, '熊本県阿蘇市車帰');
ok($zip->set_number('8692235')->is_valid_number, '熊本県阿蘇市狩尾');
ok($zip->set_number('8692236')->is_valid_number, '熊本県阿蘇市跡ケ瀬');
ok($zip->set_number('8692237')->is_valid_number, '熊本県阿蘇市的石');
ok($zip->set_number('8692301')->is_valid_number, '熊本県阿蘇市内牧');
ok($zip->set_number('8692302')->is_valid_number, '熊本県阿蘇市三久保');
ok($zip->set_number('8692303')->is_valid_number, '熊本県阿蘇市西小園');
ok($zip->set_number('8692304')->is_valid_number, '熊本県阿蘇市西湯浦');
ok($zip->set_number('8692305')->is_valid_number, '熊本県阿蘇市湯浦');
ok($zip->set_number('8692306')->is_valid_number, '熊本県阿蘇市南宮原');
ok($zip->set_number('8692307')->is_valid_number, '熊本県阿蘇市小里');
ok($zip->set_number('8692311')->is_valid_number, '熊本県阿蘇市小池');
ok($zip->set_number('8692312')->is_valid_number, '熊本県阿蘇市小倉');
ok($zip->set_number('8692313')->is_valid_number, '熊本県阿蘇市山田(その他)');
ok($zip->set_number('8692314')->is_valid_number, '熊本県阿蘇市小野田');
ok($zip->set_number('8692315')->is_valid_number, '熊本県阿蘇市今町');
ok($zip->set_number('8692316')->is_valid_number, '熊本県阿蘇市黒流町');
ok($zip->set_number('8692400')->is_valid_number, '熊本県阿蘇郡南小国町以下に掲載がない場合');
ok($zip->set_number('8692401')->is_valid_number, '熊本県阿蘇郡南小国町赤馬場');
ok($zip->set_number('8692402')->is_valid_number, '熊本県阿蘇郡南小国町満願寺');
ok($zip->set_number('8692403')->is_valid_number, '熊本県阿蘇郡南小国町中原');
ok($zip->set_number('8692413')->is_valid_number, '熊本県阿蘇市山田(蔵床、橋台、茗ケ原)');
ok($zip->set_number('8692500')->is_valid_number, '熊本県阿蘇郡小国町以下に掲載がない場合');
ok($zip->set_number('8692501')->is_valid_number, '熊本県阿蘇郡小国町宮原');
ok($zip->set_number('8692502')->is_valid_number, '熊本県阿蘇郡小国町黒渕');
ok($zip->set_number('8692503')->is_valid_number, '熊本県阿蘇郡小国町下城');
ok($zip->set_number('8692504')->is_valid_number, '熊本県阿蘇郡小国町西里');
ok($zip->set_number('8692505')->is_valid_number, '熊本県阿蘇郡小国町北里');
ok($zip->set_number('8692506')->is_valid_number, '熊本県阿蘇郡小国町上田');
ok($zip->set_number('8692600')->is_valid_number, '熊本県阿蘇市以下に掲載がない場合');
ok($zip->set_number('8692601')->is_valid_number, '熊本県阿蘇市一の宮町手野');
ok($zip->set_number('8692602')->is_valid_number, '熊本県阿蘇市一の宮町三野');
ok($zip->set_number('8692603')->is_valid_number, '熊本県阿蘇市一の宮町北坂梨');
ok($zip->set_number('8692604')->is_valid_number, '熊本県阿蘇市一の宮町中坂梨');
ok($zip->set_number('8692611')->is_valid_number, '熊本県阿蘇市一の宮町坂梨');
ok($zip->set_number('8692612')->is_valid_number, '熊本県阿蘇市一の宮町宮地');
ok($zip->set_number('8692613')->is_valid_number, '熊本県阿蘇市一の宮町中通');
ok($zip->set_number('8692621')->is_valid_number, '熊本県阿蘇市一の宮町荻の草');
ok($zip->set_number('8692700')->is_valid_number, '熊本県阿蘇郡産山村以下に掲載がない場合');
ok($zip->set_number('8692701')->is_valid_number, '熊本県阿蘇郡産山村片俣');
ok($zip->set_number('8692702')->is_valid_number, '熊本県阿蘇郡産山村大利');
ok($zip->set_number('8692703')->is_valid_number, '熊本県阿蘇郡産山村山鹿');
ok($zip->set_number('8692704')->is_valid_number, '熊本県阿蘇郡産山村田尻');
ok($zip->set_number('8692705')->is_valid_number, '熊本県阿蘇郡産山村産山');
ok($zip->set_number('8692801')->is_valid_number, '熊本県阿蘇市波野小地野');
ok($zip->set_number('8692802')->is_valid_number, '熊本県阿蘇市波野小園');
ok($zip->set_number('8692803')->is_valid_number, '熊本県阿蘇市波野赤仁田');
ok($zip->set_number('8692804')->is_valid_number, '熊本県阿蘇市波野滝水');
ok($zip->set_number('8692805')->is_valid_number, '熊本県阿蘇市波野中江');
ok($zip->set_number('8692806')->is_valid_number, '熊本県阿蘇市波野波野');
ok($zip->set_number('8692807')->is_valid_number, '熊本県阿蘇市波野新波野');
ok($zip->set_number('8693171')->is_valid_number, '熊本県宇土市長浜町');
ok($zip->set_number('8693172')->is_valid_number, '熊本県宇土市上網田町');
ok($zip->set_number('8693173')->is_valid_number, '熊本県宇土市下網田町');
ok($zip->set_number('8693174')->is_valid_number, '熊本県宇土市戸口町');
ok($zip->set_number('8693175')->is_valid_number, '熊本県宇土市赤瀬町');
ok($zip->set_number('8693201')->is_valid_number, '熊本県宇城市三角町大田尾');
ok($zip->set_number('8693202')->is_valid_number, '熊本県宇城市三角町郡浦');
ok($zip->set_number('8693203')->is_valid_number, '熊本県宇城市三角町戸馳');
ok($zip->set_number('8693204')->is_valid_number, '熊本県宇城市三角町中村');
ok($zip->set_number('8693205')->is_valid_number, '熊本県宇城市三角町波多');
ok($zip->set_number('8693206')->is_valid_number, '熊本県宇城市三角町前越');
ok($zip->set_number('8693207')->is_valid_number, '熊本県宇城市三角町三角浦');
ok($zip->set_number('8693211')->is_valid_number, '熊本県宇城市三角町大口');
ok($zip->set_number('8693212')->is_valid_number, '熊本県宇城市三角町手場');
ok($zip->set_number('8693213')->is_valid_number, '熊本県宇城市三角町里浦');
ok($zip->set_number('8693471')->is_valid_number, '熊本県宇城市不知火町永尾');
ok($zip->set_number('8693472')->is_valid_number, '熊本県宇城市不知火町松合');
ok($zip->set_number('8693473')->is_valid_number, '熊本県宇城市不知火町大見');
ok($zip->set_number('8693600')->is_valid_number, '熊本県上天草市以下に掲載がない場合');
ok($zip->set_number('8693601')->is_valid_number, '熊本県上天草市大矢野町登立');
ok($zip->set_number('8693602')->is_valid_number, '熊本県上天草市大矢野町上');
ok($zip->set_number('8693603')->is_valid_number, '熊本県上天草市大矢野町中');
ok($zip->set_number('8693604')->is_valid_number, '熊本県上天草市大矢野町維和');
ok($zip->set_number('8693711')->is_valid_number, '熊本県上天草市大矢野町湯島');
ok($zip->set_number('8694201')->is_valid_number, '熊本県八代市鏡町鏡村');
ok($zip->set_number('8694202')->is_valid_number, '熊本県八代市鏡町内田');
ok($zip->set_number('8694203')->is_valid_number, '熊本県八代市鏡町鏡');
ok($zip->set_number('8694204')->is_valid_number, '熊本県八代市鏡町芝口');
ok($zip->set_number('8694205')->is_valid_number, '熊本県八代市鏡町野崎');
ok($zip->set_number('8694211')->is_valid_number, '熊本県八代市鏡町上鏡');
ok($zip->set_number('8694212')->is_valid_number, '熊本県八代市鏡町下有佐');
ok($zip->set_number('8694213')->is_valid_number, '熊本県八代市鏡町有佐');
ok($zip->set_number('8694214')->is_valid_number, '熊本県八代市鏡町中島');
ok($zip->set_number('8694215')->is_valid_number, '熊本県八代市鏡町下村');
ok($zip->set_number('8694221')->is_valid_number, '熊本県八代市鏡町宝出');
ok($zip->set_number('8694222')->is_valid_number, '熊本県八代市鏡町両出');
ok($zip->set_number('8694223')->is_valid_number, '熊本県八代市鏡町貝洲');
ok($zip->set_number('8694224')->is_valid_number, '熊本県八代市鏡町塩浜');
ok($zip->set_number('8694225')->is_valid_number, '熊本県八代市鏡町北新地');
ok($zip->set_number('8694301')->is_valid_number, '熊本県八代市東陽町南');
ok($zip->set_number('8694302')->is_valid_number, '熊本県八代市東陽町北');
ok($zip->set_number('8694303')->is_valid_number, '熊本県八代市東陽町河俣');
ok($zip->set_number('8694304')->is_valid_number, '熊本県八代市東陽町小浦');
ok($zip->set_number('8694401')->is_valid_number, '熊本県八代市泉町柿迫(その他)');
ok($zip->set_number('8694402')->is_valid_number, '熊本県八代市泉町栗木');
ok($zip->set_number('8694403')->is_valid_number, '熊本県八代市泉町下岳');
ok($zip->set_number('8694501')->is_valid_number, '熊本県八代市泉町柿迫(8628番地)');
ok($zip->set_number('8694511')->is_valid_number, '熊本県八代市泉町葉木');
ok($zip->set_number('8694512')->is_valid_number, '熊本県八代市泉町樅木');
ok($zip->set_number('8694513')->is_valid_number, '熊本県八代市泉町久連子');
ok($zip->set_number('8694514')->is_valid_number, '熊本県八代市泉町椎原');
ok($zip->set_number('8694515')->is_valid_number, '熊本県八代市泉町仁田尾');
ok($zip->set_number('8694600')->is_valid_number, '熊本県八代郡氷川町以下に掲載がない場合');
ok($zip->set_number('8694601')->is_valid_number, '熊本県八代郡氷川町今');
ok($zip->set_number('8694602')->is_valid_number, '熊本県八代郡氷川町宮原');
ok($zip->set_number('8694603')->is_valid_number, '熊本県八代郡氷川町立神');
ok($zip->set_number('8694604')->is_valid_number, '熊本県八代郡氷川町有佐');
ok($zip->set_number('8694605')->is_valid_number, '熊本県八代郡氷川町中島');
ok($zip->set_number('8694606')->is_valid_number, '熊本県八代郡氷川町早尾');
ok($zip->set_number('8694607')->is_valid_number, '熊本県八代郡氷川町栫');
ok($zip->set_number('8694608')->is_valid_number, '熊本県八代郡氷川町宮原栄久');
ok($zip->set_number('8694611')->is_valid_number, '熊本県八代市岡町小路');
ok($zip->set_number('8694612')->is_valid_number, '熊本県八代市岡町中');
ok($zip->set_number('8694613')->is_valid_number, '熊本県八代市岡町谷川');
ok($zip->set_number('8694614')->is_valid_number, '熊本県八代市興善寺町');
ok($zip->set_number('8694615')->is_valid_number, '熊本県八代市川田町東');
ok($zip->set_number('8694616')->is_valid_number, '熊本県八代市川田町西');
ok($zip->set_number('8694701')->is_valid_number, '熊本県八代市千丁町太牟田');
ok($zip->set_number('8694702')->is_valid_number, '熊本県八代市千丁町吉王丸');
ok($zip->set_number('8694703')->is_valid_number, '熊本県八代市千丁町新牟田');
ok($zip->set_number('8694704')->is_valid_number, '熊本県八代市千丁町古閑出');
ok($zip->set_number('8694721')->is_valid_number, '熊本県八代市昭和日進町');
ok($zip->set_number('8694722')->is_valid_number, '熊本県八代市昭和明徴町');
ok($zip->set_number('8694723')->is_valid_number, '熊本県八代市昭和同仁町');
ok($zip->set_number('8694801')->is_valid_number, '熊本県八代郡氷川町新田');
ok($zip->set_number('8694802')->is_valid_number, '熊本県八代郡氷川町高塚');
ok($zip->set_number('8694803')->is_valid_number, '熊本県八代郡氷川町吉本');
ok($zip->set_number('8694804')->is_valid_number, '熊本県八代郡氷川町大野');
ok($zip->set_number('8694805')->is_valid_number, '熊本県八代郡氷川町野津');
ok($zip->set_number('8694806')->is_valid_number, '熊本県八代郡氷川町河原');
ok($zip->set_number('8694811')->is_valid_number, '熊本県八代郡氷川町鹿野');
ok($zip->set_number('8694812')->is_valid_number, '熊本県八代郡氷川町網道');
ok($zip->set_number('8694813')->is_valid_number, '熊本県八代郡氷川町若洲');
ok($zip->set_number('8694814')->is_valid_number, '熊本県八代郡氷川町島地');
ok($zip->set_number('8694815')->is_valid_number, '熊本県八代郡氷川町鹿島');
ok($zip->set_number('8695131')->is_valid_number, '熊本県八代市日奈久馬越町');
ok($zip->set_number('8695132')->is_valid_number, '熊本県八代市日奈久下西町');
ok($zip->set_number('8695133')->is_valid_number, '熊本県八代市日奈久中西町');
ok($zip->set_number('8695134')->is_valid_number, '熊本県八代市日奈久上西町');
ok($zip->set_number('8695135')->is_valid_number, '熊本県八代市日奈久中町');
ok($zip->set_number('8695136')->is_valid_number, '熊本県八代市日奈久東町');
ok($zip->set_number('8695137')->is_valid_number, '熊本県八代市日奈久浜町');
ok($zip->set_number('8695138')->is_valid_number, '熊本県八代市日奈久平成町');
ok($zip->set_number('8695141')->is_valid_number, '熊本県八代市日奈久塩南町');
ok($zip->set_number('8695142')->is_valid_number, '熊本県八代市日奈久塩北町');
ok($zip->set_number('8695143')->is_valid_number, '熊本県八代市日奈久竹之内町');
ok($zip->set_number('8695144')->is_valid_number, '熊本県八代市日奈久山下町');
ok($zip->set_number('8695145')->is_valid_number, '熊本県八代市日奈久新田町');
ok($zip->set_number('8695146')->is_valid_number, '熊本県八代市日奈久大坪町');
ok($zip->set_number('8695147')->is_valid_number, '熊本県八代市日奈久新開町');
ok($zip->set_number('8695148')->is_valid_number, '熊本県八代市日奈久栄町');
ok($zip->set_number('8695151')->is_valid_number, '熊本県八代市敷川内町');
ok($zip->set_number('8695152')->is_valid_number, '熊本県八代市揚町');
ok($zip->set_number('8695153')->is_valid_number, '熊本県八代市催合町');
ok($zip->set_number('8695154')->is_valid_number, '熊本県八代市高植本町');
ok($zip->set_number('8695155')->is_valid_number, '熊本県八代市水島町');
ok($zip->set_number('8695161')->is_valid_number, '熊本県八代市葭牟田町');
ok($zip->set_number('8695162')->is_valid_number, '熊本県八代市北原町');
ok($zip->set_number('8695163')->is_valid_number, '熊本県八代市三江湖町');
ok($zip->set_number('8695164')->is_valid_number, '熊本県八代市鼠蔵町');
ok($zip->set_number('8695165')->is_valid_number, '熊本県八代市南平和町');
ok($zip->set_number('8695166')->is_valid_number, '熊本県八代市北平和町');
ok($zip->set_number('8695171')->is_valid_number, '熊本県八代市二見洲口町');
ok($zip->set_number('8695172')->is_valid_number, '熊本県八代市二見本町');
ok($zip->set_number('8695173')->is_valid_number, '熊本県八代市二見赤松町');
ok($zip->set_number('8695174')->is_valid_number, '熊本県八代市二見下大野町');
ok($zip->set_number('8695175')->is_valid_number, '熊本県八代市二見野田崎町');
ok($zip->set_number('8695221')->is_valid_number, '熊本県八代市坂本町川嶽');
ok($zip->set_number('8695222')->is_valid_number, '熊本県八代市坂本町鶴喰');
ok($zip->set_number('8695223')->is_valid_number, '熊本県八代市坂本町田上');
ok($zip->set_number('8695224')->is_valid_number, '熊本県八代市坂本町百済来下');
ok($zip->set_number('8695225')->is_valid_number, '熊本県八代市坂本町百済来上');
ok($zip->set_number('8695301')->is_valid_number, '熊本県葦北郡芦北町横居木');
ok($zip->set_number('8695302')->is_valid_number, '熊本県葦北郡芦北町田浦');
ok($zip->set_number('8695303')->is_valid_number, '熊本県葦北郡芦北町小田浦');
ok($zip->set_number('8695304')->is_valid_number, '熊本県葦北郡芦北町海浦');
ok($zip->set_number('8695305')->is_valid_number, '熊本県葦北郡芦北町田浦町');
ok($zip->set_number('8695306')->is_valid_number, '熊本県葦北郡芦北町波多島');
ok($zip->set_number('8695307')->is_valid_number, '熊本県葦北郡芦北町井牟田');
ok($zip->set_number('8695400')->is_valid_number, '熊本県葦北郡芦北町以下に掲載がない場合');
ok($zip->set_number('8695421')->is_valid_number, '熊本県葦北郡芦北町立川');
ok($zip->set_number('8695422')->is_valid_number, '熊本県葦北郡芦北町大尼田');
ok($zip->set_number('8695423')->is_valid_number, '熊本県葦北郡芦北町松生');
ok($zip->set_number('8695424')->is_valid_number, '熊本県葦北郡芦北町伏木氏');
ok($zip->set_number('8695431')->is_valid_number, '熊本県葦北郡芦北町乙千屋');
ok($zip->set_number('8695432')->is_valid_number, '熊本県葦北郡芦北町宮浦');
ok($zip->set_number('8695433')->is_valid_number, '熊本県葦北郡芦北町八幡');
ok($zip->set_number('8695434')->is_valid_number, '熊本県葦北郡芦北町桑原');
ok($zip->set_number('8695441')->is_valid_number, '熊本県葦北郡芦北町佐敷');
ok($zip->set_number('8695442')->is_valid_number, '熊本県葦北郡芦北町花岡');
ok($zip->set_number('8695443')->is_valid_number, '熊本県葦北郡芦北町田川');
ok($zip->set_number('8695451')->is_valid_number, '熊本県葦北郡芦北町道川内');
ok($zip->set_number('8695452')->is_valid_number, '熊本県葦北郡芦北町白岩');
ok($zip->set_number('8695453')->is_valid_number, '熊本県葦北郡芦北町計石');
ok($zip->set_number('8695454')->is_valid_number, '熊本県葦北郡芦北町鶴木山');
ok($zip->set_number('8695461')->is_valid_number, '熊本県葦北郡芦北町芦北(その他)');
ok($zip->set_number('8695561')->is_valid_number, '熊本県葦北郡芦北町芦北(北田、中割、西割、松崎)');
ok($zip->set_number('8695562')->is_valid_number, '熊本県葦北郡芦北町宮崎');
ok($zip->set_number('8695563')->is_valid_number, '熊本県葦北郡芦北町湯浦');
ok($zip->set_number('8695564')->is_valid_number, '熊本県葦北郡芦北町女島');
ok($zip->set_number('8695571')->is_valid_number, '熊本県葦北郡芦北町豊岡');
ok($zip->set_number('8695572')->is_valid_number, '熊本県葦北郡芦北町丸山');
ok($zip->set_number('8695573')->is_valid_number, '熊本県葦北郡芦北町米田');
ok($zip->set_number('8695574')->is_valid_number, '熊本県葦北郡芦北町大川内');
ok($zip->set_number('8695575')->is_valid_number, '熊本県葦北郡芦北町古石');
ok($zip->set_number('8695576')->is_valid_number, '熊本県葦北郡芦北町高岡');
ok($zip->set_number('8695600')->is_valid_number, '熊本県葦北郡津奈木町以下に掲載がない場合');
ok($zip->set_number('8695601')->is_valid_number, '熊本県葦北郡津奈木町千代');
ok($zip->set_number('8695602')->is_valid_number, '熊本県葦北郡津奈木町津奈木');
ok($zip->set_number('8695603')->is_valid_number, '熊本県葦北郡津奈木町岩城');
ok($zip->set_number('8695604')->is_valid_number, '熊本県葦北郡津奈木町小津奈木');
ok($zip->set_number('8695605')->is_valid_number, '熊本県葦北郡津奈木町福浜');
ok($zip->set_number('8696101')->is_valid_number, '熊本県八代市坂本町西部');
ok($zip->set_number('8696102')->is_valid_number, '熊本県八代市坂本町深水');
ok($zip->set_number('8696103')->is_valid_number, '熊本県八代市坂本町中谷');
ok($zip->set_number('8696104')->is_valid_number, '熊本県八代市坂本町鮎帰');
ok($zip->set_number('8696105')->is_valid_number, '熊本県八代市坂本町坂本');
ok($zip->set_number('8696111')->is_valid_number, '熊本県八代市坂本町葉木');
ok($zip->set_number('8696112')->is_valid_number, '熊本県八代市坂本町鎌瀬');
ok($zip->set_number('8696113')->is_valid_number, '熊本県八代市坂本町中津道');
ok($zip->set_number('8696114')->is_valid_number, '熊本県八代市坂本町市ノ俣');
ok($zip->set_number('8696115')->is_valid_number, '熊本県八代市坂本町荒瀬');
ok($zip->set_number('8696211')->is_valid_number, '熊本県葦北郡芦北町箙瀬');
ok($zip->set_number('8696212')->is_valid_number, '熊本県葦北郡芦北町吉尾');
ok($zip->set_number('8696213')->is_valid_number, '熊本県葦北郡芦北町大岩');
ok($zip->set_number('8696214')->is_valid_number, '熊本県葦北郡芦北町黒岩');
ok($zip->set_number('8696215')->is_valid_number, '熊本県葦北郡芦北町上原');
ok($zip->set_number('8696216')->is_valid_number, '熊本県葦北郡芦北町海路');
ok($zip->set_number('8696301')->is_valid_number, '熊本県葦北郡芦北町天月');
ok($zip->set_number('8696302')->is_valid_number, '熊本県葦北郡芦北町白石');
ok($zip->set_number('8696303')->is_valid_number, '熊本県葦北郡芦北町告');
ok($zip->set_number('8696304')->is_valid_number, '熊本県葦北郡芦北町国見');
ok($zip->set_number('8696305')->is_valid_number, '熊本県葦北郡芦北町大野');
ok($zip->set_number('8696306')->is_valid_number, '熊本県葦北郡芦北町市野瀬');
ok($zip->set_number('8696307')->is_valid_number, '熊本県葦北郡芦北町塩浸');
ok($zip->set_number('8696308')->is_valid_number, '熊本県葦北郡芦北町白木');
ok($zip->set_number('8696400')->is_valid_number, '熊本県球磨郡球磨村以下に掲載がない場合');
ok($zip->set_number('8696401')->is_valid_number, '熊本県球磨郡球磨村渡');
ok($zip->set_number('8696402')->is_valid_number, '熊本県球磨郡球磨村三ケ浦');
ok($zip->set_number('8696403')->is_valid_number, '熊本県球磨郡球磨村一勝地');
ok($zip->set_number('8696404')->is_valid_number, '熊本県球磨郡球磨村神瀬');
ok($zip->set_number('8696405')->is_valid_number, '熊本県球磨郡球磨村大瀬');
ok($zip->set_number('8700001')->is_valid_number, '大分県大分市生石港町');
ok($zip->set_number('8700002')->is_valid_number, '大分県大分市浜の市');
ok($zip->set_number('8700003')->is_valid_number, '大分県大分市生石');
ok($zip->set_number('8700004')->is_valid_number, '大分県大分市王子港町');
ok($zip->set_number('8700005')->is_valid_number, '大分県大分市王子北町');
ok($zip->set_number('8700006')->is_valid_number, '大分県大分市王子中町');
ok($zip->set_number('8700007')->is_valid_number, '大分県大分市王子南町');
ok($zip->set_number('8700008')->is_valid_number, '大分県大分市王子西町');
ok($zip->set_number('8700009')->is_valid_number, '大分県大分市王子町');
ok($zip->set_number('8700011')->is_valid_number, '大分県大分市春日浦');
ok($zip->set_number('8700012')->is_valid_number, '大分県大分市浜町北');
ok($zip->set_number('8700013')->is_valid_number, '大分県大分市浜町東');
ok($zip->set_number('8700014')->is_valid_number, '大分県大分市芦崎');
ok($zip->set_number('8700015')->is_valid_number, '大分県大分市新川西');
ok($zip->set_number('8700016')->is_valid_number, '大分県大分市新川町');
ok($zip->set_number('8700017')->is_valid_number, '大分県大分市弁天');
ok($zip->set_number('8700018')->is_valid_number, '大分県大分市豊海');
ok($zip->set_number('8700021')->is_valid_number, '大分県大分市府内町');
ok($zip->set_number('8700022')->is_valid_number, '大分県大分市大手町');
ok($zip->set_number('8700023')->is_valid_number, '大分県大分市長浜町');
ok($zip->set_number('8700024')->is_valid_number, '大分県大分市錦町');
ok($zip->set_number('8700025')->is_valid_number, '大分県大分市顕徳町');
ok($zip->set_number('8700026')->is_valid_number, '大分県大分市金池町');
ok($zip->set_number('8700027')->is_valid_number, '大分県大分市末広町');
ok($zip->set_number('8700028')->is_valid_number, '大分県大分市新町');
ok($zip->set_number('8700029')->is_valid_number, '大分県大分市高砂町');
ok($zip->set_number('8700030')->is_valid_number, '大分県大分市三芳');
ok($zip->set_number('8700031')->is_valid_number, '大分県大分市勢家町');
ok($zip->set_number('8700032')->is_valid_number, '大分県大分市住吉町');
ok($zip->set_number('8700033')->is_valid_number, '大分県大分市千代町');
ok($zip->set_number('8700034')->is_valid_number, '大分県大分市都町');
ok($zip->set_number('8700035')->is_valid_number, '大分県大分市中央町');
ok($zip->set_number('8700036')->is_valid_number, '大分県大分市寿町');
ok($zip->set_number('8700037')->is_valid_number, '大分県大分市東春日町');
ok($zip->set_number('8700038')->is_valid_number, '大分県大分市西春日町');
ok($zip->set_number('8700039')->is_valid_number, '大分県大分市中春日町');
ok($zip->set_number('8700041')->is_valid_number, '大分県大分市泉町');
ok($zip->set_number('8700042')->is_valid_number, '大分県大分市豊町');
ok($zip->set_number('8700043')->is_valid_number, '大分県大分市中島東');
ok($zip->set_number('8700044')->is_valid_number, '大分県大分市舞鶴町');
ok($zip->set_number('8700045')->is_valid_number, '大分県大分市城崎町');
ok($zip->set_number('8700046')->is_valid_number, '大分県大分市荷揚町');
ok($zip->set_number('8700047')->is_valid_number, '大分県大分市中島西');
ok($zip->set_number('8700048')->is_valid_number, '大分県大分市碩田町');
ok($zip->set_number('8700049')->is_valid_number, '大分県大分市中島中央');
ok($zip->set_number('8700100')->is_valid_number, '大分県大分市以下に掲載がない場合');
ok($zip->set_number('8700101')->is_valid_number, '大分県大分市中鶴崎');
ok($zip->set_number('8700102')->is_valid_number, '大分県大分市北鶴崎');
ok($zip->set_number('8700103')->is_valid_number, '大分県大分市東鶴崎');
ok($zip->set_number('8700104')->is_valid_number, '大分県大分市南鶴崎');
ok($zip->set_number('8700105')->is_valid_number, '大分県大分市西鶴崎');
ok($zip->set_number('8700106')->is_valid_number, '大分県大分市鶴崎');
ok($zip->set_number('8700107')->is_valid_number, '大分県大分市海原');
ok($zip->set_number('8700108')->is_valid_number, '大分県大分市三佐');
ok($zip->set_number('8700109')->is_valid_number, '大分県大分市徳島');
ok($zip->set_number('8700111')->is_valid_number, '大分県大分市中ノ洲');
ok($zip->set_number('8700112')->is_valid_number, '大分県大分市一の洲');
ok($zip->set_number('8700113')->is_valid_number, '大分県大分市家島');
ok($zip->set_number('8700114')->is_valid_number, '大分県大分市小中島');
ok($zip->set_number('8700115')->is_valid_number, '大分県大分市関園');
ok($zip->set_number('8700116')->is_valid_number, '大分県大分市常行');
ok($zip->set_number('8700117')->is_valid_number, '大分県大分市南');
ok($zip->set_number('8700118')->is_valid_number, '大分県大分市下徳丸');
ok($zip->set_number('8700120')->is_valid_number, '大分県大分市鶴崎コスモス団地');
ok($zip->set_number('8700121')->is_valid_number, '大分県大分市鶴瀬');
ok($zip->set_number('8700122')->is_valid_number, '大分県大分市丸亀');
ok($zip->set_number('8700123')->is_valid_number, '大分県大分市大津留');
ok($zip->set_number('8700124')->is_valid_number, '大分県大分市毛井');
ok($zip->set_number('8700125')->is_valid_number, '大分県大分市松岡');
ok($zip->set_number('8700126')->is_valid_number, '大分県大分市横尾');
ok($zip->set_number('8700127')->is_valid_number, '大分県大分市森町');
ok($zip->set_number('8700128')->is_valid_number, '大分県大分市森');
ok($zip->set_number('8700129')->is_valid_number, '大分県大分市京が丘南');
ok($zip->set_number('8700130')->is_valid_number, '大分県大分市横尾東町');
ok($zip->set_number('8700131')->is_valid_number, '大分県大分市皆春');
ok($zip->set_number('8700132')->is_valid_number, '大分県大分市千歳');
ok($zip->set_number('8700133')->is_valid_number, '大分県大分市葛木');
ok($zip->set_number('8700134')->is_valid_number, '大分県大分市猪野');
ok($zip->set_number('8700135')->is_valid_number, '大分県大分市仲西町');
ok($zip->set_number('8700136')->is_valid_number, '大分県大分市山津町');
ok($zip->set_number('8700137')->is_valid_number, '大分県大分市寺崎町');
ok($zip->set_number('8700138')->is_valid_number, '大分県大分市原川');
ok($zip->set_number('8700139')->is_valid_number, '大分県大分市桃園団地');
ok($zip->set_number('8700140')->is_valid_number, '大分県大分市森町西');
ok($zip->set_number('8700141')->is_valid_number, '大分県大分市三川新町');
ok($zip->set_number('8700142')->is_valid_number, '大分県大分市三川下');
ok($zip->set_number('8700143')->is_valid_number, '大分県大分市三川上');
ok($zip->set_number('8700144')->is_valid_number, '大分県大分市乙津');
ok($zip->set_number('8700145')->is_valid_number, '大分県大分市乙津町');
ok($zip->set_number('8700146')->is_valid_number, '大分県大分市乙津港町');
ok($zip->set_number('8700147')->is_valid_number, '大分県大分市小池原');
ok($zip->set_number('8700148')->is_valid_number, '大分県大分市高城台');
ok($zip->set_number('8700149')->is_valid_number, '大分県大分市高城団地');
ok($zip->set_number('8700150')->is_valid_number, '大分県大分市東原');
ok($zip->set_number('8700151')->is_valid_number, '大分県大分市東明野');
ok($zip->set_number('8700152')->is_valid_number, '大分県大分市牧(その他)');
ok($zip->set_number('8700153')->is_valid_number, '大分県大分市城東町(その他)');
ok($zip->set_number('8700154')->is_valid_number, '大分県大分市高城西町(その他)');
ok($zip->set_number('8700155')->is_valid_number, '大分県大分市高城南町');
ok($zip->set_number('8700156')->is_valid_number, '大分県大分市高城新町');
ok($zip->set_number('8700157')->is_valid_number, '大分県大分市高城本町');
ok($zip->set_number('8700158')->is_valid_number, '大分県大分市岡');
ok($zip->set_number('8700159')->is_valid_number, '大分県大分市岡新町');
ok($zip->set_number('8700161')->is_valid_number, '大分県大分市明野東');
ok($zip->set_number('8700162')->is_valid_number, '大分県大分市明野高尾');
ok($zip->set_number('8700163')->is_valid_number, '大分県大分市明野南');
ok($zip->set_number('8700164')->is_valid_number, '大分県大分市明野西');
ok($zip->set_number('8700165')->is_valid_number, '大分県大分市明野北');
ok($zip->set_number('8700166')->is_valid_number, '大分県大分市明野北町');
ok($zip->set_number('8700167')->is_valid_number, '大分県大分市明野紅陽台');
ok($zip->set_number('8700168')->is_valid_number, '大分県大分市明野ハイツ');
ok($zip->set_number('8700171')->is_valid_number, '大分県大分市法勝台');
ok($zip->set_number('8700172')->is_valid_number, '大分県大分市新明治');
ok($zip->set_number('8700173')->is_valid_number, '大分県大分市公園通り');
ok($zip->set_number('8700174')->is_valid_number, '大分県大分市公園通り西');
ok($zip->set_number('8700241')->is_valid_number, '大分県大分市庄境');
ok($zip->set_number('8700242')->is_valid_number, '大分県大分市角子南');
ok($zip->set_number('8700243')->is_valid_number, '大分県大分市花江川');
ok($zip->set_number('8700244')->is_valid_number, '大分県大分市須賀');
ok($zip->set_number('8700245')->is_valid_number, '大分県大分市大在北');
ok($zip->set_number('8700251')->is_valid_number, '大分県大分市大在中央');
ok($zip->set_number('8700252')->is_valid_number, '大分県大分市大在浜');
ok($zip->set_number('8700253')->is_valid_number, '大分県大分市汐見');
ok($zip->set_number('8700254')->is_valid_number, '大分県大分市横塚');
ok($zip->set_number('8700261')->is_valid_number, '大分県大分市志村');
ok($zip->set_number('8700263')->is_valid_number, '大分県大分市横田');
ok($zip->set_number('8700265')->is_valid_number, '大分県大分市竹下');
ok($zip->set_number('8700266')->is_valid_number, '大分県大分市大在');
ok($zip->set_number('8700267')->is_valid_number, '大分県大分市城原');
ok($zip->set_number('8700268')->is_valid_number, '大分県大分市政所');
ok($zip->set_number('8700270')->is_valid_number, '大分県大分市望みが丘');
ok($zip->set_number('8700271')->is_valid_number, '大分県大分市角子原');
ok($zip->set_number('8700272')->is_valid_number, '大分県大分市迫');
ok($zip->set_number('8700273')->is_valid_number, '大分県大分市曙台');
ok($zip->set_number('8700274')->is_valid_number, '大分県大分市種具');
ok($zip->set_number('8700275')->is_valid_number, '大分県大分市宮河内ハイランド');
ok($zip->set_number('8700276')->is_valid_number, '大分県大分市宮河内');
ok($zip->set_number('8700277')->is_valid_number, '大分県大分市広内');
ok($zip->set_number('8700278')->is_valid_number, '大分県大分市青崎');
ok($zip->set_number('8700279')->is_valid_number, '大分県大分市つるさき陽光台');
ok($zip->set_number('8700301')->is_valid_number, '大分県大分市日吉原');
ok($zip->set_number('8700302')->is_valid_number, '大分県大分市坂ノ市');
ok($zip->set_number('8700303')->is_valid_number, '大分県大分市里');
ok($zip->set_number('8700304')->is_valid_number, '大分県大分市久原');
ok($zip->set_number('8700305')->is_valid_number, '大分県大分市細');
ok($zip->set_number('8700306')->is_valid_number, '大分県大分市東上野');
ok($zip->set_number('8700307')->is_valid_number, '大分県大分市坂ノ市中央');
ok($zip->set_number('8700308')->is_valid_number, '大分県大分市坂ノ市南');
ok($zip->set_number('8700309')->is_valid_number, '大分県大分市坂ノ市西');
ok($zip->set_number('8700311')->is_valid_number, '大分県大分市木田');
ok($zip->set_number('8700312')->is_valid_number, '大分県大分市市尾');
ok($zip->set_number('8700313')->is_valid_number, '大分県大分市屋山');
ok($zip->set_number('8700314')->is_valid_number, '大分県大分市久土');
ok($zip->set_number('8700315')->is_valid_number, '大分県大分市佐野');
ok($zip->set_number('8700316')->is_valid_number, '大分県大分市一木');
ok($zip->set_number('8700317')->is_valid_number, '大分県大分市丹川');
ok($zip->set_number('8700318')->is_valid_number, '大分県大分市丹生');
ok($zip->set_number('8700319')->is_valid_number, '大分県大分市大分流通業務団地');
ok($zip->set_number('8700321')->is_valid_number, '大分県大分市王ノ瀬');
ok($zip->set_number('8700322')->is_valid_number, '大分県大分市恵比寿町');
ok($zip->set_number('8700323')->is_valid_number, '大分県大分市浜中');
ok($zip->set_number('8700324')->is_valid_number, '大分県大分市久原北');
ok($zip->set_number('8700325')->is_valid_number, '大分県大分市久原中央');
ok($zip->set_number('8700326')->is_valid_number, '大分県大分市久原南');
ok($zip->set_number('8700327')->is_valid_number, '大分県大分市小佐井');
ok($zip->set_number('8700801')->is_valid_number, '大分県大分市鳴川');
ok($zip->set_number('8700802')->is_valid_number, '大分県大分市田ノ浦');
ok($zip->set_number('8700803')->is_valid_number, '大分県大分市下白木');
ok($zip->set_number('8700804')->is_valid_number, '大分県大分市御幸町');
ok($zip->set_number('8700805')->is_valid_number, '大分県大分市上白木');
ok($zip->set_number('8700806')->is_valid_number, '大分県大分市大久保');
ok($zip->set_number('8700807')->is_valid_number, '大分県大分市下八幡');
ok($zip->set_number('8700808')->is_valid_number, '大分県大分市上八幡');
ok($zip->set_number('8700809')->is_valid_number, '大分県大分市机張原');
ok($zip->set_number('8700811')->is_valid_number, '大分県大分市南生石西');
ok($zip->set_number('8700812')->is_valid_number, '大分県大分市南生石東');
ok($zip->set_number('8700813')->is_valid_number, '大分県大分市王子山の手町');
ok($zip->set_number('8700815')->is_valid_number, '大分県大分市南春日町');
ok($zip->set_number('8700816')->is_valid_number, '大分県大分市田室町');
ok($zip->set_number('8700817')->is_valid_number, '大分県大分市上春日町');
ok($zip->set_number('8700818')->is_valid_number, '大分県大分市新春日町');
ok($zip->set_number('8700819')->is_valid_number, '大分県大分市王子新町');
ok($zip->set_number('8700820')->is_valid_number, '大分県大分市西大道');
ok($zip->set_number('8700821')->is_valid_number, '大分県大分市志手');
ok($zip->set_number('8700822')->is_valid_number, '大分県大分市大道町');
ok($zip->set_number('8700823')->is_valid_number, '大分県大分市東大道');
ok($zip->set_number('8700824')->is_valid_number, '大分県大分市城南東');
ok($zip->set_number('8700825')->is_valid_number, '大分県大分市城南南');
ok($zip->set_number('8700826')->is_valid_number, '大分県大分市城南西');
ok($zip->set_number('8700827')->is_valid_number, '大分県大分市城南北');
ok($zip->set_number('8700828')->is_valid_number, '大分県大分市城南山手台');
ok($zip->set_number('8700829')->is_valid_number, '大分県大分市椎迫');
ok($zip->set_number('8700831')->is_valid_number, '大分県大分市要町');
ok($zip->set_number('8700832')->is_valid_number, '大分県大分市上野町');
ok($zip->set_number('8700833')->is_valid_number, '大分県大分市上野丘東');
ok($zip->set_number('8700834')->is_valid_number, '大分県大分市上野丘西');
ok($zip->set_number('8700835')->is_valid_number, '大分県大分市上野丘');
ok($zip->set_number('8700836')->is_valid_number, '大分県大分市上野南');
ok($zip->set_number('8700837')->is_valid_number, '大分県大分市太平町');
ok($zip->set_number('8700838')->is_valid_number, '大分県大分市桜ケ丘');
ok($zip->set_number('8700839')->is_valid_number, '大分県大分市金池南');
ok($zip->set_number('8700841')->is_valid_number, '大分県大分市六坊北町');
ok($zip->set_number('8700842')->is_valid_number, '大分県大分市六坊南町');
ok($zip->set_number('8700843')->is_valid_number, '大分県大分市元町');
ok($zip->set_number('8700844')->is_valid_number, '大分県大分市古国府');
ok($zip->set_number('8700846')->is_valid_number, '大分県大分市花園');
ok($zip->set_number('8700847')->is_valid_number, '大分県大分市広瀬町');
ok($zip->set_number('8700848')->is_valid_number, '大分県大分市賀来北');
ok($zip->set_number('8700849')->is_valid_number, '大分県大分市賀来南');
ok($zip->set_number('8700850')->is_valid_number, '大分県大分市賀来西');
ok($zip->set_number('8700851')->is_valid_number, '大分県大分市大石町');
ok($zip->set_number('8700852')->is_valid_number, '大分県大分市田中町');
ok($zip->set_number('8700853')->is_valid_number, '大分県大分市羽屋新町');
ok($zip->set_number('8700854')->is_valid_number, '大分県大分市羽屋');
ok($zip->set_number('8700855')->is_valid_number, '大分県大分市豊饒');
ok($zip->set_number('8700856')->is_valid_number, '大分県大分市畑中');
ok($zip->set_number('8700857')->is_valid_number, '大分県大分市明磧');
ok($zip->set_number('8700858')->is_valid_number, '大分県大分市尼が瀬');
ok($zip->set_number('8700859')->is_valid_number, '大分県大分市中の瀬町');
ok($zip->set_number('8700860')->is_valid_number, '大分県大分市明磧町');
ok($zip->set_number('8700861')->is_valid_number, '大分県大分市東院');
ok($zip->set_number('8700862')->is_valid_number, '大分県大分市中尾');
ok($zip->set_number('8700863')->is_valid_number, '大分県大分市国分台');
ok($zip->set_number('8700864')->is_valid_number, '大分県大分市国分');
ok($zip->set_number('8700865')->is_valid_number, '大分県大分市国分団地');
ok($zip->set_number('8700866')->is_valid_number, '大分県大分市平横瀬');
ok($zip->set_number('8700867')->is_valid_number, '大分県大分市東野台');
ok($zip->set_number('8700868')->is_valid_number, '大分県大分市野田');
ok($zip->set_number('8700869')->is_valid_number, '大分県大分市国分新町');
ok($zip->set_number('8700870')->is_valid_number, '大分県大分市季の坂');
ok($zip->set_number('8700871')->is_valid_number, '大分県大分市東八幡');
ok($zip->set_number('8700872')->is_valid_number, '大分県大分市高崎');
ok($zip->set_number('8700873')->is_valid_number, '大分県大分市高尾台');
ok($zip->set_number('8700874')->is_valid_number, '大分県大分市にじが丘');
ok($zip->set_number('8700875')->is_valid_number, '大分県大分市青葉台');
ok($zip->set_number('8700876')->is_valid_number, '大分県大分市庄の原');
ok($zip->set_number('8700877')->is_valid_number, '大分県大分市賀来');
ok($zip->set_number('8700878')->is_valid_number, '大分県大分市宮苑');
ok($zip->set_number('8700879')->is_valid_number, '大分県大分市金谷迫');
ok($zip->set_number('8700880')->is_valid_number, '大分県大分市はなの森');
ok($zip->set_number('8700881')->is_valid_number, '大分県大分市深河内');
ok($zip->set_number('8700882')->is_valid_number, '大分県大分市竹の上');
ok($zip->set_number('8700883')->is_valid_number, '大分県大分市永興');
ok($zip->set_number('8700884')->is_valid_number, '大分県大分市旭町');
ok($zip->set_number('8700885')->is_valid_number, '大分県大分市南太平寺');
ok($zip->set_number('8700886')->is_valid_number, '大分県大分市上田町');
ok($zip->set_number('8700887')->is_valid_number, '大分県大分市二又町');
ok($zip->set_number('8700888')->is_valid_number, '大分県大分市三ケ田町');
ok($zip->set_number('8700889')->is_valid_number, '大分県大分市荏隈');
ok($zip->set_number('8700891')->is_valid_number, '大分県大分市荏隈町');
ok($zip->set_number('8700892')->is_valid_number, '大分県大分市賀来新川');
ok($zip->set_number('8700901')->is_valid_number, '大分県大分市西新地');
ok($zip->set_number('8700902')->is_valid_number, '大分県大分市西ノ洲');
ok($zip->set_number('8700903')->is_valid_number, '大分県大分市向原沖');
ok($zip->set_number('8700904')->is_valid_number, '大分県大分市向原東');
ok($zip->set_number('8700905')->is_valid_number, '大分県大分市向原西');
ok($zip->set_number('8700906')->is_valid_number, '大分県大分市大州浜');
ok($zip->set_number('8700907')->is_valid_number, '大分県大分市大津町');
ok($zip->set_number('8700908')->is_valid_number, '大分県大分市青葉町');
ok($zip->set_number('8700911')->is_valid_number, '大分県大分市新貝');
ok($zip->set_number('8700912')->is_valid_number, '大分県大分市原新町');
ok($zip->set_number('8700913')->is_valid_number, '大分県大分市松原町');
ok($zip->set_number('8700914')->is_valid_number, '大分県大分市日岡');
ok($zip->set_number('8700915')->is_valid_number, '大分県大分市花高松');
ok($zip->set_number('8700916')->is_valid_number, '大分県大分市高松東');
ok($zip->set_number('8700917')->is_valid_number, '大分県大分市高松');
ok($zip->set_number('8700918')->is_valid_number, '大分県大分市日吉町');
ok($zip->set_number('8700919')->is_valid_number, '大分県大分市新栄町');
ok($zip->set_number('8700921')->is_valid_number, '大分県大分市萩原');
ok($zip->set_number('8700922')->is_valid_number, '大分県大分市城東町(3の22、4の2、4の30)');
ok($zip->set_number('8700923')->is_valid_number, '大分県大分市高城西町(1~7番)');
ok($zip->set_number('8700924')->is_valid_number, '大分県大分市牧(1~3丁目、白滝B・C、高見)');
ok($zip->set_number('8700925')->is_valid_number, '大分県大分市牧上町');
ok($zip->set_number('8700926')->is_valid_number, '大分県大分市加納');
ok($zip->set_number('8700927')->is_valid_number, '大分県大分市北下郡');
ok($zip->set_number('8700928')->is_valid_number, '大分県大分市南下郡');
ok($zip->set_number('8700929')->is_valid_number, '大分県大分市長谷町');
ok($zip->set_number('8700930')->is_valid_number, '大分県大分市津留');
ok($zip->set_number('8700931')->is_valid_number, '大分県大分市西浜');
ok($zip->set_number('8700932')->is_valid_number, '大分県大分市東浜');
ok($zip->set_number('8700933')->is_valid_number, '大分県大分市花津留');
ok($zip->set_number('8700934')->is_valid_number, '大分県大分市東津留');
ok($zip->set_number('8700935')->is_valid_number, '大分県大分市古ケ鶴');
ok($zip->set_number('8700936')->is_valid_number, '大分県大分市岩田町');
ok($zip->set_number('8700937')->is_valid_number, '大分県大分市南津留');
ok($zip->set_number('8700938')->is_valid_number, '大分県大分市今津留');
ok($zip->set_number('8700939')->is_valid_number, '大分県大分市中津留');
ok($zip->set_number('8700941')->is_valid_number, '大分県大分市下郡工業団地');
ok($zip->set_number('8700942')->is_valid_number, '大分県大分市羽田');
ok($zip->set_number('8700943')->is_valid_number, '大分県大分市片島');
ok($zip->set_number('8700944')->is_valid_number, '大分県大分市米良');
ok($zip->set_number('8700945')->is_valid_number, '大分県大分市津守');
ok($zip->set_number('8700946')->is_valid_number, '大分県大分市曲(その他)');
ok($zip->set_number('8700947')->is_valid_number, '大分県大分市富岡');
ok($zip->set_number('8700948')->is_valid_number, '大分県大分市芳河原台');
ok($zip->set_number('8700949')->is_valid_number, '大分県大分市かたしま台');
ok($zip->set_number('8700951')->is_valid_number, '大分県大分市下郡');
ok($zip->set_number('8700952')->is_valid_number, '大分県大分市下郡北');
ok($zip->set_number('8700953')->is_valid_number, '大分県大分市下郡東');
ok($zip->set_number('8700954')->is_valid_number, '大分県大分市下郡中央');
ok($zip->set_number('8700955')->is_valid_number, '大分県大分市下郡南');
ok($zip->set_number('8700956')->is_valid_number, '大分県大分市裏川団地');
ok($zip->set_number('8700957')->is_valid_number, '大分県大分市藤の台');
ok($zip->set_number('8700958')->is_valid_number, '大分県大分市ゆめが丘');
ok($zip->set_number('8700959')->is_valid_number, '大分県大分市希望が丘');
ok($zip->set_number('8700961')->is_valid_number, '大分県大分市下郡山の手');
ok($zip->set_number('8701101')->is_valid_number, '大分県大分市敷戸北町');
ok($zip->set_number('8701102')->is_valid_number, '大分県大分市敷戸新町');
ok($zip->set_number('8701103')->is_valid_number, '大分県大分市敷戸西町');
ok($zip->set_number('8701104')->is_valid_number, '大分県大分市敷戸東町');
ok($zip->set_number('8701105')->is_valid_number, '大分県大分市敷戸南町');
ok($zip->set_number('8701106')->is_valid_number, '大分県大分市敷戸台');
ok($zip->set_number('8701107')->is_valid_number, '大分県大分市敷戸駅北町');
ok($zip->set_number('8701108')->is_valid_number, '大分県大分市判田台東');
ok($zip->set_number('8701109')->is_valid_number, '大分県大分市判田台南');
ok($zip->set_number('8701110')->is_valid_number, '大分県大分市判田台');
ok($zip->set_number('8701111')->is_valid_number, '大分県大分市上判田');
ok($zip->set_number('8701112')->is_valid_number, '大分県大分市下判田');
ok($zip->set_number('8701113')->is_valid_number, '大分県大分市中判田');
ok($zip->set_number('8701114')->is_valid_number, '大分県大分市星和台');
ok($zip->set_number('8701115')->is_valid_number, '大分県大分市ひばりケ丘');
ok($zip->set_number('8701116')->is_valid_number, '大分県大分市高江中央');
ok($zip->set_number('8701117')->is_valid_number, '大分県大分市高江西');
ok($zip->set_number('8701118')->is_valid_number, '大分県大分市高江南');
ok($zip->set_number('8701119')->is_valid_number, '大分県大分市高江北');
ok($zip->set_number('8701120')->is_valid_number, '大分県大分市サンシャインしきど');
ok($zip->set_number('8701121')->is_valid_number, '大分県大分市鴛野');
ok($zip->set_number('8701122')->is_valid_number, '大分県大分市敷戸');
ok($zip->set_number('8701123')->is_valid_number, '大分県大分市寒田');
ok($zip->set_number('8701124')->is_valid_number, '大分県大分市旦野原');
ok($zip->set_number('8701125')->is_valid_number, '大分県大分市大園団地');
ok($zip->set_number('8701126')->is_valid_number, '大分県大分市判田台北');
ok($zip->set_number('8701127')->is_valid_number, '大分県大分市寒田わかば台');
ok($zip->set_number('8701128')->is_valid_number, '大分県大分市花の木坂');
ok($zip->set_number('8701130')->is_valid_number, '大分県大分市田尻中央');
ok($zip->set_number('8701131')->is_valid_number, '大分県大分市岡川');
ok($zip->set_number('8701132')->is_valid_number, '大分県大分市光吉');
ok($zip->set_number('8701133')->is_valid_number, '大分県大分市宮崎');
ok($zip->set_number('8701134')->is_valid_number, '大分県大分市小原団地');
ok($zip->set_number('8701135')->is_valid_number, '大分県大分市光吉新町');
ok($zip->set_number('8701136')->is_valid_number, '大分県大分市光吉台');
ok($zip->set_number('8701137')->is_valid_number, '大分県大分市宮崎台');
ok($zip->set_number('8701138')->is_valid_number, '大分県大分市寒田北町');
ok($zip->set_number('8701139')->is_valid_number, '大分県大分市寒田南町');
ok($zip->set_number('8701140')->is_valid_number, '大分県大分市田尻北');
ok($zip->set_number('8701141')->is_valid_number, '大分県大分市下宗方');
ok($zip->set_number('8701142')->is_valid_number, '大分県大分市高瀬');
ok($zip->set_number('8701143')->is_valid_number, '大分県大分市田尻');
ok($zip->set_number('8701144')->is_valid_number, '大分県大分市田尻西');
ok($zip->set_number('8701145')->is_valid_number, '大分県大分市田尻南');
ok($zip->set_number('8701146')->is_valid_number, '大分県大分市曲(635、639、650、669、676、678、689、');
ok($zip->set_number('8701146')->is_valid_number, '大分県大分市695、718、733、1481、1555、1618番地)');
ok($zip->set_number('8701147')->is_valid_number, '大分県大分市ふじが丘');
ok($zip->set_number('8701148')->is_valid_number, '大分県大分市天領ハイツ');
ok($zip->set_number('8701149')->is_valid_number, '大分県大分市田尻東');
ok($zip->set_number('8701150')->is_valid_number, '大分県大分市小野鶴南');
ok($zip->set_number('8701151')->is_valid_number, '大分県大分市市');
ok($zip->set_number('8701152')->is_valid_number, '大分県大分市上宗方');
ok($zip->set_number('8701153')->is_valid_number, '大分県大分市小野鶴');
ok($zip->set_number('8701154')->is_valid_number, '大分県大分市田原');
ok($zip->set_number('8701155')->is_valid_number, '大分県大分市玉沢');
ok($zip->set_number('8701156')->is_valid_number, '大分県大分市小野鶴新町');
ok($zip->set_number('8701157')->is_valid_number, '大分県大分市宗方台東');
ok($zip->set_number('8701158')->is_valid_number, '大分県大分市宗方台西');
ok($zip->set_number('8701159')->is_valid_number, '大分県大分市宗方台北');
ok($zip->set_number('8701161')->is_valid_number, '大分県大分市木上');
ok($zip->set_number('8701162')->is_valid_number, '大分県大分市口戸');
ok($zip->set_number('8701163')->is_valid_number, '大分県大分市廻栖野(1~657、776~829、842~1305、2691、');
ok($zip->set_number('8701163')->is_valid_number, '大分県大分市2925番地)');
ok($zip->set_number('8701164')->is_valid_number, '大分県大分市雄城台中央');
ok($zip->set_number('8701165')->is_valid_number, '大分県大分市雄城台');
ok($zip->set_number('8701166')->is_valid_number, '大分県大分市椿が丘');
ok($zip->set_number('8701167')->is_valid_number, '大分県大分市上宗方南');
ok($zip->set_number('8701168')->is_valid_number, '大分県大分市松が丘');
ok($zip->set_number('8701169')->is_valid_number, '大分県大分市木上台');
ok($zip->set_number('8701171')->is_valid_number, '大分県大分市鬼崎');
ok($zip->set_number('8701172')->is_valid_number, '大分県大分市緑が丘');
ok($zip->set_number('8701173')->is_valid_number, '大分県大分市横瀬');
ok($zip->set_number('8701174')->is_valid_number, '大分県大分市萌葱台');
ok($zip->set_number('8701176')->is_valid_number, '大分県大分市富士見が丘東');
ok($zip->set_number('8701177')->is_valid_number, '大分県大分市富士見が丘西');
ok($zip->set_number('8701181')->is_valid_number, '大分県大分市ふじが丘北');
ok($zip->set_number('8701182')->is_valid_number, '大分県大分市ふじが丘東');
ok($zip->set_number('8701183')->is_valid_number, '大分県大分市ふじが丘南');
ok($zip->set_number('8701184')->is_valid_number, '大分県大分市ふじが丘山手');
ok($zip->set_number('8701185')->is_valid_number, '大分県大分市ふじが丘西');
ok($zip->set_number('8701201')->is_valid_number, '大分県大分市廻栖野(その他)');
ok($zip->set_number('8701202')->is_valid_number, '大分県大分市入蔵');
ok($zip->set_number('8701203')->is_valid_number, '大分県大分市野津原');
ok($zip->set_number('8701204')->is_valid_number, '大分県大分市辻原');
ok($zip->set_number('8701205')->is_valid_number, '大分県大分市福宗');
ok($zip->set_number('8701211')->is_valid_number, '大分県大分市竹矢');
ok($zip->set_number('8701212')->is_valid_number, '大分県大分市沢田');
ok($zip->set_number('8701213')->is_valid_number, '大分県大分市下原');
ok($zip->set_number('8701214')->is_valid_number, '大分県大分市太田');
ok($zip->set_number('8701215')->is_valid_number, '大分県大分市上詰');
ok($zip->set_number('8701221')->is_valid_number, '大分県大分市荷尾杵');
ok($zip->set_number('8701222')->is_valid_number, '大分県大分市高原');
ok($zip->set_number('8701223')->is_valid_number, '大分県大分市今市');
ok($zip->set_number('8710000')->is_valid_number, '福岡県築上郡吉富町以下に掲載がない場合');
ok($zip->set_number('8710000')->is_valid_number, '大分県中津市以下に掲載がない場合');
ok($zip->set_number('8710001')->is_valid_number, '大分県中津市大新田');
ok($zip->set_number('8710002')->is_valid_number, '大分県中津市全徳');
ok($zip->set_number('8710003')->is_valid_number, '大分県中津市是則');
ok($zip->set_number('8710004')->is_valid_number, '大分県中津市上如水');
ok($zip->set_number('8710005')->is_valid_number, '大分県中津市合馬');
ok($zip->set_number('8710006')->is_valid_number, '大分県中津市東浜');
ok($zip->set_number('8710007')->is_valid_number, '大分県中津市蛎瀬');
ok($zip->set_number('8710008')->is_valid_number, '大分県中津市大塚');
ok($zip->set_number('8710009')->is_valid_number, '大分県中津市新大塚町');
ok($zip->set_number('8710011')->is_valid_number, '大分県中津市下池永');
ok($zip->set_number('8710012')->is_valid_number, '大分県中津市宮夫');
ok($zip->set_number('8710013')->is_valid_number, '大分県中津市金手');
ok($zip->set_number('8710014')->is_valid_number, '大分県中津市一ツ松');
ok($zip->set_number('8710015')->is_valid_number, '大分県中津市牛神');
ok($zip->set_number('8710016')->is_valid_number, '大分県中津市牛神町');
ok($zip->set_number('8710021')->is_valid_number, '大分県中津市沖代町');
ok($zip->set_number('8710022')->is_valid_number, '大分県中津市相原(その他)');
ok($zip->set_number('8710023')->is_valid_number, '大分県中津市湯屋');
ok($zip->set_number('8710024')->is_valid_number, '大分県中津市中央町');
ok($zip->set_number('8710025')->is_valid_number, '大分県中津市万田');
ok($zip->set_number('8710026')->is_valid_number, '大分県中津市高瀬');
ok($zip->set_number('8710027')->is_valid_number, '大分県中津市上宮永');
ok($zip->set_number('8710028')->is_valid_number, '大分県中津市角木町');
ok($zip->set_number('8710029')->is_valid_number, '大分県中津市下宮永');
ok($zip->set_number('8710030')->is_valid_number, '大分県中津市中殿町');
ok($zip->set_number('8710031')->is_valid_number, '大分県中津市中殿');
ok($zip->set_number('8710032')->is_valid_number, '大分県中津市東本町');
ok($zip->set_number('8710033')->is_valid_number, '大分県中津市島田');
ok($zip->set_number('8710034')->is_valid_number, '大分県中津市日ノ出町');
ok($zip->set_number('8710035')->is_valid_number, '大分県中津市島田仲町');
ok($zip->set_number('8710036')->is_valid_number, '大分県中津市島田本町');
ok($zip->set_number('8710037')->is_valid_number, '大分県中津市宮島町');
ok($zip->set_number('8710038')->is_valid_number, '大分県中津市枝町');
ok($zip->set_number('8710039')->is_valid_number, '大分県中津市新天神町');
ok($zip->set_number('8710039')->is_valid_number, '大分県中津市天神町');
ok($zip->set_number('8710041')->is_valid_number, '大分県中津市新博多町');
ok($zip->set_number('8710042')->is_valid_number, '大分県中津市上博多町');
ok($zip->set_number('8710043')->is_valid_number, '大分県中津市栄町');
ok($zip->set_number('8710044')->is_valid_number, '大分県中津市江三竹町');
ok($zip->set_number('8710045')->is_valid_number, '大分県中津市萱津町');
ok($zip->set_number('8710046')->is_valid_number, '大分県中津市金谷(上ノ丁、中ノ丁、西ノ丁、本町、南ノ丁、森ノ丁、山ノ神)');
ok($zip->set_number('8710046')->is_valid_number, '大分県中津市西堀端');
ok($zip->set_number('8710046')->is_valid_number, '大分県中津市東堀端');
ok($zip->set_number('8710046')->is_valid_number, '大分県中津市古金谷');
ok($zip->set_number('8710047')->is_valid_number, '大分県中津市丸山町');
ok($zip->set_number('8710048')->is_valid_number, '大分県中津市新魚町');
ok($zip->set_number('8710049')->is_valid_number, '大分県中津市諸町');
ok($zip->set_number('8710050')->is_valid_number, '大分県中津市二ノ丁');
ok($zip->set_number('8710051')->is_valid_number, '大分県中津市古博多町');
ok($zip->set_number('8710053')->is_valid_number, '大分県中津市古魚町');
ok($zip->set_number('8710054')->is_valid_number, '大分県中津市京町');
ok($zip->set_number('8710055')->is_valid_number, '大分県中津市殿町');
ok($zip->set_number('8710056')->is_valid_number, '大分県中津市片端町');
ok($zip->set_number('8710057')->is_valid_number, '大分県中津市三ノ丁');
ok($zip->set_number('8710058')->is_valid_number, '大分県中津市豊田町');
ok($zip->set_number('8710059')->is_valid_number, '大分県中津市外馬場');
ok($zip->set_number('8710060')->is_valid_number, '大分県中津市北稲堀');
ok($zip->set_number('8710061')->is_valid_number, '大分県中津市南稲堀');
ok($zip->set_number('8710062')->is_valid_number, '大分県中津市山下');
ok($zip->set_number('8710063')->is_valid_number, '大分県中津市袋町');
ok($zip->set_number('8710064')->is_valid_number, '大分県中津市餌指町');
ok($zip->set_number('8710065')->is_valid_number, '大分県中津市蛭子町');
ok($zip->set_number('8710066')->is_valid_number, '大分県中津市鷹匠町');
ok($zip->set_number('8710067')->is_valid_number, '大分県中津市仲間町');
ok($zip->set_number('8710068')->is_valid_number, '大分県中津市豊後町');
ok($zip->set_number('8710069')->is_valid_number, '大分県中津市新堀');
ok($zip->set_number('8710071')->is_valid_number, '大分県中津市鷹部屋');
ok($zip->set_number('8710072')->is_valid_number, '大分県中津市船町');
ok($zip->set_number('8710073')->is_valid_number, '大分県中津市塩町');
ok($zip->set_number('8710074')->is_valid_number, '大分県中津市桜町');
ok($zip->set_number('8710075')->is_valid_number, '大分県中津市寺町');
ok($zip->set_number('8710076')->is_valid_number, '大分県中津市米町');
ok($zip->set_number('8710077')->is_valid_number, '大分県中津市姫路町');
ok($zip->set_number('8710078')->is_valid_number, '大分県中津市小祝(上方町、中島町、本町、港町)');
ok($zip->set_number('8710079')->is_valid_number, '大分県中津市北門通');
ok($zip->set_number('8710080')->is_valid_number, '大分県中津市小祝新町');
ok($zip->set_number('8710081')->is_valid_number, '大分県中津市北堀川町');
ok($zip->set_number('8710082')->is_valid_number, '大分県中津市水主町');
ok($zip->set_number('8710083')->is_valid_number, '大分県中津市矢場');
ok($zip->set_number('8710084')->is_valid_number, '大分県中津市小堀');
ok($zip->set_number('8710085')->is_valid_number, '大分県中津市弓町');
ok($zip->set_number('8710086')->is_valid_number, '大分県中津市船頭町');
ok($zip->set_number('8710087')->is_valid_number, '大分県中津市南堀川町');
ok($zip->set_number('8710088')->is_valid_number, '大分県中津市留守居町');
ok($zip->set_number('8710089')->is_valid_number, '大分県中津市船場町');
ok($zip->set_number('8710090')->is_valid_number, '大分県中津市北新地');
ok($zip->set_number('8710091')->is_valid_number, '大分県中津市闇無町');
ok($zip->set_number('8710091')->is_valid_number, '大分県中津市角木');
ok($zip->set_number('8710092')->is_valid_number, '大分県中津市南新地');
ok($zip->set_number('8710093')->is_valid_number, '大分県中津市浦町');
ok($zip->set_number('8710094')->is_valid_number, '大分県中津市北浦町');
ok($zip->set_number('8710095')->is_valid_number, '大分県中津市角木新町');
ok($zip->set_number('8710096')->is_valid_number, '大分県中津市竜王町');
ok($zip->set_number('8710097')->is_valid_number, '大分県中津市下正路');
ok($zip->set_number('8710098')->is_valid_number, '大分県中津市市場');
ok($zip->set_number('8710099')->is_valid_number, '大分県中津市中津市の次に番地がくる場合');
ok($zip->set_number('8710101')->is_valid_number, '大分県中津市三光森山');
ok($zip->set_number('8710102')->is_valid_number, '大分県中津市三光成恒');
ok($zip->set_number('8710103')->is_valid_number, '大分県中津市三光田口');
ok($zip->set_number('8710104')->is_valid_number, '大分県中津市三光諫山');
ok($zip->set_number('8710105')->is_valid_number, '大分県中津市三光原口');
ok($zip->set_number('8710111')->is_valid_number, '大分県中津市三光佐知');
ok($zip->set_number('8710112')->is_valid_number, '大分県中津市三光臼木');
ok($zip->set_number('8710113')->is_valid_number, '大分県中津市三光土田');
ok($zip->set_number('8710114')->is_valid_number, '大分県中津市三光小袋');
ok($zip->set_number('8710122')->is_valid_number, '大分県中津市相原(2803-1、2803-24、2803-25、2803-27、');
ok($zip->set_number('8710122')->is_valid_number, '大分県中津市2803-37、2803-38、2803-39、2803-43、');
ok($zip->set_number('8710122')->is_valid_number, '大分県中津市2803-69、2803-77、2803-91、2818、2828、');
ok($zip->set_number('8710122')->is_valid_number, '大分県中津市2925-7)');
ok($zip->set_number('8710151')->is_valid_number, '大分県中津市大悟法');
ok($zip->set_number('8710152')->is_valid_number, '大分県中津市加来');
ok($zip->set_number('8710153')->is_valid_number, '大分県中津市大貞');
ok($zip->set_number('8710154')->is_valid_number, '大分県中津市古城');
ok($zip->set_number('8710155')->is_valid_number, '大分県中津市八幡町');
ok($zip->set_number('8710156')->is_valid_number, '大分県中津市榊原町');
ok($zip->set_number('8710157')->is_valid_number, '大分県中津市中原');
ok($zip->set_number('8710161')->is_valid_number, '大分県中津市上池永');
ok($zip->set_number('8710162')->is_valid_number, '大分県中津市永添');
ok($zip->set_number('8710163')->is_valid_number, '大分県中津市西永添');
ok($zip->set_number('8710164')->is_valid_number, '大分県中津市下永添');
ok($zip->set_number('8710201')->is_valid_number, '大分県中津市本耶馬渓町樋田');
ok($zip->set_number('8710202')->is_valid_number, '大分県中津市本耶馬渓町曽木');
ok($zip->set_number('8710203')->is_valid_number, '大分県中津市本耶馬渓町多志田');
ok($zip->set_number('8710204')->is_valid_number, '大分県中津市本耶馬渓町冠石野');
ok($zip->set_number('8710205')->is_valid_number, '大分県中津市本耶馬渓町下屋形');
ok($zip->set_number('8710206')->is_valid_number, '大分県中津市本耶馬渓町今行');
ok($zip->set_number('8710207')->is_valid_number, '大分県中津市本耶馬渓町東屋形');
ok($zip->set_number('8710208')->is_valid_number, '大分県中津市本耶馬渓町西屋形');
ok($zip->set_number('8710226')->is_valid_number, '福岡県築上郡上毛町原井(有野)');
ok($zip->set_number('8710311')->is_valid_number, '大分県中津市本耶馬渓町跡田');
ok($zip->set_number('8710312')->is_valid_number, '大分県中津市本耶馬渓町折元');
ok($zip->set_number('8710313')->is_valid_number, '大分県中津市本耶馬渓町落合');
ok($zip->set_number('8710314')->is_valid_number, '大分県中津市本耶馬渓町西谷');
ok($zip->set_number('8710315')->is_valid_number, '大分県中津市本耶馬渓町東谷');
ok($zip->set_number('8710401')->is_valid_number, '大分県中津市耶馬溪町平田');
ok($zip->set_number('8710402')->is_valid_number, '大分県中津市耶馬溪町冠石野');
ok($zip->set_number('8710403')->is_valid_number, '大分県中津市耶馬溪町多志田');
ok($zip->set_number('8710404')->is_valid_number, '大分県中津市耶馬溪町戸原');
ok($zip->set_number('8710405')->is_valid_number, '大分県中津市耶馬溪町柿坂');
ok($zip->set_number('8710406')->is_valid_number, '大分県中津市耶馬溪町小友田');
ok($zip->set_number('8710407')->is_valid_number, '大分県中津市耶馬溪町三尾母');
ok($zip->set_number('8710408')->is_valid_number, '大分県中津市耶馬溪町福土');
ok($zip->set_number('8710411')->is_valid_number, '大分県中津市耶馬溪町中畑');
ok($zip->set_number('8710412')->is_valid_number, '大分県中津市耶馬溪町栃木');
ok($zip->set_number('8710413')->is_valid_number, '大分県中津市耶馬溪町大野');
ok($zip->set_number('8710414')->is_valid_number, '大分県中津市耶馬溪町川原口');
ok($zip->set_number('8710421')->is_valid_number, '大分県中津市耶馬溪町山移');
ok($zip->set_number('8710422')->is_valid_number, '大分県中津市耶馬溪町深耶馬');
ok($zip->set_number('8710431')->is_valid_number, '大分県中津市耶馬溪町大島');
ok($zip->set_number('8710432')->is_valid_number, '大分県中津市耶馬溪町金吉');
ok($zip->set_number('8710433')->is_valid_number, '大分県中津市耶馬溪町宮園');
ok($zip->set_number('8710434')->is_valid_number, '大分県中津市耶馬溪町樋山路');
ok($zip->set_number('8710701')->is_valid_number, '大分県中津市山国町槻木');
ok($zip->set_number('8710702')->is_valid_number, '大分県中津市山国町草本');
ok($zip->set_number('8710703')->is_valid_number, '大分県中津市山国町小屋川');
ok($zip->set_number('8710704')->is_valid_number, '大分県中津市山国町吉野');
ok($zip->set_number('8710711')->is_valid_number, '大分県中津市山国町平小野');
ok($zip->set_number('8710712')->is_valid_number, '大分県中津市山国町守実');
ok($zip->set_number('8710713')->is_valid_number, '大分県中津市山国町藤野木');
ok($zip->set_number('8710714')->is_valid_number, '大分県中津市山国町長尾野');
ok($zip->set_number('8710715')->is_valid_number, '大分県中津市山国町宇曽');
ok($zip->set_number('8710716')->is_valid_number, '大分県中津市山国町中摩');
ok($zip->set_number('8710801')->is_valid_number, '福岡県築上郡吉富町小祝');
ok($zip->set_number('8710802')->is_valid_number, '福岡県築上郡吉富町小犬丸');
ok($zip->set_number('8710811')->is_valid_number, '福岡県築上郡吉富町広津');
ok($zip->set_number('8710821')->is_valid_number, '福岡県築上郡吉富町幸子');
ok($zip->set_number('8710822')->is_valid_number, '福岡県築上郡吉富町今吉');
ok($zip->set_number('8710823')->is_valid_number, '福岡県築上郡吉富町別府');
ok($zip->set_number('8710831')->is_valid_number, '福岡県築上郡吉富町直江');
ok($zip->set_number('8710832')->is_valid_number, '福岡県築上郡吉富町鈴熊');
ok($zip->set_number('8710833')->is_valid_number, '福岡県築上郡吉富町楡生');
ok($zip->set_number('8710834')->is_valid_number, '福岡県築上郡吉富町土屋');
ok($zip->set_number('8710900')->is_valid_number, '福岡県築上郡上毛町以下に掲載がない場合');
ok($zip->set_number('8710901')->is_valid_number, '福岡県築上郡上毛町成恒');
ok($zip->set_number('8710902')->is_valid_number, '福岡県築上郡上毛町大ノ瀬');
ok($zip->set_number('8710903')->is_valid_number, '福岡県築上郡上毛町八ツ並');
ok($zip->set_number('8710904')->is_valid_number, '福岡県築上郡上毛町安雲');
ok($zip->set_number('8710905')->is_valid_number, '福岡県築上郡上毛町尻高');
ok($zip->set_number('8710906')->is_valid_number, '福岡県築上郡上毛町矢方');
ok($zip->set_number('8710907')->is_valid_number, '福岡県築上郡上毛町緒方');
ok($zip->set_number('8710911')->is_valid_number, '福岡県築上郡上毛町中村');
ok($zip->set_number('8710912')->is_valid_number, '福岡県築上郡上毛町吉岡');
ok($zip->set_number('8710913')->is_valid_number, '福岡県築上郡上毛町垂水');
ok($zip->set_number('8710914')->is_valid_number, '福岡県築上郡上毛町宇野');
ok($zip->set_number('8710921')->is_valid_number, '福岡県築上郡上毛町土佐井');
ok($zip->set_number('8710922')->is_valid_number, '福岡県築上郡上毛町東下');
ok($zip->set_number('8710923')->is_valid_number, '福岡県築上郡上毛町下唐原');
ok($zip->set_number('8710924')->is_valid_number, '福岡県築上郡上毛町上唐原');
ok($zip->set_number('8710925')->is_valid_number, '福岡県築上郡上毛町百留');
ok($zip->set_number('8710926')->is_valid_number, '福岡県築上郡上毛町原井(その他)');
ok($zip->set_number('8710927')->is_valid_number, '福岡県築上郡上毛町東上');
ok($zip->set_number('8710928')->is_valid_number, '福岡県築上郡上毛町西友枝');
ok($zip->set_number('8720000')->is_valid_number, '大分県宇佐市以下に掲載がない場合');
ok($zip->set_number('8720001')->is_valid_number, '大分県宇佐市長洲');
ok($zip->set_number('8720011')->is_valid_number, '大分県宇佐市岩保新田');
ok($zip->set_number('8720012')->is_valid_number, '大分県宇佐市久兵衛新田');
ok($zip->set_number('8720013')->is_valid_number, '大分県宇佐市北鶴田新田');
ok($zip->set_number('8720014')->is_valid_number, '大分県宇佐市南鶴田新田');
ok($zip->set_number('8720015')->is_valid_number, '大分県宇佐市松崎');
ok($zip->set_number('8720016')->is_valid_number, '大分県宇佐市佐々礼');
ok($zip->set_number('8720021')->is_valid_number, '大分県宇佐市金屋');
ok($zip->set_number('8720022')->is_valid_number, '大分県宇佐市西大堀');
ok($zip->set_number('8720023')->is_valid_number, '大分県宇佐市蜷木');
ok($zip->set_number('8720031')->is_valid_number, '大分県宇佐市沖須町');
ok($zip->set_number('8720032')->is_valid_number, '大分県宇佐市江須賀');
ok($zip->set_number('8720033')->is_valid_number, '大分県宇佐市住吉町');
ok($zip->set_number('8720041')->is_valid_number, '大分県宇佐市神子山新田');
ok($zip->set_number('8720042')->is_valid_number, '大分県宇佐市貴船町');
ok($zip->set_number('8720043')->is_valid_number, '大分県宇佐市子安町');
ok($zip->set_number('8720044')->is_valid_number, '大分県宇佐市住江');
ok($zip->set_number('8720045')->is_valid_number, '大分県宇佐市郡中新田');
ok($zip->set_number('8720046')->is_valid_number, '大分県宇佐市高砂新田');
ok($zip->set_number('8720047')->is_valid_number, '大分県宇佐市順風新田');
ok($zip->set_number('8720101')->is_valid_number, '大分県宇佐市高森');
ok($zip->set_number('8720102')->is_valid_number, '大分県宇佐市南宇佐');
ok($zip->set_number('8720103')->is_valid_number, '大分県宇佐市北宇佐');
ok($zip->set_number('8720104')->is_valid_number, '大分県宇佐市小向野');
ok($zip->set_number('8720111')->is_valid_number, '大分県宇佐市下矢部');
ok($zip->set_number('8720112')->is_valid_number, '大分県宇佐市上矢部');
ok($zip->set_number('8720113')->is_valid_number, '大分県宇佐市正覚寺');
ok($zip->set_number('8720114')->is_valid_number, '大分県宇佐市熊');
ok($zip->set_number('8720301')->is_valid_number, '大分県宇佐市院内町御沓');
ok($zip->set_number('8720302')->is_valid_number, '大分県宇佐市院内町二日市');
ok($zip->set_number('8720311')->is_valid_number, '大分県宇佐市院内町香下');
ok($zip->set_number('8720312')->is_valid_number, '大分県宇佐市院内町櫛野');
ok($zip->set_number('8720313')->is_valid_number, '大分県宇佐市院内町新洞');
ok($zip->set_number('8720314')->is_valid_number, '大分県宇佐市院内町沖');
ok($zip->set_number('8720315')->is_valid_number, '大分県宇佐市院内町北山');
ok($zip->set_number('8720316')->is_valid_number, '大分県宇佐市院内町小坂');
ok($zip->set_number('8720317')->is_valid_number, '大分県宇佐市院内町広瀬');
ok($zip->set_number('8720318')->is_valid_number, '大分県宇佐市院内町副');
ok($zip->set_number('8720321')->is_valid_number, '大分県宇佐市院内町五名');
ok($zip->set_number('8720322')->is_valid_number, '大分県宇佐市院内町日岳');
ok($zip->set_number('8720323')->is_valid_number, '大分県宇佐市院内町大重見');
ok($zip->set_number('8720324')->is_valid_number, '大分県宇佐市院内町小野川内');
ok($zip->set_number('8720325')->is_valid_number, '大分県宇佐市院内町小稲');
ok($zip->set_number('8720326')->is_valid_number, '大分県宇佐市院内町上船木');
ok($zip->set_number('8720327')->is_valid_number, '大分県宇佐市院内町下船木');
ok($zip->set_number('8720328')->is_valid_number, '大分県宇佐市院内町高並');
ok($zip->set_number('8720331')->is_valid_number, '大分県宇佐市院内町大副');
ok($zip->set_number('8720332')->is_valid_number, '大分県宇佐市院内町山城');
ok($zip->set_number('8720333')->is_valid_number, '大分県宇佐市院内町原口');
ok($zip->set_number('8720334')->is_valid_number, '大分県宇佐市院内町落狩倉');
ok($zip->set_number('8720341')->is_valid_number, '大分県宇佐市院内町斎藤');
ok($zip->set_number('8720342')->is_valid_number, '大分県宇佐市院内町景平');
ok($zip->set_number('8720343')->is_valid_number, '大分県宇佐市院内町宮原');
ok($zip->set_number('8720344')->is_valid_number, '大分県宇佐市院内町大門');
ok($zip->set_number('8720345')->is_valid_number, '大分県宇佐市院内町月俣');
ok($zip->set_number('8720346')->is_valid_number, '大分県宇佐市院内町定別当');
ok($zip->set_number('8720366')->is_valid_number, '大分県宇佐市上拝田(新洞)');
ok($zip->set_number('8720451')->is_valid_number, '大分県宇佐市院内町下余');
ok($zip->set_number('8720452')->is_valid_number, '大分県宇佐市院内町上納持');
ok($zip->set_number('8720453')->is_valid_number, '大分県宇佐市院内町平原');
ok($zip->set_number('8720454')->is_valid_number, '大分県宇佐市院内町滝貞');
ok($zip->set_number('8720455')->is_valid_number, '大分県宇佐市院内町小平');
ok($zip->set_number('8720456')->is_valid_number, '大分県宇佐市院内町栗山');
ok($zip->set_number('8720457')->is_valid_number, '大分県宇佐市院内町岡');
ok($zip->set_number('8720458')->is_valid_number, '大分県宇佐市院内町大坪');
ok($zip->set_number('8720459')->is_valid_number, '大分県宇佐市院内町上余');
ok($zip->set_number('8720461')->is_valid_number, '大分県宇佐市院内町台');
ok($zip->set_number('8720462')->is_valid_number, '大分県宇佐市院内町羽馬礼');
ok($zip->set_number('8720463')->is_valid_number, '大分県宇佐市院内町和田');
ok($zip->set_number('8720464')->is_valid_number, '大分県宇佐市院内町西椎屋');
ok($zip->set_number('8720465')->is_valid_number, '大分県宇佐市院内町田平');
ok($zip->set_number('8720466')->is_valid_number, '大分県宇佐市院内町来鉢');
ok($zip->set_number('8720471')->is_valid_number, '大分県宇佐市院内町温見');
ok($zip->set_number('8720472')->is_valid_number, '大分県宇佐市院内町野地');
ok($zip->set_number('8720473')->is_valid_number, '大分県宇佐市院内町田所');
ok($zip->set_number('8720481')->is_valid_number, '大分県宇佐市院内町下恵良');
ok($zip->set_number('8720482')->is_valid_number, '大分県宇佐市院内町荻迫');
ok($zip->set_number('8720483')->is_valid_number, '大分県宇佐市院内町土岩屋');
ok($zip->set_number('8720484')->is_valid_number, '大分県宇佐市院内町上恵良');
ok($zip->set_number('8720501')->is_valid_number, '大分県宇佐市安心院町原');
ok($zip->set_number('8720502')->is_valid_number, '大分県宇佐市安心院町飯田');
ok($zip->set_number('8720503')->is_valid_number, '大分県宇佐市安心院町新原');
ok($zip->set_number('8720504')->is_valid_number, '大分県宇佐市安心院町荘');
ok($zip->set_number('8720505')->is_valid_number, '大分県宇佐市安心院町戸方');
ok($zip->set_number('8720506')->is_valid_number, '大分県宇佐市安心院町妻垣');
ok($zip->set_number('8720507')->is_valid_number, '大分県宇佐市安心院町木裳');
ok($zip->set_number('8720510')->is_valid_number, '大分県宇佐市安心院町有徳原');
ok($zip->set_number('8720511')->is_valid_number, '大分県宇佐市安心院町上市');
ok($zip->set_number('8720512')->is_valid_number, '大分県宇佐市安心院町古市');
ok($zip->set_number('8720513')->is_valid_number, '大分県宇佐市安心院町龍王');
ok($zip->set_number('8720514')->is_valid_number, '大分県宇佐市安心院町鳥越');
ok($zip->set_number('8720515')->is_valid_number, '大分県宇佐市安心院町野山');
ok($zip->set_number('8720516')->is_valid_number, '大分県宇佐市安心院町森');
ok($zip->set_number('8720517')->is_valid_number, '大分県宇佐市安心院町大');
ok($zip->set_number('8720518')->is_valid_number, '大分県宇佐市安心院町今井');
ok($zip->set_number('8720519')->is_valid_number, '大分県宇佐市安心院町西衲');
ok($zip->set_number('8720521')->is_valid_number, '大分県宇佐市安心院町下毛');
ok($zip->set_number('8720522')->is_valid_number, '大分県宇佐市安心院町折敷田');
ok($zip->set_number('8720523')->is_valid_number, '大分県宇佐市安心院町大佛');
ok($zip->set_number('8720524')->is_valid_number, '大分県宇佐市安心院町恒松');
ok($zip->set_number('8720525')->is_valid_number, '大分県宇佐市安心院町中山');
ok($zip->set_number('8720526')->is_valid_number, '大分県宇佐市安心院町田ノ口');
ok($zip->set_number('8720527')->is_valid_number, '大分県宇佐市安心院町辻');
ok($zip->set_number('8720541')->is_valid_number, '大分県宇佐市安心院町熊');
ok($zip->set_number('8720542')->is_valid_number, '大分県宇佐市安心院町正覚寺');
ok($zip->set_number('8720543')->is_valid_number, '大分県宇佐市安心院町平ケ倉');
ok($zip->set_number('8720651')->is_valid_number, '大分県宇佐市安心院町佐田');
ok($zip->set_number('8720652')->is_valid_number, '大分県宇佐市安心院町山蔵');
ok($zip->set_number('8720653')->is_valid_number, '大分県宇佐市安心院町房ケ畑');
ok($zip->set_number('8720654')->is_valid_number, '大分県宇佐市安心院町内川野');
ok($zip->set_number('8720655')->is_valid_number, '大分県宇佐市安心院町古川');
ok($zip->set_number('8720661')->is_valid_number, '大分県宇佐市安心院町笹ケ平');
ok($zip->set_number('8720662')->is_valid_number, '大分県宇佐市安心院町矢津');
ok($zip->set_number('8720663')->is_valid_number, '大分県宇佐市安心院町大見尾');
ok($zip->set_number('8720664')->is_valid_number, '大分県宇佐市安心院町塔尾');
ok($zip->set_number('8720671')->is_valid_number, '大分県宇佐市安心院町且尾');
ok($zip->set_number('8720672')->is_valid_number, '大分県宇佐市安心院町広谷');
ok($zip->set_number('8720673')->is_valid_number, '大分県宇佐市安心院町口ノ坪');
ok($zip->set_number('8720674')->is_valid_number, '大分県宇佐市安心院町久井田');
ok($zip->set_number('8720675')->is_valid_number, '大分県宇佐市安心院町矢崎');
ok($zip->set_number('8720701')->is_valid_number, '大分県宇佐市安心院町楢本');
ok($zip->set_number('8720702')->is_valid_number, '大分県宇佐市安心院町東恵良');
ok($zip->set_number('8720703')->is_valid_number, '大分県宇佐市安心院町尾立');
ok($zip->set_number('8720711')->is_valid_number, '大分県宇佐市安心院町六郎丸');
ok($zip->set_number('8720712')->is_valid_number, '大分県宇佐市安心院町五郎丸');
ok($zip->set_number('8720721')->is_valid_number, '大分県宇佐市安心院町若林');
ok($zip->set_number('8720722')->is_valid_number, '大分県宇佐市安心院町南畑');
ok($zip->set_number('8720723')->is_valid_number, '大分県宇佐市安心院町萱籠');
ok($zip->set_number('8720724')->is_valid_number, '大分県宇佐市安心院町東椎屋');
ok($zip->set_number('8720731')->is_valid_number, '大分県宇佐市安心院町川崎');
ok($zip->set_number('8720732')->is_valid_number, '大分県宇佐市安心院町板場');
ok($zip->set_number('8720733')->is_valid_number, '大分県宇佐市安心院町松本');
ok($zip->set_number('8720841')->is_valid_number, '大分県宇佐市安心院町矢畑');
ok($zip->set_number('8720842')->is_valid_number, '大分県宇佐市安心院町下内河野');
ok($zip->set_number('8720843')->is_valid_number, '大分県宇佐市安心院町筌ノ口');
ok($zip->set_number('8720851')->is_valid_number, '大分県宇佐市安心院町広連');
ok($zip->set_number('8720852')->is_valid_number, '大分県宇佐市安心院町上内河野');
ok($zip->set_number('8720853')->is_valid_number, '大分県宇佐市安心院町元');
ok($zip->set_number('8720854')->is_valid_number, '大分県宇佐市安心院町寒水');
ok($zip->set_number('8720855')->is_valid_number, '大分県宇佐市安心院町福貴野');
ok($zip->set_number('8720856')->is_valid_number, '大分県宇佐市安心院町山ノ口');
ok($zip->set_number('8720857')->is_valid_number, '大分県宇佐市安心院町畳石');
ok($zip->set_number('8720858')->is_valid_number, '大分県宇佐市安心院町水車');
ok($zip->set_number('8720861')->is_valid_number, '大分県宇佐市安心院町境ノ坪');
ok($zip->set_number('8720862')->is_valid_number, '大分県宇佐市安心院町川底');
ok($zip->set_number('8720863')->is_valid_number, '大分県宇佐市安心院町村部');
ok($zip->set_number('8720864')->is_valid_number, '大分県宇佐市安心院町番木');
ok($zip->set_number('8720865')->is_valid_number, '大分県宇佐市安心院町佛木');
ok($zip->set_number('8720871')->is_valid_number, '大分県宇佐市安心院町平山');
ok($zip->set_number('8720872')->is_valid_number, '大分県宇佐市安心院町舟板');
ok($zip->set_number('8720873')->is_valid_number, '大分県宇佐市安心院町新貝');
ok($zip->set_number('8721101')->is_valid_number, '大分県豊後高田市中真玉');
ok($zip->set_number('8721102')->is_valid_number, '大分県豊後高田市大岩屋');
ok($zip->set_number('8721103')->is_valid_number, '大分県豊後高田市黒土');
ok($zip->set_number('8721104')->is_valid_number, '大分県豊後高田市城前');
ok($zip->set_number('8721105')->is_valid_number, '大分県豊後高田市西真玉');
ok($zip->set_number('8721106')->is_valid_number, '大分県豊後高田市大平');
ok($zip->set_number('8721107')->is_valid_number, '大分県豊後高田市臼野');
ok($zip->set_number('8721201')->is_valid_number, '大分県豊後高田市夷');
ok($zip->set_number('8721202')->is_valid_number, '大分県豊後高田市香々地');
ok($zip->set_number('8721203')->is_valid_number, '大分県豊後高田市堅来');
ok($zip->set_number('8721204')->is_valid_number, '大分県豊後高田市上香々地');
ok($zip->set_number('8721205')->is_valid_number, '大分県豊後高田市小畑');
ok($zip->set_number('8721206')->is_valid_number, '大分県豊後高田市羽根');
ok($zip->set_number('8721207')->is_valid_number, '大分県豊後高田市見目');
ok($zip->set_number('8721321')->is_valid_number, '大分県国東市国見町竹田津');
ok($zip->set_number('8721322')->is_valid_number, '大分県国東市国見町西方寺');
ok($zip->set_number('8721323')->is_valid_number, '大分県国東市国見町鬼籠');
ok($zip->set_number('8721324')->is_valid_number, '大分県国東市国見町櫛海');
ok($zip->set_number('8721401')->is_valid_number, '大分県国東市国見町伊美');
ok($zip->set_number('8721402')->is_valid_number, '大分県国東市国見町中');
ok($zip->set_number('8721403')->is_valid_number, '大分県国東市国見町野田');
ok($zip->set_number('8721404')->is_valid_number, '大分県国東市国見町千燈');
ok($zip->set_number('8721405')->is_valid_number, '大分県国東市国見町赤根');
ok($zip->set_number('8721406')->is_valid_number, '大分県国東市国見町櫛来');
ok($zip->set_number('8721501')->is_valid_number, '大分県東国東郡姫島村姫島村一円');
ok($zip->set_number('8721611')->is_valid_number, '大分県国東市国見町向田');
ok($zip->set_number('8721612')->is_valid_number, '大分県国東市国見町大熊毛');
ok($zip->set_number('8721613')->is_valid_number, '大分県国東市国見町小熊毛');
ok($zip->set_number('8721614')->is_valid_number, '大分県国東市国見町岐部');
ok($zip->set_number('8721651')->is_valid_number, '大分県国東市国東町浜');
ok($zip->set_number('8721652')->is_valid_number, '大分県国東市国東町来浦');
ok($zip->set_number('8721653')->is_valid_number, '大分県国東市国東町岩戸寺');
ok($zip->set_number('8730000')->is_valid_number, '大分県杵築市以下に掲載がない場合');
ok($zip->set_number('8730001')->is_valid_number, '大分県杵築市杵築');
ok($zip->set_number('8730002')->is_valid_number, '大分県杵築市南杵築');
ok($zip->set_number('8730003')->is_valid_number, '大分県杵築市馬場尾');
ok($zip->set_number('8730004')->is_valid_number, '大分県杵築市宮司');
ok($zip->set_number('8730005')->is_valid_number, '大分県杵築市猪尾');
ok($zip->set_number('8730006')->is_valid_number, '大分県杵築市大内');
ok($zip->set_number('8730007')->is_valid_number, '大分県杵築市片野');
ok($zip->set_number('8730008')->is_valid_number, '大分県杵築市熊野');
ok($zip->set_number('8730011')->is_valid_number, '大分県杵築市相原');
ok($zip->set_number('8730012')->is_valid_number, '大分県杵築市中');
ok($zip->set_number('8730013')->is_valid_number, '大分県杵築市日野');
ok($zip->set_number('8730014')->is_valid_number, '大分県杵築市本庄');
ok($zip->set_number('8730015')->is_valid_number, '大分県杵築市八坂');
ok($zip->set_number('8730021')->is_valid_number, '大分県杵築市岩谷');
ok($zip->set_number('8730022')->is_valid_number, '大分県杵築市大片平');
ok($zip->set_number('8730023')->is_valid_number, '大分県杵築市鴨川');
ok($zip->set_number('8730024')->is_valid_number, '大分県杵築市船部');
ok($zip->set_number('8730025')->is_valid_number, '大分県杵築市溝井');
ok($zip->set_number('8730031')->is_valid_number, '大分県杵築市狩宿');
ok($zip->set_number('8730032')->is_valid_number, '大分県杵築市奈多');
ok($zip->set_number('8730033')->is_valid_number, '大分県杵築市守江');
ok($zip->set_number('8730034')->is_valid_number, '大分県杵築市横城');
ok($zip->set_number('8730041')->is_valid_number, '大分県杵築市大田俣水(天堤)');
ok($zip->set_number('8730053')->is_valid_number, '大分県国東市安岐町矢川(天堤)');
ok($zip->set_number('8730201')->is_valid_number, '大分県国東市安岐町吉松');
ok($zip->set_number('8730202')->is_valid_number, '大分県国東市安岐町瀬戸田');
ok($zip->set_number('8730203')->is_valid_number, '大分県国東市安岐町中園');
ok($zip->set_number('8730204')->is_valid_number, '大分県国東市安岐町成久');
ok($zip->set_number('8730205')->is_valid_number, '大分県国東市安岐町掛樋');
ok($zip->set_number('8730206')->is_valid_number, '大分県国東市安岐町山浦');
ok($zip->set_number('8730207')->is_valid_number, '大分県国東市安岐町油留木');
ok($zip->set_number('8730211')->is_valid_number, '大分県国東市安岐町馬場');
ok($zip->set_number('8730212')->is_valid_number, '大分県国東市安岐町塩屋');
ok($zip->set_number('8730221')->is_valid_number, '大分県国東市安岐町西本');
ok($zip->set_number('8730222')->is_valid_number, '大分県国東市安岐町下山口');
ok($zip->set_number('8730223')->is_valid_number, '大分県国東市安岐町大添');
ok($zip->set_number('8730224')->is_valid_number, '大分県国東市安岐町山口');
ok($zip->set_number('8730231')->is_valid_number, '大分県国東市安岐町下原');
ok($zip->set_number('8730232')->is_valid_number, '大分県国東市安岐町向陽台');
ok($zip->set_number('8730351')->is_valid_number, '大分県国東市安岐町朝来');
ok($zip->set_number('8730352')->is_valid_number, '大分県国東市安岐町明治');
ok($zip->set_number('8730353')->is_valid_number, '大分県国東市安岐町矢川(その他)');
ok($zip->set_number('8730354')->is_valid_number, '大分県国東市安岐町糸永');
ok($zip->set_number('8730355')->is_valid_number, '大分県国東市安岐町富清');
ok($zip->set_number('8730356')->is_valid_number, '大分県国東市安岐町両子');
ok($zip->set_number('8730401')->is_valid_number, '大分県国東市武蔵町池ノ内');
ok($zip->set_number('8730402')->is_valid_number, '大分県国東市武蔵町内田');
ok($zip->set_number('8730404')->is_valid_number, '大分県国東市武蔵町成吉');
ok($zip->set_number('8730405')->is_valid_number, '大分県国東市武蔵町麻田');
ok($zip->set_number('8730406')->is_valid_number, '大分県国東市武蔵町丸小野');
ok($zip->set_number('8730407')->is_valid_number, '大分県国東市武蔵町狭間');
ok($zip->set_number('8730412')->is_valid_number, '大分県国東市武蔵町古市');
ok($zip->set_number('8730414')->is_valid_number, '大分県国東市武蔵町手野');
ok($zip->set_number('8730415')->is_valid_number, '大分県国東市武蔵町吉広');
ok($zip->set_number('8730421')->is_valid_number, '大分県国東市武蔵町糸原');
ok($zip->set_number('8730422')->is_valid_number, '大分県国東市武蔵町小城');
ok($zip->set_number('8730423')->is_valid_number, '大分県国東市武蔵町三井寺');
ok($zip->set_number('8730424')->is_valid_number, '大分県国東市武蔵町志和利');
ok($zip->set_number('8730432')->is_valid_number, '大分県国東市武蔵町向陽台');
ok($zip->set_number('8730500')->is_valid_number, '大分県国東市以下に掲載がない場合');
ok($zip->set_number('8730501')->is_valid_number, '大分県国東市国東町北江');
ok($zip->set_number('8730502')->is_valid_number, '大分県国東市国東町田深');
ok($zip->set_number('8730503')->is_valid_number, '大分県国東市国東町鶴川');
ok($zip->set_number('8730504')->is_valid_number, '大分県国東市国東町安国寺');
ok($zip->set_number('8730511')->is_valid_number, '大分県国東市国東町小原');
ok($zip->set_number('8730512')->is_valid_number, '大分県国東市国東町治郎丸');
ok($zip->set_number('8730513')->is_valid_number, '大分県国東市国東町綱井');
ok($zip->set_number('8730514')->is_valid_number, '大分県国東市国東町重藤');
ok($zip->set_number('8730521')->is_valid_number, '大分県国東市国東町原');
ok($zip->set_number('8730522')->is_valid_number, '大分県国東市国東町岩屋');
ok($zip->set_number('8730523')->is_valid_number, '大分県国東市国東町赤松');
ok($zip->set_number('8730524')->is_valid_number, '大分県国東市国東町横手');
ok($zip->set_number('8730531')->is_valid_number, '大分県国東市国東町川原');
ok($zip->set_number('8730532')->is_valid_number, '大分県国東市国東町中田');
ok($zip->set_number('8730533')->is_valid_number, '大分県国東市国東町見地');
ok($zip->set_number('8730534')->is_valid_number, '大分県国東市国東町下成仏');
ok($zip->set_number('8730535')->is_valid_number, '大分県国東市国東町成仏');
ok($zip->set_number('8730641')->is_valid_number, '大分県国東市国東町深江');
ok($zip->set_number('8730642')->is_valid_number, '大分県国東市国東町東堅来');
ok($zip->set_number('8730643')->is_valid_number, '大分県国東市国東町富来浦');
ok($zip->set_number('8730644')->is_valid_number, '大分県国東市国東町浜崎');
ok($zip->set_number('8730645')->is_valid_number, '大分県国東市国東町富来');
ok($zip->set_number('8730646')->is_valid_number, '大分県国東市国東町大恩寺');
ok($zip->set_number('8740000')->is_valid_number, '大分県別府市以下に掲載がない場合');
ok($zip->set_number('8740001')->is_valid_number, '大分県別府市小坂');
ok($zip->set_number('8740002')->is_valid_number, '大分県別府市関の江新町');
ok($zip->set_number('8740003')->is_valid_number, '大分県別府市大所');
ok($zip->set_number('8740004')->is_valid_number, '大分県別府市湯山');
ok($zip->set_number('8740005')->is_valid_number, '大分県別府市天間');
ok($zip->set_number('8740011')->is_valid_number, '大分県別府市内竈');
ok($zip->set_number('8740012')->is_valid_number, '大分県別府市スパランド豊海');
ok($zip->set_number('8740013')->is_valid_number, '大分県別府市古市町');
ok($zip->set_number('8740014')->is_valid_number, '大分県別府市亀川浜田町');
ok($zip->set_number('8740015')->is_valid_number, '大分県別府市国立');
ok($zip->set_number('8740016')->is_valid_number, '大分県別府市野田');
ok($zip->set_number('8740021')->is_valid_number, '大分県別府市亀川中央町');
ok($zip->set_number('8740022')->is_valid_number, '大分県別府市亀川東町');
ok($zip->set_number('8740023')->is_valid_number, '大分県別府市上人ケ浜町');
ok($zip->set_number('8740024')->is_valid_number, '大分県別府市平田町');
ok($zip->set_number('8740025')->is_valid_number, '大分県別府市亀川四の湯町');
ok($zip->set_number('8740031')->is_valid_number, '大分県別府市照波園町');
ok($zip->set_number('8740032')->is_valid_number, '大分県別府市上人本町');
ok($zip->set_number('8740033')->is_valid_number, '大分県別府市上人南');
ok($zip->set_number('8740034')->is_valid_number, '大分県別府市上人仲町');
ok($zip->set_number('8740035')->is_valid_number, '大分県別府市上人西');
ok($zip->set_number('8740036')->is_valid_number, '大分県別府市上平田町');
ok($zip->set_number('8740037')->is_valid_number, '大分県別府市大観山町');
ok($zip->set_number('8740041')->is_valid_number, '大分県別府市北鉄輪');
ok($zip->set_number('8740042')->is_valid_number, '大分県別府市鉄輪東');
ok($zip->set_number('8740043')->is_valid_number, '大分県別府市井田');
ok($zip->set_number('8740044')->is_valid_number, '大分県別府市風呂本');
ok($zip->set_number('8740045')->is_valid_number, '大分県別府市御幸');
ok($zip->set_number('8740046')->is_valid_number, '大分県別府市鉄輪上');
ok($zip->set_number('8740801')->is_valid_number, '大分県別府市山の口');
ok($zip->set_number('8740802')->is_valid_number, '大分県別府市城島');
ok($zip->set_number('8740803')->is_valid_number, '大分県別府市東山一区');
ok($zip->set_number('8740804')->is_valid_number, '大分県別府市東山二区');
ok($zip->set_number('8740805')->is_valid_number, '大分県別府市枝郷');
ok($zip->set_number('8740811')->is_valid_number, '大分県別府市柳');
ok($zip->set_number('8740812')->is_valid_number, '大分県別府市朝見');
ok($zip->set_number('8740813')->is_valid_number, '大分県別府市両郡橋');
ok($zip->set_number('8740814')->is_valid_number, '大分県別府市浦田');
ok($zip->set_number('8740815')->is_valid_number, '大分県別府市田の口');
ok($zip->set_number('8740816')->is_valid_number, '大分県別府市河内');
ok($zip->set_number('8740817')->is_valid_number, '大分県別府市鳥越');
ok($zip->set_number('8740818')->is_valid_number, '大分県別府市山家');
ok($zip->set_number('8740819')->is_valid_number, '大分県別府市赤松');
ok($zip->set_number('8740820')->is_valid_number, '大分県別府市原町');
ok($zip->set_number('8740821')->is_valid_number, '大分県別府市乙原');
ok($zip->set_number('8740822')->is_valid_number, '大分県別府市観海寺');
ok($zip->set_number('8740823')->is_valid_number, '大分県別府市南立石本町');
ok($zip->set_number('8740824')->is_valid_number, '大分県別府市南立石板地町');
ok($zip->set_number('8740825')->is_valid_number, '大分県別府市南立石八幡町');
ok($zip->set_number('8740826')->is_valid_number, '大分県別府市鶴見園町');
ok($zip->set_number('8740827')->is_valid_number, '大分県別府市南立石二区');
ok($zip->set_number('8740828')->is_valid_number, '大分県別府市山の手町');
ok($zip->set_number('8740829')->is_valid_number, '大分県別府市上原町');
ok($zip->set_number('8740831')->is_valid_number, '大分県別府市堀田');
ok($zip->set_number('8740832')->is_valid_number, '大分県別府市南立石生目町');
ok($zip->set_number('8740833')->is_valid_number, '大分県別府市鶴見(1~18組)');
ok($zip->set_number('8740834')->is_valid_number, '大分県別府市新別府');
ok($zip->set_number('8740835')->is_valid_number, '大分県別府市実相寺');
ok($zip->set_number('8740836')->is_valid_number, '大分県別府市東荘園');
ok($zip->set_number('8740837')->is_valid_number, '大分県別府市荘園北町');
ok($zip->set_number('8740838')->is_valid_number, '大分県別府市荘園');
ok($zip->set_number('8740839')->is_valid_number, '大分県別府市南立石一区');
ok($zip->set_number('8740840')->is_valid_number, '大分県別府市鶴見(大字、番地)');
ok($zip->set_number('8740841')->is_valid_number, '大分県別府市竹の内');
ok($zip->set_number('8740842')->is_valid_number, '大分県別府市小倉');
ok($zip->set_number('8740843')->is_valid_number, '大分県別府市明礬');
ok($zip->set_number('8740844')->is_valid_number, '大分県別府市火売');
ok($zip->set_number('8740845')->is_valid_number, '大分県別府市北中');
ok($zip->set_number('8740846')->is_valid_number, '大分県別府市朝日ケ丘町');
ok($zip->set_number('8740847')->is_valid_number, '大分県別府市馬場');
ok($zip->set_number('8740848')->is_valid_number, '大分県別府市大畑');
ok($zip->set_number('8740849')->is_valid_number, '大分県別府市扇山');
ok($zip->set_number('8740901')->is_valid_number, '大分県別府市中島町');
ok($zip->set_number('8740902')->is_valid_number, '大分県別府市青山町');
ok($zip->set_number('8740903')->is_valid_number, '大分県別府市野口原');
ok($zip->set_number('8740904')->is_valid_number, '大分県別府市南荘園町');
ok($zip->set_number('8740905')->is_valid_number, '大分県別府市上野口町');
ok($zip->set_number('8740906')->is_valid_number, '大分県別府市天満町');
ok($zip->set_number('8740907')->is_valid_number, '大分県別府市幸町');
ok($zip->set_number('8740908')->is_valid_number, '大分県別府市上田の湯町');
ok($zip->set_number('8740909')->is_valid_number, '大分県別府市田の湯町');
ok($zip->set_number('8740910')->is_valid_number, '大分県別府市石垣西');
ok($zip->set_number('8740911')->is_valid_number, '大分県別府市緑丘町');
ok($zip->set_number('8740912')->is_valid_number, '大分県別府市南須賀');
ok($zip->set_number('8740913')->is_valid_number, '大分県別府市春木');
ok($zip->set_number('8740914')->is_valid_number, '大分県別府市中須賀元町');
ok($zip->set_number('8740915')->is_valid_number, '大分県別府市桜ケ丘');
ok($zip->set_number('8740916')->is_valid_number, '大分県別府市中須賀本町');
ok($zip->set_number('8740917')->is_valid_number, '大分県別府市中須賀東町');
ok($zip->set_number('8740918')->is_valid_number, '大分県別府市汐見町');
ok($zip->set_number('8740919')->is_valid_number, '大分県別府市石垣東');
ok($zip->set_number('8740920')->is_valid_number, '大分県別府市北浜');
ok($zip->set_number('8740921')->is_valid_number, '大分県別府市富士見町');
ok($zip->set_number('8740922')->is_valid_number, '大分県別府市船小路町');
ok($zip->set_number('8740923')->is_valid_number, '大分県別府市新港町');
ok($zip->set_number('8740924')->is_valid_number, '大分県別府市餅ケ浜町');
ok($zip->set_number('8740925')->is_valid_number, '大分県別府市若草町');
ok($zip->set_number('8740926')->is_valid_number, '大分県別府市京町');
ok($zip->set_number('8740927')->is_valid_number, '大分県別府市弓ケ浜町');
ok($zip->set_number('8740928')->is_valid_number, '大分県別府市北的ケ浜町');
ok($zip->set_number('8740929')->is_valid_number, '大分県別府市南的ケ浜町');
ok($zip->set_number('8740930')->is_valid_number, '大分県別府市光町');
ok($zip->set_number('8740931')->is_valid_number, '大分県別府市西野口町');
ok($zip->set_number('8740932')->is_valid_number, '大分県別府市野口中町');
ok($zip->set_number('8740933')->is_valid_number, '大分県別府市野口元町');
ok($zip->set_number('8740934')->is_valid_number, '大分県別府市駅前本町');
ok($zip->set_number('8740935')->is_valid_number, '大分県別府市駅前町');
ok($zip->set_number('8740936')->is_valid_number, '大分県別府市中央町');
ok($zip->set_number('8740937')->is_valid_number, '大分県別府市秋葉町');
ok($zip->set_number('8740938')->is_valid_number, '大分県別府市末広町');
ok($zip->set_number('8740939')->is_valid_number, '大分県別府市立田町');
ok($zip->set_number('8740941')->is_valid_number, '大分県別府市南町');
ok($zip->set_number('8740942')->is_valid_number, '大分県別府市千代町');
ok($zip->set_number('8740943')->is_valid_number, '大分県別府市楠町');
ok($zip->set_number('8740944')->is_valid_number, '大分県別府市元町');
ok($zip->set_number('8740945')->is_valid_number, '大分県別府市浜町');
ok($zip->set_number('8740946')->is_valid_number, '大分県別府市松原町');
ok($zip->set_number('8740947')->is_valid_number, '大分県別府市浜脇');
ok($zip->set_number('8750000')->is_valid_number, '大分県臼杵市以下に掲載がない場合');
ok($zip->set_number('8750001')->is_valid_number, '大分県臼杵市佐志生');
ok($zip->set_number('8750002')->is_valid_number, '大分県臼杵市下ノ江');
ok($zip->set_number('8750003')->is_valid_number, '大分県臼杵市田井');
ok($zip->set_number('8750004')->is_valid_number, '大分県臼杵市大野');
ok($zip->set_number('8750011')->is_valid_number, '大分県臼杵市諏訪');
ok($zip->set_number('8750012')->is_valid_number, '大分県臼杵市大浜');
ok($zip->set_number('8750013')->is_valid_number, '大分県臼杵市中津浦');
ok($zip->set_number('8750021')->is_valid_number, '大分県臼杵市田尻');
ok($zip->set_number('8750022')->is_valid_number, '大分県臼杵市末広');
ok($zip->set_number('8750023')->is_valid_number, '大分県臼杵市江無田');
ok($zip->set_number('8750031')->is_valid_number, '大分県臼杵市深江');
ok($zip->set_number('8750032')->is_valid_number, '大分県臼杵市風成');
ok($zip->set_number('8750033')->is_valid_number, '大分県臼杵市大泊');
ok($zip->set_number('8750034')->is_valid_number, '大分県臼杵市板知屋');
ok($zip->set_number('8750041')->is_valid_number, '大分県臼杵市臼杵');
ok($zip->set_number('8750042')->is_valid_number, '大分県臼杵市海添');
ok($zip->set_number('8750043')->is_valid_number, '大分県臼杵市二王座');
ok($zip->set_number('8750051')->is_valid_number, '大分県臼杵市戸室');
ok($zip->set_number('8750052')->is_valid_number, '大分県臼杵市市浜');
ok($zip->set_number('8750053')->is_valid_number, '大分県臼杵市福良');
ok($zip->set_number('8750061')->is_valid_number, '大分県臼杵市前田');
ok($zip->set_number('8750062')->is_valid_number, '大分県臼杵市野田');
ok($zip->set_number('8750063')->is_valid_number, '大分県臼杵市望月');
ok($zip->set_number('8750064')->is_valid_number, '大分県臼杵市深田');
ok($zip->set_number('8750065')->is_valid_number, '大分県臼杵市家野');
ok($zip->set_number('8750070')->is_valid_number, '大分県臼杵市久木小野');
ok($zip->set_number('8750071')->is_valid_number, '大分県臼杵市吉小野');
ok($zip->set_number('8750072')->is_valid_number, '大分県臼杵市中臼杵');
ok($zip->set_number('8750073')->is_valid_number, '大分県臼杵市掻懐');
ok($zip->set_number('8750074')->is_valid_number, '大分県臼杵市左津留');
ok($zip->set_number('8750075')->is_valid_number, '大分県臼杵市中尾');
ok($zip->set_number('8750076')->is_valid_number, '大分県臼杵市東神野');
ok($zip->set_number('8750077')->is_valid_number, '大分県臼杵市乙見');
ok($zip->set_number('8750078')->is_valid_number, '大分県臼杵市高山');
ok($zip->set_number('8750079')->is_valid_number, '大分県臼杵市武山');
ok($zip->set_number('8750081')->is_valid_number, '大分県臼杵市藤河内');
ok($zip->set_number('8750082')->is_valid_number, '大分県臼杵市稲田');
ok($zip->set_number('8750083')->is_valid_number, '大分県臼杵市井村');
ok($zip->set_number('8750084')->is_valid_number, '大分県臼杵市岳谷');
ok($zip->set_number('8750201')->is_valid_number, '大分県臼杵市野津町野津市');
ok($zip->set_number('8750202')->is_valid_number, '大分県臼杵市野津町山頭');
ok($zip->set_number('8750203')->is_valid_number, '大分県臼杵市野津町前河内');
ok($zip->set_number('8750211')->is_valid_number, '大分県臼杵市野津町都原');
ok($zip->set_number('8750212')->is_valid_number, '大分県臼杵市野津町老松');
ok($zip->set_number('8750213')->is_valid_number, '大分県臼杵市野津町八里合');
ok($zip->set_number('8750214')->is_valid_number, '大分県臼杵市野津町福良木');
ok($zip->set_number('8750215')->is_valid_number, '大分県臼杵市野津町王子');
ok($zip->set_number('8750216')->is_valid_number, '大分県臼杵市野津町亀甲');
ok($zip->set_number('8750221')->is_valid_number, '大分県臼杵市野津町秋山');
ok($zip->set_number('8750222')->is_valid_number, '大分県臼杵市野津町吉田');
ok($zip->set_number('8750223')->is_valid_number, '大分県臼杵市野津町東谷(その他)');
ok($zip->set_number('8750224')->is_valid_number, '大分県臼杵市野津町西畑');
ok($zip->set_number('8750231')->is_valid_number, '大分県臼杵市野津町千塚');
ok($zip->set_number('8750232')->is_valid_number, '大分県臼杵市野津町烏嶽');
ok($zip->set_number('8750233')->is_valid_number, '大分県臼杵市野津町宮原');
ok($zip->set_number('8750234')->is_valid_number, '大分県臼杵市野津町原');
ok($zip->set_number('8750235')->is_valid_number, '大分県臼杵市野津町藤小野');
ok($zip->set_number('8750236')->is_valid_number, '大分県臼杵市野津町柚野木');
ok($zip->set_number('8750237')->is_valid_number, '大分県臼杵市野津町西寒田');
ok($zip->set_number('8750323')->is_valid_number, '大分県臼杵市野津町東谷(三重谷)');
ok($zip->set_number('8750341')->is_valid_number, '大分県臼杵市野津町清水原');
ok($zip->set_number('8750342')->is_valid_number, '大分県臼杵市野津町落谷');
ok($zip->set_number('8750343')->is_valid_number, '大分県臼杵市野津町岩屋');
ok($zip->set_number('8750344')->is_valid_number, '大分県臼杵市野津町白岩');
ok($zip->set_number('8750351')->is_valid_number, '大分県臼杵市野津町泊');
ok($zip->set_number('8750352')->is_valid_number, '大分県臼杵市野津町垣河内');
ok($zip->set_number('8750353')->is_valid_number, '大分県臼杵市野津町西神野');
ok($zip->set_number('8760000')->is_valid_number, '大分県佐伯市以下に掲載がない場合');
ok($zip->set_number('8760001')->is_valid_number, '大分県佐伯市高松浦');
ok($zip->set_number('8760002')->is_valid_number, '大分県佐伯市日向泊浦');
ok($zip->set_number('8760003')->is_valid_number, '大分県佐伯市塩内浦');
ok($zip->set_number('8760004')->is_valid_number, '大分県佐伯市荒網代浦');
ok($zip->set_number('8760005')->is_valid_number, '大分県佐伯市石間浦');
ok($zip->set_number('8760006')->is_valid_number, '大分県佐伯市守後浦');
ok($zip->set_number('8760007')->is_valid_number, '大分県佐伯市久保浦');
ok($zip->set_number('8760008')->is_valid_number, '大分県佐伯市片神浦');
ok($zip->set_number('8760011')->is_valid_number, '大分県佐伯市坂の浦');
ok($zip->set_number('8760012')->is_valid_number, '大分県佐伯市鶴望');
ok($zip->set_number('8760013')->is_valid_number, '大分県佐伯市若宮町');
ok($zip->set_number('8760014')->is_valid_number, '大分県佐伯市白方');
ok($zip->set_number('8760015')->is_valid_number, '大分県佐伯市百谷');
ok($zip->set_number('8760016')->is_valid_number, '大分県佐伯市王子丸');
ok($zip->set_number('8760017')->is_valid_number, '大分県佐伯市野口');
ok($zip->set_number('8760018')->is_valid_number, '大分県佐伯市平');
ok($zip->set_number('8760021')->is_valid_number, '大分県佐伯市東灘');
ok($zip->set_number('8760022')->is_valid_number, '大分県佐伯市上灘');
ok($zip->set_number('8760023')->is_valid_number, '大分県佐伯市蛇崎');
ok($zip->set_number('8760024')->is_valid_number, '大分県佐伯市下久部');
ok($zip->set_number('8760025')->is_valid_number, '大分県佐伯市池田');
ok($zip->set_number('8760026')->is_valid_number, '大分県佐伯市匠南');
ok($zip->set_number('8760027')->is_valid_number, '大分県佐伯市上久部');
ok($zip->set_number('8760031')->is_valid_number, '大分県佐伯市川原');
ok($zip->set_number('8760032')->is_valid_number, '大分県佐伯市中山');
ok($zip->set_number('8760033')->is_valid_number, '大分県佐伯市下城');
ok($zip->set_number('8760034')->is_valid_number, '大分県佐伯市上城');
ok($zip->set_number('8760035')->is_valid_number, '大分県佐伯市岸河内');
ok($zip->set_number('8760036')->is_valid_number, '大分県佐伯市大越');
ok($zip->set_number('8760037')->is_valid_number, '大分県佐伯市長谷');
ok($zip->set_number('8760041')->is_valid_number, '大分県佐伯市長瀬');
ok($zip->set_number('8760042')->is_valid_number, '大分県佐伯市稲垣');
ok($zip->set_number('8760043')->is_valid_number, '大分県佐伯市樫野');
ok($zip->set_number('8760044')->is_valid_number, '大分県佐伯市高畠');
ok($zip->set_number('8760045')->is_valid_number, '大分県佐伯市上岡');
ok($zip->set_number('8760046')->is_valid_number, '大分県佐伯市脇');
ok($zip->set_number('8760047')->is_valid_number, '大分県佐伯市鶴岡西町');
ok($zip->set_number('8760051')->is_valid_number, '大分県佐伯市寺田');
ok($zip->set_number('8760052')->is_valid_number, '大分県佐伯市坂山');
ok($zip->set_number('8760053')->is_valid_number, '大分県佐伯市高畑');
ok($zip->set_number('8760061')->is_valid_number, '大分県佐伯市門前');
ok($zip->set_number('8760062')->is_valid_number, '大分県佐伯市古市');
ok($zip->set_number('8760063')->is_valid_number, '大分県佐伯市城西区');
ok($zip->set_number('8760064')->is_valid_number, '大分県佐伯市八迫区');
ok($zip->set_number('8760101')->is_valid_number, '大分県佐伯市弥生大坂本');
ok($zip->set_number('8760102')->is_valid_number, '大分県佐伯市弥生尺間');
ok($zip->set_number('8760103')->is_valid_number, '大分県佐伯市弥生床木');
ok($zip->set_number('8760111')->is_valid_number, '大分県佐伯市弥生井崎');
ok($zip->set_number('8760112')->is_valid_number, '大分県佐伯市弥生上小倉');
ok($zip->set_number('8760113')->is_valid_number, '大分県佐伯市弥生山梨子');
ok($zip->set_number('8760121')->is_valid_number, '大分県佐伯市弥生小田');
ok($zip->set_number('8760122')->is_valid_number, '大分県佐伯市弥生門田');
ok($zip->set_number('8760123')->is_valid_number, '大分県佐伯市弥生平井');
ok($zip->set_number('8760124')->is_valid_number, '大分県佐伯市弥生細田');
ok($zip->set_number('8760125')->is_valid_number, '大分県佐伯市弥生江良');
ok($zip->set_number('8760126')->is_valid_number, '大分県佐伯市弥生提内');
ok($zip->set_number('8760201')->is_valid_number, '大分県佐伯市本匠風戸');
ok($zip->set_number('8760202')->is_valid_number, '大分県佐伯市本匠笠掛');
ok($zip->set_number('8760203')->is_valid_number, '大分県佐伯市本匠三股');
ok($zip->set_number('8760204')->is_valid_number, '大分県佐伯市本匠宇津々');
ok($zip->set_number('8760205')->is_valid_number, '大分県佐伯市本匠波寄');
ok($zip->set_number('8760206')->is_valid_number, '大分県佐伯市本匠小川');
ok($zip->set_number('8760211')->is_valid_number, '大分県佐伯市本匠井ノ上');
ok($zip->set_number('8760212')->is_valid_number, '大分県佐伯市本匠因尾');
ok($zip->set_number('8760213')->is_valid_number, '大分県佐伯市本匠堂ノ間');
ok($zip->set_number('8760214')->is_valid_number, '大分県佐伯市本匠上津川');
ok($zip->set_number('8760215')->is_valid_number, '大分県佐伯市本匠小半');
ok($zip->set_number('8760216')->is_valid_number, '大分県佐伯市本匠山部');
ok($zip->set_number('8760801')->is_valid_number, '大分県佐伯市葛港');
ok($zip->set_number('8760802')->is_valid_number, '大分県佐伯市日の出町');
ok($zip->set_number('8760803')->is_valid_number, '大分県佐伯市駅前');
ok($zip->set_number('8760804')->is_valid_number, '大分県佐伯市蟹田');
ok($zip->set_number('8760805')->is_valid_number, '大分県佐伯市平野町');
ok($zip->set_number('8760806')->is_valid_number, '大分県佐伯市春日町');
ok($zip->set_number('8760807')->is_valid_number, '大分県佐伯市田の浦町');
ok($zip->set_number('8760811')->is_valid_number, '大分県佐伯市鶴谷町');
ok($zip->set_number('8760812')->is_valid_number, '大分県佐伯市中江町');
ok($zip->set_number('8760813')->is_valid_number, '大分県佐伯市長島町');
ok($zip->set_number('8760814')->is_valid_number, '大分県佐伯市東町');
ok($zip->set_number('8760815')->is_valid_number, '大分県佐伯市野岡町');
ok($zip->set_number('8760821')->is_valid_number, '大分県佐伯市東浜');
ok($zip->set_number('8760822')->is_valid_number, '大分県佐伯市西浜');
ok($zip->set_number('8760823')->is_valid_number, '大分県佐伯市女島');
ok($zip->set_number('8760824')->is_valid_number, '大分県佐伯市新女島');
ok($zip->set_number('8760825')->is_valid_number, '大分県佐伯市女島団地');
ok($zip->set_number('8760831')->is_valid_number, '大分県佐伯市大手町');
ok($zip->set_number('8760832')->is_valid_number, '大分県佐伯市船頭町');
ok($zip->set_number('8760833')->is_valid_number, '大分県佐伯市池船町');
ok($zip->set_number('8760834')->is_valid_number, '大分県佐伯市城南町');
ok($zip->set_number('8760835')->is_valid_number, '大分県佐伯市鶴岡町');
ok($zip->set_number('8760836')->is_valid_number, '大分県佐伯市西谷町');
ok($zip->set_number('8760841')->is_valid_number, '大分県佐伯市来島町');
ok($zip->set_number('8760842')->is_valid_number, '大分県佐伯市中ノ島東町');
ok($zip->set_number('8760843')->is_valid_number, '大分県佐伯市中の島');
ok($zip->set_number('8760844')->is_valid_number, '大分県佐伯市向島');
ok($zip->set_number('8760845')->is_valid_number, '大分県佐伯市内町');
ok($zip->set_number('8760846')->is_valid_number, '大分県佐伯市城東町');
ok($zip->set_number('8760847')->is_valid_number, '大分県佐伯市城下西町');
ok($zip->set_number('8760848')->is_valid_number, '大分県佐伯市城下東町');
ok($zip->set_number('8760849')->is_valid_number, '大分県佐伯市臼坪');
ok($zip->set_number('8760851')->is_valid_number, '大分県佐伯市常盤東町');
ok($zip->set_number('8760852')->is_valid_number, '大分県佐伯市常盤南町');
ok($zip->set_number('8760853')->is_valid_number, '大分県佐伯市中村東町');
ok($zip->set_number('8760854')->is_valid_number, '大分県佐伯市中村南町');
ok($zip->set_number('8760855')->is_valid_number, '大分県佐伯市中村西町');
ok($zip->set_number('8760856')->is_valid_number, '大分県佐伯市中村北町');
ok($zip->set_number('8760857')->is_valid_number, '大分県佐伯市常盤西町');
ok($zip->set_number('8761101')->is_valid_number, '大分県佐伯市狩生');
ok($zip->set_number('8761102')->is_valid_number, '大分県佐伯市二栄');
ok($zip->set_number('8761103')->is_valid_number, '大分県佐伯市護江');
ok($zip->set_number('8761104')->is_valid_number, '大分県佐伯市霞ケ浦');
ok($zip->set_number('8761105')->is_valid_number, '大分県佐伯市海崎');
ok($zip->set_number('8761106')->is_valid_number, '大分県佐伯市戸穴');
ok($zip->set_number('8761201')->is_valid_number, '大分県佐伯市鶴見吹浦');
ok($zip->set_number('8761202')->is_valid_number, '大分県佐伯市鶴見地松浦');
ok($zip->set_number('8761203')->is_valid_number, '大分県佐伯市鶴見沖松浦');
ok($zip->set_number('8761204')->is_valid_number, '大分県佐伯市鶴見有明浦');
ok($zip->set_number('8761205')->is_valid_number, '大分県佐伯市鶴見羽出浦');
ok($zip->set_number('8761206')->is_valid_number, '大分県佐伯市鶴見中越浦(その他)');
ok($zip->set_number('8761301')->is_valid_number, '大分県佐伯市米水津浦代浦(間越、芳ケ浦)');
ok($zip->set_number('8761306')->is_valid_number, '大分県佐伯市鶴見中越浦(猿戸、広浦)');
ok($zip->set_number('8761311')->is_valid_number, '大分県佐伯市鶴見丹賀浦');
ok($zip->set_number('8761312')->is_valid_number, '大分県佐伯市鶴見梶寄浦');
ok($zip->set_number('8761313')->is_valid_number, '大分県佐伯市鶴見大島');
ok($zip->set_number('8761401')->is_valid_number, '大分県佐伯市米水津浦代浦(その他)');
ok($zip->set_number('8761402')->is_valid_number, '大分県佐伯市米水津色利浦');
ok($zip->set_number('8761403')->is_valid_number, '大分県佐伯市米水津宮野浦');
ok($zip->set_number('8761404')->is_valid_number, '大分県佐伯市米水津小浦');
ok($zip->set_number('8761405')->is_valid_number, '大分県佐伯市米水津竹野浦');
ok($zip->set_number('8761511')->is_valid_number, '大分県佐伯市長良');
ok($zip->set_number('8761512')->is_valid_number, '大分県佐伯市堅田');
ok($zip->set_number('8761513')->is_valid_number, '大分県佐伯市青山');
ok($zip->set_number('8762121')->is_valid_number, '大分県佐伯市木立');
ok($zip->set_number('8762201')->is_valid_number, '大分県佐伯市蒲江畑野浦');
ok($zip->set_number('8762202')->is_valid_number, '大分県佐伯市蒲江尾浦');
ok($zip->set_number('8762203')->is_valid_number, '大分県佐伯市蒲江楠本浦');
ok($zip->set_number('8762301')->is_valid_number, '大分県佐伯市蒲江竹野浦河内');
ok($zip->set_number('8762302')->is_valid_number, '大分県佐伯市蒲江西野浦');
ok($zip->set_number('8762401')->is_valid_number, '大分県佐伯市蒲江蒲江浦');
ok($zip->set_number('8762402')->is_valid_number, '大分県佐伯市蒲江猪串浦');
ok($zip->set_number('8762403')->is_valid_number, '大分県佐伯市蒲江野々河内浦');
ok($zip->set_number('8762404')->is_valid_number, '大分県佐伯市蒲江森崎浦');
ok($zip->set_number('8762405')->is_valid_number, '大分県佐伯市蒲江丸市尾浦');
ok($zip->set_number('8762406')->is_valid_number, '大分県佐伯市蒲江葛原浦');
ok($zip->set_number('8762407')->is_valid_number, '大分県佐伯市蒲江波当津浦');
ok($zip->set_number('8770000')->is_valid_number, '大分県日田市以下に掲載がない場合');
ok($zip->set_number('8770001')->is_valid_number, '大分県日田市秋山町');
ok($zip->set_number('8770002')->is_valid_number, '大分県日田市城内新町');
ok($zip->set_number('8770003')->is_valid_number, '大分県日田市上城内町');
ok($zip->set_number('8770004')->is_valid_number, '大分県日田市城町');
ok($zip->set_number('8770005')->is_valid_number, '大分県日田市豆田町');
ok($zip->set_number('8770006')->is_valid_number, '大分県日田市港町');
ok($zip->set_number('8770007')->is_valid_number, '大分県日田市丸の内町');
ok($zip->set_number('8770008')->is_valid_number, '大分県日田市丸山');
ok($zip->set_number('8770011')->is_valid_number, '大分県日田市中城町');
ok($zip->set_number('8770012')->is_valid_number, '大分県日田市淡窓');
ok($zip->set_number('8770013')->is_valid_number, '大分県日田市元町');
ok($zip->set_number('8770014')->is_valid_number, '大分県日田市本町');
ok($zip->set_number('8770015')->is_valid_number, '大分県日田市中央');
ok($zip->set_number('8770016')->is_valid_number, '大分県日田市三本松');
ok($zip->set_number('8770017')->is_valid_number, '大分県日田市三本松新町');
ok($zip->set_number('8770021')->is_valid_number, '大分県日田市求町');
ok($zip->set_number('8770022')->is_valid_number, '大分県日田市神来町');
ok($zip->set_number('8770023')->is_valid_number, '大分県日田市田島(大字)');
ok($zip->set_number('8770024')->is_valid_number, '大分県日田市南元町');
ok($zip->set_number('8770025')->is_valid_number, '大分県日田市田島(丁目)');
ok($zip->set_number('8770026')->is_valid_number, '大分県日田市田島本町');
ok($zip->set_number('8770031')->is_valid_number, '大分県日田市古金町');
ok($zip->set_number('8770032')->is_valid_number, '大分県日田市小ケ瀬町');
ok($zip->set_number('8770033')->is_valid_number, '大分県日田市大部町');
ok($zip->set_number('8770034')->is_valid_number, '大分県日田市桃山町');
ok($zip->set_number('8770035')->is_valid_number, '大分県日田市日高町');
ok($zip->set_number('8770036')->is_valid_number, '大分県日田市三芳小渕町');
ok($zip->set_number('8770037')->is_valid_number, '大分県日田市若宮町');
ok($zip->set_number('8770038')->is_valid_number, '大分県日田市下井手町');
ok($zip->set_number('8770039')->is_valid_number, '大分県日田市刃連町');
ok($zip->set_number('8770041')->is_valid_number, '大分県日田市竹田新町');
ok($zip->set_number('8770042')->is_valid_number, '大分県日田市東町');
ok($zip->set_number('8770043')->is_valid_number, '大分県日田市川原町');
ok($zip->set_number('8770044')->is_valid_number, '大分県日田市隈');
ok($zip->set_number('8770045')->is_valid_number, '大分県日田市亀山町');
ok($zip->set_number('8770046')->is_valid_number, '大分県日田市本庄町');
ok($zip->set_number('8770047')->is_valid_number, '大分県日田市中本町');
ok($zip->set_number('8770051')->is_valid_number, '大分県日田市京町');
ok($zip->set_number('8770052')->is_valid_number, '大分県日田市銭渕町');
ok($zip->set_number('8770053')->is_valid_number, '大分県日田市高瀬本町');
ok($zip->set_number('8770054')->is_valid_number, '大分県日田市琴平町');
ok($zip->set_number('8770055')->is_valid_number, '大分県日田市大宮町');
ok($zip->set_number('8770056')->is_valid_number, '大分県日田市誠和町');
ok($zip->set_number('8770057')->is_valid_number, '大分県日田市八幡町');
ok($zip->set_number('8770058')->is_valid_number, '大分県日田市南部町');
ok($zip->set_number('8770059')->is_valid_number, '大分県日田市大日町');
ok($zip->set_number('8770061')->is_valid_number, '大分県日田市石井');
ok($zip->set_number('8770062')->is_valid_number, '大分県日田市上野町');
ok($zip->set_number('8770063')->is_valid_number, '大分県日田市串川町');
ok($zip->set_number('8770064')->is_valid_number, '大分県日田市小山町');
ok($zip->set_number('8770065')->is_valid_number, '大分県日田市緑町');
ok($zip->set_number('8770066')->is_valid_number, '大分県日田市川下');
ok($zip->set_number('8770067')->is_valid_number, '大分県日田市高井町');
ok($zip->set_number('8770068')->is_valid_number, '大分県日田市内河町');
ok($zip->set_number('8770071')->is_valid_number, '大分県日田市玉川町');
ok($zip->set_number('8770072')->is_valid_number, '大分県日田市新治町');
ok($zip->set_number('8770073')->is_valid_number, '大分県日田市日ノ隈町');
ok($zip->set_number('8770074')->is_valid_number, '大分県日田市中ノ島町');
ok($zip->set_number('8770075')->is_valid_number, '大分県日田市中釣町');
ok($zip->set_number('8770076')->is_valid_number, '大分県日田市亀川町');
ok($zip->set_number('8770077')->is_valid_number, '大分県日田市南友田町');
ok($zip->set_number('8770078')->is_valid_number, '大分県日田市北友田');
ok($zip->set_number('8770081')->is_valid_number, '大分県日田市清岸寺町');
ok($zip->set_number('8770082')->is_valid_number, '大分県日田市日ノ出町');
ok($zip->set_number('8770083')->is_valid_number, '大分県日田市吹上町');
ok($zip->set_number('8770084')->is_valid_number, '大分県日田市朝日ケ丘');
ok($zip->set_number('8770085')->is_valid_number, '大分県日田市朝日町');
ok($zip->set_number('8770086')->is_valid_number, '大分県日田市二串町');
ok($zip->set_number('8770087')->is_valid_number, '大分県日田市君迫町');
ok($zip->set_number('8770088')->is_valid_number, '大分県日田市小迫町');
ok($zip->set_number('8770089')->is_valid_number, '大分県日田市山田町');
ok($zip->set_number('8770111')->is_valid_number, '大分県日田市天瀬町五馬市');
ok($zip->set_number('8770112')->is_valid_number, '大分県日田市天瀬町本城');
ok($zip->set_number('8770113')->is_valid_number, '大分県日田市天瀬町塚田');
ok($zip->set_number('8770114')->is_valid_number, '大分県日田市天瀬町出口');
ok($zip->set_number('8770201')->is_valid_number, '大分県日田市大山町西大山');
ok($zip->set_number('8770202')->is_valid_number, '大分県日田市大山町東大山');
ok($zip->set_number('8770211')->is_valid_number, '大分県日田市前津江町赤石');
ok($zip->set_number('8770212')->is_valid_number, '大分県日田市前津江町大野');
ok($zip->set_number('8770221')->is_valid_number, '大分県日田市前津江町柚木(その他)');
ok($zip->set_number('8770301')->is_valid_number, '大分県日田市中津江村栃野');
ok($zip->set_number('8770302')->is_valid_number, '大分県日田市中津江村合瀬');
ok($zip->set_number('8770311')->is_valid_number, '大分県日田市上津江町川原');
ok($zip->set_number('8770312')->is_valid_number, '大分県日田市上津江町上野田');
ok($zip->set_number('8771101')->is_valid_number, '大分県日田市鶴城町');
ok($zip->set_number('8771102')->is_valid_number, '大分県日田市上宮町');
ok($zip->set_number('8771103')->is_valid_number, '大分県日田市鶴河内町');
ok($zip->set_number('8771104')->is_valid_number, '大分県日田市大鶴本町');
ok($zip->set_number('8771105')->is_valid_number, '大分県日田市大肥町');
ok($zip->set_number('8771106')->is_valid_number, '大分県日田市大肥本町');
ok($zip->set_number('8771107')->is_valid_number, '大分県日田市大鶴町');
ok($zip->set_number('8771111')->is_valid_number, '大分県日田市夜明上町');
ok($zip->set_number('8771112')->is_valid_number, '大分県日田市夜明中町');
ok($zip->set_number('8771113')->is_valid_number, '大分県日田市夜明関町');
ok($zip->set_number('8771121')->is_valid_number, '大分県日田市源栄町(池ノ鶴、皿山)');
ok($zip->set_number('8771221')->is_valid_number, '大分県日田市伏木町');
ok($zip->set_number('8771222')->is_valid_number, '大分県日田市小河内町');
ok($zip->set_number('8771223')->is_valid_number, '大分県日田市市ノ瀬町');
ok($zip->set_number('8771224')->is_valid_number, '大分県日田市秋原町');
ok($zip->set_number('8771225')->is_valid_number, '大分県日田市藤山町');
ok($zip->set_number('8771231')->is_valid_number, '大分県日田市財津町');
ok($zip->set_number('8771232')->is_valid_number, '大分県日田市清水町');
ok($zip->set_number('8771233')->is_valid_number, '大分県日田市三和団地');
ok($zip->set_number('8771234')->is_valid_number, '大分県日田市天神町');
ok($zip->set_number('8771241')->is_valid_number, '大分県日田市源栄町(その他)');
ok($zip->set_number('8771242')->is_valid_number, '大分県日田市殿町');
ok($zip->set_number('8771243')->is_valid_number, '大分県日田市鈴連町');
ok($zip->set_number('8771244')->is_valid_number, '大分県日田市三河町');
ok($zip->set_number('8771351')->is_valid_number, '大分県日田市三ノ宮町');
ok($zip->set_number('8771352')->is_valid_number, '大分県日田市石松町');
ok($zip->set_number('8771353')->is_valid_number, '大分県日田市上手町');
ok($zip->set_number('8771354')->is_valid_number, '大分県日田市坂井町');
ok($zip->set_number('8771361')->is_valid_number, '大分県日田市有田町');
ok($zip->set_number('8771362')->is_valid_number, '大分県日田市尾当町');
ok($zip->set_number('8771363')->is_valid_number, '大分県日田市中尾町');
ok($zip->set_number('8771364')->is_valid_number, '大分県日田市三池町');
ok($zip->set_number('8771365')->is_valid_number, '大分県日田市水目町');
ok($zip->set_number('8771366')->is_valid_number, '大分県日田市あやめ台');
ok($zip->set_number('8771371')->is_valid_number, '大分県日田市諸留町');
ok($zip->set_number('8771372')->is_valid_number, '大分県日田市上諸留町');
ok($zip->set_number('8771373')->is_valid_number, '大分県日田市月出町');
ok($zip->set_number('8771374')->is_valid_number, '大分県日田市松野町');
ok($zip->set_number('8771375')->is_valid_number, '大分県日田市池辺町');
ok($zip->set_number('8771381')->is_valid_number, '大分県日田市東羽田町');
ok($zip->set_number('8771382')->is_valid_number, '大分県日田市日の本町');
ok($zip->set_number('8771383')->is_valid_number, '大分県日田市岩美町');
ok($zip->set_number('8771384')->is_valid_number, '大分県日田市羽田町');
ok($zip->set_number('8780000')->is_valid_number, '大分県竹田市以下に掲載がない場合');
ok($zip->set_number('8780001')->is_valid_number, '大分県竹田市植木');
ok($zip->set_number('8780002')->is_valid_number, '大分県竹田市枝');
ok($zip->set_number('8780003')->is_valid_number, '大分県竹田市片ケ瀬');
ok($zip->set_number('8780004')->is_valid_number, '大分県竹田市中');
ok($zip->set_number('8780005')->is_valid_number, '大分県竹田市挾田');
ok($zip->set_number('8780006')->is_valid_number, '大分県竹田市平田');
ok($zip->set_number('8780007')->is_valid_number, '大分県竹田市三宅');
ok($zip->set_number('8780011')->is_valid_number, '大分県竹田市会々');
ok($zip->set_number('8780012')->is_valid_number, '大分県竹田市竹田町');
ok($zip->set_number('8780013')->is_valid_number, '大分県竹田市竹田');
ok($zip->set_number('8780021')->is_valid_number, '大分県竹田市穴井迫');
ok($zip->set_number('8780022')->is_valid_number, '大分県竹田市岩瀬');
ok($zip->set_number('8780023')->is_valid_number, '大分県竹田市君ケ園');
ok($zip->set_number('8780024')->is_valid_number, '大分県竹田市玉来');
ok($zip->set_number('8780025')->is_valid_number, '大分県竹田市拝田原');
ok($zip->set_number('8780026')->is_valid_number, '大分県竹田市飛田川');
ok($zip->set_number('8780027')->is_valid_number, '大分県竹田市向山田');
ok($zip->set_number('8780028')->is_valid_number, '大分県竹田市渡瀬');
ok($zip->set_number('8780031')->is_valid_number, '大分県竹田市岩本');
ok($zip->set_number('8780032')->is_valid_number, '大分県竹田市太田');
ok($zip->set_number('8780033')->is_valid_number, '大分県竹田市入田');
ok($zip->set_number('8780034')->is_valid_number, '大分県竹田市門田');
ok($zip->set_number('8780035')->is_valid_number, '大分県竹田市吉田');
ok($zip->set_number('8780141')->is_valid_number, '大分県竹田市小川');
ok($zip->set_number('8780142')->is_valid_number, '大分県竹田市福原');
ok($zip->set_number('8780143')->is_valid_number, '大分県竹田市城原');
ok($zip->set_number('8780144')->is_valid_number, '大分県竹田市高伏');
ok($zip->set_number('8780145')->is_valid_number, '大分県竹田市米納');
ok($zip->set_number('8780146')->is_valid_number, '大分県竹田市古園');
ok($zip->set_number('8780151')->is_valid_number, '大分県竹田市下坂田');
ok($zip->set_number('8780152')->is_valid_number, '大分県竹田市下志土知');
ok($zip->set_number('8780153')->is_valid_number, '大分県竹田市市用');
ok($zip->set_number('8780154')->is_valid_number, '大分県竹田市川床');
ok($zip->set_number('8780155')->is_valid_number, '大分県竹田市志土知');
ok($zip->set_number('8780156')->is_valid_number, '大分県竹田市久保(その他)');
ok($zip->set_number('8780161')->is_valid_number, '大分県竹田市上坂田');
ok($zip->set_number('8780162')->is_valid_number, '大分県竹田市炭竈');
ok($zip->set_number('8780163')->is_valid_number, '大分県竹田市上畑');
ok($zip->set_number('8780164')->is_valid_number, '大分県竹田市刈小野');
ok($zip->set_number('8780201')->is_valid_number, '大分県竹田市久住町久住');
ok($zip->set_number('8780202')->is_valid_number, '大分県竹田市久住町有氏');
ok($zip->set_number('8780203')->is_valid_number, '大分県竹田市久住町仏原');
ok($zip->set_number('8780204')->is_valid_number, '大分県竹田市久住町栢木');
ok($zip->set_number('8780205')->is_valid_number, '大分県竹田市久住町白丹');
ok($zip->set_number('8780206')->is_valid_number, '大分県竹田市久住町添ケ津留');
ok($zip->set_number('8780256')->is_valid_number, '大分県竹田市久保(1449番地)');
ok($zip->set_number('8780401')->is_valid_number, '大分県竹田市直入町神堤');
ok($zip->set_number('8780402')->is_valid_number, '大分県竹田市直入町長湯');
ok($zip->set_number('8780403')->is_valid_number, '大分県竹田市直入町上田北');
ok($zip->set_number('8780404')->is_valid_number, '大分県竹田市直入町下田北');
ok($zip->set_number('8780571')->is_valid_number, '大分県竹田市次倉');
ok($zip->set_number('8780572')->is_valid_number, '大分県竹田市九重野');
ok($zip->set_number('8780573')->is_valid_number, '大分県竹田市中角');
ok($zip->set_number('8780574')->is_valid_number, '大分県竹田市神原');
ok($zip->set_number('8780575')->is_valid_number, '大分県竹田市田井');
ok($zip->set_number('8780576')->is_valid_number, '大分県竹田市倉木');
ok($zip->set_number('8790101')->is_valid_number, '大分県中津市今津');
ok($zip->set_number('8790102')->is_valid_number, '大分県中津市鍋島');
ok($zip->set_number('8790103')->is_valid_number, '大分県中津市植野');
ok($zip->set_number('8790104')->is_valid_number, '大分県中津市野依');
ok($zip->set_number('8790105')->is_valid_number, '大分県中津市犬丸');
ok($zip->set_number('8790106')->is_valid_number, '大分県中津市赤迫');
ok($zip->set_number('8790107')->is_valid_number, '大分県中津市昭和新田');
ok($zip->set_number('8790111')->is_valid_number, '大分県中津市伊藤田');
ok($zip->set_number('8790112')->is_valid_number, '大分県中津市福島');
ok($zip->set_number('8790113')->is_valid_number, '大分県中津市北原');
ok($zip->set_number('8790121')->is_valid_number, '大分県中津市諸田');
ok($zip->set_number('8790122')->is_valid_number, '大分県中津市定留');
ok($zip->set_number('8790123')->is_valid_number, '大分県中津市田尻');
ok($zip->set_number('8790124')->is_valid_number, '大分県中津市田尻崎');
ok($zip->set_number('8790151')->is_valid_number, '大分県宇佐市宮熊');
ok($zip->set_number('8790152')->is_valid_number, '大分県宇佐市下庄');
ok($zip->set_number('8790153')->is_valid_number, '大分県宇佐市上庄');
ok($zip->set_number('8790161')->is_valid_number, '大分県宇佐市下敷田');
ok($zip->set_number('8790162')->is_valid_number, '大分県宇佐市中敷田');
ok($zip->set_number('8790163')->is_valid_number, '大分県宇佐市上敷田');
ok($zip->set_number('8790164')->is_valid_number, '大分県宇佐市富山');
ok($zip->set_number('8790221')->is_valid_number, '大分県中津市三光上秣');
ok($zip->set_number('8790222')->is_valid_number, '大分県中津市三光西秣');
ok($zip->set_number('8790223')->is_valid_number, '大分県中津市三光下秣');
ok($zip->set_number('8790224')->is_valid_number, '大分県中津市三光下深水');
ok($zip->set_number('8790225')->is_valid_number, '大分県中津市三光上深水');
ok($zip->set_number('8790231')->is_valid_number, '大分県宇佐市南敷田');
ok($zip->set_number('8790232')->is_valid_number, '大分県宇佐市大根川');
ok($zip->set_number('8790233')->is_valid_number, '大分県宇佐市赤尾');
ok($zip->set_number('8790234')->is_valid_number, '大分県宇佐市今仁');
ok($zip->set_number('8790235')->is_valid_number, '大分県宇佐市木部');
ok($zip->set_number('8790236')->is_valid_number, '大分県宇佐市清水');
ok($zip->set_number('8790237')->is_valid_number, '大分県宇佐市佐野');
ok($zip->set_number('8790301')->is_valid_number, '大分県宇佐市乙女新田');
ok($zip->set_number('8790302')->is_valid_number, '大分県宇佐市下乙女');
ok($zip->set_number('8790303')->is_valid_number, '大分県宇佐市上乙女');
ok($zip->set_number('8790304')->is_valid_number, '大分県宇佐市尾永井');
ok($zip->set_number('8790305')->is_valid_number, '大分県宇佐市上高家');
ok($zip->set_number('8790306')->is_valid_number, '大分県宇佐市西高家');
ok($zip->set_number('8790307')->is_valid_number, '大分県宇佐市浜高家');
ok($zip->set_number('8790308')->is_valid_number, '大分県宇佐市下高家');
ok($zip->set_number('8790309')->is_valid_number, '大分県宇佐市東高家');
ok($zip->set_number('8790311')->is_valid_number, '大分県宇佐市森山');
ok($zip->set_number('8790312')->is_valid_number, '大分県宇佐市荒木');
ok($zip->set_number('8790313')->is_valid_number, '大分県宇佐市上高');
ok($zip->set_number('8790314')->is_valid_number, '大分県宇佐市猿渡');
ok($zip->set_number('8790315')->is_valid_number, '大分県宇佐市上時枝');
ok($zip->set_number('8790316')->is_valid_number, '大分県宇佐市下時枝');
ok($zip->set_number('8790317')->is_valid_number, '大分県宇佐市下高');
ok($zip->set_number('8790441')->is_valid_number, '大分県宇佐市吉松');
ok($zip->set_number('8790442')->is_valid_number, '大分県宇佐市城井');
ok($zip->set_number('8790443')->is_valid_number, '大分県宇佐市葛原');
ok($zip->set_number('8790444')->is_valid_number, '大分県宇佐市石田');
ok($zip->set_number('8790451')->is_valid_number, '大分県宇佐市畑田');
ok($zip->set_number('8790452')->is_valid_number, '大分県宇佐市川部');
ok($zip->set_number('8790453')->is_valid_number, '大分県宇佐市上田');
ok($zip->set_number('8790454')->is_valid_number, '大分県宇佐市法鏡寺');
ok($zip->set_number('8790455')->is_valid_number, '大分県宇佐市閤');
ok($zip->set_number('8790456')->is_valid_number, '大分県宇佐市辛島');
ok($zip->set_number('8790457')->is_valid_number, '大分県宇佐市芝原');
ok($zip->set_number('8790461')->is_valid_number, '大分県宇佐市樋田');
ok($zip->set_number('8790462')->is_valid_number, '大分県宇佐市別府');
ok($zip->set_number('8790463')->is_valid_number, '大分県宇佐市中原');
ok($zip->set_number('8790464')->is_valid_number, '大分県宇佐市大塚');
ok($zip->set_number('8790465')->is_valid_number, '大分県宇佐市下拝田');
ok($zip->set_number('8790466')->is_valid_number, '大分県宇佐市上拝田(その他)');
ok($zip->set_number('8790467')->is_valid_number, '大分県宇佐市山本');
ok($zip->set_number('8790471')->is_valid_number, '大分県宇佐市四日市');
ok($zip->set_number('8790472')->is_valid_number, '大分県宇佐市上元重');
ok($zip->set_number('8790473')->is_valid_number, '大分県宇佐市下元重');
ok($zip->set_number('8790474')->is_valid_number, '大分県宇佐市山下');
ok($zip->set_number('8790501')->is_valid_number, '大分県宇佐市麻生');
ok($zip->set_number('8790502')->is_valid_number, '大分県宇佐市岳ノ首');
ok($zip->set_number('8790503')->is_valid_number, '大分県宇佐市灘');
ok($zip->set_number('8790504')->is_valid_number, '大分県宇佐市山口');
ok($zip->set_number('8790511')->is_valid_number, '大分県宇佐市山袋');
ok($zip->set_number('8790512')->is_valid_number, '大分県宇佐市黒');
ok($zip->set_number('8790513')->is_valid_number, '大分県宇佐市中');
ok($zip->set_number('8790514')->is_valid_number, '大分県宇佐市今成');
ok($zip->set_number('8790515')->is_valid_number, '大分県宇佐市末');
ok($zip->set_number('8790516')->is_valid_number, '大分県宇佐市木内');
ok($zip->set_number('8790600')->is_valid_number, '大分県豊後高田市以下に掲載がない場合');
ok($zip->set_number('8790601')->is_valid_number, '大分県豊後高田市草地');
ok($zip->set_number('8790602')->is_valid_number, '大分県豊後高田市払田');
ok($zip->set_number('8790603')->is_valid_number, '大分県豊後高田市鼎');
ok($zip->set_number('8790604')->is_valid_number, '大分県豊後高田市美和');
ok($zip->set_number('8790605')->is_valid_number, '大分県豊後高田市御玉');
ok($zip->set_number('8790606')->is_valid_number, '大分県豊後高田市玉津');
ok($zip->set_number('8790607')->is_valid_number, '大分県豊後高田市新栄');
ok($zip->set_number('8790608')->is_valid_number, '大分県豊後高田市呉崎');
ok($zip->set_number('8790609')->is_valid_number, '大分県豊後高田市城台');
ok($zip->set_number('8790611')->is_valid_number, '大分県豊後高田市森');
ok($zip->set_number('8790612')->is_valid_number, '大分県豊後高田市佐野');
ok($zip->set_number('8790613')->is_valid_number, '大分県豊後高田市小田原');
ok($zip->set_number('8790614')->is_valid_number, '大分県豊後高田市来縄');
ok($zip->set_number('8790615')->is_valid_number, '大分県豊後高田市界');
ok($zip->set_number('8790616')->is_valid_number, '大分県豊後高田市水崎');
ok($zip->set_number('8790617')->is_valid_number, '大分県豊後高田市高田');
ok($zip->set_number('8790618')->is_valid_number, '大分県豊後高田市中央通');
ok($zip->set_number('8790619')->is_valid_number, '大分県豊後高田市浜町');
ok($zip->set_number('8790621')->is_valid_number, '大分県豊後高田市是永町');
ok($zip->set_number('8790622')->is_valid_number, '大分県豊後高田市鍛治屋町');
ok($zip->set_number('8790623')->is_valid_number, '大分県豊後高田市金谷町');
ok($zip->set_number('8790624')->is_valid_number, '大分県豊後高田市本町');
ok($zip->set_number('8790625')->is_valid_number, '大分県豊後高田市水取');
ok($zip->set_number('8790626')->is_valid_number, '大分県豊後高田市今町');
ok($zip->set_number('8790627')->is_valid_number, '大分県豊後高田市新地');
ok($zip->set_number('8790628')->is_valid_number, '大分県豊後高田市新町');
ok($zip->set_number('8790721')->is_valid_number, '大分県豊後高田市加礼川');
ok($zip->set_number('8790722')->is_valid_number, '大分県豊後高田市一畑');
ok($zip->set_number('8790723')->is_valid_number, '大分県豊後高田市梅ノ木');
ok($zip->set_number('8790724')->is_valid_number, '大分県豊後高田市新城');
ok($zip->set_number('8790731')->is_valid_number, '大分県豊後高田市長岩屋');
ok($zip->set_number('8790732')->is_valid_number, '大分県豊後高田市大力');
ok($zip->set_number('8790733')->is_valid_number, '大分県豊後高田市荒尾');
ok($zip->set_number('8790734')->is_valid_number, '大分県豊後高田市築地');
ok($zip->set_number('8790735')->is_valid_number, '大分県豊後高田市松行');
ok($zip->set_number('8790841')->is_valid_number, '大分県豊後高田市田染蕗');
ok($zip->set_number('8790842')->is_valid_number, '大分県豊後高田市田染池部');
ok($zip->set_number('8790843')->is_valid_number, '大分県豊後高田市田染相原');
ok($zip->set_number('8790844')->is_valid_number, '大分県豊後高田市田染上野');
ok($zip->set_number('8790851')->is_valid_number, '大分県豊後高田市田染横嶺');
ok($zip->set_number('8790852')->is_valid_number, '大分県豊後高田市田染真中');
ok($zip->set_number('8790853')->is_valid_number, '大分県豊後高田市田染平野');
ok($zip->set_number('8790854')->is_valid_number, '大分県豊後高田市田染小崎');
ok($zip->set_number('8790855')->is_valid_number, '大分県豊後高田市田染真木');
ok($zip->set_number('8790901')->is_valid_number, '大分県杵築市大田石丸');
ok($zip->set_number('8790902')->is_valid_number, '大分県杵築市大田沓掛');
ok($zip->set_number('8790903')->is_valid_number, '大分県杵築市大田永松');
ok($zip->set_number('8790904')->is_valid_number, '大分県杵築市大田小野');
ok($zip->set_number('8790911')->is_valid_number, '大分県杵築市大田波多方');
ok($zip->set_number('8790912')->is_valid_number, '大分県杵築市大田白木原');
ok($zip->set_number('8790941')->is_valid_number, '大分県杵築市大田俣水(その他)');
ok($zip->set_number('8791121')->is_valid_number, '大分県宇佐市東大堀');
ok($zip->set_number('8791122')->is_valid_number, '大分県宇佐市横田');
ok($zip->set_number('8791123')->is_valid_number, '大分県宇佐市立石');
ok($zip->set_number('8791124')->is_valid_number, '大分県宇佐市山');
ok($zip->set_number('8791125')->is_valid_number, '大分県宇佐市両戒');
ok($zip->set_number('8791126')->is_valid_number, '大分県宇佐市江熊');
ok($zip->set_number('8791127')->is_valid_number, '大分県宇佐市西屋敷');
ok($zip->set_number('8791128')->is_valid_number, '大分県宇佐市金丸');
ok($zip->set_number('8791131')->is_valid_number, '大分県宇佐市出光');
ok($zip->set_number('8791132')->is_valid_number, '大分県宇佐市岩崎');
ok($zip->set_number('8791133')->is_valid_number, '大分県宇佐市日足');
ok($zip->set_number('8791134')->is_valid_number, '大分県宇佐市橋津');
ok($zip->set_number('8791135')->is_valid_number, '大分県宇佐市和気');
ok($zip->set_number('8791136')->is_valid_number, '大分県宇佐市西木');
ok($zip->set_number('8791137')->is_valid_number, '大分県宇佐市苅宇田');
ok($zip->set_number('8791138')->is_valid_number, '大分県宇佐市青森');
ok($zip->set_number('8791301')->is_valid_number, '大分県杵築市山香町向野');
ok($zip->set_number('8791302')->is_valid_number, '大分県杵築市山香町立石');
ok($zip->set_number('8791303')->is_valid_number, '大分県杵築市山香町下');
ok($zip->set_number('8791304')->is_valid_number, '大分県杵築市山香町小武');
ok($zip->set_number('8791305')->is_valid_number, '大分県杵築市山香町倉成');
ok($zip->set_number('8791306')->is_valid_number, '大分県杵築市山香町広瀬');
ok($zip->set_number('8791307')->is_valid_number, '大分県杵築市山香町野原');
ok($zip->set_number('8791311')->is_valid_number, '大分県杵築市山香町内河野');
ok($zip->set_number('8791312')->is_valid_number, '大分県杵築市山香町日指');
ok($zip->set_number('8791313')->is_valid_number, '大分県杵築市山香町久木野尾');
ok($zip->set_number('8791314')->is_valid_number, '大分県杵築市山香町南畑');
ok($zip->set_number('8791315')->is_valid_number, '大分県杵築市山香町山浦');
ok($zip->set_number('8791316')->is_valid_number, '大分県杵築市山香町吉野渡');
ok($zip->set_number('8791500')->is_valid_number, '大分県速見郡日出町以下に掲載がない場合');
ok($zip->set_number('8791501')->is_valid_number, '大分県速見郡日出町広瀬');
ok($zip->set_number('8791502')->is_valid_number, '大分県速見郡日出町藤原');
ok($zip->set_number('8791503')->is_valid_number, '大分県速見郡日出町真那井');
ok($zip->set_number('8791504')->is_valid_number, '大分県速見郡日出町大神');
ok($zip->set_number('8791505')->is_valid_number, '大分県速見郡日出町川崎');
ok($zip->set_number('8791506')->is_valid_number, '大分県速見郡日出町日出町の次に番地がくる場合');
ok($zip->set_number('8791507')->is_valid_number, '大分県速見郡日出町豊岡');
ok($zip->set_number('8791508')->is_valid_number, '大分県速見郡日出町平道');
ok($zip->set_number('8791509')->is_valid_number, '大分県速見郡日出町南畑');
ok($zip->set_number('8792111')->is_valid_number, '大分県大分市本神崎');
ok($zip->set_number('8792112')->is_valid_number, '大分県大分市馬場');
ok($zip->set_number('8792113')->is_valid_number, '大分県大分市木佐上');
ok($zip->set_number('8792114')->is_valid_number, '大分県大分市大平');
ok($zip->set_number('8792115')->is_valid_number, '大分県大分市志生木');
ok($zip->set_number('8792201')->is_valid_number, '大分県大分市佐賀関');
ok($zip->set_number('8792202')->is_valid_number, '大分県大分市白木');
ok($zip->set_number('8792203')->is_valid_number, '大分県大分市一尺屋');
ok($zip->set_number('8792400')->is_valid_number, '大分県津久見市以下に掲載がない場合');
ok($zip->set_number('8792401')->is_valid_number, '大分県津久見市千怒');
ok($zip->set_number('8792411')->is_valid_number, '大分県津久見市岩屋町');
ok($zip->set_number('8792412')->is_valid_number, '大分県津久見市高洲町');
ok($zip->set_number('8792413')->is_valid_number, '大分県津久見市津久見浦');
ok($zip->set_number('8792421')->is_valid_number, '大分県津久見市津久見');
ok($zip->set_number('8792422')->is_valid_number, '大分県津久見市八戸');
ok($zip->set_number('8792431')->is_valid_number, '大分県津久見市大友町');
ok($zip->set_number('8792432')->is_valid_number, '大分県津久見市文京町');
ok($zip->set_number('8792433')->is_valid_number, '大分県津久見市中田町');
ok($zip->set_number('8792434')->is_valid_number, '大分県津久見市立花町');
ok($zip->set_number('8792435')->is_valid_number, '大分県津久見市宮本町');
ok($zip->set_number('8792436')->is_valid_number, '大分県津久見市上宮本町');
ok($zip->set_number('8792441')->is_valid_number, '大分県津久見市中央町');
ok($zip->set_number('8792442')->is_valid_number, '大分県津久見市港町');
ok($zip->set_number('8792443')->is_valid_number, '大分県津久見市セメント町');
ok($zip->set_number('8792444')->is_valid_number, '大分県津久見市元町');
ok($zip->set_number('8792445')->is_valid_number, '大分県津久見市井無田町');
ok($zip->set_number('8792446')->is_valid_number, '大分県津久見市下青江');
ok($zip->set_number('8792451')->is_valid_number, '大分県津久見市新町');
ok($zip->set_number('8792452')->is_valid_number, '大分県津久見市中町');
ok($zip->set_number('8792453')->is_valid_number, '大分県津久見市小園町');
ok($zip->set_number('8792454')->is_valid_number, '大分県津久見市地蔵町');
ok($zip->set_number('8792455')->is_valid_number, '大分県津久見市岡町');
ok($zip->set_number('8792456')->is_valid_number, '大分県津久見市門前町');
ok($zip->set_number('8792457')->is_valid_number, '大分県津久見市志手町');
ok($zip->set_number('8792458')->is_valid_number, '大分県津久見市入船西町');
ok($zip->set_number('8792459')->is_valid_number, '大分県津久見市入船東町');
ok($zip->set_number('8792461')->is_valid_number, '大分県津久見市上青江');
ok($zip->set_number('8792471')->is_valid_number, '大分県津久見市合ノ元町');
ok($zip->set_number('8792472')->is_valid_number, '大分県津久見市徳浦本町');
ok($zip->set_number('8792473')->is_valid_number, '大分県津久見市徳浦宮町');
ok($zip->set_number('8792474')->is_valid_number, '大分県津久見市徳浦');
ok($zip->set_number('8792475')->is_valid_number, '大分県津久見市堅浦');
ok($zip->set_number('8792476')->is_valid_number, '大分県津久見市長目');
ok($zip->set_number('8792501')->is_valid_number, '大分県津久見市保戸島');
ok($zip->set_number('8792601')->is_valid_number, '大分県佐伯市上浦浅海井浦');
ok($zip->set_number('8792602')->is_valid_number, '大分県佐伯市上浦津井浦');
ok($zip->set_number('8792603')->is_valid_number, '大分県佐伯市上浦最勝海浦');
ok($zip->set_number('8792681')->is_valid_number, '大分県津久見市日見');
ok($zip->set_number('8792682')->is_valid_number, '大分県津久見市網代');
ok($zip->set_number('8792683')->is_valid_number, '大分県津久見市四浦');
ok($zip->set_number('8793101')->is_valid_number, '大分県佐伯市直川赤木');
ok($zip->set_number('8793102')->is_valid_number, '大分県佐伯市直川上直見');
ok($zip->set_number('8793103')->is_valid_number, '大分県佐伯市直川下直見');
ok($zip->set_number('8793104')->is_valid_number, '大分県佐伯市直川仁田原');
ok($zip->set_number('8793105')->is_valid_number, '大分県佐伯市直川横川');
ok($zip->set_number('8793201')->is_valid_number, '大分県佐伯市宇目大平');
ok($zip->set_number('8793202')->is_valid_number, '大分県佐伯市宇目河内');
ok($zip->set_number('8793203')->is_valid_number, '大分県佐伯市宇目塩見園');
ok($zip->set_number('8793204')->is_valid_number, '大分県佐伯市宇目重岡');
ok($zip->set_number('8793205')->is_valid_number, '大分県佐伯市宇目千束');
ok($zip->set_number('8793301')->is_valid_number, '大分県佐伯市宇目小野市');
ok($zip->set_number('8793302')->is_valid_number, '大分県佐伯市宇目南田原');
ok($zip->set_number('8793401')->is_valid_number, '大分県佐伯市宇目木浦鉱山');
ok($zip->set_number('8793402')->is_valid_number, '大分県佐伯市宇目木浦内');
ok($zip->set_number('8794121')->is_valid_number, '大分県日田市天瀬町馬原');
ok($zip->set_number('8794122')->is_valid_number, '大分県日田市天瀬町合田');
ok($zip->set_number('8794123')->is_valid_number, '大分県日田市天瀬町女子畑');
ok($zip->set_number('8794201')->is_valid_number, '大分県日田市天瀬町桜竹');
ok($zip->set_number('8794202')->is_valid_number, '大分県日田市天瀬町赤岩');
ok($zip->set_number('8794203')->is_valid_number, '大分県日田市天瀬町湯山');
ok($zip->set_number('8794301')->is_valid_number, '大分県玖珠郡玖珠町四日市(その他)');
ok($zip->set_number('8794331')->is_valid_number, '大分県玖珠郡玖珠町戸畑');
ok($zip->set_number('8794332')->is_valid_number, '大分県玖珠郡玖珠町山浦(秋畑、荻原、下園、下ノ寺、杉河内、千重、早水、中野、中');
ok($zip->set_number('8794332')->is_valid_number, '大分県玖珠郡玖珠町泊里、花香、牧場)');
ok($zip->set_number('8794400')->is_valid_number, '大分県玖珠郡玖珠町以下に掲載がない場合');
ok($zip->set_number('8794401')->is_valid_number, '大分県玖珠郡玖珠町四日市(1~899番地)');
ok($zip->set_number('8794402')->is_valid_number, '大分県玖珠郡玖珠町綾垣');
ok($zip->set_number('8794403')->is_valid_number, '大分県玖珠郡玖珠町帆足');
ok($zip->set_number('8794404')->is_valid_number, '大分県玖珠郡玖珠町森');
ok($zip->set_number('8794405')->is_valid_number, '大分県玖珠郡玖珠町岩室');
ok($zip->set_number('8794406')->is_valid_number, '大分県玖珠郡玖珠町日出生');
ok($zip->set_number('8794411')->is_valid_number, '大分県玖珠郡玖珠町小田');
ok($zip->set_number('8794412')->is_valid_number, '大分県玖珠郡玖珠町山田');
ok($zip->set_number('8794413')->is_valid_number, '大分県玖珠郡玖珠町塚脇');
ok($zip->set_number('8794414')->is_valid_number, '大分県玖珠郡玖珠町大隈');
ok($zip->set_number('8794521')->is_valid_number, '大分県玖珠郡玖珠町太田');
ok($zip->set_number('8794522')->is_valid_number, '大分県玖珠郡玖珠町山下');
ok($zip->set_number('8794523')->is_valid_number, '大分県玖珠郡玖珠町古後');
ok($zip->set_number('8794601')->is_valid_number, '大分県玖珠郡九重町右田(その他)');
ok($zip->set_number('8794631')->is_valid_number, '大分県玖珠郡九重町恵良');
ok($zip->set_number('8794632')->is_valid_number, '大分県玖珠郡九重町松木');
ok($zip->set_number('8794721')->is_valid_number, '大分県玖珠郡九重町粟野');
ok($zip->set_number('8794722')->is_valid_number, '大分県玖珠郡九重町引治');
ok($zip->set_number('8794723')->is_valid_number, '大分県玖珠郡九重町町田');
ok($zip->set_number('8794724')->is_valid_number, '大分県玖珠郡九重町菅原');
ok($zip->set_number('8794732')->is_valid_number, '大分県玖珠郡玖珠町山浦(第一大原野、第二大原野、阿蘇釣)');
ok($zip->set_number('8794800')->is_valid_number, '大分県玖珠郡九重町以下に掲載がない場合');
ok($zip->set_number('8794801')->is_valid_number, '大分県玖珠郡九重町右田(1~1464番地)');
ok($zip->set_number('8794802')->is_valid_number, '大分県玖珠郡九重町野上');
ok($zip->set_number('8794803')->is_valid_number, '大分県玖珠郡九重町後野上');
ok($zip->set_number('8794911')->is_valid_number, '大分県玖珠郡九重町田野');
ok($zip->set_number('8794912')->is_valid_number, '大分県玖珠郡九重町湯坪');
ok($zip->set_number('8795101')->is_valid_number, '大分県由布市湯布院町塚原');
ok($zip->set_number('8795102')->is_valid_number, '大分県由布市湯布院町川上');
ok($zip->set_number('8795103')->is_valid_number, '大分県由布市湯布院町川南');
ok($zip->set_number('8795104')->is_valid_number, '大分県由布市湯布院町中川');
ok($zip->set_number('8795111')->is_valid_number, '大分県由布市湯布院町下湯平');
ok($zip->set_number('8795112')->is_valid_number, '大分県由布市湯布院町湯平');
ok($zip->set_number('8795113')->is_valid_number, '大分県由布市湯布院町川西');
ok($zip->set_number('8795114')->is_valid_number, '大分県由布市湯布院町川北');
ok($zip->set_number('8795400')->is_valid_number, '大分県由布市以下に掲載がない場合');
ok($zip->set_number('8795401')->is_valid_number, '大分県由布市庄内町北大津留');
ok($zip->set_number('8795402')->is_valid_number, '大分県由布市庄内町小挾間');
ok($zip->set_number('8795403')->is_valid_number, '大分県由布市庄内町東大津留');
ok($zip->set_number('8795404')->is_valid_number, '大分県由布市庄内町櫟木');
ok($zip->set_number('8795405')->is_valid_number, '大分県由布市庄内町東長宝');
ok($zip->set_number('8795406')->is_valid_number, '大分県由布市庄内町西長宝');
ok($zip->set_number('8795407')->is_valid_number, '大分県由布市庄内町南大津留');
ok($zip->set_number('8795408')->is_valid_number, '大分県由布市庄内町西大津留');
ok($zip->set_number('8795411')->is_valid_number, '大分県由布市庄内町龍原');
ok($zip->set_number('8795412')->is_valid_number, '大分県由布市庄内町五ケ瀬');
ok($zip->set_number('8795413')->is_valid_number, '大分県由布市庄内町大龍');
ok($zip->set_number('8795421')->is_valid_number, '大分県由布市庄内町柿原');
ok($zip->set_number('8795422')->is_valid_number, '大分県由布市庄内町野畑');
ok($zip->set_number('8795423')->is_valid_number, '大分県由布市庄内町阿蘇野');
ok($zip->set_number('8795424')->is_valid_number, '大分県由布市庄内町直野内山');
ok($zip->set_number('8795425')->is_valid_number, '大分県由布市庄内町渕');
ok($zip->set_number('8795431')->is_valid_number, '大分県由布市庄内町長野');
ok($zip->set_number('8795432')->is_valid_number, '大分県由布市庄内町畑田');
ok($zip->set_number('8795433')->is_valid_number, '大分県由布市庄内町高岡');
ok($zip->set_number('8795434')->is_valid_number, '大分県由布市庄内町庄内原');
ok($zip->set_number('8795435')->is_valid_number, '大分県由布市庄内町中');
ok($zip->set_number('8795436')->is_valid_number, '大分県由布市庄内町西');
ok($zip->set_number('8795437')->is_valid_number, '大分県由布市庄内町平石');
ok($zip->set_number('8795501')->is_valid_number, '大分県由布市挾間町鬼崎');
ok($zip->set_number('8795502')->is_valid_number, '大分県由布市挾間町向原');
ok($zip->set_number('8795503')->is_valid_number, '大分県由布市挾間町医大ケ丘');
ok($zip->set_number('8795504')->is_valid_number, '大分県由布市挾間町下市');
ok($zip->set_number('8795506')->is_valid_number, '大分県由布市挾間町挾間');
ok($zip->set_number('8795510')->is_valid_number, '大分県由布市挾間町東院');
ok($zip->set_number('8795511')->is_valid_number, '大分県由布市挾間町古野');
ok($zip->set_number('8795512')->is_valid_number, '大分県由布市挾間町来鉢');
ok($zip->set_number('8795513')->is_valid_number, '大分県由布市挾間町高崎');
ok($zip->set_number('8795514')->is_valid_number, '大分県由布市挾間町七蔵司');
ok($zip->set_number('8795515')->is_valid_number, '大分県由布市挾間町三船');
ok($zip->set_number('8795516')->is_valid_number, '大分県由布市挾間町赤野');
ok($zip->set_number('8795517')->is_valid_number, '大分県由布市挾間町内成');
ok($zip->set_number('8795518')->is_valid_number, '大分県由布市挾間町北方');
ok($zip->set_number('8795519')->is_valid_number, '大分県由布市挾間町田代');
ok($zip->set_number('8795521')->is_valid_number, '大分県由布市挾間町鬼瀬');
ok($zip->set_number('8795522')->is_valid_number, '大分県由布市挾間町小野');
ok($zip->set_number('8795523')->is_valid_number, '大分県由布市挾間町篠原');
ok($zip->set_number('8795524')->is_valid_number, '大分県由布市挾間町時松');
ok($zip->set_number('8795525')->is_valid_number, '大分県由布市挾間町朴木');
ok($zip->set_number('8795531')->is_valid_number, '大分県由布市挾間町谷');
ok($zip->set_number('8795532')->is_valid_number, '大分県由布市挾間町筒口');
ok($zip->set_number('8795551')->is_valid_number, '大分県別府市内成');
ok($zip->set_number('8795552')->is_valid_number, '大分県別府市古賀原');
ok($zip->set_number('8796101')->is_valid_number, '大分県竹田市荻町木下');
ok($zip->set_number('8796102')->is_valid_number, '大分県竹田市荻町政所');
ok($zip->set_number('8796103')->is_valid_number, '大分県竹田市荻町新藤');
ok($zip->set_number('8796104')->is_valid_number, '大分県竹田市荻町藤渡');
ok($zip->set_number('8796111')->is_valid_number, '大分県竹田市荻町南河内');
ok($zip->set_number('8796112')->is_valid_number, '大分県竹田市荻町馬背野');
ok($zip->set_number('8796113')->is_valid_number, '大分県竹田市荻町恵良原');
ok($zip->set_number('8796115')->is_valid_number, '大分県竹田市荻町馬場');
ok($zip->set_number('8796116')->is_valid_number, '大分県竹田市荻町高城');
ok($zip->set_number('8796121')->is_valid_number, '大分県竹田市荻町桑木');
ok($zip->set_number('8796122')->is_valid_number, '大分県竹田市荻町柏原');
ok($zip->set_number('8796123')->is_valid_number, '大分県竹田市荻町宮平');
ok($zip->set_number('8796124')->is_valid_number, '大分県竹田市荻町陽目');
ok($zip->set_number('8796125')->is_valid_number, '大分県竹田市荻町仏面');
ok($zip->set_number('8796126')->is_valid_number, '大分県竹田市荻町大平');
ok($zip->set_number('8796127')->is_valid_number, '大分県竹田市荻町叶野');
ok($zip->set_number('8796128')->is_valid_number, '大分県竹田市荻町高練木');
ok($zip->set_number('8796131')->is_valid_number, '大分県竹田市荻町鴫田');
ok($zip->set_number('8796132')->is_valid_number, '大分県竹田市荻町西福寺');
ok($zip->set_number('8796133')->is_valid_number, '大分県竹田市荻町田代');
ok($zip->set_number('8796134')->is_valid_number, '大分県竹田市荻町瓜作');
ok($zip->set_number('8796135')->is_valid_number, '大分県竹田市荻町北原');
ok($zip->set_number('8796181')->is_valid_number, '大分県竹田市小塚');
ok($zip->set_number('8796182')->is_valid_number, '大分県竹田市今');
ok($zip->set_number('8796183')->is_valid_number, '大分県竹田市戸上');
ok($zip->set_number('8796184')->is_valid_number, '大分県竹田市菅生');
ok($zip->set_number('8796201')->is_valid_number, '大分県豊後大野市朝地町市万田');
ok($zip->set_number('8796202')->is_valid_number, '大分県豊後大野市朝地町下野');
ok($zip->set_number('8796211')->is_valid_number, '大分県豊後大野市朝地町宮生');
ok($zip->set_number('8796212')->is_valid_number, '大分県豊後大野市朝地町志賀');
ok($zip->set_number('8796213')->is_valid_number, '大分県豊後大野市朝地町上尾塚');
ok($zip->set_number('8796221')->is_valid_number, '大分県豊後大野市朝地町坪泉');
ok($zip->set_number('8796222')->is_valid_number, '大分県豊後大野市朝地町朝地');
ok($zip->set_number('8796223')->is_valid_number, '大分県豊後大野市朝地町板井迫');
ok($zip->set_number('8796224')->is_valid_number, '大分県豊後大野市朝地町池田');
ok($zip->set_number('8796331')->is_valid_number, '大分県豊後大野市朝地町鳥田');
ok($zip->set_number('8796332')->is_valid_number, '大分県豊後大野市朝地町綿田');
ok($zip->set_number('8796333')->is_valid_number, '大分県豊後大野市朝地町栗林');
ok($zip->set_number('8796334')->is_valid_number, '大分県豊後大野市朝地町梨小');
ok($zip->set_number('8796401')->is_valid_number, '大分県豊後大野市大野町安藤');
ok($zip->set_number('8796402')->is_valid_number, '大分県豊後大野市大野町中土師');
ok($zip->set_number('8796403')->is_valid_number, '大分県豊後大野市大野町長畑');
ok($zip->set_number('8796404')->is_valid_number, '大分県豊後大野市大野町後田');
ok($zip->set_number('8796405')->is_valid_number, '大分県豊後大野市大野町代三五');
ok($zip->set_number('8796406')->is_valid_number, '大分県豊後大野市大野町杉園');
ok($zip->set_number('8796407')->is_valid_number, '大分県豊後大野市大野町十時');
ok($zip->set_number('8796408')->is_valid_number, '大分県豊後大野市大野町沢田');
ok($zip->set_number('8796421')->is_valid_number, '大分県豊後大野市大野町中原');
ok($zip->set_number('8796422')->is_valid_number, '大分県豊後大野市大野町小倉木');
ok($zip->set_number('8796423')->is_valid_number, '大分県豊後大野市大野町矢田');
ok($zip->set_number('8796424')->is_valid_number, '大分県豊後大野市大野町夏足');
ok($zip->set_number('8796425')->is_valid_number, '大分県豊後大野市大野町両家');
ok($zip->set_number('8796426')->is_valid_number, '大分県豊後大野市大野町郡山');
ok($zip->set_number('8796431')->is_valid_number, '大分県豊後大野市大野町酒井寺');
ok($zip->set_number('8796432')->is_valid_number, '大分県豊後大野市大野町屋原');
ok($zip->set_number('8796433')->is_valid_number, '大分県豊後大野市大野町大原');
ok($zip->set_number('8796434')->is_valid_number, '大分県豊後大野市大野町桑原');
ok($zip->set_number('8796435')->is_valid_number, '大分県豊後大野市大野町北園');
ok($zip->set_number('8796441')->is_valid_number, '大分県豊後大野市大野町田中');
ok($zip->set_number('8796442')->is_valid_number, '大分県豊後大野市大野町藤北');
ok($zip->set_number('8796443')->is_valid_number, '大分県豊後大野市大野町宮迫');
ok($zip->set_number('8796444')->is_valid_number, '大分県豊後大野市大野町田代');
ok($zip->set_number('8796445')->is_valid_number, '大分県豊後大野市大野町片島');
ok($zip->set_number('8796601')->is_valid_number, '大分県豊後大野市緒方町馬場');
ok($zip->set_number('8796602')->is_valid_number, '大分県豊後大野市緒方町志賀');
ok($zip->set_number('8796611')->is_valid_number, '大分県豊後大野市緒方町夏足');
ok($zip->set_number('8796612')->is_valid_number, '大分県豊後大野市緒方町越生');
ok($zip->set_number('8796613')->is_valid_number, '大分県豊後大野市緒方町井上');
ok($zip->set_number('8796614')->is_valid_number, '大分県豊後大野市緒方町知田');
ok($zip->set_number('8796615')->is_valid_number, '大分県豊後大野市緒方町鮒川');
ok($zip->set_number('8796616')->is_valid_number, '大分県豊後大野市緒方町久土知');
ok($zip->set_number('8796621')->is_valid_number, '大分県豊後大野市緒方町野尻');
ok($zip->set_number('8796622')->is_valid_number, '大分県豊後大野市緒方町天神');
ok($zip->set_number('8796623')->is_valid_number, '大分県豊後大野市緒方町馬背畑');
ok($zip->set_number('8796624')->is_valid_number, '大分県豊後大野市緒方町平石');
ok($zip->set_number('8796625')->is_valid_number, '大分県豊後大野市緒方町上犬塚');
ok($zip->set_number('8796626')->is_valid_number, '大分県豊後大野市緒方町大化');
ok($zip->set_number('8796631')->is_valid_number, '大分県豊後大野市緒方町原尻');
ok($zip->set_number('8796632')->is_valid_number, '大分県豊後大野市緒方町辻');
ok($zip->set_number('8796633')->is_valid_number, '大分県豊後大野市緒方町小宛');
ok($zip->set_number('8796634')->is_valid_number, '大分県豊後大野市緒方町寺原');
ok($zip->set_number('8796635')->is_valid_number, '大分県豊後大野市緒方町軸丸');
ok($zip->set_number('8796641')->is_valid_number, '大分県豊後大野市緒方町草深野');
ok($zip->set_number('8796642')->is_valid_number, '大分県豊後大野市緒方町上自在');
ok($zip->set_number('8796643')->is_valid_number, '大分県豊後大野市緒方町下自在');
ok($zip->set_number('8796751')->is_valid_number, '大分県豊後大野市緒方町上年野');
ok($zip->set_number('8796752')->is_valid_number, '大分県豊後大野市緒方町柚木');
ok($zip->set_number('8796753')->is_valid_number, '大分県豊後大野市緒方町下徳田');
ok($zip->set_number('8796754')->is_valid_number, '大分県豊後大野市緒方町冬原');
ok($zip->set_number('8796755')->is_valid_number, '大分県豊後大野市緒方町上冬原');
ok($zip->set_number('8796756')->is_valid_number, '大分県豊後大野市緒方町徳田');
ok($zip->set_number('8796757')->is_valid_number, '大分県豊後大野市緒方町木野');
ok($zip->set_number('8796758')->is_valid_number, '大分県豊後大野市緒方町中野');
ok($zip->set_number('8796759')->is_valid_number, '大分県豊後大野市緒方町大石');
ok($zip->set_number('8796861')->is_valid_number, '大分県豊後大野市緒方町小原');
ok($zip->set_number('8796862')->is_valid_number, '大分県豊後大野市緒方町栗生');
ok($zip->set_number('8796863')->is_valid_number, '大分県豊後大野市緒方町滞迫');
ok($zip->set_number('8796864')->is_valid_number, '大分県豊後大野市緒方町上畑');
ok($zip->set_number('8796865')->is_valid_number, '大分県豊後大野市緒方町尾平鉱山');
ok($zip->set_number('8796901')->is_valid_number, '大分県豊後大野市清川町臼尾');
ok($zip->set_number('8796902')->is_valid_number, '大分県豊後大野市清川町雨堤');
ok($zip->set_number('8796903')->is_valid_number, '大分県豊後大野市清川町砂田');
ok($zip->set_number('8796904')->is_valid_number, '大分県豊後大野市清川町天神');
ok($zip->set_number('8796905')->is_valid_number, '大分県豊後大野市清川町三玉');
ok($zip->set_number('8796911')->is_valid_number, '大分県豊後大野市清川町宇田枝');
ok($zip->set_number('8796912')->is_valid_number, '大分県豊後大野市清川町六種');
ok($zip->set_number('8796913')->is_valid_number, '大分県豊後大野市清川町平石');
ok($zip->set_number('8796914')->is_valid_number, '大分県豊後大野市清川町左右知');
ok($zip->set_number('8796921')->is_valid_number, '大分県豊後大野市清川町伏野');
ok($zip->set_number('8796922')->is_valid_number, '大分県豊後大野市清川町大白谷');
ok($zip->set_number('8797100')->is_valid_number, '大分県豊後大野市以下に掲載がない場合');
ok($zip->set_number('8797101')->is_valid_number, '大分県豊後大野市三重町宮野');
ok($zip->set_number('8797102')->is_valid_number, '大分県豊後大野市三重町菅生');
ok($zip->set_number('8797103')->is_valid_number, '大分県豊後大野市三重町西畑');
ok($zip->set_number('8797104')->is_valid_number, '大分県豊後大野市三重町小坂');
ok($zip->set_number('8797105')->is_valid_number, '大分県豊後大野市三重町芦刈');
ok($zip->set_number('8797106')->is_valid_number, '大分県豊後大野市三重町井迫');
ok($zip->set_number('8797107')->is_valid_number, '大分県豊後大野市三重町上田原');
ok($zip->set_number('8797108')->is_valid_number, '大分県豊後大野市三重町浅瀬');
ok($zip->set_number('8797111')->is_valid_number, '大分県豊後大野市三重町赤嶺');
ok($zip->set_number('8797121')->is_valid_number, '大分県豊後大野市三重町山部');
ok($zip->set_number('8797122')->is_valid_number, '大分県豊後大野市三重町鷲谷');
ok($zip->set_number('8797123')->is_valid_number, '大分県豊後大野市三重町松尾');
ok($zip->set_number('8797124')->is_valid_number, '大分県豊後大野市三重町内山');
ok($zip->set_number('8797125')->is_valid_number, '大分県豊後大野市三重町内田');
ok($zip->set_number('8797131')->is_valid_number, '大分県豊後大野市三重町市場');
ok($zip->set_number('8797141')->is_valid_number, '大分県豊後大野市三重町秋葉');
ok($zip->set_number('8797142')->is_valid_number, '大分県豊後大野市三重町小田');
ok($zip->set_number('8797143')->is_valid_number, '大分県豊後大野市三重町久田');
ok($zip->set_number('8797144')->is_valid_number, '大分県豊後大野市三重町本城');
ok($zip->set_number('8797151')->is_valid_number, '大分県豊後大野市三重町西泉');
ok($zip->set_number('8797152')->is_valid_number, '大分県豊後大野市三重町百枝');
ok($zip->set_number('8797153')->is_valid_number, '大分県豊後大野市三重町玉田');
ok($zip->set_number('8797154')->is_valid_number, '大分県豊後大野市三重町川辺');
ok($zip->set_number('8797155')->is_valid_number, '大分県豊後大野市三重町向野');
ok($zip->set_number('8797261')->is_valid_number, '大分県豊後大野市三重町伏野');
ok($zip->set_number('8797262')->is_valid_number, '大分県豊後大野市三重町奥畑');
ok($zip->set_number('8797263')->is_valid_number, '大分県豊後大野市三重町中津留');
ok($zip->set_number('8797264')->is_valid_number, '大分県豊後大野市三重町大白谷');
ok($zip->set_number('8797301')->is_valid_number, '大分県豊後大野市犬飼町犬飼');
ok($zip->set_number('8797302')->is_valid_number, '大分県豊後大野市犬飼町久原');
ok($zip->set_number('8797303')->is_valid_number, '大分県豊後大野市犬飼町柚野木');
ok($zip->set_number('8797304')->is_valid_number, '大分県豊後大野市犬飼町大寒');
ok($zip->set_number('8797305')->is_valid_number, '大分県豊後大野市犬飼町田原');
ok($zip->set_number('8797306')->is_valid_number, '大分県豊後大野市犬飼町下津尾');
ok($zip->set_number('8797307')->is_valid_number, '大分県豊後大野市犬飼町西寒田');
ok($zip->set_number('8797311')->is_valid_number, '大分県豊後大野市犬飼町柴北');
ok($zip->set_number('8797312')->is_valid_number, '大分県豊後大野市犬飼町高津原');
ok($zip->set_number('8797313')->is_valid_number, '大分県豊後大野市犬飼町黒松');
ok($zip->set_number('8797314')->is_valid_number, '大分県豊後大野市犬飼町栗ケ畑');
ok($zip->set_number('8797315')->is_valid_number, '大分県豊後大野市犬飼町山内');
ok($zip->set_number('8797316')->is_valid_number, '大分県豊後大野市犬飼町長畑');
ok($zip->set_number('8797401')->is_valid_number, '大分県豊後大野市千歳町新殿');
ok($zip->set_number('8797402')->is_valid_number, '大分県豊後大野市千歳町船田');
ok($zip->set_number('8797403')->is_valid_number, '大分県豊後大野市千歳町石田');
ok($zip->set_number('8797404')->is_valid_number, '大分県豊後大野市千歳町長峰');
ok($zip->set_number('8797411')->is_valid_number, '大分県豊後大野市千歳町柴山');
ok($zip->set_number('8797412')->is_valid_number, '大分県豊後大野市千歳町高畑');
ok($zip->set_number('8797413')->is_valid_number, '大分県豊後大野市千歳町下山');
ok($zip->set_number('8797414')->is_valid_number, '大分県豊後大野市千歳町前田');
ok($zip->set_number('8797501')->is_valid_number, '大分県大分市竹中');
ok($zip->set_number('8797502')->is_valid_number, '大分県大分市端登');
ok($zip->set_number('8797503')->is_valid_number, '大分県大分市河原内');
ok($zip->set_number('8797504')->is_valid_number, '大分県大分市安藤');
ok($zip->set_number('8797761')->is_valid_number, '大分県大分市中戸次');
ok($zip->set_number('8797762')->is_valid_number, '大分県大分市けやき台');
ok($zip->set_number('8797763')->is_valid_number, '大分県大分市下戸次');
ok($zip->set_number('8797764')->is_valid_number, '大分県大分市上戸次');
ok($zip->set_number('8797765')->is_valid_number, '大分県大分市美園団地');
ok($zip->set_number('8797871')->is_valid_number, '大分県大分市辻');
ok($zip->set_number('8797872')->is_valid_number, '大分県大分市月形');
ok($zip->set_number('8797873')->is_valid_number, '大分県大分市宮尾');
ok($zip->set_number('8797874')->is_valid_number, '大分県大分市福良');
ok($zip->set_number('8797875')->is_valid_number, '大分県大分市吉野原');
ok($zip->set_number('8797881')->is_valid_number, '大分県大分市奥');
ok($zip->set_number('8797882')->is_valid_number, '大分県大分市杉原');
ok($zip->set_number('8797883')->is_valid_number, '大分県大分市萩尾');
ok($zip->set_number('8797884')->is_valid_number, '大分県大分市志津留');
ok($zip->set_number('8797885')->is_valid_number, '大分県大分市梅が丘');
ok($zip->set_number('8800000')->is_valid_number, '宮崎県宮崎市以下に掲載がない場合');
ok($zip->set_number('8800001')->is_valid_number, '宮崎県宮崎市橘通西');
ok($zip->set_number('8800002')->is_valid_number, '宮崎県宮崎市中央通');
ok($zip->set_number('8800003')->is_valid_number, '宮崎県宮崎市高松町');
ok($zip->set_number('8800004')->is_valid_number, '宮崎県宮崎市元宮町');
ok($zip->set_number('8800005')->is_valid_number, '宮崎県宮崎市南高松町');
ok($zip->set_number('8800006')->is_valid_number, '宮崎県宮崎市千草町');
ok($zip->set_number('8800007')->is_valid_number, '宮崎県宮崎市原町');
ok($zip->set_number('8800011')->is_valid_number, '宮崎県宮崎市上野町');
ok($zip->set_number('8800012')->is_valid_number, '宮崎県宮崎市末広');
ok($zip->set_number('8800013')->is_valid_number, '宮崎県宮崎市松橋');
ok($zip->set_number('8800014')->is_valid_number, '宮崎県宮崎市鶴島');
ok($zip->set_number('8800015')->is_valid_number, '宮崎県宮崎市大工');
ok($zip->set_number('8800016')->is_valid_number, '宮崎県宮崎市西高松町');
ok($zip->set_number('8800017')->is_valid_number, '宮崎県宮崎市北高松町');
ok($zip->set_number('8800021')->is_valid_number, '宮崎県宮崎市清水');
ok($zip->set_number('8800022')->is_valid_number, '宮崎県宮崎市大橋');
ok($zip->set_number('8800023')->is_valid_number, '宮崎県宮崎市和知川原');
ok($zip->set_number('8800024')->is_valid_number, '宮崎県宮崎市祇園');
ok($zip->set_number('8800025')->is_valid_number, '宮崎県宮崎市中津瀬町');
ok($zip->set_number('8800026')->is_valid_number, '宮崎県宮崎市花殿町');
ok($zip->set_number('8800027')->is_valid_number, '宮崎県宮崎市西池町');
ok($zip->set_number('8800031')->is_valid_number, '宮崎県宮崎市船塚');
ok($zip->set_number('8800032')->is_valid_number, '宮崎県宮崎市霧島');
ok($zip->set_number('8800033')->is_valid_number, '宮崎県宮崎市神宮西');
ok($zip->set_number('8800034')->is_valid_number, '宮崎県宮崎市矢の先町');
ok($zip->set_number('8800035')->is_valid_number, '宮崎県宮崎市下北方町');
ok($zip->set_number('8800036')->is_valid_number, '宮崎県宮崎市花ケ島町');
ok($zip->set_number('8800037')->is_valid_number, '宮崎県宮崎市南方町');
ok($zip->set_number('8800041')->is_valid_number, '宮崎県宮崎市池内町');
ok($zip->set_number('8800042')->is_valid_number, '宮崎県宮崎市平和が丘東町');
ok($zip->set_number('8800043')->is_valid_number, '宮崎県宮崎市上北方');
ok($zip->set_number('8800044')->is_valid_number, '宮崎県宮崎市瓜生野(その他)');
ok($zip->set_number('8800045')->is_valid_number, '宮崎県宮崎市大瀬町(その他)');
ok($zip->set_number('8800046')->is_valid_number, '宮崎県宮崎市平和が丘北町');
ok($zip->set_number('8800047')->is_valid_number, '宮崎県宮崎市平和が丘西町');
ok($zip->set_number('8800051')->is_valid_number, '宮崎県宮崎市江平西');
ok($zip->set_number('8800052')->is_valid_number, '宮崎県宮崎市丸山');
ok($zip->set_number('8800053')->is_valid_number, '宮崎県宮崎市神宮');
ok($zip->set_number('8800054')->is_valid_number, '宮崎県宮崎市神宮町');
ok($zip->set_number('8800055')->is_valid_number, '宮崎県宮崎市南花ケ島町');
ok($zip->set_number('8800056')->is_valid_number, '宮崎県宮崎市神宮東');
ok($zip->set_number('8800057')->is_valid_number, '宮崎県宮崎市桜町');
ok($zip->set_number('8800121')->is_valid_number, '宮崎県宮崎市島之内');
ok($zip->set_number('8800122')->is_valid_number, '宮崎県宮崎市塩路');
ok($zip->set_number('8800123')->is_valid_number, '宮崎県宮崎市芳士');
ok($zip->set_number('8800124')->is_valid_number, '宮崎県宮崎市新名爪');
ok($zip->set_number('8800125')->is_valid_number, '宮崎県宮崎市広原');
ok($zip->set_number('8800204')->is_valid_number, '宮崎県宮崎市佐土原町下富田');
ok($zip->set_number('8800211')->is_valid_number, '宮崎県宮崎市佐土原町下田島');
ok($zip->set_number('8800212')->is_valid_number, '宮崎県宮崎市佐土原町下那珂');
ok($zip->set_number('8800213')->is_valid_number, '宮崎県宮崎市佐土原町石崎');
ok($zip->set_number('8800214')->is_valid_number, '宮崎県宮崎市佐土原町松小路');
ok($zip->set_number('8800301')->is_valid_number, '宮崎県宮崎市佐土原町上田島');
ok($zip->set_number('8800302')->is_valid_number, '宮崎県宮崎市佐土原町西上那珂');
ok($zip->set_number('8800303')->is_valid_number, '宮崎県宮崎市佐土原町東上那珂');
ok($zip->set_number('8800341')->is_valid_number, '宮崎県西都市現王島');
ok($zip->set_number('8800344')->is_valid_number, '宮崎県宮崎市瓜生野(下畑)');
ok($zip->set_number('8800345')->is_valid_number, '宮崎県宮崎市大瀬町(上畑)');
ok($zip->set_number('8800801')->is_valid_number, '宮崎県宮崎市老松');
ok($zip->set_number('8800802')->is_valid_number, '宮崎県宮崎市別府町');
ok($zip->set_number('8800803')->is_valid_number, '宮崎県宮崎市旭');
ok($zip->set_number('8800804')->is_valid_number, '宮崎県宮崎市宮田町');
ok($zip->set_number('8800805')->is_valid_number, '宮崎県宮崎市橘通東');
ok($zip->set_number('8800806')->is_valid_number, '宮崎県宮崎市広島');
ok($zip->set_number('8800811')->is_valid_number, '宮崎県宮崎市錦町');
ok($zip->set_number('8800812')->is_valid_number, '宮崎県宮崎市高千穂通');
ok($zip->set_number('8800813')->is_valid_number, '宮崎県宮崎市丸島町');
ok($zip->set_number('8800814')->is_valid_number, '宮崎県宮崎市江平中町');
ok($zip->set_number('8800815')->is_valid_number, '宮崎県宮崎市江平町');
ok($zip->set_number('8800816')->is_valid_number, '宮崎県宮崎市江平東');
ok($zip->set_number('8800817')->is_valid_number, '宮崎県宮崎市江平東町');
ok($zip->set_number('8800818')->is_valid_number, '宮崎県宮崎市錦本町');
ok($zip->set_number('8800821')->is_valid_number, '宮崎県宮崎市浮城町');
ok($zip->set_number('8800822')->is_valid_number, '宮崎県宮崎市権現町');
ok($zip->set_number('8800823')->is_valid_number, '宮崎県宮崎市北権現町');
ok($zip->set_number('8800824')->is_valid_number, '宮崎県宮崎市大島町');
ok($zip->set_number('8800825')->is_valid_number, '宮崎県宮崎市東大宮');
ok($zip->set_number('8800826')->is_valid_number, '宮崎県宮崎市波島');
ok($zip->set_number('8800831')->is_valid_number, '宮崎県宮崎市新栄町');
ok($zip->set_number('8800832')->is_valid_number, '宮崎県宮崎市稗原町');
ok($zip->set_number('8800833')->is_valid_number, '宮崎県宮崎市昭栄町');
ok($zip->set_number('8800834')->is_valid_number, '宮崎県宮崎市新別府町');
ok($zip->set_number('8800835')->is_valid_number, '宮崎県宮崎市阿波岐原町');
ok($zip->set_number('8800836')->is_valid_number, '宮崎県宮崎市山崎町');
ok($zip->set_number('8800837')->is_valid_number, '宮崎県宮崎市村角町');
ok($zip->set_number('8800841')->is_valid_number, '宮崎県宮崎市吉村町');
ok($zip->set_number('8800842')->is_valid_number, '宮崎県宮崎市青葉町');
ok($zip->set_number('8800843')->is_valid_number, '宮崎県宮崎市下原町');
ok($zip->set_number('8800844')->is_valid_number, '宮崎県宮崎市柳丸町');
ok($zip->set_number('8800845')->is_valid_number, '宮崎県宮崎市新城町');
ok($zip->set_number('8800851')->is_valid_number, '宮崎県宮崎市港東');
ok($zip->set_number('8800852')->is_valid_number, '宮崎県宮崎市高洲町');
ok($zip->set_number('8800853')->is_valid_number, '宮崎県宮崎市中西町');
ok($zip->set_number('8800854')->is_valid_number, '宮崎県宮崎市一の宮町');
ok($zip->set_number('8800855')->is_valid_number, '宮崎県宮崎市田代町');
ok($zip->set_number('8800856')->is_valid_number, '宮崎県宮崎市日ノ出町');
ok($zip->set_number('8800857')->is_valid_number, '宮崎県宮崎市小戸町');
ok($zip->set_number('8800858')->is_valid_number, '宮崎県宮崎市港');
ok($zip->set_number('8800861')->is_valid_number, '宮崎県宮崎市出来島町');
ok($zip->set_number('8800862')->is_valid_number, '宮崎県宮崎市潮見町');
ok($zip->set_number('8800863')->is_valid_number, '宮崎県宮崎市前原町');
ok($zip->set_number('8800864')->is_valid_number, '宮崎県宮崎市吾妻町');
ok($zip->set_number('8800865')->is_valid_number, '宮崎県宮崎市松山');
ok($zip->set_number('8800866')->is_valid_number, '宮崎県宮崎市川原町');
ok($zip->set_number('8800867')->is_valid_number, '宮崎県宮崎市瀬頭');
ok($zip->set_number('8800868')->is_valid_number, '宮崎県宮崎市瀬頭町');
ok($zip->set_number('8800871')->is_valid_number, '宮崎県宮崎市大王町');
ok($zip->set_number('8800872')->is_valid_number, '宮崎県宮崎市永楽町');
ok($zip->set_number('8800873')->is_valid_number, '宮崎県宮崎市堀川町');
ok($zip->set_number('8800874')->is_valid_number, '宮崎県宮崎市昭和町');
ok($zip->set_number('8800875')->is_valid_number, '宮崎県宮崎市曽師町');
ok($zip->set_number('8800876')->is_valid_number, '宮崎県宮崎市浄土江町');
ok($zip->set_number('8800877')->is_valid_number, '宮崎県宮崎市宮脇町');
ok($zip->set_number('8800878')->is_valid_number, '宮崎県宮崎市大和町');
ok($zip->set_number('8800879')->is_valid_number, '宮崎県宮崎市宮崎駅東');
ok($zip->set_number('8800901')->is_valid_number, '宮崎県宮崎市東大淀');
ok($zip->set_number('8800902')->is_valid_number, '宮崎県宮崎市大淀');
ok($zip->set_number('8800903')->is_valid_number, '宮崎県宮崎市太田');
ok($zip->set_number('8800904')->is_valid_number, '宮崎県宮崎市中村東');
ok($zip->set_number('8800905')->is_valid_number, '宮崎県宮崎市中村西');
ok($zip->set_number('8800906')->is_valid_number, '宮崎県宮崎市南町');
ok($zip->set_number('8800907')->is_valid_number, '宮崎県宮崎市淀川');
ok($zip->set_number('8800908')->is_valid_number, '宮崎県宮崎市谷川');
ok($zip->set_number('8800909')->is_valid_number, '宮崎県宮崎市谷川町');
ok($zip->set_number('8800911')->is_valid_number, '宮崎県宮崎市田吉');
ok($zip->set_number('8800912')->is_valid_number, '宮崎県宮崎市赤江');
ok($zip->set_number('8800913')->is_valid_number, '宮崎県宮崎市恒久(丁目)');
ok($zip->set_number('8800914')->is_valid_number, '宮崎県宮崎市宮の元町');
ok($zip->set_number('8800915')->is_valid_number, '宮崎県宮崎市恒久南');
ok($zip->set_number('8800916')->is_valid_number, '宮崎県宮崎市恒久(番地)');
ok($zip->set_number('8800917')->is_valid_number, '宮崎県宮崎市城ケ崎');
ok($zip->set_number('8800921')->is_valid_number, '宮崎県宮崎市本郷南方');
ok($zip->set_number('8800922')->is_valid_number, '宮崎県宮崎市本郷');
ok($zip->set_number('8800923')->is_valid_number, '宮崎県宮崎市希望ケ丘');
ok($zip->set_number('8800924')->is_valid_number, '宮崎県宮崎市郡司分');
ok($zip->set_number('8800925')->is_valid_number, '宮崎県宮崎市本郷北方');
ok($zip->set_number('8800926')->is_valid_number, '宮崎県宮崎市月見ケ丘');
ok($zip->set_number('8800927')->is_valid_number, '宮崎県宮崎市源藤町');
ok($zip->set_number('8800928')->is_valid_number, '宮崎県宮崎市東宮');
ok($zip->set_number('8800929')->is_valid_number, '宮崎県宮崎市まなび野');
ok($zip->set_number('8800930')->is_valid_number, '宮崎県宮崎市花山手東');
ok($zip->set_number('8800931')->is_valid_number, '宮崎県宮崎市古城町');
ok($zip->set_number('8800932')->is_valid_number, '宮崎県宮崎市大坪西');
ok($zip->set_number('8800933')->is_valid_number, '宮崎県宮崎市大坪町');
ok($zip->set_number('8800934')->is_valid_number, '宮崎県宮崎市大坪東');
ok($zip->set_number('8800935')->is_valid_number, '宮崎県宮崎市天満町');
ok($zip->set_number('8800936')->is_valid_number, '宮崎県宮崎市天満');
ok($zip->set_number('8800937')->is_valid_number, '宮崎県宮崎市京塚');
ok($zip->set_number('8800938')->is_valid_number, '宮崎県宮崎市京塚町');
ok($zip->set_number('8800939')->is_valid_number, '宮崎県宮崎市花山手西');
ok($zip->set_number('8800941')->is_valid_number, '宮崎県宮崎市北川内町');
ok($zip->set_number('8800942')->is_valid_number, '宮崎県宮崎市生目台東');
ok($zip->set_number('8800943')->is_valid_number, '宮崎県宮崎市生目台西');
ok($zip->set_number('8800944')->is_valid_number, '宮崎県宮崎市江南');
ok($zip->set_number('8800945')->is_valid_number, '宮崎県宮崎市福島町(番地)');
ok($zip->set_number('8800946')->is_valid_number, '宮崎県宮崎市福島町(丁目)');
ok($zip->set_number('8800947')->is_valid_number, '宮崎県宮崎市薫る坂');
ok($zip->set_number('8800951')->is_valid_number, '宮崎県宮崎市大塚町');
ok($zip->set_number('8800952')->is_valid_number, '宮崎県宮崎市大塚台東');
ok($zip->set_number('8800953')->is_valid_number, '宮崎県宮崎市小松台東');
ok($zip->set_number('8800954')->is_valid_number, '宮崎県宮崎市小松台西');
ok($zip->set_number('8800955')->is_valid_number, '宮崎県宮崎市桜ケ丘町');
ok($zip->set_number('8800956')->is_valid_number, '宮崎県宮崎市小松台南町');
ok($zip->set_number('8801100')->is_valid_number, '宮崎県東諸県郡国富町以下に掲載がない場合');
ok($zip->set_number('8801101')->is_valid_number, '宮崎県東諸県郡国富町本庄');
ok($zip->set_number('8801102')->is_valid_number, '宮崎県東諸県郡国富町宮王丸');
ok($zip->set_number('8801103')->is_valid_number, '宮崎県東諸県郡国富町嵐田');
ok($zip->set_number('8801104')->is_valid_number, '宮崎県東諸県郡国富町田尻');
ok($zip->set_number('8801105')->is_valid_number, '宮崎県東諸県郡国富町向高');
ok($zip->set_number('8801106')->is_valid_number, '宮崎県東諸県郡国富町森永');
ok($zip->set_number('8801107')->is_valid_number, '宮崎県東諸県郡国富町竹田');
ok($zip->set_number('8801108')->is_valid_number, '宮崎県東諸県郡国富町須志田');
ok($zip->set_number('8801111')->is_valid_number, '宮崎県東諸県郡国富町岩知野');
ok($zip->set_number('8801112')->is_valid_number, '宮崎県東諸県郡国富町塚原');
ok($zip->set_number('8801113')->is_valid_number, '宮崎県東諸県郡国富町木脇');
ok($zip->set_number('8801114')->is_valid_number, '宮崎県東諸県郡国富町三名');
ok($zip->set_number('8801121')->is_valid_number, '宮崎県東諸県郡国富町伊左生(吹上)');
ok($zip->set_number('8801221')->is_valid_number, '宮崎県東諸県郡国富町伊左生(その他)');
ok($zip->set_number('8801222')->is_valid_number, '宮崎県東諸県郡国富町八代北俣');
ok($zip->set_number('8801223')->is_valid_number, '宮崎県東諸県郡国富町八代南俣');
ok($zip->set_number('8801224')->is_valid_number, '宮崎県東諸県郡国富町深年');
ok($zip->set_number('8801300')->is_valid_number, '宮崎県東諸県郡綾町以下に掲載がない場合');
ok($zip->set_number('8801301')->is_valid_number, '宮崎県東諸県郡綾町入野');
ok($zip->set_number('8801302')->is_valid_number, '宮崎県東諸県郡綾町北俣');
ok($zip->set_number('8801303')->is_valid_number, '宮崎県東諸県郡綾町南俣');
ok($zip->set_number('8802101')->is_valid_number, '宮崎県宮崎市跡江');
ok($zip->set_number('8802102')->is_valid_number, '宮崎県宮崎市有田');
ok($zip->set_number('8802103')->is_valid_number, '宮崎県宮崎市生目');
ok($zip->set_number('8802104')->is_valid_number, '宮崎県宮崎市浮田');
ok($zip->set_number('8802105')->is_valid_number, '宮崎県宮崎市大塚台西');
ok($zip->set_number('8802111')->is_valid_number, '宮崎県宮崎市柏原');
ok($zip->set_number('8802112')->is_valid_number, '宮崎県宮崎市小松');
ok($zip->set_number('8802113')->is_valid_number, '宮崎県宮崎市小松台北町');
ok($zip->set_number('8802114')->is_valid_number, '宮崎県宮崎市富吉');
ok($zip->set_number('8802115')->is_valid_number, '宮崎県宮崎市長嶺');
ok($zip->set_number('8802116')->is_valid_number, '宮崎県宮崎市細江(その他)');
ok($zip->set_number('8802211')->is_valid_number, '宮崎県宮崎市高岡町花見');
ok($zip->set_number('8802212')->is_valid_number, '宮崎県宮崎市高岡町下倉永');
ok($zip->set_number('8802213')->is_valid_number, '宮崎県宮崎市高岡町上倉永(その他)');
ok($zip->set_number('8802214')->is_valid_number, '宮崎県宮崎市高岡町小山田');
ok($zip->set_number('8802215')->is_valid_number, '宮崎県宮崎市高岡町高浜');
ok($zip->set_number('8802221')->is_valid_number, '宮崎県宮崎市高岡町内山(1~3214番地)');
ok($zip->set_number('8802222')->is_valid_number, '宮崎県宮崎市高岡町五町(1~3137番地)');
ok($zip->set_number('8802223')->is_valid_number, '宮崎県宮崎市高岡町浦之名(2793~4389番地)');
ok($zip->set_number('8802224')->is_valid_number, '宮崎県宮崎市高岡町飯田');
ok($zip->set_number('8802231')->is_valid_number, '宮崎県宮崎市糸原');
ok($zip->set_number('8802232')->is_valid_number, '宮崎県宮崎市堤内');
ok($zip->set_number('8802233')->is_valid_number, '宮崎県宮崎市吉野');
ok($zip->set_number('8802234')->is_valid_number, '宮崎県宮崎市金崎');
ok($zip->set_number('8802303')->is_valid_number, '宮崎県都城市山之口町山之口(上平野、仲田)');
ok($zip->set_number('8802321')->is_valid_number, '宮崎県宮崎市高岡町内山(その他)');
ok($zip->set_number('8802322')->is_valid_number, '宮崎県宮崎市高岡町五町(その他)');
ok($zip->set_number('8802323')->is_valid_number, '宮崎県宮崎市高岡町浦之名(その他)');
ok($zip->set_number('8802325')->is_valid_number, '宮崎県宮崎市高岡町紙屋');
ok($zip->set_number('8810000')->is_valid_number, '宮崎県西都市以下に掲載がない場合');
ok($zip->set_number('8810001')->is_valid_number, '宮崎県西都市岡富');
ok($zip->set_number('8810002')->is_valid_number, '宮崎県西都市黒生野');
ok($zip->set_number('8810003')->is_valid_number, '宮崎県西都市右松');
ok($zip->set_number('8810004')->is_valid_number, '宮崎県西都市清水');
ok($zip->set_number('8810005')->is_valid_number, '宮崎県西都市三宅');
ok($zip->set_number('8810006')->is_valid_number, '宮崎県西都市新町');
ok($zip->set_number('8810011')->is_valid_number, '宮崎県西都市有吉町');
ok($zip->set_number('8810012')->is_valid_number, '宮崎県西都市小野崎');
ok($zip->set_number('8810013')->is_valid_number, '宮崎県西都市小野崎町');
ok($zip->set_number('8810014')->is_valid_number, '宮崎県西都市下妻');
ok($zip->set_number('8810015')->is_valid_number, '宮崎県西都市聖陵町');
ok($zip->set_number('8810016')->is_valid_number, '宮崎県西都市御舟町');
ok($zip->set_number('8810021')->is_valid_number, '宮崎県西都市上町');
ok($zip->set_number('8810022')->is_valid_number, '宮崎県西都市桜川町');
ok($zip->set_number('8810023')->is_valid_number, '宮崎県西都市調殿');
ok($zip->set_number('8810024')->is_valid_number, '宮崎県西都市中妻');
ok($zip->set_number('8810025')->is_valid_number, '宮崎県西都市童子丸');
ok($zip->set_number('8810026')->is_valid_number, '宮崎県西都市穂北');
ok($zip->set_number('8810027')->is_valid_number, '宮崎県西都市南方');
ok($zip->set_number('8810031')->is_valid_number, '宮崎県西都市旭');
ok($zip->set_number('8810032')->is_valid_number, '宮崎県西都市白馬町');
ok($zip->set_number('8810033')->is_valid_number, '宮崎県西都市妻');
ok($zip->set_number('8810034')->is_valid_number, '宮崎県西都市妻町');
ok($zip->set_number('8810035')->is_valid_number, '宮崎県西都市中央町');
ok($zip->set_number('8810036')->is_valid_number, '宮崎県西都市水流崎町');
ok($zip->set_number('8810037')->is_valid_number, '宮崎県西都市茶臼原');
ok($zip->set_number('8810101')->is_valid_number, '宮崎県西都市三納');
ok($zip->set_number('8810102')->is_valid_number, '宮崎県西都市平郡');
ok($zip->set_number('8810103')->is_valid_number, '宮崎県西都市加勢');
ok($zip->set_number('8810104')->is_valid_number, '宮崎県西都市鹿野田');
ok($zip->set_number('8810105')->is_valid_number, '宮崎県西都市都於郡町');
ok($zip->set_number('8810106')->is_valid_number, '宮崎県西都市岩爪');
ok($zip->set_number('8810111')->is_valid_number, '宮崎県西都市荒武');
ok($zip->set_number('8810112')->is_valid_number, '宮崎県西都市山田');
ok($zip->set_number('8810113')->is_valid_number, '宮崎県西都市下三財');
ok($zip->set_number('8810114')->is_valid_number, '宮崎県西都市藤田');
ok($zip->set_number('8810115')->is_valid_number, '宮崎県西都市上三財');
ok($zip->set_number('8810116')->is_valid_number, '宮崎県西都市寒川');
ok($zip->set_number('8811121')->is_valid_number, '宮崎県西都市尾八重');
ok($zip->set_number('8811122')->is_valid_number, '宮崎県西都市片内');
ok($zip->set_number('8811123')->is_valid_number, '宮崎県西都市中尾');
ok($zip->set_number('8811231')->is_valid_number, '宮崎県西都市上揚');
ok($zip->set_number('8811232')->is_valid_number, '宮崎県西都市銀鏡');
ok($zip->set_number('8811233')->is_valid_number, '宮崎県西都市八重');
ok($zip->set_number('8811301')->is_valid_number, '宮崎県児湯郡西米良村越野尾');
ok($zip->set_number('8811302')->is_valid_number, '宮崎県児湯郡西米良村小川');
ok($zip->set_number('8811303')->is_valid_number, '宮崎県児湯郡西米良村横野');
ok($zip->set_number('8811400')->is_valid_number, '宮崎県児湯郡西米良村以下に掲載がない場合');
ok($zip->set_number('8811411')->is_valid_number, '宮崎県児湯郡西米良村村所');
ok($zip->set_number('8811412')->is_valid_number, '宮崎県児湯郡西米良村板谷');
ok($zip->set_number('8811413')->is_valid_number, '宮崎県児湯郡西米良村上米良');
ok($zip->set_number('8811414')->is_valid_number, '宮崎県児湯郡西米良村竹原');
ok($zip->set_number('8820000')->is_valid_number, '宮崎県延岡市以下に掲載がない場合');
ok($zip->set_number('8820001')->is_valid_number, '宮崎県延岡市大峡町');
ok($zip->set_number('8820002')->is_valid_number, '宮崎県延岡市差木野町');
ok($zip->set_number('8820003')->is_valid_number, '宮崎県延岡市稲葉崎町');
ok($zip->set_number('8820004')->is_valid_number, '宮崎県延岡市樫山町');
ok($zip->set_number('8820005')->is_valid_number, '宮崎県延岡市夏田町');
ok($zip->set_number('8820006')->is_valid_number, '宮崎県延岡市尾崎町');
ok($zip->set_number('8820007')->is_valid_number, '宮崎県延岡市桜ケ丘');
ok($zip->set_number('8820011')->is_valid_number, '宮崎県延岡市須佐町');
ok($zip->set_number('8820012')->is_valid_number, '宮崎県延岡市鹿小路');
ok($zip->set_number('8820013')->is_valid_number, '宮崎県延岡市追内町');
ok($zip->set_number('8820014')->is_valid_number, '宮崎県延岡市白石町');
ok($zip->set_number('8820015')->is_valid_number, '宮崎県延岡市水尻町');
ok($zip->set_number('8820016')->is_valid_number, '宮崎県延岡市東海町');
ok($zip->set_number('8820017')->is_valid_number, '宮崎県延岡市川島町');
ok($zip->set_number('8820021')->is_valid_number, '宮崎県延岡市無鹿町');
ok($zip->set_number('8820022')->is_valid_number, '宮崎県延岡市二ツ島町');
ok($zip->set_number('8820023')->is_valid_number, '宮崎県延岡市牧町');
ok($zip->set_number('8820024')->is_valid_number, '宮崎県延岡市大武町');
ok($zip->set_number('8820025')->is_valid_number, '宮崎県延岡市粟野名町');
ok($zip->set_number('8820026')->is_valid_number, '宮崎県延岡市柚の木田町');
ok($zip->set_number('8820027')->is_valid_number, '宮崎県延岡市大門町');
ok($zip->set_number('8820031')->is_valid_number, '宮崎県延岡市中川原町');
ok($zip->set_number('8820032')->is_valid_number, '宮崎県延岡市中の瀬町');
ok($zip->set_number('8820033')->is_valid_number, '宮崎県延岡市川原崎町');
ok($zip->set_number('8820034')->is_valid_number, '宮崎県延岡市昭和町');
ok($zip->set_number('8820035')->is_valid_number, '宮崎県延岡市日の出町');
ok($zip->set_number('8820036')->is_valid_number, '宮崎県延岡市桜園町');
ok($zip->set_number('8820037')->is_valid_number, '宮崎県延岡市山月町');
ok($zip->set_number('8820041')->is_valid_number, '宮崎県延岡市北小路');
ok($zip->set_number('8820042')->is_valid_number, '宮崎県延岡市高千穂通');
ok($zip->set_number('8820043')->is_valid_number, '宮崎県延岡市祗園町');
ok($zip->set_number('8820044')->is_valid_number, '宮崎県延岡市博労町');
ok($zip->set_number('8820045')->is_valid_number, '宮崎県延岡市瀬之口町');
ok($zip->set_number('8820046')->is_valid_number, '宮崎県延岡市恵比須町');
ok($zip->set_number('8820047')->is_valid_number, '宮崎県延岡市紺屋町');
ok($zip->set_number('8820051')->is_valid_number, '宮崎県延岡市富美山町');
ok($zip->set_number('8820052')->is_valid_number, '宮崎県延岡市萩町');
ok($zip->set_number('8820053')->is_valid_number, '宮崎県延岡市幸町');
ok($zip->set_number('8820054')->is_valid_number, '宮崎県延岡市栄町');
ok($zip->set_number('8820055')->is_valid_number, '宮崎県延岡市山下町');
ok($zip->set_number('8820056')->is_valid_number, '宮崎県延岡市岡富町');
ok($zip->set_number('8820057')->is_valid_number, '宮崎県延岡市岡富山');
ok($zip->set_number('8820061')->is_valid_number, '宮崎県延岡市小峰町');
ok($zip->set_number('8820062')->is_valid_number, '宮崎県延岡市松山町');
ok($zip->set_number('8820063')->is_valid_number, '宮崎県延岡市古川町');
ok($zip->set_number('8820064')->is_valid_number, '宮崎県延岡市高野町');
ok($zip->set_number('8820065')->is_valid_number, '宮崎県延岡市平田町');
ok($zip->set_number('8820066')->is_valid_number, '宮崎県延岡市舞野町');
ok($zip->set_number('8820071')->is_valid_number, '宮崎県延岡市天下町');
ok($zip->set_number('8820072')->is_valid_number, '宮崎県延岡市吉野町');
ok($zip->set_number('8820073')->is_valid_number, '宮崎県延岡市貝の畑町');
ok($zip->set_number('8820074')->is_valid_number, '宮崎県延岡市細見町');
ok($zip->set_number('8820075')->is_valid_number, '宮崎県延岡市岡元町');
ok($zip->set_number('8820076')->is_valid_number, '宮崎県延岡市小川町');
ok($zip->set_number('8820077')->is_valid_number, '宮崎県延岡市行縢町');
ok($zip->set_number('8820081')->is_valid_number, '宮崎県延岡市佐野町');
ok($zip->set_number('8820082')->is_valid_number, '宮崎県延岡市祝子町');
ok($zip->set_number('8820083')->is_valid_number, '宮崎県延岡市柚木町');
ok($zip->set_number('8820084')->is_valid_number, '宮崎県延岡市宇和田町');
ok($zip->set_number('8820085')->is_valid_number, '宮崎県延岡市鹿狩瀬町');
ok($zip->set_number('8820086')->is_valid_number, '宮崎県延岡市大野町');
ok($zip->set_number('8820087')->is_valid_number, '宮崎県延岡市妙町');
ok($zip->set_number('8820091')->is_valid_number, '宮崎県延岡市桑平町');
ok($zip->set_number('8820092')->is_valid_number, '宮崎県延岡市宮長町');
ok($zip->set_number('8820093')->is_valid_number, '宮崎県延岡市神戸町');
ok($zip->set_number('8820094')->is_valid_number, '宮崎県延岡市安井町');
ok($zip->set_number('8820095')->is_valid_number, '宮崎県延岡市浦城町');
ok($zip->set_number('8820096')->is_valid_number, '宮崎県延岡市島浦町');
ok($zip->set_number('8820097')->is_valid_number, '宮崎県延岡市北川町川内名(祝子川)');
ok($zip->set_number('8820101')->is_valid_number, '宮崎県延岡市北方町二股');
ok($zip->set_number('8820104')->is_valid_number, '宮崎県延岡市北方町角田');
ok($zip->set_number('8820106')->is_valid_number, '宮崎県延岡市北方町笠下');
ok($zip->set_number('8820107')->is_valid_number, '宮崎県延岡市北方町藤の木');
ok($zip->set_number('8820121')->is_valid_number, '宮崎県延岡市北方町板上');
ok($zip->set_number('8820122')->is_valid_number, '宮崎県延岡市北方町板下');
ok($zip->set_number('8820123')->is_valid_number, '宮崎県延岡市北方町うそ越');
ok($zip->set_number('8820124')->is_valid_number, '宮崎県延岡市北方町曽木');
ok($zip->set_number('8820125')->is_valid_number, '宮崎県延岡市北方町川水流');
ok($zip->set_number('8820126')->is_valid_number, '宮崎県延岡市北方町上崎');
ok($zip->set_number('8820127')->is_valid_number, '宮崎県延岡市北方町蔵田');
ok($zip->set_number('8820128')->is_valid_number, '宮崎県延岡市北方町南久保山');
ok($zip->set_number('8820129')->is_valid_number, '宮崎県延岡市北方町北久保山');
ok($zip->set_number('8820231')->is_valid_number, '宮崎県延岡市北方町上鹿川');
ok($zip->set_number('8820232')->is_valid_number, '宮崎県延岡市北方町下鹿川');
ok($zip->set_number('8820233')->is_valid_number, '宮崎県延岡市北方町菅原');
ok($zip->set_number('8820234')->is_valid_number, '宮崎県延岡市北方町美々地');
ok($zip->set_number('8820235')->is_valid_number, '宮崎県延岡市北方町槇峰');
ok($zip->set_number('8820236')->is_valid_number, '宮崎県延岡市北方町日平');
ok($zip->set_number('8820237')->is_valid_number, '宮崎県延岡市北方町椎畑');
ok($zip->set_number('8820238')->is_valid_number, '宮崎県延岡市北方町滝下');
ok($zip->set_number('8820241')->is_valid_number, '宮崎県延岡市北方町三ケ村');
ok($zip->set_number('8820242')->is_valid_number, '宮崎県延岡市北方町八峡');
ok($zip->set_number('8820243')->is_valid_number, '宮崎県延岡市北方町早日渡');
ok($zip->set_number('8820244')->is_valid_number, '宮崎県延岡市北方町早中');
ok($zip->set_number('8820245')->is_valid_number, '宮崎県延岡市北方町早上');
ok($zip->set_number('8820301')->is_valid_number, '宮崎県西臼杵郡日之影町七折(阿下、笠戸、椛木、鹿川、新町、滝ノ内、中川、');
ok($zip->set_number('8820301')->is_valid_number, '宮崎県西臼杵郡日之影町西ノ内、舟ノ尾、八戸、簗崎)');
ok($zip->set_number('8820302')->is_valid_number, '宮崎県西臼杵郡日之影町岩井川(境野)');
ok($zip->set_number('8820304')->is_valid_number, '宮崎県西臼杵郡日之影町分城');
ok($zip->set_number('8820400')->is_valid_number, '宮崎県西臼杵郡日之影町以下に掲載がない場合');
ok($zip->set_number('8820401')->is_valid_number, '宮崎県西臼杵郡日之影町七折(その他)');
ok($zip->set_number('8820402')->is_valid_number, '宮崎県西臼杵郡日之影町岩井川(その他)');
ok($zip->set_number('8820403')->is_valid_number, '宮崎県西臼杵郡日之影町見立');
ok($zip->set_number('8820801')->is_valid_number, '宮崎県延岡市野田町');
ok($zip->set_number('8820802')->is_valid_number, '宮崎県延岡市野地町');
ok($zip->set_number('8820803')->is_valid_number, '宮崎県延岡市大貫町');
ok($zip->set_number('8820804')->is_valid_number, '宮崎県延岡市西階町');
ok($zip->set_number('8820805')->is_valid_number, '宮崎県延岡市野田');
ok($zip->set_number('8820811')->is_valid_number, '宮崎県延岡市天神小路');
ok($zip->set_number('8820812')->is_valid_number, '宮崎県延岡市本小路');
ok($zip->set_number('8820813')->is_valid_number, '宮崎県延岡市東本小路');
ok($zip->set_number('8820814')->is_valid_number, '宮崎県延岡市北町');
ok($zip->set_number('8820815')->is_valid_number, '宮崎県延岡市柳沢町');
ok($zip->set_number('8820816')->is_valid_number, '宮崎県延岡市桜小路');
ok($zip->set_number('8820821')->is_valid_number, '宮崎県延岡市本町');
ok($zip->set_number('8820822')->is_valid_number, '宮崎県延岡市南町');
ok($zip->set_number('8820823')->is_valid_number, '宮崎県延岡市中町');
ok($zip->set_number('8820824')->is_valid_number, '宮崎県延岡市中央通');
ok($zip->set_number('8820825')->is_valid_number, '宮崎県延岡市須崎町');
ok($zip->set_number('8820826')->is_valid_number, '宮崎県延岡市船倉町');
ok($zip->set_number('8820827')->is_valid_number, '宮崎県延岡市新町');
ok($zip->set_number('8820831')->is_valid_number, '宮崎県延岡市出口町');
ok($zip->set_number('8820832')->is_valid_number, '宮崎県延岡市西小路');
ok($zip->set_number('8820833')->is_valid_number, '宮崎県延岡市上大瀬町');
ok($zip->set_number('8820834')->is_valid_number, '宮崎県延岡市北新小路');
ok($zip->set_number('8820835')->is_valid_number, '宮崎県延岡市新小路');
ok($zip->set_number('8820836')->is_valid_number, '宮崎県延岡市恒富町');
ok($zip->set_number('8820837')->is_valid_number, '宮崎県延岡市古城町');
ok($zip->set_number('8820841')->is_valid_number, '宮崎県延岡市大瀬町');
ok($zip->set_number('8820842')->is_valid_number, '宮崎県延岡市三ツ瀬町');
ok($zip->set_number('8820843')->is_valid_number, '宮崎県延岡市永池町');
ok($zip->set_number('8820844')->is_valid_number, '宮崎県延岡市春日町');
ok($zip->set_number('8820845')->is_valid_number, '宮崎県延岡市安賀多町');
ok($zip->set_number('8820846')->is_valid_number, '宮崎県延岡市中島町');
ok($zip->set_number('8820847')->is_valid_number, '宮崎県延岡市旭町');
ok($zip->set_number('8820851')->is_valid_number, '宮崎県延岡市浜砂');
ok($zip->set_number('8820852')->is_valid_number, '宮崎県延岡市東浜砂町');
ok($zip->set_number('8820853')->is_valid_number, '宮崎県延岡市方財町');
ok($zip->set_number('8820854')->is_valid_number, '宮崎県延岡市長浜町');
ok($zip->set_number('8820855')->is_valid_number, '宮崎県延岡市卸本町');
ok($zip->set_number('8820856')->is_valid_number, '宮崎県延岡市出北');
ok($zip->set_number('8820857')->is_valid_number, '宮崎県延岡市惣領町');
ok($zip->set_number('8820861')->is_valid_number, '宮崎県延岡市別府町');
ok($zip->set_number('8820862')->is_valid_number, '宮崎県延岡市浜町');
ok($zip->set_number('8820863')->is_valid_number, '宮崎県延岡市緑ケ丘');
ok($zip->set_number('8820864')->is_valid_number, '宮崎県延岡市塩浜町');
ok($zip->set_number('8820865')->is_valid_number, '宮崎県延岡市鶴ケ丘');
ok($zip->set_number('8820866')->is_valid_number, '宮崎県延岡市平原町');
ok($zip->set_number('8820867')->is_valid_number, '宮崎県延岡市構口町');
ok($zip->set_number('8820871')->is_valid_number, '宮崎県延岡市愛宕山');
ok($zip->set_number('8820872')->is_valid_number, '宮崎県延岡市愛宕町');
ok($zip->set_number('8820873')->is_valid_number, '宮崎県延岡市共栄町');
ok($zip->set_number('8820874')->is_valid_number, '宮崎県延岡市伊達町');
ok($zip->set_number('8820875')->is_valid_number, '宮崎県延岡市若葉町');
ok($zip->set_number('8820876')->is_valid_number, '宮崎県延岡市沖田町');
ok($zip->set_number('8820877')->is_valid_number, '宮崎県延岡市片田町');
ok($zip->set_number('8820881')->is_valid_number, '宮崎県延岡市三須町');
ok($zip->set_number('8820882')->is_valid_number, '宮崎県延岡市小野町');
ok($zip->set_number('8820883')->is_valid_number, '宮崎県延岡市下三輪町');
ok($zip->set_number('8820884')->is_valid_number, '宮崎県延岡市中三輪町');
ok($zip->set_number('8820885')->is_valid_number, '宮崎県延岡市上三輪町');
ok($zip->set_number('8821100')->is_valid_number, '宮崎県西臼杵郡高千穂町以下に掲載がない場合');
ok($zip->set_number('8821101')->is_valid_number, '宮崎県西臼杵郡高千穂町三田井');
ok($zip->set_number('8821102')->is_valid_number, '宮崎県西臼杵郡高千穂町押方');
ok($zip->set_number('8821103')->is_valid_number, '宮崎県西臼杵郡高千穂町向山');
ok($zip->set_number('8821200')->is_valid_number, '宮崎県西臼杵郡五ヶ瀬町以下に掲載がない場合');
ok($zip->set_number('8821201')->is_valid_number, '宮崎県西臼杵郡五ヶ瀬町鞍岡');
ok($zip->set_number('8821202')->is_valid_number, '宮崎県西臼杵郡五ヶ瀬町桑野内');
ok($zip->set_number('8821203')->is_valid_number, '宮崎県西臼杵郡五ヶ瀬町三ヶ所');
ok($zip->set_number('8821411')->is_valid_number, '宮崎県西臼杵郡高千穂町上野');
ok($zip->set_number('8821412')->is_valid_number, '宮崎県西臼杵郡高千穂町下野');
ok($zip->set_number('8821413')->is_valid_number, '宮崎県西臼杵郡高千穂町田原');
ok($zip->set_number('8821414')->is_valid_number, '宮崎県西臼杵郡高千穂町河内');
ok($zip->set_number('8821415')->is_valid_number, '宮崎県西臼杵郡高千穂町五ケ所');
ok($zip->set_number('8821621')->is_valid_number, '宮崎県西臼杵郡高千穂町岩戸');
ok($zip->set_number('8821622')->is_valid_number, '宮崎県西臼杵郡高千穂町上岩戸');
ok($zip->set_number('8830000')->is_valid_number, '宮崎県日向市以下に掲載がない場合');
ok($zip->set_number('8830001')->is_valid_number, '宮崎県日向市細島');
ok($zip->set_number('8830002')->is_valid_number, '宮崎県日向市平野町');
ok($zip->set_number('8830003')->is_valid_number, '宮崎県日向市伊勢ケ浜');
ok($zip->set_number('8830004')->is_valid_number, '宮崎県日向市浜町');
ok($zip->set_number('8830005')->is_valid_number, '宮崎県日向市中堀町');
ok($zip->set_number('8830006')->is_valid_number, '宮崎県日向市山手町');
ok($zip->set_number('8830011')->is_valid_number, '宮崎県日向市曽根町');
ok($zip->set_number('8830012')->is_valid_number, '宮崎県日向市江良町');
ok($zip->set_number('8830013')->is_valid_number, '宮崎県日向市新生町');
ok($zip->set_number('8830014')->is_valid_number, '宮崎県日向市原町');
ok($zip->set_number('8830015')->is_valid_number, '宮崎県日向市永江町');
ok($zip->set_number('8830021')->is_valid_number, '宮崎県日向市財光寺');
ok($zip->set_number('8830022')->is_valid_number, '宮崎県日向市平岩');
ok($zip->set_number('8830023')->is_valid_number, '宮崎県日向市財光寺沖町');
ok($zip->set_number('8830024')->is_valid_number, '宮崎県日向市財光寺往還町');
ok($zip->set_number('8830031')->is_valid_number, '宮崎県日向市比良町');
ok($zip->set_number('8830032')->is_valid_number, '宮崎県日向市山下町');
ok($zip->set_number('8830033')->is_valid_number, '宮崎県日向市塩見');
ok($zip->set_number('8830034')->is_valid_number, '宮崎県日向市富高');
ok($zip->set_number('8830035')->is_valid_number, '宮崎県日向市春原町');
ok($zip->set_number('8830036')->is_valid_number, '宮崎県日向市南町');
ok($zip->set_number('8830037')->is_valid_number, '宮崎県日向市不動寺');
ok($zip->set_number('8830038')->is_valid_number, '宮崎県日向市迎洋園');
ok($zip->set_number('8830041')->is_valid_number, '宮崎県日向市北町');
ok($zip->set_number('8830042')->is_valid_number, '宮崎県日向市高砂町');
ok($zip->set_number('8830043')->is_valid_number, '宮崎県日向市都町');
ok($zip->set_number('8830044')->is_valid_number, '宮崎県日向市上町');
ok($zip->set_number('8830045')->is_valid_number, '宮崎県日向市本町');
ok($zip->set_number('8830046')->is_valid_number, '宮崎県日向市中町');
ok($zip->set_number('8830051')->is_valid_number, '宮崎県日向市向江町');
ok($zip->set_number('8830052')->is_valid_number, '宮崎県日向市鶴町');
ok($zip->set_number('8830053')->is_valid_number, '宮崎県日向市梶木町');
ok($zip->set_number('8830061')->is_valid_number, '宮崎県日向市大王町');
ok($zip->set_number('8830062')->is_valid_number, '宮崎県日向市日知屋');
ok($zip->set_number('8830063')->is_valid_number, '宮崎県日向市竹島町');
ok($zip->set_number('8830064')->is_valid_number, '宮崎県日向市日知屋古田町');
ok($zip->set_number('8830065')->is_valid_number, '宮崎県日向市船場町');
ok($zip->set_number('8830066')->is_valid_number, '宮崎県日向市亀崎');
ok($zip->set_number('8830067')->is_valid_number, '宮崎県日向市亀崎東');
ok($zip->set_number('8830068')->is_valid_number, '宮崎県日向市亀崎西');
ok($zip->set_number('8830101')->is_valid_number, '宮崎県日向市東郷町山陰乙(その他)');
ok($zip->set_number('8830102')->is_valid_number, '宮崎県日向市東郷町山陰丙');
ok($zip->set_number('8830103')->is_valid_number, '宮崎県日向市東郷町山陰丁');
ok($zip->set_number('8830104')->is_valid_number, '宮崎県日向市東郷町山陰戊(513の1以内)');
ok($zip->set_number('8830105')->is_valid_number, '宮崎県日向市東郷町山陰己');
ok($zip->set_number('8830106')->is_valid_number, '宮崎県日向市東郷町山陰辛');
ok($zip->set_number('8830107')->is_valid_number, '宮崎県日向市東郷町山陰庚');
ok($zip->set_number('8830108')->is_valid_number, '宮崎県日向市東郷町八重原');
ok($zip->set_number('8830109')->is_valid_number, '宮崎県日向市東郷町山陰');
ok($zip->set_number('8830111')->is_valid_number, '宮崎県日向市東郷町迫野内');
ok($zip->set_number('8830211')->is_valid_number, '宮崎県日向市東郷町坪谷');
ok($zip->set_number('8830212')->is_valid_number, '宮崎県日向市東郷町山陰戊(その他)');
ok($zip->set_number('8830213')->is_valid_number, '宮崎県日向市東郷町下三ケ');
ok($zip->set_number('8830301')->is_valid_number, '宮崎県東臼杵郡美郷町南郷水清谷');
ok($zip->set_number('8830302')->is_valid_number, '宮崎県東臼杵郡美郷町南郷中渡川');
ok($zip->set_number('8830303')->is_valid_number, '宮崎県東臼杵郡美郷町南郷上渡川');
ok($zip->set_number('8830304')->is_valid_number, '宮崎県東臼杵郡美郷町南郷鬼神野');
ok($zip->set_number('8830305')->is_valid_number, '宮崎県東臼杵郡美郷町南郷山三ヶ');
ok($zip->set_number('8830306')->is_valid_number, '宮崎県東臼杵郡美郷町南郷神門');
ok($zip->set_number('8830402')->is_valid_number, '宮崎県東臼杵郡椎葉村大河内(1~1302番地)');
ok($zip->set_number('8831100')->is_valid_number, '宮崎県東臼杵郡美郷町以下に掲載がない場合');
ok($zip->set_number('8831101')->is_valid_number, '宮崎県東臼杵郡美郷町西郷田代');
ok($zip->set_number('8831102')->is_valid_number, '宮崎県東臼杵郡美郷町西郷立石');
ok($zip->set_number('8831211')->is_valid_number, '宮崎県東臼杵郡美郷町西郷山三ヶ');
ok($zip->set_number('8831212')->is_valid_number, '宮崎県東臼杵郡美郷町西郷小原');
ok($zip->set_number('8831300')->is_valid_number, '宮崎県東臼杵郡諸塚村以下に掲載がない場合');
ok($zip->set_number('8831301')->is_valid_number, '宮崎県東臼杵郡諸塚村家代');
ok($zip->set_number('8831302')->is_valid_number, '宮崎県東臼杵郡諸塚村七ツ山(その他)');
ok($zip->set_number('8831402')->is_valid_number, '宮崎県東臼杵郡諸塚村七ツ山(飯干、小原井、川内、立岩、八重の平、本村)');
ok($zip->set_number('8831600')->is_valid_number, '宮崎県東臼杵郡椎葉村以下に掲載がない場合');
ok($zip->set_number('8831601')->is_valid_number, '宮崎県東臼杵郡椎葉村下福良');
ok($zip->set_number('8831602')->is_valid_number, '宮崎県東臼杵郡椎葉村大河内(その他)');
ok($zip->set_number('8831603')->is_valid_number, '宮崎県東臼杵郡椎葉村不土野');
ok($zip->set_number('8831604')->is_valid_number, '宮崎県東臼杵郡椎葉村松尾');
ok($zip->set_number('8840000')->is_valid_number, '宮崎県児湯郡高鍋町以下に掲載がない場合');
ok($zip->set_number('8840001')->is_valid_number, '宮崎県児湯郡高鍋町高鍋町');
ok($zip->set_number('8840002')->is_valid_number, '宮崎県児湯郡高鍋町北高鍋');
ok($zip->set_number('8840003')->is_valid_number, '宮崎県児湯郡高鍋町南高鍋');
ok($zip->set_number('8840004')->is_valid_number, '宮崎県児湯郡高鍋町蚊口浦');
ok($zip->set_number('8840005')->is_valid_number, '宮崎県児湯郡高鍋町持田');
ok($zip->set_number('8840006')->is_valid_number, '宮崎県児湯郡高鍋町上江');
ok($zip->set_number('8840100')->is_valid_number, '宮崎県児湯郡木城町以下に掲載がない場合');
ok($zip->set_number('8840101')->is_valid_number, '宮崎県児湯郡木城町高城');
ok($zip->set_number('8840102')->is_valid_number, '宮崎県児湯郡木城町椎木');
ok($zip->set_number('8840103')->is_valid_number, '宮崎県児湯郡木城町川原');
ok($zip->set_number('8840104')->is_valid_number, '宮崎県児湯郡木城町石河内');
ok($zip->set_number('8840105')->is_valid_number, '宮崎県児湯郡木城町中之又');
ok($zip->set_number('8850000')->is_valid_number, '宮崎県都城市以下に掲載がない場合');
ok($zip->set_number('8850001')->is_valid_number, '宮崎県都城市金田町');
ok($zip->set_number('8850002')->is_valid_number, '宮崎県都城市太郎坊町');
ok($zip->set_number('8850003')->is_valid_number, '宮崎県都城市高木町');
ok($zip->set_number('8850004')->is_valid_number, '宮崎県都城市都北町');
ok($zip->set_number('8850005')->is_valid_number, '宮崎県都城市神之山町');
ok($zip->set_number('8850006')->is_valid_number, '宮崎県都城市吉尾町');
ok($zip->set_number('8850011')->is_valid_number, '宮崎県都城市下川東');
ok($zip->set_number('8850012')->is_valid_number, '宮崎県都城市上川東');
ok($zip->set_number('8850013')->is_valid_number, '宮崎県都城市郡元町');
ok($zip->set_number('8850014')->is_valid_number, '宮崎県都城市祝吉町');
ok($zip->set_number('8850015')->is_valid_number, '宮崎県都城市千町');
ok($zip->set_number('8850016')->is_valid_number, '宮崎県都城市早水町');
ok($zip->set_number('8850017')->is_valid_number, '宮崎県都城市年見町');
ok($zip->set_number('8850018')->is_valid_number, '宮崎県都城市郡元');
ok($zip->set_number('8850019')->is_valid_number, '宮崎県都城市祝吉');
ok($zip->set_number('8850021')->is_valid_number, '宮崎県都城市平江町');
ok($zip->set_number('8850022')->is_valid_number, '宮崎県都城市小松原町');
ok($zip->set_number('8850023')->is_valid_number, '宮崎県都城市栄町');
ok($zip->set_number('8850024')->is_valid_number, '宮崎県都城市北原町');
ok($zip->set_number('8850025')->is_valid_number, '宮崎県都城市前田町');
ok($zip->set_number('8850026')->is_valid_number, '宮崎県都城市大王町');
ok($zip->set_number('8850031')->is_valid_number, '宮崎県都城市天神町');
ok($zip->set_number('8850032')->is_valid_number, '宮崎県都城市中原町');
ok($zip->set_number('8850033')->is_valid_number, '宮崎県都城市妻ケ丘町');
ok($zip->set_number('8850034')->is_valid_number, '宮崎県都城市菖蒲原町');
ok($zip->set_number('8850035')->is_valid_number, '宮崎県都城市立野町');
ok($zip->set_number('8850036')->is_valid_number, '宮崎県都城市広原町');
ok($zip->set_number('8850037')->is_valid_number, '宮崎県都城市花繰町');
ok($zip->set_number('8850041')->is_valid_number, '宮崎県都城市一万城町');
ok($zip->set_number('8850042')->is_valid_number, '宮崎県都城市上長飯町');
ok($zip->set_number('8850043')->is_valid_number, '宮崎県都城市豊満町');
ok($zip->set_number('8850044')->is_valid_number, '宮崎県都城市安久町');
ok($zip->set_number('8850051')->is_valid_number, '宮崎県都城市蔵原町');
ok($zip->set_number('8850052')->is_valid_number, '宮崎県都城市東町');
ok($zip->set_number('8850053')->is_valid_number, '宮崎県都城市上東町');
ok($zip->set_number('8850054')->is_valid_number, '宮崎県都城市若葉町');
ok($zip->set_number('8850055')->is_valid_number, '宮崎県都城市早鈴町');
ok($zip->set_number('8850061')->is_valid_number, '宮崎県都城市下長飯町');
ok($zip->set_number('8850062')->is_valid_number, '宮崎県都城市大岩田町');
ok($zip->set_number('8850063')->is_valid_number, '宮崎県都城市梅北町');
ok($zip->set_number('8850064')->is_valid_number, '宮崎県都城市今町');
ok($zip->set_number('8850071')->is_valid_number, '宮崎県都城市中町');
ok($zip->set_number('8850072')->is_valid_number, '宮崎県都城市上町');
ok($zip->set_number('8850073')->is_valid_number, '宮崎県都城市姫城町');
ok($zip->set_number('8850074')->is_valid_number, '宮崎県都城市甲斐元町');
ok($zip->set_number('8850075')->is_valid_number, '宮崎県都城市八幡町');
ok($zip->set_number('8850076')->is_valid_number, '宮崎県都城市西町');
ok($zip->set_number('8850077')->is_valid_number, '宮崎県都城市松元町');
ok($zip->set_number('8850078')->is_valid_number, '宮崎県都城市宮丸町');
ok($zip->set_number('8850079')->is_valid_number, '宮崎県都城市牟田町');
ok($zip->set_number('8850081')->is_valid_number, '宮崎県都城市鷹尾');
ok($zip->set_number('8850082')->is_valid_number, '宮崎県都城市南鷹尾町');
ok($zip->set_number('8850083')->is_valid_number, '宮崎県都城市都島町');
ok($zip->set_number('8850084')->is_valid_number, '宮崎県都城市五十町');
ok($zip->set_number('8850085')->is_valid_number, '宮崎県都城市平塚町');
ok($zip->set_number('8850086')->is_valid_number, '宮崎県都城市久保原町');
ok($zip->set_number('8850091')->is_valid_number, '宮崎県都城市横市町');
ok($zip->set_number('8850092')->is_valid_number, '宮崎県都城市南横市町');
ok($zip->set_number('8850093')->is_valid_number, '宮崎県都城市志比田町');
ok($zip->set_number('8850094')->is_valid_number, '宮崎県都城市都原町');
ok($zip->set_number('8850095')->is_valid_number, '宮崎県都城市蓑原町');
ok($zip->set_number('8850111')->is_valid_number, '宮崎県都城市菓子野町');
ok($zip->set_number('8850112')->is_valid_number, '宮崎県都城市乙房町');
ok($zip->set_number('8850113')->is_valid_number, '宮崎県都城市関之尾町');
ok($zip->set_number('8850114')->is_valid_number, '宮崎県都城市庄内町');
ok($zip->set_number('8850221')->is_valid_number, '宮崎県都城市高野町');
ok($zip->set_number('8850222')->is_valid_number, '宮崎県都城市美川町');
ok($zip->set_number('8850223')->is_valid_number, '宮崎県都城市吉之元町');
ok($zip->set_number('8850224')->is_valid_number, '宮崎県都城市御池町');
ok($zip->set_number('8850225')->is_valid_number, '宮崎県都城市夏尾町');
ok($zip->set_number('8851101')->is_valid_number, '宮崎県都城市岩満町');
ok($zip->set_number('8851102')->is_valid_number, '宮崎県都城市下水流町');
ok($zip->set_number('8851103')->is_valid_number, '宮崎県都城市上水流町');
ok($zip->set_number('8851104')->is_valid_number, '宮崎県都城市野々美谷町');
ok($zip->set_number('8851105')->is_valid_number, '宮崎県都城市丸谷町');
ok($zip->set_number('8851201')->is_valid_number, '宮崎県都城市高城町高城');
ok($zip->set_number('8851202')->is_valid_number, '宮崎県都城市高城町穂満坊');
ok($zip->set_number('8851203')->is_valid_number, '宮崎県都城市高城町大井手');
ok($zip->set_number('8851204')->is_valid_number, '宮崎県都城市高城町桜木');
ok($zip->set_number('8851205')->is_valid_number, '宮崎県都城市高城町石山');
ok($zip->set_number('8851311')->is_valid_number, '宮崎県都城市高城町有水');
ok($zip->set_number('8851312')->is_valid_number, '宮崎県都城市高城町四家');
ok($zip->set_number('8860000')->is_valid_number, '宮崎県小林市以下に掲載がない場合');
ok($zip->set_number('8860001')->is_valid_number, '宮崎県小林市東方(その他)');
ok($zip->set_number('8860002')->is_valid_number, '宮崎県小林市水流迫');
ok($zip->set_number('8860003')->is_valid_number, '宮崎県小林市堤');
ok($zip->set_number('8860004')->is_valid_number, '宮崎県小林市細野');
ok($zip->set_number('8860005')->is_valid_number, '宮崎県小林市南西方');
ok($zip->set_number('8860006')->is_valid_number, '宮崎県小林市北西方');
ok($zip->set_number('8860007')->is_valid_number, '宮崎県小林市真方');
ok($zip->set_number('8860008')->is_valid_number, '宮崎県小林市本町');
ok($zip->set_number('8860009')->is_valid_number, '宮崎県小林市駅南');
ok($zip->set_number('8860101')->is_valid_number, '宮崎県小林市東方(5741、5871番地)');
ok($zip->set_number('8860111')->is_valid_number, '宮崎県小林市須木中原');
ok($zip->set_number('8860112')->is_valid_number, '宮崎県小林市須木下田');
ok($zip->set_number('8860113')->is_valid_number, '宮崎県小林市須木鳥田町');
ok($zip->set_number('8860114')->is_valid_number, '宮崎県小林市須木奈佐木');
ok($zip->set_number('8860115')->is_valid_number, '宮崎県小林市須木内山');
ok($zip->set_number('8860211')->is_valid_number, '宮崎県小林市野尻町紙屋');
ok($zip->set_number('8860212')->is_valid_number, '宮崎県小林市野尻町東麓');
ok($zip->set_number('8860213')->is_valid_number, '宮崎県小林市野尻町三ケ野山');
ok($zip->set_number('8870000')->is_valid_number, '宮崎県日南市以下に掲載がない場合');
ok($zip->set_number('8870001')->is_valid_number, '宮崎県日南市油津');
ok($zip->set_number('8870002')->is_valid_number, '宮崎県日南市西町');
ok($zip->set_number('8870003')->is_valid_number, '宮崎県日南市瀬西');
ok($zip->set_number('8870004')->is_valid_number, '宮崎県日南市天福');
ok($zip->set_number('8870005')->is_valid_number, '宮崎県日南市材木町');
ok($zip->set_number('8870006')->is_valid_number, '宮崎県日南市春日町');
ok($zip->set_number('8870007')->is_valid_number, '宮崎県日南市乙姫町');
ok($zip->set_number('8870011')->is_valid_number, '宮崎県日南市瀬貝');
ok($zip->set_number('8870012')->is_valid_number, '宮崎県日南市園田');
ok($zip->set_number('8870013')->is_valid_number, '宮崎県日南市木山');
ok($zip->set_number('8870014')->is_valid_number, '宮崎県日南市岩崎');
ok($zip->set_number('8870015')->is_valid_number, '宮崎県日南市平野');
ok($zip->set_number('8870016')->is_valid_number, '宮崎県日南市中平野');
ok($zip->set_number('8870017')->is_valid_number, '宮崎県日南市梅ケ浜');
ok($zip->set_number('8870021')->is_valid_number, '宮崎県日南市中央通');
ok($zip->set_number('8870022')->is_valid_number, '宮崎県日南市上平野町');
ok($zip->set_number('8870023')->is_valid_number, '宮崎県日南市隈谷');
ok($zip->set_number('8870024')->is_valid_number, '宮崎県日南市西弁分');
ok($zip->set_number('8870031')->is_valid_number, '宮崎県日南市戸高');
ok($zip->set_number('8870032')->is_valid_number, '宮崎県日南市益安');
ok($zip->set_number('8870033')->is_valid_number, '宮崎県日南市平山');
ok($zip->set_number('8870034')->is_valid_number, '宮崎県日南市風田');
ok($zip->set_number('8870041')->is_valid_number, '宮崎県日南市吾田東(1~4丁目)');
ok($zip->set_number('8870101')->is_valid_number, '宮崎県日南市宮浦');
ok($zip->set_number('8870102')->is_valid_number, '宮崎県日南市富土');
ok($zip->set_number('8870111')->is_valid_number, '宮崎県日南市伊比井');
ok($zip->set_number('8880000')->is_valid_number, '宮崎県串間市以下に掲載がない場合');
ok($zip->set_number('8880001')->is_valid_number, '宮崎県串間市西方');
ok($zip->set_number('8880002')->is_valid_number, '宮崎県串間市高松');
ok($zip->set_number('8880003')->is_valid_number, '宮崎県串間市奴久見');
ok($zip->set_number('8880004')->is_valid_number, '宮崎県串間市串間');
ok($zip->set_number('8880005')->is_valid_number, '宮崎県串間市北方');
ok($zip->set_number('8880006')->is_valid_number, '宮崎県串間市秋山');
ok($zip->set_number('8880007')->is_valid_number, '宮崎県串間市南方');
ok($zip->set_number('8880008')->is_valid_number, '宮崎県串間市本城');
ok($zip->set_number('8880009')->is_valid_number, '宮崎県串間市崎田');
ok($zip->set_number('8880011')->is_valid_number, '宮崎県串間市寺里');
ok($zip->set_number('8880012')->is_valid_number, '宮崎県串間市西浜');
ok($zip->set_number('8880013')->is_valid_number, '宮崎県串間市東町');
ok($zip->set_number('8880221')->is_valid_number, '宮崎県串間市大納');
ok($zip->set_number('8880222')->is_valid_number, '宮崎県串間市都井');
ok($zip->set_number('8890101')->is_valid_number, '宮崎県延岡市北川町川内名(その他)');
ok($zip->set_number('8890102')->is_valid_number, '宮崎県延岡市北川町長井');
ok($zip->set_number('8890301')->is_valid_number, '宮崎県延岡市北浦町古江');
ok($zip->set_number('8890302')->is_valid_number, '宮崎県延岡市北浦町市振');
ok($zip->set_number('8890303')->is_valid_number, '宮崎県延岡市北浦町宮野浦');
ok($zip->set_number('8890304')->is_valid_number, '宮崎県延岡市北浦町三川内');
ok($zip->set_number('8890321')->is_valid_number, '宮崎県延岡市須美江町');
ok($zip->set_number('8890322')->is_valid_number, '宮崎県延岡市熊野江町');
ok($zip->set_number('8890501')->is_valid_number, '宮崎県延岡市石田町');
ok($zip->set_number('8890502')->is_valid_number, '宮崎県延岡市上伊形町');
ok($zip->set_number('8890503')->is_valid_number, '宮崎県延岡市伊形町');
ok($zip->set_number('8890504')->is_valid_number, '宮崎県延岡市下伊形町');
ok($zip->set_number('8890505')->is_valid_number, '宮崎県延岡市北一ケ岡');
ok($zip->set_number('8890506')->is_valid_number, '宮崎県延岡市南一ケ岡');
ok($zip->set_number('8890507')->is_valid_number, '宮崎県延岡市旭ケ丘');
ok($zip->set_number('8890511')->is_valid_number, '宮崎県延岡市松原町');
ok($zip->set_number('8890512')->is_valid_number, '宮崎県延岡市新浜町');
ok($zip->set_number('8890513')->is_valid_number, '宮崎県延岡市土々呂町');
ok($zip->set_number('8890514')->is_valid_number, '宮崎県延岡市櫛津町');
ok($zip->set_number('8890515')->is_valid_number, '宮崎県延岡市妙見町');
ok($zip->set_number('8890516')->is_valid_number, '宮崎県延岡市鯛名町');
ok($zip->set_number('8890517')->is_valid_number, '宮崎県延岡市赤水町');
ok($zip->set_number('8890600')->is_valid_number, '宮崎県東臼杵郡門川町以下に掲載がない場合');
ok($zip->set_number('8890601')->is_valid_number, '宮崎県東臼杵郡門川町須賀崎');
ok($zip->set_number('8890602')->is_valid_number, '宮崎県東臼杵郡門川町庵川');
ok($zip->set_number('8890603')->is_valid_number, '宮崎県東臼杵郡門川町加草');
ok($zip->set_number('8890604')->is_valid_number, '宮崎県東臼杵郡門川町川内');
ok($zip->set_number('8890605')->is_valid_number, '宮崎県東臼杵郡門川町庵川西');
ok($zip->set_number('8890611')->is_valid_number, '宮崎県東臼杵郡門川町門川尾末');
ok($zip->set_number('8890612')->is_valid_number, '宮崎県東臼杵郡門川町中須');
ok($zip->set_number('8890613')->is_valid_number, '宮崎県東臼杵郡門川町本町');
ok($zip->set_number('8890614')->is_valid_number, '宮崎県東臼杵郡門川町上町');
ok($zip->set_number('8890615')->is_valid_number, '宮崎県東臼杵郡門川町栄ケ丘');
ok($zip->set_number('8890616')->is_valid_number, '宮崎県東臼杵郡門川町南町');
ok($zip->set_number('8890617')->is_valid_number, '宮崎県東臼杵郡門川町南ケ丘');
ok($zip->set_number('8890621')->is_valid_number, '宮崎県東臼杵郡門川町東栄町');
ok($zip->set_number('8890622')->is_valid_number, '宮崎県東臼杵郡門川町西栄町');
ok($zip->set_number('8890623')->is_valid_number, '宮崎県東臼杵郡門川町宮ケ原');
ok($zip->set_number('8890624')->is_valid_number, '宮崎県東臼杵郡門川町城ケ丘');
ok($zip->set_number('8890625')->is_valid_number, '宮崎県東臼杵郡門川町平城東');
ok($zip->set_number('8890626')->is_valid_number, '宮崎県東臼杵郡門川町平城西');
ok($zip->set_number('8890901')->is_valid_number, '宮崎県東臼杵郡美郷町北郷宇納間');
ok($zip->set_number('8890902')->is_valid_number, '宮崎県東臼杵郡美郷町北郷入下');
ok($zip->set_number('8890903')->is_valid_number, '宮崎県東臼杵郡美郷町北郷黒木');
ok($zip->set_number('8891101')->is_valid_number, '宮崎県日向市東郷町山陰乙(鳥川)');
ok($zip->set_number('8891111')->is_valid_number, '宮崎県日向市美々津町');
ok($zip->set_number('8891112')->is_valid_number, '宮崎県日向市幸脇');
ok($zip->set_number('8891121')->is_valid_number, '宮崎県日向市東郷町山陰甲');
ok($zip->set_number('8891200')->is_valid_number, '宮崎県児湯郡都農町以下に掲載がない場合');
ok($zip->set_number('8891201')->is_valid_number, '宮崎県児湯郡都農町川北');
ok($zip->set_number('8891300')->is_valid_number, '宮崎県児湯郡川南町以下に掲載がない場合');
ok($zip->set_number('8891301')->is_valid_number, '宮崎県児湯郡川南町川南');
ok($zip->set_number('8891302')->is_valid_number, '宮崎県児湯郡川南町平田');
ok($zip->set_number('8891400')->is_valid_number, '宮崎県児湯郡新富町以下に掲載がない場合');
ok($zip->set_number('8891401')->is_valid_number, '宮崎県児湯郡新富町日置');
ok($zip->set_number('8891402')->is_valid_number, '宮崎県児湯郡新富町三納代');
ok($zip->set_number('8891403')->is_valid_number, '宮崎県児湯郡新富町上富田');
ok($zip->set_number('8891404')->is_valid_number, '宮崎県児湯郡新富町下富田');
ok($zip->set_number('8891405')->is_valid_number, '宮崎県児湯郡新富町伊倉');
ok($zip->set_number('8891406')->is_valid_number, '宮崎県児湯郡新富町新田');
ok($zip->set_number('8891411')->is_valid_number, '宮崎県児湯郡新富町富田');
ok($zip->set_number('8891412')->is_valid_number, '宮崎県児湯郡新富町富田東');
ok($zip->set_number('8891413')->is_valid_number, '宮崎県児湯郡新富町富田西');
ok($zip->set_number('8891414')->is_valid_number, '宮崎県児湯郡新富町富田南');
ok($zip->set_number('8891415')->is_valid_number, '宮崎県児湯郡新富町富田北');
ok($zip->set_number('8891601')->is_valid_number, '宮崎県宮崎市清武町木原');
ok($zip->set_number('8891602')->is_valid_number, '宮崎県宮崎市清武町今泉');
ok($zip->set_number('8891603')->is_valid_number, '宮崎県宮崎市清武町正手');
ok($zip->set_number('8891604')->is_valid_number, '宮崎県宮崎市清武町船引');
ok($zip->set_number('8891605')->is_valid_number, '宮崎県宮崎市清武町加納(番地)');
ok($zip->set_number('8891606')->is_valid_number, '宮崎県宮崎市清武町池田台');
ok($zip->set_number('8891607')->is_valid_number, '宮崎県宮崎市清武町加納(丁目)');
ok($zip->set_number('8891608')->is_valid_number, '宮崎県宮崎市清武町池田台北');
ok($zip->set_number('8891609')->is_valid_number, '宮崎県宮崎市清武町あさひ');
ok($zip->set_number('8891611')->is_valid_number, '宮崎県宮崎市清武町新町');
ok($zip->set_number('8891612')->is_valid_number, '宮崎県宮崎市清武町岡');
ok($zip->set_number('8891613')->is_valid_number, '宮崎県宮崎市清武町西新町');
ok($zip->set_number('8891701')->is_valid_number, '宮崎県宮崎市田野町甲');
ok($zip->set_number('8891702')->is_valid_number, '宮崎県宮崎市田野町乙');
ok($zip->set_number('8891703')->is_valid_number, '宮崎県宮崎市田野町あけぼの');
ok($zip->set_number('8891704')->is_valid_number, '宮崎県宮崎市田野町南原');
ok($zip->set_number('8891713')->is_valid_number, '宮崎県宮崎市高岡町上倉永(1206~1268番地、内の八重)');
ok($zip->set_number('8891716')->is_valid_number, '宮崎県宮崎市細江(平和)');
ok($zip->set_number('8891801')->is_valid_number, '宮崎県都城市山之口町富吉');
ok($zip->set_number('8891802')->is_valid_number, '宮崎県都城市山之口町花木');
ok($zip->set_number('8891803')->is_valid_number, '宮崎県都城市山之口町山之口(その他)');
ok($zip->set_number('8891900')->is_valid_number, '宮崎県北諸県郡三股町以下に掲載がない場合');
ok($zip->set_number('8891901')->is_valid_number, '宮崎県北諸県郡三股町樺山');
ok($zip->set_number('8891902')->is_valid_number, '宮崎県北諸県郡三股町五本松');
ok($zip->set_number('8891903')->is_valid_number, '宮崎県北諸県郡三股町稗田');
ok($zip->set_number('8891904')->is_valid_number, '宮崎県北諸県郡三股町新馬場');
ok($zip->set_number('8891905')->is_valid_number, '宮崎県北諸県郡三股町今市');
ok($zip->set_number('8891906')->is_valid_number, '宮崎県北諸県郡三股町中原');
ok($zip->set_number('8891907')->is_valid_number, '宮崎県北諸県郡三股町花見原');
ok($zip->set_number('8891911')->is_valid_number, '宮崎県北諸県郡三股町長田');
ok($zip->set_number('8891912')->is_valid_number, '宮崎県北諸県郡三股町宮村');
ok($zip->set_number('8891913')->is_valid_number, '宮崎県北諸県郡三股町餅原');
ok($zip->set_number('8891914')->is_valid_number, '宮崎県北諸県郡三股町蓼池');
ok($zip->set_number('8892151')->is_valid_number, '宮崎県宮崎市熊野');
ok($zip->set_number('8892152')->is_valid_number, '宮崎県宮崎市学園木花台北');
ok($zip->set_number('8892153')->is_valid_number, '宮崎県宮崎市学園木花台南');
ok($zip->set_number('8892154')->is_valid_number, '宮崎県宮崎市学園木花台桜');
ok($zip->set_number('8892155')->is_valid_number, '宮崎県宮崎市学園木花台西');
ok($zip->set_number('8892156')->is_valid_number, '宮崎県宮崎市鏡洲');
ok($zip->set_number('8892161')->is_valid_number, '宮崎県宮崎市加江田');
ok($zip->set_number('8892162')->is_valid_number, '宮崎県宮崎市青島');
ok($zip->set_number('8892163')->is_valid_number, '宮崎県宮崎市青島西');
ok($zip->set_number('8892164')->is_valid_number, '宮崎県宮崎市折生迫');
ok($zip->set_number('8892301')->is_valid_number, '宮崎県宮崎市内海');
ok($zip->set_number('8892401')->is_valid_number, '宮崎県日南市北郷町大藤');
ok($zip->set_number('8892402')->is_valid_number, '宮崎県日南市北郷町郷之原');
ok($zip->set_number('8892403')->is_valid_number, '宮崎県日南市北郷町北河内');
ok($zip->set_number('8892511')->is_valid_number, '宮崎県日南市酒谷乙');
ok($zip->set_number('8892512')->is_valid_number, '宮崎県日南市酒谷甲');
ok($zip->set_number('8892513')->is_valid_number, '宮崎県日南市吉野方');
ok($zip->set_number('8892514')->is_valid_number, '宮崎県日南市楠原');
ok($zip->set_number('8892521')->is_valid_number, '宮崎県日南市東弁分乙');
ok($zip->set_number('8892522')->is_valid_number, '宮崎県日南市東弁分甲');
ok($zip->set_number('8892523')->is_valid_number, '宮崎県日南市松永');
ok($zip->set_number('8892524')->is_valid_number, '宮崎県日南市殿所');
ok($zip->set_number('8892525')->is_valid_number, '宮崎県日南市今町');
ok($zip->set_number('8892531')->is_valid_number, '宮崎県日南市本町');
ok($zip->set_number('8892532')->is_valid_number, '宮崎県日南市板敷');
ok($zip->set_number('8892533')->is_valid_number, '宮崎県日南市星倉');
ok($zip->set_number('8892534')->is_valid_number, '宮崎県日南市時任町');
ok($zip->set_number('8892535')->is_valid_number, '宮崎県日南市飫肥');
ok($zip->set_number('8892536')->is_valid_number, '宮崎県日南市吾田西');
ok($zip->set_number('8892541')->is_valid_number, '宮崎県日南市吾田東(5~11丁目)');
ok($zip->set_number('8893141')->is_valid_number, '宮崎県日南市大堂津');
ok($zip->set_number('8893142')->is_valid_number, '宮崎県日南市塩鶴');
ok($zip->set_number('8893143')->is_valid_number, '宮崎県日南市下方');
ok($zip->set_number('8893151')->is_valid_number, '宮崎県日南市上方');
ok($zip->set_number('8893152')->is_valid_number, '宮崎県日南市毛吉田');
ok($zip->set_number('8893153')->is_valid_number, '宮崎県日南市萩之嶺');
ok($zip->set_number('8893154')->is_valid_number, '宮崎県日南市塚田甲');
ok($zip->set_number('8893155')->is_valid_number, '宮崎県日南市塚田乙');
ok($zip->set_number('8893156')->is_valid_number, '宮崎県日南市大窪');
ok($zip->set_number('8893201')->is_valid_number, '宮崎県日南市南郷町津屋野');
ok($zip->set_number('8893202')->is_valid_number, '宮崎県日南市南郷町中村甲');
ok($zip->set_number('8893203')->is_valid_number, '宮崎県日南市南郷町谷之口');
ok($zip->set_number('8893204')->is_valid_number, '宮崎県日南市南郷町中村乙');
ok($zip->set_number('8893205')->is_valid_number, '宮崎県日南市南郷町西町');
ok($zip->set_number('8893206')->is_valid_number, '宮崎県日南市南郷町南町');
ok($zip->set_number('8893207')->is_valid_number, '宮崎県日南市南郷町東町');
ok($zip->set_number('8893211')->is_valid_number, '宮崎県日南市南郷町贄波');
ok($zip->set_number('8893212')->is_valid_number, '宮崎県日南市南郷町脇本');
ok($zip->set_number('8893213')->is_valid_number, '宮崎県日南市南郷町潟上');
ok($zip->set_number('8893214')->is_valid_number, '宮崎県日南市南郷町榎原');
ok($zip->set_number('8893215')->is_valid_number, '宮崎県日南市南郷町榎原甲');
ok($zip->set_number('8893216')->is_valid_number, '宮崎県日南市南郷町榎原乙');
ok($zip->set_number('8893217')->is_valid_number, '宮崎県日南市南郷町榎原丙');
ok($zip->set_number('8893311')->is_valid_number, '宮崎県串間市市木');
ok($zip->set_number('8893531')->is_valid_number, '宮崎県串間市奈留');
ok($zip->set_number('8893532')->is_valid_number, '宮崎県串間市大平');
ok($zip->set_number('8893533')->is_valid_number, '宮崎県串間市一氏');
ok($zip->set_number('8893534')->is_valid_number, '宮崎県串間市大矢取');
ok($zip->set_number('8894151')->is_valid_number, '宮崎県えびの市向江');
ok($zip->set_number('8894152')->is_valid_number, '宮崎県えびの市島内');
ok($zip->set_number('8894153')->is_valid_number, '宮崎県えびの市浦');
ok($zip->set_number('8894154')->is_valid_number, '宮崎県えびの市柳水流');
ok($zip->set_number('8894155')->is_valid_number, '宮崎県えびの市亀沢');
ok($zip->set_number('8894161')->is_valid_number, '宮崎県えびの市岡松');
ok($zip->set_number('8894162')->is_valid_number, '宮崎県えびの市内竪');
ok($zip->set_number('8894163')->is_valid_number, '宮崎県えびの市水流');
ok($zip->set_number('8894164')->is_valid_number, '宮崎県えびの市昌明寺');
ok($zip->set_number('8894165')->is_valid_number, '宮崎県えびの市西川北');
ok($zip->set_number('8894221')->is_valid_number, '宮崎県えびの市栗下');
ok($zip->set_number('8894222')->is_valid_number, '宮崎県えびの市小田');
ok($zip->set_number('8894231')->is_valid_number, '宮崎県えびの市東長江浦');
ok($zip->set_number('8894232')->is_valid_number, '宮崎県えびの市西長江浦');
ok($zip->set_number('8894233')->is_valid_number, '宮崎県えびの市灰塚');
ok($zip->set_number('8894234')->is_valid_number, '宮崎県えびの市永山');
ok($zip->set_number('8894241')->is_valid_number, '宮崎県えびの市西郷');
ok($zip->set_number('8894242')->is_valid_number, '宮崎県えびの市湯田');
ok($zip->set_number('8894243')->is_valid_number, '宮崎県えびの市榎田');
ok($zip->set_number('8894244')->is_valid_number, '宮崎県えびの市東川北');
ok($zip->set_number('8894300')->is_valid_number, '宮崎県えびの市以下に掲載がない場合');
ok($zip->set_number('8894301')->is_valid_number, '宮崎県えびの市原田');
ok($zip->set_number('8894302')->is_valid_number, '宮崎県えびの市末永');
ok($zip->set_number('8894303')->is_valid_number, '宮崎県えびの市池島');
ok($zip->set_number('8894304')->is_valid_number, '宮崎県えびの市上江');
ok($zip->set_number('8894305')->is_valid_number, '宮崎県えびの市前田');
ok($zip->set_number('8894306')->is_valid_number, '宮崎県えびの市今西');
ok($zip->set_number('8894311')->is_valid_number, '宮崎県えびの市大明司');
ok($zip->set_number('8894312')->is_valid_number, '宮崎県えびの市坂元');
ok($zip->set_number('8894313')->is_valid_number, '宮崎県えびの市杉水流');
ok($zip->set_number('8894314')->is_valid_number, '宮崎県えびの市大河平');
ok($zip->set_number('8894400')->is_valid_number, '宮崎県西諸県郡高原町以下に掲載がない場合');
ok($zip->set_number('8894411')->is_valid_number, '宮崎県西諸県郡高原町広原');
ok($zip->set_number('8894412')->is_valid_number, '宮崎県西諸県郡高原町西麓');
ok($zip->set_number('8894413')->is_valid_number, '宮崎県西諸県郡高原町後川内');
ok($zip->set_number('8894414')->is_valid_number, '宮崎県西諸県郡高原町蒲牟田');
ok($zip->set_number('8894501')->is_valid_number, '宮崎県都城市高崎町笛水');
ok($zip->set_number('8894502')->is_valid_number, '宮崎県都城市高崎町江平');
ok($zip->set_number('8894503')->is_valid_number, '宮崎県都城市高崎町縄瀬');
ok($zip->set_number('8894504')->is_valid_number, '宮崎県都城市高崎町東霧島');
ok($zip->set_number('8894505')->is_valid_number, '宮崎県都城市高崎町大牟田');
ok($zip->set_number('8894506')->is_valid_number, '宮崎県都城市高崎町前田');
ok($zip->set_number('8894601')->is_valid_number, '宮崎県都城市山田町山田');
ok($zip->set_number('8894602')->is_valid_number, '宮崎県都城市山田町中霧島');
ok($zip->set_number('8900000')->is_valid_number, '鹿児島県鹿児島市以下に掲載がない場合');
ok($zip->set_number('8900000')->is_valid_number, '鹿児島県鹿児島郡三島村以下に掲載がない場合');
ok($zip->set_number('8900001')->is_valid_number, '鹿児島県鹿児島市千年');
ok($zip->set_number('8900002')->is_valid_number, '鹿児島県鹿児島市西伊敷(1~4丁目)');
ok($zip->set_number('8900003')->is_valid_number, '鹿児島県鹿児島市伊敷町(その他)');
ok($zip->set_number('8900004')->is_valid_number, '鹿児島県鹿児島市下伊敷町');
ok($zip->set_number('8900005')->is_valid_number, '鹿児島県鹿児島市下伊敷');
ok($zip->set_number('8900006')->is_valid_number, '鹿児島県鹿児島市若葉町');
ok($zip->set_number('8900007')->is_valid_number, '鹿児島県鹿児島市伊敷台');
ok($zip->set_number('8900008')->is_valid_number, '鹿児島県鹿児島市伊敷');
ok($zip->set_number('8900011')->is_valid_number, '鹿児島県鹿児島市玉里団地(1丁目)');
ok($zip->set_number('8900012')->is_valid_number, '鹿児島県鹿児島市玉里町');
ok($zip->set_number('8900013')->is_valid_number, '鹿児島県鹿児島市城山(1丁目)');
ok($zip->set_number('8900014')->is_valid_number, '鹿児島県鹿児島市草牟田');
ok($zip->set_number('8900015')->is_valid_number, '鹿児島県鹿児島市草牟田町');
ok($zip->set_number('8900016')->is_valid_number, '鹿児島県鹿児島市新照院町');
ok($zip->set_number('8900021')->is_valid_number, '鹿児島県鹿児島市小野');
ok($zip->set_number('8900022')->is_valid_number, '鹿児島県鹿児島市小野町(その他)');
ok($zip->set_number('8900023')->is_valid_number, '鹿児島県鹿児島市永吉');
ok($zip->set_number('8900024')->is_valid_number, '鹿児島県鹿児島市明和');
ok($zip->set_number('8900025')->is_valid_number, '鹿児島県鹿児島市原良町');
ok($zip->set_number('8900026')->is_valid_number, '鹿児島県鹿児島市原良');
ok($zip->set_number('8900031')->is_valid_number, '鹿児島県鹿児島市武岡');
ok($zip->set_number('8900032')->is_valid_number, '鹿児島県鹿児島市西陵');
ok($zip->set_number('8900033')->is_valid_number, '鹿児島県鹿児島市西別府町');
ok($zip->set_number('8900034')->is_valid_number, '鹿児島県鹿児島市田上');
ok($zip->set_number('8900035')->is_valid_number, '鹿児島県鹿児島市田上町');
ok($zip->set_number('8900036')->is_valid_number, '鹿児島県鹿児島市田上台');
ok($zip->set_number('8900037')->is_valid_number, '鹿児島県鹿児島市広木');
ok($zip->set_number('8900038')->is_valid_number, '鹿児島県鹿児島市向陽');
ok($zip->set_number('8900041')->is_valid_number, '鹿児島県鹿児島市城西');
ok($zip->set_number('8900042')->is_valid_number, '鹿児島県鹿児島市薬師');
ok($zip->set_number('8900043')->is_valid_number, '鹿児島県鹿児島市鷹師');
ok($zip->set_number('8900044')->is_valid_number, '鹿児島県鹿児島市常盤町');
ok($zip->set_number('8900045')->is_valid_number, '鹿児島県鹿児島市武');
ok($zip->set_number('8900046')->is_valid_number, '鹿児島県鹿児島市西田');
ok($zip->set_number('8900047')->is_valid_number, '鹿児島県鹿児島市常盤');
ok($zip->set_number('8900051')->is_valid_number, '鹿児島県鹿児島市高麗町');
ok($zip->set_number('8900052')->is_valid_number, '鹿児島県鹿児島市上之園町');
ok($zip->set_number('8900053')->is_valid_number, '鹿児島県鹿児島市中央町');
ok($zip->set_number('8900054')->is_valid_number, '鹿児島県鹿児島市荒田');
ok($zip->set_number('8900055')->is_valid_number, '鹿児島県鹿児島市上荒田町');
ok($zip->set_number('8900056')->is_valid_number, '鹿児島県鹿児島市下荒田');
ok($zip->set_number('8900061')->is_valid_number, '鹿児島県鹿児島市天保山町');
ok($zip->set_number('8900062')->is_valid_number, '鹿児島県鹿児島市与次郎');
ok($zip->set_number('8900063')->is_valid_number, '鹿児島県鹿児島市鴨池');
ok($zip->set_number('8900064')->is_valid_number, '鹿児島県鹿児島市鴨池新町');
ok($zip->set_number('8900065')->is_valid_number, '鹿児島県鹿児島市郡元');
ok($zip->set_number('8900066')->is_valid_number, '鹿児島県鹿児島市真砂町');
ok($zip->set_number('8900067')->is_valid_number, '鹿児島県鹿児島市真砂本町');
ok($zip->set_number('8900068')->is_valid_number, '鹿児島県鹿児島市東郡元町');
ok($zip->set_number('8900069')->is_valid_number, '鹿児島県鹿児島市南郡元町');
ok($zip->set_number('8900071')->is_valid_number, '鹿児島県鹿児島市三和町');
ok($zip->set_number('8900072')->is_valid_number, '鹿児島県鹿児島市新栄町');
ok($zip->set_number('8900073')->is_valid_number, '鹿児島県鹿児島市宇宿');
ok($zip->set_number('8900074')->is_valid_number, '鹿児島県鹿児島市宇宿町');
ok($zip->set_number('8900075')->is_valid_number, '鹿児島県鹿児島市桜ケ丘(7、8丁目)');
ok($zip->set_number('8900076')->is_valid_number, '鹿児島県鹿児島市中央港新町');
ok($zip->set_number('8900081')->is_valid_number, '鹿児島県鹿児島市唐湊');
ok($zip->set_number('8900082')->is_valid_number, '鹿児島県鹿児島市紫原');
ok($zip->set_number('8900083')->is_valid_number, '鹿児島県鹿児島市西紫原町');
ok($zip->set_number('8900084')->is_valid_number, '鹿児島県鹿児島市郡元町');
ok($zip->set_number('8900085')->is_valid_number, '鹿児島県鹿児島市南新町');
ok($zip->set_number('8900086')->is_valid_number, '鹿児島県鹿児島市日之出町');
ok($zip->set_number('8900901')->is_valid_number, '鹿児島県鹿児島郡三島村硫黄島');
ok($zip->set_number('8900902')->is_valid_number, '鹿児島県鹿児島郡三島村黒島');
ok($zip->set_number('8900903')->is_valid_number, '鹿児島県鹿児島郡三島村竹島');
ok($zip->set_number('8910101')->is_valid_number, '鹿児島県鹿児島市五ケ別府町');
ok($zip->set_number('8910102')->is_valid_number, '鹿児島県鹿児島市星ケ峯');
ok($zip->set_number('8910103')->is_valid_number, '鹿児島県鹿児島市皇徳寺台');
ok($zip->set_number('8910104')->is_valid_number, '鹿児島県鹿児島市山田町');
ok($zip->set_number('8910105')->is_valid_number, '鹿児島県鹿児島市中山町');
ok($zip->set_number('8910106')->is_valid_number, '鹿児島県鹿児島市自由ケ丘');
ok($zip->set_number('8910107')->is_valid_number, '鹿児島県鹿児島市希望ケ丘町');
ok($zip->set_number('8910108')->is_valid_number, '鹿児島県鹿児島市中山');
ok($zip->set_number('8910109')->is_valid_number, '鹿児島県鹿児島市清和');
ok($zip->set_number('8910111')->is_valid_number, '鹿児島県鹿児島市小原町');
ok($zip->set_number('8910112')->is_valid_number, '鹿児島県鹿児島市魚見町');
ok($zip->set_number('8910113')->is_valid_number, '鹿児島県鹿児島市東谷山');
ok($zip->set_number('8910114')->is_valid_number, '鹿児島県鹿児島市小松原');
ok($zip->set_number('8910115')->is_valid_number, '鹿児島県鹿児島市東開町');
ok($zip->set_number('8910116')->is_valid_number, '鹿児島県鹿児島市上福元町');
ok($zip->set_number('8910117')->is_valid_number, '鹿児島県鹿児島市西谷山');
ok($zip->set_number('8910122')->is_valid_number, '鹿児島県鹿児島市南栄');
ok($zip->set_number('8910123')->is_valid_number, '鹿児島県鹿児島市卸本町');
ok($zip->set_number('8910131')->is_valid_number, '鹿児島県鹿児島市谷山港');
ok($zip->set_number('8910132')->is_valid_number, '鹿児島県鹿児島市七ツ島');
ok($zip->set_number('8910133')->is_valid_number, '鹿児島県鹿児島市平川町');
ok($zip->set_number('8910141')->is_valid_number, '鹿児島県鹿児島市谷山中央');
ok($zip->set_number('8910143')->is_valid_number, '鹿児島県鹿児島市和田');
ok($zip->set_number('8910144')->is_valid_number, '鹿児島県鹿児島市下福元町');
ok($zip->set_number('8910145')->is_valid_number, '鹿児島県鹿児島市錦江台');
ok($zip->set_number('8910146')->is_valid_number, '鹿児島県鹿児島市慈眼寺町');
ok($zip->set_number('8910150')->is_valid_number, '鹿児島県鹿児島市坂之上');
ok($zip->set_number('8910151')->is_valid_number, '鹿児島県鹿児島市光山');
ok($zip->set_number('8910175')->is_valid_number, '鹿児島県鹿児島市桜ケ丘(1~6丁目)');
ok($zip->set_number('8910201')->is_valid_number, '鹿児島県鹿児島市喜入瀬々串町');
ok($zip->set_number('8910202')->is_valid_number, '鹿児島県鹿児島市喜入中名町');
ok($zip->set_number('8910203')->is_valid_number, '鹿児島県鹿児島市喜入町');
ok($zip->set_number('8910204')->is_valid_number, '鹿児島県鹿児島市喜入一倉町');
ok($zip->set_number('8910205')->is_valid_number, '鹿児島県鹿児島市喜入前之浜町');
ok($zip->set_number('8910206')->is_valid_number, '鹿児島県鹿児島市喜入生見町');
ok($zip->set_number('8910304')->is_valid_number, '鹿児島県指宿市東方(600~5974、5976~7816、7833、7834、');
ok($zip->set_number('8910304')->is_valid_number, '鹿児島県指宿市10603~11015)');
ok($zip->set_number('8910311')->is_valid_number, '鹿児島県指宿市西方');
ok($zip->set_number('8910312')->is_valid_number, '鹿児島県指宿市池田');
ok($zip->set_number('8910313')->is_valid_number, '鹿児島県指宿市新西方');
ok($zip->set_number('8910314')->is_valid_number, '鹿児島県指宿市小牧');
ok($zip->set_number('8910315')->is_valid_number, '鹿児島県指宿市岩本');
ok($zip->set_number('8910400')->is_valid_number, '鹿児島県指宿市以下に掲載がない場合');
ok($zip->set_number('8910401')->is_valid_number, '鹿児島県指宿市大牟礼');
ok($zip->set_number('8910402')->is_valid_number, '鹿児島県指宿市十町');
ok($zip->set_number('8910403')->is_valid_number, '鹿児島県指宿市十二町');
ok($zip->set_number('8910404')->is_valid_number, '鹿児島県指宿市東方(その他)');
ok($zip->set_number('8910405')->is_valid_number, '鹿児島県指宿市湊');
ok($zip->set_number('8910406')->is_valid_number, '鹿児島県指宿市湯の浜');
ok($zip->set_number('8910501')->is_valid_number, '鹿児島県指宿市山川新栄町');
ok($zip->set_number('8910502')->is_valid_number, '鹿児島県指宿市山川朝日町');
ok($zip->set_number('8910503')->is_valid_number, '鹿児島県指宿市山川潮見町');
ok($zip->set_number('8910504')->is_valid_number, '鹿児島県指宿市山川新生町');
ok($zip->set_number('8910505')->is_valid_number, '鹿児島県指宿市山川山下町');
ok($zip->set_number('8910506')->is_valid_number, '鹿児島県指宿市山川金生町');
ok($zip->set_number('8910507')->is_valid_number, '鹿児島県指宿市山川入船町');
ok($zip->set_number('8910511')->is_valid_number, '鹿児島県指宿市山川福元');
ok($zip->set_number('8910512')->is_valid_number, '鹿児島県指宿市山川浜児ケ水');
ok($zip->set_number('8910513')->is_valid_number, '鹿児島県指宿市山川岡児ケ水');
ok($zip->set_number('8910514')->is_valid_number, '鹿児島県指宿市山川大山(その他)');
ok($zip->set_number('8910515')->is_valid_number, '鹿児島県指宿市山川小川');
ok($zip->set_number('8910516')->is_valid_number, '鹿児島県指宿市山川成川');
ok($zip->set_number('8910601')->is_valid_number, '鹿児島県指宿市開聞上野');
ok($zip->set_number('8910602')->is_valid_number, '鹿児島県指宿市開聞川尻');
ok($zip->set_number('8910603')->is_valid_number, '鹿児島県指宿市開聞十町');
ok($zip->set_number('8910604')->is_valid_number, '鹿児島県指宿市開聞仙田');
ok($zip->set_number('8910614')->is_valid_number, '鹿児島県指宿市山川大山(1400~1717番)');
ok($zip->set_number('8910621')->is_valid_number, '鹿児島県指宿市山川利永');
ok($zip->set_number('8910701')->is_valid_number, '鹿児島県南九州市頴娃町郡');
ok($zip->set_number('8910702')->is_valid_number, '鹿児島県南九州市頴娃町牧之内');
ok($zip->set_number('8910703')->is_valid_number, '鹿児島県南九州市頴娃町御領');
ok($zip->set_number('8910704')->is_valid_number, '鹿児島県南九州市頴娃町別府');
ok($zip->set_number('8910705')->is_valid_number, '鹿児島県南九州市頴娃町上別府');
ok($zip->set_number('8910911')->is_valid_number, '鹿児島県南九州市知覧町塩屋');
ok($zip->set_number('8910912')->is_valid_number, '鹿児島県南九州市知覧町南別府');
ok($zip->set_number('8911101')->is_valid_number, '鹿児島県鹿児島市花尾町');
ok($zip->set_number('8911102')->is_valid_number, '鹿児島県鹿児島市東俣町');
ok($zip->set_number('8911103')->is_valid_number, '鹿児島県鹿児島市川田町');
ok($zip->set_number('8911104')->is_valid_number, '鹿児島県鹿児島市油須木町');
ok($zip->set_number('8911105')->is_valid_number, '鹿児島県鹿児島市郡山町');
ok($zip->set_number('8911106')->is_valid_number, '鹿児島県鹿児島市西俣町');
ok($zip->set_number('8911107')->is_valid_number, '鹿児島県鹿児島市有屋田町');
ok($zip->set_number('8911108')->is_valid_number, '鹿児島県鹿児島市郡山岳町');
ok($zip->set_number('8911201')->is_valid_number, '鹿児島県鹿児島市岡之原町(その他)');
ok($zip->set_number('8911202')->is_valid_number, '鹿児島県鹿児島市西伊敷(5~7丁目)');
ok($zip->set_number('8911203')->is_valid_number, '鹿児島県鹿児島市伊敷町(4710~4741、4747~4761-3番地)');
ok($zip->set_number('8911204')->is_valid_number, '鹿児島県鹿児島市花野光ケ丘');
ok($zip->set_number('8911205')->is_valid_number, '鹿児島県鹿児島市犬迫町');
ok($zip->set_number('8911206')->is_valid_number, '鹿児島県鹿児島市皆与志町');
ok($zip->set_number('8911222')->is_valid_number, '鹿児島県鹿児島市小野町(4784~5118番地)');
ok($zip->set_number('8911231')->is_valid_number, '鹿児島県鹿児島市小山田町(その他)');
ok($zip->set_number('8911274')->is_valid_number, '鹿児島県鹿児島市緑ヶ丘町(35番以降)');
ok($zip->set_number('8911275')->is_valid_number, '鹿児島県鹿児島市川上町(3649、3661、3667、3669-4、3671、3672、3');
ok($zip->set_number('8911275')->is_valid_number, '鹿児島県鹿児島市674、3701、3704、3723-3、4128、4132、4133、4');
ok($zip->set_number('8911275')->is_valid_number, '鹿児島県鹿児島市138、4203、4209、4215、4236-1、4238、4241、4');
ok($zip->set_number('8911275')->is_valid_number, '鹿児島県鹿児島市242、4244番地)');
ok($zip->set_number('8911301')->is_valid_number, '鹿児島県鹿児島市西佐多町');
ok($zip->set_number('8911302')->is_valid_number, '鹿児島県鹿児島市東佐多町');
ok($zip->set_number('8911303')->is_valid_number, '鹿児島県鹿児島市本城町');
ok($zip->set_number('8911304')->is_valid_number, '鹿児島県鹿児島市本名町');
ok($zip->set_number('8911305')->is_valid_number, '鹿児島県鹿児島市宮之浦町');
ok($zip->set_number('8911306')->is_valid_number, '鹿児島県鹿児島市牟礼岡');
ok($zip->set_number('8911401')->is_valid_number, '鹿児島県鹿児島市黒神町(その他)');
ok($zip->set_number('8911402')->is_valid_number, '鹿児島県鹿児島市高免町');
ok($zip->set_number('8911403')->is_valid_number, '鹿児島県鹿児島市新島町');
ok($zip->set_number('8911411')->is_valid_number, '鹿児島県鹿児島市桜島白浜町');
ok($zip->set_number('8911412')->is_valid_number, '鹿児島県鹿児島市桜島二俣町');
ok($zip->set_number('8911413')->is_valid_number, '鹿児島県鹿児島市桜島松浦町');
ok($zip->set_number('8911414')->is_valid_number, '鹿児島県鹿児島市桜島西道町');
ok($zip->set_number('8911415')->is_valid_number, '鹿児島県鹿児島市桜島藤野町');
ok($zip->set_number('8911416')->is_valid_number, '鹿児島県鹿児島市桜島武町');
ok($zip->set_number('8911417')->is_valid_number, '鹿児島県鹿児島市桜島赤生原町');
ok($zip->set_number('8911418')->is_valid_number, '鹿児島県鹿児島市桜島小池町');
ok($zip->set_number('8911419')->is_valid_number, '鹿児島県鹿児島市桜島横山町');
ok($zip->set_number('8911420')->is_valid_number, '鹿児島県鹿児島市桜島赤水町');
ok($zip->set_number('8911501')->is_valid_number, '鹿児島県鹿児島市黒神町(枦ノ木ケ谷)');
ok($zip->set_number('8911541')->is_valid_number, '鹿児島県鹿児島市野尻町');
ok($zip->set_number('8911542')->is_valid_number, '鹿児島県鹿児島市持木町');
ok($zip->set_number('8911543')->is_valid_number, '鹿児島県鹿児島市東桜島町');
ok($zip->set_number('8911544')->is_valid_number, '鹿児島県鹿児島市古里町');
ok($zip->set_number('8911545')->is_valid_number, '鹿児島県鹿児島市有村町');
ok($zip->set_number('8912100')->is_valid_number, '鹿児島県垂水市以下に掲載がない場合');
ok($zip->set_number('8912101')->is_valid_number, '鹿児島県垂水市海潟');
ok($zip->set_number('8912102')->is_valid_number, '鹿児島県垂水市中俣');
ok($zip->set_number('8912103')->is_valid_number, '鹿児島県垂水市市木');
ok($zip->set_number('8912104')->is_valid_number, '鹿児島県垂水市田神');
ok($zip->set_number('8912105')->is_valid_number, '鹿児島県垂水市松原町');
ok($zip->set_number('8912106')->is_valid_number, '鹿児島県垂水市中央町');
ok($zip->set_number('8912111')->is_valid_number, '鹿児島県垂水市新御堂');
ok($zip->set_number('8912112')->is_valid_number, '鹿児島県垂水市本城');
ok($zip->set_number('8912113')->is_valid_number, '鹿児島県垂水市高城');
ok($zip->set_number('8912114')->is_valid_number, '鹿児島県垂水市新城');
ok($zip->set_number('8912115')->is_valid_number, '鹿児島県垂水市浜平');
ok($zip->set_number('8912116')->is_valid_number, '鹿児島県垂水市柊原');
ok($zip->set_number('8912117')->is_valid_number, '鹿児島県垂水市潮彩町');
ok($zip->set_number('8912121')->is_valid_number, '鹿児島県垂水市栄町');
ok($zip->set_number('8912122')->is_valid_number, '鹿児島県垂水市上町');
ok($zip->set_number('8912123')->is_valid_number, '鹿児島県垂水市本町');
ok($zip->set_number('8912124')->is_valid_number, '鹿児島県垂水市錦江町');
ok($zip->set_number('8912125')->is_valid_number, '鹿児島県垂水市旭町');
ok($zip->set_number('8912126')->is_valid_number, '鹿児島県垂水市南松原町');
ok($zip->set_number('8912127')->is_valid_number, '鹿児島県垂水市下宮町');
ok($zip->set_number('8912301')->is_valid_number, '鹿児島県鹿屋市有武町');
ok($zip->set_number('8912302')->is_valid_number, '鹿児島県鹿屋市小薄町');
ok($zip->set_number('8912303')->is_valid_number, '鹿児島県鹿屋市海道町');
ok($zip->set_number('8912304')->is_valid_number, '鹿児島県鹿屋市花岡町');
ok($zip->set_number('8912305')->is_valid_number, '鹿児島県鹿屋市根木原町');
ok($zip->set_number('8912306')->is_valid_number, '鹿児島県鹿屋市花里町');
ok($zip->set_number('8912311')->is_valid_number, '鹿児島県鹿屋市白水町');
ok($zip->set_number('8912312')->is_valid_number, '鹿児島県鹿屋市小野原町');
ok($zip->set_number('8912313')->is_valid_number, '鹿児島県鹿屋市天神町');
ok($zip->set_number('8912314')->is_valid_number, '鹿児島県鹿屋市船間町');
ok($zip->set_number('8912321')->is_valid_number, '鹿児島県鹿屋市古江町');
ok($zip->set_number('8912322')->is_valid_number, '鹿児島県鹿屋市古里町');
ok($zip->set_number('8913100')->is_valid_number, '鹿児島県西之表市以下に掲載がない場合');
ok($zip->set_number('8913101')->is_valid_number, '鹿児島県西之表市西之表');
ok($zip->set_number('8913102')->is_valid_number, '鹿児島県西之表市安納(1~3048、4901~4930番地)');
ok($zip->set_number('8913103')->is_valid_number, '鹿児島県西之表市現和');
ok($zip->set_number('8913104')->is_valid_number, '鹿児島県西之表市住吉');
ok($zip->set_number('8913111')->is_valid_number, '鹿児島県西之表市西町');
ok($zip->set_number('8913112')->is_valid_number, '鹿児島県西之表市栄町');
ok($zip->set_number('8913113')->is_valid_number, '鹿児島県西之表市東町');
ok($zip->set_number('8913114')->is_valid_number, '鹿児島県西之表市池田');
ok($zip->set_number('8913115')->is_valid_number, '鹿児島県西之表市天神町');
ok($zip->set_number('8913116')->is_valid_number, '鹿児島県西之表市鴨女町');
ok($zip->set_number('8913117')->is_valid_number, '鹿児島県西之表市桜が丘');
ok($zip->set_number('8913118')->is_valid_number, '鹿児島県西之表市馬毛島');
ok($zip->set_number('8913202')->is_valid_number, '鹿児島県西之表市安納(その他)');
ok($zip->set_number('8913221')->is_valid_number, '鹿児島県西之表市伊関');
ok($zip->set_number('8913222')->is_valid_number, '鹿児島県西之表市国上');
ok($zip->set_number('8913431')->is_valid_number, '鹿児島県西之表市古田');
ok($zip->set_number('8913432')->is_valid_number, '鹿児島県西之表市安城');
ok($zip->set_number('8913600')->is_valid_number, '鹿児島県熊毛郡中種子町以下に掲載がない場合');
ok($zip->set_number('8913601')->is_valid_number, '鹿児島県熊毛郡中種子町納官');
ok($zip->set_number('8913602')->is_valid_number, '鹿児島県熊毛郡中種子町牧川');
ok($zip->set_number('8913603')->is_valid_number, '鹿児島県熊毛郡中種子町増田');
ok($zip->set_number('8913604')->is_valid_number, '鹿児島県熊毛郡中種子町野間');
ok($zip->set_number('8913605')->is_valid_number, '鹿児島県熊毛郡中種子町油久');
ok($zip->set_number('8913606')->is_valid_number, '鹿児島県熊毛郡中種子町坂井');
ok($zip->set_number('8913607')->is_valid_number, '鹿児島県熊毛郡中種子町田島');
ok($zip->set_number('8913700')->is_valid_number, '鹿児島県熊毛郡南種子町以下に掲載がない場合');
ok($zip->set_number('8913701')->is_valid_number, '鹿児島県熊毛郡南種子町中之上');
ok($zip->set_number('8913702')->is_valid_number, '鹿児島県熊毛郡南種子町平山');
ok($zip->set_number('8913703')->is_valid_number, '鹿児島県熊毛郡南種子町茎永');
ok($zip->set_number('8913704')->is_valid_number, '鹿児島県熊毛郡南種子町中之下');
ok($zip->set_number('8913705')->is_valid_number, '鹿児島県熊毛郡南種子町西之');
ok($zip->set_number('8913706')->is_valid_number, '鹿児島県熊毛郡南種子町島間');
ok($zip->set_number('8914200')->is_valid_number, '鹿児島県熊毛郡屋久島町以下に掲載がない場合');
ok($zip->set_number('8914201')->is_valid_number, '鹿児島県熊毛郡屋久島町永田');
ok($zip->set_number('8914202')->is_valid_number, '鹿児島県熊毛郡屋久島町吉田');
ok($zip->set_number('8914203')->is_valid_number, '鹿児島県熊毛郡屋久島町一湊');
ok($zip->set_number('8914204')->is_valid_number, '鹿児島県熊毛郡屋久島町志戸子');
ok($zip->set_number('8914205')->is_valid_number, '鹿児島県熊毛郡屋久島町宮之浦');
ok($zip->set_number('8914206')->is_valid_number, '鹿児島県熊毛郡屋久島町楠川');
ok($zip->set_number('8914207')->is_valid_number, '鹿児島県熊毛郡屋久島町小瀬田');
ok($zip->set_number('8914208')->is_valid_number, '鹿児島県熊毛郡屋久島町口永良部島');
ok($zip->set_number('8914311')->is_valid_number, '鹿児島県熊毛郡屋久島町安房');
ok($zip->set_number('8914312')->is_valid_number, '鹿児島県熊毛郡屋久島町船行');
ok($zip->set_number('8914401')->is_valid_number, '鹿児島県熊毛郡屋久島町麦生(高平)');
ok($zip->set_number('8914402')->is_valid_number, '鹿児島県熊毛郡屋久島町麦生(その他)');
ok($zip->set_number('8914403')->is_valid_number, '鹿児島県熊毛郡屋久島町原');
ok($zip->set_number('8914404')->is_valid_number, '鹿児島県熊毛郡屋久島町尾之間');
ok($zip->set_number('8914405')->is_valid_number, '鹿児島県熊毛郡屋久島町小島');
ok($zip->set_number('8914406')->is_valid_number, '鹿児島県熊毛郡屋久島町平内');
ok($zip->set_number('8914407')->is_valid_number, '鹿児島県熊毛郡屋久島町湯泊');
ok($zip->set_number('8914408')->is_valid_number, '鹿児島県熊毛郡屋久島町中間');
ok($zip->set_number('8914409')->is_valid_number, '鹿児島県熊毛郡屋久島町栗生');
ok($zip->set_number('8915101')->is_valid_number, '鹿児島県鹿児島郡十島村口之島');
ok($zip->set_number('8915200')->is_valid_number, '鹿児島県鹿児島郡十島村以下に掲載がない場合');
ok($zip->set_number('8915201')->is_valid_number, '鹿児島県鹿児島郡十島村中之島');
ok($zip->set_number('8915202')->is_valid_number, '鹿児島県鹿児島郡十島村平島');
ok($zip->set_number('8915203')->is_valid_number, '鹿児島県鹿児島郡十島村諏訪之瀬島');
ok($zip->set_number('8915204')->is_valid_number, '鹿児島県鹿児島郡十島村悪石島');
ok($zip->set_number('8915205')->is_valid_number, '鹿児島県鹿児島郡十島村小宝島');
ok($zip->set_number('8915301')->is_valid_number, '鹿児島県鹿児島郡十島村宝島');
ok($zip->set_number('8916141')->is_valid_number, '鹿児島県大島郡喜界町伊実久');
ok($zip->set_number('8916142')->is_valid_number, '鹿児島県大島郡喜界町小野津');
ok($zip->set_number('8916143')->is_valid_number, '鹿児島県大島郡喜界町志戸桶');
ok($zip->set_number('8916144')->is_valid_number, '鹿児島県大島郡喜界町佐手久');
ok($zip->set_number('8916151')->is_valid_number, '鹿児島県大島郡喜界町塩道');
ok($zip->set_number('8916152')->is_valid_number, '鹿児島県大島郡喜界町早町');
ok($zip->set_number('8916153')->is_valid_number, '鹿児島県大島郡喜界町長嶺');
ok($zip->set_number('8916154')->is_valid_number, '鹿児島県大島郡喜界町白水');
ok($zip->set_number('8916161')->is_valid_number, '鹿児島県大島郡喜界町嘉鈍');
ok($zip->set_number('8916162')->is_valid_number, '鹿児島県大島郡喜界町阿伝');
ok($zip->set_number('8916163')->is_valid_number, '鹿児島県大島郡喜界町花良治(蒲生)');
ok($zip->set_number('8916164')->is_valid_number, '鹿児島県大島郡喜界町花良治');
ok($zip->set_number('8916200')->is_valid_number, '鹿児島県大島郡喜界町以下に掲載がない場合');
ok($zip->set_number('8916201')->is_valid_number, '鹿児島県大島郡喜界町赤連');
ok($zip->set_number('8916202')->is_valid_number, '鹿児島県大島郡喜界町湾');
ok($zip->set_number('8916203')->is_valid_number, '鹿児島県大島郡喜界町中里');
ok($zip->set_number('8916211')->is_valid_number, '鹿児島県大島郡喜界町中間');
ok($zip->set_number('8916212')->is_valid_number, '鹿児島県大島郡喜界町中熊(先内)');
ok($zip->set_number('8916213')->is_valid_number, '鹿児島県大島郡喜界町大朝戸');
ok($zip->set_number('8916214')->is_valid_number, '鹿児島県大島郡喜界町西目');
ok($zip->set_number('8916215')->is_valid_number, '鹿児島県大島郡喜界町中熊');
ok($zip->set_number('8916216')->is_valid_number, '鹿児島県大島郡喜界町坂嶺');
ok($zip->set_number('8916217')->is_valid_number, '鹿児島県大島郡喜界町伊砂');
ok($zip->set_number('8916221')->is_valid_number, '鹿児島県大島郡喜界町池治');
ok($zip->set_number('8916222')->is_valid_number, '鹿児島県大島郡喜界町島中');
ok($zip->set_number('8916223')->is_valid_number, '鹿児島県大島郡喜界町滝川');
ok($zip->set_number('8916224')->is_valid_number, '鹿児島県大島郡喜界町城久');
ok($zip->set_number('8916225')->is_valid_number, '鹿児島県大島郡喜界町山田');
ok($zip->set_number('8916226')->is_valid_number, '鹿児島県大島郡喜界町羽里');
ok($zip->set_number('8916227')->is_valid_number, '鹿児島県大島郡喜界町川嶺');
ok($zip->set_number('8916228')->is_valid_number, '鹿児島県大島郡喜界町浦原');
ok($zip->set_number('8916229')->is_valid_number, '鹿児島県大島郡喜界町先山');
ok($zip->set_number('8916231')->is_valid_number, '鹿児島県大島郡喜界町荒木');
ok($zip->set_number('8916232')->is_valid_number, '鹿児島県大島郡喜界町手久津久');
ok($zip->set_number('8916233')->is_valid_number, '鹿児島県大島郡喜界町上嘉鉄');
ok($zip->set_number('8917100')->is_valid_number, '鹿児島県大島郡徳之島町以下に掲載がない場合');
ok($zip->set_number('8917101')->is_valid_number, '鹿児島県大島郡徳之島町亀津');
ok($zip->set_number('8917102')->is_valid_number, '鹿児島県大島郡徳之島町亀徳');
ok($zip->set_number('8917103')->is_valid_number, '鹿児島県大島郡徳之島町南原');
ok($zip->set_number('8917104')->is_valid_number, '鹿児島県大島郡徳之島町尾母');
ok($zip->set_number('8917105')->is_valid_number, '鹿児島県大島郡徳之島町白井');
ok($zip->set_number('8917111')->is_valid_number, '鹿児島県大島郡徳之島町徳和瀬');
ok($zip->set_number('8917112')->is_valid_number, '鹿児島県大島郡徳之島町諸田');
ok($zip->set_number('8917113')->is_valid_number, '鹿児島県大島郡徳之島町神之嶺');
ok($zip->set_number('8917114')->is_valid_number, '鹿児島県大島郡徳之島町井之川');
ok($zip->set_number('8917115')->is_valid_number, '鹿児島県大島郡徳之島町下久志');
ok($zip->set_number('8917116')->is_valid_number, '鹿児島県大島郡徳之島町旭ケ丘');
ok($zip->set_number('8917421')->is_valid_number, '鹿児島県大島郡徳之島町手々');
ok($zip->set_number('8917422')->is_valid_number, '鹿児島県大島郡徳之島町金見');
ok($zip->set_number('8917423')->is_valid_number, '鹿児島県大島郡徳之島町山');
ok($zip->set_number('8917424')->is_valid_number, '鹿児島県大島郡徳之島町轟木');
ok($zip->set_number('8917425')->is_valid_number, '鹿児島県大島郡徳之島町花徳');
ok($zip->set_number('8917426')->is_valid_number, '鹿児島県大島郡徳之島町母間');
ok($zip->set_number('8917600')->is_valid_number, '鹿児島県大島郡天城町以下に掲載がない場合');
ok($zip->set_number('8917601')->is_valid_number, '鹿児島県大島郡天城町与名間');
ok($zip->set_number('8917602')->is_valid_number, '鹿児島県大島郡天城町松原');
ok($zip->set_number('8917603')->is_valid_number, '鹿児島県大島郡天城町岡前');
ok($zip->set_number('8917604')->is_valid_number, '鹿児島県大島郡天城町前野');
ok($zip->set_number('8917605')->is_valid_number, '鹿児島県大島郡天城町浅間');
ok($zip->set_number('8917611')->is_valid_number, '鹿児島県大島郡天城町天城');
ok($zip->set_number('8917612')->is_valid_number, '鹿児島県大島郡天城町平土野');
ok($zip->set_number('8917621')->is_valid_number, '鹿児島県大島郡天城町兼久');
ok($zip->set_number('8917622')->is_valid_number, '鹿児島県大島郡天城町大津川');
ok($zip->set_number('8917623')->is_valid_number, '鹿児島県大島郡天城町瀬滝');
ok($zip->set_number('8917624')->is_valid_number, '鹿児島県大島郡天城町当部');
ok($zip->set_number('8917731')->is_valid_number, '鹿児島県大島郡天城町西阿木名');
ok($zip->set_number('8918111')->is_valid_number, '鹿児島県大島郡伊仙町喜念');
ok($zip->set_number('8918112')->is_valid_number, '鹿児島県大島郡伊仙町佐弁');
ok($zip->set_number('8918113')->is_valid_number, '鹿児島県大島郡伊仙町目手久');
ok($zip->set_number('8918114')->is_valid_number, '鹿児島県大島郡伊仙町面縄');
ok($zip->set_number('8918115')->is_valid_number, '鹿児島県大島郡伊仙町古里');
ok($zip->set_number('8918116')->is_valid_number, '鹿児島県大島郡伊仙町検福(その他)');
ok($zip->set_number('8918117')->is_valid_number, '鹿児島県大島郡伊仙町中山');
ok($zip->set_number('8918201')->is_valid_number, '鹿児島県大島郡伊仙町伊仙');
ok($zip->set_number('8918216')->is_valid_number, '鹿児島県大島郡伊仙町検福(416~516番地)');
ok($zip->set_number('8918221')->is_valid_number, '鹿児島県大島郡伊仙町阿三(799の1~867番地)');
ok($zip->set_number('8918300')->is_valid_number, '鹿児島県大島郡伊仙町以下に掲載がない場合');
ok($zip->set_number('8918321')->is_valid_number, '鹿児島県大島郡伊仙町阿三(その他)');
ok($zip->set_number('8918322')->is_valid_number, '鹿児島県大島郡伊仙町阿権');
ok($zip->set_number('8918323')->is_valid_number, '鹿児島県大島郡伊仙町木之香');
ok($zip->set_number('8918324')->is_valid_number, '鹿児島県大島郡伊仙町糸木名');
ok($zip->set_number('8918325')->is_valid_number, '鹿児島県大島郡伊仙町八重竿');
ok($zip->set_number('8918326')->is_valid_number, '鹿児島県大島郡伊仙町馬根');
ok($zip->set_number('8918327')->is_valid_number, '鹿児島県大島郡伊仙町犬田布');
ok($zip->set_number('8918328')->is_valid_number, '鹿児島県大島郡伊仙町崎原');
ok($zip->set_number('8918329')->is_valid_number, '鹿児島県大島郡伊仙町小島');
ok($zip->set_number('8919100')->is_valid_number, '鹿児島県大島郡和泊町以下に掲載がない場合');
ok($zip->set_number('8919101')->is_valid_number, '鹿児島県大島郡和泊町国頭');
ok($zip->set_number('8919102')->is_valid_number, '鹿児島県大島郡和泊町喜美留');
ok($zip->set_number('8919103')->is_valid_number, '鹿児島県大島郡和泊町出花');
ok($zip->set_number('8919104')->is_valid_number, '鹿児島県大島郡和泊町西原');
ok($zip->set_number('8919111')->is_valid_number, '鹿児島県大島郡和泊町手々知名');
ok($zip->set_number('8919112')->is_valid_number, '鹿児島県大島郡和泊町和泊');
ok($zip->set_number('8919113')->is_valid_number, '鹿児島県大島郡和泊町和');
ok($zip->set_number('8919114')->is_valid_number, '鹿児島県大島郡和泊町畦布');
ok($zip->set_number('8919115')->is_valid_number, '鹿児島県大島郡和泊町伊延');
ok($zip->set_number('8919116')->is_valid_number, '鹿児島県大島郡和泊町上手々知名');
ok($zip->set_number('8919121')->is_valid_number, '鹿児島県大島郡和泊町根折');
ok($zip->set_number('8919122')->is_valid_number, '鹿児島県大島郡和泊町玉城');
ok($zip->set_number('8919123')->is_valid_number, '鹿児島県大島郡和泊町皆川');
ok($zip->set_number('8919124')->is_valid_number, '鹿児島県大島郡和泊町古里');
ok($zip->set_number('8919125')->is_valid_number, '鹿児島県大島郡和泊町大城');
ok($zip->set_number('8919131')->is_valid_number, '鹿児島県大島郡和泊町内城');
ok($zip->set_number('8919132')->is_valid_number, '鹿児島県大島郡和泊町後蘭');
ok($zip->set_number('8919133')->is_valid_number, '鹿児島県大島郡和泊町谷山');
ok($zip->set_number('8919134')->is_valid_number, '鹿児島県大島郡和泊町仁志');
ok($zip->set_number('8919135')->is_valid_number, '鹿児島県大島郡和泊町永嶺');
ok($zip->set_number('8919136')->is_valid_number, '鹿児島県大島郡和泊町瀬名');
ok($zip->set_number('8919200')->is_valid_number, '鹿児島県大島郡知名町以下に掲載がない場合');
ok($zip->set_number('8919201')->is_valid_number, '鹿児島県大島郡知名町余多');
ok($zip->set_number('8919202')->is_valid_number, '鹿児島県大島郡知名町屋者');
ok($zip->set_number('8919203')->is_valid_number, '鹿児島県大島郡知名町下平川');
ok($zip->set_number('8919204')->is_valid_number, '鹿児島県大島郡知名町上平川');
ok($zip->set_number('8919205')->is_valid_number, '鹿児島県大島郡知名町久志検');
ok($zip->set_number('8919206')->is_valid_number, '鹿児島県大島郡知名町赤嶺');
ok($zip->set_number('8919207')->is_valid_number, '鹿児島県大島郡知名町竿津');
ok($zip->set_number('8919211')->is_valid_number, '鹿児島県大島郡知名町芦清良');
ok($zip->set_number('8919212')->is_valid_number, '鹿児島県大島郡知名町黒貫');
ok($zip->set_number('8919213')->is_valid_number, '鹿児島県大島郡知名町瀬利覚');
ok($zip->set_number('8919214')->is_valid_number, '鹿児島県大島郡知名町知名');
ok($zip->set_number('8919215')->is_valid_number, '鹿児島県大島郡知名町屋子母');
ok($zip->set_number('8919221')->is_valid_number, '鹿児島県大島郡知名町大津勘');
ok($zip->set_number('8919222')->is_valid_number, '鹿児島県大島郡知名町徳時');
ok($zip->set_number('8919223')->is_valid_number, '鹿児島県大島郡知名町住吉');
ok($zip->set_number('8919224')->is_valid_number, '鹿児島県大島郡知名町正名');
ok($zip->set_number('8919231')->is_valid_number, '鹿児島県大島郡知名町田皆');
ok($zip->set_number('8919232')->is_valid_number, '鹿児島県大島郡知名町新城');
ok($zip->set_number('8919233')->is_valid_number, '鹿児島県大島郡知名町下城');
ok($zip->set_number('8919234')->is_valid_number, '鹿児島県大島郡知名町上城');
ok($zip->set_number('8919300')->is_valid_number, '鹿児島県大島郡与論町以下に掲載がない場合');
ok($zip->set_number('8919301')->is_valid_number, '鹿児島県大島郡与論町茶花');
ok($zip->set_number('8919302')->is_valid_number, '鹿児島県大島郡与論町立長');
ok($zip->set_number('8919303')->is_valid_number, '鹿児島県大島郡与論町城');
ok($zip->set_number('8919304')->is_valid_number, '鹿児島県大島郡与論町朝戸');
ok($zip->set_number('8919305')->is_valid_number, '鹿児島県大島郡与論町西区');
ok($zip->set_number('8919306')->is_valid_number, '鹿児島県大島郡与論町東区');
ok($zip->set_number('8919307')->is_valid_number, '鹿児島県大島郡与論町古里');
ok($zip->set_number('8919308')->is_valid_number, '鹿児島県大島郡与論町那間');
ok($zip->set_number('8919309')->is_valid_number, '鹿児島県大島郡与論町叶');
ok($zip->set_number('8920801')->is_valid_number, '鹿児島県鹿児島市稲荷町');
ok($zip->set_number('8920802')->is_valid_number, '鹿児島県鹿児島市清水町');
ok($zip->set_number('8920803')->is_valid_number, '鹿児島県鹿児島市祇園之洲町');
ok($zip->set_number('8920804')->is_valid_number, '鹿児島県鹿児島市春日町');
ok($zip->set_number('8920805')->is_valid_number, '鹿児島県鹿児島市大竜町');
ok($zip->set_number('8920806')->is_valid_number, '鹿児島県鹿児島市池之上町');
ok($zip->set_number('8920807')->is_valid_number, '鹿児島県鹿児島市皷川町');
ok($zip->set_number('8920811')->is_valid_number, '鹿児島県鹿児島市玉里団地(2、3丁目)');
ok($zip->set_number('8920812')->is_valid_number, '鹿児島県鹿児島市浜町');
ok($zip->set_number('8920813')->is_valid_number, '鹿児島県鹿児島市城山(2丁目)');
ok($zip->set_number('8920814')->is_valid_number, '鹿児島県鹿児島市本港新町');
ok($zip->set_number('8920815')->is_valid_number, '鹿児島県鹿児島市易居町');
ok($zip->set_number('8920816')->is_valid_number, '鹿児島県鹿児島市山下町');
ok($zip->set_number('8920817')->is_valid_number, '鹿児島県鹿児島市小川町');
ok($zip->set_number('8920818')->is_valid_number, '鹿児島県鹿児島市上本町');
ok($zip->set_number('8920819')->is_valid_number, '鹿児島県鹿児島市柳町');
ok($zip->set_number('8920821')->is_valid_number, '鹿児島県鹿児島市名山町');
ok($zip->set_number('8920822')->is_valid_number, '鹿児島県鹿児島市泉町');
ok($zip->set_number('8920823')->is_valid_number, '鹿児島県鹿児島市住吉町');
ok($zip->set_number('8920824')->is_valid_number, '鹿児島県鹿児島市堀江町');
ok($zip->set_number('8920825')->is_valid_number, '鹿児島県鹿児島市大黒町');
ok($zip->set_number('8920826')->is_valid_number, '鹿児島県鹿児島市呉服町');
ok($zip->set_number('8920827')->is_valid_number, '鹿児島県鹿児島市中町');
ok($zip->set_number('8920828')->is_valid_number, '鹿児島県鹿児島市金生町');
ok($zip->set_number('8920831')->is_valid_number, '鹿児島県鹿児島市船津町');
ok($zip->set_number('8920832')->is_valid_number, '鹿児島県鹿児島市新町');
ok($zip->set_number('8920833')->is_valid_number, '鹿児島県鹿児島市松原町');
ok($zip->set_number('8920834')->is_valid_number, '鹿児島県鹿児島市南林寺町');
ok($zip->set_number('8920835')->is_valid_number, '鹿児島県鹿児島市城南町');
ok($zip->set_number('8920836')->is_valid_number, '鹿児島県鹿児島市錦江町');
ok($zip->set_number('8920837')->is_valid_number, '鹿児島県鹿児島市甲突町');
ok($zip->set_number('8920838')->is_valid_number, '鹿児島県鹿児島市新屋敷町');
ok($zip->set_number('8920841')->is_valid_number, '鹿児島県鹿児島市照国町');
ok($zip->set_number('8920842')->is_valid_number, '鹿児島県鹿児島市東千石町');
ok($zip->set_number('8920843')->is_valid_number, '鹿児島県鹿児島市千日町');
ok($zip->set_number('8920844')->is_valid_number, '鹿児島県鹿児島市山之口町');
ok($zip->set_number('8920845')->is_valid_number, '鹿児島県鹿児島市樋之口町');
ok($zip->set_number('8920846')->is_valid_number, '鹿児島県鹿児島市加治屋町');
ok($zip->set_number('8920847')->is_valid_number, '鹿児島県鹿児島市西千石町');
ok($zip->set_number('8920848')->is_valid_number, '鹿児島県鹿児島市平之町');
ok($zip->set_number('8920851')->is_valid_number, '鹿児島県鹿児島市上竜尾町');
ok($zip->set_number('8920852')->is_valid_number, '鹿児島県鹿児島市下竜尾町');
ok($zip->set_number('8920853')->is_valid_number, '鹿児島県鹿児島市城山町');
ok($zip->set_number('8920854')->is_valid_number, '鹿児島県鹿児島市長田町');
ok($zip->set_number('8920855')->is_valid_number, '鹿児島県鹿児島市冷水町');
ok($zip->set_number('8920861')->is_valid_number, '鹿児島県鹿児島市東坂元');
ok($zip->set_number('8920862')->is_valid_number, '鹿児島県鹿児島市坂元町');
ok($zip->set_number('8920863')->is_valid_number, '鹿児島県鹿児島市西坂元町');
ok($zip->set_number('8920871')->is_valid_number, '鹿児島県鹿児島市吉野町');
ok($zip->set_number('8920872')->is_valid_number, '鹿児島県鹿児島市大明丘');
ok($zip->set_number('8920873')->is_valid_number, '鹿児島県鹿児島市下田町');
ok($zip->set_number('8920874')->is_valid_number, '鹿児島県鹿児島市緑ヶ丘町(1~34番)');
ok($zip->set_number('8920875')->is_valid_number, '鹿児島県鹿児島市川上町(その他)');
ok($zip->set_number('8920876')->is_valid_number, '鹿児島県鹿児島市岡之原町(832の2・4、852の3)');
ok($zip->set_number('8920877')->is_valid_number, '鹿児島県鹿児島市吉野');
ok($zip->set_number('8930000')->is_valid_number, '鹿児島県鹿屋市以下に掲載がない場合');
ok($zip->set_number('8930001')->is_valid_number, '鹿児島県鹿屋市古前城町');
ok($zip->set_number('8930002')->is_valid_number, '鹿児島県鹿屋市本町');
ok($zip->set_number('8930003')->is_valid_number, '鹿児島県鹿屋市曽田町');
ok($zip->set_number('8930004')->is_valid_number, '鹿児島県鹿屋市朝日町');
ok($zip->set_number('8930005')->is_valid_number, '鹿児島県鹿屋市共栄町');
ok($zip->set_number('8930006')->is_valid_number, '鹿児島県鹿屋市向江町');
ok($zip->set_number('8930007')->is_valid_number, '鹿児島県鹿屋市北田町');
ok($zip->set_number('8930008')->is_valid_number, '鹿児島県鹿屋市西大手町');
ok($zip->set_number('8930009')->is_valid_number, '鹿児島県鹿屋市大手町');
ok($zip->set_number('8930011')->is_valid_number, '鹿児島県鹿屋市打馬');
ok($zip->set_number('8930012')->is_valid_number, '鹿児島県鹿屋市王子町');
ok($zip->set_number('8930013')->is_valid_number, '鹿児島県鹿屋市札元');
ok($zip->set_number('8930014')->is_valid_number, '鹿児島県鹿屋市寿');
ok($zip->set_number('8930015')->is_valid_number, '鹿児島県鹿屋市新川町');
ok($zip->set_number('8930016')->is_valid_number, '鹿児島県鹿屋市白崎町');
ok($zip->set_number('8930021')->is_valid_number, '鹿児島県鹿屋市東原町');
ok($zip->set_number('8930022')->is_valid_number, '鹿児島県鹿屋市旭原町');
ok($zip->set_number('8930023')->is_valid_number, '鹿児島県鹿屋市笠之原町');
ok($zip->set_number('8930024')->is_valid_number, '鹿児島県鹿屋市下祓川町');
ok($zip->set_number('8930025')->is_valid_number, '鹿児島県鹿屋市西祓川町');
ok($zip->set_number('8930026')->is_valid_number, '鹿児島県鹿屋市祓川町');
ok($zip->set_number('8930027')->is_valid_number, '鹿児島県鹿屋市上祓川町');
ok($zip->set_number('8930031')->is_valid_number, '鹿児島県鹿屋市川東町');
ok($zip->set_number('8930032')->is_valid_number, '鹿児島県鹿屋市川西町');
ok($zip->set_number('8930033')->is_valid_number, '鹿児島県鹿屋市永野田町');
ok($zip->set_number('8930034')->is_valid_number, '鹿児島県鹿屋市名貫町');
ok($zip->set_number('8930035')->is_valid_number, '鹿児島県鹿屋市飯隈町');
ok($zip->set_number('8930036')->is_valid_number, '鹿児島県鹿屋市萩塚町');
ok($zip->set_number('8930037')->is_valid_number, '鹿児島県鹿屋市田崎町');
ok($zip->set_number('8930041')->is_valid_number, '鹿児島県鹿屋市星塚町');
ok($zip->set_number('8930042')->is_valid_number, '鹿児島県鹿屋市池園町');
ok($zip->set_number('8930043')->is_valid_number, '鹿児島県鹿屋市南町');
ok($zip->set_number('8930044')->is_valid_number, '鹿児島県鹿屋市獅子目町');
ok($zip->set_number('8930045')->is_valid_number, '鹿児島県鹿屋市田淵町');
ok($zip->set_number('8930046')->is_valid_number, '鹿児島県鹿屋市横山町');
ok($zip->set_number('8930047')->is_valid_number, '鹿児島県鹿屋市下堀町');
ok($zip->set_number('8930051')->is_valid_number, '鹿児島県鹿屋市大姶良町');
ok($zip->set_number('8930052')->is_valid_number, '鹿児島県鹿屋市永小原町');
ok($zip->set_number('8930053')->is_valid_number, '鹿児島県鹿屋市浜田町');
ok($zip->set_number('8930054')->is_valid_number, '鹿児島県鹿屋市高須町');
ok($zip->set_number('8930055')->is_valid_number, '鹿児島県鹿屋市野里町');
ok($zip->set_number('8930056')->is_valid_number, '鹿児島県鹿屋市上野町');
ok($zip->set_number('8930057')->is_valid_number, '鹿児島県鹿屋市今坂町');
ok($zip->set_number('8930061')->is_valid_number, '鹿児島県鹿屋市上谷町');
ok($zip->set_number('8930062')->is_valid_number, '鹿児島県鹿屋市新生町');
ok($zip->set_number('8930063')->is_valid_number, '鹿児島県鹿屋市新栄町');
ok($zip->set_number('8930064')->is_valid_number, '鹿児島県鹿屋市西原');
ok($zip->set_number('8930065')->is_valid_number, '鹿児島県鹿屋市郷之原町');
ok($zip->set_number('8930066')->is_valid_number, '鹿児島県鹿屋市高牧町');
ok($zip->set_number('8930067')->is_valid_number, '鹿児島県鹿屋市大浦町');
ok($zip->set_number('8930131')->is_valid_number, '鹿児島県鹿屋市上高隈町');
ok($zip->set_number('8930132')->is_valid_number, '鹿児島県鹿屋市下高隈町');
ok($zip->set_number('8930201')->is_valid_number, '鹿児島県鹿屋市輝北町上百引');
ok($zip->set_number('8930202')->is_valid_number, '鹿児島県鹿屋市輝北町下百引');
ok($zip->set_number('8930203')->is_valid_number, '鹿児島県鹿屋市輝北町平房');
ok($zip->set_number('8931101')->is_valid_number, '鹿児島県鹿屋市吾平町上名');
ok($zip->set_number('8931102')->is_valid_number, '鹿児島県鹿屋市吾平町下名');
ok($zip->set_number('8931103')->is_valid_number, '鹿児島県鹿屋市吾平町麓');
ok($zip->set_number('8931200')->is_valid_number, '鹿児島県肝属郡肝付町以下に掲載がない場合');
ok($zip->set_number('8931201')->is_valid_number, '鹿児島県肝属郡肝付町野崎');
ok($zip->set_number('8931202')->is_valid_number, '鹿児島県肝属郡肝付町波見');
ok($zip->set_number('8931203')->is_valid_number, '鹿児島県肝属郡肝付町後田');
ok($zip->set_number('8931204')->is_valid_number, '鹿児島県肝属郡肝付町富山');
ok($zip->set_number('8931205')->is_valid_number, '鹿児島県肝属郡肝付町宮下');
ok($zip->set_number('8931206')->is_valid_number, '鹿児島県肝属郡肝付町前田');
ok($zip->set_number('8931207')->is_valid_number, '鹿児島県肝属郡肝付町新富');
ok($zip->set_number('8931401')->is_valid_number, '鹿児島県肝属郡肝付町北方');
ok($zip->set_number('8931402')->is_valid_number, '鹿児島県肝属郡肝付町南方');
ok($zip->set_number('8931511')->is_valid_number, '鹿児島県肝属郡肝付町岸良');
ok($zip->set_number('8931600')->is_valid_number, '鹿児島県肝属郡東串良町以下に掲載がない場合');
ok($zip->set_number('8931601')->is_valid_number, '鹿児島県鹿屋市串良町細山田');
ok($zip->set_number('8931602')->is_valid_number, '鹿児島県鹿屋市串良町有里');
ok($zip->set_number('8931603')->is_valid_number, '鹿児島県鹿屋市串良町岡崎');
ok($zip->set_number('8931604')->is_valid_number, '鹿児島県鹿屋市串良町下小原');
ok($zip->set_number('8931605')->is_valid_number, '鹿児島県鹿屋市串良町上小原');
ok($zip->set_number('8931611')->is_valid_number, '鹿児島県肝属郡東串良町岩弘');
ok($zip->set_number('8931612')->is_valid_number, '鹿児島県肝属郡東串良町池之原');
ok($zip->set_number('8931613')->is_valid_number, '鹿児島県肝属郡東串良町川西');
ok($zip->set_number('8931614')->is_valid_number, '鹿児島県肝属郡東串良町新川西');
ok($zip->set_number('8931615')->is_valid_number, '鹿児島県肝属郡東串良町川東');
ok($zip->set_number('8932300')->is_valid_number, '鹿児島県肝属郡錦江町以下に掲載がない場合');
ok($zip->set_number('8932301')->is_valid_number, '鹿児島県肝属郡錦江町神川');
ok($zip->set_number('8932302')->is_valid_number, '鹿児島県肝属郡錦江町城元');
ok($zip->set_number('8932303')->is_valid_number, '鹿児島県肝属郡錦江町馬場');
ok($zip->set_number('8932401')->is_valid_number, '鹿児島県肝属郡錦江町田代麓');
ok($zip->set_number('8932402')->is_valid_number, '鹿児島県肝属郡錦江町田代川原');
ok($zip->set_number('8932500')->is_valid_number, '鹿児島県肝属郡南大隅町以下に掲載がない場合');
ok($zip->set_number('8932501')->is_valid_number, '鹿児島県肝属郡南大隅町根占川北');
ok($zip->set_number('8932502')->is_valid_number, '鹿児島県肝属郡南大隅町根占川南');
ok($zip->set_number('8932503')->is_valid_number, '鹿児島県肝属郡南大隅町根占横別府');
ok($zip->set_number('8932504')->is_valid_number, '鹿児島県肝属郡南大隅町根占山本');
ok($zip->set_number('8932505')->is_valid_number, '鹿児島県肝属郡南大隅町根占辺田');
ok($zip->set_number('8932601')->is_valid_number, '鹿児島県肝属郡南大隅町佐多伊座敷');
ok($zip->set_number('8932602')->is_valid_number, '鹿児島県肝属郡南大隅町佐多辺塚');
ok($zip->set_number('8932603')->is_valid_number, '鹿児島県肝属郡南大隅町佐多郡');
ok($zip->set_number('8932604')->is_valid_number, '鹿児島県肝属郡南大隅町佐多馬籠');
ok($zip->set_number('8940000')->is_valid_number, '鹿児島県奄美市以下に掲載がない場合');
ok($zip->set_number('8940001')->is_valid_number, '鹿児島県奄美市名瀬大熊');
ok($zip->set_number('8940002')->is_valid_number, '鹿児島県奄美市名瀬有屋');
ok($zip->set_number('8940003')->is_valid_number, '鹿児島県奄美市名瀬仲勝');
ok($zip->set_number('8940004')->is_valid_number, '鹿児島県奄美市名瀬鳩浜町');
ok($zip->set_number('8940005')->is_valid_number, '鹿児島県奄美市名瀬佐大熊町');
ok($zip->set_number('8940006')->is_valid_number, '鹿児島県奄美市名瀬小浜町');
ok($zip->set_number('8940007')->is_valid_number, '鹿児島県奄美市名瀬和光町');
ok($zip->set_number('8940008')->is_valid_number, '鹿児島県奄美市名瀬浦上(その他)');
ok($zip->set_number('8940009')->is_valid_number, '鹿児島県奄美市名瀬大熊町');
ok($zip->set_number('8940011')->is_valid_number, '鹿児島県奄美市名瀬安勝町');
ok($zip->set_number('8940012')->is_valid_number, '鹿児島県奄美市名瀬小俣町');
ok($zip->set_number('8940013')->is_valid_number, '鹿児島県奄美市名瀬春日町');
ok($zip->set_number('8940014')->is_valid_number, '鹿児島県奄美市名瀬平田町');
ok($zip->set_number('8940015')->is_valid_number, '鹿児島県奄美市名瀬真名津町');
ok($zip->set_number('8940016')->is_valid_number, '鹿児島県奄美市名瀬古田町');
ok($zip->set_number('8940017')->is_valid_number, '鹿児島県奄美市名瀬石橋町');
ok($zip->set_number('8940021')->is_valid_number, '鹿児島県奄美市名瀬伊津部町');
ok($zip->set_number('8940022')->is_valid_number, '鹿児島県奄美市名瀬久里町');
ok($zip->set_number('8940023')->is_valid_number, '鹿児島県奄美市名瀬永田町');
ok($zip->set_number('8940024')->is_valid_number, '鹿児島県奄美市名瀬井根町');
ok($zip->set_number('8940025')->is_valid_number, '鹿児島県奄美市名瀬幸町');
ok($zip->set_number('8940026')->is_valid_number, '鹿児島県奄美市名瀬港町');
ok($zip->set_number('8940027')->is_valid_number, '鹿児島県奄美市名瀬末広町');
ok($zip->set_number('8940031')->is_valid_number, '鹿児島県奄美市名瀬金久町');
ok($zip->set_number('8940032')->is_valid_number, '鹿児島県奄美市名瀬柳町');
ok($zip->set_number('8940033')->is_valid_number, '鹿児島県奄美市名瀬矢之脇町');
ok($zip->set_number('8940034')->is_valid_number, '鹿児島県奄美市名瀬入舟町');
ok($zip->set_number('8940035')->is_valid_number, '鹿児島県奄美市名瀬塩浜町');
ok($zip->set_number('8940036')->is_valid_number, '鹿児島県奄美市名瀬長浜町');
ok($zip->set_number('8940041')->is_valid_number, '鹿児島県奄美市名瀬朝仁新町');
ok($zip->set_number('8940042')->is_valid_number, '鹿児島県奄美市名瀬朝仁町');
ok($zip->set_number('8940043')->is_valid_number, '鹿児島県奄美市名瀬朝仁');
ok($zip->set_number('8940044')->is_valid_number, '鹿児島県奄美市名瀬浜里町');
ok($zip->set_number('8940045')->is_valid_number, '鹿児島県奄美市名瀬平松町');
ok($zip->set_number('8940046')->is_valid_number, '鹿児島県奄美市名瀬小宿');
ok($zip->set_number('8940047')->is_valid_number, '鹿児島県奄美市名瀬知名瀬');
ok($zip->set_number('8940048')->is_valid_number, '鹿児島県奄美市名瀬根瀬部');
ok($zip->set_number('8940061')->is_valid_number, '鹿児島県奄美市名瀬朝日町');
ok($zip->set_number('8940062')->is_valid_number, '鹿児島県奄美市名瀬有屋町');
ok($zip->set_number('8940063')->is_valid_number, '鹿児島県奄美市名瀬仲勝町');
ok($zip->set_number('8940068')->is_valid_number, '鹿児島県奄美市名瀬浦上町');
ok($zip->set_number('8940100')->is_valid_number, '鹿児島県大島郡龍郷町以下に掲載がない場合');
ok($zip->set_number('8940101')->is_valid_number, '鹿児島県大島郡龍郷町屋入');
ok($zip->set_number('8940102')->is_valid_number, '鹿児島県大島郡龍郷町瀬留');
ok($zip->set_number('8940103')->is_valid_number, '鹿児島県大島郡龍郷町玉里');
ok($zip->set_number('8940104')->is_valid_number, '鹿児島県大島郡龍郷町浦');
ok($zip->set_number('8940105')->is_valid_number, '鹿児島県大島郡龍郷町大勝');
ok($zip->set_number('8940106')->is_valid_number, '鹿児島県大島郡龍郷町中勝');
ok($zip->set_number('8940107')->is_valid_number, '鹿児島県大島郡龍郷町戸口');
ok($zip->set_number('8940108')->is_valid_number, '鹿児島県奄美市名瀬浦上(小又)');
ok($zip->set_number('8940321')->is_valid_number, '鹿児島県大島郡龍郷町龍郷');
ok($zip->set_number('8940322')->is_valid_number, '鹿児島県大島郡龍郷町久場');
ok($zip->set_number('8940323')->is_valid_number, '鹿児島県大島郡龍郷町安木屋場');
ok($zip->set_number('8940324')->is_valid_number, '鹿児島県大島郡龍郷町円');
ok($zip->set_number('8940331')->is_valid_number, '鹿児島県大島郡龍郷町嘉渡');
ok($zip->set_number('8940332')->is_valid_number, '鹿児島県大島郡龍郷町幾里');
ok($zip->set_number('8940333')->is_valid_number, '鹿児島県大島郡龍郷町秋名');
ok($zip->set_number('8940351')->is_valid_number, '鹿児島県奄美市名瀬芦花部');
ok($zip->set_number('8940352')->is_valid_number, '鹿児島県奄美市名瀬有良');
ok($zip->set_number('8940411')->is_valid_number, '鹿児島県大島郡龍郷町赤尾木');
ok($zip->set_number('8940412')->is_valid_number, '鹿児島県大島郡龍郷町芦徳');
ok($zip->set_number('8940501')->is_valid_number, '鹿児島県奄美市笠利町宇宿');
ok($zip->set_number('8940502')->is_valid_number, '鹿児島県奄美市笠利町万屋');
ok($zip->set_number('8940503')->is_valid_number, '鹿児島県奄美市笠利町和野');
ok($zip->set_number('8940504')->is_valid_number, '鹿児島県奄美市笠利町節田');
ok($zip->set_number('8940505')->is_valid_number, '鹿児島県奄美市笠利町平');
ok($zip->set_number('8940506')->is_valid_number, '鹿児島県奄美市笠利町手花部');
ok($zip->set_number('8940507')->is_valid_number, '鹿児島県奄美市笠利町喜瀬');
ok($zip->set_number('8940508')->is_valid_number, '鹿児島県奄美市笠利町用安');
ok($zip->set_number('8940511')->is_valid_number, '鹿児島県奄美市笠利町里');
ok($zip->set_number('8940512')->is_valid_number, '鹿児島県奄美市笠利町中金久');
ok($zip->set_number('8940513')->is_valid_number, '鹿児島県奄美市笠利町外金久');
ok($zip->set_number('8940621')->is_valid_number, '鹿児島県奄美市笠利町用');
ok($zip->set_number('8940622')->is_valid_number, '鹿児島県奄美市笠利町笠利');
ok($zip->set_number('8940623')->is_valid_number, '鹿児島県奄美市笠利町辺留');
ok($zip->set_number('8940624')->is_valid_number, '鹿児島県奄美市笠利町須野');
ok($zip->set_number('8940625')->is_valid_number, '鹿児島県奄美市笠利町川上');
ok($zip->set_number('8940626')->is_valid_number, '鹿児島県奄美市笠利町屋仁');
ok($zip->set_number('8940627')->is_valid_number, '鹿児島県奄美市笠利町佐仁');
ok($zip->set_number('8940771')->is_valid_number, '鹿児島県奄美市名瀬小湊');
ok($zip->set_number('8940772')->is_valid_number, '鹿児島県奄美市名瀬西仲勝');
ok($zip->set_number('8940773')->is_valid_number, '鹿児島県奄美市名瀬朝戸');
ok($zip->set_number('8940774')->is_valid_number, '鹿児島県奄美市名瀬伊津部勝');
ok($zip->set_number('8940775')->is_valid_number, '鹿児島県奄美市名瀬名瀬勝');
ok($zip->set_number('8940776')->is_valid_number, '鹿児島県奄美市名瀬崎原');
ok($zip->set_number('8941111')->is_valid_number, '鹿児島県奄美市住用町城');
ok($zip->set_number('8941112')->is_valid_number, '鹿児島県奄美市住用町和瀬');
ok($zip->set_number('8941113')->is_valid_number, '鹿児島県奄美市住用町見里');
ok($zip->set_number('8941114')->is_valid_number, '鹿児島県奄美市住用町東仲間');
ok($zip->set_number('8941115')->is_valid_number, '鹿児島県奄美市住用町川内');
ok($zip->set_number('8941116')->is_valid_number, '鹿児島県奄美市住用町摺勝');
ok($zip->set_number('8941201')->is_valid_number, '鹿児島県奄美市住用町石原');
ok($zip->set_number('8941202')->is_valid_number, '鹿児島県奄美市住用町西仲間');
ok($zip->set_number('8941203')->is_valid_number, '鹿児島県奄美市住用町神屋');
ok($zip->set_number('8941204')->is_valid_number, '鹿児島県奄美市住用町山間(その他)');
ok($zip->set_number('8941205')->is_valid_number, '鹿児島県奄美市住用町役勝');
ok($zip->set_number('8941304')->is_valid_number, '鹿児島県奄美市住用町山間(493~592番地、戸玉)');
ok($zip->set_number('8941321')->is_valid_number, '鹿児島県奄美市住用町市');
ok($zip->set_number('8941500')->is_valid_number, '鹿児島県大島郡瀬戸内町以下に掲載がない場合');
ok($zip->set_number('8941501')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋(高丘)');
ok($zip->set_number('8941502')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋(宮前)');
ok($zip->set_number('8941503')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋(大湊)');
ok($zip->set_number('8941504')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋(春日)');
ok($zip->set_number('8941505')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋(松江)');
ok($zip->set_number('8941506')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋(船津)');
ok($zip->set_number('8941507')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋(瀬久井)');
ok($zip->set_number('8941508')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋');
ok($zip->set_number('8941509')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋瀬久井東');
ok($zip->set_number('8941510')->is_valid_number, '鹿児島県大島郡瀬戸内町古仁屋瀬久井西');
ok($zip->set_number('8941511')->is_valid_number, '鹿児島県大島郡瀬戸内町阿木名');
ok($zip->set_number('8941512')->is_valid_number, '鹿児島県大島郡瀬戸内町勝浦');
ok($zip->set_number('8941513')->is_valid_number, '鹿児島県大島郡瀬戸内町網野子');
ok($zip->set_number('8941514')->is_valid_number, '鹿児島県大島郡瀬戸内町節子');
ok($zip->set_number('8941515')->is_valid_number, '鹿児島県大島郡瀬戸内町嘉徳');
ok($zip->set_number('8941521')->is_valid_number, '鹿児島県大島郡瀬戸内町清水');
ok($zip->set_number('8941522')->is_valid_number, '鹿児島県大島郡瀬戸内町嘉鉄');
ok($zip->set_number('8941523')->is_valid_number, '鹿児島県大島郡瀬戸内町蘇刈');
ok($zip->set_number('8941524')->is_valid_number, '鹿児島県大島郡瀬戸内町伊須');
ok($zip->set_number('8941531')->is_valid_number, '鹿児島県大島郡瀬戸内町手安');
ok($zip->set_number('8941741')->is_valid_number, '鹿児島県大島郡瀬戸内町篠川');
ok($zip->set_number('8941742')->is_valid_number, '鹿児島県大島郡瀬戸内町阿室釜');
ok($zip->set_number('8941743')->is_valid_number, '鹿児島県大島郡瀬戸内町小名瀬');
ok($zip->set_number('8941744')->is_valid_number, '鹿児島県大島郡瀬戸内町阿鉄');
ok($zip->set_number('8941745')->is_valid_number, '鹿児島県大島郡瀬戸内町油井');
ok($zip->set_number('8941746')->is_valid_number, '鹿児島県大島郡瀬戸内町久根津');
ok($zip->set_number('8941851')->is_valid_number, '鹿児島県大島郡瀬戸内町久慈');
ok($zip->set_number('8941852')->is_valid_number, '鹿児島県大島郡瀬戸内町古志');
ok($zip->set_number('8941853')->is_valid_number, '鹿児島県大島郡瀬戸内町花天');
ok($zip->set_number('8941854')->is_valid_number, '鹿児島県大島郡瀬戸内町管鈍');
ok($zip->set_number('8941855')->is_valid_number, '鹿児島県大島郡瀬戸内町西古見');
ok($zip->set_number('8942141')->is_valid_number, '鹿児島県大島郡瀬戸内町諸鈍');
ok($zip->set_number('8942142')->is_valid_number, '鹿児島県大島郡瀬戸内町生間');
ok($zip->set_number('8942143')->is_valid_number, '鹿児島県大島郡瀬戸内町渡連');
ok($zip->set_number('8942144')->is_valid_number, '鹿児島県大島郡瀬戸内町諸数');
ok($zip->set_number('8942231')->is_valid_number, '鹿児島県大島郡瀬戸内町押角');
ok($zip->set_number('8942232')->is_valid_number, '鹿児島県大島郡瀬戸内町勝能');
ok($zip->set_number('8942233')->is_valid_number, '鹿児島県大島郡瀬戸内町野見山');
ok($zip->set_number('8942234')->is_valid_number, '鹿児島県大島郡瀬戸内町秋徳');
ok($zip->set_number('8942235')->is_valid_number, '鹿児島県大島郡瀬戸内町於斉');
ok($zip->set_number('8942236')->is_valid_number, '鹿児島県大島郡瀬戸内町伊子茂');
ok($zip->set_number('8942237')->is_valid_number, '鹿児島県大島郡瀬戸内町花富');
ok($zip->set_number('8942321')->is_valid_number, '鹿児島県大島郡瀬戸内町西阿室');
ok($zip->set_number('8942322')->is_valid_number, '鹿児島県大島郡瀬戸内町瀬相');
ok($zip->set_number('8942323')->is_valid_number, '鹿児島県大島郡瀬戸内町俵');
ok($zip->set_number('8942401')->is_valid_number, '鹿児島県大島郡瀬戸内町瀬武');
ok($zip->set_number('8942402')->is_valid_number, '鹿児島県大島郡瀬戸内町薩川');
ok($zip->set_number('8942403')->is_valid_number, '鹿児島県大島郡瀬戸内町実久');
ok($zip->set_number('8942404')->is_valid_number, '鹿児島県大島郡瀬戸内町芝');
ok($zip->set_number('8942411')->is_valid_number, '鹿児島県大島郡瀬戸内町阿多地');
ok($zip->set_number('8942412')->is_valid_number, '鹿児島県大島郡瀬戸内町須子茂');
ok($zip->set_number('8942413')->is_valid_number, '鹿児島県大島郡瀬戸内町嘉入');
ok($zip->set_number('8942414')->is_valid_number, '鹿児島県大島郡瀬戸内町三浦');
ok($zip->set_number('8942415')->is_valid_number, '鹿児島県大島郡瀬戸内町知之浦');
ok($zip->set_number('8942416')->is_valid_number, '鹿児島県大島郡瀬戸内町武名');
ok($zip->set_number('8942417')->is_valid_number, '鹿児島県大島郡瀬戸内町木慈');
ok($zip->set_number('8942501')->is_valid_number, '鹿児島県大島郡瀬戸内町池地');
ok($zip->set_number('8942502')->is_valid_number, '鹿児島県大島郡瀬戸内町請阿室');
ok($zip->set_number('8942601')->is_valid_number, '鹿児島県大島郡瀬戸内町与路');
ok($zip->set_number('8943100')->is_valid_number, '鹿児島県大島郡大和村以下に掲載がない場合');
ok($zip->set_number('8943101')->is_valid_number, '鹿児島県大島郡大和村国直');
ok($zip->set_number('8943102')->is_valid_number, '鹿児島県大島郡大和村湯湾釜');
ok($zip->set_number('8943103')->is_valid_number, '鹿児島県大島郡大和村津名久');
ok($zip->set_number('8943104')->is_valid_number, '鹿児島県大島郡大和村思勝');
ok($zip->set_number('8943105')->is_valid_number, '鹿児島県大島郡大和村大和浜');
ok($zip->set_number('8943106')->is_valid_number, '鹿児島県大島郡大和村大棚');
ok($zip->set_number('8943107')->is_valid_number, '鹿児島県大島郡大和村大金久');
ok($zip->set_number('8943211')->is_valid_number, '鹿児島県大島郡大和村戸円');
ok($zip->set_number('8943212')->is_valid_number, '鹿児島県大島郡大和村名音');
ok($zip->set_number('8943213')->is_valid_number, '鹿児島県大島郡大和村志戸勘');
ok($zip->set_number('8943214')->is_valid_number, '鹿児島県大島郡大和村今里');
ok($zip->set_number('8943300')->is_valid_number, '鹿児島県大島郡宇検村以下に掲載がない場合');
ok($zip->set_number('8943301')->is_valid_number, '鹿児島県大島郡宇検村湯湾');
ok($zip->set_number('8943302')->is_valid_number, '鹿児島県大島郡宇検村芦検');
ok($zip->set_number('8943303')->is_valid_number, '鹿児島県大島郡宇検村田検');
ok($zip->set_number('8943304')->is_valid_number, '鹿児島県大島郡宇検村須古');
ok($zip->set_number('8943305')->is_valid_number, '鹿児島県大島郡宇検村石良');
ok($zip->set_number('8943411')->is_valid_number, '鹿児島県大島郡宇検村宇検');
ok($zip->set_number('8943412')->is_valid_number, '鹿児島県大島郡宇検村久志');
ok($zip->set_number('8943413')->is_valid_number, '鹿児島県大島郡宇検村生勝');
ok($zip->set_number('8943521')->is_valid_number, '鹿児島県大島郡宇検村名柄');
ok($zip->set_number('8943522')->is_valid_number, '鹿児島県大島郡宇検村佐念');
ok($zip->set_number('8943523')->is_valid_number, '鹿児島県大島郡宇検村部連');
ok($zip->set_number('8943631')->is_valid_number, '鹿児島県大島郡宇検村平田');
ok($zip->set_number('8943632')->is_valid_number, '鹿児島県大島郡宇検村阿室');
ok($zip->set_number('8943633')->is_valid_number, '鹿児島県大島郡宇検村屋鈍');
ok($zip->set_number('8950000')->is_valid_number, '鹿児島県薩摩川内市以下に掲載がない場合');
ok($zip->set_number('8950001')->is_valid_number, '鹿児島県薩摩川内市白浜町');
ok($zip->set_number('8950002')->is_valid_number, '鹿児島県薩摩川内市楠元町');
ok($zip->set_number('8950003')->is_valid_number, '鹿児島県薩摩川内市中村町');
ok($zip->set_number('8950004')->is_valid_number, '鹿児島県薩摩川内市久住町');
ok($zip->set_number('8950005')->is_valid_number, '鹿児島県薩摩川内市永利町');
ok($zip->set_number('8950006')->is_valid_number, '鹿児島県薩摩川内市田崎町');
ok($zip->set_number('8950007')->is_valid_number, '鹿児島県薩摩川内市百次町');
ok($zip->set_number('8950011')->is_valid_number, '鹿児島県薩摩川内市天辰町');
ok($zip->set_number('8950012')->is_valid_number, '鹿児島県薩摩川内市平佐');
ok($zip->set_number('8950012')->is_valid_number, '鹿児島県薩摩川内市平佐町');
ok($zip->set_number('8950013')->is_valid_number, '鹿児島県薩摩川内市宮崎町');
ok($zip->set_number('8950021')->is_valid_number, '鹿児島県薩摩川内市向田本町');
ok($zip->set_number('8950022')->is_valid_number, '鹿児島県薩摩川内市白和町');
ok($zip->set_number('8950023')->is_valid_number, '鹿児島県薩摩川内市横馬場町');
ok($zip->set_number('8950024')->is_valid_number, '鹿児島県薩摩川内市鳥追町');
ok($zip->set_number('8950025')->is_valid_number, '鹿児島県薩摩川内市向田町');
ok($zip->set_number('8950026')->is_valid_number, '鹿児島県薩摩川内市東向田町');
ok($zip->set_number('8950027')->is_valid_number, '鹿児島県薩摩川内市西向田町');
ok($zip->set_number('8950031')->is_valid_number, '鹿児島県薩摩川内市勝目町');
ok($zip->set_number('8950032')->is_valid_number, '鹿児島県薩摩川内市山之口町');
ok($zip->set_number('8950033')->is_valid_number, '鹿児島県薩摩川内市川永野町');
ok($zip->set_number('8950034')->is_valid_number, '鹿児島県薩摩川内市木場茶屋町');
ok($zip->set_number('8950035')->is_valid_number, '鹿児島県薩摩川内市尾白江町');
ok($zip->set_number('8950036')->is_valid_number, '鹿児島県薩摩川内市矢倉町');
ok($zip->set_number('8950041')->is_valid_number, '鹿児島県薩摩川内市隈之城町');
ok($zip->set_number('8950042')->is_valid_number, '鹿児島県薩摩川内市中福良町');
ok($zip->set_number('8950043')->is_valid_number, '鹿児島県薩摩川内市都町');
ok($zip->set_number('8950044')->is_valid_number, '鹿児島県薩摩川内市青山町');
ok($zip->set_number('8950051')->is_valid_number, '鹿児島県薩摩川内市東開聞町');
ok($zip->set_number('8950052')->is_valid_number, '鹿児島県薩摩川内市神田町');
ok($zip->set_number('8950053')->is_valid_number, '鹿児島県薩摩川内市冷水町');
ok($zip->set_number('8950054')->is_valid_number, '鹿児島県薩摩川内市若松町');
ok($zip->set_number('8950055')->is_valid_number, '鹿児島県薩摩川内市西開聞町');
ok($zip->set_number('8950056')->is_valid_number, '鹿児島県薩摩川内市宮里町');
ok($zip->set_number('8950061')->is_valid_number, '鹿児島県薩摩川内市御陵下町');
ok($zip->set_number('8950062')->is_valid_number, '鹿児島県薩摩川内市大王町');
ok($zip->set_number('8950063')->is_valid_number, '鹿児島県薩摩川内市若葉町');
ok($zip->set_number('8950064')->is_valid_number, '鹿児島県薩摩川内市花木町');
ok($zip->set_number('8950065')->is_valid_number, '鹿児島県薩摩川内市宮内町');
ok($zip->set_number('8950066')->is_valid_number, '鹿児島県薩摩川内市五代町');
ok($zip->set_number('8950067')->is_valid_number, '鹿児島県薩摩川内市上川内町');
ok($zip->set_number('8950071')->is_valid_number, '鹿児島県薩摩川内市田海町');
ok($zip->set_number('8950072')->is_valid_number, '鹿児島県薩摩川内市中郷');
ok($zip->set_number('8950072')->is_valid_number, '鹿児島県薩摩川内市中郷町');
ok($zip->set_number('8950073')->is_valid_number, '鹿児島県薩摩川内市国分寺町');
ok($zip->set_number('8950074')->is_valid_number, '鹿児島県薩摩川内市原田町');
ok($zip->set_number('8950075')->is_valid_number, '鹿児島県薩摩川内市東大小路町');
ok($zip->set_number('8950076')->is_valid_number, '鹿児島県薩摩川内市大小路町');
ok($zip->set_number('8950077')->is_valid_number, '鹿児島県薩摩川内市運動公園町(その他)');
ok($zip->set_number('8950131')->is_valid_number, '鹿児島県薩摩川内市高江町');
ok($zip->set_number('8950132')->is_valid_number, '鹿児島県薩摩川内市久見崎町');
ok($zip->set_number('8950133')->is_valid_number, '鹿児島県薩摩川内市寄田町');
ok($zip->set_number('8950211')->is_valid_number, '鹿児島県薩摩川内市高城町');
ok($zip->set_number('8950212')->is_valid_number, '鹿児島県薩摩川内市陽成町');
ok($zip->set_number('8950213')->is_valid_number, '鹿児島県薩摩川内市城上町');
ok($zip->set_number('8950214')->is_valid_number, '鹿児島県薩摩川内市運動公園町(3030番地)');
ok($zip->set_number('8951101')->is_valid_number, '鹿児島県薩摩川内市東郷町宍野');
ok($zip->set_number('8951102')->is_valid_number, '鹿児島県薩摩川内市東郷町藤川');
ok($zip->set_number('8951103')->is_valid_number, '鹿児島県薩摩川内市東郷町鳥丸');
ok($zip->set_number('8951104')->is_valid_number, '鹿児島県薩摩川内市東郷町山田');
ok($zip->set_number('8951105')->is_valid_number, '鹿児島県薩摩川内市東郷町南瀬');
ok($zip->set_number('8951106')->is_valid_number, '鹿児島県薩摩川内市東郷町斧渕');
ok($zip->set_number('8951201')->is_valid_number, '鹿児島県薩摩川内市樋脇町倉野');
ok($zip->set_number('8951202')->is_valid_number, '鹿児島県薩摩川内市樋脇町塔之原');
ok($zip->set_number('8951203')->is_valid_number, '鹿児島県薩摩川内市樋脇町市比野');
ok($zip->set_number('8951401')->is_valid_number, '鹿児島県薩摩川内市入来町副田');
ok($zip->set_number('8951402')->is_valid_number, '鹿児島県薩摩川内市入来町浦之名');
ok($zip->set_number('8951501')->is_valid_number, '鹿児島県薩摩川内市祁答院町下手');
ok($zip->set_number('8951502')->is_valid_number, '鹿児島県薩摩川内市祁答院町藺牟田');
ok($zip->set_number('8951503')->is_valid_number, '鹿児島県薩摩川内市祁答院町上手');
ok($zip->set_number('8951504')->is_valid_number, '鹿児島県薩摩川内市祁答院町黒木');
ok($zip->set_number('8951721')->is_valid_number, '鹿児島県薩摩郡さつま町山崎');
ok($zip->set_number('8951722')->is_valid_number, '鹿児島県薩摩郡さつま町久富木');
ok($zip->set_number('8951723')->is_valid_number, '鹿児島県薩摩郡さつま町二渡');
ok($zip->set_number('8951800')->is_valid_number, '鹿児島県薩摩郡さつま町以下に掲載がない場合');
ok($zip->set_number('8951801')->is_valid_number, '鹿児島県薩摩郡さつま町広瀬');
ok($zip->set_number('8951802')->is_valid_number, '鹿児島県薩摩郡さつま町田原');
ok($zip->set_number('8951803')->is_valid_number, '鹿児島県薩摩郡さつま町宮之城屋地');
ok($zip->set_number('8951804')->is_valid_number, '鹿児島県薩摩郡さつま町船木');
ok($zip->set_number('8951805')->is_valid_number, '鹿児島県薩摩郡さつま町白男川');
ok($zip->set_number('8951806')->is_valid_number, '鹿児島県薩摩郡さつま町泊野');
ok($zip->set_number('8951807')->is_valid_number, '鹿児島県薩摩郡さつま町平川');
ok($zip->set_number('8951811')->is_valid_number, '鹿児島県薩摩郡さつま町虎居');
ok($zip->set_number('8951812')->is_valid_number, '鹿児島県薩摩郡さつま町虎居町');
ok($zip->set_number('8951813')->is_valid_number, '鹿児島県薩摩郡さつま町轟町');
ok($zip->set_number('8951814')->is_valid_number, '鹿児島県薩摩郡さつま町旭町');
ok($zip->set_number('8951815')->is_valid_number, '鹿児島県薩摩郡さつま町西新町');
ok($zip->set_number('8951816')->is_valid_number, '鹿児島県薩摩郡さつま町時吉');
ok($zip->set_number('8951817')->is_valid_number, '鹿児島県薩摩郡さつま町湯田');
ok($zip->set_number('8952101')->is_valid_number, '鹿児島県薩摩郡さつま町鶴田');
ok($zip->set_number('8952102')->is_valid_number, '鹿児島県薩摩郡さつま町神子');
ok($zip->set_number('8952103')->is_valid_number, '鹿児島県薩摩郡さつま町紫尾');
ok($zip->set_number('8952104')->is_valid_number, '鹿児島県薩摩郡さつま町柏原');
ok($zip->set_number('8952131')->is_valid_number, '鹿児島県薩摩郡さつま町柊野');
ok($zip->set_number('8952201')->is_valid_number, '鹿児島県薩摩郡さつま町求名');
ok($zip->set_number('8952202')->is_valid_number, '鹿児島県薩摩郡さつま町中津川');
ok($zip->set_number('8952203')->is_valid_number, '鹿児島県薩摩郡さつま町永野');
ok($zip->set_number('8952441')->is_valid_number, '鹿児島県伊佐市大口曽木');
ok($zip->set_number('8952442')->is_valid_number, '鹿児島県伊佐市大口針持');
ok($zip->set_number('8952500')->is_valid_number, '鹿児島県伊佐市以下に掲載がない場合');
ok($zip->set_number('8952501')->is_valid_number, '鹿児島県伊佐市大口牛尾');
ok($zip->set_number('8952502')->is_valid_number, '鹿児島県伊佐市大口木ノ氏');
ok($zip->set_number('8952503')->is_valid_number, '鹿児島県伊佐市大口篠原');
ok($zip->set_number('8952504')->is_valid_number, '鹿児島県伊佐市大口青木');
ok($zip->set_number('8952505')->is_valid_number, '鹿児島県伊佐市大口目丸');
ok($zip->set_number('8952506')->is_valid_number, '鹿児島県伊佐市大口原田');
ok($zip->set_number('8952507')->is_valid_number, '鹿児島県伊佐市大口大田');
ok($zip->set_number('8952511')->is_valid_number, '鹿児島県伊佐市大口里');
ok($zip->set_number('8952512')->is_valid_number, '鹿児島県伊佐市大口元町');
ok($zip->set_number('8952513')->is_valid_number, '鹿児島県伊佐市大口上町');
ok($zip->set_number('8952521')->is_valid_number, '鹿児島県伊佐市大口鳥巣');
ok($zip->set_number('8952522')->is_valid_number, '鹿児島県伊佐市大口大島');
ok($zip->set_number('8952523')->is_valid_number, '鹿児島県伊佐市大口金波田');
ok($zip->set_number('8952524')->is_valid_number, '鹿児島県伊佐市大口堂崎');
ok($zip->set_number('8952525')->is_valid_number, '鹿児島県伊佐市大口下殿');
ok($zip->set_number('8952526')->is_valid_number, '鹿児島県伊佐市大口宮人');
ok($zip->set_number('8952527')->is_valid_number, '鹿児島県伊佐市大口田代');
ok($zip->set_number('8952528')->is_valid_number, '鹿児島県伊佐市大口川岩瀬');
ok($zip->set_number('8952529')->is_valid_number, '鹿児島県伊佐市大口白木');
ok($zip->set_number('8952631')->is_valid_number, '鹿児島県伊佐市大口小木原');
ok($zip->set_number('8952632')->is_valid_number, '鹿児島県伊佐市大口渕辺');
ok($zip->set_number('8952633')->is_valid_number, '鹿児島県伊佐市大口平出水');
ok($zip->set_number('8952634')->is_valid_number, '鹿児島県伊佐市大口小川内');
ok($zip->set_number('8952635')->is_valid_number, '鹿児島県伊佐市大口山野');
ok($zip->set_number('8952701')->is_valid_number, '鹿児島県伊佐市菱刈前目');
ok($zip->set_number('8952702')->is_valid_number, '鹿児島県伊佐市菱刈下手');
ok($zip->set_number('8952703')->is_valid_number, '鹿児島県伊佐市菱刈花北');
ok($zip->set_number('8952704')->is_valid_number, '鹿児島県伊佐市菱刈市山');
ok($zip->set_number('8952705')->is_valid_number, '鹿児島県伊佐市菱刈重留');
ok($zip->set_number('8952706')->is_valid_number, '鹿児島県伊佐市菱刈田中');
ok($zip->set_number('8952707')->is_valid_number, '鹿児島県伊佐市菱刈徳辺');
ok($zip->set_number('8952708')->is_valid_number, '鹿児島県伊佐市菱刈川北');
ok($zip->set_number('8952811')->is_valid_number, '鹿児島県伊佐市菱刈荒田');
ok($zip->set_number('8952812')->is_valid_number, '鹿児島県伊佐市菱刈川南');
ok($zip->set_number('8952813')->is_valid_number, '鹿児島県伊佐市菱刈南浦');
ok($zip->set_number('8960000')->is_valid_number, '鹿児島県いちき串木野市以下に掲載がない場合');
ok($zip->set_number('8960001')->is_valid_number, '鹿児島県いちき串木野市曙町');
ok($zip->set_number('8960002')->is_valid_number, '鹿児島県いちき串木野市春日町');
ok($zip->set_number('8960003')->is_valid_number, '鹿児島県いちき串木野市京町');
ok($zip->set_number('8960004')->is_valid_number, '鹿児島県いちき串木野市汐見町');
ok($zip->set_number('8960005')->is_valid_number, '鹿児島県いちき串木野市西塩田町');
ok($zip->set_number('8960006')->is_valid_number, '鹿児島県いちき串木野市東塩田町');
ok($zip->set_number('8960011')->is_valid_number, '鹿児島県いちき串木野市大原町');
ok($zip->set_number('8960012')->is_valid_number, '鹿児島県いちき串木野市中尾町');
ok($zip->set_number('8960013')->is_valid_number, '鹿児島県いちき串木野市栄町');
ok($zip->set_number('8960014')->is_valid_number, '鹿児島県いちき串木野市元町');
ok($zip->set_number('8960015')->is_valid_number, '鹿児島県いちき串木野市旭町');
ok($zip->set_number('8960016')->is_valid_number, '鹿児島県いちき串木野市桜町');
ok($zip->set_number('8960017')->is_valid_number, '鹿児島県いちき串木野市高見町');
ok($zip->set_number('8960021')->is_valid_number, '鹿児島県いちき串木野市住吉町');
ok($zip->set_number('8960022')->is_valid_number, '鹿児島県いちき串木野市緑町');
ok($zip->set_number('8960023')->is_valid_number, '鹿児島県いちき串木野市塩屋町');
ok($zip->set_number('8960024')->is_valid_number, '鹿児島県いちき串木野市美住町');
ok($zip->set_number('8960025')->is_valid_number, '鹿児島県いちき串木野市御倉町');
ok($zip->set_number('8960026')->is_valid_number, '鹿児島県いちき串木野市昭和通');
ok($zip->set_number('8960027')->is_valid_number, '鹿児島県いちき串木野市恵比須町');
ok($zip->set_number('8960028')->is_valid_number, '鹿児島県いちき串木野市ひばりが丘');
ok($zip->set_number('8960031')->is_valid_number, '鹿児島県いちき串木野市東島平町');
ok($zip->set_number('8960032')->is_valid_number, '鹿児島県いちき串木野市西島平町');
ok($zip->set_number('8960033')->is_valid_number, '鹿児島県いちき串木野市長崎町');
ok($zip->set_number('8960034')->is_valid_number, '鹿児島県いちき串木野市小瀬町');
ok($zip->set_number('8960035')->is_valid_number, '鹿児島県いちき串木野市新生町');
ok($zip->set_number('8960036')->is_valid_number, '鹿児島県いちき串木野市浦和町');
ok($zip->set_number('8960037')->is_valid_number, '鹿児島県いちき串木野市別府');
ok($zip->set_number('8960041')->is_valid_number, '鹿児島県いちき串木野市北浜町');
ok($zip->set_number('8960042')->is_valid_number, '鹿児島県いちき串木野市本浜町');
ok($zip->set_number('8960043')->is_valid_number, '鹿児島県いちき串木野市港町');
ok($zip->set_number('8960044')->is_valid_number, '鹿児島県いちき串木野市西浜町');
ok($zip->set_number('8960045')->is_valid_number, '鹿児島県いちき串木野市まぐろ本町');
ok($zip->set_number('8960046')->is_valid_number, '鹿児島県いちき串木野市西薩町');
ok($zip->set_number('8960051')->is_valid_number, '鹿児島県いちき串木野市冠嶽');
ok($zip->set_number('8960052')->is_valid_number, '鹿児島県いちき串木野市上名');
ok($zip->set_number('8960054')->is_valid_number, '鹿児島県いちき串木野市日出町');
ok($zip->set_number('8960055')->is_valid_number, '鹿児島県いちき串木野市照島');
ok($zip->set_number('8960056')->is_valid_number, '鹿児島県いちき串木野市八房');
ok($zip->set_number('8960057')->is_valid_number, '鹿児島県いちき串木野市海瀬');
ok($zip->set_number('8960058')->is_valid_number, '鹿児島県いちき串木野市袴田');
ok($zip->set_number('8960061')->is_valid_number, '鹿児島県いちき串木野市愛木町');
ok($zip->set_number('8960062')->is_valid_number, '鹿児島県いちき串木野市浜田町');
ok($zip->set_number('8960063')->is_valid_number, '鹿児島県いちき串木野市口之町');
ok($zip->set_number('8960064')->is_valid_number, '鹿児島県いちき串木野市羽島');
ok($zip->set_number('8960065')->is_valid_number, '鹿児島県いちき串木野市荒川');
ok($zip->set_number('8960066')->is_valid_number, '鹿児島県いちき串木野市野元');
ok($zip->set_number('8960067')->is_valid_number, '鹿児島県いちき串木野市平江');
ok($zip->set_number('8960068')->is_valid_number, '鹿児島県いちき串木野市三井');
ok($zip->set_number('8960069')->is_valid_number, '鹿児島県いちき串木野市浜ケ城');
ok($zip->set_number('8960071')->is_valid_number, '鹿児島県いちき串木野市深田上');
ok($zip->set_number('8960072')->is_valid_number, '鹿児島県いちき串木野市薩摩山');
ok($zip->set_number('8960073')->is_valid_number, '鹿児島県いちき串木野市野下');
ok($zip->set_number('8960074')->is_valid_number, '鹿児島県いちき串木野市金山下');
ok($zip->set_number('8960075')->is_valid_number, '鹿児島県いちき串木野市金山');
ok($zip->set_number('8960076')->is_valid_number, '鹿児島県いちき串木野市芹ケ野');
ok($zip->set_number('8960077')->is_valid_number, '鹿児島県いちき串木野市深田下');
ok($zip->set_number('8960078')->is_valid_number, '鹿児島県いちき串木野市生福');
ok($zip->set_number('8960079')->is_valid_number, '鹿児島県いちき串木野市河内');
ok($zip->set_number('8960081')->is_valid_number, '鹿児島県いちき串木野市大薗');
ok($zip->set_number('8960082')->is_valid_number, '鹿児島県いちき串木野市小薗');
ok($zip->set_number('8960083')->is_valid_number, '鹿児島県いちき串木野市麓');
ok($zip->set_number('8960084')->is_valid_number, '鹿児島県いちき串木野市浅山');
ok($zip->set_number('8961101')->is_valid_number, '鹿児島県薩摩川内市里町里');
ok($zip->set_number('8961201')->is_valid_number, '鹿児島県薩摩川内市上甑町中甑');
ok($zip->set_number('8961202')->is_valid_number, '鹿児島県薩摩川内市上甑町中野');
ok($zip->set_number('8961203')->is_valid_number, '鹿児島県薩摩川内市上甑町江石');
ok($zip->set_number('8961204')->is_valid_number, '鹿児島県薩摩川内市上甑町小島');
ok($zip->set_number('8961205')->is_valid_number, '鹿児島県薩摩川内市上甑町瀬上');
ok($zip->set_number('8961206')->is_valid_number, '鹿児島県薩摩川内市上甑町桑之浦');
ok($zip->set_number('8961281')->is_valid_number, '鹿児島県薩摩川内市上甑町平良');
ok($zip->set_number('8961301')->is_valid_number, '鹿児島県薩摩川内市鹿島町藺牟田');
ok($zip->set_number('8961411')->is_valid_number, '鹿児島県薩摩川内市下甑町長浜');
ok($zip->set_number('8961412')->is_valid_number, '鹿児島県薩摩川内市下甑町瀬々野浦(1700番地~、内川内)');
ok($zip->set_number('8961512')->is_valid_number, '鹿児島県薩摩川内市下甑町瀬々野浦(その他)');
ok($zip->set_number('8961521')->is_valid_number, '鹿児島県薩摩川内市下甑町青瀬');
ok($zip->set_number('8961601')->is_valid_number, '鹿児島県薩摩川内市下甑町手打');
ok($zip->set_number('8961602')->is_valid_number, '鹿児島県薩摩川内市下甑町片野浦');
ok($zip->set_number('8970000')->is_valid_number, '鹿児島県南さつま市以下に掲載がない場合');
ok($zip->set_number('8970001')->is_valid_number, '鹿児島県南さつま市加世田村原');
ok($zip->set_number('8970002')->is_valid_number, '鹿児島県南さつま市加世田武田');
ok($zip->set_number('8970003')->is_valid_number, '鹿児島県南さつま市加世田川畑');
ok($zip->set_number('8970004')->is_valid_number, '鹿児島県南さつま市加世田内山田');
ok($zip->set_number('8970005')->is_valid_number, '鹿児島県南さつま市加世田麓町');
ok($zip->set_number('8970006')->is_valid_number, '鹿児島県南さつま市加世田本町');
ok($zip->set_number('8970007')->is_valid_number, '鹿児島県南さつま市加世田白亀');
ok($zip->set_number('8970008')->is_valid_number, '鹿児島県南さつま市加世田地頭所');
ok($zip->set_number('8970009')->is_valid_number, '鹿児島県南さつま市加世田ハーモニー');
ok($zip->set_number('8970031')->is_valid_number, '鹿児島県南さつま市加世田東本町');
ok($zip->set_number('8970131')->is_valid_number, '鹿児島県南九州市川辺町上山田');
ok($zip->set_number('8970132')->is_valid_number, '鹿児島県南九州市川辺町中山田');
ok($zip->set_number('8970133')->is_valid_number, '鹿児島県南九州市川辺町下山田');
ok($zip->set_number('8970200')->is_valid_number, '鹿児島県南九州市以下に掲載がない場合');
ok($zip->set_number('8970201')->is_valid_number, '鹿児島県南九州市川辺町神殿');
ok($zip->set_number('8970202')->is_valid_number, '鹿児島県南九州市川辺町清水');
ok($zip->set_number('8970203')->is_valid_number, '鹿児島県南九州市川辺町野崎');
ok($zip->set_number('8970204')->is_valid_number, '鹿児島県南九州市川辺町古殿');
ok($zip->set_number('8970205')->is_valid_number, '鹿児島県南九州市川辺町野間');
ok($zip->set_number('8970211')->is_valid_number, '鹿児島県南九州市川辺町両添');
ok($zip->set_number('8970212')->is_valid_number, '鹿児島県南九州市川辺町今田');
ok($zip->set_number('8970213')->is_valid_number, '鹿児島県南九州市川辺町小野');
ok($zip->set_number('8970214')->is_valid_number, '鹿児島県南九州市川辺町宮');
ok($zip->set_number('8970215')->is_valid_number, '鹿児島県南九州市川辺町平山');
ok($zip->set_number('8970221')->is_valid_number, '鹿児島県南九州市川辺町田部田');
ok($zip->set_number('8970222')->is_valid_number, '鹿児島県南九州市川辺町永田');
ok($zip->set_number('8970223')->is_valid_number, '鹿児島県南九州市川辺町高田');
ok($zip->set_number('8970224')->is_valid_number, '鹿児島県南九州市川辺町本別府');
ok($zip->set_number('8970301')->is_valid_number, '鹿児島県南九州市知覧町厚地');
ok($zip->set_number('8970302')->is_valid_number, '鹿児島県南九州市知覧町郡');
ok($zip->set_number('8970303')->is_valid_number, '鹿児島県南九州市知覧町永里');
ok($zip->set_number('8970304')->is_valid_number, '鹿児島県南九州市知覧町東別府');
ok($zip->set_number('8970305')->is_valid_number, '鹿児島県南九州市知覧町瀬世');
ok($zip->set_number('8970306')->is_valid_number, '鹿児島県南九州市知覧町西元');
ok($zip->set_number('8971121')->is_valid_number, '鹿児島県南さつま市加世田唐仁原');
ok($zip->set_number('8971122')->is_valid_number, '鹿児島県南さつま市加世田小湊');
ok($zip->set_number('8971123')->is_valid_number, '鹿児島県南さつま市加世田高橋');
ok($zip->set_number('8971124')->is_valid_number, '鹿児島県南さつま市加世田宮原');
ok($zip->set_number('8971125')->is_valid_number, '鹿児島県南さつま市加世田益山');
ok($zip->set_number('8971201')->is_valid_number, '鹿児島県南さつま市大浦町(その他)');
ok($zip->set_number('8971301')->is_valid_number, '鹿児島県南さつま市笠沙町片浦');
ok($zip->set_number('8971302')->is_valid_number, '鹿児島県南さつま市笠沙町赤生木');
ok($zip->set_number('8980000')->is_valid_number, '鹿児島県枕崎市以下に掲載がない場合');
ok($zip->set_number('8980001')->is_valid_number, '鹿児島県枕崎市松之尾町');
ok($zip->set_number('8980002')->is_valid_number, '鹿児島県枕崎市汐見町');
ok($zip->set_number('8980003')->is_valid_number, '鹿児島県枕崎市折口町');
ok($zip->set_number('8980004')->is_valid_number, '鹿児島県枕崎市港町');
ok($zip->set_number('8980005')->is_valid_number, '鹿児島県枕崎市中町');
ok($zip->set_number('8980006')->is_valid_number, '鹿児島県枕崎市泉町');
ok($zip->set_number('8980007')->is_valid_number, '鹿児島県枕崎市新町');
ok($zip->set_number('8980008')->is_valid_number, '鹿児島県枕崎市旭町');
ok($zip->set_number('8980009')->is_valid_number, '鹿児島県枕崎市恵比須町');
ok($zip->set_number('8980011')->is_valid_number, '鹿児島県枕崎市緑町');
ok($zip->set_number('8980012')->is_valid_number, '鹿児島県枕崎市千代田町');
ok($zip->set_number('8980013')->is_valid_number, '鹿児島県枕崎市山手町');
ok($zip->set_number('8980014')->is_valid_number, '鹿児島県枕崎市東本町');
ok($zip->set_number('8980015')->is_valid_number, '鹿児島県枕崎市西本町');
ok($zip->set_number('8980016')->is_valid_number, '鹿児島県枕崎市高見町');
ok($zip->set_number('8980017')->is_valid_number, '鹿児島県枕崎市住吉町');
ok($zip->set_number('8980018')->is_valid_number, '鹿児島県枕崎市桜木町');
ok($zip->set_number('8980021')->is_valid_number, '鹿児島県枕崎市東鹿篭');
ok($zip->set_number('8980022')->is_valid_number, '鹿児島県枕崎市宮田町');
ok($zip->set_number('8980023')->is_valid_number, '鹿児島県枕崎市若葉町');
ok($zip->set_number('8980024')->is_valid_number, '鹿児島県枕崎市西鹿篭');
ok($zip->set_number('8980025')->is_valid_number, '鹿児島県枕崎市立神本町');
ok($zip->set_number('8980026')->is_valid_number, '鹿児島県枕崎市大塚北町');
ok($zip->set_number('8980027')->is_valid_number, '鹿児島県枕崎市大塚西町');
ok($zip->set_number('8980028')->is_valid_number, '鹿児島県枕崎市大塚中町');
ok($zip->set_number('8980029')->is_valid_number, '鹿児島県枕崎市大塚南町');
ok($zip->set_number('8980031')->is_valid_number, '鹿児島県枕崎市枕崎');
ok($zip->set_number('8980032')->is_valid_number, '鹿児島県枕崎市別府');
ok($zip->set_number('8980033')->is_valid_number, '鹿児島県枕崎市宮前町');
ok($zip->set_number('8980034')->is_valid_number, '鹿児島県枕崎市日之出町');
ok($zip->set_number('8980035')->is_valid_number, '鹿児島県枕崎市平田町');
ok($zip->set_number('8980036')->is_valid_number, '鹿児島県枕崎市明和町');
ok($zip->set_number('8980037')->is_valid_number, '鹿児島県枕崎市栄本町');
ok($zip->set_number('8980038')->is_valid_number, '鹿児島県枕崎市栄中町');
ok($zip->set_number('8980041')->is_valid_number, '鹿児島県枕崎市塩屋北町');
ok($zip->set_number('8980042')->is_valid_number, '鹿児島県枕崎市塩屋南町');
ok($zip->set_number('8980043')->is_valid_number, '鹿児島県枕崎市火之神北町');
ok($zip->set_number('8980044')->is_valid_number, '鹿児島県枕崎市春日町');
ok($zip->set_number('8980045')->is_valid_number, '鹿児島県枕崎市立神北町');
ok($zip->set_number('8980046')->is_valid_number, '鹿児島県枕崎市園見本町');
ok($zip->set_number('8980047')->is_valid_number, '鹿児島県枕崎市園見西町');
ok($zip->set_number('8980048')->is_valid_number, '鹿児島県枕崎市火之神町');
ok($zip->set_number('8980049')->is_valid_number, '鹿児島県枕崎市火之神岬町');
ok($zip->set_number('8980051')->is_valid_number, '鹿児島県枕崎市中央町');
ok($zip->set_number('8980052')->is_valid_number, '鹿児島県枕崎市岩崎町');
ok($zip->set_number('8980053')->is_valid_number, '鹿児島県枕崎市木場町');
ok($zip->set_number('8980054')->is_valid_number, '鹿児島県枕崎市鹿篭麓町');
ok($zip->set_number('8980055')->is_valid_number, '鹿児島県枕崎市桜山西町');
ok($zip->set_number('8980056')->is_valid_number, '鹿児島県枕崎市美原町');
ok($zip->set_number('8980057')->is_valid_number, '鹿児島県枕崎市木原町');
ok($zip->set_number('8980058')->is_valid_number, '鹿児島県枕崎市岩戸町');
ok($zip->set_number('8980061')->is_valid_number, '鹿児島県枕崎市桜山町');
ok($zip->set_number('8980062')->is_valid_number, '鹿児島県枕崎市寿町');
ok($zip->set_number('8980063')->is_valid_number, '鹿児島県枕崎市妙見町');
ok($zip->set_number('8980064')->is_valid_number, '鹿児島県枕崎市桜山本町');
ok($zip->set_number('8980065')->is_valid_number, '鹿児島県枕崎市桜山東町');
ok($zip->set_number('8980066')->is_valid_number, '鹿児島県枕崎市清水町');
ok($zip->set_number('8980071')->is_valid_number, '鹿児島県枕崎市美山町');
ok($zip->set_number('8980072')->is_valid_number, '鹿児島県枕崎市道野町');
ok($zip->set_number('8980073')->is_valid_number, '鹿児島県枕崎市桜山上町');
ok($zip->set_number('8980074')->is_valid_number, '鹿児島県枕崎市金山西町');
ok($zip->set_number('8980075')->is_valid_number, '鹿児島県枕崎市田布川町');
ok($zip->set_number('8980076')->is_valid_number, '鹿児島県枕崎市金山町');
ok($zip->set_number('8980080')->is_valid_number, '鹿児島県枕崎市あけぼの町');
ok($zip->set_number('8980081')->is_valid_number, '鹿児島県枕崎市豊留町');
ok($zip->set_number('8980082')->is_valid_number, '鹿児島県枕崎市板敷本町');
ok($zip->set_number('8980083')->is_valid_number, '鹿児島県枕崎市板敷南町');
ok($zip->set_number('8980084')->is_valid_number, '鹿児島県枕崎市板敷西町');
ok($zip->set_number('8980085')->is_valid_number, '鹿児島県枕崎市別府東町');
ok($zip->set_number('8980086')->is_valid_number, '鹿児島県枕崎市別府西町');
ok($zip->set_number('8980087')->is_valid_number, '鹿児島県枕崎市瀬戸町');
ok($zip->set_number('8980088')->is_valid_number, '鹿児島県枕崎市国見町');
ok($zip->set_number('8980089')->is_valid_number, '鹿児島県枕崎市白沢北町');
ok($zip->set_number('8980091')->is_valid_number, '鹿児島県枕崎市白沢東町');
ok($zip->set_number('8980092')->is_valid_number, '鹿児島県枕崎市白沢西町');
ok($zip->set_number('8980093')->is_valid_number, '鹿児島県枕崎市仁田浦町');
ok($zip->set_number('8980094')->is_valid_number, '鹿児島県枕崎市駒水町');
ok($zip->set_number('8980095')->is_valid_number, '鹿児島県枕崎市下松町');
ok($zip->set_number('8980096')->is_valid_number, '鹿児島県枕崎市まかや町');
ok($zip->set_number('8980097')->is_valid_number, '鹿児島県枕崎市里町');
ok($zip->set_number('8980098')->is_valid_number, '鹿児島県枕崎市茅野町');
ok($zip->set_number('8980099')->is_valid_number, '鹿児島県枕崎市小塚町');
ok($zip->set_number('8980101')->is_valid_number, '鹿児島県南さつま市坊津町坊');
ok($zip->set_number('8980102')->is_valid_number, '鹿児島県南さつま市坊津町泊');
ok($zip->set_number('8980211')->is_valid_number, '鹿児島県南さつま市坊津町久志');
ok($zip->set_number('8980212')->is_valid_number, '鹿児島県南さつま市坊津町秋目');
ok($zip->set_number('8980221')->is_valid_number, '鹿児島県南さつま市大浦町(4713~5277番地)');
ok($zip->set_number('8990121')->is_valid_number, '鹿児島県出水市米ノ津町');
ok($zip->set_number('8990122')->is_valid_number, '鹿児島県出水市境町');
ok($zip->set_number('8990123')->is_valid_number, '鹿児島県出水市下鯖町');
ok($zip->set_number('8990124')->is_valid_number, '鹿児島県出水市美原町');
ok($zip->set_number('8990125')->is_valid_number, '鹿児島県出水市黄金町');
ok($zip->set_number('8990126')->is_valid_number, '鹿児島県出水市六月田町');
ok($zip->set_number('8990131')->is_valid_number, '鹿児島県出水市明神町');
ok($zip->set_number('8990132')->is_valid_number, '鹿児島県出水市下知識町');
ok($zip->set_number('8990133')->is_valid_number, '鹿児島県出水市福ノ江町');
ok($zip->set_number('8990134')->is_valid_number, '鹿児島県出水市浦田町');
ok($zip->set_number('8990136')->is_valid_number, '鹿児島県出水市汐見町');
ok($zip->set_number('8990137')->is_valid_number, '鹿児島県出水市今釜町');
ok($zip->set_number('8990138')->is_valid_number, '鹿児島県出水市住吉町');
ok($zip->set_number('8990200')->is_valid_number, '鹿児島県出水市以下に掲載がない場合');
ok($zip->set_number('8990201')->is_valid_number, '鹿児島県出水市緑町');
ok($zip->set_number('8990202')->is_valid_number, '鹿児島県出水市昭和町');
ok($zip->set_number('8990203')->is_valid_number, '鹿児島県出水市上鯖渕');
ok($zip->set_number('8990204')->is_valid_number, '鹿児島県出水市麓町');
ok($zip->set_number('8990205')->is_valid_number, '鹿児島県出水市本町');
ok($zip->set_number('8990206')->is_valid_number, '鹿児島県出水市向江町');
ok($zip->set_number('8990207')->is_valid_number, '鹿児島県出水市中央町');
ok($zip->set_number('8990208')->is_valid_number, '鹿児島県出水市文化町');
ok($zip->set_number('8990211')->is_valid_number, '鹿児島県出水市知識町');
ok($zip->set_number('8990212')->is_valid_number, '鹿児島県出水市上知識町');
ok($zip->set_number('8990213')->is_valid_number, '鹿児島県出水市西出水町');
ok($zip->set_number('8990214')->is_valid_number, '鹿児島県出水市五万石町');
ok($zip->set_number('8990215')->is_valid_number, '鹿児島県出水市武本');
ok($zip->set_number('8990216')->is_valid_number, '鹿児島県出水市大野原町');
ok($zip->set_number('8990217')->is_valid_number, '鹿児島県出水市平和町');
ok($zip->set_number('8990341')->is_valid_number, '鹿児島県出水市上大川内');
ok($zip->set_number('8990342')->is_valid_number, '鹿児島県出水市下大川内');
ok($zip->set_number('8990401')->is_valid_number, '鹿児島県出水市高尾野町大久保');
ok($zip->set_number('8990402')->is_valid_number, '鹿児島県出水市高尾野町柴引');
ok($zip->set_number('8990403')->is_valid_number, '鹿児島県出水市高尾野町唐笠木');
ok($zip->set_number('8990404')->is_valid_number, '鹿児島県出水市高尾野町下高尾野');
ok($zip->set_number('8990405')->is_valid_number, '鹿児島県出水市高尾野町下水流');
ok($zip->set_number('8990406')->is_valid_number, '鹿児島県出水市高尾野町上水流');
ok($zip->set_number('8990407')->is_valid_number, '鹿児島県出水市高尾野町江内');
ok($zip->set_number('8990435')->is_valid_number, '鹿児島県出水市荘');
ok($zip->set_number('8990501')->is_valid_number, '鹿児島県出水市野田町上名');
ok($zip->set_number('8990502')->is_valid_number, '鹿児島県出水市野田町下名');
ok($zip->set_number('8991131')->is_valid_number, '鹿児島県阿久根市脇本');
ok($zip->set_number('8991211')->is_valid_number, '鹿児島県出水郡長島町山門野');
ok($zip->set_number('8991212')->is_valid_number, '鹿児島県出水郡長島町川床');
ok($zip->set_number('8991301')->is_valid_number, '鹿児島県出水郡長島町蔵之元');
ok($zip->set_number('8991302')->is_valid_number, '鹿児島県出水郡長島町平尾');
ok($zip->set_number('8991303')->is_valid_number, '鹿児島県出水郡長島町指江');
ok($zip->set_number('8991304')->is_valid_number, '鹿児島県出水郡長島町城川内');
ok($zip->set_number('8991321')->is_valid_number, '鹿児島県出水郡長島町下山門野');
ok($zip->set_number('8991400')->is_valid_number, '鹿児島県出水郡長島町以下に掲載がない場合');
ok($zip->set_number('8991401')->is_valid_number, '鹿児島県出水郡長島町鷹巣');
ok($zip->set_number('8991402')->is_valid_number, '鹿児島県出水郡長島町浦底');
ok($zip->set_number('8991403')->is_valid_number, '鹿児島県出水郡長島町諸浦');
ok($zip->set_number('8991501')->is_valid_number, '鹿児島県出水郡長島町獅子島');
ok($zip->set_number('8991600')->is_valid_number, '鹿児島県阿久根市以下に掲載がない場合');
ok($zip->set_number('8991601')->is_valid_number, '鹿児島県阿久根市折口');
ok($zip->set_number('8991602')->is_valid_number, '鹿児島県阿久根市多田');
ok($zip->set_number('8991603')->is_valid_number, '鹿児島県阿久根市鶴川内');
ok($zip->set_number('8991604')->is_valid_number, '鹿児島県阿久根市山下');
ok($zip->set_number('8991611')->is_valid_number, '鹿児島県阿久根市赤瀬川');
ok($zip->set_number('8991612')->is_valid_number, '鹿児島県阿久根市丸尾町');
ok($zip->set_number('8991613')->is_valid_number, '鹿児島県阿久根市新町');
ok($zip->set_number('8991614')->is_valid_number, '鹿児島県阿久根市晴海町');
ok($zip->set_number('8991615')->is_valid_number, '鹿児島県阿久根市琴平町');
ok($zip->set_number('8991616')->is_valid_number, '鹿児島県阿久根市栄町');
ok($zip->set_number('8991617')->is_valid_number, '鹿児島県阿久根市浜町');
ok($zip->set_number('8991621')->is_valid_number, '鹿児島県阿久根市本町');
ok($zip->set_number('8991622')->is_valid_number, '鹿児島県阿久根市高松町');
ok($zip->set_number('8991623')->is_valid_number, '鹿児島県阿久根市港町');
ok($zip->set_number('8991624')->is_valid_number, '鹿児島県阿久根市大丸町');
ok($zip->set_number('8991625')->is_valid_number, '鹿児島県阿久根市波留');
ok($zip->set_number('8991626')->is_valid_number, '鹿児島県阿久根市鶴見町');
ok($zip->set_number('8991627')->is_valid_number, '鹿児島県阿久根市西目');
ok($zip->set_number('8991628')->is_valid_number, '鹿児島県阿久根市塩鶴町');
ok($zip->set_number('8991629')->is_valid_number, '鹿児島県阿久根市塩浜町');
ok($zip->set_number('8991741')->is_valid_number, '鹿児島県阿久根市大川');
ok($zip->set_number('8991801')->is_valid_number, '鹿児島県薩摩川内市西方町');
ok($zip->set_number('8991802')->is_valid_number, '鹿児島県薩摩川内市湯田町');
ok($zip->set_number('8991921')->is_valid_number, '鹿児島県薩摩川内市水引町');
ok($zip->set_number('8991922')->is_valid_number, '鹿児島県薩摩川内市小倉町');
ok($zip->set_number('8991923')->is_valid_number, '鹿児島県薩摩川内市湯島町');
ok($zip->set_number('8991924')->is_valid_number, '鹿児島県薩摩川内市港町');
ok($zip->set_number('8991925')->is_valid_number, '鹿児島県薩摩川内市網津町');
ok($zip->set_number('8992101')->is_valid_number, '鹿児島県いちき串木野市湊町');
ok($zip->set_number('8992102')->is_valid_number, '鹿児島県いちき串木野市川上');
ok($zip->set_number('8992103')->is_valid_number, '鹿児島県いちき串木野市大里');
ok($zip->set_number('8992201')->is_valid_number, '鹿児島県日置市東市来町湯田');
ok($zip->set_number('8992202')->is_valid_number, '鹿児島県日置市東市来町長里');
ok($zip->set_number('8992203')->is_valid_number, '鹿児島県日置市東市来町伊作田');
ok($zip->set_number('8992204')->is_valid_number, '鹿児島県日置市東市来町神之川');
ok($zip->set_number('8992311')->is_valid_number, '鹿児島県日置市東市来町養母');
ok($zip->set_number('8992421')->is_valid_number, '鹿児島県日置市日吉町神之川');
ok($zip->set_number('8992431')->is_valid_number, '鹿児島県日置市東市来町美山');
ok($zip->set_number('8992432')->is_valid_number, '鹿児島県日置市東市来町寺脇');
ok($zip->set_number('8992433')->is_valid_number, '鹿児島県日置市東市来町宮田');
ok($zip->set_number('8992434')->is_valid_number, '鹿児島県日置市東市来町南神之川');
ok($zip->set_number('8992441')->is_valid_number, '鹿児島県日置市伊集院町桑畑');
ok($zip->set_number('8992442')->is_valid_number, '鹿児島県日置市伊集院町野田');
ok($zip->set_number('8992443')->is_valid_number, '鹿児島県日置市伊集院町寺脇');
ok($zip->set_number('8992500')->is_valid_number, '鹿児島県日置市以下に掲載がない場合');
ok($zip->set_number('8992501')->is_valid_number, '鹿児島県日置市伊集院町下谷口');
ok($zip->set_number('8992502')->is_valid_number, '鹿児島県日置市伊集院町徳重');
ok($zip->set_number('8992503')->is_valid_number, '鹿児島県日置市伊集院町妙円寺');
ok($zip->set_number('8992504')->is_valid_number, '鹿児島県日置市伊集院町郡');
ok($zip->set_number('8992505')->is_valid_number, '鹿児島県日置市伊集院町猪鹿倉');
ok($zip->set_number('8992506')->is_valid_number, '鹿児島県日置市伊集院町清藤');
ok($zip->set_number('8992511')->is_valid_number, '鹿児島県日置市伊集院町下神殿');
ok($zip->set_number('8992512')->is_valid_number, '鹿児島県日置市伊集院町上神殿');
ok($zip->set_number('8992513')->is_valid_number, '鹿児島県日置市伊集院町麦生田');
ok($zip->set_number('8992514')->is_valid_number, '鹿児島県日置市伊集院町中川');
ok($zip->set_number('8992515')->is_valid_number, '鹿児島県日置市伊集院町竹之山');
ok($zip->set_number('8992516')->is_valid_number, '鹿児島県日置市伊集院町土橋');
ok($zip->set_number('8992521')->is_valid_number, '鹿児島県日置市伊集院町大田(その他)');
ok($zip->set_number('8992522')->is_valid_number, '鹿児島県日置市伊集院町飯牟礼');
ok($zip->set_number('8992523')->is_valid_number, '鹿児島県日置市伊集院町古城');
ok($zip->set_number('8992524')->is_valid_number, '鹿児島県日置市伊集院町恋之原');
ok($zip->set_number('8992531')->is_valid_number, '鹿児島県鹿児島市小山田町(5199、5200、5205番地)');
ok($zip->set_number('8992701')->is_valid_number, '鹿児島県鹿児島市石谷町');
ok($zip->set_number('8992702')->is_valid_number, '鹿児島県鹿児島市福山町');
ok($zip->set_number('8992703')->is_valid_number, '鹿児島県鹿児島市上谷口町');
ok($zip->set_number('8992704')->is_valid_number, '鹿児島県鹿児島市春山町');
ok($zip->set_number('8992705')->is_valid_number, '鹿児島県鹿児島市直木町');
ok($zip->set_number('8992706')->is_valid_number, '鹿児島県鹿児島市入佐町(その他)');
ok($zip->set_number('8992707')->is_valid_number, '鹿児島県鹿児島市松陽台町');
ok($zip->set_number('8992708')->is_valid_number, '鹿児島県鹿児島市四元町');
ok($zip->set_number('8992709')->is_valid_number, '鹿児島県鹿児島市平田町');
ok($zip->set_number('8993101')->is_valid_number, '鹿児島県日置市日吉町日置');
ok($zip->set_number('8993102')->is_valid_number, '鹿児島県日置市日吉町山田');
ok($zip->set_number('8993103')->is_valid_number, '鹿児島県日置市日吉町吉利(5614、5619、5647、5653番地)');
ok($zip->set_number('8993121')->is_valid_number, '鹿児島県日置市伊集院町大田(久木野々石塚)');
ok($zip->set_number('8993203')->is_valid_number, '鹿児島県日置市日吉町吉利(その他)');
ok($zip->set_number('8993206')->is_valid_number, '鹿児島県鹿児島市入佐町(1738、1739番地)');
ok($zip->set_number('8993221')->is_valid_number, '鹿児島県日置市吹上町永吉');
ok($zip->set_number('8993301')->is_valid_number, '鹿児島県日置市吹上町中原');
ok($zip->set_number('8993302')->is_valid_number, '鹿児島県日置市吹上町中之里');
ok($zip->set_number('8993303')->is_valid_number, '鹿児島県日置市吹上町湯之浦');
ok($zip->set_number('8993304')->is_valid_number, '鹿児島県日置市吹上町入来');
ok($zip->set_number('8993305')->is_valid_number, '鹿児島県日置市吹上町今田');
ok($zip->set_number('8993306')->is_valid_number, '鹿児島県日置市吹上町小野');
ok($zip->set_number('8993307')->is_valid_number, '鹿児島県日置市吹上町花熟里');
ok($zip->set_number('8993308')->is_valid_number, '鹿児島県日置市吹上町田尻');
ok($zip->set_number('8993309')->is_valid_number, '鹿児島県日置市吹上町与倉');
ok($zip->set_number('8993311')->is_valid_number, '鹿児島県日置市吹上町和田');
ok($zip->set_number('8993401')->is_valid_number, '鹿児島県南さつま市金峰町大野');
ok($zip->set_number('8993402')->is_valid_number, '鹿児島県南さつま市金峰町大坂');
ok($zip->set_number('8993403')->is_valid_number, '鹿児島県南さつま市金峰町尾下');
ok($zip->set_number('8993404')->is_valid_number, '鹿児島県南さつま市金峰町高橋');
ok($zip->set_number('8993405')->is_valid_number, '鹿児島県南さつま市金峰町池辺');
ok($zip->set_number('8993511')->is_valid_number, '鹿児島県南さつま市金峰町宮崎');
ok($zip->set_number('8993512')->is_valid_number, '鹿児島県南さつま市金峰町花瀬');
ok($zip->set_number('8993513')->is_valid_number, '鹿児島県南さつま市金峰町白川');
ok($zip->set_number('8993514')->is_valid_number, '鹿児島県南さつま市金峰町新山');
ok($zip->set_number('8993515')->is_valid_number, '鹿児島県南さつま市金峰町中津野');
ok($zip->set_number('8993516')->is_valid_number, '鹿児島県南さつま市金峰町浦之名');
ok($zip->set_number('8993611')->is_valid_number, '鹿児島県南さつま市加世田津貫');
ok($zip->set_number('8994101')->is_valid_number, '鹿児島県曽於市財部町南俣');
ok($zip->set_number('8994102')->is_valid_number, '鹿児島県曽於市財部町北俣');
ok($zip->set_number('8994103')->is_valid_number, '鹿児島県曽於市財部町下財部');
ok($zip->set_number('8994201')->is_valid_number, '鹿児島県霧島市霧島田口');
ok($zip->set_number('8994202')->is_valid_number, '鹿児島県霧島市霧島永水');
ok($zip->set_number('8994203')->is_valid_number, '鹿児島県霧島市霧島大窪');
ok($zip->set_number('8994204')->is_valid_number, '鹿児島県霧島市霧島川北');
ok($zip->set_number('8994300')->is_valid_number, '鹿児島県霧島市以下に掲載がない場合');
ok($zip->set_number('8994301')->is_valid_number, '鹿児島県霧島市国分重久');
ok($zip->set_number('8994302')->is_valid_number, '鹿児島県霧島市国分台明寺');
ok($zip->set_number('8994303')->is_valid_number, '鹿児島県霧島市国分川原');
ok($zip->set_number('8994304')->is_valid_number, '鹿児島県霧島市国分清水');
ok($zip->set_number('8994305')->is_valid_number, '鹿児島県霧島市国分郡田');
ok($zip->set_number('8994311')->is_valid_number, '鹿児島県霧島市国分名波町');
ok($zip->set_number('8994312')->is_valid_number, '鹿児島県霧島市国分山下町');
ok($zip->set_number('8994313')->is_valid_number, '鹿児島県霧島市国分上井');
ok($zip->set_number('8994314')->is_valid_number, '鹿児島県霧島市国分川内');
ok($zip->set_number('8994315')->is_valid_number, '鹿児島県霧島市国分湊');
ok($zip->set_number('8994316')->is_valid_number, '鹿児島県霧島市国分上小川');
ok($zip->set_number('8994317')->is_valid_number, '鹿児島県霧島市国分上野原テクノパーク');
ok($zip->set_number('8994318')->is_valid_number, '鹿児島県霧島市国分上野原縄文の森');
ok($zip->set_number('8994321')->is_valid_number, '鹿児島県霧島市国分広瀬');
ok($zip->set_number('8994322')->is_valid_number, '鹿児島県霧島市国分福島');
ok($zip->set_number('8994323')->is_valid_number, '鹿児島県霧島市国分松木');
ok($zip->set_number('8994324')->is_valid_number, '鹿児島県霧島市国分松木東');
ok($zip->set_number('8994325')->is_valid_number, '鹿児島県霧島市国分松木町');
ok($zip->set_number('8994331')->is_valid_number, '鹿児島県霧島市国分城山町');
ok($zip->set_number('8994332')->is_valid_number, '鹿児島県霧島市国分中央');
ok($zip->set_number('8994341')->is_valid_number, '鹿児島県霧島市国分野口東');
ok($zip->set_number('8994342')->is_valid_number, '鹿児島県霧島市国分野口町');
ok($zip->set_number('8994343')->is_valid_number, '鹿児島県霧島市国分野口西');
ok($zip->set_number('8994344')->is_valid_number, '鹿児島県霧島市国分野口北');
ok($zip->set_number('8994345')->is_valid_number, '鹿児島県霧島市国分府中');
ok($zip->set_number('8994346')->is_valid_number, '鹿児島県霧島市国分府中町');
ok($zip->set_number('8994351')->is_valid_number, '鹿児島県霧島市国分新町');
ok($zip->set_number('8994352')->is_valid_number, '鹿児島県霧島市国分向花');
ok($zip->set_number('8994353')->is_valid_number, '鹿児島県霧島市国分向花町');
ok($zip->set_number('8994354')->is_valid_number, '鹿児島県霧島市国分姫城');
ok($zip->set_number('8994355')->is_valid_number, '鹿児島県霧島市国分剣之宇都町');
ok($zip->set_number('8994356')->is_valid_number, '鹿児島県霧島市国分姫城南');
ok($zip->set_number('8994461')->is_valid_number, '鹿児島県霧島市国分上之段');
ok($zip->set_number('8994462')->is_valid_number, '鹿児島県霧島市国分敷根');
ok($zip->set_number('8994463')->is_valid_number, '鹿児島県霧島市国分下井');
ok($zip->set_number('8994501')->is_valid_number, '鹿児島県霧島市福山町福山');
ok($zip->set_number('8994502')->is_valid_number, '鹿児島県霧島市福山町福地');
ok($zip->set_number('8994503')->is_valid_number, '鹿児島県霧島市福山町福沢');
ok($zip->set_number('8994504')->is_valid_number, '鹿児島県霧島市福山町佳例川');
ok($zip->set_number('8994631')->is_valid_number, '鹿児島県垂水市牛根境');
ok($zip->set_number('8994632')->is_valid_number, '鹿児島県垂水市牛根麓');
ok($zip->set_number('8994633')->is_valid_number, '鹿児島県垂水市二川');
ok($zip->set_number('8995101')->is_valid_number, '鹿児島県霧島市隼人町住吉');
ok($zip->set_number('8995102')->is_valid_number, '鹿児島県霧島市隼人町真孝');
ok($zip->set_number('8995103')->is_valid_number, '鹿児島県霧島市隼人町小浜');
ok($zip->set_number('8995104')->is_valid_number, '鹿児島県霧島市隼人町野久美田');
ok($zip->set_number('8995105')->is_valid_number, '鹿児島県霧島市隼人町小田');
ok($zip->set_number('8995106')->is_valid_number, '鹿児島県霧島市隼人町内山田');
ok($zip->set_number('8995111')->is_valid_number, '鹿児島県霧島市隼人町姫城');
ok($zip->set_number('8995112')->is_valid_number, '鹿児島県霧島市隼人町松永');
ok($zip->set_number('8995113')->is_valid_number, '鹿児島県霧島市隼人町嘉例川');
ok($zip->set_number('8995114')->is_valid_number, '鹿児島県霧島市隼人町西光寺');
ok($zip->set_number('8995115')->is_valid_number, '鹿児島県霧島市隼人町東郷');
ok($zip->set_number('8995116')->is_valid_number, '鹿児島県霧島市隼人町内');
ok($zip->set_number('8995117')->is_valid_number, '鹿児島県霧島市隼人町見次');
ok($zip->set_number('8995118')->is_valid_number, '鹿児島県霧島市隼人町朝日');
ok($zip->set_number('8995121')->is_valid_number, '鹿児島県霧島市隼人町神宮');
ok($zip->set_number('8995201')->is_valid_number, '鹿児島県姶良市加治木町西別府');
ok($zip->set_number('8995202')->is_valid_number, '鹿児島県姶良市加治木町辺川');
ok($zip->set_number('8995203')->is_valid_number, '鹿児島県姶良市加治木町小山田');
ok($zip->set_number('8995204')->is_valid_number, '鹿児島県姶良市加治木町日木山');
ok($zip->set_number('8995211')->is_valid_number, '鹿児島県姶良市加治木町新富町');
ok($zip->set_number('8995212')->is_valid_number, '鹿児島県姶良市加治木町諏訪町');
ok($zip->set_number('8995213')->is_valid_number, '鹿児島県姶良市加治木町朝日町');
ok($zip->set_number('8995214')->is_valid_number, '鹿児島県姶良市加治木町仮屋町');
ok($zip->set_number('8995215')->is_valid_number, '鹿児島県姶良市加治木町本町');
ok($zip->set_number('8995221')->is_valid_number, '鹿児島県姶良市加治木町港町');
ok($zip->set_number('8995222')->is_valid_number, '鹿児島県姶良市加治木町錦江町');
ok($zip->set_number('8995223')->is_valid_number, '鹿児島県姶良市加治木町新生町');
ok($zip->set_number('8995231')->is_valid_number, '鹿児島県姶良市加治木町反土');
ok($zip->set_number('8995241')->is_valid_number, '鹿児島県姶良市加治木町木田');
ok($zip->set_number('8995301')->is_valid_number, '鹿児島県姶良市蒲生町漆');
ok($zip->set_number('8995302')->is_valid_number, '鹿児島県姶良市蒲生町上久徳');
ok($zip->set_number('8995303')->is_valid_number, '鹿児島県姶良市蒲生町北');
ok($zip->set_number('8995304')->is_valid_number, '鹿児島県姶良市蒲生町下久徳');
ok($zip->set_number('8995305')->is_valid_number, '鹿児島県姶良市蒲生町白男');
ok($zip->set_number('8995306')->is_valid_number, '鹿児島県姶良市蒲生町西浦');
ok($zip->set_number('8995307')->is_valid_number, '鹿児島県姶良市蒲生町久末');
ok($zip->set_number('8995308')->is_valid_number, '鹿児島県姶良市蒲生町米丸');
ok($zip->set_number('8995400')->is_valid_number, '鹿児島県姶良市以下に掲載がない場合');
ok($zip->set_number('8995401')->is_valid_number, '鹿児島県姶良市寺師');
ok($zip->set_number('8995402')->is_valid_number, '鹿児島県姶良市中津野');
ok($zip->set_number('8995403')->is_valid_number, '鹿児島県姶良市増田');
ok($zip->set_number('8995404')->is_valid_number, '鹿児島県姶良市永瀬');
ok($zip->set_number('8995405')->is_valid_number, '鹿児島県姶良市住吉');
ok($zip->set_number('8995411')->is_valid_number, '鹿児島県姶良市鍋倉');
ok($zip->set_number('8995412')->is_valid_number, '鹿児島県姶良市三拾町');
ok($zip->set_number('8995413')->is_valid_number, '鹿児島県姶良市豊留');
ok($zip->set_number('8995414')->is_valid_number, '鹿児島県姶良市深水');
ok($zip->set_number('8995421')->is_valid_number, '鹿児島県姶良市東餠田');
ok($zip->set_number('8995422')->is_valid_number, '鹿児島県姶良市松原町');
ok($zip->set_number('8995431')->is_valid_number, '鹿児島県姶良市西餠田');
ok($zip->set_number('8995432')->is_valid_number, '鹿児島県姶良市宮島町');
ok($zip->set_number('8995433')->is_valid_number, '鹿児島県姶良市西宮島町');
ok($zip->set_number('8995541')->is_valid_number, '鹿児島県姶良市北山');
ok($zip->set_number('8995542')->is_valid_number, '鹿児島県姶良市上名');
ok($zip->set_number('8995543')->is_valid_number, '鹿児島県姶良市下名');
ok($zip->set_number('8995544')->is_valid_number, '鹿児島県姶良市大山');
ok($zip->set_number('8995545')->is_valid_number, '鹿児島県姶良市木津志');
ok($zip->set_number('8995651')->is_valid_number, '鹿児島県姶良市脇元');
ok($zip->set_number('8995652')->is_valid_number, '鹿児島県姶良市平松');
ok($zip->set_number('8995653')->is_valid_number, '鹿児島県姶良市池島町');
ok($zip->set_number('8995654')->is_valid_number, '鹿児島県姶良市永池町');
ok($zip->set_number('8995655')->is_valid_number, '鹿児島県姶良市船津');
ok($zip->set_number('8995656')->is_valid_number, '鹿児島県姶良市西姶良');
ok($zip->set_number('8996101')->is_valid_number, '鹿児島県姶良郡湧水町鶴丸');
ok($zip->set_number('8996102')->is_valid_number, '鹿児島県姶良郡湧水町中津川');
ok($zip->set_number('8996103')->is_valid_number, '鹿児島県姶良郡湧水町川添');
ok($zip->set_number('8996104')->is_valid_number, '鹿児島県姶良郡湧水町川西');
ok($zip->set_number('8996105')->is_valid_number, '鹿児島県姶良郡湧水町般若寺');
ok($zip->set_number('8996200')->is_valid_number, '鹿児島県姶良郡湧水町以下に掲載がない場合');
ok($zip->set_number('8996201')->is_valid_number, '鹿児島県姶良郡湧水町木場');
ok($zip->set_number('8996202')->is_valid_number, '鹿児島県姶良郡湧水町北方');
ok($zip->set_number('8996203')->is_valid_number, '鹿児島県姶良郡湧水町田尾原');
ok($zip->set_number('8996204')->is_valid_number, '鹿児島県姶良郡湧水町稲葉崎');
ok($zip->set_number('8996205')->is_valid_number, '鹿児島県姶良郡湧水町幸田');
ok($zip->set_number('8996206')->is_valid_number, '鹿児島県姶良郡湧水町恒次');
ok($zip->set_number('8996207')->is_valid_number, '鹿児島県姶良郡湧水町米永');
ok($zip->set_number('8996301')->is_valid_number, '鹿児島県霧島市横川町上ノ');
ok($zip->set_number('8996302')->is_valid_number, '鹿児島県霧島市横川町下ノ');
ok($zip->set_number('8996303')->is_valid_number, '鹿児島県霧島市横川町中ノ');
ok($zip->set_number('8996401')->is_valid_number, '鹿児島県霧島市溝辺町有川');
ok($zip->set_number('8996402')->is_valid_number, '鹿児島県霧島市溝辺町竹子');
ok($zip->set_number('8996403')->is_valid_number, '鹿児島県霧島市溝辺町三縄');
ok($zip->set_number('8996404')->is_valid_number, '鹿児島県霧島市溝辺町麓');
ok($zip->set_number('8996405')->is_valid_number, '鹿児島県霧島市溝辺町崎森');
ok($zip->set_number('8996501')->is_valid_number, '鹿児島県霧島市牧園町万膳(その他)');
ok($zip->set_number('8996502')->is_valid_number, '鹿児島県霧島市牧園町三体堂(その他)');
ok($zip->set_number('8996503')->is_valid_number, '鹿児島県霧島市牧園町高千穂(3012~3240番)');
ok($zip->set_number('8996504')->is_valid_number, '鹿児島県霧島市牧園町上中津川(その他)');
ok($zip->set_number('8996505')->is_valid_number, '鹿児島県霧島市牧園町持松');
ok($zip->set_number('8996506')->is_valid_number, '鹿児島県霧島市牧園町下中津川');
ok($zip->set_number('8996507')->is_valid_number, '鹿児島県霧島市牧園町宿窪田');
ok($zip->set_number('8996601')->is_valid_number, '鹿児島県霧島市牧園町万膳(1400~1477番)');
ok($zip->set_number('8996602')->is_valid_number, '鹿児島県霧島市牧園町三体堂(1824-2、1824-9、1824-41、');
ok($zip->set_number('8996602')->is_valid_number, '鹿児島県霧島市1835-81、1835-108、1835-109、1835-228、');
ok($zip->set_number('8996602')->is_valid_number, '鹿児島県霧島市1835-238、1835-253、2003-5、2003-9、');
ok($zip->set_number('8996602')->is_valid_number, '鹿児島県霧島市2003-14、2003-17、2003-18、2057-8)');
ok($zip->set_number('8996603')->is_valid_number, '鹿児島県霧島市牧園町高千穂(その他)');
ok($zip->set_number('8996604')->is_valid_number, '鹿児島県霧島市牧園町上中津川(1896~2072番)');
ok($zip->set_number('8997100')->is_valid_number, '鹿児島県志布志市以下に掲載がない場合');
ok($zip->set_number('8997101')->is_valid_number, '鹿児島県志布志市志布志町夏井');
ok($zip->set_number('8997102')->is_valid_number, '鹿児島県志布志市志布志町帖');
ok($zip->set_number('8997103')->is_valid_number, '鹿児島県志布志市志布志町志布志');
ok($zip->set_number('8997104')->is_valid_number, '鹿児島県志布志市志布志町安楽');
ok($zip->set_number('8997211')->is_valid_number, '鹿児島県志布志市志布志町内之倉');
ok($zip->set_number('8997212')->is_valid_number, '鹿児島県志布志市志布志町田之浦');
ok($zip->set_number('8997300')->is_valid_number, '鹿児島県曽於郡大崎町以下に掲載がない場合');
ok($zip->set_number('8997301')->is_valid_number, '鹿児島県曽於郡大崎町菱田');
ok($zip->set_number('8997302')->is_valid_number, '鹿児島県曽於郡大崎町神領');
ok($zip->set_number('8997303')->is_valid_number, '鹿児島県曽於郡大崎町益丸');
ok($zip->set_number('8997304')->is_valid_number, '鹿児島県曽於郡大崎町横瀬');
ok($zip->set_number('8997305')->is_valid_number, '鹿児島県曽於郡大崎町假宿');
ok($zip->set_number('8997306')->is_valid_number, '鹿児島県曽於郡大崎町永吉');
ok($zip->set_number('8997307')->is_valid_number, '鹿児島県曽於郡大崎町持留');
ok($zip->set_number('8997308')->is_valid_number, '鹿児島県曽於郡大崎町岡別府');
ok($zip->set_number('8997309')->is_valid_number, '鹿児島県曽於郡大崎町井俣');
ok($zip->set_number('8997401')->is_valid_number, '鹿児島県志布志市有明町伊崎田');
ok($zip->set_number('8997402')->is_valid_number, '鹿児島県志布志市有明町野井倉');
ok($zip->set_number('8997403')->is_valid_number, '鹿児島県志布志市有明町蓬原(春日)');
ok($zip->set_number('8997503')->is_valid_number, '鹿児島県志布志市有明町蓬原(その他)');
ok($zip->set_number('8997511')->is_valid_number, '鹿児島県志布志市有明町原田');
ok($zip->set_number('8997512')->is_valid_number, '鹿児島県志布志市有明町野神(その他)');
ok($zip->set_number('8997513')->is_valid_number, '鹿児島県志布志市有明町山重');
ok($zip->set_number('8997601')->is_valid_number, '鹿児島県志布志市松山町新橋');
ok($zip->set_number('8997602')->is_valid_number, '鹿児島県志布志市松山町泰野');
ok($zip->set_number('8997603')->is_valid_number, '鹿児島県志布志市松山町尾野見');
ok($zip->set_number('8998101')->is_valid_number, '鹿児島県曽於市末吉町岩崎(池原、岩之上、岩南、前田、牧原、道添、宮原)');
ok($zip->set_number('8998102')->is_valid_number, '鹿児島県曽於市大隅町岩川');
ok($zip->set_number('8998103')->is_valid_number, '鹿児島県曽於市大隅町中之内');
ok($zip->set_number('8998104')->is_valid_number, '鹿児島県曽於市大隅町鳴神町');
ok($zip->set_number('8998105')->is_valid_number, '鹿児島県曽於市大隅町段中町');
ok($zip->set_number('8998106')->is_valid_number, '鹿児島県曽於市大隅町下窪町');
ok($zip->set_number('8998211')->is_valid_number, '鹿児島県曽於市大隅町荒谷(荒谷、大迫、中大迫)');
ok($zip->set_number('8998212')->is_valid_number, '鹿児島県曽於市大隅町月野');
ok($zip->set_number('8998213')->is_valid_number, '鹿児島県曽於市大隅町境木町');
ok($zip->set_number('8998311')->is_valid_number, '鹿児島県曽於市大隅町荒谷(その他)');
ok($zip->set_number('8998312')->is_valid_number, '鹿児島県志布志市有明町野神(抜谷、塗木、本地、曲、水ノ谷)');
ok($zip->set_number('8998313')->is_valid_number, '鹿児島県曽於郡大崎町野方');
ok($zip->set_number('8998421')->is_valid_number, '鹿児島県曽於市大隅町大谷');
ok($zip->set_number('8998422')->is_valid_number, '鹿児島県曽於市大隅町坂元');
ok($zip->set_number('8998423')->is_valid_number, '鹿児島県曽於市大隅町須田木');
ok($zip->set_number('8998424')->is_valid_number, '鹿児島県曽於市大隅町恒吉');
ok($zip->set_number('8998511')->is_valid_number, '鹿児島県鹿屋市輝北町市成');
ok($zip->set_number('8998512')->is_valid_number, '鹿児島県鹿屋市輝北町諏訪原');
ok($zip->set_number('8998600')->is_valid_number, '鹿児島県曽於市以下に掲載がない場合');
ok($zip->set_number('8998601')->is_valid_number, '鹿児島県曽於市末吉町岩崎(その他)');
ok($zip->set_number('8998602')->is_valid_number, '鹿児島県曽於市末吉町栄町');
ok($zip->set_number('8998603')->is_valid_number, '鹿児島県曽於市末吉町新町');
ok($zip->set_number('8998604')->is_valid_number, '鹿児島県曽於市末吉町諏訪方');
ok($zip->set_number('8998605')->is_valid_number, '鹿児島県曽於市末吉町二之方');
ok($zip->set_number('8998606')->is_valid_number, '鹿児島県曽於市末吉町深川');
ok($zip->set_number('8998607')->is_valid_number, '鹿児島県曽於市末吉町本町');
ok($zip->set_number('8998608')->is_valid_number, '鹿児島県曽於市末吉町南之郷');
ok($zip->set_number('8998609')->is_valid_number, '鹿児島県曽於市末吉町上町');
ok($zip->set_number('9000000')->is_valid_number, '沖縄県那覇市以下に掲載がない場合');
ok($zip->set_number('9000001')->is_valid_number, '沖縄県那覇市港町');
ok($zip->set_number('9000002')->is_valid_number, '沖縄県那覇市曙');
ok($zip->set_number('9000003')->is_valid_number, '沖縄県那覇市安謝');
ok($zip->set_number('9000004')->is_valid_number, '沖縄県那覇市銘苅');
ok($zip->set_number('9000005')->is_valid_number, '沖縄県那覇市天久');
ok($zip->set_number('9000006')->is_valid_number, '沖縄県那覇市おもろまち');
ok($zip->set_number('9000011')->is_valid_number, '沖縄県那覇市上之屋');
ok($zip->set_number('9000012')->is_valid_number, '沖縄県那覇市泊');
ok($zip->set_number('9000013')->is_valid_number, '沖縄県那覇市牧志');
ok($zip->set_number('9000014')->is_valid_number, '沖縄県那覇市松尾');
ok($zip->set_number('9000015')->is_valid_number, '沖縄県那覇市久茂地');
ok($zip->set_number('9000016')->is_valid_number, '沖縄県那覇市前島');
ok($zip->set_number('9000021')->is_valid_number, '沖縄県那覇市泉崎');
ok($zip->set_number('9000022')->is_valid_number, '沖縄県那覇市樋川');
ok($zip->set_number('9000023')->is_valid_number, '沖縄県那覇市楚辺');
ok($zip->set_number('9000024')->is_valid_number, '沖縄県那覇市古波蔵');
ok($zip->set_number('9000025')->is_valid_number, '沖縄県那覇市壺川');
ok($zip->set_number('9000026')->is_valid_number, '沖縄県那覇市奥武山町');
ok($zip->set_number('9000027')->is_valid_number, '沖縄県那覇市山下町');
ok($zip->set_number('9000028')->is_valid_number, '沖縄県那覇市垣花町');
ok($zip->set_number('9000029')->is_valid_number, '沖縄県那覇市旭町');
ok($zip->set_number('9000031')->is_valid_number, '沖縄県那覇市若狭');
ok($zip->set_number('9000032')->is_valid_number, '沖縄県那覇市松山');
ok($zip->set_number('9000033')->is_valid_number, '沖縄県那覇市久米');
ok($zip->set_number('9000034')->is_valid_number, '沖縄県那覇市東町');
ok($zip->set_number('9000035')->is_valid_number, '沖縄県那覇市通堂町');
ok($zip->set_number('9000036')->is_valid_number, '沖縄県那覇市西');
ok($zip->set_number('9000037')->is_valid_number, '沖縄県那覇市辻');
ok($zip->set_number('9010141')->is_valid_number, '沖縄県那覇市住吉町');
ok($zip->set_number('9010142')->is_valid_number, '沖縄県那覇市鏡水');
ok($zip->set_number('9010143')->is_valid_number, '沖縄県那覇市安次嶺');
ok($zip->set_number('9010144')->is_valid_number, '沖縄県那覇市当間');
ok($zip->set_number('9010145')->is_valid_number, '沖縄県那覇市高良');
ok($zip->set_number('9010146')->is_valid_number, '沖縄県那覇市具志');
ok($zip->set_number('9010147')->is_valid_number, '沖縄県那覇市宮城');
ok($zip->set_number('9010148')->is_valid_number, '沖縄県那覇市大嶺');
ok($zip->set_number('9010151')->is_valid_number, '沖縄県那覇市鏡原町');
ok($zip->set_number('9010152')->is_valid_number, '沖縄県那覇市小禄');
ok($zip->set_number('9010153')->is_valid_number, '沖縄県那覇市宇栄原');
ok($zip->set_number('9010154')->is_valid_number, '沖縄県那覇市赤嶺');
ok($zip->set_number('9010155')->is_valid_number, '沖縄県那覇市金城');
ok($zip->set_number('9010156')->is_valid_number, '沖縄県那覇市田原');
ok($zip->set_number('9010200')->is_valid_number, '沖縄県豊見城市以下に掲載がない場合');
ok($zip->set_number('9010201')->is_valid_number, '沖縄県豊見城市真玉橋');
ok($zip->set_number('9010202')->is_valid_number, '沖縄県豊見城市嘉数');
ok($zip->set_number('9010203')->is_valid_number, '沖縄県豊見城市長堂');
ok($zip->set_number('9010204')->is_valid_number, '沖縄県豊見城市金良');
ok($zip->set_number('9010205')->is_valid_number, '沖縄県豊見城市根差部');
ok($zip->set_number('9010211')->is_valid_number, '沖縄県豊見城市饒波');
ok($zip->set_number('9010212')->is_valid_number, '沖縄県豊見城市平良');
ok($zip->set_number('9010213')->is_valid_number, '沖縄県豊見城市高嶺');
ok($zip->set_number('9010214')->is_valid_number, '沖縄県豊見城市保栄茂');
ok($zip->set_number('9010215')->is_valid_number, '沖縄県豊見城市渡嘉敷');
ok($zip->set_number('9010221')->is_valid_number, '沖縄県豊見城市座安');
ok($zip->set_number('9010222')->is_valid_number, '沖縄県豊見城市渡橋名');
ok($zip->set_number('9010223')->is_valid_number, '沖縄県豊見城市翁長');
ok($zip->set_number('9010224')->is_valid_number, '沖縄県豊見城市与根');
ok($zip->set_number('9010225')->is_valid_number, '沖縄県豊見城市豊崎');
ok($zip->set_number('9010231')->is_valid_number, '沖縄県豊見城市我那覇');
ok($zip->set_number('9010232')->is_valid_number, '沖縄県豊見城市伊良波');
ok($zip->set_number('9010233')->is_valid_number, '沖縄県豊見城市瀬長');
ok($zip->set_number('9010234')->is_valid_number, '沖縄県豊見城市田頭');
ok($zip->set_number('9010235')->is_valid_number, '沖縄県豊見城市名嘉地');
ok($zip->set_number('9010241')->is_valid_number, '沖縄県豊見城市豊見城');
ok($zip->set_number('9010242')->is_valid_number, '沖縄県豊見城市高安');
ok($zip->set_number('9010243')->is_valid_number, '沖縄県豊見城市上田');
ok($zip->set_number('9010244')->is_valid_number, '沖縄県豊見城市宜保');
ok($zip->set_number('9010300')->is_valid_number, '沖縄県糸満市以下に掲載がない場合');
ok($zip->set_number('9010301')->is_valid_number, '沖縄県糸満市阿波根');
ok($zip->set_number('9010302')->is_valid_number, '沖縄県糸満市潮平');
ok($zip->set_number('9010303')->is_valid_number, '沖縄県糸満市兼城');
ok($zip->set_number('9010304')->is_valid_number, '沖縄県糸満市西川町');
ok($zip->set_number('9010305')->is_valid_number, '沖縄県糸満市西崎');
ok($zip->set_number('9010306')->is_valid_number, '沖縄県糸満市西崎町');
ok($zip->set_number('9010311')->is_valid_number, '沖縄県糸満市武富');
ok($zip->set_number('9010312')->is_valid_number, '沖縄県糸満市北波平');
ok($zip->set_number('9010313')->is_valid_number, '沖縄県糸満市賀数');
ok($zip->set_number('9010314')->is_valid_number, '沖縄県糸満市座波');
ok($zip->set_number('9010315')->is_valid_number, '沖縄県糸満市照屋');
ok($zip->set_number('9010321')->is_valid_number, '沖縄県糸満市豊原');
ok($zip->set_number('9010322')->is_valid_number, '沖縄県糸満市与座');
ok($zip->set_number('9010323')->is_valid_number, '沖縄県糸満市新垣');
ok($zip->set_number('9010324')->is_valid_number, '沖縄県糸満市国吉');
ok($zip->set_number('9010325')->is_valid_number, '沖縄県糸満市大里');
ok($zip->set_number('9010331')->is_valid_number, '沖縄県糸満市真栄平');
ok($zip->set_number('9010332')->is_valid_number, '沖縄県糸満市宇江城');
ok($zip->set_number('9010333')->is_valid_number, '沖縄県糸満市摩文仁');
ok($zip->set_number('9010334')->is_valid_number, '沖縄県糸満市大度');
ok($zip->set_number('9010335')->is_valid_number, '沖縄県糸満市米須');
ok($zip->set_number('9010336')->is_valid_number, '沖縄県糸満市真壁');
ok($zip->set_number('9010341')->is_valid_number, '沖縄県糸満市小波蔵');
ok($zip->set_number('9010342')->is_valid_number, '沖縄県糸満市糸洲');
ok($zip->set_number('9010343')->is_valid_number, '沖縄県糸満市南波平');
ok($zip->set_number('9010344')->is_valid_number, '沖縄県糸満市伊原');
ok($zip->set_number('9010345')->is_valid_number, '沖縄県糸満市福地');
ok($zip->set_number('9010351')->is_valid_number, '沖縄県糸満市名城');
ok($zip->set_number('9010352')->is_valid_number, '沖縄県糸満市山城');
ok($zip->set_number('9010353')->is_valid_number, '沖縄県糸満市束里');
ok($zip->set_number('9010354')->is_valid_number, '沖縄県糸満市喜屋武');
ok($zip->set_number('9010361')->is_valid_number, '沖縄県糸満市糸満');
ok($zip->set_number('9010362')->is_valid_number, '沖縄県糸満市真栄里');
ok($zip->set_number('9010363')->is_valid_number, '沖縄県糸満市伊敷');
ok($zip->set_number('9010364')->is_valid_number, '沖縄県糸満市潮崎町');
ok($zip->set_number('9010400')->is_valid_number, '沖縄県島尻郡八重瀬町以下に掲載がない場合');
ok($zip->set_number('9010401')->is_valid_number, '沖縄県島尻郡八重瀬町東風平');
ok($zip->set_number('9010402')->is_valid_number, '沖縄県島尻郡八重瀬町富盛');
ok($zip->set_number('9010403')->is_valid_number, '沖縄県島尻郡八重瀬町世名城');
ok($zip->set_number('9010404')->is_valid_number, '沖縄県島尻郡八重瀬町高良');
ok($zip->set_number('9010405')->is_valid_number, '沖縄県島尻郡八重瀬町伊覇');
ok($zip->set_number('9010406')->is_valid_number, '沖縄県島尻郡八重瀬町屋宜原');
ok($zip->set_number('9010411')->is_valid_number, '沖縄県島尻郡八重瀬町友寄');
ok($zip->set_number('9010412')->is_valid_number, '沖縄県島尻郡八重瀬町上田原');
ok($zip->set_number('9010413')->is_valid_number, '沖縄県島尻郡八重瀬町志多伯');
ok($zip->set_number('9010414')->is_valid_number, '沖縄県島尻郡八重瀬町当銘');
ok($zip->set_number('9010415')->is_valid_number, '沖縄県島尻郡八重瀬町小城');
ok($zip->set_number('9010416')->is_valid_number, '沖縄県島尻郡八重瀬町宜次');
ok($zip->set_number('9010417')->is_valid_number, '沖縄県島尻郡八重瀬町外間');
ok($zip->set_number('9010501')->is_valid_number, '沖縄県島尻郡八重瀬町長毛');
ok($zip->set_number('9010502')->is_valid_number, '沖縄県島尻郡八重瀬町大頓');
ok($zip->set_number('9010503')->is_valid_number, '沖縄県島尻郡八重瀬町新城');
ok($zip->set_number('9010504')->is_valid_number, '沖縄県島尻郡八重瀬町後原');
ok($zip->set_number('9010511')->is_valid_number, '沖縄県島尻郡八重瀬町港川');
ok($zip->set_number('9010512')->is_valid_number, '沖縄県島尻郡八重瀬町具志頭');
ok($zip->set_number('9010513')->is_valid_number, '沖縄県島尻郡八重瀬町玻名城');
ok($zip->set_number('9010514')->is_valid_number, '沖縄県島尻郡八重瀬町安里');
ok($zip->set_number('9010515')->is_valid_number, '沖縄県島尻郡八重瀬町与座');
ok($zip->set_number('9010516')->is_valid_number, '沖縄県島尻郡八重瀬町仲座');
ok($zip->set_number('9010601')->is_valid_number, '沖縄県南城市玉城垣花');
ok($zip->set_number('9010602')->is_valid_number, '沖縄県南城市玉城仲村渠');
ok($zip->set_number('9010603')->is_valid_number, '沖縄県南城市玉城百名');
ok($zip->set_number('9010604')->is_valid_number, '沖縄県南城市玉城玉城');
ok($zip->set_number('9010605')->is_valid_number, '沖縄県南城市玉城中山');
ok($zip->set_number('9010606')->is_valid_number, '沖縄県南城市玉城糸数');
ok($zip->set_number('9010607')->is_valid_number, '沖縄県南城市玉城喜良原');
ok($zip->set_number('9010608')->is_valid_number, '沖縄県南城市玉城親慶原');
ok($zip->set_number('9010611')->is_valid_number, '沖縄県南城市玉城富里');
ok($zip->set_number('9010612')->is_valid_number, '沖縄県南城市玉城當山');
ok($zip->set_number('9010613')->is_valid_number, '沖縄県南城市玉城志堅原');
ok($zip->set_number('9010614')->is_valid_number, '沖縄県南城市玉城奥武');
ok($zip->set_number('9010615')->is_valid_number, '沖縄県南城市玉城堀川');
ok($zip->set_number('9010616')->is_valid_number, '沖縄県南城市玉城前川');
ok($zip->set_number('9010617')->is_valid_number, '沖縄県南城市玉城愛地');
ok($zip->set_number('9010618')->is_valid_number, '沖縄県南城市玉城船越');
ok($zip->set_number('9010619')->is_valid_number, '沖縄県南城市玉城屋嘉部');
ok($zip->set_number('9011100')->is_valid_number, '沖縄県島尻郡南風原町以下に掲載がない場合');
ok($zip->set_number('9011101')->is_valid_number, '沖縄県島尻郡南風原町大名');
ok($zip->set_number('9011102')->is_valid_number, '沖縄県島尻郡南風原町宮城');
ok($zip->set_number('9011103')->is_valid_number, '沖縄県島尻郡南風原町与那覇');
ok($zip->set_number('9011104')->is_valid_number, '沖縄県島尻郡南風原町宮平');
ok($zip->set_number('9011105')->is_valid_number, '沖縄県島尻郡南風原町新川');
ok($zip->set_number('9011111')->is_valid_number, '沖縄県島尻郡南風原町兼城');
ok($zip->set_number('9011112')->is_valid_number, '沖縄県島尻郡南風原町本部');
ok($zip->set_number('9011113')->is_valid_number, '沖縄県島尻郡南風原町喜屋武');
ok($zip->set_number('9011114')->is_valid_number, '沖縄県島尻郡南風原町神里');
ok($zip->set_number('9011115')->is_valid_number, '沖縄県島尻郡南風原町山川');
ok($zip->set_number('9011116')->is_valid_number, '沖縄県島尻郡南風原町照屋');
ok($zip->set_number('9011117')->is_valid_number, '沖縄県島尻郡南風原町津嘉山');
ok($zip->set_number('9011201')->is_valid_number, '沖縄県南城市大里嶺井');
ok($zip->set_number('9011202')->is_valid_number, '沖縄県南城市大里大里');
ok($zip->set_number('9011203')->is_valid_number, '沖縄県南城市大里大城');
ok($zip->set_number('9011204')->is_valid_number, '沖縄県南城市大里稲嶺');
ok($zip->set_number('9011205')->is_valid_number, '沖縄県南城市大里高平');
ok($zip->set_number('9011206')->is_valid_number, '沖縄県南城市大里仲間');
ok($zip->set_number('9011207')->is_valid_number, '沖縄県南城市大里古堅');
ok($zip->set_number('9011208')->is_valid_number, '沖縄県南城市大里平良');
ok($zip->set_number('9011300')->is_valid_number, '沖縄県島尻郡与那原町以下に掲載がない場合');
ok($zip->set_number('9011301')->is_valid_number, '沖縄県島尻郡与那原町板良敷');
ok($zip->set_number('9011302')->is_valid_number, '沖縄県島尻郡与那原町上与那原');
ok($zip->set_number('9011303')->is_valid_number, '沖縄県島尻郡与那原町与那原');
ok($zip->set_number('9011304')->is_valid_number, '沖縄県島尻郡与那原町東浜');
ok($zip->set_number('9011400')->is_valid_number, '沖縄県南城市以下に掲載がない場合');
ok($zip->set_number('9011401')->is_valid_number, '沖縄県南城市佐敷伊原');
ok($zip->set_number('9011402')->is_valid_number, '沖縄県南城市佐敷手登根');
ok($zip->set_number('9011403')->is_valid_number, '沖縄県南城市佐敷佐敷');
ok($zip->set_number('9011404')->is_valid_number, '沖縄県南城市佐敷冨祖崎');
ok($zip->set_number('9011405')->is_valid_number, '沖縄県南城市佐敷仲伊保');
ok($zip->set_number('9011406')->is_valid_number, '沖縄県南城市佐敷屋比久');
ok($zip->set_number('9011407')->is_valid_number, '沖縄県南城市つきしろ');
ok($zip->set_number('9011411')->is_valid_number, '沖縄県南城市佐敷兼久');
ok($zip->set_number('9011412')->is_valid_number, '沖縄県南城市佐敷新里');
ok($zip->set_number('9011413')->is_valid_number, '沖縄県南城市佐敷小谷');
ok($zip->set_number('9011414')->is_valid_number, '沖縄県南城市佐敷津波古');
ok($zip->set_number('9011415')->is_valid_number, '沖縄県南城市佐敷新開');
ok($zip->set_number('9011501')->is_valid_number, '沖縄県南城市知念久高');
ok($zip->set_number('9011502')->is_valid_number, '沖縄県南城市知念安座真');
ok($zip->set_number('9011503')->is_valid_number, '沖縄県南城市知念知名');
ok($zip->set_number('9011504')->is_valid_number, '沖縄県南城市知念海野');
ok($zip->set_number('9011505')->is_valid_number, '沖縄県南城市知念久原');
ok($zip->set_number('9011511')->is_valid_number, '沖縄県南城市知念久手堅');
ok($zip->set_number('9011512')->is_valid_number, '沖縄県南城市知念吉富');
ok($zip->set_number('9011513')->is_valid_number, '沖縄県南城市知念知念');
ok($zip->set_number('9011514')->is_valid_number, '沖縄県南城市知念具志堅');
ok($zip->set_number('9011515')->is_valid_number, '沖縄県南城市知念山里');
ok($zip->set_number('9011516')->is_valid_number, '沖縄県南城市知念志喜屋');
ok($zip->set_number('9012100')->is_valid_number, '沖縄県浦添市以下に掲載がない場合');
ok($zip->set_number('9012101')->is_valid_number, '沖縄県浦添市西原');
ok($zip->set_number('9012102')->is_valid_number, '沖縄県浦添市前田');
ok($zip->set_number('9012103')->is_valid_number, '沖縄県浦添市仲間');
ok($zip->set_number('9012104')->is_valid_number, '沖縄県浦添市当山');
ok($zip->set_number('9012111')->is_valid_number, '沖縄県浦添市経塚');
ok($zip->set_number('9012112')->is_valid_number, '沖縄県浦添市沢岻');
ok($zip->set_number('9012113')->is_valid_number, '沖縄県浦添市大平');
ok($zip->set_number('9012114')->is_valid_number, '沖縄県浦添市安波茶');
ok($zip->set_number('9012121')->is_valid_number, '沖縄県浦添市内間');
ok($zip->set_number('9012122')->is_valid_number, '沖縄県浦添市勢理客');
ok($zip->set_number('9012123')->is_valid_number, '沖縄県浦添市西洲');
ok($zip->set_number('9012124')->is_valid_number, '沖縄県浦添市小湾');
ok($zip->set_number('9012125')->is_valid_number, '沖縄県浦添市仲西');
ok($zip->set_number('9012126')->is_valid_number, '沖縄県浦添市宮城');
ok($zip->set_number('9012127')->is_valid_number, '沖縄県浦添市屋富祖');
ok($zip->set_number('9012128')->is_valid_number, '沖縄県浦添市伊奈武瀬');
ok($zip->set_number('9012131')->is_valid_number, '沖縄県浦添市牧港');
ok($zip->set_number('9012132')->is_valid_number, '沖縄県浦添市伊祖');
ok($zip->set_number('9012133')->is_valid_number, '沖縄県浦添市城間');
ok($zip->set_number('9012134')->is_valid_number, '沖縄県浦添市港川');
ok($zip->set_number('9012200')->is_valid_number, '沖縄県宜野湾市以下に掲載がない場合');
ok($zip->set_number('9012201')->is_valid_number, '沖縄県宜野湾市新城');
ok($zip->set_number('9012202')->is_valid_number, '沖縄県宜野湾市普天間');
ok($zip->set_number('9012203')->is_valid_number, '沖縄県宜野湾市野嵩');
ok($zip->set_number('9012204')->is_valid_number, '沖縄県宜野湾市上原');
ok($zip->set_number('9012205')->is_valid_number, '沖縄県宜野湾市赤道');
ok($zip->set_number('9012206')->is_valid_number, '沖縄県宜野湾市愛知');
ok($zip->set_number('9012207')->is_valid_number, '沖縄県宜野湾市神山');
ok($zip->set_number('9012211')->is_valid_number, '沖縄県宜野湾市宜野湾');
ok($zip->set_number('9012212')->is_valid_number, '沖縄県宜野湾市長田');
ok($zip->set_number('9012213')->is_valid_number, '沖縄県宜野湾市志真志');
ok($zip->set_number('9012214')->is_valid_number, '沖縄県宜野湾市我如古');
ok($zip->set_number('9012215')->is_valid_number, '沖縄県宜野湾市真栄原');
ok($zip->set_number('9012216')->is_valid_number, '沖縄県宜野湾市佐真下');
ok($zip->set_number('9012221')->is_valid_number, '沖縄県宜野湾市伊佐');
ok($zip->set_number('9012222')->is_valid_number, '沖縄県宜野湾市喜友名');
ok($zip->set_number('9012223')->is_valid_number, '沖縄県宜野湾市大山');
ok($zip->set_number('9012224')->is_valid_number, '沖縄県宜野湾市真志喜');
ok($zip->set_number('9012225')->is_valid_number, '沖縄県宜野湾市大謝名');
ok($zip->set_number('9012226')->is_valid_number, '沖縄県宜野湾市嘉数');
ok($zip->set_number('9012227')->is_valid_number, '沖縄県宜野湾市宇地泊');
ok($zip->set_number('9012300')->is_valid_number, '沖縄県中頭郡北中城村以下に掲載がない場合');
ok($zip->set_number('9012301')->is_valid_number, '沖縄県中頭郡北中城村島袋');
ok($zip->set_number('9012302')->is_valid_number, '沖縄県中頭郡北中城村渡口');
ok($zip->set_number('9012303')->is_valid_number, '沖縄県中頭郡北中城村仲順');
ok($zip->set_number('9012304')->is_valid_number, '沖縄県中頭郡北中城村屋宜原');
ok($zip->set_number('9012305')->is_valid_number, '沖縄県中頭郡北中城村比嘉');
ok($zip->set_number('9012306')->is_valid_number, '沖縄県中頭郡北中城村ライカム');
ok($zip->set_number('9012311')->is_valid_number, '沖縄県中頭郡北中城村喜舎場');
ok($zip->set_number('9012312')->is_valid_number, '沖縄県中頭郡北中城村和仁屋');
ok($zip->set_number('9012313')->is_valid_number, '沖縄県中頭郡北中城村熱田');
ok($zip->set_number('9012314')->is_valid_number, '沖縄県中頭郡北中城村大城');
ok($zip->set_number('9012315')->is_valid_number, '沖縄県中頭郡北中城村荻道');
ok($zip->set_number('9012316')->is_valid_number, '沖縄県中頭郡北中城村安谷屋');
ok($zip->set_number('9012317')->is_valid_number, '沖縄県中頭郡北中城村瑞慶覧');
ok($zip->set_number('9012321')->is_valid_number, '沖縄県中頭郡北中城村美崎');
ok($zip->set_number('9012400')->is_valid_number, '沖縄県中頭郡中城村以下に掲載がない場合');
ok($zip->set_number('9012401')->is_valid_number, '沖縄県中頭郡中城村久場');
ok($zip->set_number('9012402')->is_valid_number, '沖縄県中頭郡中城村泊');
ok($zip->set_number('9012403')->is_valid_number, '沖縄県中頭郡中城村伊舎堂');
ok($zip->set_number('9012404')->is_valid_number, '沖縄県中頭郡中城村添石');
ok($zip->set_number('9012405')->is_valid_number, '沖縄県中頭郡中城村屋宜');
ok($zip->set_number('9012406')->is_valid_number, '沖縄県中頭郡中城村当間');
ok($zip->set_number('9012407')->is_valid_number, '沖縄県中頭郡中城村安里');
ok($zip->set_number('9012411')->is_valid_number, '沖縄県中頭郡中城村浜');
ok($zip->set_number('9012412')->is_valid_number, '沖縄県中頭郡中城村奥間');
ok($zip->set_number('9012413')->is_valid_number, '沖縄県中頭郡中城村津覇');
ok($zip->set_number('9012414')->is_valid_number, '沖縄県中頭郡中城村北浜');
ok($zip->set_number('9012415')->is_valid_number, '沖縄県中頭郡中城村南浜');
ok($zip->set_number('9012416')->is_valid_number, '沖縄県中頭郡中城村和宇慶');
ok($zip->set_number('9012417')->is_valid_number, '沖縄県中頭郡中城村伊集');
ok($zip->set_number('9012421')->is_valid_number, '沖縄県中頭郡中城村登又');
ok($zip->set_number('9012422')->is_valid_number, '沖縄県中頭郡中城村新垣');
ok($zip->set_number('9012423')->is_valid_number, '沖縄県中頭郡中城村北上原');
ok($zip->set_number('9012424')->is_valid_number, '沖縄県中頭郡中城村南上原');
ok($zip->set_number('9013100')->is_valid_number, '沖縄県島尻郡久米島町以下に掲載がない場合');
ok($zip->set_number('9013101')->is_valid_number, '沖縄県島尻郡久米島町宇江城');
ok($zip->set_number('9013102')->is_valid_number, '沖縄県島尻郡久米島町比屋定');
ok($zip->set_number('9013103')->is_valid_number, '沖縄県島尻郡久米島町阿嘉');
ok($zip->set_number('9013104')->is_valid_number, '沖縄県島尻郡久米島町真謝');
ok($zip->set_number('9013105')->is_valid_number, '沖縄県島尻郡久米島町宇根');
ok($zip->set_number('9013106')->is_valid_number, '沖縄県島尻郡久米島町奥武');
ok($zip->set_number('9013107')->is_valid_number, '沖縄県島尻郡久米島町謝名堂');
ok($zip->set_number('9013108')->is_valid_number, '沖縄県島尻郡久米島町比嘉');
ok($zip->set_number('9013111')->is_valid_number, '沖縄県島尻郡久米島町山城');
ok($zip->set_number('9013112')->is_valid_number, '沖縄県島尻郡久米島町真我里');
ok($zip->set_number('9013113')->is_valid_number, '沖縄県島尻郡久米島町銭田');
ok($zip->set_number('9013114')->is_valid_number, '沖縄県島尻郡久米島町島尻');
ok($zip->set_number('9013115')->is_valid_number, '沖縄県島尻郡久米島町儀間');
ok($zip->set_number('9013121')->is_valid_number, '沖縄県島尻郡久米島町嘉手苅');
ok($zip->set_number('9013122')->is_valid_number, '沖縄県島尻郡久米島町兼城');
ok($zip->set_number('9013123')->is_valid_number, '沖縄県島尻郡久米島町大田');
ok($zip->set_number('9013124')->is_valid_number, '沖縄県島尻郡久米島町仲泊');
ok($zip->set_number('9013125')->is_valid_number, '沖縄県島尻郡久米島町鳥島');
ok($zip->set_number('9013131')->is_valid_number, '沖縄県島尻郡久米島町西銘');
ok($zip->set_number('9013132')->is_valid_number, '沖縄県島尻郡久米島町大原');
ok($zip->set_number('9013133')->is_valid_number, '沖縄県島尻郡久米島町北原');
ok($zip->set_number('9013134')->is_valid_number, '沖縄県島尻郡久米島町具志川');
ok($zip->set_number('9013135')->is_valid_number, '沖縄県島尻郡久米島町仲村渠');
ok($zip->set_number('9013136')->is_valid_number, '沖縄県島尻郡久米島町仲地');
ok($zip->set_number('9013137')->is_valid_number, '沖縄県島尻郡久米島町山里');
ok($zip->set_number('9013138')->is_valid_number, '沖縄県島尻郡久米島町上江洲');
ok($zip->set_number('9013311')->is_valid_number, '沖縄県島尻郡座間味村阿嘉');
ok($zip->set_number('9013312')->is_valid_number, '沖縄県島尻郡座間味村慶留間');
ok($zip->set_number('9013400')->is_valid_number, '沖縄県島尻郡座間味村以下に掲載がない場合');
ok($zip->set_number('9013401')->is_valid_number, '沖縄県島尻郡座間味村阿佐');
ok($zip->set_number('9013402')->is_valid_number, '沖縄県島尻郡座間味村座間味');
ok($zip->set_number('9013403')->is_valid_number, '沖縄県島尻郡座間味村阿真');
ok($zip->set_number('9013500')->is_valid_number, '沖縄県島尻郡渡嘉敷村以下に掲載がない場合');
ok($zip->set_number('9013501')->is_valid_number, '沖縄県島尻郡渡嘉敷村渡嘉敷');
ok($zip->set_number('9013502')->is_valid_number, '沖縄県島尻郡渡嘉敷村阿波連');
ok($zip->set_number('9013601')->is_valid_number, '沖縄県島尻郡渡名喜村渡名喜村一円');
ok($zip->set_number('9013700')->is_valid_number, '沖縄県島尻郡粟国村以下に掲載がない場合');
ok($zip->set_number('9013701')->is_valid_number, '沖縄県島尻郡粟国村浜');
ok($zip->set_number('9013702')->is_valid_number, '沖縄県島尻郡粟国村東');
ok($zip->set_number('9013703')->is_valid_number, '沖縄県島尻郡粟国村西');
ok($zip->set_number('9013800')->is_valid_number, '沖縄県島尻郡南大東村以下に掲載がない場合');
ok($zip->set_number('9013801')->is_valid_number, '沖縄県島尻郡南大東村北');
ok($zip->set_number('9013802')->is_valid_number, '沖縄県島尻郡南大東村新東');
ok($zip->set_number('9013803')->is_valid_number, '沖縄県島尻郡南大東村旧東');
ok($zip->set_number('9013804')->is_valid_number, '沖縄県島尻郡南大東村南');
ok($zip->set_number('9013805')->is_valid_number, '沖縄県島尻郡南大東村在所');
ok($zip->set_number('9013806')->is_valid_number, '沖縄県島尻郡南大東村池之沢');
ok($zip->set_number('9013900')->is_valid_number, '沖縄県島尻郡北大東村以下に掲載がない場合');
ok($zip->set_number('9013901')->is_valid_number, '沖縄県島尻郡北大東村南');
ok($zip->set_number('9013902')->is_valid_number, '沖縄県島尻郡北大東村中野');
ok($zip->set_number('9013903')->is_valid_number, '沖縄県島尻郡北大東村港');
ok($zip->set_number('9020061')->is_valid_number, '沖縄県那覇市古島');
ok($zip->set_number('9020062')->is_valid_number, '沖縄県那覇市松川');
ok($zip->set_number('9020063')->is_valid_number, '沖縄県那覇市三原');
ok($zip->set_number('9020064')->is_valid_number, '沖縄県那覇市寄宮');
ok($zip->set_number('9020065')->is_valid_number, '沖縄県那覇市壺屋');
ok($zip->set_number('9020066')->is_valid_number, '沖縄県那覇市大道');
ok($zip->set_number('9020067')->is_valid_number, '沖縄県那覇市安里');
ok($zip->set_number('9020068')->is_valid_number, '沖縄県那覇市真嘉比');
ok($zip->set_number('9020069')->is_valid_number, '沖縄県那覇市松島');
ok($zip->set_number('9020071')->is_valid_number, '沖縄県那覇市繁多川');
ok($zip->set_number('9020072')->is_valid_number, '沖縄県那覇市真地');
ok($zip->set_number('9020073')->is_valid_number, '沖縄県那覇市上間');
ok($zip->set_number('9020074')->is_valid_number, '沖縄県那覇市仲井真');
ok($zip->set_number('9020075')->is_valid_number, '沖縄県那覇市国場');
ok($zip->set_number('9020076')->is_valid_number, '沖縄県那覇市与儀');
ok($zip->set_number('9020077')->is_valid_number, '沖縄県那覇市長田');
ok($zip->set_number('9020078')->is_valid_number, '沖縄県那覇市識名');
ok($zip->set_number('9030100')->is_valid_number, '沖縄県中頭郡西原町以下に掲載がない場合');
ok($zip->set_number('9030101')->is_valid_number, '沖縄県中頭郡西原町掛保久');
ok($zip->set_number('9030102')->is_valid_number, '沖縄県中頭郡西原町嘉手苅');
ok($zip->set_number('9030103')->is_valid_number, '沖縄県中頭郡西原町小那覇');
ok($zip->set_number('9030104')->is_valid_number, '沖縄県中頭郡西原町兼久');
ok($zip->set_number('9030105')->is_valid_number, '沖縄県中頭郡西原町東崎');
ok($zip->set_number('9030111')->is_valid_number, '沖縄県中頭郡西原町与那城');
ok($zip->set_number('9030112')->is_valid_number, '沖縄県中頭郡西原町我謝');
ok($zip->set_number('9030113')->is_valid_number, '沖縄県中頭郡西原町安室');
ok($zip->set_number('9030114')->is_valid_number, '沖縄県中頭郡西原町桃原');
ok($zip->set_number('9030115')->is_valid_number, '沖縄県中頭郡西原町池田');
ok($zip->set_number('9030116')->is_valid_number, '沖縄県中頭郡西原町幸地');
ok($zip->set_number('9030117')->is_valid_number, '沖縄県中頭郡西原町翁長');
ok($zip->set_number('9030118')->is_valid_number, '沖縄県中頭郡西原町小波津');
ok($zip->set_number('9030121')->is_valid_number, '沖縄県中頭郡西原町内間');
ok($zip->set_number('9030122')->is_valid_number, '沖縄県中頭郡西原町小橋川');
ok($zip->set_number('9030123')->is_valid_number, '沖縄県中頭郡西原町津花波');
ok($zip->set_number('9030124')->is_valid_number, '沖縄県中頭郡西原町呉屋');
ok($zip->set_number('9030125')->is_valid_number, '沖縄県中頭郡西原町上原');
ok($zip->set_number('9030126')->is_valid_number, '沖縄県中頭郡西原町棚原');
ok($zip->set_number('9030127')->is_valid_number, '沖縄県中頭郡西原町徳佐田');
ok($zip->set_number('9030128')->is_valid_number, '沖縄県中頭郡西原町森川');
ok($zip->set_number('9030129')->is_valid_number, '沖縄県中頭郡西原町千原');
ok($zip->set_number('9030801')->is_valid_number, '沖縄県那覇市首里末吉町');
ok($zip->set_number('9030802')->is_valid_number, '沖縄県那覇市首里大名町');
ok($zip->set_number('9030803')->is_valid_number, '沖縄県那覇市首里平良町');
ok($zip->set_number('9030804')->is_valid_number, '沖縄県那覇市首里石嶺町');
ok($zip->set_number('9030805')->is_valid_number, '沖縄県那覇市首里鳥堀町');
ok($zip->set_number('9030806')->is_valid_number, '沖縄県那覇市首里汀良町');
ok($zip->set_number('9030807')->is_valid_number, '沖縄県那覇市首里久場川町');
ok($zip->set_number('9030811')->is_valid_number, '沖縄県那覇市首里赤平町');
ok($zip->set_number('9030812')->is_valid_number, '沖縄県那覇市首里当蔵町');
ok($zip->set_number('9030813')->is_valid_number, '沖縄県那覇市首里赤田町');
ok($zip->set_number('9030814')->is_valid_number, '沖縄県那覇市首里崎山町');
ok($zip->set_number('9030815')->is_valid_number, '沖縄県那覇市首里金城町');
ok($zip->set_number('9030816')->is_valid_number, '沖縄県那覇市首里真和志町');
ok($zip->set_number('9030821')->is_valid_number, '沖縄県那覇市首里儀保町');
ok($zip->set_number('9030822')->is_valid_number, '沖縄県那覇市首里桃原町');
ok($zip->set_number('9030823')->is_valid_number, '沖縄県那覇市首里大中町');
ok($zip->set_number('9030824')->is_valid_number, '沖縄県那覇市首里池端町');
ok($zip->set_number('9030825')->is_valid_number, '沖縄県那覇市首里山川町');
ok($zip->set_number('9030826')->is_valid_number, '沖縄県那覇市首里寒川町');
ok($zip->set_number('9040000')->is_valid_number, '沖縄県沖縄市以下に掲載がない場合');
ok($zip->set_number('9040001')->is_valid_number, '沖縄県沖縄市越来');
ok($zip->set_number('9040002')->is_valid_number, '沖縄県沖縄市城前町');
ok($zip->set_number('9040003')->is_valid_number, '沖縄県沖縄市住吉');
ok($zip->set_number('9040004')->is_valid_number, '沖縄県沖縄市中央');
ok($zip->set_number('9040005')->is_valid_number, '沖縄県沖縄市嘉間良');
ok($zip->set_number('9040006')->is_valid_number, '沖縄県沖縄市八重島');
ok($zip->set_number('9040011')->is_valid_number, '沖縄県沖縄市照屋');
ok($zip->set_number('9040012')->is_valid_number, '沖縄県沖縄市安慶田');
ok($zip->set_number('9040013')->is_valid_number, '沖縄県沖縄市室川');
ok($zip->set_number('9040014')->is_valid_number, '沖縄県沖縄市仲宗根町');
ok($zip->set_number('9040021')->is_valid_number, '沖縄県沖縄市胡屋');
ok($zip->set_number('9040022')->is_valid_number, '沖縄県沖縄市園田');
ok($zip->set_number('9040023')->is_valid_number, '沖縄県沖縄市久保田');
ok($zip->set_number('9040031')->is_valid_number, '沖縄県沖縄市上地');
ok($zip->set_number('9040032')->is_valid_number, '沖縄県沖縄市諸見里');
ok($zip->set_number('9040033')->is_valid_number, '沖縄県沖縄市山里');
ok($zip->set_number('9040034')->is_valid_number, '沖縄県沖縄市山内');
ok($zip->set_number('9040035')->is_valid_number, '沖縄県沖縄市南桃原');
ok($zip->set_number('9040100')->is_valid_number, '沖縄県中頭郡北谷町以下に掲載がない場合');
ok($zip->set_number('9040101')->is_valid_number, '沖縄県中頭郡北谷町上勢頭');
ok($zip->set_number('9040102')->is_valid_number, '沖縄県中頭郡北谷町伊平');
ok($zip->set_number('9040103')->is_valid_number, '沖縄県中頭郡北谷町桑江');
ok($zip->set_number('9040104')->is_valid_number, '沖縄県中頭郡北谷町桃原');
ok($zip->set_number('9040105')->is_valid_number, '沖縄県中頭郡北谷町吉原');
ok($zip->set_number('9040106')->is_valid_number, '沖縄県中頭郡北谷町玉上');
ok($zip->set_number('9040107')->is_valid_number, '沖縄県中頭郡北谷町大村');
ok($zip->set_number('9040111')->is_valid_number, '沖縄県中頭郡北谷町砂辺');
ok($zip->set_number('9040112')->is_valid_number, '沖縄県中頭郡北谷町浜川');
ok($zip->set_number('9040113')->is_valid_number, '沖縄県中頭郡北谷町宮城');
ok($zip->set_number('9040114')->is_valid_number, '沖縄県中頭郡北谷町港');
ok($zip->set_number('9040115')->is_valid_number, '沖縄県中頭郡北谷町美浜');
ok($zip->set_number('9040116')->is_valid_number, '沖縄県中頭郡北谷町北谷');
ok($zip->set_number('9040117')->is_valid_number, '沖縄県中頭郡北谷町北前');
ok($zip->set_number('9040200')->is_valid_number, '沖縄県中頭郡嘉手納町以下に掲載がない場合');
ok($zip->set_number('9040201')->is_valid_number, '沖縄県中頭郡嘉手納町久得');
ok($zip->set_number('9040202')->is_valid_number, '沖縄県中頭郡嘉手納町屋良');
ok($zip->set_number('9040203')->is_valid_number, '沖縄県中頭郡嘉手納町嘉手納');
ok($zip->set_number('9040204')->is_valid_number, '沖縄県中頭郡嘉手納町水釜');
ok($zip->set_number('9040205')->is_valid_number, '沖縄県中頭郡嘉手納町兼久');
ok($zip->set_number('9040300')->is_valid_number, '沖縄県中頭郡読谷村以下に掲載がない場合');
ok($zip->set_number('9040301')->is_valid_number, '沖縄県中頭郡読谷村座喜味');
ok($zip->set_number('9040302')->is_valid_number, '沖縄県中頭郡読谷村喜名');
ok($zip->set_number('9040303')->is_valid_number, '沖縄県中頭郡読谷村伊良皆');
ok($zip->set_number('9040304')->is_valid_number, '沖縄県中頭郡読谷村楚辺');
ok($zip->set_number('9040305')->is_valid_number, '沖縄県中頭郡読谷村都屋');
ok($zip->set_number('9040311')->is_valid_number, '沖縄県中頭郡読谷村比謝');
ok($zip->set_number('9040312')->is_valid_number, '沖縄県中頭郡読谷村比謝矼');
ok($zip->set_number('9040313')->is_valid_number, '沖縄県中頭郡読谷村大湾');
ok($zip->set_number('9040314')->is_valid_number, '沖縄県中頭郡読谷村古堅');
ok($zip->set_number('9040315')->is_valid_number, '沖縄県中頭郡読谷村渡具知');
ok($zip->set_number('9040316')->is_valid_number, '沖縄県中頭郡読谷村大木');
ok($zip->set_number('9040321')->is_valid_number, '沖縄県中頭郡読谷村上地');
ok($zip->set_number('9040322')->is_valid_number, '沖縄県中頭郡読谷村波平');
ok($zip->set_number('9040323')->is_valid_number, '沖縄県中頭郡読谷村高志保');
ok($zip->set_number('9040324')->is_valid_number, '沖縄県中頭郡読谷村長浜');
ok($zip->set_number('9040325')->is_valid_number, '沖縄県中頭郡読谷村瀬名波');
ok($zip->set_number('9040326')->is_valid_number, '沖縄県中頭郡読谷村渡慶次');
ok($zip->set_number('9040327')->is_valid_number, '沖縄県中頭郡読谷村儀間');
ok($zip->set_number('9040328')->is_valid_number, '沖縄県中頭郡読谷村宇座');
ok($zip->set_number('9040400')->is_valid_number, '沖縄県国頭郡恩納村以下に掲載がない場合');
ok($zip->set_number('9040401')->is_valid_number, '沖縄県国頭郡恩納村名嘉真');
ok($zip->set_number('9040402')->is_valid_number, '沖縄県国頭郡恩納村安富祖');
ok($zip->set_number('9040403')->is_valid_number, '沖縄県国頭郡恩納村喜瀬武原');
ok($zip->set_number('9040404')->is_valid_number, '沖縄県国頭郡恩納村瀬良垣');
ok($zip->set_number('9040411')->is_valid_number, '沖縄県国頭郡恩納村恩納');
ok($zip->set_number('9040412')->is_valid_number, '沖縄県国頭郡恩納村谷茶');
ok($zip->set_number('9040413')->is_valid_number, '沖縄県国頭郡恩納村冨着');
ok($zip->set_number('9040414')->is_valid_number, '沖縄県国頭郡恩納村前兼久');
ok($zip->set_number('9040415')->is_valid_number, '沖縄県国頭郡恩納村仲泊');
ok($zip->set_number('9040416')->is_valid_number, '沖縄県国頭郡恩納村山田');
ok($zip->set_number('9040417')->is_valid_number, '沖縄県国頭郡恩納村真栄田');
ok($zip->set_number('9041101')->is_valid_number, '沖縄県うるま市石川東山本町');
ok($zip->set_number('9041102')->is_valid_number, '沖縄県うるま市石川東山');
ok($zip->set_number('9041103')->is_valid_number, '沖縄県うるま市石川赤崎');
ok($zip->set_number('9041104')->is_valid_number, '沖縄県うるま市石川石崎');
ok($zip->set_number('9041105')->is_valid_number, '沖縄県うるま市石川白浜');
ok($zip->set_number('9041106')->is_valid_number, '沖縄県うるま市石川');
ok($zip->set_number('9041107')->is_valid_number, '沖縄県うるま市石川曙');
ok($zip->set_number('9041108')->is_valid_number, '沖縄県うるま市石川東恩納崎');
ok($zip->set_number('9041111')->is_valid_number, '沖縄県うるま市石川東恩納');
ok($zip->set_number('9041112')->is_valid_number, '沖縄県うるま市石川楚南');
ok($zip->set_number('9041113')->is_valid_number, '沖縄県うるま市石川山城');
ok($zip->set_number('9041114')->is_valid_number, '沖縄県うるま市石川嘉手苅');
ok($zip->set_number('9041115')->is_valid_number, '沖縄県うるま市石川伊波');
ok($zip->set_number('9041200')->is_valid_number, '沖縄県国頭郡金武町以下に掲載がない場合');
ok($zip->set_number('9041201')->is_valid_number, '沖縄県国頭郡金武町金武');
ok($zip->set_number('9041202')->is_valid_number, '沖縄県国頭郡金武町伊芸');
ok($zip->set_number('9041203')->is_valid_number, '沖縄県国頭郡金武町屋嘉');
ok($zip->set_number('9041300')->is_valid_number, '沖縄県国頭郡宜野座村以下に掲載がない場合');
ok($zip->set_number('9041301')->is_valid_number, '沖縄県国頭郡宜野座村松田');
ok($zip->set_number('9041302')->is_valid_number, '沖縄県国頭郡宜野座村宜野座');
ok($zip->set_number('9041303')->is_valid_number, '沖縄県国頭郡宜野座村惣慶');
ok($zip->set_number('9041304')->is_valid_number, '沖縄県国頭郡宜野座村漢那');
ok($zip->set_number('9042141')->is_valid_number, '沖縄県沖縄市池原');
ok($zip->set_number('9042142')->is_valid_number, '沖縄県沖縄市登川');
ok($zip->set_number('9042143')->is_valid_number, '沖縄県沖縄市知花');
ok($zip->set_number('9042144')->is_valid_number, '沖縄県沖縄市白川');
ok($zip->set_number('9042145')->is_valid_number, '沖縄県沖縄市倉敷');
ok($zip->set_number('9042151')->is_valid_number, '沖縄県沖縄市松本');
ok($zip->set_number('9042152')->is_valid_number, '沖縄県沖縄市明道');
ok($zip->set_number('9042153')->is_valid_number, '沖縄県沖縄市美里');
ok($zip->set_number('9042154')->is_valid_number, '沖縄県沖縄市東');
ok($zip->set_number('9042155')->is_valid_number, '沖縄県沖縄市美原');
ok($zip->set_number('9042156')->is_valid_number, '沖縄県沖縄市美里仲原町');
ok($zip->set_number('9042161')->is_valid_number, '沖縄県沖縄市古謝');
ok($zip->set_number('9042162')->is_valid_number, '沖縄県沖縄市海邦');
ok($zip->set_number('9042162')->is_valid_number, '沖縄県沖縄市海邦町');
ok($zip->set_number('9042163')->is_valid_number, '沖縄県沖縄市大里');
ok($zip->set_number('9042164')->is_valid_number, '沖縄県沖縄市桃原');
ok($zip->set_number('9042165')->is_valid_number, '沖縄県沖縄市宮里');
ok($zip->set_number('9042166')->is_valid_number, '沖縄県沖縄市古謝津嘉山町');
ok($zip->set_number('9042171')->is_valid_number, '沖縄県沖縄市高原');
ok($zip->set_number('9042172')->is_valid_number, '沖縄県沖縄市泡瀬');
ok($zip->set_number('9042173')->is_valid_number, '沖縄県沖縄市比屋根');
ok($zip->set_number('9042174')->is_valid_number, '沖縄県沖縄市与儀');
ok($zip->set_number('9042175')->is_valid_number, '沖縄県沖縄市潮乃森');
ok($zip->set_number('9042200')->is_valid_number, '沖縄県うるま市以下に掲載がない場合');
ok($zip->set_number('9042201')->is_valid_number, '沖縄県うるま市昆布');
ok($zip->set_number('9042202')->is_valid_number, '沖縄県うるま市天願');
ok($zip->set_number('9042203')->is_valid_number, '沖縄県うるま市川崎');
ok($zip->set_number('9042204')->is_valid_number, '沖縄県うるま市西原');
ok($zip->set_number('9042205')->is_valid_number, '沖縄県うるま市栄野比');
ok($zip->set_number('9042211')->is_valid_number, '沖縄県うるま市宇堅');
ok($zip->set_number('9042212')->is_valid_number, '沖縄県うるま市赤野');
ok($zip->set_number('9042213')->is_valid_number, '沖縄県うるま市田場');
ok($zip->set_number('9042214')->is_valid_number, '沖縄県うるま市安慶名');
ok($zip->set_number('9042215')->is_valid_number, '沖縄県うるま市みどり町');
ok($zip->set_number('9042221')->is_valid_number, '沖縄県うるま市平良川');
ok($zip->set_number('9042222')->is_valid_number, '沖縄県うるま市上江洲');
ok($zip->set_number('9042223')->is_valid_number, '沖縄県うるま市具志川');
ok($zip->set_number('9042224')->is_valid_number, '沖縄県うるま市大田');
ok($zip->set_number('9042225')->is_valid_number, '沖縄県うるま市喜屋武');
ok($zip->set_number('9042226')->is_valid_number, '沖縄県うるま市仲嶺');
ok($zip->set_number('9042231')->is_valid_number, '沖縄県うるま市塩屋');
ok($zip->set_number('9042232')->is_valid_number, '沖縄県うるま市川田');
ok($zip->set_number('9042233')->is_valid_number, '沖縄県うるま市豊原');
ok($zip->set_number('9042234')->is_valid_number, '沖縄県うるま市州崎');
ok($zip->set_number('9042235')->is_valid_number, '沖縄県うるま市前原');
ok($zip->set_number('9042236')->is_valid_number, '沖縄県うるま市喜仲');
ok($zip->set_number('9042241')->is_valid_number, '沖縄県うるま市兼箇段');
ok($zip->set_number('9042242')->is_valid_number, '沖縄県うるま市高江洲');
ok($zip->set_number('9042243')->is_valid_number, '沖縄県うるま市宮里');
ok($zip->set_number('9042244')->is_valid_number, '沖縄県うるま市江洲');
ok($zip->set_number('9042245')->is_valid_number, '沖縄県うるま市赤道');
ok($zip->set_number('9042301')->is_valid_number, '沖縄県うるま市与那城照間');
ok($zip->set_number('9042302')->is_valid_number, '沖縄県うるま市与那城西原');
ok($zip->set_number('9042303')->is_valid_number, '沖縄県うるま市与那城');
ok($zip->set_number('9042304')->is_valid_number, '沖縄県うるま市与那城屋慶名');
ok($zip->set_number('9042305')->is_valid_number, '沖縄県うるま市与那城中央');
ok($zip->set_number('9042306')->is_valid_number, '沖縄県うるま市与那城安勢理');
ok($zip->set_number('9042307')->is_valid_number, '沖縄県うるま市与那城饒辺');
ok($zip->set_number('9042311')->is_valid_number, '沖縄県うるま市勝連南風原');
ok($zip->set_number('9042312')->is_valid_number, '沖縄県うるま市勝連平安名');
ok($zip->set_number('9042313')->is_valid_number, '沖縄県うるま市勝連内間');
ok($zip->set_number('9042314')->is_valid_number, '沖縄県うるま市勝連平敷屋');
ok($zip->set_number('9042315')->is_valid_number, '沖縄県うるま市勝連浜');
ok($zip->set_number('9042316')->is_valid_number, '沖縄県うるま市勝連比嘉');
ok($zip->set_number('9042317')->is_valid_number, '沖縄県うるま市勝連津堅');
ok($zip->set_number('9042421')->is_valid_number, '沖縄県うるま市与那城伊計');
ok($zip->set_number('9042422')->is_valid_number, '沖縄県うるま市与那城池味');
ok($zip->set_number('9042423')->is_valid_number, '沖縄県うるま市与那城宮城');
ok($zip->set_number('9042424')->is_valid_number, '沖縄県うるま市与那城上原');
ok($zip->set_number('9042425')->is_valid_number, '沖縄県うるま市与那城桃原');
ok($zip->set_number('9042426')->is_valid_number, '沖縄県うるま市与那城平安座');
ok($zip->set_number('9042427')->is_valid_number, '沖縄県うるま市与那城屋平');
ok($zip->set_number('9042428')->is_valid_number, '沖縄県うるま市与那城平宮');
ok($zip->set_number('9050000')->is_valid_number, '沖縄県名護市以下に掲載がない場合');
ok($zip->set_number('9050001')->is_valid_number, '沖縄県名護市安和');
ok($zip->set_number('9050002')->is_valid_number, '沖縄県名護市勝山');
ok($zip->set_number('9050003')->is_valid_number, '沖縄県名護市旭川');
ok($zip->set_number('9050004')->is_valid_number, '沖縄県名護市中山');
ok($zip->set_number('9050005')->is_valid_number, '沖縄県名護市為又');
ok($zip->set_number('9050006')->is_valid_number, '沖縄県名護市宇茂佐');
ok($zip->set_number('9050007')->is_valid_number, '沖縄県名護市屋部');
ok($zip->set_number('9050008')->is_valid_number, '沖縄県名護市山入端');
ok($zip->set_number('9050009')->is_valid_number, '沖縄県名護市宇茂佐の森');
ok($zip->set_number('9050011')->is_valid_number, '沖縄県名護市宮里');
ok($zip->set_number('9050012')->is_valid_number, '沖縄県名護市名護');
ok($zip->set_number('9050013')->is_valid_number, '沖縄県名護市城');
ok($zip->set_number('9050014')->is_valid_number, '沖縄県名護市港');
ok($zip->set_number('9050015')->is_valid_number, '沖縄県名護市大南');
ok($zip->set_number('9050016')->is_valid_number, '沖縄県名護市大東');
ok($zip->set_number('9050017')->is_valid_number, '沖縄県名護市大中');
ok($zip->set_number('9050018')->is_valid_number, '沖縄県名護市大西');
ok($zip->set_number('9050019')->is_valid_number, '沖縄県名護市大北');
ok($zip->set_number('9050021')->is_valid_number, '沖縄県名護市東江');
ok($zip->set_number('9050022')->is_valid_number, '沖縄県名護市世冨慶');
ok($zip->set_number('9050023')->is_valid_number, '沖縄県名護市数久田');
ok($zip->set_number('9050024')->is_valid_number, '沖縄県名護市許田');
ok($zip->set_number('9050025')->is_valid_number, '沖縄県名護市幸喜');
ok($zip->set_number('9050026')->is_valid_number, '沖縄県名護市喜瀬');
ok($zip->set_number('9050200')->is_valid_number, '沖縄県国頭郡本部町以下に掲載がない場合');
ok($zip->set_number('9050201')->is_valid_number, '沖縄県国頭郡本部町具志堅');
ok($zip->set_number('9050202')->is_valid_number, '沖縄県国頭郡本部町嘉津宇');
ok($zip->set_number('9050203')->is_valid_number, '沖縄県国頭郡本部町謝花');
ok($zip->set_number('9050204')->is_valid_number, '沖縄県国頭郡本部町豊原');
ok($zip->set_number('9050205')->is_valid_number, '沖縄県国頭郡本部町山川');
ok($zip->set_number('9050206')->is_valid_number, '沖縄県国頭郡本部町石川');
ok($zip->set_number('9050207')->is_valid_number, '沖縄県国頭郡本部町備瀬');
ok($zip->set_number('9050208')->is_valid_number, '沖縄県国頭郡本部町新里');
ok($zip->set_number('9050209')->is_valid_number, '沖縄県国頭郡本部町北里');
ok($zip->set_number('9050211')->is_valid_number, '沖縄県国頭郡本部町東');
ok($zip->set_number('9050212')->is_valid_number, '沖縄県国頭郡本部町大浜');
ok($zip->set_number('9050213')->is_valid_number, '沖縄県国頭郡本部町谷茶');
ok($zip->set_number('9050214')->is_valid_number, '沖縄県国頭郡本部町渡久地');
ok($zip->set_number('9050215')->is_valid_number, '沖縄県国頭郡本部町野原');
ok($zip->set_number('9050216')->is_valid_number, '沖縄県国頭郡本部町浜元');
ok($zip->set_number('9050217')->is_valid_number, '沖縄県国頭郡本部町浦崎');
ok($zip->set_number('9050218')->is_valid_number, '沖縄県国頭郡本部町古島');
ok($zip->set_number('9050219')->is_valid_number, '沖縄県国頭郡本部町山里');
ok($zip->set_number('9050221')->is_valid_number, '沖縄県国頭郡本部町伊豆味');
ok($zip->set_number('9050222')->is_valid_number, '沖縄県国頭郡本部町並里');
ok($zip->set_number('9050223')->is_valid_number, '沖縄県国頭郡本部町大嘉陽');
ok($zip->set_number('9050224')->is_valid_number, '沖縄県国頭郡本部町辺名地');
ok($zip->set_number('9050225')->is_valid_number, '沖縄県国頭郡本部町崎本部');
ok($zip->set_number('9050226')->is_valid_number, '沖縄県国頭郡本部町健堅');
ok($zip->set_number('9050227')->is_valid_number, '沖縄県国頭郡本部町瀬底');
ok($zip->set_number('9050228')->is_valid_number, '沖縄県国頭郡本部町伊野波');
ok($zip->set_number('9050229')->is_valid_number, '沖縄県国頭郡本部町大堂');
ok($zip->set_number('9050400')->is_valid_number, '沖縄県国頭郡今帰仁村以下に掲載がない場合');
ok($zip->set_number('9050401')->is_valid_number, '沖縄県国頭郡今帰仁村仲宗根');
ok($zip->set_number('9050402')->is_valid_number, '沖縄県国頭郡今帰仁村渡喜仁');
ok($zip->set_number('9050403')->is_valid_number, '沖縄県国頭郡今帰仁村運天');
ok($zip->set_number('9050404')->is_valid_number, '沖縄県国頭郡今帰仁村上運天');
ok($zip->set_number('9050405')->is_valid_number, '沖縄県国頭郡今帰仁村勢理客');
ok($zip->set_number('9050406')->is_valid_number, '沖縄県国頭郡今帰仁村古宇利');
ok($zip->set_number('9050411')->is_valid_number, '沖縄県国頭郡今帰仁村天底');
ok($zip->set_number('9050412')->is_valid_number, '沖縄県国頭郡今帰仁村湧川');
ok($zip->set_number('9050413')->is_valid_number, '沖縄県国頭郡今帰仁村呉我山');
ok($zip->set_number('9050414')->is_valid_number, '沖縄県国頭郡今帰仁村謝名');
ok($zip->set_number('9050415')->is_valid_number, '沖縄県国頭郡今帰仁村玉城');
ok($zip->set_number('9050421')->is_valid_number, '沖縄県国頭郡今帰仁村越地');
ok($zip->set_number('9050422')->is_valid_number, '沖縄県国頭郡今帰仁村崎山');
ok($zip->set_number('9050423')->is_valid_number, '沖縄県国頭郡今帰仁村平敷');
ok($zip->set_number('9050424')->is_valid_number, '沖縄県国頭郡今帰仁村仲尾次');
ok($zip->set_number('9050425')->is_valid_number, '沖縄県国頭郡今帰仁村与那嶺');
ok($zip->set_number('9050426')->is_valid_number, '沖縄県国頭郡今帰仁村諸志');
ok($zip->set_number('9050427')->is_valid_number, '沖縄県国頭郡今帰仁村兼次');
ok($zip->set_number('9050428')->is_valid_number, '沖縄県国頭郡今帰仁村今泊');
ok($zip->set_number('9050500')->is_valid_number, '沖縄県国頭郡伊江村以下に掲載がない場合');
ok($zip->set_number('9050501')->is_valid_number, '沖縄県国頭郡伊江村東江上');
ok($zip->set_number('9050502')->is_valid_number, '沖縄県国頭郡伊江村東江前');
ok($zip->set_number('9050503')->is_valid_number, '沖縄県国頭郡伊江村川平');
ok($zip->set_number('9050504')->is_valid_number, '沖縄県国頭郡伊江村西江前');
ok($zip->set_number('9050505')->is_valid_number, '沖縄県国頭郡伊江村西江上');
ok($zip->set_number('9050600')->is_valid_number, '沖縄県島尻郡伊是名村以下に掲載がない場合');
ok($zip->set_number('9050601')->is_valid_number, '沖縄県島尻郡伊是名村内花');
ok($zip->set_number('9050602')->is_valid_number, '沖縄県島尻郡伊是名村諸見');
ok($zip->set_number('9050603')->is_valid_number, '沖縄県島尻郡伊是名村仲田');
ok($zip->set_number('9050604')->is_valid_number, '沖縄県島尻郡伊是名村伊是名');
ok($zip->set_number('9050605')->is_valid_number, '沖縄県島尻郡伊是名村勢理客');
ok($zip->set_number('9050700')->is_valid_number, '沖縄県島尻郡伊平屋村以下に掲載がない場合');
ok($zip->set_number('9050701')->is_valid_number, '沖縄県島尻郡伊平屋村田名');
ok($zip->set_number('9050702')->is_valid_number, '沖縄県島尻郡伊平屋村前泊');
ok($zip->set_number('9050703')->is_valid_number, '沖縄県島尻郡伊平屋村我喜屋');
ok($zip->set_number('9050704')->is_valid_number, '沖縄県島尻郡伊平屋村島尻');
ok($zip->set_number('9050705')->is_valid_number, '沖縄県島尻郡伊平屋村野甫');
ok($zip->set_number('9051141')->is_valid_number, '沖縄県名護市源河');
ok($zip->set_number('9051142')->is_valid_number, '沖縄県名護市稲嶺');
ok($zip->set_number('9051143')->is_valid_number, '沖縄県名護市真喜屋');
ok($zip->set_number('9051144')->is_valid_number, '沖縄県名護市仲尾次');
ok($zip->set_number('9051145')->is_valid_number, '沖縄県名護市川上');
ok($zip->set_number('9051146')->is_valid_number, '沖縄県名護市親川');
ok($zip->set_number('9051147')->is_valid_number, '沖縄県名護市田井等');
ok($zip->set_number('9051151')->is_valid_number, '沖縄県名護市振慶名');
ok($zip->set_number('9051152')->is_valid_number, '沖縄県名護市伊差川');
ok($zip->set_number('9051153')->is_valid_number, '沖縄県名護市仲尾');
ok($zip->set_number('9051154')->is_valid_number, '沖縄県名護市呉我');
ok($zip->set_number('9051155')->is_valid_number, '沖縄県名護市我部祖河');
ok($zip->set_number('9051156')->is_valid_number, '沖縄県名護市古我知');
ok($zip->set_number('9051200')->is_valid_number, '沖縄県国頭郡東村以下に掲載がない場合');
ok($zip->set_number('9051201')->is_valid_number, '沖縄県国頭郡東村高江');
ok($zip->set_number('9051202')->is_valid_number, '沖縄県国頭郡東村宮城');
ok($zip->set_number('9051203')->is_valid_number, '沖縄県国頭郡東村川田');
ok($zip->set_number('9051204')->is_valid_number, '沖縄県国頭郡東村平良');
ok($zip->set_number('9051205')->is_valid_number, '沖縄県国頭郡東村慶佐次');
ok($zip->set_number('9051206')->is_valid_number, '沖縄県国頭郡東村有銘');
ok($zip->set_number('9051300')->is_valid_number, '沖縄県国頭郡大宜味村以下に掲載がない場合');
ok($zip->set_number('9051301')->is_valid_number, '沖縄県国頭郡大宜味村田嘉里');
ok($zip->set_number('9051302')->is_valid_number, '沖縄県国頭郡大宜味村謝名城');
ok($zip->set_number('9051303')->is_valid_number, '沖縄県国頭郡大宜味村喜如嘉');
ok($zip->set_number('9051304')->is_valid_number, '沖縄県国頭郡大宜味村饒波');
ok($zip->set_number('9051305')->is_valid_number, '沖縄県国頭郡大宜味村大兼久');
ok($zip->set_number('9051306')->is_valid_number, '沖縄県国頭郡大宜味村大宜味');
ok($zip->set_number('9051307')->is_valid_number, '沖縄県国頭郡大宜味村根路銘');
ok($zip->set_number('9051308')->is_valid_number, '沖縄県国頭郡大宜味村上原');
ok($zip->set_number('9051311')->is_valid_number, '沖縄県国頭郡大宜味村塩屋');
ok($zip->set_number('9051312')->is_valid_number, '沖縄県国頭郡大宜味村屋古');
ok($zip->set_number('9051313')->is_valid_number, '沖縄県国頭郡大宜味村押川');
ok($zip->set_number('9051314')->is_valid_number, '沖縄県国頭郡大宜味村田港');
ok($zip->set_number('9051315')->is_valid_number, '沖縄県国頭郡大宜味村大保');
ok($zip->set_number('9051316')->is_valid_number, '沖縄県国頭郡大宜味村白浜');
ok($zip->set_number('9051317')->is_valid_number, '沖縄県国頭郡大宜味村江洲');
ok($zip->set_number('9051318')->is_valid_number, '沖縄県国頭郡大宜味村津波');
ok($zip->set_number('9051319')->is_valid_number, '沖縄県国頭郡大宜味村宮城');
ok($zip->set_number('9051400')->is_valid_number, '沖縄県国頭郡国頭村以下に掲載がない場合');
ok($zip->set_number('9051411')->is_valid_number, '沖縄県国頭郡国頭村辺土名');
ok($zip->set_number('9051412')->is_valid_number, '沖縄県国頭郡国頭村奥間');
ok($zip->set_number('9051413')->is_valid_number, '沖縄県国頭郡国頭村比地');
ok($zip->set_number('9051414')->is_valid_number, '沖縄県国頭郡国頭村半地');
ok($zip->set_number('9051415')->is_valid_number, '沖縄県国頭郡国頭村浜');
ok($zip->set_number('9051416')->is_valid_number, '沖縄県国頭郡国頭村鏡地');
ok($zip->set_number('9051417')->is_valid_number, '沖縄県国頭郡国頭村桃原');
ok($zip->set_number('9051421')->is_valid_number, '沖縄県国頭郡国頭村辺戸');
ok($zip->set_number('9051422')->is_valid_number, '沖縄県国頭郡国頭村宜名真');
ok($zip->set_number('9051423')->is_valid_number, '沖縄県国頭郡国頭村宇嘉');
ok($zip->set_number('9051424')->is_valid_number, '沖縄県国頭郡国頭村辺野喜');
ok($zip->set_number('9051425')->is_valid_number, '沖縄県国頭郡国頭村佐手');
ok($zip->set_number('9051426')->is_valid_number, '沖縄県国頭郡国頭村謝敷');
ok($zip->set_number('9051427')->is_valid_number, '沖縄県国頭郡国頭村与那');
ok($zip->set_number('9051428')->is_valid_number, '沖縄県国頭郡国頭村伊地');
ok($zip->set_number('9051429')->is_valid_number, '沖縄県国頭郡国頭村宇良');
ok($zip->set_number('9051501')->is_valid_number, '沖縄県国頭郡国頭村奥');
ok($zip->set_number('9051502')->is_valid_number, '沖縄県国頭郡国頭村楚洲');
ok($zip->set_number('9051503')->is_valid_number, '沖縄県国頭郡国頭村安田');
ok($zip->set_number('9051504')->is_valid_number, '沖縄県国頭郡国頭村安波');
ok($zip->set_number('9051631')->is_valid_number, '沖縄県名護市屋我');
ok($zip->set_number('9051632')->is_valid_number, '沖縄県名護市饒平名');
ok($zip->set_number('9051633')->is_valid_number, '沖縄県名護市我部');
ok($zip->set_number('9051634')->is_valid_number, '沖縄県名護市運天原');
ok($zip->set_number('9051635')->is_valid_number, '沖縄県名護市済井出');
ok($zip->set_number('9052171')->is_valid_number, '沖縄県名護市辺野古');
ok($zip->set_number('9052172')->is_valid_number, '沖縄県名護市豊原');
ok($zip->set_number('9052173')->is_valid_number, '沖縄県名護市久志');
ok($zip->set_number('9052261')->is_valid_number, '沖縄県名護市天仁屋');
ok($zip->set_number('9052262')->is_valid_number, '沖縄県名護市嘉陽');
ok($zip->set_number('9052263')->is_valid_number, '沖縄県名護市安部');
ok($zip->set_number('9052264')->is_valid_number, '沖縄県名護市三原');
ok($zip->set_number('9052265')->is_valid_number, '沖縄県名護市汀間');
ok($zip->set_number('9052266')->is_valid_number, '沖縄県名護市瀬嵩');
ok($zip->set_number('9052267')->is_valid_number, '沖縄県名護市大浦');
ok($zip->set_number('9052268')->is_valid_number, '沖縄県名護市大川');
ok($zip->set_number('9052269')->is_valid_number, '沖縄県名護市二見');
ok($zip->set_number('9060000')->is_valid_number, '沖縄県宮古島市以下に掲載がない場合');
ok($zip->set_number('9060001')->is_valid_number, '沖縄県宮古島市平良大神');
ok($zip->set_number('9060002')->is_valid_number, '沖縄県宮古島市平良狩俣');
ok($zip->set_number('9060003')->is_valid_number, '沖縄県宮古島市平良島尻');
ok($zip->set_number('9060004')->is_valid_number, '沖縄県宮古島市平良大浦');
ok($zip->set_number('9060005')->is_valid_number, '沖縄県宮古島市平良西原');
ok($zip->set_number('9060006')->is_valid_number, '沖縄県宮古島市平良西仲宗根');
ok($zip->set_number('9060007')->is_valid_number, '沖縄県宮古島市平良東仲宗根');
ok($zip->set_number('9060008')->is_valid_number, '沖縄県宮古島市平良荷川取');
ok($zip->set_number('9060011')->is_valid_number, '沖縄県宮古島市平良東仲宗根添');
ok($zip->set_number('9060012')->is_valid_number, '沖縄県宮古島市平良西里');
ok($zip->set_number('9060013')->is_valid_number, '沖縄県宮古島市平良下里');
ok($zip->set_number('9060014')->is_valid_number, '沖縄県宮古島市平良松原');
ok($zip->set_number('9060015')->is_valid_number, '沖縄県宮古島市平良久貝');
ok($zip->set_number('9060101')->is_valid_number, '沖縄県宮古島市城辺保良');
ok($zip->set_number('9060102')->is_valid_number, '沖縄県宮古島市城辺新城');
ok($zip->set_number('9060103')->is_valid_number, '沖縄県宮古島市城辺福里');
ok($zip->set_number('9060104')->is_valid_number, '沖縄県宮古島市城辺比嘉');
ok($zip->set_number('9060105')->is_valid_number, '沖縄県宮古島市城辺長間');
ok($zip->set_number('9060106')->is_valid_number, '沖縄県宮古島市城辺西里添');
ok($zip->set_number('9060107')->is_valid_number, '沖縄県宮古島市城辺友利');
ok($zip->set_number('9060108')->is_valid_number, '沖縄県宮古島市城辺砂川');
ok($zip->set_number('9060109')->is_valid_number, '沖縄県宮古島市城辺下里添');
ok($zip->set_number('9060201')->is_valid_number, '沖縄県宮古島市上野野原');
ok($zip->set_number('9060202')->is_valid_number, '沖縄県宮古島市上野新里');
ok($zip->set_number('9060203')->is_valid_number, '沖縄県宮古島市上野宮国');
ok($zip->set_number('9060204')->is_valid_number, '沖縄県宮古島市上野上野');
ok($zip->set_number('9060301')->is_valid_number, '沖縄県宮古島市下地川満');
ok($zip->set_number('9060302')->is_valid_number, '沖縄県宮古島市下地嘉手苅');
ok($zip->set_number('9060303')->is_valid_number, '沖縄県宮古島市下地洲鎌');
ok($zip->set_number('9060304')->is_valid_number, '沖縄県宮古島市下地上地');
ok($zip->set_number('9060305')->is_valid_number, '沖縄県宮古島市下地与那覇');
ok($zip->set_number('9060306')->is_valid_number, '沖縄県宮古島市下地来間');
ok($zip->set_number('9060421')->is_valid_number, '沖縄県宮古島市平良池間');
ok($zip->set_number('9060422')->is_valid_number, '沖縄県宮古島市平良前里');
ok($zip->set_number('9060501')->is_valid_number, '沖縄県宮古島市伊良部前里添');
ok($zip->set_number('9060502')->is_valid_number, '沖縄県宮古島市伊良部池間添');
ok($zip->set_number('9060503')->is_valid_number, '沖縄県宮古島市伊良部伊良部');
ok($zip->set_number('9060504')->is_valid_number, '沖縄県宮古島市伊良部仲地');
ok($zip->set_number('9060505')->is_valid_number, '沖縄県宮古島市伊良部国仲');
ok($zip->set_number('9060506')->is_valid_number, '沖縄県宮古島市伊良部長浜');
ok($zip->set_number('9060507')->is_valid_number, '沖縄県宮古島市伊良部佐和田');
ok($zip->set_number('9060600')->is_valid_number, '沖縄県宮古郡多良間村以下に掲載がない場合');
ok($zip->set_number('9060601')->is_valid_number, '沖縄県宮古郡多良間村塩川');
ok($zip->set_number('9060602')->is_valid_number, '沖縄県宮古郡多良間村仲筋');
ok($zip->set_number('9060603')->is_valid_number, '沖縄県宮古郡多良間村水納');
ok($zip->set_number('9070000')->is_valid_number, '沖縄県石垣市以下に掲載がない場合');
ok($zip->set_number('9070000')->is_valid_number, '沖縄県八重山郡竹富町以下に掲載がない場合');
ok($zip->set_number('9070001')->is_valid_number, '沖縄県石垣市大浜');
ok($zip->set_number('9070002')->is_valid_number, '沖縄県石垣市真栄里');
ok($zip->set_number('9070003')->is_valid_number, '沖縄県石垣市平得');
ok($zip->set_number('9070004')->is_valid_number, '沖縄県石垣市登野城');
ok($zip->set_number('9070011')->is_valid_number, '沖縄県石垣市八島町');
ok($zip->set_number('9070012')->is_valid_number, '沖縄県石垣市美崎町');
ok($zip->set_number('9070013')->is_valid_number, '沖縄県石垣市浜崎町');
ok($zip->set_number('9070014')->is_valid_number, '沖縄県石垣市新栄町');
ok($zip->set_number('9070015')->is_valid_number, '沖縄県石垣市南ぬ浜町');
ok($zip->set_number('9070021')->is_valid_number, '沖縄県石垣市名蔵');
ok($zip->set_number('9070022')->is_valid_number, '沖縄県石垣市大川');
ok($zip->set_number('9070023')->is_valid_number, '沖縄県石垣市石垣');
ok($zip->set_number('9070024')->is_valid_number, '沖縄県石垣市新川');
ok($zip->set_number('9070031')->is_valid_number, '沖縄県石垣市登野城尖閣');
ok($zip->set_number('9070241')->is_valid_number, '沖縄県石垣市桃里');
ok($zip->set_number('9070242')->is_valid_number, '沖縄県石垣市白保');
ok($zip->set_number('9070243')->is_valid_number, '沖縄県石垣市宮良');
ok($zip->set_number('9070244')->is_valid_number, '沖縄県石垣市盛山');
ok($zip->set_number('9070331')->is_valid_number, '沖縄県石垣市平久保');
ok($zip->set_number('9070332')->is_valid_number, '沖縄県石垣市伊原間');
ok($zip->set_number('9070333')->is_valid_number, '沖縄県石垣市野底');
ok($zip->set_number('9070451')->is_valid_number, '沖縄県石垣市桴海');
ok($zip->set_number('9070452')->is_valid_number, '沖縄県石垣市崎枝');
ok($zip->set_number('9070453')->is_valid_number, '沖縄県石垣市川平');
ok($zip->set_number('9071101')->is_valid_number, '沖縄県八重山郡竹富町竹富');
ok($zip->set_number('9071221')->is_valid_number, '沖縄県八重山郡竹富町小浜');
ok($zip->set_number('9071311')->is_valid_number, '沖縄県八重山郡竹富町黒島');
ok($zip->set_number('9071431')->is_valid_number, '沖縄県八重山郡竹富町高那');
ok($zip->set_number('9071432')->is_valid_number, '沖縄県八重山郡竹富町古見');
ok($zip->set_number('9071433')->is_valid_number, '沖縄県八重山郡竹富町南風見仲');
ok($zip->set_number('9071434')->is_valid_number, '沖縄県八重山郡竹富町南風見');
ok($zip->set_number('9071435')->is_valid_number, '沖縄県八重山郡竹富町新城');
ok($zip->set_number('9071541')->is_valid_number, '沖縄県八重山郡竹富町上原');
ok($zip->set_number('9071542')->is_valid_number, '沖縄県八重山郡竹富町西表');
ok($zip->set_number('9071543')->is_valid_number, '沖縄県八重山郡竹富町崎山');
ok($zip->set_number('9071544')->is_valid_number, '沖縄県八重山郡竹富町鳩間');
ok($zip->set_number('9071751')->is_valid_number, '沖縄県八重山郡竹富町波照間');
ok($zip->set_number('9071800')->is_valid_number, '沖縄県八重山郡与那国町以下に掲載がない場合');
ok($zip->set_number('9071801')->is_valid_number, '沖縄県八重山郡与那国町与那国');
ok($zip->set_number('9100001')->is_valid_number, '福井県福井市大願寺');
ok($zip->set_number('9100002')->is_valid_number, '福井県福井市町屋');
ok($zip->set_number('9100003')->is_valid_number, '福井県福井市松本');
ok($zip->set_number('9100004')->is_valid_number, '福井県福井市宝永');
ok($zip->set_number('9100005')->is_valid_number, '福井県福井市大手');
ok($zip->set_number('9100006')->is_valid_number, '福井県福井市中央');
ok($zip->set_number('9100011')->is_valid_number, '福井県福井市経田');
ok($zip->set_number('9100012')->is_valid_number, '福井県福井市経栄');
ok($zip->set_number('9100013')->is_valid_number, '福井県福井市幾代');
ok($zip->set_number('9100014')->is_valid_number, '福井県福井市幾久町');
ok($zip->set_number('9100015')->is_valid_number, '福井県福井市二の宮');
ok($zip->set_number('9100016')->is_valid_number, '福井県福井市大宮');
ok($zip->set_number('9100017')->is_valid_number, '福井県福井市文京');
ok($zip->set_number('9100018')->is_valid_number, '福井県福井市田原');
ok($zip->set_number('9100019')->is_valid_number, '福井県福井市春山');
ok($zip->set_number('9100021')->is_valid_number, '福井県福井市乾徳');
ok($zip->set_number('9100022')->is_valid_number, '福井県福井市花月');
ok($zip->set_number('9100023')->is_valid_number, '福井県福井市順化');
ok($zip->set_number('9100024')->is_valid_number, '福井県福井市照手');
ok($zip->set_number('9100025')->is_valid_number, '福井県福井市照手町');
ok($zip->set_number('9100026')->is_valid_number, '福井県福井市光陽');
ok($zip->set_number('9100027')->is_valid_number, '福井県福井市豊岡');
ok($zip->set_number('9100028')->is_valid_number, '福井県福井市学園');
ok($zip->set_number('9100029')->is_valid_number, '福井県福井市日光');
ok($zip->set_number('9100031')->is_valid_number, '福井県福井市堀ノ宮町');
ok($zip->set_number('9100032')->is_valid_number, '福井県福井市堀ノ宮');
ok($zip->set_number('9100033')->is_valid_number, '福井県福井市三郎丸');
ok($zip->set_number('9100034')->is_valid_number, '福井県福井市菅谷');
ok($zip->set_number('9100035')->is_valid_number, '福井県福井市菅谷町');
ok($zip->set_number('9100036')->is_valid_number, '福井県福井市三郎丸町');
ok($zip->set_number('9100037')->is_valid_number, '福井県福井市西堀町');
ok($zip->set_number('9100038')->is_valid_number, '福井県福井市三ツ屋');
ok($zip->set_number('9100039')->is_valid_number, '福井県福井市三ツ屋町');
ok($zip->set_number('9100041')->is_valid_number, '福井県福井市天菅生町');
ok($zip->set_number('9100042')->is_valid_number, '福井県福井市岸水町');
ok($zip->set_number('9100043')->is_valid_number, '福井県福井市四十谷町');
ok($zip->set_number('9100044')->is_valid_number, '福井県福井市田ノ谷町');
ok($zip->set_number('9100045')->is_valid_number, '福井県福井市北楢原町');
ok($zip->set_number('9100046')->is_valid_number, '福井県福井市南楢原町');
ok($zip->set_number('9100047')->is_valid_number, '福井県福井市海老助町');
ok($zip->set_number('9100048')->is_valid_number, '福井県福井市地蔵堂町');
ok($zip->set_number('9100049')->is_valid_number, '福井県福井市深谷町');
ok($zip->set_number('9100051')->is_valid_number, '福井県福井市郡町');
ok($zip->set_number('9100052')->is_valid_number, '福井県福井市黒丸町');
ok($zip->set_number('9100053')->is_valid_number, '福井県福井市土橋町');
ok($zip->set_number('9100054')->is_valid_number, '福井県福井市安竹町');
ok($zip->set_number('9100055')->is_valid_number, '福井県福井市上伏町');
ok($zip->set_number('9100056')->is_valid_number, '福井県福井市里別所新町');
ok($zip->set_number('9100057')->is_valid_number, '福井県福井市里別所町');
ok($zip->set_number('9100061')->is_valid_number, '福井県福井市舟橋新町');
ok($zip->set_number('9100062')->is_valid_number, '福井県福井市灯明寺町');
ok($zip->set_number('9100063')->is_valid_number, '福井県福井市灯明寺');
ok($zip->set_number('9100064')->is_valid_number, '福井県福井市新田塚町');
ok($zip->set_number('9100065')->is_valid_number, '福井県福井市八ツ島町');
ok($zip->set_number('9100066')->is_valid_number, '福井県福井市八ツ島');
ok($zip->set_number('9100067')->is_valid_number, '福井県福井市新田塚');
ok($zip->set_number('9100068')->is_valid_number, '福井県福井市舟橋新');
ok($zip->set_number('9100069')->is_valid_number, '福井県福井市舟橋黒竜');
ok($zip->set_number('9100070')->is_valid_number, '福井県福井市高木西');
ok($zip->set_number('9100101')->is_valid_number, '福井県福井市つくし野');
ok($zip->set_number('9100102')->is_valid_number, '福井県福井市川合鷲塚町');
ok($zip->set_number('9100103')->is_valid_number, '福井県福井市中角町');
ok($zip->set_number('9100104')->is_valid_number, '福井県福井市網戸瀬町');
ok($zip->set_number('9100105')->is_valid_number, '福井県福井市河合勝見町');
ok($zip->set_number('9100106')->is_valid_number, '福井県福井市六日市町');
ok($zip->set_number('9100107')->is_valid_number, '福井県福井市高屋町');
ok($zip->set_number('9100108')->is_valid_number, '福井県福井市山室町');
ok($zip->set_number('9100109')->is_valid_number, '福井県福井市二日市町');
ok($zip->set_number('9100121')->is_valid_number, '福井県福井市定正町');
ok($zip->set_number('9100122')->is_valid_number, '福井県福井市石盛町');
ok($zip->set_number('9100123')->is_valid_number, '福井県福井市八重巻町');
ok($zip->set_number('9100124')->is_valid_number, '福井県福井市天池町');
ok($zip->set_number('9100125')->is_valid_number, '福井県福井市石盛');
ok($zip->set_number('9100126')->is_valid_number, '福井県福井市定正');
ok($zip->set_number('9100132')->is_valid_number, '福井県福井市河合寄安町');
ok($zip->set_number('9100134')->is_valid_number, '福井県福井市上野本町');
ok($zip->set_number('9100135')->is_valid_number, '福井県福井市上野本町新');
ok($zip->set_number('9100136')->is_valid_number, '福井県福井市栗森町浜');
ok($zip->set_number('9100137')->is_valid_number, '福井県福井市栗森');
ok($zip->set_number('9100138')->is_valid_number, '福井県福井市東森田');
ok($zip->set_number('9100141')->is_valid_number, '福井県福井市上森田町');
ok($zip->set_number('9100142')->is_valid_number, '福井県福井市上森田');
ok($zip->set_number('9100143')->is_valid_number, '福井県福井市下森田新町');
ok($zip->set_number('9100144')->is_valid_number, '福井県福井市下森田本町');
ok($zip->set_number('9100145')->is_valid_number, '福井県福井市下森田藤巻町');
ok($zip->set_number('9100146')->is_valid_number, '福井県福井市下森田桜町');
ok($zip->set_number('9100147')->is_valid_number, '福井県福井市下森田町');
ok($zip->set_number('9100151')->is_valid_number, '福井県福井市栄町');
ok($zip->set_number('9100152')->is_valid_number, '福井県福井市古市');
ok($zip->set_number('9100153')->is_valid_number, '福井県福井市古市町');
ok($zip->set_number('9100154')->is_valid_number, '福井県福井市稲多元町');
ok($zip->set_number('9100155')->is_valid_number, '福井県福井市稲多浜町');
ok($zip->set_number('9100156')->is_valid_number, '福井県福井市稲多新町');
ok($zip->set_number('9100157')->is_valid_number, '福井県福井市八重巻東町');
ok($zip->set_number('9100158')->is_valid_number, '福井県福井市八重巻中町');
ok($zip->set_number('9100200')->is_valid_number, '福井県坂井市以下に掲載がない場合');
ok($zip->set_number('9100201')->is_valid_number, '福井県坂井市丸岡町上竹田(曽谷)');
ok($zip->set_number('9100202')->is_valid_number, '福井県坂井市丸岡町上竹田(岡)');
ok($zip->set_number('9100203')->is_valid_number, '福井県坂井市丸岡町山口');
ok($zip->set_number('9100204')->is_valid_number, '福井県坂井市丸岡町山竹田');
ok($zip->set_number('9100205')->is_valid_number, '福井県坂井市丸岡町上竹田(その他)');
ok($zip->set_number('9100206')->is_valid_number, '福井県坂井市丸岡町川上');
ok($zip->set_number('9100207')->is_valid_number, '福井県坂井市丸岡町山久保');
ok($zip->set_number('9100208')->is_valid_number, '福井県坂井市丸岡町坪江');
ok($zip->set_number('9100211')->is_valid_number, '福井県坂井市丸岡町女形谷');
ok($zip->set_number('9100212')->is_valid_number, '福井県坂井市丸岡町赤坂');
ok($zip->set_number('9100213')->is_valid_number, '福井県坂井市丸岡町田屋');
ok($zip->set_number('9100214')->is_valid_number, '福井県坂井市丸岡町畑中');
ok($zip->set_number('9100215')->is_valid_number, '福井県坂井市丸岡町与河');
ok($zip->set_number('9100221')->is_valid_number, '福井県坂井市丸岡町城北');
ok($zip->set_number('9100222')->is_valid_number, '福井県坂井市丸岡町伏屋');
ok($zip->set_number('9100223')->is_valid_number, '福井県坂井市丸岡町三本木');
ok($zip->set_number('9100224')->is_valid_number, '福井県坂井市丸岡町八ケ郷');
ok($zip->set_number('9100225')->is_valid_number, '福井県坂井市丸岡町松川');
ok($zip->set_number('9100226')->is_valid_number, '福井県坂井市丸岡町松川町');
ok($zip->set_number('9100227')->is_valid_number, '福井県坂井市丸岡町荒町');
ok($zip->set_number('9100231')->is_valid_number, '福井県坂井市丸岡町霞町');
ok($zip->set_number('9100232')->is_valid_number, '福井県坂井市丸岡町霞ケ丘');
ok($zip->set_number('9100233')->is_valid_number, '福井県坂井市丸岡町東陽');
ok($zip->set_number('9100234')->is_valid_number, '福井県坂井市丸岡町今市');
ok($zip->set_number('9100235')->is_valid_number, '福井県坂井市丸岡町巽町');
ok($zip->set_number('9100236')->is_valid_number, '福井県坂井市丸岡町本町');
ok($zip->set_number('9100237')->is_valid_number, '福井県坂井市丸岡町乾');
ok($zip->set_number('9100241')->is_valid_number, '福井県坂井市丸岡町柳町');
ok($zip->set_number('9100242')->is_valid_number, '福井県坂井市丸岡町西里丸岡');
ok($zip->set_number('9100243')->is_valid_number, '福井県坂井市丸岡町石城戸町');
ok($zip->set_number('9100244')->is_valid_number, '福井県坂井市丸岡町富田町');
ok($zip->set_number('9100245')->is_valid_number, '福井県坂井市丸岡町谷町');
ok($zip->set_number('9100246')->is_valid_number, '福井県坂井市丸岡町西瓜屋');
ok($zip->set_number('9100251')->is_valid_number, '福井県坂井市丸岡町一本田福所');
ok($zip->set_number('9100252')->is_valid_number, '福井県坂井市丸岡町御幸');
ok($zip->set_number('9100253')->is_valid_number, '福井県坂井市丸岡町一本田中');
ok($zip->set_number('9100254')->is_valid_number, '福井県坂井市丸岡町一本田');
ok($zip->set_number('9100261')->is_valid_number, '福井県坂井市丸岡町針ノ木');
ok($zip->set_number('9100262')->is_valid_number, '福井県坂井市丸岡町栄');
ok($zip->set_number('9100263')->is_valid_number, '福井県坂井市丸岡町上田町');
ok($zip->set_number('9100264')->is_valid_number, '福井県坂井市丸岡町乾下田');
ok($zip->set_number('9100265')->is_valid_number, '福井県坂井市丸岡町朝陽');
ok($zip->set_number('9100271')->is_valid_number, '福井県坂井市丸岡町堀水');
ok($zip->set_number('9100272')->is_valid_number, '福井県坂井市丸岡町乗兼');
ok($zip->set_number('9100273')->is_valid_number, '福井県坂井市丸岡町長畝');
ok($zip->set_number('9100274')->is_valid_number, '福井県坂井市丸岡町千田');
ok($zip->set_number('9100275')->is_valid_number, '福井県坂井市丸岡町宇田');
ok($zip->set_number('9100276')->is_valid_number, '福井県坂井市丸岡町玄女');
ok($zip->set_number('9100277')->is_valid_number, '福井県坂井市丸岡町里竹田');
ok($zip->set_number('9100301')->is_valid_number, '福井県坂井市丸岡町愛宕');
ok($zip->set_number('9100302')->is_valid_number, '福井県坂井市丸岡町里丸岡');
ok($zip->set_number('9100303')->is_valid_number, '福井県坂井市丸岡町猪爪');
ok($zip->set_number('9100304')->is_valid_number, '福井県坂井市丸岡町今福');
ok($zip->set_number('9100305')->is_valid_number, '福井県坂井市丸岡町八幡町');
ok($zip->set_number('9100311')->is_valid_number, '福井県坂井市丸岡町豊原');
ok($zip->set_number('9100312')->is_valid_number, '福井県坂井市丸岡町曽々木');
ok($zip->set_number('9100313')->is_valid_number, '福井県坂井市丸岡町内田');
ok($zip->set_number('9100314')->is_valid_number, '福井県坂井市丸岡町舛田');
ok($zip->set_number('9100315')->is_valid_number, '福井県坂井市丸岡町小黒');
ok($zip->set_number('9100316')->is_valid_number, '福井県坂井市丸岡町篠岡');
ok($zip->set_number('9100317')->is_valid_number, '福井県坂井市丸岡町石上');
ok($zip->set_number('9100321')->is_valid_number, '福井県坂井市丸岡町山崎三ケ');
ok($zip->set_number('9100322')->is_valid_number, '福井県坂井市丸岡町大森');
ok($zip->set_number('9100323')->is_valid_number, '福井県坂井市丸岡町野中山王');
ok($zip->set_number('9100324')->is_valid_number, '福井県坂井市丸岡町油為頭');
ok($zip->set_number('9100325')->is_valid_number, '福井県坂井市丸岡町板倉');
ok($zip->set_number('9100326')->is_valid_number, '福井県坂井市丸岡町末政');
ok($zip->set_number('9100331')->is_valid_number, '福井県坂井市丸岡町上久米田');
ok($zip->set_number('9100332')->is_valid_number, '福井県坂井市丸岡町下久米田');
ok($zip->set_number('9100333')->is_valid_number, '福井県坂井市丸岡町金元');
ok($zip->set_number('9100334')->is_valid_number, '福井県坂井市丸岡町東二ツ屋');
ok($zip->set_number('9100335')->is_valid_number, '福井県坂井市丸岡町上金屋');
ok($zip->set_number('9100336')->is_valid_number, '福井県坂井市丸岡町楽間');
ok($zip->set_number('9100337')->is_valid_number, '福井県坂井市丸岡町新鳴鹿');
ok($zip->set_number('9100338')->is_valid_number, '福井県坂井市丸岡町為安');
ok($zip->set_number('9100339')->is_valid_number, '福井県坂井市丸岡町寄永');
ok($zip->set_number('9100341')->is_valid_number, '福井県坂井市丸岡町四ツ柳');
ok($zip->set_number('9100342')->is_valid_number, '福井県坂井市丸岡町高田');
ok($zip->set_number('9100343')->is_valid_number, '福井県坂井市丸岡町坪ノ内');
ok($zip->set_number('9100344')->is_valid_number, '福井県坂井市丸岡町友末');
ok($zip->set_number('9100345')->is_valid_number, '福井県坂井市丸岡町四郎丸');
ok($zip->set_number('9100346')->is_valid_number, '福井県坂井市丸岡町磯部島');
ok($zip->set_number('9100347')->is_valid_number, '福井県坂井市丸岡町熊堂');
ok($zip->set_number('9100348')->is_valid_number, '福井県坂井市丸岡町今町');
ok($zip->set_number('9100349')->is_valid_number, '福井県坂井市丸岡町反保');
ok($zip->set_number('9100350')->is_valid_number, '福井県坂井市丸岡町南今市');
ok($zip->set_number('9100351')->is_valid_number, '福井県坂井市丸岡町寅国');
ok($zip->set_number('9100352')->is_valid_number, '福井県坂井市丸岡町新間');
ok($zip->set_number('9100353')->is_valid_number, '福井県坂井市丸岡町筑後清水');
ok($zip->set_number('9100354')->is_valid_number, '福井県坂井市丸岡町豊原高瀬');
ok($zip->set_number('9100355')->is_valid_number, '福井県坂井市丸岡町高瀬');
ok($zip->set_number('9100356')->is_valid_number, '福井県坂井市丸岡町牛ケ島');
ok($zip->set_number('9100357')->is_valid_number, '福井県坂井市丸岡町儀間');
ok($zip->set_number('9100361')->is_valid_number, '福井県坂井市丸岡町安田新');
ok($zip->set_number('9100362')->is_valid_number, '福井県坂井市丸岡町上安田');
ok($zip->set_number('9100363')->is_valid_number, '福井県坂井市丸岡町下安田');
ok($zip->set_number('9100364')->is_valid_number, '福井県坂井市丸岡町八丁');
ok($zip->set_number('9100365')->is_valid_number, '福井県坂井市丸岡町磯部福庄');
ok($zip->set_number('9100366')->is_valid_number, '福井県坂井市丸岡町宇随');
ok($zip->set_number('9100367')->is_valid_number, '福井県坂井市丸岡町羽崎');
ok($zip->set_number('9100368')->is_valid_number, '福井県坂井市丸岡町磯部新保');
ok($zip->set_number('9100369')->is_valid_number, '福井県坂井市丸岡町新九頭竜');
ok($zip->set_number('9100371')->is_valid_number, '福井県坂井市丸岡町八ツ口');
ok($zip->set_number('9100372')->is_valid_number, '福井県坂井市丸岡町吉政');
ok($zip->set_number('9100373')->is_valid_number, '福井県坂井市丸岡町高柳');
ok($zip->set_number('9100374')->is_valid_number, '福井県坂井市丸岡町北横地');
ok($zip->set_number('9100375')->is_valid_number, '福井県坂井市丸岡町南横地');
ok($zip->set_number('9100381')->is_valid_number, '福井県坂井市丸岡町舟寄');
ok($zip->set_number('9100382')->is_valid_number, '福井県坂井市丸岡町笹和田');
ok($zip->set_number('9100383')->is_valid_number, '福井県坂井市丸岡町長崎');
ok($zip->set_number('9100384')->is_valid_number, '福井県坂井市丸岡町四ツ屋');
ok($zip->set_number('9100801')->is_valid_number, '福井県福井市寺前町');
ok($zip->set_number('9100802')->is_valid_number, '福井県福井市大和田町');
ok($zip->set_number('9100803')->is_valid_number, '福井県福井市高柳町');
ok($zip->set_number('9100804')->is_valid_number, '福井県福井市高木中央');
ok($zip->set_number('9100805')->is_valid_number, '福井県福井市高木');
ok($zip->set_number('9100806')->is_valid_number, '福井県福井市高木町');
ok($zip->set_number('9100807')->is_valid_number, '福井県福井市高木北');
ok($zip->set_number('9100808')->is_valid_number, '福井県福井市舟橋');
ok($zip->set_number('9100809')->is_valid_number, '福井県福井市舟橋町');
ok($zip->set_number('9100811')->is_valid_number, '福井県福井市中藤新保町');
ok($zip->set_number('9100812')->is_valid_number, '福井県福井市新田本町');
ok($zip->set_number('9100813')->is_valid_number, '福井県福井市中新田町');
ok($zip->set_number('9100814')->is_valid_number, '福井県福井市北野下町');
ok($zip->set_number('9100815')->is_valid_number, '福井県福井市北野上町');
ok($zip->set_number('9100816')->is_valid_number, '福井県福井市中ノ郷町');
ok($zip->set_number('9100817')->is_valid_number, '福井県福井市泉田町');
ok($zip->set_number('9100818')->is_valid_number, '福井県福井市堂島町');
ok($zip->set_number('9100821')->is_valid_number, '福井県福井市島橋町');
ok($zip->set_number('9100822')->is_valid_number, '福井県福井市玄正島町');
ok($zip->set_number('9100823')->is_valid_number, '福井県福井市重立町');
ok($zip->set_number('9100824')->is_valid_number, '福井県福井市間山町');
ok($zip->set_number('9100825')->is_valid_number, '福井県福井市原目町');
ok($zip->set_number('9100826')->is_valid_number, '福井県福井市上中町');
ok($zip->set_number('9100827')->is_valid_number, '福井県福井市藤島町');
ok($zip->set_number('9100828')->is_valid_number, '福井県福井市林町');
ok($zip->set_number('9100829')->is_valid_number, '福井県福井市林藤島町');
ok($zip->set_number('9100831')->is_valid_number, '福井県福井市若栄町');
ok($zip->set_number('9100832')->is_valid_number, '福井県福井市新保町');
ok($zip->set_number('9100833')->is_valid_number, '福井県福井市新保');
ok($zip->set_number('9100834')->is_valid_number, '福井県福井市丸山');
ok($zip->set_number('9100835')->is_valid_number, '福井県福井市丸山町');
ok($zip->set_number('9100836')->is_valid_number, '福井県福井市大和田');
ok($zip->set_number('9100837')->is_valid_number, '福井県福井市高柳');
ok($zip->set_number('9100838')->is_valid_number, '福井県福井市新保北');
ok($zip->set_number('9100841')->is_valid_number, '福井県福井市開発町');
ok($zip->set_number('9100842')->is_valid_number, '福井県福井市開発');
ok($zip->set_number('9100843')->is_valid_number, '福井県福井市西開発');
ok($zip->set_number('9100844')->is_valid_number, '福井県福井市長本町');
ok($zip->set_number('9100845')->is_valid_number, '福井県福井市志比口');
ok($zip->set_number('9100846')->is_valid_number, '福井県福井市四ツ井');
ok($zip->set_number('9100851')->is_valid_number, '福井県福井市米松');
ok($zip->set_number('9100852')->is_valid_number, '福井県福井市松城町');
ok($zip->set_number('9100853')->is_valid_number, '福井県福井市城東');
ok($zip->set_number('9100854')->is_valid_number, '福井県福井市御幸');
ok($zip->set_number('9100855')->is_valid_number, '福井県福井市西方');
ok($zip->set_number('9100856')->is_valid_number, '福井県福井市勝見');
ok($zip->set_number('9100857')->is_valid_number, '福井県福井市豊島');
ok($zip->set_number('9100858')->is_valid_number, '福井県福井市手寄');
ok($zip->set_number('9100859')->is_valid_number, '福井県福井市日之出');
ok($zip->set_number('9101100')->is_valid_number, '福井県吉田郡永平寺町以下に掲載がない場合');
ok($zip->set_number('9101101')->is_valid_number, '福井県吉田郡永平寺町松岡樋爪');
ok($zip->set_number('9101102')->is_valid_number, '福井県吉田郡永平寺町松岡学園');
ok($zip->set_number('9101103')->is_valid_number, '福井県吉田郡永平寺町松岡上合月');
ok($zip->set_number('9101104')->is_valid_number, '福井県吉田郡永平寺町松岡下合月');
ok($zip->set_number('9101105')->is_valid_number, '福井県吉田郡永平寺町松岡末政');
ok($zip->set_number('9101106')->is_valid_number, '福井県吉田郡永平寺町松岡御公領');
ok($zip->set_number('9101111')->is_valid_number, '福井県吉田郡永平寺町松岡志比堺');
ok($zip->set_number('9101112')->is_valid_number, '福井県吉田郡永平寺町松岡越坂');
ok($zip->set_number('9101113')->is_valid_number, '福井県吉田郡永平寺町松岡松ケ丘');
ok($zip->set_number('9101114')->is_valid_number, '福井県吉田郡永平寺町松岡城東');
ok($zip->set_number('9101115')->is_valid_number, '福井県吉田郡永平寺町松岡石舟');
ok($zip->set_number('9101116')->is_valid_number, '福井県吉田郡永平寺町松岡清水');
ok($zip->set_number('9101117')->is_valid_number, '福井県吉田郡永平寺町松岡神明');
ok($zip->set_number('9101118')->is_valid_number, '福井県吉田郡永平寺町松岡薬師');
ok($zip->set_number('9101121')->is_valid_number, '福井県吉田郡永平寺町松岡吉野');
ok($zip->set_number('9101122')->is_valid_number, '福井県吉田郡永平寺町松岡宮重');
ok($zip->set_number('9101123')->is_valid_number, '福井県吉田郡永平寺町松岡湯谷');
ok($zip->set_number('9101124')->is_valid_number, '福井県吉田郡永平寺町松岡上吉野');
ok($zip->set_number('9101125')->is_valid_number, '福井県吉田郡永平寺町松岡西野中');
ok($zip->set_number('9101126')->is_valid_number, '福井県吉田郡永平寺町松岡小畑');
ok($zip->set_number('9101127')->is_valid_number, '福井県吉田郡永平寺町松岡吉野堺');
ok($zip->set_number('9101131')->is_valid_number, '福井県吉田郡永平寺町松岡椚');
ok($zip->set_number('9101132')->is_valid_number, '福井県吉田郡永平寺町松岡葵');
ok($zip->set_number('9101133')->is_valid_number, '福井県吉田郡永平寺町松岡春日');
ok($zip->set_number('9101134')->is_valid_number, '福井県吉田郡永平寺町松岡芝原');
ok($zip->set_number('9101135')->is_valid_number, '福井県吉田郡永平寺町松岡室');
ok($zip->set_number('9101136')->is_valid_number, '福井県吉田郡永平寺町松岡窪');
ok($zip->set_number('9101137')->is_valid_number, '福井県吉田郡永平寺町松岡観音');
ok($zip->set_number('9101138')->is_valid_number, '福井県吉田郡永平寺町松岡松ケ原');
ok($zip->set_number('9101139')->is_valid_number, '福井県吉田郡永平寺町松岡木ノ下');
ok($zip->set_number('9101141')->is_valid_number, '福井県吉田郡永平寺町松岡領家');
ok($zip->set_number('9101142')->is_valid_number, '福井県吉田郡永平寺町松岡兼定島');
ok($zip->set_number('9101143')->is_valid_number, '福井県吉田郡永平寺町松岡渡新田');
ok($zip->set_number('9101144')->is_valid_number, '福井県吉田郡永平寺町松岡平成');
ok($zip->set_number('9101201')->is_valid_number, '福井県吉田郡永平寺町鳴鹿山鹿');
ok($zip->set_number('9101202')->is_valid_number, '福井県吉田郡永平寺町下浄法寺');
ok($zip->set_number('9101203')->is_valid_number, '福井県吉田郡永平寺町上浄法寺');
ok($zip->set_number('9101204')->is_valid_number, '福井県吉田郡永平寺町岩野');
ok($zip->set_number('9101205')->is_valid_number, '福井県吉田郡永平寺町吉波');
ok($zip->set_number('9101206')->is_valid_number, '福井県吉田郡永平寺町栃原');
ok($zip->set_number('9101211')->is_valid_number, '福井県吉田郡永平寺町法寺岡');
ok($zip->set_number('9101212')->is_valid_number, '福井県吉田郡永平寺町東古市');
ok($zip->set_number('9101213')->is_valid_number, '福井県吉田郡永平寺町高橋');
ok($zip->set_number('9101214')->is_valid_number, '福井県吉田郡永平寺町谷口');
ok($zip->set_number('9101215')->is_valid_number, '福井県吉田郡永平寺町花谷');
ok($zip->set_number('9101216')->is_valid_number, '福井県吉田郡永平寺町光明寺');
ok($zip->set_number('9101217')->is_valid_number, '福井県吉田郡永平寺町飯島');
ok($zip->set_number('9101218')->is_valid_number, '福井県吉田郡永平寺町轟');
ok($zip->set_number('9101221')->is_valid_number, '福井県吉田郡永平寺町山');
ok($zip->set_number('9101222')->is_valid_number, '福井県吉田郡永平寺町諏訪間');
ok($zip->set_number('9101223')->is_valid_number, '福井県吉田郡永平寺町けやき台');
ok($zip->set_number('9101224')->is_valid_number, '福井県吉田郡永平寺町寺本');
ok($zip->set_number('9101225')->is_valid_number, '福井県吉田郡永平寺町京善');
ok($zip->set_number('9101226')->is_valid_number, '福井県吉田郡永平寺町市野々');
ok($zip->set_number('9101227')->is_valid_number, '福井県吉田郡永平寺町荒谷');
ok($zip->set_number('9101228')->is_valid_number, '福井県吉田郡永平寺町志比');
ok($zip->set_number('9101301')->is_valid_number, '福井県吉田郡永平寺町中島');
ok($zip->set_number('9101302')->is_valid_number, '福井県吉田郡永平寺町市荒川');
ok($zip->set_number('9101303')->is_valid_number, '福井県吉田郡永平寺町藤巻');
ok($zip->set_number('9101304')->is_valid_number, '福井県吉田郡永平寺町吉峰');
ok($zip->set_number('9101305')->is_valid_number, '福井県吉田郡永平寺町竹原');
ok($zip->set_number('9101311')->is_valid_number, '福井県吉田郡永平寺町大野島');
ok($zip->set_number('9101312')->is_valid_number, '福井県吉田郡永平寺町清水');
ok($zip->set_number('9101313')->is_valid_number, '福井県吉田郡永平寺町石上');
ok($zip->set_number('9101314')->is_valid_number, '福井県吉田郡永平寺町栗住波');
ok($zip->set_number('9101315')->is_valid_number, '福井県吉田郡永平寺町せせらぎ');
ok($zip->set_number('9101316')->is_valid_number, '福井県吉田郡永平寺町市右エ門島');
ok($zip->set_number('9101321')->is_valid_number, '福井県吉田郡永平寺町山王');
ok($zip->set_number('9101322')->is_valid_number, '福井県吉田郡永平寺町大月');
ok($zip->set_number('9101323')->is_valid_number, '福井県吉田郡永平寺町浅見');
ok($zip->set_number('9101324')->is_valid_number, '福井県吉田郡永平寺町野中');
ok($zip->set_number('9101325')->is_valid_number, '福井県吉田郡永平寺町北島');
ok($zip->set_number('9101326')->is_valid_number, '福井県吉田郡永平寺町牧福島');
ok($zip->set_number('9102141')->is_valid_number, '福井県福井市高尾町');
ok($zip->set_number('9102142')->is_valid_number, '福井県福井市前波町');
ok($zip->set_number('9102143')->is_valid_number, '福井県福井市宿布町');
ok($zip->set_number('9102144')->is_valid_number, '福井県福井市上毘沙門町');
ok($zip->set_number('9102145')->is_valid_number, '福井県福井市中毘沙門町');
ok($zip->set_number('9102146')->is_valid_number, '福井県福井市下毘沙門町');
ok($zip->set_number('9102147')->is_valid_number, '福井県福井市成願寺町');
ok($zip->set_number('9102148')->is_valid_number, '福井県福井市篠尾町');
ok($zip->set_number('9102149')->is_valid_number, '福井県福井市東郷美里町');
ok($zip->set_number('9102151')->is_valid_number, '福井県福井市安波賀中島町');
ok($zip->set_number('9102152')->is_valid_number, '福井県福井市安波賀町');
ok($zip->set_number('9102153')->is_valid_number, '福井県福井市城戸ノ内町');
ok($zip->set_number('9102154')->is_valid_number, '福井県福井市東新町');
ok($zip->set_number('9102155')->is_valid_number, '福井県福井市浄教寺町');
ok($zip->set_number('9102156')->is_valid_number, '福井県福井市鹿俣町');
ok($zip->set_number('9102157')->is_valid_number, '福井県福井市西新町');
ok($zip->set_number('9102161')->is_valid_number, '福井県福井市脇三ケ町');
ok($zip->set_number('9102162')->is_valid_number, '福井県福井市南山町');
ok($zip->set_number('9102163')->is_valid_number, '福井県福井市栃泉町');
ok($zip->set_number('9102164')->is_valid_number, '福井県福井市深見町');
ok($zip->set_number('9102165')->is_valid_number, '福井県福井市東郷二ケ町');
ok($zip->set_number('9102166')->is_valid_number, '福井県福井市小路町');
ok($zip->set_number('9102167')->is_valid_number, '福井県福井市安原町');
ok($zip->set_number('9102171')->is_valid_number, '福井県福井市荒木町');
ok($zip->set_number('9102172')->is_valid_number, '福井県福井市荒木新保町');
ok($zip->set_number('9102173')->is_valid_number, '福井県福井市下東郷町');
ok($zip->set_number('9102174')->is_valid_number, '福井県福井市上東郷町');
ok($zip->set_number('9102175')->is_valid_number, '福井県福井市円成寺町');
ok($zip->set_number('9102176')->is_valid_number, '福井県福井市東郷中島町');
ok($zip->set_number('9102177')->is_valid_number, '福井県福井市稲津町');
ok($zip->set_number('9102178')->is_valid_number, '福井県福井市栂野町');
ok($zip->set_number('9102201')->is_valid_number, '福井県福井市皿谷町');
ok($zip->set_number('9102202')->is_valid_number, '福井県福井市所谷町');
ok($zip->set_number('9102203')->is_valid_number, '福井県福井市西中町');
ok($zip->set_number('9102204')->is_valid_number, '福井県福井市美山大谷町');
ok($zip->set_number('9102205')->is_valid_number, '福井県福井市篭谷町');
ok($zip->set_number('9102206')->is_valid_number, '福井県福井市吉山町(上吉山)');
ok($zip->set_number('9102207')->is_valid_number, '福井県福井市吉山町(下吉山)');
ok($zip->set_number('9102208')->is_valid_number, '福井県福井市吉山町(その他)');
ok($zip->set_number('9102211')->is_valid_number, '福井県福井市獺ケ口町');
ok($zip->set_number('9102212')->is_valid_number, '福井県福井市小和清水町');
ok($zip->set_number('9102213')->is_valid_number, '福井県福井市大久保町');
ok($zip->set_number('9102214')->is_valid_number, '福井県福井市福島町');
ok($zip->set_number('9102221')->is_valid_number, '福井県福井市奈良瀬町');
ok($zip->set_number('9102222')->is_valid_number, '福井県福井市市波町');
ok($zip->set_number('9102223')->is_valid_number, '福井県福井市宇坂別所町');
ok($zip->set_number('9102224')->is_valid_number, '福井県福井市三万谷町');
ok($zip->set_number('9102225')->is_valid_number, '福井県福井市田尻町');
ok($zip->set_number('9102226')->is_valid_number, '福井県福井市高田町');
ok($zip->set_number('9102227')->is_valid_number, '福井県福井市宇坂大谷町');
ok($zip->set_number('9102331')->is_valid_number, '福井県福井市計石町');
ok($zip->set_number('9102332')->is_valid_number, '福井県福井市野波町(その他)');
ok($zip->set_number('9102333')->is_valid_number, '福井県福井市野波町(追分)');
ok($zip->set_number('9102334')->is_valid_number, '福井県福井市大宮町');
ok($zip->set_number('9102335')->is_valid_number, '福井県福井市縫原町');
ok($zip->set_number('9102336')->is_valid_number, '福井県福井市仁位町');
ok($zip->set_number('9102337')->is_valid_number, '福井県福井市薬師町(上薬師)');
ok($zip->set_number('9102338')->is_valid_number, '福井県福井市薬師町(下薬師)');
ok($zip->set_number('9102339')->is_valid_number, '福井県福井市薬師町(その他)');
ok($zip->set_number('9102341')->is_valid_number, '福井県福井市東川上町');
ok($zip->set_number('9102342')->is_valid_number, '福井県福井市東俣町');
ok($zip->set_number('9102343')->is_valid_number, '福井県福井市南西俣町');
ok($zip->set_number('9102344')->is_valid_number, '福井県福井市南宮地町');
ok($zip->set_number('9102345')->is_valid_number, '福井県福井市間戸町');
ok($zip->set_number('9102346')->is_valid_number, '福井県福井市椙谷町');
ok($zip->set_number('9102347')->is_valid_number, '福井県福井市境寺町');
ok($zip->set_number('9102348')->is_valid_number, '福井県福井市品ケ瀬町');
ok($zip->set_number('9102351')->is_valid_number, '福井県福井市美山町');
ok($zip->set_number('9102352')->is_valid_number, '福井県福井市小宇坂町');
ok($zip->set_number('9102353')->is_valid_number, '福井県福井市小宇坂島町');
ok($zip->set_number('9102354')->is_valid_number, '福井県福井市東天田町');
ok($zip->set_number('9102355')->is_valid_number, '福井県福井市西天田町');
ok($zip->set_number('9102356')->is_valid_number, '福井県福井市蔵作町');
ok($zip->set_number('9102357')->is_valid_number, '福井県福井市朝谷町');
ok($zip->set_number('9102461')->is_valid_number, '福井県福井市南野津又町');
ok($zip->set_number('9102462')->is_valid_number, '福井県福井市神当部町');
ok($zip->set_number('9102463')->is_valid_number, '福井県福井市味見河内町');
ok($zip->set_number('9102464')->is_valid_number, '福井県福井市中手町');
ok($zip->set_number('9102465')->is_valid_number, '福井県福井市小当見町');
ok($zip->set_number('9102466')->is_valid_number, '福井県福井市西市布町');
ok($zip->set_number('9102471')->is_valid_number, '福井県福井市西河原町');
ok($zip->set_number('9102472')->is_valid_number, '福井県福井市東河原町');
ok($zip->set_number('9102473')->is_valid_number, '福井県福井市横越町');
ok($zip->set_number('9102474')->is_valid_number, '福井県福井市折立町');
ok($zip->set_number('9102475')->is_valid_number, '福井県福井市赤谷町');
ok($zip->set_number('9102500')->is_valid_number, '福井県今立郡池田町以下に掲載がない場合');
ok($zip->set_number('9102501')->is_valid_number, '福井県今立郡池田町持越');
ok($zip->set_number('9102502')->is_valid_number, '福井県今立郡池田町野尻');
ok($zip->set_number('9102503')->is_valid_number, '福井県今立郡池田町谷口');
ok($zip->set_number('9102504')->is_valid_number, '福井県今立郡池田町安善寺');
ok($zip->set_number('9102505')->is_valid_number, '福井県今立郡池田町水海');
ok($zip->set_number('9102506')->is_valid_number, '福井県今立郡池田町広瀬');
ok($zip->set_number('9102507')->is_valid_number, '福井県今立郡池田町清水谷');
ok($zip->set_number('9102508')->is_valid_number, '福井県今立郡池田町柿ケ原');
ok($zip->set_number('9102511')->is_valid_number, '福井県今立郡池田町薮田');
ok($zip->set_number('9102512')->is_valid_number, '福井県今立郡池田町稲荷');
ok($zip->set_number('9102513')->is_valid_number, '福井県今立郡池田町寺島');
ok($zip->set_number('9102514')->is_valid_number, '福井県今立郡池田町学園');
ok($zip->set_number('9102515')->is_valid_number, '福井県今立郡池田町池田');
ok($zip->set_number('9102516')->is_valid_number, '福井県今立郡池田町山田');
ok($zip->set_number('9102517')->is_valid_number, '福井県今立郡池田町寺谷');
ok($zip->set_number('9102521')->is_valid_number, '福井県今立郡池田町常安');
ok($zip->set_number('9102522')->is_valid_number, '福井県今立郡池田町月ケ瀬');
ok($zip->set_number('9102523')->is_valid_number, '福井県今立郡池田町河内');
ok($zip->set_number('9102523')->is_valid_number, '福井県今立郡池田町志津原');
ok($zip->set_number('9102524')->is_valid_number, '福井県今立郡池田町土合皿尾');
ok($zip->set_number('9102525')->is_valid_number, '福井県今立郡池田町市');
ok($zip->set_number('9102526')->is_valid_number, '福井県今立郡池田町上荒谷');
ok($zip->set_number('9102527')->is_valid_number, '福井県今立郡池田町板垣');
ok($zip->set_number('9102531')->is_valid_number, '福井県今立郡池田町東角間');
ok($zip->set_number('9102532')->is_valid_number, '福井県今立郡池田町新保');
ok($zip->set_number('9102533')->is_valid_number, '福井県今立郡池田町東俣');
ok($zip->set_number('9102534')->is_valid_number, '福井県今立郡池田町魚見');
ok($zip->set_number('9102535')->is_valid_number, '福井県今立郡池田町菅生');
ok($zip->set_number('9102536')->is_valid_number, '福井県今立郡池田町西角間');
ok($zip->set_number('9102537')->is_valid_number, '福井県今立郡池田町定方');
ok($zip->set_number('9102551')->is_valid_number, '福井県今立郡池田町尾緩');
ok($zip->set_number('9102552')->is_valid_number, '福井県今立郡池田町大本');
ok($zip->set_number('9102553')->is_valid_number, '福井県今立郡池田町籠掛');
ok($zip->set_number('9102554')->is_valid_number, '福井県今立郡池田町金見谷');
ok($zip->set_number('9102555')->is_valid_number, '福井県今立郡池田町千代谷');
ok($zip->set_number('9102556')->is_valid_number, '福井県今立郡池田町白粟');
ok($zip->set_number('9102556')->is_valid_number, '福井県今立郡池田町松ケ谷');
ok($zip->set_number('9102557')->is_valid_number, '福井県今立郡池田町小畑');
ok($zip->set_number('9103101')->is_valid_number, '福井県福井市昭和新町');
ok($zip->set_number('9103102')->is_valid_number, '福井県福井市小尉町');
ok($zip->set_number('9103103')->is_valid_number, '福井県福井市三宅町');
ok($zip->set_number('9103104')->is_valid_number, '福井県福井市布施田町');
ok($zip->set_number('9103105')->is_valid_number, '福井県福井市西中野町');
ok($zip->set_number('9103106')->is_valid_number, '福井県福井市池尻町');
ok($zip->set_number('9103107')->is_valid_number, '福井県福井市黒丸城町');
ok($zip->set_number('9103111')->is_valid_number, '福井県福井市島山梨子町');
ok($zip->set_number('9103112')->is_valid_number, '福井県福井市御所垣内町');
ok($zip->set_number('9103113')->is_valid_number, '福井県福井市江上町');
ok($zip->set_number('9103114')->is_valid_number, '福井県福井市剣大谷町');
ok($zip->set_number('9103115')->is_valid_number, '福井県福井市仙町');
ok($zip->set_number('9103116')->is_valid_number, '福井県福井市内山梨子町');
ok($zip->set_number('9103117')->is_valid_number, '福井県福井市浄土寺町');
ok($zip->set_number('9103118')->is_valid_number, '福井県福井市上野町');
ok($zip->set_number('9103121')->is_valid_number, '福井県福井市佐野町');
ok($zip->set_number('9103122')->is_valid_number, '福井県福井市小野町');
ok($zip->set_number('9103123')->is_valid_number, '福井県福井市石畠町');
ok($zip->set_number('9103124')->is_valid_number, '福井県福井市田ノ頭町');
ok($zip->set_number('9103125')->is_valid_number, '福井県福井市市ノ瀬町');
ok($zip->set_number('9103126')->is_valid_number, '福井県福井市深坂町');
ok($zip->set_number('9103127')->is_valid_number, '福井県福井市中山町');
ok($zip->set_number('9103128')->is_valid_number, '福井県福井市為寄町');
ok($zip->set_number('9103131')->is_valid_number, '福井県福井市白方町');
ok($zip->set_number('9103132')->is_valid_number, '福井県福井市浜島町');
ok($zip->set_number('9103133')->is_valid_number, '福井県福井市石新保町');
ok($zip->set_number('9103134')->is_valid_number, '福井県福井市浜別所町');
ok($zip->set_number('9103135')->is_valid_number, '福井県福井市両橋屋町');
ok($zip->set_number('9103136')->is_valid_number, '福井県福井市川尻町');
ok($zip->set_number('9103137')->is_valid_number, '福井県福井市石橋町');
ok($zip->set_number('9103138')->is_valid_number, '福井県福井市テクノポート');
ok($zip->set_number('9103141')->is_valid_number, '福井県福井市砂子田町');
ok($zip->set_number('9103142')->is_valid_number, '福井県福井市波寄町');
ok($zip->set_number('9103143')->is_valid_number, '福井県福井市砂子坂町');
ok($zip->set_number('9103144')->is_valid_number, '福井県福井市水切町');
ok($zip->set_number('9103145')->is_valid_number, '福井県福井市串野町');
ok($zip->set_number('9103146')->is_valid_number, '福井県福井市小幡町');
ok($zip->set_number('9103147')->is_valid_number, '福井県福井市木下町');
ok($zip->set_number('9103148')->is_valid_number, '福井県福井市菖蒲谷町');
ok($zip->set_number('9103251')->is_valid_number, '福井県福井市荒谷町');
ok($zip->set_number('9103252')->is_valid_number, '福井県福井市燈豊町');
ok($zip->set_number('9103253')->is_valid_number, '福井県福井市大谷町');
ok($zip->set_number('9103254')->is_valid_number, '福井県福井市八幡町');
ok($zip->set_number('9103255')->is_valid_number, '福井県福井市大年町');
ok($zip->set_number('9103256')->is_valid_number, '福井県福井市中町');
ok($zip->set_number('9103261')->is_valid_number, '福井県福井市西荒井町');
ok($zip->set_number('9103262')->is_valid_number, '福井県福井市一王寺町');
ok($zip->set_number('9103263')->is_valid_number, '福井県福井市中河内町');
ok($zip->set_number('9103264')->is_valid_number, '福井県福井市木米町');
ok($zip->set_number('9103265')->is_valid_number, '福井県福井市柿谷町');
ok($zip->set_number('9103266')->is_valid_number, '福井県福井市足谷町');
ok($zip->set_number('9103266')->is_valid_number, '福井県福井市猫瀬町');
ok($zip->set_number('9103266')->is_valid_number, '福井県福井市東平町');
ok($zip->set_number('9103267')->is_valid_number, '福井県福井市河内町');
ok($zip->set_number('9103268')->is_valid_number, '福井県福井市奥平町');
ok($zip->set_number('9103268')->is_valid_number, '福井県福井市清水平町');
ok($zip->set_number('9103268')->is_valid_number, '福井県福井市中平町');
ok($zip->set_number('9103371')->is_valid_number, '福井県福井市大窪町');
ok($zip->set_number('9103372')->is_valid_number, '福井県福井市西二ツ屋町');
ok($zip->set_number('9103373')->is_valid_number, '福井県福井市西畑町');
ok($zip->set_number('9103374')->is_valid_number, '福井県福井市高須町');
ok($zip->set_number('9103375')->is_valid_number, '福井県福井市宮郷町');
ok($zip->set_number('9103376')->is_valid_number, '福井県福井市和布町');
ok($zip->set_number('9103377')->is_valid_number, '福井県福井市浜住町');
ok($zip->set_number('9103378')->is_valid_number, '福井県福井市免鳥町');
ok($zip->set_number('9103381')->is_valid_number, '福井県福井市蓑町');
ok($zip->set_number('9103382')->is_valid_number, '福井県福井市松蔭町');
ok($zip->set_number('9103383')->is_valid_number, '福井県福井市糸崎町');
ok($zip->set_number('9103384')->is_valid_number, '福井県福井市長橋町');
ok($zip->set_number('9103385')->is_valid_number, '福井県福井市北菅生町');
ok($zip->set_number('9103386')->is_valid_number, '福井県福井市南菅生町');
ok($zip->set_number('9103401')->is_valid_number, '福井県福井市国見町');
ok($zip->set_number('9103402')->is_valid_number, '福井県福井市鮎川町');
ok($zip->set_number('9103403')->is_valid_number, '福井県福井市白浜町');
ok($zip->set_number('9103404')->is_valid_number, '福井県福井市大丹生町');
ok($zip->set_number('9103405')->is_valid_number, '福井県福井市小丹生町');
ok($zip->set_number('9103511')->is_valid_number, '福井県福井市白滝町');
ok($zip->set_number('9103512')->is_valid_number, '福井県福井市西別所町');
ok($zip->set_number('9103513')->is_valid_number, '福井県福井市宿堂町');
ok($zip->set_number('9103514')->is_valid_number, '福井県福井市水谷町');
ok($zip->set_number('9103515')->is_valid_number, '福井県福井市大矢町');
ok($zip->set_number('9103516')->is_valid_number, '福井県福井市風尾町');
ok($zip->set_number('9103517')->is_valid_number, '福井県福井市畠中町');
ok($zip->set_number('9103518')->is_valid_number, '福井県福井市国山町');
ok($zip->set_number('9103521')->is_valid_number, '福井県福井市千合町');
ok($zip->set_number('9103522')->is_valid_number, '福井県福井市謡谷町');
ok($zip->set_number('9103523')->is_valid_number, '福井県福井市武周町');
ok($zip->set_number('9103524')->is_valid_number, '福井県福井市別畑町');
ok($zip->set_number('9103525')->is_valid_number, '福井県福井市尼ケ谷町');
ok($zip->set_number('9103526')->is_valid_number, '福井県福井市二ツ屋町');
ok($zip->set_number('9103551')->is_valid_number, '福井県福井市大味町');
ok($zip->set_number('9103552')->is_valid_number, '福井県福井市茱崎町');
ok($zip->set_number('9103553')->is_valid_number, '福井県福井市蒲生町');
ok($zip->set_number('9103554')->is_valid_number, '福井県福井市浜北山町');
ok($zip->set_number('9103555')->is_valid_number, '福井県福井市居倉町');
ok($zip->set_number('9103556')->is_valid_number, '福井県福井市赤坂町');
ok($zip->set_number('9103557')->is_valid_number, '福井県福井市城有町');
ok($zip->set_number('9103558')->is_valid_number, '福井県福井市八ツ俣町');
ok($zip->set_number('9103601')->is_valid_number, '福井県福井市清水町');
ok($zip->set_number('9103602')->is_valid_number, '福井県福井市竹生町');
ok($zip->set_number('9103603')->is_valid_number, '福井県福井市片粕町');
ok($zip->set_number('9103604')->is_valid_number, '福井県福井市グリーンハイツ');
ok($zip->set_number('9103605')->is_valid_number, '福井県福井市朝宮町');
ok($zip->set_number('9103606')->is_valid_number, '福井県福井市田尻栃谷町');
ok($zip->set_number('9103607')->is_valid_number, '福井県福井市清水杉谷町');
ok($zip->set_number('9103608')->is_valid_number, '福井県福井市三留町');
ok($zip->set_number('9103611')->is_valid_number, '福井県福井市片山町');
ok($zip->set_number('9103612')->is_valid_number, '福井県福井市清水山町');
ok($zip->set_number('9103613')->is_valid_number, '福井県福井市甑谷町');
ok($zip->set_number('9103614')->is_valid_number, '福井県福井市在田町');
ok($zip->set_number('9103615')->is_valid_number, '福井県福井市坪谷町');
ok($zip->set_number('9103616')->is_valid_number, '福井県福井市真栗町');
ok($zip->set_number('9103617')->is_valid_number, '福井県福井市御油町');
ok($zip->set_number('9103621')->is_valid_number, '福井県福井市小羽町');
ok($zip->set_number('9103622')->is_valid_number, '福井県福井市風巻町');
ok($zip->set_number('9103623')->is_valid_number, '福井県福井市島寺町');
ok($zip->set_number('9103631')->is_valid_number, '福井県福井市和田町');
ok($zip->set_number('9103632')->is_valid_number, '福井県福井市下天下町');
ok($zip->set_number('9103633')->is_valid_number, '福井県福井市上天下町');
ok($zip->set_number('9103634')->is_valid_number, '福井県福井市大森町');
ok($zip->set_number('9103635')->is_valid_number, '福井県福井市志津が丘');
ok($zip->set_number('9103636')->is_valid_number, '福井県福井市山内町');
ok($zip->set_number('9103641')->is_valid_number, '福井県福井市平尾町');
ok($zip->set_number('9103642')->is_valid_number, '福井県福井市本折町');
ok($zip->set_number('9103643')->is_valid_number, '福井県福井市滝波町');
ok($zip->set_number('9103644')->is_valid_number, '福井県福井市加茂内町');
ok($zip->set_number('9103644')->is_valid_number, '福井県福井市加茂町');
ok($zip->set_number('9103645')->is_valid_number, '福井県福井市笹谷町');
ok($zip->set_number('9103646')->is_valid_number, '福井県福井市清水畑町');
ok($zip->set_number('9104102')->is_valid_number, '福井県あわら市芦鶴');
ok($zip->set_number('9104103')->is_valid_number, '福井県あわら市二面');
ok($zip->set_number('9104104')->is_valid_number, '福井県あわら市温泉');
ok($zip->set_number('9104105')->is_valid_number, '福井県あわら市舟津');
ok($zip->set_number('9104111')->is_valid_number, '福井県あわら市牛山');
ok($zip->set_number('9104112')->is_valid_number, '福井県あわら市井江葭');
ok($zip->set_number('9104113')->is_valid_number, '福井県あわら市横垣');
ok($zip->set_number('9104115')->is_valid_number, '福井県あわら市国影');
ok($zip->set_number('9104121')->is_valid_number, '福井県あわら市東温泉');
ok($zip->set_number('9104122')->is_valid_number, '福井県あわら市重義');
ok($zip->set_number('9104123')->is_valid_number, '福井県あわら市番田');
ok($zip->set_number('9104124')->is_valid_number, '福井県あわら市田中々');
ok($zip->set_number('9104125')->is_valid_number, '福井県あわら市堀江十楽');
ok($zip->set_number('9104126')->is_valid_number, '福井県あわら市布目');
ok($zip->set_number('9104127')->is_valid_number, '福井県あわら市西温泉');
ok($zip->set_number('9104131')->is_valid_number, '福井県あわら市東善寺');
ok($zip->set_number('9104132')->is_valid_number, '福井県あわら市谷畠');
ok($zip->set_number('9104133')->is_valid_number, '福井県あわら市轟木');
ok($zip->set_number('9104134')->is_valid_number, '福井県あわら市上番');
ok($zip->set_number('9104137')->is_valid_number, '福井県あわら市中番');
ok($zip->set_number('9104138')->is_valid_number, '福井県あわら市下番');
ok($zip->set_number('9104141')->is_valid_number, '福井県あわら市玉木');
ok($zip->set_number('9104142')->is_valid_number, '福井県あわら市河間');
ok($zip->set_number('9104144')->is_valid_number, '福井県あわら市中浜');
ok($zip->set_number('9104145')->is_valid_number, '福井県あわら市角屋');
ok($zip->set_number('9104146')->is_valid_number, '福井県あわら市北本堂');
ok($zip->set_number('9104147')->is_valid_number, '福井県あわら市公文');
ok($zip->set_number('9104147')->is_valid_number, '福井県あわら市宮前');
ok($zip->set_number('9104271')->is_valid_number, '福井県あわら市浜坂');
ok($zip->set_number('9104272')->is_valid_number, '福井県あわら市北潟');
ok($zip->set_number('9104272')->is_valid_number, '福井県あわら市富津(北潟)');
ok($zip->set_number('9104273')->is_valid_number, '福井県あわら市赤尾');
ok($zip->set_number('9104274')->is_valid_number, '福井県あわら市番堂野');
ok($zip->set_number('9104275')->is_valid_number, '福井県あわら市城新田');
ok($zip->set_number('9104276')->is_valid_number, '福井県あわら市十三(城)');
ok($zip->set_number('9104276')->is_valid_number, '福井県あわら市城');
ok($zip->set_number('9104277')->is_valid_number, '福井県あわら市波松');
ok($zip->set_number('9110000')->is_valid_number, '福井県勝山市以下に掲載がない場合');
ok($zip->set_number('9110001')->is_valid_number, '福井県勝山市北谷町小原');
ok($zip->set_number('9110002')->is_valid_number, '福井県勝山市北谷町木根橋');
ok($zip->set_number('9110003')->is_valid_number, '福井県勝山市北谷町河合');
ok($zip->set_number('9110004')->is_valid_number, '福井県勝山市北谷町北六呂師');
ok($zip->set_number('9110004')->is_valid_number, '福井県勝山市北谷町中尾');
ok($zip->set_number('9110005')->is_valid_number, '福井県勝山市北谷町杉山');
ok($zip->set_number('9110006')->is_valid_number, '福井県勝山市北谷町谷');
ok($zip->set_number('9110011')->is_valid_number, '福井県勝山市野向町牛ケ谷');
ok($zip->set_number('9110012')->is_valid_number, '福井県勝山市野向町薬師神谷');
ok($zip->set_number('9110013')->is_valid_number, '福井県勝山市野向町深谷');
ok($zip->set_number('9110014')->is_valid_number, '福井県勝山市野向町聖丸');
ok($zip->set_number('9110015')->is_valid_number, '福井県勝山市野向町竹林');
ok($zip->set_number('9110016')->is_valid_number, '福井県勝山市野向町龍谷');
ok($zip->set_number('9110017')->is_valid_number, '福井県勝山市野向町北野津又');
ok($zip->set_number('9110017')->is_valid_number, '福井県勝山市野向町横倉');
ok($zip->set_number('9110021')->is_valid_number, '福井県勝山市村岡町栃神谷');
ok($zip->set_number('9110022')->is_valid_number, '福井県勝山市村岡町暮見');
ok($zip->set_number('9110022')->is_valid_number, '福井県勝山市芳野ケ原');
ok($zip->set_number('9110023')->is_valid_number, '福井県勝山市村岡町寺尾');
ok($zip->set_number('9110024')->is_valid_number, '福井県勝山市村岡町浄土寺');
ok($zip->set_number('9110025')->is_valid_number, '福井県勝山市村岡町五本寺');
ok($zip->set_number('9110026')->is_valid_number, '福井県勝山市村岡町黒原');
ok($zip->set_number('9110031')->is_valid_number, '福井県勝山市長山町');
ok($zip->set_number('9110032')->is_valid_number, '福井県勝山市芳野町');
ok($zip->set_number('9110033')->is_valid_number, '福井県勝山市栄町');
ok($zip->set_number('9110034')->is_valid_number, '福井県勝山市滝波町');
ok($zip->set_number('9110035')->is_valid_number, '福井県勝山市郡町');
ok($zip->set_number('9110041')->is_valid_number, '福井県勝山市荒土町北新在家');
ok($zip->set_number('9110041')->is_valid_number, '福井県勝山市荒土町清水島');
ok($zip->set_number('9110041')->is_valid_number, '福井県勝山市荒土町布市');
ok($zip->set_number('9110042')->is_valid_number, '福井県勝山市荒土町田名部');
ok($zip->set_number('9110042')->is_valid_number, '福井県勝山市荒土町松田');
ok($zip->set_number('9110043')->is_valid_number, '福井県勝山市荒土町新保');
ok($zip->set_number('9110044')->is_valid_number, '福井県勝山市荒土町松ケ崎');
ok($zip->set_number('9110045')->is_valid_number, '福井県勝山市荒土町伊波');
ok($zip->set_number('9110045')->is_valid_number, '福井県勝山市荒土町妙金島');
ok($zip->set_number('9110046')->is_valid_number, '福井県勝山市荒土町中清水');
ok($zip->set_number('9110046')->is_valid_number, '福井県勝山市荒土町堀名');
ok($zip->set_number('9110046')->is_valid_number, '福井県勝山市荒土町堀名中清水');
ok($zip->set_number('9110047')->is_valid_number, '福井県勝山市荒土町北宮地');
ok($zip->set_number('9110048')->is_valid_number, '福井県勝山市荒土町境');
ok($zip->set_number('9110048')->is_valid_number, '福井県勝山市荒土町新道');
ok($zip->set_number('9110048')->is_valid_number, '福井県勝山市荒土町戸倉');
ok($zip->set_number('9110048')->is_valid_number, '福井県勝山市荒土町西ケ原');
ok($zip->set_number('9110048')->is_valid_number, '福井県勝山市荒土町別所');
ok($zip->set_number('9110048')->is_valid_number, '福井県勝山市荒土町細野');
ok($zip->set_number('9110048')->is_valid_number, '福井県勝山市荒土町細野口');
ok($zip->set_number('9110051')->is_valid_number, '福井県勝山市北郷町新町');
ok($zip->set_number('9110051')->is_valid_number, '福井県勝山市北郷町志比原');
ok($zip->set_number('9110051')->is_valid_number, '福井県勝山市北郷町檜曽谷');
ok($zip->set_number('9110052')->is_valid_number, '福井県勝山市北郷町西妙金島');
ok($zip->set_number('9110053')->is_valid_number, '福井県勝山市北郷町上森川');
ok($zip->set_number('9110053')->is_valid_number, '福井県勝山市北郷町下森川');
ok($zip->set_number('9110053')->is_valid_number, '福井県勝山市北郷町森川');
ok($zip->set_number('9110054')->is_valid_number, '福井県勝山市北郷町東野');
ok($zip->set_number('9110055')->is_valid_number, '福井県勝山市北郷町伊知地');
ok($zip->set_number('9110055')->is_valid_number, '福井県勝山市北郷町岩屋');
ok($zip->set_number('9110055')->is_valid_number, '福井県勝山市北郷町上野');
ok($zip->set_number('9110056')->is_valid_number, '福井県勝山市北郷町坂東島');
ok($zip->set_number('9110801')->is_valid_number, '福井県勝山市沢町');
ok($zip->set_number('9110802')->is_valid_number, '福井県勝山市昭和町');
ok($zip->set_number('9110803')->is_valid_number, '福井県勝山市旭町');
ok($zip->set_number('9110804')->is_valid_number, '福井県勝山市元町');
ok($zip->set_number('9110805')->is_valid_number, '福井県勝山市立川町');
ok($zip->set_number('9110806')->is_valid_number, '福井県勝山市本町');
ok($zip->set_number('9110811')->is_valid_number, '福井県勝山市片瀬');
ok($zip->set_number('9110811')->is_valid_number, '福井県勝山市片瀬町');
ok($zip->set_number('9110812')->is_valid_number, '福井県勝山市猪野');
ok($zip->set_number('9110813')->is_valid_number, '福井県勝山市猪野口');
ok($zip->set_number('9110814')->is_valid_number, '福井県勝山市若猪野');
ok($zip->set_number('9110815')->is_valid_number, '福井県勝山市上高島');
ok($zip->set_number('9110815')->is_valid_number, '福井県勝山市北市');
ok($zip->set_number('9110815')->is_valid_number, '福井県勝山市下高島');
ok($zip->set_number('9110815')->is_valid_number, '福井県勝山市高島');
ok($zip->set_number('9110815')->is_valid_number, '福井県勝山市西高島');
ok($zip->set_number('9110816')->is_valid_number, '福井県勝山市猪野毛屋');
ok($zip->set_number('9110816')->is_valid_number, '福井県勝山市毛屋');
ok($zip->set_number('9110816')->is_valid_number, '福井県勝山市毛屋町');
ok($zip->set_number('9110816')->is_valid_number, '福井県勝山市下毛屋');
ok($zip->set_number('9110817')->is_valid_number, '福井県勝山市旭毛屋町');
ok($zip->set_number('9110821')->is_valid_number, '福井県勝山市平泉寺町岡横江');
ok($zip->set_number('9110822')->is_valid_number, '福井県勝山市平泉寺町神野');
ok($zip->set_number('9110822')->is_valid_number, '福井県勝山市平泉寺町平泉寺');
ok($zip->set_number('9110823')->is_valid_number, '福井県勝山市平泉寺町赤尾');
ok($zip->set_number('9110824')->is_valid_number, '福井県勝山市平泉寺町池ケ原');
ok($zip->set_number('9110824')->is_valid_number, '福井県勝山市平泉寺町大矢谷');
ok($zip->set_number('9110824')->is_valid_number, '福井県勝山市平泉寺町小矢谷');
ok($zip->set_number('9110825')->is_valid_number, '福井県勝山市平泉寺町岩ケ野');
ok($zip->set_number('9110825')->is_valid_number, '福井県勝山市平泉寺町上野');
ok($zip->set_number('9110826')->is_valid_number, '福井県勝山市平泉寺町壁倉');
ok($zip->set_number('9110827')->is_valid_number, '福井県勝山市平泉寺町笹尾');
ok($zip->set_number('9110828')->is_valid_number, '福井県勝山市平泉寺町大渡');
ok($zip->set_number('9110828')->is_valid_number, '福井県勝山市平泉寺町経塚');
ok($zip->set_number('9110831')->is_valid_number, '福井県勝山市遅羽町千代田');
ok($zip->set_number('9110831')->is_valid_number, '福井県勝山市遅羽町中島');
ok($zip->set_number('9110831')->is_valid_number, '福井県勝山市遅羽町比島');
ok($zip->set_number('9110832')->is_valid_number, '福井県勝山市遅羽町蓬生');
ok($zip->set_number('9110833')->is_valid_number, '福井県勝山市遅羽町北山');
ok($zip->set_number('9110834')->is_valid_number, '福井県勝山市遅羽町大袋');
ok($zip->set_number('9110834')->is_valid_number, '福井県勝山市遅羽町新道');
ok($zip->set_number('9110835')->is_valid_number, '福井県勝山市遅羽町ほう崎');
ok($zip->set_number('9110836')->is_valid_number, '福井県勝山市遅羽町下荒井');
ok($zip->set_number('9110841')->is_valid_number, '福井県勝山市鹿谷町発坂');
ok($zip->set_number('9110842')->is_valid_number, '福井県勝山市鹿谷町志田');
ok($zip->set_number('9110843')->is_valid_number, '福井県勝山市鹿谷町杉俣');
ok($zip->set_number('9110843')->is_valid_number, '福井県勝山市鹿谷町本郷');
ok($zip->set_number('9110844')->is_valid_number, '福井県勝山市鹿谷町東遅羽口');
ok($zip->set_number('9110844')->is_valid_number, '福井県勝山市鹿谷町西遅羽口');
ok($zip->set_number('9110845')->is_valid_number, '福井県勝山市鹿谷町矢戸口');
ok($zip->set_number('9110846')->is_valid_number, '福井県勝山市鹿谷町北西俣');
ok($zip->set_number('9110847')->is_valid_number, '福井県勝山市鹿谷町西光寺');
ok($zip->set_number('9110848')->is_valid_number, '福井県勝山市鹿谷町出村');
ok($zip->set_number('9110848')->is_valid_number, '福井県勝山市鹿谷町保田');
ok($zip->set_number('9110848')->is_valid_number, '福井県勝山市鹿谷町保田出村');
ok($zip->set_number('9120000')->is_valid_number, '福井県大野市以下に掲載がない場合');
ok($zip->set_number('9120001')->is_valid_number, '福井県大野市大矢戸');
ok($zip->set_number('9120002')->is_valid_number, '福井県大野市小矢戸');
ok($zip->set_number('9120003')->is_valid_number, '福井県大野市西大月');
ok($zip->set_number('9120003')->is_valid_number, '福井県大野市東大月');
ok($zip->set_number('9120004')->is_valid_number, '福井県大野市中津川');
ok($zip->set_number('9120005')->is_valid_number, '福井県大野市太田');
ok($zip->set_number('9120006')->is_valid_number, '福井県大野市庄林');
ok($zip->set_number('9120007')->is_valid_number, '福井県大野市西市');
ok($zip->set_number('9120008')->is_valid_number, '福井県大野市矢');
ok($zip->set_number('9120011')->is_valid_number, '福井県大野市南新在家');
ok($zip->set_number('9120012')->is_valid_number, '福井県大野市横枕');
ok($zip->set_number('9120013')->is_valid_number, '福井県大野市堂本');
ok($zip->set_number('9120014')->is_valid_number, '福井県大野市中保');
ok($zip->set_number('9120015')->is_valid_number, '福井県大野市中挾');
ok($zip->set_number('9120016')->is_valid_number, '福井県大野市友江');
ok($zip->set_number('9120017')->is_valid_number, '福井県大野市東中野');
ok($zip->set_number('9120021')->is_valid_number, '福井県大野市中野');
ok($zip->set_number('9120021')->is_valid_number, '福井県大野市中野町');
ok($zip->set_number('9120022')->is_valid_number, '福井県大野市陽明町');
ok($zip->set_number('9120023')->is_valid_number, '福井県大野市中荒井');
ok($zip->set_number('9120023')->is_valid_number, '福井県大野市中荒井町');
ok($zip->set_number('9120024')->is_valid_number, '福井県大野市錦町');
ok($zip->set_number('9120025')->is_valid_number, '福井県大野市本町');
ok($zip->set_number('9120026')->is_valid_number, '福井県大野市要町');
ok($zip->set_number('9120027')->is_valid_number, '福井県大野市新町');
ok($zip->set_number('9120031')->is_valid_number, '福井県大野市月美町');
ok($zip->set_number('9120032')->is_valid_number, '福井県大野市清和町');
ok($zip->set_number('9120033')->is_valid_number, '福井県大野市美里町');
ok($zip->set_number('9120034')->is_valid_number, '福井県大野市吉野町');
ok($zip->set_number('9120035')->is_valid_number, '福井県大野市有明町');
ok($zip->set_number('9120036')->is_valid_number, '福井県大野市美川町');
ok($zip->set_number('9120041')->is_valid_number, '福井県大野市菖蒲池');
ok($zip->set_number('9120042')->is_valid_number, '福井県大野市東中');
ok($zip->set_number('9120042')->is_valid_number, '福井県大野市東中町');
ok($zip->set_number('9120043')->is_valid_number, '福井県大野市国時町');
ok($zip->set_number('9120044')->is_valid_number, '福井県大野市桜塚町');
ok($zip->set_number('9120045')->is_valid_number, '福井県大野市若杉町');
ok($zip->set_number('9120046')->is_valid_number, '福井県大野市神明');
ok($zip->set_number('9120046')->is_valid_number, '福井県大野市神明町');
ok($zip->set_number('9120047')->is_valid_number, '福井県大野市幸町');
ok($zip->set_number('9120051')->is_valid_number, '福井県大野市日吉町');
ok($zip->set_number('9120052')->is_valid_number, '福井県大野市弥生町');
ok($zip->set_number('9120053')->is_valid_number, '福井県大野市春日');
ok($zip->set_number('9120054')->is_valid_number, '福井県大野市糸魚町');
ok($zip->set_number('9120055')->is_valid_number, '福井県大野市高砂町');
ok($zip->set_number('9120061')->is_valid_number, '福井県大野市篠座');
ok($zip->set_number('9120061')->is_valid_number, '福井県大野市篠座町');
ok($zip->set_number('9120062')->is_valid_number, '福井県大野市千歳');
ok($zip->set_number('9120063')->is_valid_number, '福井県大野市阿難祖地頭方');
ok($zip->set_number('9120063')->is_valid_number, '福井県大野市阿難祖領家');
ok($zip->set_number('9120064')->is_valid_number, '福井県大野市上舌');
ok($zip->set_number('9120065')->is_valid_number, '福井県大野市下舌');
ok($zip->set_number('9120066')->is_valid_number, '福井県大野市南春日野');
ok($zip->set_number('9120067')->is_valid_number, '福井県大野市右近次郎');
ok($zip->set_number('9120068')->is_valid_number, '福井県大野市茜町');
ok($zip->set_number('9120071')->is_valid_number, '福井県大野市鍬掛');
ok($zip->set_number('9120072')->is_valid_number, '福井県大野市飯降');
ok($zip->set_number('9120073')->is_valid_number, '福井県大野市深井');
ok($zip->set_number('9120074')->is_valid_number, '福井県大野市上荒井');
ok($zip->set_number('9120075')->is_valid_number, '福井県大野市下黒谷');
ok($zip->set_number('9120076')->is_valid_number, '福井県大野市上黒谷');
ok($zip->set_number('9120081')->is_valid_number, '福井県大野市元町');
ok($zip->set_number('9120082')->is_valid_number, '福井県大野市大和町');
ok($zip->set_number('9120083')->is_valid_number, '福井県大野市明倫町');
ok($zip->set_number('9120084')->is_valid_number, '福井県大野市天神町');
ok($zip->set_number('9120085')->is_valid_number, '福井県大野市新庄');
ok($zip->set_number('9120086')->is_valid_number, '福井県大野市泉町');
ok($zip->set_number('9120086')->is_valid_number, '福井県大野市清水');
ok($zip->set_number('9120087')->is_valid_number, '福井県大野市亀山');
ok($zip->set_number('9120087')->is_valid_number, '福井県大野市城町');
ok($zip->set_number('9120088')->is_valid_number, '福井県大野市水落');
ok($zip->set_number('9120088')->is_valid_number, '福井県大野市水落町');
ok($zip->set_number('9120091')->is_valid_number, '福井県大野市犬山');
ok($zip->set_number('9120091')->is_valid_number, '福井県大野市牛ケ原');
ok($zip->set_number('9120092')->is_valid_number, '福井県大野市清瀧');
ok($zip->set_number('9120093')->is_valid_number, '福井県大野市中丁');
ok($zip->set_number('9120094')->is_valid_number, '福井県大野市上丁');
ok($zip->set_number('9120095')->is_valid_number, '福井県大野市下丁');
ok($zip->set_number('9120131')->is_valid_number, '福井県大野市南六呂師');
ok($zip->set_number('9120132')->is_valid_number, '福井県大野市大月');
ok($zip->set_number('9120133')->is_valid_number, '福井県大野市御領');
ok($zip->set_number('9120134')->is_valid_number, '福井県大野市石谷');
ok($zip->set_number('9120135')->is_valid_number, '福井県大野市森本');
ok($zip->set_number('9120136')->is_valid_number, '福井県大野市松丸');
ok($zip->set_number('9120137')->is_valid_number, '福井県大野市萩ケ野');
ok($zip->set_number('9120138')->is_valid_number, '福井県大野市花房');
ok($zip->set_number('9120139')->is_valid_number, '福井県大野市不動堂');
ok($zip->set_number('9120141')->is_valid_number, '福井県大野市橋爪');
ok($zip->set_number('9120142')->is_valid_number, '福井県大野市蓑道');
ok($zip->set_number('9120143')->is_valid_number, '福井県大野市金山');
ok($zip->set_number('9120144')->is_valid_number, '福井県大野市小黒見');
ok($zip->set_number('9120145')->is_valid_number, '福井県大野市堂嶋');
ok($zip->set_number('9120146')->is_valid_number, '福井県大野市落合');
ok($zip->set_number('9120147')->is_valid_number, '福井県大野市柿ケ嶋');
ok($zip->set_number('9120148')->is_valid_number, '福井県大野市八町');
ok($zip->set_number('9120149')->is_valid_number, '福井県大野市伏石');
ok($zip->set_number('9120151')->is_valid_number, '福井県大野市上打波');
ok($zip->set_number('9120152')->is_valid_number, '福井県大野市下打波');
ok($zip->set_number('9120153')->is_valid_number, '福井県大野市仏原');
ok($zip->set_number('9120154')->is_valid_number, '福井県大野市東勝原');
ok($zip->set_number('9120155')->is_valid_number, '福井県大野市西勝原');
ok($zip->set_number('9120201')->is_valid_number, '福井県大野市朝日前坂');
ok($zip->set_number('9120202')->is_valid_number, '福井県大野市角野前坂');
ok($zip->set_number('9120203')->is_valid_number, '福井県大野市後野');
ok($zip->set_number('9120204')->is_valid_number, '福井県大野市貝皿');
ok($zip->set_number('9120205')->is_valid_number, '福井県大野市朝日');
ok($zip->set_number('9120206')->is_valid_number, '福井県大野市板倉');
ok($zip->set_number('9120207')->is_valid_number, '福井県大野市下山');
ok($zip->set_number('9120211')->is_valid_number, '福井県大野市下半原');
ok($zip->set_number('9120212')->is_valid_number, '福井県大野市箱ケ瀬');
ok($zip->set_number('9120213')->is_valid_number, '福井県大野市野尻');
ok($zip->set_number('9120214')->is_valid_number, '福井県大野市長野');
ok($zip->set_number('9120215')->is_valid_number, '福井県大野市下大納');
ok($zip->set_number('9120216')->is_valid_number, '福井県大野市上大納');
ok($zip->set_number('9120217')->is_valid_number, '福井県大野市角野');
ok($zip->set_number('9120218')->is_valid_number, '福井県大野市川合');
ok($zip->set_number('9120221')->is_valid_number, '福井県大野市上半原');
ok($zip->set_number('9120222')->is_valid_number, '福井県大野市東市布');
ok($zip->set_number('9120401')->is_valid_number, '福井県大野市吉');
ok($zip->set_number('9120402')->is_valid_number, '福井県大野市北御門');
ok($zip->set_number('9120403')->is_valid_number, '福井県大野市森政領家');
ok($zip->set_number('9120404')->is_valid_number, '福井県大野市猪島');
ok($zip->set_number('9120405')->is_valid_number, '福井県大野市森政地頭');
ok($zip->set_number('9120411')->is_valid_number, '福井県大野市友兼');
ok($zip->set_number('9120412')->is_valid_number, '福井県大野市御給');
ok($zip->set_number('9120413')->is_valid_number, '福井県大野市東山');
ok($zip->set_number('9120414')->is_valid_number, '福井県大野市野中');
ok($zip->set_number('9120415')->is_valid_number, '福井県大野市稲郷');
ok($zip->set_number('9120416')->is_valid_number, '福井県大野市開発');
ok($zip->set_number('9120421')->is_valid_number, '福井県大野市五條方');
ok($zip->set_number('9120422')->is_valid_number, '福井県大野市佐開');
ok($zip->set_number('9120423')->is_valid_number, '福井県大野市下若生子');
ok($zip->set_number('9120424')->is_valid_number, '福井県大野市今井');
ok($zip->set_number('9120425')->is_valid_number, '福井県大野市平沢');
ok($zip->set_number('9120426')->is_valid_number, '福井県大野市西山');
ok($zip->set_number('9120427')->is_valid_number, '福井県大野市森山');
ok($zip->set_number('9120431')->is_valid_number, '福井県大野市下据');
ok($zip->set_number('9120431')->is_valid_number, '福井県大野市西里');
ok($zip->set_number('9120432')->is_valid_number, '福井県大野市下郷');
ok($zip->set_number('9120433')->is_valid_number, '福井県大野市木本');
ok($zip->set_number('9120434')->is_valid_number, '福井県大野市宝慶寺');
ok($zip->set_number('9120435')->is_valid_number, '福井県大野市榎');
ok($zip->set_number('9120436')->is_valid_number, '福井県大野市西据');
ok($zip->set_number('9120437')->is_valid_number, '福井県大野市中据');
ok($zip->set_number('9120801')->is_valid_number, '福井県大野市新河原');
ok($zip->set_number('9120802')->is_valid_number, '福井県大野市新田');
ok($zip->set_number('9120803')->is_valid_number, '福井県大野市富嶋');
ok($zip->set_number('9120804')->is_valid_number, '福井県大野市森目');
ok($zip->set_number('9120805')->is_valid_number, '福井県大野市土布子');
ok($zip->set_number('9120811')->is_valid_number, '福井県大野市土打');
ok($zip->set_number('9120812')->is_valid_number, '福井県大野市富塚');
ok($zip->set_number('9120813')->is_valid_number, '福井県大野市上野');
ok($zip->set_number('9120814')->is_valid_number, '福井県大野市上麻生嶋');
ok($zip->set_number('9120814')->is_valid_number, '福井県大野市川嶋');
ok($zip->set_number('9120815')->is_valid_number, '福井県大野市下麻生嶋');
ok($zip->set_number('9120821')->is_valid_number, '福井県大野市七板');
ok($zip->set_number('9120822')->is_valid_number, '福井県大野市下唯野');
ok($zip->set_number('9120823')->is_valid_number, '福井県大野市蕨生');
ok($zip->set_number('9120824')->is_valid_number, '福井県大野市木落');
ok($zip->set_number('9120825')->is_valid_number, '福井県大野市新塚原');
ok($zip->set_number('9120825')->is_valid_number, '福井県大野市塚原');
ok($zip->set_number('9120826')->is_valid_number, '福井県大野市井ノ口');
ok($zip->set_number('9120827')->is_valid_number, '福井県大野市田野');
ok($zip->set_number('9130001')->is_valid_number, '福井県坂井市三国町池上');
ok($zip->set_number('9130002')->is_valid_number, '福井県坂井市三国町加戸');
ok($zip->set_number('9130003')->is_valid_number, '福井県坂井市三国町西谷');
ok($zip->set_number('9130004')->is_valid_number, '福井県坂井市三国町平山');
ok($zip->set_number('9130005')->is_valid_number, '福井県坂井市三国町浜地');
ok($zip->set_number('9130011')->is_valid_number, '福井県坂井市三国町水居');
ok($zip->set_number('9130012')->is_valid_number, '福井県坂井市三国町西今市');
ok($zip->set_number('9130013')->is_valid_number, '福井県坂井市三国町藤沢');
ok($zip->set_number('9130014')->is_valid_number, '福井県坂井市三国町玉江');
ok($zip->set_number('9130015')->is_valid_number, '福井県坂井市三国町野中');
ok($zip->set_number('9130016')->is_valid_number, '福井県坂井市三国町三国東');
ok($zip->set_number('9130017')->is_valid_number, '福井県坂井市三国町竹松');
ok($zip->set_number('9130021')->is_valid_number, '福井県坂井市三国町楽円');
ok($zip->set_number('9130022')->is_valid_number, '福井県坂井市三国町油屋');
ok($zip->set_number('9130023')->is_valid_number, '福井県坂井市三国町石丸');
ok($zip->set_number('9130024')->is_valid_number, '福井県坂井市三国町池見');
ok($zip->set_number('9130025')->is_valid_number, '福井県坂井市三国町川崎');
ok($zip->set_number('9130026')->is_valid_number, '福井県坂井市三国町殿島');
ok($zip->set_number('9130027')->is_valid_number, '福井県坂井市三国町汐見');
ok($zip->set_number('9130031')->is_valid_number, '福井県坂井市三国町新保(その他)');
ok($zip->set_number('9130032')->is_valid_number, '福井県坂井市三国町山岸(その他)');
ok($zip->set_number('9130033')->is_valid_number, '福井県坂井市三国町下野');
ok($zip->set_number('9130034')->is_valid_number, '福井県坂井市三国町西野中');
ok($zip->set_number('9130035')->is_valid_number, '福井県坂井市三国町沖野々');
ok($zip->set_number('9130035')->is_valid_number, '福井県坂井市三国町横越');
ok($zip->set_number('9130036')->is_valid_number, '福井県坂井市三国町米納津(その他)');
ok($zip->set_number('9130037')->is_valid_number, '福井県坂井市三国町黒目(その他)');
ok($zip->set_number('9130038')->is_valid_number, '福井県坂井市三国町黒目(テクノポート)');
ok($zip->set_number('9130038')->is_valid_number, '福井県坂井市三国町新保(テクノポート)');
ok($zip->set_number('9130038')->is_valid_number, '福井県坂井市三国町山岸(テクノポート)');
ok($zip->set_number('9130038')->is_valid_number, '福井県坂井市三国町米納津(テクノポート)');
ok($zip->set_number('9130041')->is_valid_number, '福井県坂井市三国町覚善');
ok($zip->set_number('9130042')->is_valid_number, '福井県坂井市三国町中央');
ok($zip->set_number('9130043')->is_valid_number, '福井県坂井市三国町錦');
ok($zip->set_number('9130044')->is_valid_number, '福井県坂井市三国町山王');
ok($zip->set_number('9130045')->is_valid_number, '福井県坂井市三国町南本町');
ok($zip->set_number('9130046')->is_valid_number, '福井県坂井市三国町北本町');
ok($zip->set_number('9130047')->is_valid_number, '福井県坂井市三国町神明');
ok($zip->set_number('9130048')->is_valid_number, '福井県坂井市三国町緑ケ丘');
ok($zip->set_number('9130051')->is_valid_number, '福井県坂井市三国町嵩');
ok($zip->set_number('9130052')->is_valid_number, '福井県坂井市三国町運動公園');
ok($zip->set_number('9130053')->is_valid_number, '福井県坂井市三国町青葉台');
ok($zip->set_number('9130054')->is_valid_number, '福井県坂井市三国町滝谷');
ok($zip->set_number('9130055')->is_valid_number, '福井県坂井市三国町つつじが丘');
ok($zip->set_number('9130056')->is_valid_number, '福井県坂井市三国町宿');
ok($zip->set_number('9130057')->is_valid_number, '福井県坂井市三国町米ケ脇');
ok($zip->set_number('9130058')->is_valid_number, '福井県坂井市三国町新宿');
ok($zip->set_number('9130061')->is_valid_number, '福井県坂井市三国町梶');
ok($zip->set_number('9130062')->is_valid_number, '福井県坂井市三国町陣ケ岡');
ok($zip->set_number('9130063')->is_valid_number, '福井県坂井市三国町安島(東尋坊)');
ok($zip->set_number('9130064')->is_valid_number, '福井県坂井市三国町安島(その他)');
ok($zip->set_number('9130065')->is_valid_number, '福井県坂井市三国町崎');
ok($zip->set_number('9140000')->is_valid_number, '福井県敦賀市以下に掲載がない場合');
ok($zip->set_number('9140001')->is_valid_number, '福井県敦賀市新保');
ok($zip->set_number('9140002')->is_valid_number, '福井県敦賀市葉原');
ok($zip->set_number('9140003')->is_valid_number, '福井県敦賀市獺河内');
ok($zip->set_number('9140004')->is_valid_number, '福井県敦賀市池河内');
ok($zip->set_number('9140005')->is_valid_number, '福井県敦賀市樫曲');
ok($zip->set_number('9140006')->is_valid_number, '福井県敦賀市越坂');
ok($zip->set_number('9140007')->is_valid_number, '福井県敦賀市田尻');
ok($zip->set_number('9140011')->is_valid_number, '福井県敦賀市深山寺');
ok($zip->set_number('9140012')->is_valid_number, '福井県敦賀市川北');
ok($zip->set_number('9140013')->is_valid_number, '福井県敦賀市谷口');
ok($zip->set_number('9140014')->is_valid_number, '福井県敦賀市井川');
ok($zip->set_number('9140015')->is_valid_number, '福井県敦賀市河原町');
ok($zip->set_number('9140016')->is_valid_number, '福井県敦賀市余座');
ok($zip->set_number('9140017')->is_valid_number, '福井県敦賀市藤ケ丘町');
ok($zip->set_number('9140018')->is_valid_number, '福井県敦賀市大蔵');
ok($zip->set_number('9140021')->is_valid_number, '福井県敦賀市泉ケ丘町');
ok($zip->set_number('9140022')->is_valid_number, '福井県敦賀市高野');
ok($zip->set_number('9140023')->is_valid_number, '福井県敦賀市深川町');
ok($zip->set_number('9140024')->is_valid_number, '福井県敦賀市吉河');
ok($zip->set_number('9140025')->is_valid_number, '福井県敦賀市樋ノ水町');
ok($zip->set_number('9140026')->is_valid_number, '福井県敦賀市木ノ芽町');
ok($zip->set_number('9140027')->is_valid_number, '福井県敦賀市若泉町');
ok($zip->set_number('9140028')->is_valid_number, '福井県敦賀市中');
ok($zip->set_number('9140031')->is_valid_number, '福井県敦賀市谷');
ok($zip->set_number('9140032')->is_valid_number, '福井県敦賀市小河');
ok($zip->set_number('9140033')->is_valid_number, '福井県敦賀市鳩原');
ok($zip->set_number('9140034')->is_valid_number, '福井県敦賀市小河口');
ok($zip->set_number('9140035')->is_valid_number, '福井県敦賀市山泉');
ok($zip->set_number('9140036')->is_valid_number, '福井県敦賀市堂');
ok($zip->set_number('9140037')->is_valid_number, '福井県敦賀市道口');
ok($zip->set_number('9140038')->is_valid_number, '福井県敦賀市坂下');
ok($zip->set_number('9140039')->is_valid_number, '福井県敦賀市観音町');
ok($zip->set_number('9140039')->is_valid_number, '福井県敦賀市羽織町');
ok($zip->set_number('9140041')->is_valid_number, '福井県敦賀市布田町');
ok($zip->set_number('9140042')->is_valid_number, '福井県敦賀市石ケ町');
ok($zip->set_number('9140043')->is_valid_number, '福井県敦賀市衣掛町');
ok($zip->set_number('9140044')->is_valid_number, '福井県敦賀市岡山町');
ok($zip->set_number('9140045')->is_valid_number, '福井県敦賀市古田刈');
ok($zip->set_number('9140046')->is_valid_number, '福井県敦賀市長沢');
ok($zip->set_number('9140047')->is_valid_number, '福井県敦賀市東洋町');
ok($zip->set_number('9140051')->is_valid_number, '福井県敦賀市本町');
ok($zip->set_number('9140052')->is_valid_number, '福井県敦賀市清水町');
ok($zip->set_number('9140053')->is_valid_number, '福井県敦賀市舞崎町');
ok($zip->set_number('9140054')->is_valid_number, '福井県敦賀市白銀町');
ok($zip->set_number('9140055')->is_valid_number, '福井県敦賀市鉄輪町');
ok($zip->set_number('9140056')->is_valid_number, '福井県敦賀市津内町');
ok($zip->set_number('9140057')->is_valid_number, '福井県敦賀市開町');
ok($zip->set_number('9140058')->is_valid_number, '福井県敦賀市三島町');
ok($zip->set_number('9140059')->is_valid_number, '福井県敦賀市国広町');
ok($zip->set_number('9140061')->is_valid_number, '福井県敦賀市蓬莱町');
ok($zip->set_number('9140062')->is_valid_number, '福井県敦賀市相生町');
ok($zip->set_number('9140063')->is_valid_number, '福井県敦賀市神楽町');
ok($zip->set_number('9140064')->is_valid_number, '福井県敦賀市結城町');
ok($zip->set_number('9140065')->is_valid_number, '福井県敦賀市松栄町');
ok($zip->set_number('9140066')->is_valid_number, '福井県敦賀市川崎町');
ok($zip->set_number('9140071')->is_valid_number, '福井県敦賀市泉');
ok($zip->set_number('9140072')->is_valid_number, '福井県敦賀市金ケ崎町');
ok($zip->set_number('9140073')->is_valid_number, '福井県敦賀市天筒町');
ok($zip->set_number('9140074')->is_valid_number, '福井県敦賀市角鹿町');
ok($zip->set_number('9140075')->is_valid_number, '福井県敦賀市曙町');
ok($zip->set_number('9140076')->is_valid_number, '福井県敦賀市元町');
ok($zip->set_number('9140077')->is_valid_number, '福井県敦賀市栄新町');
ok($zip->set_number('9140078')->is_valid_number, '福井県敦賀市桜町');
ok($zip->set_number('9140079')->is_valid_number, '福井県敦賀市港町');
ok($zip->set_number('9140121')->is_valid_number, '福井県敦賀市野神');
ok($zip->set_number('9140122')->is_valid_number, '福井県敦賀市新和町');
ok($zip->set_number('9140123')->is_valid_number, '福井県敦賀市和久野');
ok($zip->set_number('9140124')->is_valid_number, '福井県敦賀市市野々');
ok($zip->set_number('9140124')->is_valid_number, '福井県敦賀市市野々町');
ok($zip->set_number('9140125')->is_valid_number, '福井県敦賀市若葉町');
ok($zip->set_number('9140131')->is_valid_number, '福井県敦賀市公文名');
ok($zip->set_number('9140132')->is_valid_number, '福井県敦賀市御名');
ok($zip->set_number('9140133')->is_valid_number, '福井県敦賀市みどりケ丘町');
ok($zip->set_number('9140134')->is_valid_number, '福井県敦賀市山');
ok($zip->set_number('9140135')->is_valid_number, '福井県敦賀市長谷');
ok($zip->set_number('9140136')->is_valid_number, '福井県敦賀市砂流');
ok($zip->set_number('9140137')->is_valid_number, '福井県敦賀市ひばりケ丘町');
ok($zip->set_number('9140138')->is_valid_number, '福井県敦賀市櫛林');
ok($zip->set_number('9140141')->is_valid_number, '福井県敦賀市莇生野');
ok($zip->set_number('9140142')->is_valid_number, '福井県敦賀市萩野町');
ok($zip->set_number('9140143')->is_valid_number, '福井県敦賀市沢');
ok($zip->set_number('9140144')->is_valid_number, '福井県敦賀市桜ケ丘町');
ok($zip->set_number('9140145')->is_valid_number, '福井県敦賀市野坂');
ok($zip->set_number('9140146')->is_valid_number, '福井県敦賀市金山');
ok($zip->set_number('9140147')->is_valid_number, '福井県敦賀市関');
ok($zip->set_number('9140261')->is_valid_number, '福井県敦賀市元比田');
ok($zip->set_number('9140262')->is_valid_number, '福井県敦賀市大比田');
ok($zip->set_number('9140263')->is_valid_number, '福井県敦賀市横浜');
ok($zip->set_number('9140264')->is_valid_number, '福井県敦賀市杉津');
ok($zip->set_number('9140265')->is_valid_number, '福井県敦賀市阿曽');
ok($zip->set_number('9140266')->is_valid_number, '福井県敦賀市挙野');
ok($zip->set_number('9140267')->is_valid_number, '福井県敦賀市五幡');
ok($zip->set_number('9140268')->is_valid_number, '福井県敦賀市江良');
ok($zip->set_number('9140271')->is_valid_number, '福井県敦賀市泉(東浦)');
ok($zip->set_number('9140272')->is_valid_number, '福井県敦賀市赤崎');
ok($zip->set_number('9140273')->is_valid_number, '福井県敦賀市田結');
ok($zip->set_number('9140274')->is_valid_number, '福井県敦賀市鞠山');
ok($zip->set_number('9140301')->is_valid_number, '福井県敦賀市市橋');
ok($zip->set_number('9140302')->is_valid_number, '福井県敦賀市疋田');
ok($zip->set_number('9140303')->is_valid_number, '福井県敦賀市追分');
ok($zip->set_number('9140304')->is_valid_number, '福井県敦賀市深坂');
ok($zip->set_number('9140305')->is_valid_number, '福井県敦賀市駄口');
ok($zip->set_number('9140306')->is_valid_number, '福井県敦賀市山中');
ok($zip->set_number('9140311')->is_valid_number, '福井県敦賀市奥野');
ok($zip->set_number('9140312')->is_valid_number, '福井県敦賀市曽々木');
ok($zip->set_number('9140313')->is_valid_number, '福井県敦賀市刀根');
ok($zip->set_number('9140314')->is_valid_number, '福井県敦賀市杉箸');
ok($zip->set_number('9140315')->is_valid_number, '福井県敦賀市麻生口');
ok($zip->set_number('9140316')->is_valid_number, '福井県敦賀市奥麻生');
ok($zip->set_number('9140317')->is_valid_number, '福井県敦賀市新道');
ok($zip->set_number('9140801')->is_valid_number, '福井県敦賀市松島町');
ok($zip->set_number('9140802')->is_valid_number, '福井県敦賀市呉竹町');
ok($zip->set_number('9140803')->is_valid_number, '福井県敦賀市新松島町');
ok($zip->set_number('9140805')->is_valid_number, '福井県敦賀市鋳物師町');
ok($zip->set_number('9140806')->is_valid_number, '福井県敦賀市松原町');
ok($zip->set_number('9140807')->is_valid_number, '福井県敦賀市松葉町');
ok($zip->set_number('9140811')->is_valid_number, '福井県敦賀市中央町');
ok($zip->set_number('9140812')->is_valid_number, '福井県敦賀市昭和町');
ok($zip->set_number('9140813')->is_valid_number, '福井県敦賀市呉羽町');
ok($zip->set_number('9140814')->is_valid_number, '福井県敦賀市木崎');
ok($zip->set_number('9140815')->is_valid_number, '福井県敦賀市平和町');
ok($zip->set_number('9140821')->is_valid_number, '福井県敦賀市櫛川');
ok($zip->set_number('9140822')->is_valid_number, '福井県敦賀市櫛川町');
ok($zip->set_number('9140823')->is_valid_number, '福井県敦賀市沓見');
ok($zip->set_number('9140824')->is_valid_number, '福井県敦賀市原');
ok($zip->set_number('9140825')->is_valid_number, '福井県敦賀市永大町');
ok($zip->set_number('9140831')->is_valid_number, '福井県敦賀市沓');
ok($zip->set_number('9140832')->is_valid_number, '福井県敦賀市常宮');
ok($zip->set_number('9140833')->is_valid_number, '福井県敦賀市縄間');
ok($zip->set_number('9140834')->is_valid_number, '福井県敦賀市名子');
ok($zip->set_number('9140835')->is_valid_number, '福井県敦賀市二村');
ok($zip->set_number('9140841')->is_valid_number, '福井県敦賀市立石');
ok($zip->set_number('9140842')->is_valid_number, '福井県敦賀市明神町');
ok($zip->set_number('9140843')->is_valid_number, '福井県敦賀市浦底');
ok($zip->set_number('9140844')->is_valid_number, '福井県敦賀市色浜');
ok($zip->set_number('9140845')->is_valid_number, '福井県敦賀市手');
ok($zip->set_number('9150000')->is_valid_number, '福井県越前市以下に掲載がない場合');
ok($zip->set_number('9150001')->is_valid_number, '福井県越前市中新庄町');
ok($zip->set_number('9150002')->is_valid_number, '福井県越前市長尾町');
ok($zip->set_number('9150003')->is_valid_number, '福井県越前市戸谷町');
ok($zip->set_number('9150004')->is_valid_number, '福井県越前市北町');
ok($zip->set_number('9150005')->is_valid_number, '福井県越前市真柄町');
ok($zip->set_number('9150006')->is_valid_number, '福井県越前市杉崎町');
ok($zip->set_number('9150007')->is_valid_number, '福井県越前市三ツ屋町');
ok($zip->set_number('9150011')->is_valid_number, '福井県越前市金屋町');
ok($zip->set_number('9150011')->is_valid_number, '福井県越前市上真柄町');
ok($zip->set_number('9150012')->is_valid_number, '福井県越前市清水頭町');
ok($zip->set_number('9150013')->is_valid_number, '福井県越前市上真柄宮谷入会地');
ok($zip->set_number('9150013')->is_valid_number, '福井県越前市宮谷町');
ok($zip->set_number('9150014')->is_valid_number, '福井県越前市西尾町');
ok($zip->set_number('9150015')->is_valid_number, '福井県越前市大手町');
ok($zip->set_number('9150016')->is_valid_number, '福井県越前市岩内町');
ok($zip->set_number('9150021')->is_valid_number, '福井県越前市北小山町');
ok($zip->set_number('9150022')->is_valid_number, '福井県越前市南小山町');
ok($zip->set_number('9150023')->is_valid_number, '福井県越前市池泉町');
ok($zip->set_number('9150024')->is_valid_number, '福井県越前市上大坪町');
ok($zip->set_number('9150025')->is_valid_number, '福井県越前市味真野町');
ok($zip->set_number('9150026')->is_valid_number, '福井県越前市五分市町');
ok($zip->set_number('9150031')->is_valid_number, '福井県越前市余川町');
ok($zip->set_number('9150032')->is_valid_number, '福井県越前市檜尾谷町');
ok($zip->set_number('9150033')->is_valid_number, '福井県越前市蓑脇町');
ok($zip->set_number('9150034')->is_valid_number, '福井県越前市中居町');
ok($zip->set_number('9150035')->is_valid_number, '福井県越前市入谷町');
ok($zip->set_number('9150036')->is_valid_number, '福井県越前市文室町');
ok($zip->set_number('9150037')->is_valid_number, '福井県越前市萱谷町');
ok($zip->set_number('9150041')->is_valid_number, '福井県越前市葛岡町');
ok($zip->set_number('9150042')->is_valid_number, '福井県越前市大屋町');
ok($zip->set_number('9150043')->is_valid_number, '福井県越前市庄田町');
ok($zip->set_number('9150044')->is_valid_number, '福井県越前市平林町');
ok($zip->set_number('9150045')->is_valid_number, '福井県越前市荒谷町');
ok($zip->set_number('9150046')->is_valid_number, '福井県越前市西谷町');
ok($zip->set_number('9150051')->is_valid_number, '福井県越前市帆山町');
ok($zip->set_number('9150052')->is_valid_number, '福井県越前市矢放町');
ok($zip->set_number('9150053')->is_valid_number, '福井県越前市問屋町');
ok($zip->set_number('9150054')->is_valid_number, '福井県越前市小野谷町');
ok($zip->set_number('9150055')->is_valid_number, '福井県越前市畑町');
ok($zip->set_number('9150056')->is_valid_number, '福井県越前市向新保町');
ok($zip->set_number('9150057')->is_valid_number, '福井県越前市矢船町');
ok($zip->set_number('9150061')->is_valid_number, '福井県越前市堀川町');
ok($zip->set_number('9150062')->is_valid_number, '福井県越前市姫川');
ok($zip->set_number('9150063')->is_valid_number, '福井県越前市若竹町');
ok($zip->set_number('9150064')->is_valid_number, '福井県越前市あおば町');
ok($zip->set_number('9150065')->is_valid_number, '福井県越前市豊町');
ok($zip->set_number('9150066')->is_valid_number, '福井県越前市神明町');
ok($zip->set_number('9150067')->is_valid_number, '福井県越前市住吉町');
ok($zip->set_number('9150068')->is_valid_number, '福井県越前市天王町');
ok($zip->set_number('9150069')->is_valid_number, '福井県越前市吾妻町');
ok($zip->set_number('9150071')->is_valid_number, '福井県越前市府中');
ok($zip->set_number('9150072')->is_valid_number, '福井県越前市万代町');
ok($zip->set_number('9150073')->is_valid_number, '福井県越前市錦町');
ok($zip->set_number('9150074')->is_valid_number, '福井県越前市蓬莱町');
ok($zip->set_number('9150075')->is_valid_number, '福井県越前市幸町');
ok($zip->set_number('9150076')->is_valid_number, '福井県越前市国府');
ok($zip->set_number('9150081')->is_valid_number, '福井県越前市馬上免町');
ok($zip->set_number('9150082')->is_valid_number, '福井県越前市国高');
ok($zip->set_number('9150083')->is_valid_number, '福井県越前市押田');
ok($zip->set_number('9150084')->is_valid_number, '福井県越前市村国');
ok($zip->set_number('9150085')->is_valid_number, '福井県越前市八幡');
ok($zip->set_number('9150091')->is_valid_number, '福井県越前市高木町');
ok($zip->set_number('9150092')->is_valid_number, '福井県越前市塚町');
ok($zip->set_number('9150093')->is_valid_number, '福井県越前市庄町');
ok($zip->set_number('9150094')->is_valid_number, '福井県越前市横市町');
ok($zip->set_number('9150095')->is_valid_number, '福井県越前市稲寄町');
ok($zip->set_number('9150096')->is_valid_number, '福井県越前市瓜生町');
ok($zip->set_number('9150097')->is_valid_number, '福井県越前市長土呂町');
ok($zip->set_number('9150201')->is_valid_number, '福井県越前市西河内町');
ok($zip->set_number('9150202')->is_valid_number, '福井県越前市相木町');
ok($zip->set_number('9150203')->is_valid_number, '福井県越前市清根町');
ok($zip->set_number('9150203')->is_valid_number, '福井県越前市横住町');
ok($zip->set_number('9150204')->is_valid_number, '福井県越前市寺地町');
ok($zip->set_number('9150205')->is_valid_number, '福井県越前市波垣町');
ok($zip->set_number('9150206')->is_valid_number, '福井県越前市春山町');
ok($zip->set_number('9150207')->is_valid_number, '福井県越前市東樫尾町');
ok($zip->set_number('9150208')->is_valid_number, '福井県越前市領家町');
ok($zip->set_number('9150209')->is_valid_number, '福井県越前市藤木町');
ok($zip->set_number('9150211')->is_valid_number, '福井県越前市室谷町');
ok($zip->set_number('9150212')->is_valid_number, '福井県越前市長谷町');
ok($zip->set_number('9150213')->is_valid_number, '福井県越前市南中町');
ok($zip->set_number('9150214')->is_valid_number, '福井県越前市赤谷町');
ok($zip->set_number('9150215')->is_valid_number, '福井県越前市柳元町');
ok($zip->set_number('9150216')->is_valid_number, '福井県越前市市野々町');
ok($zip->set_number('9150217')->is_valid_number, '福井県越前市水間町');
ok($zip->set_number('9150218')->is_valid_number, '福井県越前市大谷町');
ok($zip->set_number('9150219')->is_valid_number, '福井県越前市北坂下町');
ok($zip->set_number('9150219')->is_valid_number, '福井県越前市殿町');
ok($zip->set_number('9150221')->is_valid_number, '福井県越前市杉尾町');
ok($zip->set_number('9150222')->is_valid_number, '福井県越前市轟井町');
ok($zip->set_number('9150223')->is_valid_number, '福井県越前市島町');
ok($zip->set_number('9150223')->is_valid_number, '福井県越前市長五町');
ok($zip->set_number('9150224')->is_valid_number, '福井県越前市八石町');
ok($zip->set_number('9150225')->is_valid_number, '福井県越前市別印町');
ok($zip->set_number('9150226')->is_valid_number, '福井県越前市南坂下町');
ok($zip->set_number('9150227')->is_valid_number, '福井県越前市中印町');
ok($zip->set_number('9150228')->is_valid_number, '福井県越前市大平町');
ok($zip->set_number('9150231')->is_valid_number, '福井県越前市定友町');
ok($zip->set_number('9150232')->is_valid_number, '福井県越前市新在家町');
ok($zip->set_number('9150233')->is_valid_number, '福井県越前市岩本町');
ok($zip->set_number('9150234')->is_valid_number, '福井県越前市大滝町');
ok($zip->set_number('9150235')->is_valid_number, '福井県越前市不老町');
ok($zip->set_number('9150241')->is_valid_number, '福井県越前市粟田部町中央');
ok($zip->set_number('9150242')->is_valid_number, '福井県越前市粟田部町');
ok($zip->set_number('9150243')->is_valid_number, '福井県越前市千原町');
ok($zip->set_number('9150244')->is_valid_number, '福井県越前市西樫尾町');
ok($zip->set_number('9150251')->is_valid_number, '福井県越前市東庄境町');
ok($zip->set_number('9150252')->is_valid_number, '福井県越前市西庄境町');
ok($zip->set_number('9150253')->is_valid_number, '福井県越前市中津山町');
ok($zip->set_number('9150254')->is_valid_number, '福井県越前市国中町');
ok($zip->set_number('9150255')->is_valid_number, '福井県越前市新堂町');
ok($zip->set_number('9150256')->is_valid_number, '福井県越前市赤坂町');
ok($zip->set_number('9150261')->is_valid_number, '福井県越前市朽飯町');
ok($zip->set_number('9150262')->is_valid_number, '福井県越前市高岡町');
ok($zip->set_number('9150263')->is_valid_number, '福井県越前市山室町');
ok($zip->set_number('9150264')->is_valid_number, '福井県越前市野岡町');
ok($zip->set_number('9150265')->is_valid_number, '福井県越前市仲山');
ok($zip->set_number('9150801')->is_valid_number, '福井県越前市家久町');
ok($zip->set_number('9150802')->is_valid_number, '福井県越前市北府');
ok($zip->set_number('9150802')->is_valid_number, '福井県越前市北府本町');
ok($zip->set_number('9150803')->is_valid_number, '福井県越前市平出');
ok($zip->set_number('9150804')->is_valid_number, '福井県越前市新保');
ok($zip->set_number('9150804')->is_valid_number, '福井県越前市新保町');
ok($zip->set_number('9150805')->is_valid_number, '福井県越前市芝原');
ok($zip->set_number('9150806')->is_valid_number, '福井県越前市本保町');
ok($zip->set_number('9150811')->is_valid_number, '福井県越前市本多');
ok($zip->set_number('9150812')->is_valid_number, '福井県越前市桂町');
ok($zip->set_number('9150813')->is_valid_number, '福井県越前市京町');
ok($zip->set_number('9150814')->is_valid_number, '福井県越前市中央');
ok($zip->set_number('9150815')->is_valid_number, '福井県越前市深草');
ok($zip->set_number('9150816')->is_valid_number, '福井県越前市小松');
ok($zip->set_number('9150821')->is_valid_number, '福井県越前市若松町');
ok($zip->set_number('9150822')->is_valid_number, '福井県越前市元町');
ok($zip->set_number('9150823')->is_valid_number, '福井県越前市本町');
ok($zip->set_number('9150824')->is_valid_number, '福井県越前市武生柳町');
ok($zip->set_number('9150825')->is_valid_number, '福井県越前市南');
ok($zip->set_number('9150826')->is_valid_number, '福井県越前市御幸町');
ok($zip->set_number('9150827')->is_valid_number, '福井県越前市平和町');
ok($zip->set_number('9150831')->is_valid_number, '福井県越前市日野美');
ok($zip->set_number('9150832')->is_valid_number, '福井県越前市高瀬');
ok($zip->set_number('9150833')->is_valid_number, '福井県越前市沢町');
ok($zip->set_number('9150834')->is_valid_number, '福井県越前市北千福町');
ok($zip->set_number('9150835')->is_valid_number, '福井県越前市岡本町');
ok($zip->set_number('9150836')->is_valid_number, '福井県越前市野上町');
ok($zip->set_number('9150841')->is_valid_number, '福井県越前市文京');
ok($zip->set_number('9150842')->is_valid_number, '福井県越前市常久町');
ok($zip->set_number('9150843')->is_valid_number, '福井県越前市月見町');
ok($zip->set_number('9150844')->is_valid_number, '福井県越前市妙法寺町');
ok($zip->set_number('9150845')->is_valid_number, '福井県越前市三ツ口町');
ok($zip->set_number('9150846')->is_valid_number, '福井県越前市千福町');
ok($zip->set_number('9150847')->is_valid_number, '福井県越前市東千福町');
ok($zip->set_number('9150851')->is_valid_number, '福井県越前市畷町');
ok($zip->set_number('9150852')->is_valid_number, '福井県越前市松森町');
ok($zip->set_number('9150853')->is_valid_number, '福井県越前市行松町');
ok($zip->set_number('9150854')->is_valid_number, '福井県越前市富士見が丘');
ok($zip->set_number('9150855')->is_valid_number, '福井県越前市下平吹町');
ok($zip->set_number('9150856')->is_valid_number, '福井県越前市中平吹町');
ok($zip->set_number('9150857')->is_valid_number, '福井県越前市四郎丸町');
ok($zip->set_number('9150861')->is_valid_number, '福井県越前市今宿町');
ok($zip->set_number('9150862')->is_valid_number, '福井県越前市国兼町');
ok($zip->set_number('9150863')->is_valid_number, '福井県越前市大塩町');
ok($zip->set_number('9150864')->is_valid_number, '福井県越前市上小松町');
ok($zip->set_number('9150865')->is_valid_number, '福井県越前市瓜生野町');
ok($zip->set_number('9150865')->is_valid_number, '福井県越前市森久町');
ok($zip->set_number('9150871')->is_valid_number, '福井県越前市向が丘町');
ok($zip->set_number('9150872')->is_valid_number, '福井県越前市広瀬町');
ok($zip->set_number('9150873')->is_valid_number, '福井県越前市池ノ上町');
ok($zip->set_number('9150874')->is_valid_number, '福井県越前市向陽町');
ok($zip->set_number('9150875')->is_valid_number, '福井県越前市塚原町');
ok($zip->set_number('9150876')->is_valid_number, '福井県越前市白崎町');
ok($zip->set_number('9150877')->is_valid_number, '福井県越前市春日野町');
ok($zip->set_number('9150881')->is_valid_number, '福井県越前市下太田町');
ok($zip->set_number('9150882')->is_valid_number, '福井県越前市上太田町');
ok($zip->set_number('9150883')->is_valid_number, '福井県越前市新町');
ok($zip->set_number('9150884')->is_valid_number, '福井県越前市大虫本町');
ok($zip->set_number('9150885')->is_valid_number, '福井県越前市大虫町');
ok($zip->set_number('9150886')->is_valid_number, '福井県越前市上四目町');
ok($zip->set_number('9150887')->is_valid_number, '福井県越前市下四目町');
ok($zip->set_number('9150888')->is_valid_number, '福井県越前市高森町');
ok($zip->set_number('9150891')->is_valid_number, '福井県越前市余田町');
ok($zip->set_number('9150892')->is_valid_number, '福井県越前市氷坂町');
ok($zip->set_number('9150893')->is_valid_number, '福井県越前市片屋町');
ok($zip->set_number('9150894')->is_valid_number, '福井県越前市丹生郷町');
ok($zip->set_number('9150895')->is_valid_number, '福井県越前市三ツ俣町');
ok($zip->set_number('9150896')->is_valid_number, '福井県越前市横根町');
ok($zip->set_number('9150897')->is_valid_number, '福井県越前市北山町');
ok($zip->set_number('9151101')->is_valid_number, '福井県南条郡南越前町具谷');
ok($zip->set_number('9151102')->is_valid_number, '福井県南条郡南越前町菅谷');
ok($zip->set_number('9151103')->is_valid_number, '福井県南条郡南越前町大谷');
ok($zip->set_number('9151104')->is_valid_number, '福井県南条郡南越前町大良');
ok($zip->set_number('9151105')->is_valid_number, '福井県南条郡南越前町赤萩');
ok($zip->set_number('9151106')->is_valid_number, '福井県南条郡南越前町河内');
ok($zip->set_number('9151111')->is_valid_number, '福井県南条郡南越前町河野');
ok($zip->set_number('9151112')->is_valid_number, '福井県南条郡南越前町今泉');
ok($zip->set_number('9151113')->is_valid_number, '福井県南条郡南越前町甲楽城');
ok($zip->set_number('9151114')->is_valid_number, '福井県南条郡南越前町糠');
ok($zip->set_number('9151114')->is_valid_number, '福井県南条郡南越前町糠(神土)');
ok($zip->set_number('9151114')->is_valid_number, '福井県南条郡南越前町糠(杉山)');
ok($zip->set_number('9151114')->is_valid_number, '福井県南条郡南越前町八田');
ok($zip->set_number('9151201')->is_valid_number, '福井県越前市安養寺町');
ok($zip->set_number('9151202')->is_valid_number, '福井県越前市黒川町');
ok($zip->set_number('9151203')->is_valid_number, '福井県越前市上杉本町');
ok($zip->set_number('9151204')->is_valid_number, '福井県越前市都辺町');
ok($zip->set_number('9151205')->is_valid_number, '福井県越前市萩原町');
ok($zip->set_number('9151211')->is_valid_number, '福井県越前市堀町');
ok($zip->set_number('9151212')->is_valid_number, '福井県越前市米口町');
ok($zip->set_number('9151212')->is_valid_number, '福井県越前市仏谷町');
ok($zip->set_number('9151213')->is_valid_number, '福井県越前市丸岡町');
ok($zip->set_number('9151214')->is_valid_number, '福井県越前市勝蓮花町');
ok($zip->set_number('9151215')->is_valid_number, '福井県越前市小野町');
ok($zip->set_number('9151221')->is_valid_number, '福井県越前市勾当原町');
ok($zip->set_number('9151222')->is_valid_number, '福井県越前市下中津原町');
ok($zip->set_number('9151223')->is_valid_number, '福井県越前市中津原町');
ok($zip->set_number('9151224')->is_valid_number, '福井県越前市下別所町');
ok($zip->set_number('9151225')->is_valid_number, '福井県越前市湯谷町');
ok($zip->set_number('9151226')->is_valid_number, '福井県越前市中山町');
ok($zip->set_number('9151231')->is_valid_number, '福井県越前市千合谷町');
ok($zip->set_number('9151232')->is_valid_number, '福井県越前市二階堂町');
ok($zip->set_number('9151233')->is_valid_number, '福井県越前市菖蒲谷町');
ok($zip->set_number('9151234')->is_valid_number, '福井県越前市小谷町');
ok($zip->set_number('9151234')->is_valid_number, '福井県越前市土山町');
ok($zip->set_number('9151235')->is_valid_number, '福井県越前市菅町');
ok($zip->set_number('9151235')->is_valid_number, '福井県越前市安戸町');
ok($zip->set_number('9151241')->is_valid_number, '福井県越前市曽原町');
ok($zip->set_number('9151242')->is_valid_number, '福井県越前市粟野町');
ok($zip->set_number('9151243')->is_valid_number, '福井県越前市小杉町');
ok($zip->set_number('9151244')->is_valid_number, '福井県越前市牧町');
ok($zip->set_number('9151245')->is_valid_number, '福井県越前市若須町');
ok($zip->set_number('9151246')->is_valid_number, '福井県越前市中野町');
ok($zip->set_number('9160000')->is_valid_number, '福井県鯖江市以下に掲載がない場合');
ok($zip->set_number('9160001')->is_valid_number, '福井県鯖江市吉江町');
ok($zip->set_number('9160002')->is_valid_number, '福井県鯖江市米岡町');
ok($zip->set_number('9160003')->is_valid_number, '福井県鯖江市田所町');
ok($zip->set_number('9160004')->is_valid_number, '福井県鯖江市糺町');
ok($zip->set_number('9160005')->is_valid_number, '福井県鯖江市杉本町');
ok($zip->set_number('9160006')->is_valid_number, '福井県鯖江市西番町');
ok($zip->set_number('9160007')->is_valid_number, '福井県鯖江市三尾野出作町');
ok($zip->set_number('9160008')->is_valid_number, '福井県鯖江市入町');
ok($zip->set_number('9160011')->is_valid_number, '福井県鯖江市つつじケ丘町');
ok($zip->set_number('9160012')->is_valid_number, '福井県鯖江市東米岡');
ok($zip->set_number('9160013')->is_valid_number, '福井県鯖江市鳥羽');
ok($zip->set_number('9160014')->is_valid_number, '福井県鯖江市鳥羽町');
ok($zip->set_number('9160015')->is_valid_number, '福井県鯖江市御幸町');
ok($zip->set_number('9160016')->is_valid_number, '福井県鯖江市神中町');
ok($zip->set_number('9160017')->is_valid_number, '福井県鯖江市神明町');
ok($zip->set_number('9160018')->is_valid_number, '福井県鯖江市幸町');
ok($zip->set_number('9160019')->is_valid_number, '福井県鯖江市丸山町');
ok($zip->set_number('9160021')->is_valid_number, '福井県鯖江市三六町');
ok($zip->set_number('9160022')->is_valid_number, '福井県鯖江市水落町');
ok($zip->set_number('9160023')->is_valid_number, '福井県鯖江市西山町');
ok($zip->set_number('9160024')->is_valid_number, '福井県鯖江市長泉寺町');
ok($zip->set_number('9160025')->is_valid_number, '福井県鯖江市旭町');
ok($zip->set_number('9160026')->is_valid_number, '福井県鯖江市本町');
ok($zip->set_number('9160027')->is_valid_number, '福井県鯖江市桜町');
ok($zip->set_number('9160028')->is_valid_number, '福井県鯖江市小黒町');
ok($zip->set_number('9160029')->is_valid_number, '福井県鯖江市北野町');
ok($zip->set_number('9160031')->is_valid_number, '福井県鯖江市橋立町');
ok($zip->set_number('9160032')->is_valid_number, '福井県鯖江市舟枝町');
ok($zip->set_number('9160033')->is_valid_number, '福井県鯖江市中野町');
ok($zip->set_number('9160034')->is_valid_number, '福井県鯖江市下新庄町');
ok($zip->set_number('9160035')->is_valid_number, '福井県鯖江市新町');
ok($zip->set_number('9160036')->is_valid_number, '福井県鯖江市横越町');
ok($zip->set_number('9160037')->is_valid_number, '福井県鯖江市上河端町');
ok($zip->set_number('9160038')->is_valid_number, '福井県鯖江市下河端町');
ok($zip->set_number('9160041')->is_valid_number, '福井県鯖江市東鯖江');
ok($zip->set_number('9160042')->is_valid_number, '福井県鯖江市新横江');
ok($zip->set_number('9160043')->is_valid_number, '福井県鯖江市定次町');
ok($zip->set_number('9160044')->is_valid_number, '福井県鯖江市五郎丸町');
ok($zip->set_number('9160045')->is_valid_number, '福井県鯖江市宮前');
ok($zip->set_number('9160046')->is_valid_number, '福井県鯖江市横江町');
ok($zip->set_number('9160047')->is_valid_number, '福井県鯖江市柳町');
ok($zip->set_number('9160051')->is_valid_number, '福井県鯖江市屋形町');
ok($zip->set_number('9160052')->is_valid_number, '福井県鯖江市深江町');
ok($zip->set_number('9160053')->is_valid_number, '福井県鯖江市日の出町');
ok($zip->set_number('9160054')->is_valid_number, '福井県鯖江市舟津町');
ok($zip->set_number('9160055')->is_valid_number, '福井県鯖江市上鯖江');
ok($zip->set_number('9160055')->is_valid_number, '福井県鯖江市上鯖江町');
ok($zip->set_number('9160056')->is_valid_number, '福井県鯖江市住吉町');
ok($zip->set_number('9160057')->is_valid_number, '福井県鯖江市有定町');
ok($zip->set_number('9160061')->is_valid_number, '福井県鯖江市平井町');
ok($zip->set_number('9160062')->is_valid_number, '福井県鯖江市熊田町');
ok($zip->set_number('9160063')->is_valid_number, '福井県鯖江市鳥井町');
ok($zip->set_number('9160064')->is_valid_number, '福井県鯖江市下司町');
ok($zip->set_number('9160065')->is_valid_number, '福井県鯖江市当田町');
ok($zip->set_number('9160066')->is_valid_number, '福井県鯖江市上氏家町');
ok($zip->set_number('9160067')->is_valid_number, '福井県鯖江市下氏家町');
ok($zip->set_number('9160068')->is_valid_number, '福井県鯖江市二丁掛町');
ok($zip->set_number('9160071')->is_valid_number, '福井県鯖江市持明寺町');
ok($zip->set_number('9160072')->is_valid_number, '福井県鯖江市冬島町');
ok($zip->set_number('9160073')->is_valid_number, '福井県鯖江市下野田町');
ok($zip->set_number('9160074')->is_valid_number, '福井県鯖江市上野田町');
ok($zip->set_number('9160075')->is_valid_number, '福井県鯖江市漆原町');
ok($zip->set_number('9160076')->is_valid_number, '福井県鯖江市石生谷町');
ok($zip->set_number('9160077')->is_valid_number, '福井県鯖江市和田町');
ok($zip->set_number('9160078')->is_valid_number, '福井県鯖江市西大井町');
ok($zip->set_number('9160081')->is_valid_number, '福井県鯖江市石田下町');
ok($zip->set_number('9160082')->is_valid_number, '福井県鯖江市石田中町');
ok($zip->set_number('9160083')->is_valid_number, '福井県鯖江市石田上町');
ok($zip->set_number('9160084')->is_valid_number, '福井県鯖江市小泉町');
ok($zip->set_number('9160085')->is_valid_number, '福井県鯖江市大倉町');
ok($zip->set_number('9160086')->is_valid_number, '福井県鯖江市吉田町');
ok($zip->set_number('9160087')->is_valid_number, '福井県鯖江市田村町');
ok($zip->set_number('9160088')->is_valid_number, '福井県鯖江市川去町');
ok($zip->set_number('9160101')->is_valid_number, '福井県丹生郡越前町天谷');
ok($zip->set_number('9160102')->is_valid_number, '福井県丹生郡越前町真木');
ok($zip->set_number('9160103')->is_valid_number, '福井県丹生郡越前町杖立');
ok($zip->set_number('9160104')->is_valid_number, '福井県丹生郡越前町森');
ok($zip->set_number('9160105')->is_valid_number, '福井県丹生郡越前町清水');
ok($zip->set_number('9160106')->is_valid_number, '福井県丹生郡越前町大玉');
ok($zip->set_number('9160107')->is_valid_number, '福井県丹生郡越前町上糸生');
ok($zip->set_number('9160108')->is_valid_number, '福井県丹生郡越前町小川');
ok($zip->set_number('9160111')->is_valid_number, '福井県丹生郡越前町小倉');
ok($zip->set_number('9160112')->is_valid_number, '福井県丹生郡越前町葛野');
ok($zip->set_number('9160113')->is_valid_number, '福井県丹生郡越前町野田');
ok($zip->set_number('9160114')->is_valid_number, '福井県丹生郡越前町下糸生');
ok($zip->set_number('9160115')->is_valid_number, '福井県丹生郡越前町脇');
ok($zip->set_number('9160116')->is_valid_number, '福井県丹生郡越前町中野');
ok($zip->set_number('9160117')->is_valid_number, '福井県丹生郡越前町大谷寺');
ok($zip->set_number('9160121')->is_valid_number, '福井県丹生郡越前町大畑');
ok($zip->set_number('9160122')->is_valid_number, '福井県丹生郡越前町天王');
ok($zip->set_number('9160123')->is_valid_number, '福井県丹生郡越前町天宝');
ok($zip->set_number('9160124')->is_valid_number, '福井県丹生郡越前町宝泉寺');
ok($zip->set_number('9160125')->is_valid_number, '福井県丹生郡越前町横山');
ok($zip->set_number('9160126')->is_valid_number, '福井県丹生郡越前町牛越');
ok($zip->set_number('9160127')->is_valid_number, '福井県丹生郡越前町野末');
ok($zip->set_number('9160131')->is_valid_number, '福井県丹生郡越前町乙坂');
ok($zip->set_number('9160132')->is_valid_number, '福井県丹生郡越前町田中');
ok($zip->set_number('9160133')->is_valid_number, '福井県丹生郡越前町気比庄');
ok($zip->set_number('9160134')->is_valid_number, '福井県丹生郡越前町新庄');
ok($zip->set_number('9160135')->is_valid_number, '福井県丹生郡越前町市');
ok($zip->set_number('9160136')->is_valid_number, '福井県丹生郡越前町栃川');
ok($zip->set_number('9160137')->is_valid_number, '福井県丹生郡越前町宮の西団地');
ok($zip->set_number('9160141')->is_valid_number, '福井県丹生郡越前町西田中');
ok($zip->set_number('9160142')->is_valid_number, '福井県丹生郡越前町上川去');
ok($zip->set_number('9160143')->is_valid_number, '福井県丹生郡越前町宇田');
ok($zip->set_number('9160143')->is_valid_number, '福井県丹生郡越前町漆本');
ok($zip->set_number('9160144')->is_valid_number, '福井県丹生郡越前町佐々生');
ok($zip->set_number('9160145')->is_valid_number, '福井県丹生郡越前町岩開');
ok($zip->set_number('9160146')->is_valid_number, '福井県丹生郡越前町朝日');
ok($zip->set_number('9160147')->is_valid_number, '福井県丹生郡越前町内郡');
ok($zip->set_number('9160151')->is_valid_number, '福井県丹生郡越前町金谷');
ok($zip->set_number('9160152')->is_valid_number, '福井県丹生郡越前町青野');
ok($zip->set_number('9160153')->is_valid_number, '福井県丹生郡越前町頭谷');
ok($zip->set_number('9160154')->is_valid_number, '福井県丹生郡越前町境野');
ok($zip->set_number('9160155')->is_valid_number, '福井県丹生郡越前町茱原');
ok($zip->set_number('9160156')->is_valid_number, '福井県丹生郡越前町東内郡');
ok($zip->set_number('9160200')->is_valid_number, '福井県丹生郡越前町以下に掲載がない場合');
ok($zip->set_number('9160201')->is_valid_number, '福井県丹生郡越前町入尾');
ok($zip->set_number('9160202')->is_valid_number, '福井県丹生郡越前町細野');
ok($zip->set_number('9160203')->is_valid_number, '福井県丹生郡越前町山田');
ok($zip->set_number('9160204')->is_valid_number, '福井県丹生郡越前町中');
ok($zip->set_number('9160205')->is_valid_number, '福井県丹生郡越前町赤井谷');
ok($zip->set_number('9160206')->is_valid_number, '福井県丹生郡越前町笈松');
ok($zip->set_number('9160211')->is_valid_number, '福井県丹生郡越前町笹川');
ok($zip->set_number('9160212')->is_valid_number, '福井県丹生郡越前町岩倉');
ok($zip->set_number('9160213')->is_valid_number, '福井県丹生郡越前町桜谷');
ok($zip->set_number('9160214')->is_valid_number, '福井県丹生郡越前町上戸');
ok($zip->set_number('9160215')->is_valid_number, '福井県丹生郡越前町織田');
ok($zip->set_number('9160216')->is_valid_number, '福井県丹生郡越前町打越');
ok($zip->set_number('9160217')->is_valid_number, '福井県丹生郡越前町丸山');
ok($zip->set_number('9160218')->is_valid_number, '福井県丹生郡越前町萩野');
ok($zip->set_number('9160219')->is_valid_number, '福井県丹生郡越前町西ケ丘');
ok($zip->set_number('9160221')->is_valid_number, '福井県丹生郡越前町三崎');
ok($zip->set_number('9160222')->is_valid_number, '福井県丹生郡越前町大王丸');
ok($zip->set_number('9160223')->is_valid_number, '福井県丹生郡越前町下河原');
ok($zip->set_number('9160224')->is_valid_number, '福井県丹生郡越前町平等');
ok($zip->set_number('9160225')->is_valid_number, '福井県丹生郡越前町上山中');
ok($zip->set_number('9160226')->is_valid_number, '福井県丹生郡越前町下山中');
ok($zip->set_number('9160227')->is_valid_number, '福井県丹生郡越前町四ツ杉');
ok($zip->set_number('9160251')->is_valid_number, '福井県丹生郡越前町大谷');
ok($zip->set_number('9160252')->is_valid_number, '福井県丹生郡越前町蝉口');
ok($zip->set_number('9160253')->is_valid_number, '福井県丹生郡越前町蚊谷寺');
ok($zip->set_number('9160254')->is_valid_number, '福井県丹生郡越前町広野');
ok($zip->set_number('9160255')->is_valid_number, '福井県丹生郡越前町江波');
ok($zip->set_number('9160261')->is_valid_number, '福井県丹生郡越前町野');
ok($zip->set_number('9160262')->is_valid_number, '福井県丹生郡越前町宇須尾');
ok($zip->set_number('9160263')->is_valid_number, '福井県丹生郡越前町円満');
ok($zip->set_number('9160264')->is_valid_number, '福井県丹生郡越前町八田');
ok($zip->set_number('9160265')->is_valid_number, '福井県丹生郡越前町八田新保');
ok($zip->set_number('9160266')->is_valid_number, '福井県丹生郡越前町寺');
ok($zip->set_number('9160267')->is_valid_number, '福井県丹生郡越前町上野');
ok($zip->set_number('9160268')->is_valid_number, '福井県丹生郡越前町陶の谷');
ok($zip->set_number('9160271')->is_valid_number, '福井県丹生郡越前町舟場');
ok($zip->set_number('9160272')->is_valid_number, '福井県丹生郡越前町樫津');
ok($zip->set_number('9160273')->is_valid_number, '福井県丹生郡越前町小曽原');
ok($zip->set_number('9160274')->is_valid_number, '福井県丹生郡越前町増谷');
ok($zip->set_number('9160275')->is_valid_number, '福井県丹生郡越前町熊谷');
ok($zip->set_number('9160276')->is_valid_number, '福井県丹生郡越前町古屋');
ok($zip->set_number('9160301')->is_valid_number, '福井県丹生郡越前町梨子ヶ平');
ok($zip->set_number('9160302')->is_valid_number, '福井県丹生郡越前町左右');
ok($zip->set_number('9160303')->is_valid_number, '福井県丹生郡越前町血ケ平');
ok($zip->set_number('9160304')->is_valid_number, '福井県丹生郡越前町玉川');
ok($zip->set_number('9160311')->is_valid_number, '福井県丹生郡越前町梅浦');
ok($zip->set_number('9160312')->is_valid_number, '福井県丹生郡越前町宿');
ok($zip->set_number('9160313')->is_valid_number, '福井県丹生郡越前町新保');
ok($zip->set_number('9160314')->is_valid_number, '福井県丹生郡越前町城ケ谷');
ok($zip->set_number('9160315')->is_valid_number, '福井県丹生郡越前町小樟');
ok($zip->set_number('9160316')->is_valid_number, '福井県丹生郡越前町大樟');
ok($zip->set_number('9160421')->is_valid_number, '福井県丹生郡越前町道口');
ok($zip->set_number('9160422')->is_valid_number, '福井県丹生郡越前町厨');
ok($zip->set_number('9160423')->is_valid_number, '福井県丹生郡越前町茂原');
ok($zip->set_number('9160424')->is_valid_number, '福井県丹生郡越前町白浜');
ok($zip->set_number('9160425')->is_valid_number, '福井県丹生郡越前町高佐');
ok($zip->set_number('9160426')->is_valid_number, '福井県丹生郡越前町米ノ');
ok($zip->set_number('9160427')->is_valid_number, '福井県丹生郡越前町六呂師');
ok($zip->set_number('9160428')->is_valid_number, '福井県丹生郡越前町午房ケ平');
ok($zip->set_number('9161101')->is_valid_number, '福井県鯖江市大正寺町');
ok($zip->set_number('9161102')->is_valid_number, '福井県鯖江市大野町');
ok($zip->set_number('9161103')->is_valid_number, '福井県鯖江市別所町');
ok($zip->set_number('9161104')->is_valid_number, '福井県鯖江市乙坂今北町');
ok($zip->set_number('9161105')->is_valid_number, '福井県鯖江市吉谷町');
ok($zip->set_number('9161106')->is_valid_number, '福井県鯖江市四方谷町');
ok($zip->set_number('9161107')->is_valid_number, '福井県鯖江市南井町');
ok($zip->set_number('9161111')->is_valid_number, '福井県鯖江市上戸口町');
ok($zip->set_number('9161112')->is_valid_number, '福井県鯖江市中戸口町');
ok($zip->set_number('9161113')->is_valid_number, '福井県鯖江市戸口町');
ok($zip->set_number('9161114')->is_valid_number, '福井県鯖江市磯部町');
ok($zip->set_number('9161115')->is_valid_number, '福井県鯖江市落井町');
ok($zip->set_number('9161116')->is_valid_number, '福井県鯖江市川島町');
ok($zip->set_number('9161118')->is_valid_number, '福井県鯖江市松成町');
ok($zip->set_number('9161133')->is_valid_number, '福井県鯖江市中野松成');
ok($zip->set_number('9161221')->is_valid_number, '福井県鯖江市西袋町');
ok($zip->set_number('9161222')->is_valid_number, '福井県鯖江市河和田町');
ok($zip->set_number('9161223')->is_valid_number, '福井県鯖江市片山町');
ok($zip->set_number('9161224')->is_valid_number, '福井県鯖江市莇生田町');
ok($zip->set_number('9161225')->is_valid_number, '福井県鯖江市別司町');
ok($zip->set_number('9161231')->is_valid_number, '福井県鯖江市金谷町');
ok($zip->set_number('9161232')->is_valid_number, '福井県鯖江市寺中町');
ok($zip->set_number('9161233')->is_valid_number, '福井県鯖江市尾花町');
ok($zip->set_number('9161234')->is_valid_number, '福井県鯖江市沢町');
ok($zip->set_number('9161235')->is_valid_number, '福井県鯖江市上河内町');
ok($zip->set_number('9161236')->is_valid_number, '福井県鯖江市東清水町');
ok($zip->set_number('9161237')->is_valid_number, '福井県鯖江市北中町');
ok($zip->set_number('9170000')->is_valid_number, '福井県小浜市以下に掲載がない場合');
ok($zip->set_number('9170001')->is_valid_number, '福井県小浜市福谷');
ok($zip->set_number('9170002')->is_valid_number, '福井県小浜市北長町');
ok($zip->set_number('9170002')->is_valid_number, '福井県小浜市北塩屋');
ok($zip->set_number('9170003')->is_valid_number, '福井県小浜市学園町');
ok($zip->set_number('9170004')->is_valid_number, '福井県小浜市大湊');
ok($zip->set_number('9170004')->is_valid_number, '福井県小浜市小湊');
ok($zip->set_number('9170004')->is_valid_number, '福井県小浜市湊');
ok($zip->set_number('9170005')->is_valid_number, '福井県小浜市板屋町');
ok($zip->set_number('9170006')->is_valid_number, '福井県小浜市小松原');
ok($zip->set_number('9170007')->is_valid_number, '福井県小浜市下竹原');
ok($zip->set_number('9170007')->is_valid_number, '福井県小浜市西長町');
ok($zip->set_number('9170008')->is_valid_number, '福井県小浜市新小松原');
ok($zip->set_number('9170011')->is_valid_number, '福井県小浜市奈胡');
ok($zip->set_number('9170012')->is_valid_number, '福井県小浜市熊野');
ok($zip->set_number('9170013')->is_valid_number, '福井県小浜市太良庄');
ok($zip->set_number('9170014')->is_valid_number, '福井県小浜市北川');
ok($zip->set_number('9170014')->is_valid_number, '福井県小浜市高塚');
ok($zip->set_number('9170015')->is_valid_number, '福井県小浜市栗田');
ok($zip->set_number('9170016')->is_valid_number, '福井県小浜市次吉');
ok($zip->set_number('9170017')->is_valid_number, '福井県小浜市江古川');
ok($zip->set_number('9170017')->is_valid_number, '福井県小浜市羽賀');
ok($zip->set_number('9170018')->is_valid_number, '福井県小浜市松ケ崎');
ok($zip->set_number('9170019')->is_valid_number, '福井県小浜市山王前');
ok($zip->set_number('9170021')->is_valid_number, '福井県小浜市関');
ok($zip->set_number('9170021')->is_valid_number, '福井県小浜市竹原');
ok($zip->set_number('9170022')->is_valid_number, '福井県小浜市上竹原');
ok($zip->set_number('9170023')->is_valid_number, '福井県小浜市府中');
ok($zip->set_number('9170024')->is_valid_number, '福井県小浜市和久里');
ok($zip->set_number('9170025')->is_valid_number, '福井県小浜市木崎');
ok($zip->set_number('9170026')->is_valid_number, '福井県小浜市多田');
ok($zip->set_number('9170027')->is_valid_number, '福井県小浜市生守');
ok($zip->set_number('9170027')->is_valid_number, '福井県小浜市生守団地');
ok($zip->set_number('9170028')->is_valid_number, '福井県小浜市野代');
ok($zip->set_number('9170031')->is_valid_number, '福井県小浜市谷田部');
ok($zip->set_number('9170032')->is_valid_number, '福井県小浜市尾崎');
ok($zip->set_number('9170033')->is_valid_number, '福井県小浜市須縄');
ok($zip->set_number('9170034')->is_valid_number, '福井県小浜市奥田縄');
ok($zip->set_number('9170035')->is_valid_number, '福井県小浜市口田縄');
ok($zip->set_number('9170036')->is_valid_number, '福井県小浜市上中井');
ok($zip->set_number('9170036')->is_valid_number, '福井県小浜市下中井');
ok($zip->set_number('9170036')->is_valid_number, '福井県小浜市新滝');
ok($zip->set_number('9170036')->is_valid_number, '福井県小浜市滝谷');
ok($zip->set_number('9170036')->is_valid_number, '福井県小浜市中井');
ok($zip->set_number('9170037')->is_valid_number, '福井県小浜市相生');
ok($zip->set_number('9170037')->is_valid_number, '福井県小浜市西相生');
ok($zip->set_number('9170037')->is_valid_number, '福井県小浜市東相生');
ok($zip->set_number('9170041')->is_valid_number, '福井県小浜市青井');
ok($zip->set_number('9170042')->is_valid_number, '福井県小浜市東勢');
ok($zip->set_number('9170043')->is_valid_number, '福井県小浜市西勢');
ok($zip->set_number('9170044')->is_valid_number, '福井県小浜市荒木');
ok($zip->set_number('9170044')->is_valid_number, '福井県小浜市黒駒');
ok($zip->set_number('9170044')->is_valid_number, '福井県小浜市法海');
ok($zip->set_number('9170044')->is_valid_number, '福井県小浜市飯盛');
ok($zip->set_number('9170045')->is_valid_number, '福井県小浜市加斗');
ok($zip->set_number('9170045')->is_valid_number, '福井県小浜市上加斗');
ok($zip->set_number('9170045')->is_valid_number, '福井県小浜市下加斗');
ok($zip->set_number('9170046')->is_valid_number, '福井県小浜市岡津');
ok($zip->set_number('9170047')->is_valid_number, '福井県小浜市鯉川');
ok($zip->set_number('9170051')->is_valid_number, '福井県小浜市小浜白鳥');
ok($zip->set_number('9170052')->is_valid_number, '福井県小浜市小浜男山');
ok($zip->set_number('9170053')->is_valid_number, '福井県小浜市小浜大宮');
ok($zip->set_number('9170054')->is_valid_number, '福井県小浜市伏原');
ok($zip->set_number('9170055')->is_valid_number, '福井県小浜市小浜浅間');
ok($zip->set_number('9170056')->is_valid_number, '福井県小浜市小浜大原');
ok($zip->set_number('9170057')->is_valid_number, '福井県小浜市小浜飛鳥');
ok($zip->set_number('9170058')->is_valid_number, '福井県小浜市小浜香取');
ok($zip->set_number('9170059')->is_valid_number, '福井県小浜市小浜貴船');
ok($zip->set_number('9170061')->is_valid_number, '福井県小浜市小浜玉前');
ok($zip->set_number('9170062')->is_valid_number, '福井県小浜市小浜今宮');
ok($zip->set_number('9170063')->is_valid_number, '福井県小浜市小浜酒井');
ok($zip->set_number('9170064')->is_valid_number, '福井県小浜市小浜竜田');
ok($zip->set_number('9170065')->is_valid_number, '福井県小浜市小浜住吉');
ok($zip->set_number('9170066')->is_valid_number, '福井県小浜市小浜神田');
ok($zip->set_number('9170067')->is_valid_number, '福井県小浜市小浜鹿島');
ok($zip->set_number('9170068')->is_valid_number, '福井県小浜市小浜日吉');
ok($zip->set_number('9170069')->is_valid_number, '福井県小浜市小浜白鬚');
ok($zip->set_number('9170071')->is_valid_number, '福井県小浜市一番町');
ok($zip->set_number('9170072')->is_valid_number, '福井県小浜市千種');
ok($zip->set_number('9170073')->is_valid_number, '福井県小浜市四谷町');
ok($zip->set_number('9170074')->is_valid_number, '福井県小浜市後瀬町');
ok($zip->set_number('9170075')->is_valid_number, '福井県小浜市南川町');
ok($zip->set_number('9170076')->is_valid_number, '福井県小浜市湯岡');
ok($zip->set_number('9170077')->is_valid_number, '福井県小浜市駅前町');
ok($zip->set_number('9170078')->is_valid_number, '福井県小浜市大手町');
ok($zip->set_number('9170081')->is_valid_number, '福井県小浜市川崎');
ok($zip->set_number('9170082')->is_valid_number, '福井県小浜市小浜津島');
ok($zip->set_number('9170083')->is_valid_number, '福井県小浜市小浜清滝');
ok($zip->set_number('9170084')->is_valid_number, '福井県小浜市小浜広峰');
ok($zip->set_number('9170085')->is_valid_number, '福井県小浜市小浜生玉');
ok($zip->set_number('9170086')->is_valid_number, '福井県小浜市小浜塩竈');
ok($zip->set_number('9170087')->is_valid_number, '福井県小浜市小浜鈴鹿');
ok($zip->set_number('9170088')->is_valid_number, '福井県小浜市小浜多賀');
ok($zip->set_number('9170091')->is_valid_number, '福井県小浜市西津');
ok($zip->set_number('9170092')->is_valid_number, '福井県小浜市山手');
ok($zip->set_number('9170093')->is_valid_number, '福井県小浜市水取');
ok($zip->set_number('9170094')->is_valid_number, '福井県小浜市丸山');
ok($zip->set_number('9170095')->is_valid_number, '福井県小浜市城内');
ok($zip->set_number('9170096')->is_valid_number, '福井県小浜市雲浜');
ok($zip->set_number('9170097')->is_valid_number, '福井県小浜市堀屋敷');
ok($zip->set_number('9170101')->is_valid_number, '福井県小浜市田烏');
ok($zip->set_number('9170102')->is_valid_number, '福井県小浜市矢代');
ok($zip->set_number('9170103')->is_valid_number, '福井県小浜市志積');
ok($zip->set_number('9170104')->is_valid_number, '福井県小浜市犬熊');
ok($zip->set_number('9170105')->is_valid_number, '福井県小浜市阿納');
ok($zip->set_number('9170106')->is_valid_number, '福井県小浜市阿納尻');
ok($zip->set_number('9170107')->is_valid_number, '福井県小浜市甲ケ崎');
ok($zip->set_number('9170111')->is_valid_number, '福井県小浜市西小川');
ok($zip->set_number('9170112')->is_valid_number, '福井県小浜市加尾');
ok($zip->set_number('9170113')->is_valid_number, '福井県小浜市宇久');
ok($zip->set_number('9170114')->is_valid_number, '福井県小浜市若狭');
ok($zip->set_number('9170115')->is_valid_number, '福井県小浜市仏谷');
ok($zip->set_number('9170116')->is_valid_number, '福井県小浜市堅海');
ok($zip->set_number('9170117')->is_valid_number, '福井県小浜市泊');
ok($zip->set_number('9170221')->is_valid_number, '福井県小浜市大谷');
ok($zip->set_number('9170222')->is_valid_number, '福井県小浜市新保');
ok($zip->set_number('9170223')->is_valid_number, '福井県小浜市大戸');
ok($zip->set_number('9170223')->is_valid_number, '福井県小浜市加茂');
ok($zip->set_number('9170224')->is_valid_number, '福井県小浜市竹長');
ok($zip->set_number('9170225')->is_valid_number, '福井県小浜市本保');
ok($zip->set_number('9170226')->is_valid_number, '福井県小浜市平野');
ok($zip->set_number('9170231')->is_valid_number, '福井県小浜市国分');
ok($zip->set_number('9170232')->is_valid_number, '福井県小浜市東市場');
ok($zip->set_number('9170233')->is_valid_number, '福井県小浜市太興寺');
ok($zip->set_number('9170234')->is_valid_number, '福井県小浜市上野');
ok($zip->set_number('9170235')->is_valid_number, '福井県小浜市四分一');
ok($zip->set_number('9170236')->is_valid_number, '福井県小浜市三分一');
ok($zip->set_number('9170237')->is_valid_number, '福井県小浜市門前');
ok($zip->set_number('9170238')->is_valid_number, '福井県小浜市池河内');
ok($zip->set_number('9170241')->is_valid_number, '福井県小浜市池田');
ok($zip->set_number('9170241')->is_valid_number, '福井県小浜市市場');
ok($zip->set_number('9170241')->is_valid_number, '福井県小浜市遠敷');
ok($zip->set_number('9170241')->is_valid_number, '福井県小浜市検見坂');
ok($zip->set_number('9170241')->is_valid_number, '福井県小浜市島');
ok($zip->set_number('9170241')->is_valid_number, '福井県小浜市中村');
ok($zip->set_number('9170242')->is_valid_number, '福井県小浜市金屋');
ok($zip->set_number('9170242')->is_valid_number, '福井県小浜市中の宮');
ok($zip->set_number('9170243')->is_valid_number, '福井県小浜市竜前');
ok($zip->set_number('9170244')->is_valid_number, '福井県小浜市神宮寺');
ok($zip->set_number('9170245')->is_valid_number, '福井県小浜市忠野');
ok($zip->set_number('9170246')->is_valid_number, '福井県小浜市下根来');
ok($zip->set_number('9170247')->is_valid_number, '福井県小浜市中ノ畑');
ok($zip->set_number('9170248')->is_valid_number, '福井県小浜市上根来');
ok($zip->set_number('9170249')->is_valid_number, '福井県小浜市宮の前');
ok($zip->set_number('9170351')->is_valid_number, '福井県小浜市田茂谷');
ok($zip->set_number('9170352')->is_valid_number, '福井県小浜市深谷');
ok($zip->set_number('9170353')->is_valid_number, '福井県小浜市深野');
ok($zip->set_number('9170354')->is_valid_number, '福井県小浜市和多田');
ok($zip->set_number('9170355')->is_valid_number, '福井県小浜市下田');
ok($zip->set_number('9170356')->is_valid_number, '福井県小浜市上田');
ok($zip->set_number('9170357')->is_valid_number, '福井県小浜市小屋');
ok($zip->set_number('9170361')->is_valid_number, '福井県大飯郡おおい町名田庄挙原');
ok($zip->set_number('9170361')->is_valid_number, '福井県大飯郡おおい町名田庄木谷');
ok($zip->set_number('9170361')->is_valid_number, '福井県大飯郡おおい町名田庄出合');
ok($zip->set_number('9170361')->is_valid_number, '福井県大飯郡おおい町名田庄虫谷');
ok($zip->set_number('9170362')->is_valid_number, '福井県大飯郡おおい町名田庄永谷');
ok($zip->set_number('9170363')->is_valid_number, '福井県大飯郡おおい町名田庄挙野');
ok($zip->set_number('9170364')->is_valid_number, '福井県大飯郡おおい町名田庄虫鹿野');
ok($zip->set_number('9170365')->is_valid_number, '福井県大飯郡おおい町名田庄小倉畑');
ok($zip->set_number('9170371')->is_valid_number, '福井県大飯郡おおい町名田庄小倉');
ok($zip->set_number('9170372')->is_valid_number, '福井県大飯郡おおい町名田庄堂本');
ok($zip->set_number('9170373')->is_valid_number, '福井県大飯郡おおい町名田庄染ケ谷');
ok($zip->set_number('9170373')->is_valid_number, '福井県大飯郡おおい町名田庄槇谷');
ok($zip->set_number('9170374')->is_valid_number, '福井県大飯郡おおい町名田庄中');
ok($zip->set_number('9170375')->is_valid_number, '福井県大飯郡おおい町名田庄納田終');
ok($zip->set_number('9170381')->is_valid_number, '福井県大飯郡おおい町名田庄三重');
ok($zip->set_number('9170382')->is_valid_number, '福井県大飯郡おおい町名田庄久坂');
ok($zip->set_number('9170383')->is_valid_number, '福井県大飯郡おおい町名田庄下');
ok($zip->set_number('9170384')->is_valid_number, '福井県大飯郡おおい町名田庄西谷');
ok($zip->set_number('9170385')->is_valid_number, '福井県大飯郡おおい町名田庄井上');
ok($zip->set_number('9170386')->is_valid_number, '福井県大飯郡おおい町名田庄口坂本');
ok($zip->set_number('9170387')->is_valid_number, '福井県大飯郡おおい町名田庄奥坂本');
ok($zip->set_number('9180000')->is_valid_number, '福井県福井市以下に掲載がない場合');
ok($zip->set_number('9188001')->is_valid_number, '福井県福井市つくも');
ok($zip->set_number('9188002')->is_valid_number, '福井県福井市左内町');
ok($zip->set_number('9188003')->is_valid_number, '福井県福井市毛矢');
ok($zip->set_number('9188004')->is_valid_number, '福井県福井市西木田');
ok($zip->set_number('9188005')->is_valid_number, '福井県福井市みのり');
ok($zip->set_number('9188006')->is_valid_number, '福井県福井市足羽上町');
ok($zip->set_number('9188007')->is_valid_number, '福井県福井市足羽');
ok($zip->set_number('9188008')->is_valid_number, '福井県福井市有楽町');
ok($zip->set_number('9188009')->is_valid_number, '福井県福井市山奥町');
ok($zip->set_number('9188011')->is_valid_number, '福井県福井市月見');
ok($zip->set_number('9188012')->is_valid_number, '福井県福井市花堂北');
ok($zip->set_number('9188013')->is_valid_number, '福井県福井市花堂東');
ok($zip->set_number('9188014')->is_valid_number, '福井県福井市花堂中');
ok($zip->set_number('9188015')->is_valid_number, '福井県福井市花堂南');
ok($zip->set_number('9188016')->is_valid_number, '福井県福井市江端町');
ok($zip->set_number('9188017')->is_valid_number, '福井県福井市下荒井町');
ok($zip->set_number('9188018')->is_valid_number, '福井県福井市大島町');
ok($zip->set_number('9188021')->is_valid_number, '福井県福井市門前');
ok($zip->set_number('9188021')->is_valid_number, '福井県福井市門前町');
ok($zip->set_number('9188022')->is_valid_number, '福井県福井市西谷町');
ok($zip->set_number('9188023')->is_valid_number, '福井県福井市西谷');
ok($zip->set_number('9188024')->is_valid_number, '福井県福井市舞屋町');
ok($zip->set_number('9188025')->is_valid_number, '福井県福井市江守中');
ok($zip->set_number('9188025')->is_valid_number, '福井県福井市江守中町');
ok($zip->set_number('9188026')->is_valid_number, '福井県福井市渕');
ok($zip->set_number('9188026')->is_valid_number, '福井県福井市渕町');
ok($zip->set_number('9188027')->is_valid_number, '福井県福井市福');
ok($zip->set_number('9188027')->is_valid_number, '福井県福井市福町');
ok($zip->set_number('9188031')->is_valid_number, '福井県福井市種池');
ok($zip->set_number('9188031')->is_valid_number, '福井県福井市種池町');
ok($zip->set_number('9188032')->is_valid_number, '福井県福井市南江守町');
ok($zip->set_number('9188033')->is_valid_number, '福井県福井市合谷町');
ok($zip->set_number('9188034')->is_valid_number, '福井県福井市南居町');
ok($zip->set_number('9188035')->is_valid_number, '福井県福井市江守の里');
ok($zip->set_number('9188036')->is_valid_number, '福井県福井市新下江守町');
ok($zip->set_number('9188037')->is_valid_number, '福井県福井市下江守町');
ok($zip->set_number('9188041')->is_valid_number, '福井県福井市西下野町');
ok($zip->set_number('9188042')->is_valid_number, '福井県福井市東下野町');
ok($zip->set_number('9188043')->is_valid_number, '福井県福井市狐橋');
ok($zip->set_number('9188044')->is_valid_number, '福井県福井市高塚町');
ok($zip->set_number('9188045')->is_valid_number, '福井県福井市福新町');
ok($zip->set_number('9188046')->is_valid_number, '福井県福井市運動公園');
ok($zip->set_number('9188047')->is_valid_number, '福井県福井市久喜津町');
ok($zip->set_number('9188051')->is_valid_number, '福井県福井市桃園');
ok($zip->set_number('9188052')->is_valid_number, '福井県福井市明里町');
ok($zip->set_number('9188053')->is_valid_number, '福井県福井市小山谷町');
ok($zip->set_number('9188054')->is_valid_number, '福井県福井市加茂河原町');
ok($zip->set_number('9188055')->is_valid_number, '福井県福井市若杉');
ok($zip->set_number('9188055')->is_valid_number, '福井県福井市若杉町');
ok($zip->set_number('9188056')->is_valid_number, '福井県福井市若杉浜');
ok($zip->set_number('9188057')->is_valid_number, '福井県福井市加茂河原');
ok($zip->set_number('9188058')->is_valid_number, '福井県福井市加茂緑苑町');
ok($zip->set_number('9188061')->is_valid_number, '福井県福井市金屋町');
ok($zip->set_number('9188062')->is_valid_number, '福井県福井市下市町');
ok($zip->set_number('9188063')->is_valid_number, '福井県福井市大瀬町');
ok($zip->set_number('9188064')->is_valid_number, '福井県福井市西学園');
ok($zip->set_number('9188065')->is_valid_number, '福井県福井市水越');
ok($zip->set_number('9188066')->is_valid_number, '福井県福井市渡町');
ok($zip->set_number('9188067')->is_valid_number, '福井県福井市飯塚町');
ok($zip->set_number('9188068')->is_valid_number, '福井県福井市角折町');
ok($zip->set_number('9188071')->is_valid_number, '福井県福井市恐神町');
ok($zip->set_number('9188072')->is_valid_number, '福井県福井市北堀町');
ok($zip->set_number('9188073')->is_valid_number, '福井県福井市安田町');
ok($zip->set_number('9188074')->is_valid_number, '福井県福井市細坂町');
ok($zip->set_number('9188075')->is_valid_number, '福井県福井市羽坂町');
ok($zip->set_number('9188076')->is_valid_number, '福井県福井市本堂町');
ok($zip->set_number('9188077')->is_valid_number, '福井県福井市末町');
ok($zip->set_number('9188078')->is_valid_number, '福井県福井市更毛町');
ok($zip->set_number('9188081')->is_valid_number, '福井県福井市上一光町');
ok($zip->set_number('9188082')->is_valid_number, '福井県福井市下一光町');
ok($zip->set_number('9188083')->is_valid_number, '福井県福井市五太子町');
ok($zip->set_number('9188101')->is_valid_number, '福井県福井市一本木町');
ok($zip->set_number('9188102')->is_valid_number, '福井県福井市西板垣町');
ok($zip->set_number('9188103')->is_valid_number, '福井県福井市板垣町');
ok($zip->set_number('9188104')->is_valid_number, '福井県福井市板垣');
ok($zip->set_number('9188105')->is_valid_number, '福井県福井市木田');
ok($zip->set_number('9188106')->is_valid_number, '福井県福井市木田町');
ok($zip->set_number('9188107')->is_valid_number, '福井県福井市春日町');
ok($zip->set_number('9188108')->is_valid_number, '福井県福井市春日');
ok($zip->set_number('9188111')->is_valid_number, '福井県福井市馬垣町');
ok($zip->set_number('9188112')->is_valid_number, '福井県福井市下馬');
ok($zip->set_number('9188113')->is_valid_number, '福井県福井市下馬町');
ok($zip->set_number('9188114')->is_valid_number, '福井県福井市羽水');
ok($zip->set_number('9188115')->is_valid_number, '福井県福井市別所町');
ok($zip->set_number('9188116')->is_valid_number, '福井県福井市大町');
ok($zip->set_number('9188131')->is_valid_number, '福井県福井市小稲津町');
ok($zip->set_number('9188132')->is_valid_number, '福井県福井市上六条町');
ok($zip->set_number('9188133')->is_valid_number, '福井県福井市上莇生田町');
ok($zip->set_number('9188134')->is_valid_number, '福井県福井市下莇生田町');
ok($zip->set_number('9188135')->is_valid_number, '福井県福井市下六条町');
ok($zip->set_number('9188136')->is_valid_number, '福井県福井市天王町');
ok($zip->set_number('9188151')->is_valid_number, '福井県福井市中荒井町');
ok($zip->set_number('9188152')->is_valid_number, '福井県福井市今市町');
ok($zip->set_number('9188153')->is_valid_number, '福井県福井市安保町');
ok($zip->set_number('9188154')->is_valid_number, '福井県福井市冬野町');
ok($zip->set_number('9188155')->is_valid_number, '福井県福井市杉谷町');
ok($zip->set_number('9188156')->is_valid_number, '福井県福井市引目町');
ok($zip->set_number('9188161')->is_valid_number, '福井県福井市鉾ケ崎町');
ok($zip->set_number('9188162')->is_valid_number, '福井県福井市角原町');
ok($zip->set_number('9188163')->is_valid_number, '福井県福井市生野町');
ok($zip->set_number('9188164')->is_valid_number, '福井県福井市三本木町');
ok($zip->set_number('9188165')->is_valid_number, '福井県福井市徳尾町');
ok($zip->set_number('9188166')->is_valid_number, '福井県福井市主計中町');
ok($zip->set_number('9188171')->is_valid_number, '福井県福井市森行町');
ok($zip->set_number('9188172')->is_valid_number, '福井県福井市末広町');
ok($zip->set_number('9188173')->is_valid_number, '福井県福井市下江尻町');
ok($zip->set_number('9188174')->is_valid_number, '福井県福井市上江尻町');
ok($zip->set_number('9188175')->is_valid_number, '福井県福井市江尻ケ丘町');
ok($zip->set_number('9188176')->is_valid_number, '福井県福井市三十八社町');
ok($zip->set_number('9188181')->is_valid_number, '福井県福井市浅水町');
ok($zip->set_number('9188182')->is_valid_number, '福井県福井市浅水二日町');
ok($zip->set_number('9188183')->is_valid_number, '福井県福井市浅水三ケ町');
ok($zip->set_number('9188184')->is_valid_number, '福井県福井市真木町');
ok($zip->set_number('9188185')->is_valid_number, '福井県福井市中野町');
ok($zip->set_number('9188186')->is_valid_number, '福井県福井市中野');
ok($zip->set_number('9188187')->is_valid_number, '福井県福井市花守町');
ok($zip->set_number('9188188')->is_valid_number, '福井県福井市三尾野町');
ok($zip->set_number('9188201')->is_valid_number, '福井県福井市南四ツ居町');
ok($zip->set_number('9188202')->is_valid_number, '福井県福井市大東');
ok($zip->set_number('9188203')->is_valid_number, '福井県福井市上北野');
ok($zip->set_number('9188204')->is_valid_number, '福井県福井市南四ツ居');
ok($zip->set_number('9188205')->is_valid_number, '福井県福井市北四ツ居');
ok($zip->set_number('9188206')->is_valid_number, '福井県福井市北四ツ居町');
ok($zip->set_number('9188207')->is_valid_number, '福井県福井市円山');
ok($zip->set_number('9188211')->is_valid_number, '福井県福井市下中町');
ok($zip->set_number('9188212')->is_valid_number, '福井県福井市北今泉町');
ok($zip->set_number('9188213')->is_valid_number, '福井県福井市今泉町');
ok($zip->set_number('9188214')->is_valid_number, '福井県福井市東今泉町');
ok($zip->set_number('9188215')->is_valid_number, '福井県福井市寮町');
ok($zip->set_number('9188216')->is_valid_number, '福井県福井市殿下町');
ok($zip->set_number('9188217')->is_valid_number, '福井県福井市印田町');
ok($zip->set_number('9188218')->is_valid_number, '福井県福井市河増町');
ok($zip->set_number('9188221')->is_valid_number, '福井県福井市堅達町');
ok($zip->set_number('9188222')->is_valid_number, '福井県福井市坂下町');
ok($zip->set_number('9188223')->is_valid_number, '福井県福井市河水町');
ok($zip->set_number('9188224')->is_valid_number, '福井県福井市花野谷町');
ok($zip->set_number('9188225')->is_valid_number, '福井県福井市宮地町');
ok($zip->set_number('9188226')->is_valid_number, '福井県福井市大畑町');
ok($zip->set_number('9188227')->is_valid_number, '福井県福井市次郎丸町');
ok($zip->set_number('9188228')->is_valid_number, '福井県福井市岡西谷町');
ok($zip->set_number('9188231')->is_valid_number, '福井県福井市問屋町');
ok($zip->set_number('9188232')->is_valid_number, '福井県福井市荒木別所町');
ok($zip->set_number('9188233')->is_valid_number, '福井県福井市合島町');
ok($zip->set_number('9188234')->is_valid_number, '福井県福井市曽万布町');
ok($zip->set_number('9188235')->is_valid_number, '福井県福井市和田中町');
ok($zip->set_number('9188236')->is_valid_number, '福井県福井市和田中');
ok($zip->set_number('9188237')->is_valid_number, '福井県福井市和田東');
ok($zip->set_number('9188238')->is_valid_number, '福井県福井市和田');
ok($zip->set_number('9188239')->is_valid_number, '福井県福井市成和');
ok($zip->set_number('9190101')->is_valid_number, '福井県南条郡南越前町湯尾');
ok($zip->set_number('9190102')->is_valid_number, '福井県南条郡南越前町八乙女');
ok($zip->set_number('9190103')->is_valid_number, '福井県南条郡南越前町社谷');
ok($zip->set_number('9190104')->is_valid_number, '福井県南条郡南越前町燧');
ok($zip->set_number('9190111')->is_valid_number, '福井県南条郡南越前町杉谷');
ok($zip->set_number('9190112')->is_valid_number, '福井県南条郡南越前町杣木俣');
ok($zip->set_number('9190113')->is_valid_number, '福井県南条郡南越前町瀬戸');
ok($zip->set_number('9190114')->is_valid_number, '福井県南条郡南越前町小倉谷');
ok($zip->set_number('9190115')->is_valid_number, '福井県南条郡南越前町上温谷');
ok($zip->set_number('9190116')->is_valid_number, '福井県南条郡南越前町古木');
ok($zip->set_number('9190117')->is_valid_number, '福井県南条郡南越前町馬上免');
ok($zip->set_number('9190118')->is_valid_number, '福井県南条郡南越前町長沢');
ok($zip->set_number('9190119')->is_valid_number, '福井県南条郡南越前町久喜');
ok($zip->set_number('9190121')->is_valid_number, '福井県南条郡南越前町合波');
ok($zip->set_number('9190122')->is_valid_number, '福井県南条郡南越前町大門');
ok($zip->set_number('9190123')->is_valid_number, '福井県南条郡南越前町荒井');
ok($zip->set_number('9190124')->is_valid_number, '福井県南条郡南越前町八飯');
ok($zip->set_number('9190125')->is_valid_number, '福井県南条郡南越前町宇津尾');
ok($zip->set_number('9190126')->is_valid_number, '福井県南条郡南越前町橋立');
ok($zip->set_number('9190127')->is_valid_number, '福井県南条郡南越前町広野');
ok($zip->set_number('9190128')->is_valid_number, '福井県南条郡南越前町板取');
ok($zip->set_number('9190129')->is_valid_number, '福井県南条郡南越前町孫谷');
ok($zip->set_number('9190131')->is_valid_number, '福井県南条郡南越前町今庄');
ok($zip->set_number('9190132')->is_valid_number, '福井県南条郡南越前町南今庄');
ok($zip->set_number('9190133')->is_valid_number, '福井県南条郡南越前町新道');
ok($zip->set_number('9190135')->is_valid_number, '福井県南条郡南越前町二ツ屋');
ok($zip->set_number('9190136')->is_valid_number, '福井県南条郡南越前町大桐');
ok($zip->set_number('9190200')->is_valid_number, '福井県南条郡南越前町以下に掲載がない場合');
ok($zip->set_number('9190201')->is_valid_number, '福井県南条郡南越前町上平吹');
ok($zip->set_number('9190202')->is_valid_number, '福井県南条郡南越前町鋳物師');
ok($zip->set_number('9190203')->is_valid_number, '福井県南条郡南越前町牧谷');
ok($zip->set_number('9190204')->is_valid_number, '福井県南条郡南越前町上野');
ok($zip->set_number('9190205')->is_valid_number, '福井県南条郡南越前町堂宮');
ok($zip->set_number('9190206')->is_valid_number, '福井県南条郡南越前町金粕');
ok($zip->set_number('9190211')->is_valid_number, '福井県南条郡南越前町関ケ鼻');
ok($zip->set_number('9190212')->is_valid_number, '福井県南条郡南越前町鯖波');
ok($zip->set_number('9190213')->is_valid_number, '福井県南条郡南越前町阿久和');
ok($zip->set_number('9190214')->is_valid_number, '福井県南条郡南越前町中小屋');
ok($zip->set_number('9190215')->is_valid_number, '福井県南条郡南越前町奥野々');
ok($zip->set_number('9190216')->is_valid_number, '福井県南条郡南越前町上別所');
ok($zip->set_number('9190217')->is_valid_number, '福井県南条郡南越前町杣山');
ok($zip->set_number('9190221')->is_valid_number, '福井県南条郡南越前町島');
ok($zip->set_number('9190222')->is_valid_number, '福井県南条郡南越前町日野');
ok($zip->set_number('9190223')->is_valid_number, '福井県南条郡南越前町東大道');
ok($zip->set_number('9190224')->is_valid_number, '福井県南条郡南越前町西大道');
ok($zip->set_number('9190225')->is_valid_number, '福井県南条郡南越前町東谷');
ok($zip->set_number('9190226')->is_valid_number, '福井県南条郡南越前町清水');
ok($zip->set_number('9190227')->is_valid_number, '福井県南条郡南越前町脇本');
ok($zip->set_number('9190301')->is_valid_number, '福井県福井市下細江町');
ok($zip->set_number('9190302')->is_valid_number, '福井県福井市上細江町');
ok($zip->set_number('9190303')->is_valid_number, '福井県福井市岩倉町');
ok($zip->set_number('9190304')->is_valid_number, '福井県福井市田中町');
ok($zip->set_number('9190305')->is_valid_number, '福井県福井市徳光町');
ok($zip->set_number('9190311')->is_valid_number, '福井県福井市田治島町');
ok($zip->set_number('9190312')->is_valid_number, '福井県福井市東大味町');
ok($zip->set_number('9190313')->is_valid_number, '福井県福井市西大味町');
ok($zip->set_number('9190314')->is_valid_number, '福井県福井市生部町');
ok($zip->set_number('9190315')->is_valid_number, '福井県福井市西袋町');
ok($zip->set_number('9190316')->is_valid_number, '福井県福井市大村町');
ok($zip->set_number('9190317')->is_valid_number, '福井県福井市北山町');
ok($zip->set_number('9190318')->is_valid_number, '福井県福井市北山新保町');
ok($zip->set_number('9190321')->is_valid_number, '福井県福井市下河北町');
ok($zip->set_number('9190322')->is_valid_number, '福井県福井市上河北町');
ok($zip->set_number('9190323')->is_valid_number, '福井県福井市太田町');
ok($zip->set_number('9190324')->is_valid_number, '福井県福井市帆谷町');
ok($zip->set_number('9190325')->is_valid_number, '福井県福井市二上町');
ok($zip->set_number('9190326')->is_valid_number, '福井県福井市半田町');
ok($zip->set_number('9190327')->is_valid_number, '福井県福井市大土呂町');
ok($zip->set_number('9190328')->is_valid_number, '福井県福井市新開町');
ok($zip->set_number('9190373')->is_valid_number, '福井県福井市下東郷町(新村)');
ok($zip->set_number('9190401')->is_valid_number, '福井県坂井市春江町堀越');
ok($zip->set_number('9190402')->is_valid_number, '福井県坂井市春江町大牧');
ok($zip->set_number('9190403')->is_valid_number, '福井県坂井市春江町井向');
ok($zip->set_number('9190404')->is_valid_number, '福井県坂井市春江町西長田');
ok($zip->set_number('9190405')->is_valid_number, '福井県坂井市春江町上小森');
ok($zip->set_number('9190406')->is_valid_number, '福井県坂井市春江町下小森');
ok($zip->set_number('9190407')->is_valid_number, '福井県坂井市春江町辻');
ok($zip->set_number('9190408')->is_valid_number, '福井県坂井市春江町木部西方寺');
ok($zip->set_number('9190409')->is_valid_number, '福井県坂井市春江町定広');
ok($zip->set_number('9190411')->is_valid_number, '福井県坂井市春江町藤鷲塚');
ok($zip->set_number('9190412')->is_valid_number, '福井県坂井市春江町江留中');
ok($zip->set_number('9190413')->is_valid_number, '福井県坂井市春江町随応寺');
ok($zip->set_number('9190414')->is_valid_number, '福井県坂井市春江町江留下屋敷');
ok($zip->set_number('9190415')->is_valid_number, '福井県坂井市春江町江留下');
ok($zip->set_number('9190416')->is_valid_number, '福井県坂井市春江町江留下宇和江');
ok($zip->set_number('9190417')->is_valid_number, '福井県坂井市春江町江留下相田');
ok($zip->set_number('9190418')->is_valid_number, '福井県坂井市春江町江留下高道');
ok($zip->set_number('9190419')->is_valid_number, '福井県坂井市春江町随応寺東');
ok($zip->set_number('9190421')->is_valid_number, '福井県坂井市春江町大針');
ok($zip->set_number('9190422')->is_valid_number, '福井県坂井市春江町沖布目');
ok($zip->set_number('9190423')->is_valid_number, '福井県坂井市春江町石仏');
ok($zip->set_number('9190424')->is_valid_number, '福井県坂井市春江町いちい野');
ok($zip->set_number('9190425')->is_valid_number, '福井県坂井市春江町いちい野北');
ok($zip->set_number('9190426')->is_valid_number, '福井県坂井市春江町いちい野中央');
ok($zip->set_number('9190431')->is_valid_number, '福井県坂井市春江町為国');
ok($zip->set_number('9190432')->is_valid_number, '福井県坂井市春江町為国亀ケ久保');
ok($zip->set_number('9190433')->is_valid_number, '福井県坂井市春江町為国平成');
ok($zip->set_number('9190434')->is_valid_number, '福井県坂井市春江町境');
ok($zip->set_number('9190434')->is_valid_number, '福井県坂井市春江町境上町');
ok($zip->set_number('9190434')->is_valid_number, '福井県坂井市春江町境元町');
ok($zip->set_number('9190435')->is_valid_number, '福井県坂井市春江町為国幸');
ok($zip->set_number('9190436')->is_valid_number, '福井県坂井市春江町為国中区');
ok($zip->set_number('9190437')->is_valid_number, '福井県坂井市春江町為国西の宮');
ok($zip->set_number('9190441')->is_valid_number, '福井県坂井市春江町定重');
ok($zip->set_number('9190442')->is_valid_number, '福井県坂井市春江町寄安');
ok($zip->set_number('9190443')->is_valid_number, '福井県坂井市春江町正蓮花');
ok($zip->set_number('9190444')->is_valid_number, '福井県坂井市春江町中筋三ツ屋');
ok($zip->set_number('9190445')->is_valid_number, '福井県坂井市春江町中筋高田');
ok($zip->set_number('9190446')->is_valid_number, '福井県坂井市春江町中筋春日');
ok($zip->set_number('9190447')->is_valid_number, '福井県坂井市春江町中筋大手');
ok($zip->set_number('9190448')->is_valid_number, '福井県坂井市春江町中筋北浦');
ok($zip->set_number('9190449')->is_valid_number, '福井県坂井市春江町中筋');
ok($zip->set_number('9190451')->is_valid_number, '福井県坂井市春江町江留上旭');
ok($zip->set_number('9190452')->is_valid_number, '福井県坂井市春江町江留上本町');
ok($zip->set_number('9190453')->is_valid_number, '福井県坂井市春江町江留上中央');
ok($zip->set_number('9190454')->is_valid_number, '福井県坂井市春江町江留上日の出');
ok($zip->set_number('9190455')->is_valid_number, '福井県坂井市春江町江留上');
ok($zip->set_number('9190461')->is_valid_number, '福井県坂井市春江町江留上緑');
ok($zip->set_number('9190462')->is_valid_number, '福井県坂井市春江町江留上大和');
ok($zip->set_number('9190463')->is_valid_number, '福井県坂井市春江町江留上昭和');
ok($zip->set_number('9190464')->is_valid_number, '福井県坂井市春江町江留上錦');
ok($zip->set_number('9190465')->is_valid_number, '福井県坂井市春江町江留上新町');
ok($zip->set_number('9190471')->is_valid_number, '福井県坂井市春江町金剛寺');
ok($zip->set_number('9190472')->is_valid_number, '福井県坂井市春江町松木');
ok($zip->set_number('9190473')->is_valid_number, '福井県坂井市春江町本堂');
ok($zip->set_number('9190474')->is_valid_number, '福井県坂井市春江町西太郎丸');
ok($zip->set_number('9190475')->is_valid_number, '福井県坂井市春江町東太郎丸');
ok($zip->set_number('9190476')->is_valid_number, '福井県坂井市春江町針原');
ok($zip->set_number('9190477')->is_valid_number, '福井県坂井市春江町田端');
ok($zip->set_number('9190479')->is_valid_number, '福井県坂井市春江町高江');
ok($zip->set_number('9190481')->is_valid_number, '福井県坂井市春江町千歩寺');
ok($zip->set_number('9190482')->is_valid_number, '福井県坂井市春江町中庄');
ok($zip->set_number('9190483')->is_valid_number, '福井県坂井市春江町石塚');
ok($zip->set_number('9190484')->is_valid_number, '福井県坂井市春江町安沢');
ok($zip->set_number('9190485')->is_valid_number, '福井県坂井市春江町取次');
ok($zip->set_number('9190486')->is_valid_number, '福井県坂井市春江町布施田新');
ok($zip->set_number('9190487')->is_valid_number, '福井県坂井市春江町正善');
ok($zip->set_number('9190488')->is_valid_number, '福井県坂井市春江町姫王');
ok($zip->set_number('9190501')->is_valid_number, '福井県坂井市坂井町下関');
ok($zip->set_number('9190502')->is_valid_number, '福井県坂井市坂井町上関');
ok($zip->set_number('9190503')->is_valid_number, '福井県坂井市坂井町長屋');
ok($zip->set_number('9190504')->is_valid_number, '福井県坂井市坂井町御油田');
ok($zip->set_number('9190505')->is_valid_number, '福井県坂井市坂井町河和田');
ok($zip->set_number('9190506')->is_valid_number, '福井県坂井市坂井町定旨');
ok($zip->set_number('9190507')->is_valid_number, '福井県坂井市坂井町五本');
ok($zip->set_number('9190511')->is_valid_number, '福井県坂井市坂井町長畑');
ok($zip->set_number('9190512')->is_valid_number, '福井県坂井市坂井町宮領');
ok($zip->set_number('9190513')->is_valid_number, '福井県坂井市坂井町田島');
ok($zip->set_number('9190514')->is_valid_number, '福井県坂井市坂井町田島窪');
ok($zip->set_number('9190515')->is_valid_number, '福井県坂井市坂井町若宮');
ok($zip->set_number('9190516')->is_valid_number, '福井県坂井市坂井町福島');
ok($zip->set_number('9190517')->is_valid_number, '福井県坂井市坂井町朝日');
ok($zip->set_number('9190521')->is_valid_number, '福井県坂井市坂井町下新庄');
ok($zip->set_number('9190522')->is_valid_number, '福井県坂井市坂井町上新庄');
ok($zip->set_number('9190523')->is_valid_number, '福井県坂井市坂井町新庄');
ok($zip->set_number('9190524')->is_valid_number, '福井県坂井市坂井町東長田');
ok($zip->set_number('9190525')->is_valid_number, '福井県坂井市坂井町徳分田');
ok($zip->set_number('9190526')->is_valid_number, '福井県坂井市坂井町上兵庫');
ok($zip->set_number('9190527')->is_valid_number, '福井県坂井市坂井町下兵庫');
ok($zip->set_number('9190531')->is_valid_number, '福井県坂井市坂井町今井');
ok($zip->set_number('9190532')->is_valid_number, '福井県坂井市坂井町高柳');
ok($zip->set_number('9190533')->is_valid_number, '福井県坂井市坂井町木部東');
ok($zip->set_number('9190534')->is_valid_number, '福井県坂井市坂井町清永');
ok($zip->set_number('9190535')->is_valid_number, '福井県坂井市坂井町島');
ok($zip->set_number('9190536')->is_valid_number, '福井県坂井市坂井町木部新保');
ok($zip->set_number('9190537')->is_valid_number, '福井県坂井市坂井町折戸');
ok($zip->set_number('9190541')->is_valid_number, '福井県坂井市坂井町東');
ok($zip->set_number('9190542')->is_valid_number, '福井県坂井市坂井町蔵垣内');
ok($zip->set_number('9190543')->is_valid_number, '福井県坂井市坂井町西');
ok($zip->set_number('9190544')->is_valid_number, '福井県坂井市坂井町東中野');
ok($zip->set_number('9190545')->is_valid_number, '福井県坂井市坂井町東荒井');
ok($zip->set_number('9190546')->is_valid_number, '福井県坂井市坂井町蛸');
ok($zip->set_number('9190547')->is_valid_number, '福井県坂井市坂井町大味');
ok($zip->set_number('9190600')->is_valid_number, '福井県あわら市以下に掲載がない場合');
ok($zip->set_number('9190601')->is_valid_number, '福井県あわら市山室');
ok($zip->set_number('9190602')->is_valid_number, '福井県あわら市菅野');
ok($zip->set_number('9190603')->is_valid_number, '福井県あわら市矢地');
ok($zip->set_number('9190604')->is_valid_number, '福井県あわら市自由ケ丘');
ok($zip->set_number('9190611')->is_valid_number, '福井県あわら市清間');
ok($zip->set_number('9190612')->is_valid_number, '福井県あわら市桑原');
ok($zip->set_number('9190613')->is_valid_number, '福井県あわら市古屋石塚');
ok($zip->set_number('9190614')->is_valid_number, '福井県あわら市伊井');
ok($zip->set_number('9190615')->is_valid_number, '福井県あわら市池口');
ok($zip->set_number('9190616')->is_valid_number, '福井県あわら市河原井手');
ok($zip->set_number('9190621')->is_valid_number, '福井県あわら市市姫');
ok($zip->set_number('9190623')->is_valid_number, '福井県あわら市稲越');
ok($zip->set_number('9190628')->is_valid_number, '福井県あわら市大溝');
ok($zip->set_number('9190631')->is_valid_number, '福井県あわら市高塚');
ok($zip->set_number('9190632')->is_valid_number, '福井県あわら市春宮');
ok($zip->set_number('9190633')->is_valid_number, '福井県あわら市花乃杜');
ok($zip->set_number('9190634')->is_valid_number, '福井県あわら市北金津');
ok($zip->set_number('9190721')->is_valid_number, '福井県あわら市牛ノ谷');
ok($zip->set_number('9190722')->is_valid_number, '福井県あわら市畝市野々');
ok($zip->set_number('9190723')->is_valid_number, '福井県あわら市熊坂');
ok($zip->set_number('9190724')->is_valid_number, '福井県あわら市上野');
ok($zip->set_number('9190725')->is_valid_number, '福井県あわら市前谷');
ok($zip->set_number('9190726')->is_valid_number, '福井県あわら市笹岡');
ok($zip->set_number('9190727')->is_valid_number, '福井県あわら市下金屋');
ok($zip->set_number('9190731')->is_valid_number, '福井県あわら市権世市野々');
ok($zip->set_number('9190732')->is_valid_number, '福井県あわら市鎌谷');
ok($zip->set_number('9190733')->is_valid_number, '福井県あわら市清滝');
ok($zip->set_number('9190734')->is_valid_number, '福井県あわら市東山');
ok($zip->set_number('9190735')->is_valid_number, '福井県あわら市後山');
ok($zip->set_number('9190736')->is_valid_number, '福井県あわら市椚');
ok($zip->set_number('9190737')->is_valid_number, '福井県あわら市権世');
ok($zip->set_number('9190741')->is_valid_number, '福井県あわら市中川');
ok($zip->set_number('9190742')->is_valid_number, '福井県あわら市瓜生');
ok($zip->set_number('9190743')->is_valid_number, '福井県あわら市南疋田');
ok($zip->set_number('9190744')->is_valid_number, '福井県あわら市北疋田');
ok($zip->set_number('9190745')->is_valid_number, '福井県あわら市次郎丸');
ok($zip->set_number('9190746')->is_valid_number, '福井県あわら市東田中');
ok($zip->set_number('9190747')->is_valid_number, '福井県あわら市御簾尾');
ok($zip->set_number('9190748')->is_valid_number, '福井県あわら市北野');
ok($zip->set_number('9190749')->is_valid_number, '福井県あわら市北');
ok($zip->set_number('9190801')->is_valid_number, '福井県あわら市細呂木');
ok($zip->set_number('9190802')->is_valid_number, '福井県あわら市橋屋');
ok($zip->set_number('9190803')->is_valid_number, '福井県あわら市樋山');
ok($zip->set_number('9190804')->is_valid_number, '福井県あわら市沢');
ok($zip->set_number('9190805')->is_valid_number, '福井県あわら市滝');
ok($zip->set_number('9190806')->is_valid_number, '福井県あわら市宮谷');
ok($zip->set_number('9190807')->is_valid_number, '福井県あわら市指中');
ok($zip->set_number('9190811')->is_valid_number, '福井県あわら市蓮ケ浦');
ok($zip->set_number('9190812')->is_valid_number, '福井県あわら市柿原');
ok($zip->set_number('9190813')->is_valid_number, '福井県あわら市山西方寺');
ok($zip->set_number('9190814')->is_valid_number, '福井県あわら市青ノ木');
ok($zip->set_number('9190815')->is_valid_number, '福井県あわら市清王');
ok($zip->set_number('9190816')->is_valid_number, '福井県あわら市山十楽');
ok($zip->set_number('9190817')->is_valid_number, '福井県あわら市坂口');
ok($zip->set_number('9191100')->is_valid_number, '福井県三方郡美浜町以下に掲載がない場合');
ok($zip->set_number('9191121')->is_valid_number, '福井県三方郡美浜町和田');
ok($zip->set_number('9191122')->is_valid_number, '福井県三方郡美浜町松原');
ok($zip->set_number('9191123')->is_valid_number, '福井県三方郡美浜町久々子');
ok($zip->set_number('9191124')->is_valid_number, '福井県三方郡美浜町早瀬');
ok($zip->set_number('9191125')->is_valid_number, '福井県三方郡美浜町笹田');
ok($zip->set_number('9191126')->is_valid_number, '福井県三方郡美浜町日向');
ok($zip->set_number('9191131')->is_valid_number, '福井県三方郡美浜町木野');
ok($zip->set_number('9191132')->is_valid_number, '福井県三方郡美浜町佐柿');
ok($zip->set_number('9191133')->is_valid_number, '福井県三方郡美浜町麻生');
ok($zip->set_number('9191134')->is_valid_number, '福井県三方郡美浜町宮代');
ok($zip->set_number('9191135')->is_valid_number, '福井県三方郡美浜町五十谷');
ok($zip->set_number('9191135')->is_valid_number, '福井県三方郡美浜町安江');
ok($zip->set_number('9191135')->is_valid_number, '福井県三方郡美浜町寄戸');
ok($zip->set_number('9191136')->is_valid_number, '福井県三方郡美浜町中寺');
ok($zip->set_number('9191137')->is_valid_number, '福井県三方郡美浜町南市');
ok($zip->set_number('9191138')->is_valid_number, '福井県三方郡美浜町河原市');
ok($zip->set_number('9191141')->is_valid_number, '福井県三方郡美浜町郷市');
ok($zip->set_number('9191142')->is_valid_number, '福井県三方郡美浜町興道寺');
ok($zip->set_number('9191143')->is_valid_number, '福井県三方郡美浜町佐野');
ok($zip->set_number('9191144')->is_valid_number, '福井県三方郡美浜町新庄');
ok($zip->set_number('9191145')->is_valid_number, '福井県三方郡美浜町金山');
ok($zip->set_number('9191146')->is_valid_number, '福井県三方郡美浜町大薮');
ok($zip->set_number('9191147')->is_valid_number, '福井県三方郡美浜町気山');
ok($zip->set_number('9191201')->is_valid_number, '福井県三方郡美浜町丹生');
ok($zip->set_number('9191202')->is_valid_number, '福井県三方郡美浜町竹波');
ok($zip->set_number('9191203')->is_valid_number, '福井県三方郡美浜町菅浜');
ok($zip->set_number('9191204')->is_valid_number, '福井県三方郡美浜町北田');
ok($zip->set_number('9191205')->is_valid_number, '福井県三方郡美浜町佐田');
ok($zip->set_number('9191206')->is_valid_number, '福井県三方郡美浜町太田');
ok($zip->set_number('9191207')->is_valid_number, '福井県三方郡美浜町山上');
ok($zip->set_number('9191208')->is_valid_number, '福井県三方郡美浜町坂尻');
ok($zip->set_number('9191279')->is_valid_number, '福井県敦賀市白木');
ok($zip->set_number('9191300')->is_valid_number, '福井県三方上中郡若狭町以下に掲載がない場合');
ok($zip->set_number('9191301')->is_valid_number, '福井県三方上中郡若狭町気山');
ok($zip->set_number('9191302')->is_valid_number, '福井県三方上中郡若狭町上瀬');
ok($zip->set_number('9191303')->is_valid_number, '福井県三方上中郡若狭町三方');
ok($zip->set_number('9191304')->is_valid_number, '福井県三方上中郡若狭町生倉');
ok($zip->set_number('9191305')->is_valid_number, '福井県三方上中郡若狭町北前川');
ok($zip->set_number('9191306')->is_valid_number, '福井県三方上中郡若狭町南前川');
ok($zip->set_number('9191311')->is_valid_number, '福井県三方上中郡若狭町藤井');
ok($zip->set_number('9191312')->is_valid_number, '福井県三方上中郡若狭町相田');
ok($zip->set_number('9191313')->is_valid_number, '福井県三方上中郡若狭町横渡');
ok($zip->set_number('9191314')->is_valid_number, '福井県三方上中郡若狭町能登野');
ok($zip->set_number('9191315')->is_valid_number, '福井県三方上中郡若狭町高岸');
ok($zip->set_number('9191316')->is_valid_number, '福井県三方上中郡若狭町井崎');
ok($zip->set_number('9191321')->is_valid_number, '福井県三方上中郡若狭町上野');
ok($zip->set_number('9191322')->is_valid_number, '福井県三方上中郡若狭町成願寺');
ok($zip->set_number('9191323')->is_valid_number, '福井県三方上中郡若狭町倉見');
ok($zip->set_number('9191324')->is_valid_number, '福井県三方上中郡若狭町白屋');
ok($zip->set_number('9191325')->is_valid_number, '福井県三方上中郡若狭町岩屋');
ok($zip->set_number('9191326')->is_valid_number, '福井県三方上中郡若狭町田上');
ok($zip->set_number('9191327')->is_valid_number, '福井県三方上中郡若狭町東黒田');
ok($zip->set_number('9191328')->is_valid_number, '福井県三方上中郡若狭町三十三団地');
ok($zip->set_number('9191331')->is_valid_number, '福井県三方上中郡若狭町鳥浜');
ok($zip->set_number('9191332')->is_valid_number, '福井県三方上中郡若狭町館川');
ok($zip->set_number('9191333')->is_valid_number, '福井県三方上中郡若狭町中央');
ok($zip->set_number('9191334')->is_valid_number, '福井県三方上中郡若狭町田名');
ok($zip->set_number('9191335')->is_valid_number, '福井県三方上中郡若狭町佐古');
ok($zip->set_number('9191336')->is_valid_number, '福井県三方上中郡若狭町向笠');
ok($zip->set_number('9191451')->is_valid_number, '福井県三方上中郡若狭町常神');
ok($zip->set_number('9191452')->is_valid_number, '福井県三方上中郡若狭町神子');
ok($zip->set_number('9191453')->is_valid_number, '福井県三方上中郡若狭町小川');
ok($zip->set_number('9191454')->is_valid_number, '福井県三方上中郡若狭町遊子');
ok($zip->set_number('9191455')->is_valid_number, '福井県三方上中郡若狭町塩坂越');
ok($zip->set_number('9191461')->is_valid_number, '福井県三方上中郡若狭町海山');
ok($zip->set_number('9191462')->is_valid_number, '福井県三方上中郡若狭町島の内');
ok($zip->set_number('9191462')->is_valid_number, '福井県三方上中郡若狭町田井');
ok($zip->set_number('9191463')->is_valid_number, '福井県三方上中郡若狭町成出');
ok($zip->set_number('9191464')->is_valid_number, '福井県三方上中郡若狭町世久見');
ok($zip->set_number('9191501')->is_valid_number, '福井県三方上中郡若狭町海士坂');
ok($zip->set_number('9191502')->is_valid_number, '福井県三方上中郡若狭町麻生野');
ok($zip->set_number('9191503')->is_valid_number, '福井県三方上中郡若狭町上黒田');
ok($zip->set_number('9191504')->is_valid_number, '福井県三方上中郡若狭町大鳥羽');
ok($zip->set_number('9191505')->is_valid_number, '福井県三方上中郡若狭町長江');
ok($zip->set_number('9191506')->is_valid_number, '福井県三方上中郡若狭町持田');
ok($zip->set_number('9191507')->is_valid_number, '福井県三方上中郡若狭町有田');
ok($zip->set_number('9191511')->is_valid_number, '福井県三方上中郡若狭町三生野');
ok($zip->set_number('9191512')->is_valid_number, '福井県三方上中郡若狭町無悪');
ok($zip->set_number('9191513')->is_valid_number, '福井県三方上中郡若狭町三田');
ok($zip->set_number('9191514')->is_valid_number, '福井県三方上中郡若狭町小原');
ok($zip->set_number('9191515')->is_valid_number, '福井県三方上中郡若狭町南');
ok($zip->set_number('9191516')->is_valid_number, '福井県三方上中郡若狭町山内');
ok($zip->set_number('9191521')->is_valid_number, '福井県三方上中郡若狭町下タ中');
ok($zip->set_number('9191522')->is_valid_number, '福井県三方上中郡若狭町末野');
ok($zip->set_number('9191523')->is_valid_number, '福井県三方上中郡若狭町安賀里');
ok($zip->set_number('9191524')->is_valid_number, '福井県三方上中郡若狭町脇袋');
ok($zip->set_number('9191525')->is_valid_number, '福井県三方上中郡若狭町瓜生');
ok($zip->set_number('9191526')->is_valid_number, '福井県三方上中郡若狭町関');
ok($zip->set_number('9191527')->is_valid_number, '福井県三方上中郡若狭町上吉田');
ok($zip->set_number('9191528')->is_valid_number, '福井県三方上中郡若狭町下吉田');
ok($zip->set_number('9191531')->is_valid_number, '福井県三方上中郡若狭町新道');
ok($zip->set_number('9191532')->is_valid_number, '福井県三方上中郡若狭町熊川');
ok($zip->set_number('9191533')->is_valid_number, '福井県三方上中郡若狭町河内');
ok($zip->set_number('9191534')->is_valid_number, '福井県三方上中郡若狭町仮屋');
ok($zip->set_number('9191535')->is_valid_number, '福井県三方上中郡若狭町若王子');
ok($zip->set_number('9191536')->is_valid_number, '福井県三方上中郡若狭町三宅');
ok($zip->set_number('9191541')->is_valid_number, '福井県三方上中郡若狭町市場');
ok($zip->set_number('9191542')->is_valid_number, '福井県三方上中郡若狭町井ノ口');
ok($zip->set_number('9191543')->is_valid_number, '福井県三方上中郡若狭町天徳寺');
ok($zip->set_number('9191544')->is_valid_number, '福井県三方上中郡若狭町神谷');
ok($zip->set_number('9191545')->is_valid_number, '福井県三方上中郡若狭町日笠');
ok($zip->set_number('9191551')->is_valid_number, '福井県三方上中郡若狭町杉山');
ok($zip->set_number('9191552')->is_valid_number, '福井県三方上中郡若狭町若狭テクノバレー');
ok($zip->set_number('9191553')->is_valid_number, '福井県三方上中郡若狭町堤');
ok($zip->set_number('9191554')->is_valid_number, '福井県三方上中郡若狭町兼田');
ok($zip->set_number('9191555')->is_valid_number, '福井県三方上中郡若狭町武生');
ok($zip->set_number('9191556')->is_valid_number, '福井県三方上中郡若狭町玉置');
ok($zip->set_number('9191557')->is_valid_number, '福井県三方上中郡若狭町上野木');
ok($zip->set_number('9191558')->is_valid_number, '福井県三方上中郡若狭町中野木');
ok($zip->set_number('9191559')->is_valid_number, '福井県三方上中郡若狭町下野木');
ok($zip->set_number('9192100')->is_valid_number, '福井県大飯郡おおい町以下に掲載がない場合');
ok($zip->set_number('9192101')->is_valid_number, '福井県大飯郡おおい町大島');
ok($zip->set_number('9192102')->is_valid_number, '福井県大飯郡おおい町長井');
ok($zip->set_number('9192103')->is_valid_number, '福井県大飯郡おおい町尾内');
ok($zip->set_number('9192104')->is_valid_number, '福井県大飯郡おおい町成和');
ok($zip->set_number('9192105')->is_valid_number, '福井県大飯郡おおい町小堀');
ok($zip->set_number('9192106')->is_valid_number, '福井県大飯郡おおい町犬見');
ok($zip->set_number('9192107')->is_valid_number, '福井県大飯郡おおい町成海');
ok($zip->set_number('9192111')->is_valid_number, '福井県大飯郡おおい町本郷');
ok($zip->set_number('9192112')->is_valid_number, '福井県大飯郡おおい町山田');
ok($zip->set_number('9192113')->is_valid_number, '福井県大飯郡おおい町芝崎');
ok($zip->set_number('9192114')->is_valid_number, '福井県大飯郡おおい町野尻');
ok($zip->set_number('9192115')->is_valid_number, '福井県大飯郡おおい町父子');
ok($zip->set_number('9192116')->is_valid_number, '福井県大飯郡おおい町岡田');
ok($zip->set_number('9192121')->is_valid_number, '福井県大飯郡おおい町万願寺');
ok($zip->set_number('9192122')->is_valid_number, '福井県大飯郡おおい町神崎');
ok($zip->set_number('9192123')->is_valid_number, '福井県大飯郡おおい町鹿野');
ok($zip->set_number('9192124')->is_valid_number, '福井県大飯郡おおい町小車田');
ok($zip->set_number('9192125')->is_valid_number, '福井県大飯郡おおい町石山');
ok($zip->set_number('9192126')->is_valid_number, '福井県大飯郡おおい町佐畑');
ok($zip->set_number('9192127')->is_valid_number, '福井県大飯郡おおい町笹谷');
ok($zip->set_number('9192128')->is_valid_number, '福井県大飯郡おおい町岡安');
ok($zip->set_number('9192129')->is_valid_number, '福井県大飯郡おおい町広岡');
ok($zip->set_number('9192131')->is_valid_number, '福井県大飯郡おおい町福谷');
ok($zip->set_number('9192132')->is_valid_number, '福井県大飯郡おおい町安川');
ok($zip->set_number('9192133')->is_valid_number, '福井県大飯郡おおい町久保');
ok($zip->set_number('9192134')->is_valid_number, '福井県大飯郡おおい町川上');
ok($zip->set_number('9192135')->is_valid_number, '福井県大飯郡おおい町三森');
ok($zip->set_number('9192200')->is_valid_number, '福井県大飯郡高浜町以下に掲載がない場合');
ok($zip->set_number('9192201')->is_valid_number, '福井県大飯郡高浜町和田');
ok($zip->set_number('9192202')->is_valid_number, '福井県大飯郡高浜町安土');
ok($zip->set_number('9192203')->is_valid_number, '福井県大飯郡高浜町水明');
ok($zip->set_number('9192204')->is_valid_number, '福井県大飯郡高浜町青戸');
ok($zip->set_number('9192205')->is_valid_number, '福井県大飯郡高浜町下車持');
ok($zip->set_number('9192206')->is_valid_number, '福井県大飯郡高浜町上車持');
ok($zip->set_number('9192207')->is_valid_number, '福井県大飯郡高浜町馬居寺');
ok($zip->set_number('9192211')->is_valid_number, '福井県大飯郡高浜町中津海');
ok($zip->set_number('9192212')->is_valid_number, '福井県大飯郡高浜町鐘寄');
ok($zip->set_number('9192213')->is_valid_number, '福井県大飯郡高浜町畑');
ok($zip->set_number('9192214')->is_valid_number, '福井県大飯郡高浜町湯谷');
ok($zip->set_number('9192215')->is_valid_number, '福井県大飯郡高浜町南団地');
ok($zip->set_number('9192216')->is_valid_number, '福井県大飯郡高浜町笠原');
ok($zip->set_number('9192216')->is_valid_number, '福井県大飯郡高浜町子生');
ok($zip->set_number('9192216')->is_valid_number, '福井県大飯郡高浜町坂田');
ok($zip->set_number('9192221')->is_valid_number, '福井県大飯郡高浜町事代');
ok($zip->set_number('9192222')->is_valid_number, '福井県大飯郡高浜町岩神');
ok($zip->set_number('9192223')->is_valid_number, '福井県大飯郡高浜町紫水ケ丘');
ok($zip->set_number('9192224')->is_valid_number, '福井県大飯郡高浜町薗部');
ok($zip->set_number('9192225')->is_valid_number, '福井県大飯郡高浜町宮崎');
ok($zip->set_number('9192226')->is_valid_number, '福井県大飯郡高浜町立石');
ok($zip->set_number('9192227')->is_valid_number, '福井県大飯郡高浜町若宮');
ok($zip->set_number('9192228')->is_valid_number, '福井県大飯郡高浜町塩土');
ok($zip->set_number('9192229')->is_valid_number, '福井県大飯郡高浜町三明');
ok($zip->set_number('9192351')->is_valid_number, '福井県大飯郡高浜町山中');
ok($zip->set_number('9192352')->is_valid_number, '福井県大飯郡高浜町鎌倉');
ok($zip->set_number('9192353')->is_valid_number, '福井県大飯郡高浜町下');
ok($zip->set_number('9192354')->is_valid_number, '福井県大飯郡高浜町宮尾');
ok($zip->set_number('9192355')->is_valid_number, '福井県大飯郡高浜町日引');
ok($zip->set_number('9192356')->is_valid_number, '福井県大飯郡高浜町上瀬');
ok($zip->set_number('9192361')->is_valid_number, '福井県大飯郡高浜町音海');
ok($zip->set_number('9192362')->is_valid_number, '福井県大飯郡高浜町田ノ浦');
ok($zip->set_number('9192363')->is_valid_number, '福井県大飯郡高浜町小黒飯');
ok($zip->set_number('9192364')->is_valid_number, '福井県大飯郡高浜町難波江');
ok($zip->set_number('9192365')->is_valid_number, '福井県大飯郡高浜町神野');
ok($zip->set_number('9192366')->is_valid_number, '福井県大飯郡高浜町神野浦');
ok($zip->set_number('9192371')->is_valid_number, '福井県大飯郡高浜町中山');
ok($zip->set_number('9192372')->is_valid_number, '福井県大飯郡高浜町高屋');
ok($zip->set_number('9192372')->is_valid_number, '福井県大飯郡高浜町緑ケ丘');
ok($zip->set_number('9192373')->is_valid_number, '福井県大飯郡高浜町小和田');
ok($zip->set_number('9192374')->is_valid_number, '福井県大飯郡高浜町高野');
ok($zip->set_number('9192375')->is_valid_number, '福井県大飯郡高浜町旭ケ丘');
ok($zip->set_number('9192375')->is_valid_number, '福井県大飯郡高浜町蒜畠');
ok($zip->set_number('9192376')->is_valid_number, '福井県大飯郡高浜町今寺');
ok($zip->set_number('9192381')->is_valid_number, '福井県大飯郡高浜町西三松');
ok($zip->set_number('9192382')->is_valid_number, '福井県大飯郡高浜町東三松');
ok($zip->set_number('9192383')->is_valid_number, '福井県大飯郡高浜町日置');
ok($zip->set_number('9192384')->is_valid_number, '福井県大飯郡高浜町青');
ok($zip->set_number('9192385')->is_valid_number, '福井県大飯郡高浜町横津海');
ok($zip->set_number('9192386')->is_valid_number, '福井県大飯郡高浜町関屋');
ok($zip->set_number('9192387')->is_valid_number, '福井県大飯郡高浜町六路谷');
ok($zip->set_number('9200000')->is_valid_number, '石川県金沢市以下に掲載がない場合');
ok($zip->set_number('9200001')->is_valid_number, '石川県金沢市千木町');
ok($zip->set_number('9200002')->is_valid_number, '石川県金沢市千木');
ok($zip->set_number('9200003')->is_valid_number, '石川県金沢市疋田');
ok($zip->set_number('9200004')->is_valid_number, '石川県金沢市疋田町');
ok($zip->set_number('9200005')->is_valid_number, '石川県金沢市高柳町');
ok($zip->set_number('9200006')->is_valid_number, '石川県金沢市宮保町');
ok($zip->set_number('9200007')->is_valid_number, '石川県金沢市田中町');
ok($zip->set_number('9200008')->is_valid_number, '石川県金沢市今昭町');
ok($zip->set_number('9200011')->is_valid_number, '石川県金沢市松寺町');
ok($zip->set_number('9200012')->is_valid_number, '石川県金沢市磯部町');
ok($zip->set_number('9200013')->is_valid_number, '石川県金沢市沖町');
ok($zip->set_number('9200014')->is_valid_number, '石川県金沢市諸江町');
ok($zip->set_number('9200015')->is_valid_number, '石川県金沢市諸江町(上丁)');
ok($zip->set_number('9200016')->is_valid_number, '石川県金沢市諸江町(中丁)');
ok($zip->set_number('9200017')->is_valid_number, '石川県金沢市諸江町(下丁)');
ok($zip->set_number('9200018')->is_valid_number, '石川県金沢市三口町');
ok($zip->set_number('9200021')->is_valid_number, '石川県金沢市七ツ屋町');
ok($zip->set_number('9200022')->is_valid_number, '石川県金沢市北安江');
ok($zip->set_number('9200023')->is_valid_number, '石川県金沢市北安江町');
ok($zip->set_number('9200024')->is_valid_number, '石川県金沢市西念');
ok($zip->set_number('9200025')->is_valid_number, '石川県金沢市駅西本町');
ok($zip->set_number('9200026')->is_valid_number, '石川県金沢市西念町');
ok($zip->set_number('9200027')->is_valid_number, '石川県金沢市駅西新町');
ok($zip->set_number('9200031')->is_valid_number, '石川県金沢市広岡');
ok($zip->set_number('9200032')->is_valid_number, '石川県金沢市広岡町');
ok($zip->set_number('9200033')->is_valid_number, '石川県金沢市日吉町');
ok($zip->set_number('9200034')->is_valid_number, '石川県金沢市醒ケ井町');
ok($zip->set_number('9200035')->is_valid_number, '石川県金沢市中橋町');
ok($zip->set_number('9200036')->is_valid_number, '石川県金沢市元菊町');
ok($zip->set_number('9200041')->is_valid_number, '石川県金沢市長田本町');
ok($zip->set_number('9200042')->is_valid_number, '石川県金沢市長田町');
ok($zip->set_number('9200043')->is_valid_number, '石川県金沢市長田');
ok($zip->set_number('9200044')->is_valid_number, '石川県金沢市南広岡町');
ok($zip->set_number('9200045')->is_valid_number, '石川県金沢市向中町');
ok($zip->set_number('9200046')->is_valid_number, '石川県金沢市大和町');
ok($zip->set_number('9200047')->is_valid_number, '石川県金沢市大豆田本町(その他)');
ok($zip->set_number('9200051')->is_valid_number, '石川県金沢市二口町');
ok($zip->set_number('9200052')->is_valid_number, '石川県金沢市薬師堂町');
ok($zip->set_number('9200053')->is_valid_number, '石川県金沢市若宮町');
ok($zip->set_number('9200054')->is_valid_number, '石川県金沢市若宮');
ok($zip->set_number('9200055')->is_valid_number, '石川県金沢市北町');
ok($zip->set_number('9200056')->is_valid_number, '石川県金沢市出雲町');
ok($zip->set_number('9200057')->is_valid_number, '石川県金沢市桜田町');
ok($zip->set_number('9200058')->is_valid_number, '石川県金沢市示野中町');
ok($zip->set_number('9200059')->is_valid_number, '石川県金沢市示野町');
ok($zip->set_number('9200061')->is_valid_number, '石川県金沢市問屋町');
ok($zip->set_number('9200062')->is_valid_number, '石川県金沢市割出町');
ok($zip->set_number('9200063')->is_valid_number, '石川県金沢市三浦町');
ok($zip->set_number('9200064')->is_valid_number, '石川県金沢市南新保町');
ok($zip->set_number('9200065')->is_valid_number, '石川県金沢市二ツ屋町');
ok($zip->set_number('9200067')->is_valid_number, '石川県金沢市二宮町');
ok($zip->set_number('9200068')->is_valid_number, '石川県金沢市戸板');
ok($zip->set_number('9200069')->is_valid_number, '石川県金沢市戸板西');
ok($zip->set_number('9200101')->is_valid_number, '石川県金沢市利屋町');
ok($zip->set_number('9200102')->is_valid_number, '石川県金沢市岸川町');
ok($zip->set_number('9200103')->is_valid_number, '石川県金沢市花園八幡町');
ok($zip->set_number('9200104')->is_valid_number, '石川県金沢市四坊高坂町');
ok($zip->set_number('9200104')->is_valid_number, '石川県金沢市四坊町');
ok($zip->set_number('9200105')->is_valid_number, '石川県金沢市月影町');
ok($zip->set_number('9200106')->is_valid_number, '石川県金沢市今町');
ok($zip->set_number('9200107')->is_valid_number, '石川県金沢市二日市町');
ok($zip->set_number('9200111')->is_valid_number, '石川県金沢市浅丘町');
ok($zip->set_number('9200112')->is_valid_number, '石川県金沢市榎尾町');
ok($zip->set_number('9200113')->is_valid_number, '石川県金沢市俵原町');
ok($zip->set_number('9200114')->is_valid_number, '石川県金沢市加賀朝日町');
ok($zip->set_number('9200115')->is_valid_number, '石川県金沢市千杉町');
ok($zip->set_number('9200116')->is_valid_number, '石川県金沢市地代町');
ok($zip->set_number('9200121')->is_valid_number, '石川県金沢市琴町');
ok($zip->set_number('9200122')->is_valid_number, '石川県金沢市上平町');
ok($zip->set_number('9200123')->is_valid_number, '石川県金沢市滝下町');
ok($zip->set_number('9200124')->is_valid_number, '石川県金沢市中尾町');
ok($zip->set_number('9200125')->is_valid_number, '石川県金沢市今泉町');
ok($zip->set_number('9200126')->is_valid_number, '石川県金沢市朝日牧町');
ok($zip->set_number('9200127')->is_valid_number, '石川県金沢市南千谷町');
ok($zip->set_number('9200128')->is_valid_number, '石川県金沢市北千石町');
ok($zip->set_number('9200129')->is_valid_number, '石川県金沢市琴坂町');
ok($zip->set_number('9200131')->is_valid_number, '石川県金沢市東原町');
ok($zip->set_number('9200132')->is_valid_number, '石川県金沢市清水谷町');
ok($zip->set_number('9200133')->is_valid_number, '石川県金沢市堀切町');
ok($zip->set_number('9200134')->is_valid_number, '石川県金沢市曲子原町');
ok($zip->set_number('9200135')->is_valid_number, '石川県金沢市土子原町');
ok($zip->set_number('9200136')->is_valid_number, '石川県金沢市松根町');
ok($zip->set_number('9200137')->is_valid_number, '石川県金沢市竹又町');
ok($zip->set_number('9200141')->is_valid_number, '石川県金沢市直江野町');
ok($zip->set_number('9200142')->is_valid_number, '石川県金沢市納年町');
ok($zip->set_number('9200143')->is_valid_number, '石川県金沢市北方町');
ok($zip->set_number('9200144')->is_valid_number, '石川県金沢市小嶺町');
ok($zip->set_number('9200145')->is_valid_number, '石川県金沢市市瀬町');
ok($zip->set_number('9200146')->is_valid_number, '石川県金沢市柚木町');
ok($zip->set_number('9200147')->is_valid_number, '石川県金沢市不室町');
ok($zip->set_number('9200148')->is_valid_number, '石川県金沢市牧山町');
ok($zip->set_number('9200151')->is_valid_number, '石川県金沢市梨木町');
ok($zip->set_number('9200152')->is_valid_number, '石川県金沢市鳴瀬元町');
ok($zip->set_number('9200153')->is_valid_number, '石川県金沢市宮野町');
ok($zip->set_number('9200154')->is_valid_number, '石川県金沢市正部町');
ok($zip->set_number('9200155')->is_valid_number, '石川県金沢市高坂町');
ok($zip->set_number('9200156')->is_valid_number, '石川県金沢市古屋谷町');
ok($zip->set_number('9200157')->is_valid_number, '石川県金沢市車町');
ok($zip->set_number('9200161')->is_valid_number, '石川県金沢市鞁筒町');
ok($zip->set_number('9200162')->is_valid_number, '石川県金沢市小池町');
ok($zip->set_number('9200163')->is_valid_number, '石川県金沢市桐山町');
ok($zip->set_number('9200164')->is_valid_number, '石川県金沢市堅田町');
ok($zip->set_number('9200165')->is_valid_number, '石川県金沢市深谷町');
ok($zip->set_number('9200166')->is_valid_number, '石川県金沢市四王寺町');
ok($zip->set_number('9200167')->is_valid_number, '石川県金沢市福畠町');
ok($zip->set_number('9200168')->is_valid_number, '石川県金沢市小野町');
ok($zip->set_number('9200171')->is_valid_number, '石川県金沢市岩出町');
ok($zip->set_number('9200172')->is_valid_number, '石川県金沢市河原市町');
ok($zip->set_number('9200173')->is_valid_number, '石川県金沢市不動寺町');
ok($zip->set_number('9200174')->is_valid_number, '石川県金沢市薬師町');
ok($zip->set_number('9200175')->is_valid_number, '石川県金沢市上涌波町');
ok($zip->set_number('9200176')->is_valid_number, '石川県金沢市下涌波町');
ok($zip->set_number('9200177')->is_valid_number, '石川県金沢市北陽台');
ok($zip->set_number('9200178')->is_valid_number, '石川県金沢市月浦町');
ok($zip->set_number('9200200')->is_valid_number, '石川県河北郡内灘町以下に掲載がない場合');
ok($zip->set_number('9200201')->is_valid_number, '石川県金沢市木越町(瑞樹団地)');
ok($zip->set_number('9200201')->is_valid_number, '石川県金沢市みずき');
ok($zip->set_number('9200202')->is_valid_number, '石川県金沢市木越');
ok($zip->set_number('9200203')->is_valid_number, '石川県金沢市木越町(その他)');
ok($zip->set_number('9200204')->is_valid_number, '石川県金沢市千田町');
ok($zip->set_number('9200205')->is_valid_number, '石川県金沢市大浦町');
ok($zip->set_number('9200206')->is_valid_number, '石川県金沢市北寺町');
ok($zip->set_number('9200207')->is_valid_number, '石川県金沢市須崎町');
ok($zip->set_number('9200208')->is_valid_number, '石川県金沢市蚊爪町');
ok($zip->set_number('9200209')->is_valid_number, '石川県金沢市東蚊爪町');
ok($zip->set_number('9200210')->is_valid_number, '石川県金沢市大河端西');
ok($zip->set_number('9200211')->is_valid_number, '石川県金沢市湊');
ok($zip->set_number('9200212')->is_valid_number, '石川県金沢市北間町');
ok($zip->set_number('9200213')->is_valid_number, '石川県金沢市大河端町');
ok($zip->set_number('9200214')->is_valid_number, '石川県金沢市三ツ屋町');
ok($zip->set_number('9200215')->is_valid_number, '石川県金沢市弓取町');
ok($zip->set_number('9200219')->is_valid_number, '石川県金沢市かたつ');
ok($zip->set_number('9200223')->is_valid_number, '石川県金沢市戸水町');
ok($zip->set_number('9200224')->is_valid_number, '石川県金沢市五郎島町');
ok($zip->set_number('9200225')->is_valid_number, '石川県金沢市大野町新町');
ok($zip->set_number('9200226')->is_valid_number, '石川県金沢市粟崎町');
ok($zip->set_number('9200227')->is_valid_number, '石川県金沢市粟崎浜町');
ok($zip->set_number('9200231')->is_valid_number, '石川県金沢市大野町(ソ、タ、ヌ、ヨ、レ)');
ok($zip->set_number('9200261')->is_valid_number, '石川県河北郡内灘町室');
ok($zip->set_number('9200262')->is_valid_number, '石川県河北郡内灘町西荒屋');
ok($zip->set_number('9200263')->is_valid_number, '石川県河北郡内灘町湖西');
ok($zip->set_number('9200264')->is_valid_number, '石川県河北郡内灘町宮坂');
ok($zip->set_number('9200265')->is_valid_number, '石川県河北郡内灘町大学');
ok($zip->set_number('9200266')->is_valid_number, '石川県河北郡内灘町大根布');
ok($zip->set_number('9200267')->is_valid_number, '石川県河北郡内灘町大清台');
ok($zip->set_number('9200268')->is_valid_number, '石川県河北郡内灘町ハマナス');
ok($zip->set_number('9200269')->is_valid_number, '石川県河北郡内灘町白帆台');
ok($zip->set_number('9200271')->is_valid_number, '石川県河北郡内灘町鶴ケ丘');
ok($zip->set_number('9200272')->is_valid_number, '石川県河北郡内灘町向陽台');
ok($zip->set_number('9200273')->is_valid_number, '石川県河北郡内灘町アカシア');
ok($zip->set_number('9200274')->is_valid_number, '石川県河北郡内灘町向粟崎');
ok($zip->set_number('9200275')->is_valid_number, '石川県河北郡内灘町旭ケ丘');
ok($zip->set_number('9200276')->is_valid_number, '石川県河北郡内灘町緑台');
ok($zip->set_number('9200277')->is_valid_number, '石川県河北郡内灘町千鳥台');
ok($zip->set_number('9200310')->is_valid_number, '石川県金沢市金石相生町');
ok($zip->set_number('9200311')->is_valid_number, '石川県金沢市金石上浜町');
ok($zip->set_number('9200312')->is_valid_number, '石川県金沢市金石松前町');
ok($zip->set_number('9200313')->is_valid_number, '石川県金沢市金石浜町');
ok($zip->set_number('9200314')->is_valid_number, '石川県金沢市金石御船町');
ok($zip->set_number('9200315')->is_valid_number, '石川県金沢市金石下寺町');
ok($zip->set_number('9200316')->is_valid_number, '石川県金沢市金石通町');
ok($zip->set_number('9200317')->is_valid_number, '石川県金沢市金石下本町');
ok($zip->set_number('9200318')->is_valid_number, '石川県金沢市金石味噌屋町');
ok($zip->set_number('9200319')->is_valid_number, '石川県金沢市金石上越前町');
ok($zip->set_number('9200321')->is_valid_number, '石川県金沢市金石海禅寺町');
ok($zip->set_number('9200322')->is_valid_number, '石川県金沢市金石今町');
ok($zip->set_number('9200330')->is_valid_number, '石川県金沢市金石新町');
ok($zip->set_number('9200331')->is_valid_number, '石川県金沢市大野町(その他)');
ok($zip->set_number('9200332')->is_valid_number, '石川県金沢市無量寺町');
ok($zip->set_number('9200333')->is_valid_number, '石川県金沢市無量寺');
ok($zip->set_number('9200334')->is_valid_number, '石川県金沢市桂町');
ok($zip->set_number('9200335')->is_valid_number, '石川県金沢市金石東');
ok($zip->set_number('9200336')->is_valid_number, '石川県金沢市金石本町');
ok($zip->set_number('9200337')->is_valid_number, '石川県金沢市金石西');
ok($zip->set_number('9200338')->is_valid_number, '石川県金沢市金石北');
ok($zip->set_number('9200339')->is_valid_number, '石川県金沢市木曳野');
ok($zip->set_number('9200341')->is_valid_number, '石川県金沢市寺中町');
ok($zip->set_number('9200342')->is_valid_number, '石川県金沢市畝田町');
ok($zip->set_number('9200342')->is_valid_number, '石川県金沢市畝田西');
ok($zip->set_number('9200343')->is_valid_number, '石川県金沢市畝田中');
ok($zip->set_number('9200344')->is_valid_number, '石川県金沢市畝田東');
ok($zip->set_number('9200345')->is_valid_number, '石川県金沢市藤江北');
ok($zip->set_number('9200346')->is_valid_number, '石川県金沢市藤江南');
ok($zip->set_number('9200347')->is_valid_number, '石川県金沢市松村町');
ok($zip->set_number('9200348')->is_valid_number, '石川県金沢市松村');
ok($zip->set_number('9200351')->is_valid_number, '石川県金沢市普正寺町');
ok($zip->set_number('9200352')->is_valid_number, '石川県金沢市観音堂町');
ok($zip->set_number('9200353')->is_valid_number, '石川県金沢市赤土町');
ok($zip->set_number('9200354')->is_valid_number, '石川県金沢市二ツ寺町');
ok($zip->set_number('9200355')->is_valid_number, '石川県金沢市稚日野町');
ok($zip->set_number('9200356')->is_valid_number, '石川県金沢市専光寺町');
ok($zip->set_number('9200357')->is_valid_number, '石川県金沢市佐奇森町');
ok($zip->set_number('9200361')->is_valid_number, '石川県金沢市袋畠町');
ok($zip->set_number('9200362')->is_valid_number, '石川県金沢市古府');
ok($zip->set_number('9200362')->is_valid_number, '石川県金沢市古府町');
ok($zip->set_number('9200362')->is_valid_number, '石川県金沢市古府町(西)');
ok($zip->set_number('9200363')->is_valid_number, '石川県金沢市古府町(南)');
ok($zip->set_number('9200364')->is_valid_number, '石川県金沢市松島');
ok($zip->set_number('9200364')->is_valid_number, '石川県金沢市松島町');
ok($zip->set_number('9200365')->is_valid_number, '石川県金沢市神野町');
ok($zip->set_number('9200366')->is_valid_number, '石川県金沢市南塚町');
ok($zip->set_number('9200367')->is_valid_number, '石川県金沢市北塚町');
ok($zip->set_number('9200368')->is_valid_number, '石川県金沢市神野');
ok($zip->set_number('9200370')->is_valid_number, '石川県金沢市上安原');
ok($zip->set_number('9200371')->is_valid_number, '石川県金沢市下安原町');
ok($zip->set_number('9200372')->is_valid_number, '石川県金沢市豊穂町');
ok($zip->set_number('9200373')->is_valid_number, '石川県金沢市みどり');
ok($zip->set_number('9200374')->is_valid_number, '石川県金沢市上安原町');
ok($zip->set_number('9200374')->is_valid_number, '石川県金沢市上安原南');
ok($zip->set_number('9200375')->is_valid_number, '石川県金沢市中屋町');
ok($zip->set_number('9200376')->is_valid_number, '石川県金沢市福増町');
ok($zip->set_number('9200377')->is_valid_number, '石川県金沢市打木町');
ok($zip->set_number('9200378')->is_valid_number, '石川県金沢市いなほ');
ok($zip->set_number('9200379')->is_valid_number, '石川県金沢市中屋南');
ok($zip->set_number('9200381')->is_valid_number, '石川県金沢市中屋');
ok($zip->set_number('9200801')->is_valid_number, '石川県金沢市神谷内町');
ok($zip->set_number('9200802')->is_valid_number, '石川県金沢市三池町');
ok($zip->set_number('9200803')->is_valid_number, '石川県金沢市神宮寺町');
ok($zip->set_number('9200804')->is_valid_number, '石川県金沢市鳴和');
ok($zip->set_number('9200805')->is_valid_number, '石川県金沢市小金町');
ok($zip->set_number('9200806')->is_valid_number, '石川県金沢市神宮寺');
ok($zip->set_number('9200807')->is_valid_number, '石川県金沢市乙丸町');
ok($zip->set_number('9200808')->is_valid_number, '石川県金沢市三池新町');
ok($zip->set_number('9200809')->is_valid_number, '石川県金沢市三池栄町');
ok($zip->set_number('9200811')->is_valid_number, '石川県金沢市小坂町');
ok($zip->set_number('9200812')->is_valid_number, '石川県金沢市南御所町');
ok($zip->set_number('9200813')->is_valid_number, '石川県金沢市御所町');
ok($zip->set_number('9200814')->is_valid_number, '石川県金沢市鳴和町');
ok($zip->set_number('9200815')->is_valid_number, '石川県金沢市鳴和台');
ok($zip->set_number('9200816')->is_valid_number, '石川県金沢市山の上町');
ok($zip->set_number('9200817')->is_valid_number, '石川県金沢市春日町');
ok($zip->set_number('9200818')->is_valid_number, '石川県金沢市大樋町');
ok($zip->set_number('9200821')->is_valid_number, '石川県金沢市山王町');
ok($zip->set_number('9200822')->is_valid_number, '石川県金沢市東長江町');
ok($zip->set_number('9200823')->is_valid_number, '石川県金沢市夕日寺町');
ok($zip->set_number('9200824')->is_valid_number, '石川県金沢市伝燈寺町');
ok($zip->set_number('9200825')->is_valid_number, '石川県金沢市釣部町');
ok($zip->set_number('9200826')->is_valid_number, '石川県金沢市小二又町');
ok($zip->set_number('9200827')->is_valid_number, '石川県金沢市牧町');
ok($zip->set_number('9200831')->is_valid_number, '石川県金沢市東山');
ok($zip->set_number('9200832')->is_valid_number, '石川県金沢市卯辰町');
ok($zip->set_number('9200833')->is_valid_number, '石川県金沢市末広町');
ok($zip->set_number('9200834')->is_valid_number, '石川県金沢市常盤町');
ok($zip->set_number('9200835')->is_valid_number, '石川県金沢市東御影町');
ok($zip->set_number('9200836')->is_valid_number, '石川県金沢市子来町');
ok($zip->set_number('9200837')->is_valid_number, '石川県金沢市鶯町');
ok($zip->set_number('9200838')->is_valid_number, '石川県金沢市観音町');
ok($zip->set_number('9200841')->is_valid_number, '石川県金沢市浅野本町');
ok($zip->set_number('9200842')->is_valid_number, '石川県金沢市元町');
ok($zip->set_number('9200843')->is_valid_number, '石川県金沢市森山');
ok($zip->set_number('9200844')->is_valid_number, '石川県金沢市小橋町');
ok($zip->set_number('9200845')->is_valid_number, '石川県金沢市瓢箪町');
ok($zip->set_number('9200846')->is_valid_number, '石川県金沢市昌永町');
ok($zip->set_number('9200847')->is_valid_number, '石川県金沢市堀川町');
ok($zip->set_number('9200848')->is_valid_number, '石川県金沢市京町');
ok($zip->set_number('9200849')->is_valid_number, '石川県金沢市堀川新町');
ok($zip->set_number('9200851')->is_valid_number, '石川県金沢市笠市町');
ok($zip->set_number('9200852')->is_valid_number, '石川県金沢市此花町');
ok($zip->set_number('9200853')->is_valid_number, '石川県金沢市本町');
ok($zip->set_number('9200854')->is_valid_number, '石川県金沢市安江町');
ok($zip->set_number('9200855')->is_valid_number, '石川県金沢市武蔵町');
ok($zip->set_number('9200856')->is_valid_number, '石川県金沢市昭和町');
ok($zip->set_number('9200857')->is_valid_number, '石川県金沢市折違町');
ok($zip->set_number('9200858')->is_valid_number, '石川県金沢市木ノ新保町');
ok($zip->set_number('9200861')->is_valid_number, '石川県金沢市三社町');
ok($zip->set_number('9200862')->is_valid_number, '石川県金沢市芳斉');
ok($zip->set_number('9200863')->is_valid_number, '石川県金沢市玉川町');
ok($zip->set_number('9200864')->is_valid_number, '石川県金沢市高岡町');
ok($zip->set_number('9200865')->is_valid_number, '石川県金沢市長町');
ok($zip->set_number('9200866')->is_valid_number, '石川県金沢市中央通町');
ok($zip->set_number('9200867')->is_valid_number, '石川県金沢市長土塀');
ok($zip->set_number('9200868')->is_valid_number, '石川県金沢市六枚町');
ok($zip->set_number('9200869')->is_valid_number, '石川県金沢市上堤町');
ok($zip->set_number('9200901')->is_valid_number, '石川県金沢市彦三町');
ok($zip->set_number('9200902')->is_valid_number, '石川県金沢市尾張町');
ok($zip->set_number('9200903')->is_valid_number, '石川県金沢市博労町');
ok($zip->set_number('9200904')->is_valid_number, '石川県金沢市下近江町');
ok($zip->set_number('9200905')->is_valid_number, '石川県金沢市上近江町');
ok($zip->set_number('9200906')->is_valid_number, '石川県金沢市十間町');
ok($zip->set_number('9200907')->is_valid_number, '石川県金沢市青草町');
ok($zip->set_number('9200908')->is_valid_number, '石川県金沢市主計町');
ok($zip->set_number('9200909')->is_valid_number, '石川県金沢市袋町');
ok($zip->set_number('9200910')->is_valid_number, '石川県金沢市下新町');
ok($zip->set_number('9200911')->is_valid_number, '石川県金沢市橋場町');
ok($zip->set_number('9200912')->is_valid_number, '石川県金沢市大手町');
ok($zip->set_number('9200913')->is_valid_number, '石川県金沢市西町三番丁');
ok($zip->set_number('9200914')->is_valid_number, '石川県金沢市西町四番丁');
ok($zip->set_number('9200915')->is_valid_number, '石川県金沢市西町藪ノ内通');
ok($zip->set_number('9200916')->is_valid_number, '石川県金沢市下松原町');
ok($zip->set_number('9200917')->is_valid_number, '石川県金沢市下堤町');
ok($zip->set_number('9200918')->is_valid_number, '石川県金沢市尾山町');
ok($zip->set_number('9200919')->is_valid_number, '石川県金沢市南町');
ok($zip->set_number('9200921')->is_valid_number, '石川県金沢市材木町');
ok($zip->set_number('9200922')->is_valid_number, '石川県金沢市横山町');
ok($zip->set_number('9200923')->is_valid_number, '石川県金沢市桜町');
ok($zip->set_number('9200924')->is_valid_number, '石川県金沢市田井町');
ok($zip->set_number('9200925')->is_valid_number, '石川県金沢市天神町');
ok($zip->set_number('9200926')->is_valid_number, '石川県金沢市暁町');
ok($zip->set_number('9200927')->is_valid_number, '石川県金沢市扇町');
ok($zip->set_number('9200928')->is_valid_number, '石川県金沢市並木町');
ok($zip->set_number('9200931')->is_valid_number, '石川県金沢市兼六元町');
ok($zip->set_number('9200932')->is_valid_number, '石川県金沢市小将町');
ok($zip->set_number('9200933')->is_valid_number, '石川県金沢市東兼六町');
ok($zip->set_number('9200934')->is_valid_number, '石川県金沢市宝町');
ok($zip->set_number('9200935')->is_valid_number, '石川県金沢市石引');
ok($zip->set_number('9200936')->is_valid_number, '石川県金沢市兼六町');
ok($zip->set_number('9200937')->is_valid_number, '石川県金沢市丸の内');
ok($zip->set_number('9200938')->is_valid_number, '石川県金沢市飛梅町');
ok($zip->set_number('9200939')->is_valid_number, '石川県金沢市下石引町');
ok($zip->set_number('9200941')->is_valid_number, '石川県金沢市旭町');
ok($zip->set_number('9200942')->is_valid_number, '石川県金沢市小立野');
ok($zip->set_number('9200943')->is_valid_number, '石川県金沢市上野本町');
ok($zip->set_number('9200944')->is_valid_number, '石川県金沢市三口新町');
ok($zip->set_number('9200945')->is_valid_number, '石川県金沢市大桑新町');
ok($zip->set_number('9200946')->is_valid_number, '石川県金沢市大桑町(カ、コ、サ乙、サ甲、ソ、タ、ツ甲、ナ、メ、ユ、ヨ、');
ok($zip->set_number('9200946')->is_valid_number, '石川県金沢市ラ、ワ、穴欠、穴淵欠、子、庚、葭島、下葭島欠)');
ok($zip->set_number('9200947')->is_valid_number, '石川県金沢市笠舞本町');
ok($zip->set_number('9200951')->is_valid_number, '石川県金沢市花里町');
ok($zip->set_number('9200952')->is_valid_number, '石川県金沢市錦町');
ok($zip->set_number('9200953')->is_valid_number, '石川県金沢市涌波');
ok($zip->set_number('9200954')->is_valid_number, '石川県金沢市涌波町');
ok($zip->set_number('9200955')->is_valid_number, '石川県金沢市土清水');
ok($zip->set_number('9200956')->is_valid_number, '石川県金沢市舘山町');
ok($zip->set_number('9200957')->is_valid_number, '石川県金沢市舘町');
ok($zip->set_number('9200961')->is_valid_number, '石川県金沢市香林坊');
ok($zip->set_number('9200962')->is_valid_number, '石川県金沢市広坂');
ok($zip->set_number('9200963')->is_valid_number, '石川県金沢市出羽町');
ok($zip->set_number('9200964')->is_valid_number, '石川県金沢市本多町');
ok($zip->set_number('9200965')->is_valid_number, '石川県金沢市笠舞');
ok($zip->set_number('9200966')->is_valid_number, '石川県金沢市城南');
ok($zip->set_number('9200967')->is_valid_number, '石川県金沢市菊川');
ok($zip->set_number('9200968')->is_valid_number, '石川県金沢市幸町');
ok($zip->set_number('9200971')->is_valid_number, '石川県金沢市鱗町');
ok($zip->set_number('9200972')->is_valid_number, '石川県金沢市杉浦町');
ok($zip->set_number('9200973')->is_valid_number, '石川県金沢市枝町');
ok($zip->set_number('9200974')->is_valid_number, '石川県金沢市川岸町');
ok($zip->set_number('9200975')->is_valid_number, '石川県金沢市中川除町');
ok($zip->set_number('9200976')->is_valid_number, '石川県金沢市十三間町');
ok($zip->set_number('9200977')->is_valid_number, '石川県金沢市十三間町中丁');
ok($zip->set_number('9200978')->is_valid_number, '石川県金沢市水溜町');
ok($zip->set_number('9200981')->is_valid_number, '石川県金沢市片町');
ok($zip->set_number('9200982')->is_valid_number, '石川県金沢市大工町');
ok($zip->set_number('9200983')->is_valid_number, '石川県金沢市池田町一番丁');
ok($zip->set_number('9200984')->is_valid_number, '石川県金沢市池田町二番丁');
ok($zip->set_number('9200985')->is_valid_number, '石川県金沢市池田町三番丁');
ok($zip->set_number('9200986')->is_valid_number, '石川県金沢市池田町四番丁');
ok($zip->set_number('9200987')->is_valid_number, '石川県金沢市池田町立丁');
ok($zip->set_number('9200988')->is_valid_number, '石川県金沢市木倉町');
ok($zip->set_number('9200991')->is_valid_number, '石川県金沢市下柿木畠');
ok($zip->set_number('9200992')->is_valid_number, '石川県金沢市上柿木畠');
ok($zip->set_number('9200993')->is_valid_number, '石川県金沢市下本多町');
ok($zip->set_number('9200994')->is_valid_number, '石川県金沢市茨木町');
ok($zip->set_number('9200995')->is_valid_number, '石川県金沢市新竪町');
ok($zip->set_number('9200996')->is_valid_number, '石川県金沢市油車');
ok($zip->set_number('9200997')->is_valid_number, '石川県金沢市竪町');
ok($zip->set_number('9200998')->is_valid_number, '石川県金沢市里見町');
ok($zip->set_number('9200999')->is_valid_number, '石川県金沢市柿木畠');
ok($zip->set_number('9201101')->is_valid_number, '石川県金沢市荒山町');
ok($zip->set_number('9201101')->is_valid_number, '石川県金沢市奥新保町');
ok($zip->set_number('9201101')->is_valid_number, '石川県金沢市砂子坂町');
ok($zip->set_number('9201102')->is_valid_number, '石川県金沢市二俣町');
ok($zip->set_number('9201103')->is_valid_number, '石川県金沢市田島町');
ok($zip->set_number('9201104')->is_valid_number, '石川県金沢市清水町');
ok($zip->set_number('9201105')->is_valid_number, '石川県金沢市戸室新保');
ok($zip->set_number('9201106')->is_valid_number, '石川県金沢市戸室別所');
ok($zip->set_number('9201106')->is_valid_number, '石川県金沢市湯谷原町');
ok($zip->set_number('9201107')->is_valid_number, '石川県金沢市小豆沢町');
ok($zip->set_number('9201108')->is_valid_number, '石川県金沢市俵町');
ok($zip->set_number('9201109')->is_valid_number, '石川県金沢市中山町');
ok($zip->set_number('9201111')->is_valid_number, '石川県金沢市魚帰町');
ok($zip->set_number('9201111')->is_valid_number, '石川県金沢市大菱池町');
ok($zip->set_number('9201111')->is_valid_number, '石川県金沢市小菱池町');
ok($zip->set_number('9201111')->is_valid_number, '石川県金沢市菱池小原町');
ok($zip->set_number('9201112')->is_valid_number, '石川県金沢市折谷町');
ok($zip->set_number('9201113')->is_valid_number, '石川県金沢市上山町');
ok($zip->set_number('9201114')->is_valid_number, '石川県金沢市古郷町');
ok($zip->set_number('9201115')->is_valid_number, '石川県金沢市石黒町');
ok($zip->set_number('9201116')->is_valid_number, '石川県金沢市板ケ谷町');
ok($zip->set_number('9201117')->is_valid_number, '石川県金沢市横谷町');
ok($zip->set_number('9201118')->is_valid_number, '石川県金沢市湯涌河内町');
ok($zip->set_number('9201119')->is_valid_number, '石川県金沢市湯涌曲町');
ok($zip->set_number('9201121')->is_valid_number, '石川県金沢市東町');
ok($zip->set_number('9201122')->is_valid_number, '石川県金沢市湯涌荒屋町');
ok($zip->set_number('9201123')->is_valid_number, '石川県金沢市湯涌町');
ok($zip->set_number('9201124')->is_valid_number, '石川県金沢市湯涌田子島町');
ok($zip->set_number('9201125')->is_valid_number, '石川県金沢市上原町');
ok($zip->set_number('9201126')->is_valid_number, '石川県金沢市白見町');
ok($zip->set_number('9201127')->is_valid_number, '石川県金沢市下谷町');
ok($zip->set_number('9201128')->is_valid_number, '石川県金沢市羽場町');
ok($zip->set_number('9201129')->is_valid_number, '石川県金沢市芝原町');
ok($zip->set_number('9201131')->is_valid_number, '石川県金沢市東荒屋町');
ok($zip->set_number('9201132')->is_valid_number, '石川県金沢市朝加屋町');
ok($zip->set_number('9201133')->is_valid_number, '石川県金沢市藤六町');
ok($zip->set_number('9201134')->is_valid_number, '石川県金沢市東市瀬町');
ok($zip->set_number('9201135')->is_valid_number, '石川県金沢市北袋町');
ok($zip->set_number('9201136')->is_valid_number, '石川県金沢市西市瀬町');
ok($zip->set_number('9201137')->is_valid_number, '石川県金沢市七曲町');
ok($zip->set_number('9201138')->is_valid_number, '石川県金沢市茅原町');
ok($zip->set_number('9201141')->is_valid_number, '石川県金沢市平等本町');
ok($zip->set_number('9201142')->is_valid_number, '石川県金沢市蓮如町');
ok($zip->set_number('9201143')->is_valid_number, '石川県金沢市高池町');
ok($zip->set_number('9201144')->is_valid_number, '石川県金沢市袋板屋町');
ok($zip->set_number('9201145')->is_valid_number, '石川県金沢市浅川町');
ok($zip->set_number('9201146')->is_valid_number, '石川県金沢市上中町');
ok($zip->set_number('9201147')->is_valid_number, '石川県金沢市銚子町');
ok($zip->set_number('9201148')->is_valid_number, '石川県金沢市金川町');
ok($zip->set_number('9201149')->is_valid_number, '石川県金沢市打尾町');
ok($zip->set_number('9201151')->is_valid_number, '石川県金沢市田上町');
ok($zip->set_number('9201152')->is_valid_number, '石川県金沢市田上');
ok($zip->set_number('9201153')->is_valid_number, '石川県金沢市田上新町');
ok($zip->set_number('9201154')->is_valid_number, '石川県金沢市太陽が丘');
ok($zip->set_number('9201155')->is_valid_number, '石川県金沢市田上本町');
ok($zip->set_number('9201156')->is_valid_number, '石川県金沢市田上の里');
ok($zip->set_number('9201157')->is_valid_number, '石川県金沢市田上さくら');
ok($zip->set_number('9201158')->is_valid_number, '石川県金沢市朝霧台');
ok($zip->set_number('9201161')->is_valid_number, '石川県金沢市鈴見台');
ok($zip->set_number('9201162')->is_valid_number, '石川県金沢市鈴見町');
ok($zip->set_number('9201163')->is_valid_number, '石川県金沢市角間新町');
ok($zip->set_number('9201164')->is_valid_number, '石川県金沢市角間町');
ok($zip->set_number('9201165')->is_valid_number, '石川県金沢市若松町');
ok($zip->set_number('9201166')->is_valid_number, '石川県金沢市上若松町');
ok($zip->set_number('9201167')->is_valid_number, '石川県金沢市もりの里');
ok($zip->set_number('9201301')->is_valid_number, '石川県金沢市永安町');
ok($zip->set_number('9201302')->is_valid_number, '石川県金沢市末町');
ok($zip->set_number('9201303')->is_valid_number, '石川県金沢市辰巳町');
ok($zip->set_number('9201304')->is_valid_number, '石川県金沢市上辰巳町');
ok($zip->set_number('9201311')->is_valid_number, '石川県金沢市菅池町');
ok($zip->set_number('9201312')->is_valid_number, '石川県金沢市瀬領町');
ok($zip->set_number('9201313')->is_valid_number, '石川県金沢市駒帰町');
ok($zip->set_number('9201314')->is_valid_number, '石川県金沢市娚杉町');
ok($zip->set_number('9201315')->is_valid_number, '石川県金沢市寺津町');
ok($zip->set_number('9201316')->is_valid_number, '石川県金沢市二又新町');
ok($zip->set_number('9201321')->is_valid_number, '石川県金沢市水淵町');
ok($zip->set_number('9201322')->is_valid_number, '石川県金沢市相合谷町');
ok($zip->set_number('9201323')->is_valid_number, '石川県金沢市下鴛原町');
ok($zip->set_number('9201324')->is_valid_number, '石川県金沢市鴛原町');
ok($zip->set_number('9201325')->is_valid_number, '石川県金沢市城力町');
ok($zip->set_number('9201326')->is_valid_number, '石川県金沢市熊走町');
ok($zip->set_number('9201331')->is_valid_number, '石川県金沢市天池町');
ok($zip->set_number('9201332')->is_valid_number, '石川県金沢市樫見町');
ok($zip->set_number('9201333')->is_valid_number, '石川県金沢市国見町');
ok($zip->set_number('9201334')->is_valid_number, '石川県金沢市平町');
ok($zip->set_number('9201335')->is_valid_number, '石川県金沢市大平沢町');
ok($zip->set_number('9201336')->is_valid_number, '石川県金沢市中戸町');
ok($zip->set_number('9201337')->is_valid_number, '石川県金沢市山川町');
ok($zip->set_number('9201341')->is_valid_number, '石川県金沢市別所町');
ok($zip->set_number('9201342')->is_valid_number, '石川県金沢市蓮花町');
ok($zip->set_number('9201343')->is_valid_number, '石川県金沢市小原町');
ok($zip->set_number('9201344')->is_valid_number, '石川県金沢市住吉町');
ok($zip->set_number('9201345')->is_valid_number, '石川県金沢市新保町');
ok($zip->set_number('9201346')->is_valid_number, '石川県金沢市三小牛町');
ok($zip->set_number('9202101')->is_valid_number, '石川県白山市曽谷町');
ok($zip->set_number('9202102')->is_valid_number, '石川県白山市坂尻町');
ok($zip->set_number('9202103')->is_valid_number, '石川県白山市小柳町');
ok($zip->set_number('9202104')->is_valid_number, '石川県白山市月橋町');
ok($zip->set_number('9202111')->is_valid_number, '石川県白山市鶴来朝日町');
ok($zip->set_number('9202112')->is_valid_number, '石川県白山市鶴来日吉町');
ok($zip->set_number('9202113')->is_valid_number, '石川県白山市八幡町');
ok($zip->set_number('9202114')->is_valid_number, '石川県白山市三宮町');
ok($zip->set_number('9202115')->is_valid_number, '石川県白山市白山町');
ok($zip->set_number('9202116')->is_valid_number, '石川県白山市中島町');
ok($zip->set_number('9202121')->is_valid_number, '石川県白山市鶴来本町(1~4丁目)');
ok($zip->set_number('9202122')->is_valid_number, '石川県白山市鶴来知守町');
ok($zip->set_number('9202123')->is_valid_number, '石川県白山市鶴来日詰町');
ok($zip->set_number('9202124')->is_valid_number, '石川県白山市鶴来清沢町');
ok($zip->set_number('9202125')->is_valid_number, '石川県白山市鶴来今町');
ok($zip->set_number('9202126')->is_valid_number, '石川県白山市鶴来新町');
ok($zip->set_number('9202127')->is_valid_number, '石川県白山市鶴来上東町');
ok($zip->set_number('9202128')->is_valid_number, '石川県白山市鶴来下東町');
ok($zip->set_number('9202129')->is_valid_number, '石川県白山市鶴来古町');
ok($zip->set_number('9202131')->is_valid_number, '石川県白山市森島町');
ok($zip->set_number('9202132')->is_valid_number, '石川県白山市明島町');
ok($zip->set_number('9202133')->is_valid_number, '石川県白山市鶴来大国町');
ok($zip->set_number('9202134')->is_valid_number, '石川県白山市鶴来水戸町(2~4丁目)');
ok($zip->set_number('9202141')->is_valid_number, '石川県白山市安養寺町');
ok($zip->set_number('9202142')->is_valid_number, '石川県白山市深瀬新町');
ok($zip->set_number('9202143')->is_valid_number, '石川県白山市七原町');
ok($zip->set_number('9202144')->is_valid_number, '石川県白山市大竹町');
ok($zip->set_number('9202145')->is_valid_number, '石川県白山市明法島町');
ok($zip->set_number('9202146')->is_valid_number, '石川県白山市日向町');
ok($zip->set_number('9202147')->is_valid_number, '石川県白山市中ノ郷町');
ok($zip->set_number('9202148')->is_valid_number, '石川県白山市行町');
ok($zip->set_number('9202151')->is_valid_number, '石川県白山市荒屋町');
ok($zip->set_number('9202152')->is_valid_number, '石川県白山市明光(1~4丁目)');
ok($zip->set_number('9202153')->is_valid_number, '石川県白山市日御子町');
ok($zip->set_number('9202154')->is_valid_number, '石川県白山市井口町');
ok($zip->set_number('9202155')->is_valid_number, '石川県白山市知気寺町');
ok($zip->set_number('9202161')->is_valid_number, '石川県白山市熱野町');
ok($zip->set_number('9202162')->is_valid_number, '石川県白山市道法寺町');
ok($zip->set_number('9202163')->is_valid_number, '石川県白山市柴木町');
ok($zip->set_number('9202164')->is_valid_number, '石川県白山市柴木(2丁目)');
ok($zip->set_number('9202165')->is_valid_number, '石川県白山市富光寺町');
ok($zip->set_number('9202166')->is_valid_number, '石川県白山市鶴来桑島町');
ok($zip->set_number('9202167')->is_valid_number, '石川県白山市部入道町');
ok($zip->set_number('9202168')->is_valid_number, '石川県白山市陽羽里');
ok($zip->set_number('9202301')->is_valid_number, '石川県白山市河内町口直海');
ok($zip->set_number('9202302')->is_valid_number, '石川県白山市河内町ふじが丘');
ok($zip->set_number('9202303')->is_valid_number, '石川県白山市河内町福岡');
ok($zip->set_number('9202304')->is_valid_number, '石川県白山市河内町きりの里');
ok($zip->set_number('9202305')->is_valid_number, '石川県白山市河内町江津');
ok($zip->set_number('9202306')->is_valid_number, '石川県白山市河内町吉岡');
ok($zip->set_number('9202311')->is_valid_number, '石川県白山市河内町中直海');
ok($zip->set_number('9202312')->is_valid_number, '石川県白山市河内町奥池');
ok($zip->set_number('9202313')->is_valid_number, '石川県白山市河内町久保');
ok($zip->set_number('9202314')->is_valid_number, '石川県白山市河内町吹上');
ok($zip->set_number('9202315')->is_valid_number, '石川県白山市河内町板尾');
ok($zip->set_number('9202316')->is_valid_number, '石川県白山市河内町金間');
ok($zip->set_number('9202317')->is_valid_number, '石川県白山市河内町下折');
ok($zip->set_number('9202318')->is_valid_number, '石川県白山市河内町内尾');
ok($zip->set_number('9202321')->is_valid_number, '石川県白山市吉野');
ok($zip->set_number('9202322')->is_valid_number, '石川県白山市佐良');
ok($zip->set_number('9202323')->is_valid_number, '石川県白山市瀬波');
ok($zip->set_number('9202324')->is_valid_number, '石川県白山市中宮');
ok($zip->set_number('9202325')->is_valid_number, '石川県白山市木滑新');
ok($zip->set_number('9202326')->is_valid_number, '石川県白山市木滑');
ok($zip->set_number('9202327')->is_valid_number, '石川県白山市市原');
ok($zip->set_number('9202331')->is_valid_number, '石川県白山市瀬戸');
ok($zip->set_number('9202332')->is_valid_number, '石川県白山市荒谷');
ok($zip->set_number('9202333')->is_valid_number, '石川県白山市尾添');
ok($zip->set_number('9202334')->is_valid_number, '石川県白山市深瀬');
ok($zip->set_number('9202335')->is_valid_number, '石川県白山市女原');
ok($zip->set_number('9202336')->is_valid_number, '石川県白山市東二口');
ok($zip->set_number('9202337')->is_valid_number, '石川県白山市五味島');
ok($zip->set_number('9202338')->is_valid_number, '石川県白山市釜谷');
ok($zip->set_number('9202339')->is_valid_number, '石川県白山市鴇ケ谷');
ok($zip->set_number('9202341')->is_valid_number, '石川県白山市釜清水町');
ok($zip->set_number('9202342')->is_valid_number, '石川県白山市下吉谷町');
ok($zip->set_number('9202343')->is_valid_number, '石川県白山市西佐良町');
ok($zip->set_number('9202344')->is_valid_number, '石川県白山市上吉谷町');
ok($zip->set_number('9202345')->is_valid_number, '石川県白山市三ツ屋野町');
ok($zip->set_number('9202346')->is_valid_number, '石川県白山市河原山町');
ok($zip->set_number('9202347')->is_valid_number, '石川県白山市仏師ケ野町');
ok($zip->set_number('9202351')->is_valid_number, '石川県白山市柳原町');
ok($zip->set_number('9202352')->is_valid_number, '石川県白山市野地町');
ok($zip->set_number('9202353')->is_valid_number, '石川県白山市左礫町');
ok($zip->set_number('9202354')->is_valid_number, '石川県白山市三ツ瀬町');
ok($zip->set_number('9202355')->is_valid_number, '石川県白山市数瀬町');
ok($zip->set_number('9202356')->is_valid_number, '石川県白山市阿手町');
ok($zip->set_number('9202357')->is_valid_number, '石川県白山市五十谷町');
ok($zip->set_number('9202361')->is_valid_number, '石川県白山市三坂町');
ok($zip->set_number('9202362')->is_valid_number, '石川県白山市別宮町');
ok($zip->set_number('9202363')->is_valid_number, '石川県白山市別宮出町');
ok($zip->set_number('9202364')->is_valid_number, '石川県白山市杉森町');
ok($zip->set_number('9202365')->is_valid_number, '石川県白山市神子清水町');
ok($zip->set_number('9202366')->is_valid_number, '石川県白山市渡津町');
ok($zip->set_number('9202367')->is_valid_number, '石川県白山市相滝町');
ok($zip->set_number('9202368')->is_valid_number, '石川県白山市出合町');
ok($zip->set_number('9202371')->is_valid_number, '石川県白山市広瀬町');
ok($zip->set_number('9202372')->is_valid_number, '石川県白山市瀬木野町');
ok($zip->set_number('9202373')->is_valid_number, '石川県白山市河合町');
ok($zip->set_number('9202374')->is_valid_number, '石川県白山市下野町');
ok($zip->set_number('9202375')->is_valid_number, '石川県白山市上野町');
ok($zip->set_number('9202376')->is_valid_number, '石川県白山市若原町');
ok($zip->set_number('9202501')->is_valid_number, '石川県白山市白峰');
ok($zip->set_number('9202502')->is_valid_number, '石川県白山市桑島');
ok($zip->set_number('9202503')->is_valid_number, '石川県白山市下田原');
ok($zip->set_number('9203101')->is_valid_number, '石川県金沢市才田町');
ok($zip->set_number('9203102')->is_valid_number, '石川県金沢市忠縄町');
ok($zip->set_number('9203103')->is_valid_number, '石川県金沢市湖陽');
ok($zip->set_number('9203104')->is_valid_number, '石川県金沢市八田町東');
ok($zip->set_number('9203105')->is_valid_number, '石川県金沢市八田町西');
ok($zip->set_number('9203106')->is_valid_number, '石川県金沢市八田町');
ok($zip->set_number('9203107')->is_valid_number, '石川県金沢市湖南町');
ok($zip->set_number('9203111')->is_valid_number, '石川県金沢市梅田町');
ok($zip->set_number('9203112')->is_valid_number, '石川県金沢市観法寺町');
ok($zip->set_number('9203113')->is_valid_number, '石川県金沢市塚崎町');
ok($zip->set_number('9203114')->is_valid_number, '石川県金沢市吉原町');
ok($zip->set_number('9203115')->is_valid_number, '石川県金沢市弥勒町');
ok($zip->set_number('9203116')->is_valid_number, '石川県金沢市南森本町');
ok($zip->set_number('9203117')->is_valid_number, '石川県金沢市北森本町');
ok($zip->set_number('9203121')->is_valid_number, '石川県金沢市大場町');
ok($zip->set_number('9203122')->is_valid_number, '石川県金沢市福久町');
ok($zip->set_number('9203123')->is_valid_number, '石川県金沢市福久東');
ok($zip->set_number('9203124')->is_valid_number, '石川県金沢市荒屋');
ok($zip->set_number('9203125')->is_valid_number, '石川県金沢市荒屋町');
ok($zip->set_number('9203126')->is_valid_number, '石川県金沢市福久');
ok($zip->set_number('9203131')->is_valid_number, '石川県金沢市百坂町');
ok($zip->set_number('9203132')->is_valid_number, '石川県金沢市法光寺町');
ok($zip->set_number('9203133')->is_valid_number, '石川県金沢市柳橋町');
ok($zip->set_number('9203134')->is_valid_number, '石川県金沢市金市町');
ok($zip->set_number('9203135')->is_valid_number, '石川県金沢市横枕町');
ok($zip->set_number('9208201')->is_valid_number, '石川県金沢市鞍月東');
ok($zip->set_number('9208202')->is_valid_number, '石川県金沢市西都');
ok($zip->set_number('9208203')->is_valid_number, '石川県金沢市鞍月');
ok($zip->set_number('9208204')->is_valid_number, '石川県金沢市戸水');
ok($zip->set_number('9208205')->is_valid_number, '石川県金沢市大友');
ok($zip->set_number('9208213')->is_valid_number, '石川県金沢市直江東');
ok($zip->set_number('9208214')->is_valid_number, '石川県金沢市直江南');
ok($zip->set_number('9208215')->is_valid_number, '石川県金沢市直江西');
ok($zip->set_number('9208216')->is_valid_number, '石川県金沢市直江町');
ok($zip->set_number('9208217')->is_valid_number, '石川県金沢市近岡町');
ok($zip->set_number('9208218')->is_valid_number, '石川県金沢市直江北');
ok($zip->set_number('9208221')->is_valid_number, '石川県金沢市御供田町');
ok($zip->set_number('9208222')->is_valid_number, '石川県金沢市大友町');
ok($zip->set_number('9210000')->is_valid_number, '石川県野々市市以下に掲載がない場合');
ok($zip->set_number('9218001')->is_valid_number, '石川県金沢市高畠');
ok($zip->set_number('9218002')->is_valid_number, '石川県金沢市玉鉾');
ok($zip->set_number('9218003')->is_valid_number, '石川県金沢市玉鉾町');
ok($zip->set_number('9218004')->is_valid_number, '石川県金沢市米丸町');
ok($zip->set_number('9218005')->is_valid_number, '石川県金沢市間明町');
ok($zip->set_number('9218006')->is_valid_number, '石川県金沢市進和町');
ok($zip->set_number('9218011')->is_valid_number, '石川県金沢市入江');
ok($zip->set_number('9218012')->is_valid_number, '石川県金沢市本江町');
ok($zip->set_number('9218013')->is_valid_number, '石川県金沢市新神田');
ok($zip->set_number('9218014')->is_valid_number, '石川県金沢市糸田');
ok($zip->set_number('9218015')->is_valid_number, '石川県金沢市東力');
ok($zip->set_number('9218016')->is_valid_number, '石川県金沢市東力町');
ok($zip->set_number('9218021')->is_valid_number, '石川県金沢市御影町');
ok($zip->set_number('9218022')->is_valid_number, '石川県金沢市中村町');
ok($zip->set_number('9218023')->is_valid_number, '石川県金沢市千日町');
ok($zip->set_number('9218024')->is_valid_number, '石川県金沢市白菊町');
ok($zip->set_number('9218025')->is_valid_number, '石川県金沢市増泉');
ok($zip->set_number('9218026')->is_valid_number, '石川県金沢市糸田新町');
ok($zip->set_number('9218027')->is_valid_number, '石川県金沢市神田');
ok($zip->set_number('9218031')->is_valid_number, '石川県金沢市野町');
ok($zip->set_number('9218032')->is_valid_number, '石川県金沢市清川町');
ok($zip->set_number('9218033')->is_valid_number, '石川県金沢市寺町');
ok($zip->set_number('9218034')->is_valid_number, '石川県金沢市泉野町');
ok($zip->set_number('9218035')->is_valid_number, '石川県金沢市泉が丘');
ok($zip->set_number('9218036')->is_valid_number, '石川県金沢市弥生');
ok($zip->set_number('9218041')->is_valid_number, '石川県金沢市泉');
ok($zip->set_number('9218042')->is_valid_number, '石川県金沢市泉本町');
ok($zip->set_number('9218043')->is_valid_number, '石川県金沢市西泉');
ok($zip->set_number('9218044')->is_valid_number, '石川県金沢市米泉町');
ok($zip->set_number('9218045')->is_valid_number, '石川県金沢市大桑');
ok($zip->set_number('9218046')->is_valid_number, '石川県金沢市大桑町(ア、イ、ヰ、ウ、上野、ヲ、オ乙、鐘搗山、上川原、上猫下、');
ok($zip->set_number('9218046')->is_valid_number, '石川県金沢市ク、ケ、御所谷、小寺山、シ、下上野、下西欠、平、チ、ツ乙、ツ丙、テ、ト、');
ok($zip->set_number('9218046')->is_valid_number, '石川県金沢市中上野、中尾山、中平、中ノ大平、西ノ山、猫シタイ、ノ、ハ、開、');
ok($zip->set_number('9218046')->is_valid_number, '石川県金沢市法師山、坊山、マ、鱒川淵、ム、元末、元涌波庚、ヤ、リ、ル、レ乙、');
ok($zip->set_number('9218046')->is_valid_number, '石川県金沢市レ甲、ロ乙、ロ甲、和)');
ok($zip->set_number('9218046')->is_valid_number, '石川県金沢市三小牛町(ヘ)');
ok($zip->set_number('9218047')->is_valid_number, '石川県金沢市大豆田本町(ハ、ロ)');
ok($zip->set_number('9218051')->is_valid_number, '石川県金沢市黒田');
ok($zip->set_number('9218052')->is_valid_number, '石川県金沢市保古');
ok($zip->set_number('9218053')->is_valid_number, '石川県金沢市保古町');
ok($zip->set_number('9218054')->is_valid_number, '石川県金沢市西金沢');
ok($zip->set_number('9218055')->is_valid_number, '石川県金沢市西金沢新町');
ok($zip->set_number('9218056')->is_valid_number, '石川県金沢市押野');
ok($zip->set_number('9218061')->is_valid_number, '石川県金沢市森戸');
ok($zip->set_number('9218062')->is_valid_number, '石川県金沢市新保本');
ok($zip->set_number('9218063')->is_valid_number, '石川県金沢市八日市出町');
ok($zip->set_number('9218064')->is_valid_number, '石川県金沢市八日市');
ok($zip->set_number('9218065')->is_valid_number, '石川県金沢市上荒屋');
ok($zip->set_number('9218066')->is_valid_number, '石川県金沢市矢木');
ok($zip->set_number('9218101')->is_valid_number, '石川県金沢市法島町');
ok($zip->set_number('9218102')->is_valid_number, '石川県金沢市西大桑町');
ok($zip->set_number('9218103')->is_valid_number, '石川県金沢市つつじが丘');
ok($zip->set_number('9218104')->is_valid_number, '石川県金沢市野田町');
ok($zip->set_number('9218105')->is_valid_number, '石川県金沢市平和町');
ok($zip->set_number('9218106')->is_valid_number, '石川県金沢市十一屋町');
ok($zip->set_number('9218107')->is_valid_number, '石川県金沢市野田');
ok($zip->set_number('9218111')->is_valid_number, '石川県金沢市若草町');
ok($zip->set_number('9218112')->is_valid_number, '石川県金沢市長坂');
ok($zip->set_number('9218114')->is_valid_number, '石川県金沢市長坂町');
ok($zip->set_number('9218115')->is_valid_number, '石川県金沢市長坂台');
ok($zip->set_number('9218116')->is_valid_number, '石川県金沢市泉野出町');
ok($zip->set_number('9218117')->is_valid_number, '石川県金沢市緑が丘');
ok($zip->set_number('9218121')->is_valid_number, '石川県金沢市平栗');
ok($zip->set_number('9218122')->is_valid_number, '石川県金沢市清瀬町');
ok($zip->set_number('9218123')->is_valid_number, '石川県金沢市坪野町');
ok($zip->set_number('9218124')->is_valid_number, '石川県金沢市倉ケ嶽');
ok($zip->set_number('9218131')->is_valid_number, '石川県金沢市三十苅町');
ok($zip->set_number('9218132')->is_valid_number, '石川県金沢市しじま台');
ok($zip->set_number('9218133')->is_valid_number, '石川県金沢市四十万町');
ok($zip->set_number('9218134')->is_valid_number, '石川県金沢市南四十万');
ok($zip->set_number('9218135')->is_valid_number, '石川県金沢市四十万');
ok($zip->set_number('9218141')->is_valid_number, '石川県金沢市馬替');
ok($zip->set_number('9218142')->is_valid_number, '石川県金沢市光が丘');
ok($zip->set_number('9218143')->is_valid_number, '石川県金沢市大額町');
ok($zip->set_number('9218144')->is_valid_number, '石川県金沢市額谷町');
ok($zip->set_number('9218145')->is_valid_number, '石川県金沢市額谷');
ok($zip->set_number('9218146')->is_valid_number, '石川県金沢市額乙丸町');
ok($zip->set_number('9218147')->is_valid_number, '石川県金沢市大額');
ok($zip->set_number('9218148')->is_valid_number, '石川県金沢市額新保');
ok($zip->set_number('9218149')->is_valid_number, '石川県金沢市額新町');
ok($zip->set_number('9218151')->is_valid_number, '石川県金沢市窪');
ok($zip->set_number('9218152')->is_valid_number, '石川県金沢市高尾');
ok($zip->set_number('9218153')->is_valid_number, '石川県金沢市高尾町');
ok($zip->set_number('9218154')->is_valid_number, '石川県金沢市高尾南');
ok($zip->set_number('9218155')->is_valid_number, '石川県金沢市高尾台');
ok($zip->set_number('9218161')->is_valid_number, '石川県金沢市有松');
ok($zip->set_number('9218162')->is_valid_number, '石川県金沢市三馬');
ok($zip->set_number('9218163')->is_valid_number, '石川県金沢市横川');
ok($zip->set_number('9218164')->is_valid_number, '石川県金沢市久安');
ok($zip->set_number('9218171')->is_valid_number, '石川県金沢市富樫');
ok($zip->set_number('9218172')->is_valid_number, '石川県金沢市伏見新町');
ok($zip->set_number('9218173')->is_valid_number, '石川県金沢市円光寺');
ok($zip->set_number('9218174')->is_valid_number, '石川県金沢市山科町');
ok($zip->set_number('9218175')->is_valid_number, '石川県金沢市山科');
ok($zip->set_number('9218176')->is_valid_number, '石川県金沢市円光寺本町');
ok($zip->set_number('9218177')->is_valid_number, '石川県金沢市伏見台');
ok($zip->set_number('9218178')->is_valid_number, '石川県金沢市寺地');
ok($zip->set_number('9218801')->is_valid_number, '石川県野々市市御経塚');
ok($zip->set_number('9218802')->is_valid_number, '石川県野々市市押野');
ok($zip->set_number('9218803')->is_valid_number, '石川県野々市市押越');
ok($zip->set_number('9218804')->is_valid_number, '石川県野々市市野代');
ok($zip->set_number('9218805')->is_valid_number, '石川県野々市市稲荷');
ok($zip->set_number('9218806')->is_valid_number, '石川県野々市市三日市');
ok($zip->set_number('9218807')->is_valid_number, '石川県野々市市二日市町');
ok($zip->set_number('9218808')->is_valid_number, '石川県野々市市長池');
ok($zip->set_number('9218809')->is_valid_number, '石川県野々市市二日市');
ok($zip->set_number('9218811')->is_valid_number, '石川県野々市市高橋町');
ok($zip->set_number('9218812')->is_valid_number, '石川県野々市市扇が丘');
ok($zip->set_number('9218813')->is_valid_number, '石川県野々市市住吉町');
ok($zip->set_number('9218814')->is_valid_number, '石川県野々市市菅原町');
ok($zip->set_number('9218815')->is_valid_number, '石川県野々市市本町');
ok($zip->set_number('9218816')->is_valid_number, '石川県野々市市若松町');
ok($zip->set_number('9218817')->is_valid_number, '石川県野々市市横宮町');
ok($zip->set_number('9218821')->is_valid_number, '石川県野々市市白山町');
ok($zip->set_number('9218822')->is_valid_number, '石川県野々市市矢作');
ok($zip->set_number('9218823')->is_valid_number, '石川県野々市市粟田');
ok($zip->set_number('9218824')->is_valid_number, '石川県野々市市新庄');
ok($zip->set_number('9218825')->is_valid_number, '石川県野々市市三納');
ok($zip->set_number('9218831')->is_valid_number, '石川県野々市市下林');
ok($zip->set_number('9218832')->is_valid_number, '石川県野々市市藤平田');
ok($zip->set_number('9218833')->is_valid_number, '石川県野々市市藤平');
ok($zip->set_number('9218834')->is_valid_number, '石川県野々市市中林');
ok($zip->set_number('9218835')->is_valid_number, '石川県野々市市上林');
ok($zip->set_number('9218836')->is_valid_number, '石川県野々市市末松');
ok($zip->set_number('9218837')->is_valid_number, '石川県野々市市清金');
ok($zip->set_number('9218841')->is_valid_number, '石川県野々市市郷町');
ok($zip->set_number('9218842')->is_valid_number, '石川県野々市市徳用');
ok($zip->set_number('9218843')->is_valid_number, '石川県野々市市田尻町');
ok($zip->set_number('9218844')->is_valid_number, '石川県野々市市堀内');
ok($zip->set_number('9218845')->is_valid_number, '石川県野々市市太平寺');
ok($zip->set_number('9218846')->is_valid_number, '石川県野々市市位川');
ok($zip->set_number('9218847')->is_valid_number, '石川県野々市市蓮花寺町');
ok($zip->set_number('9218848')->is_valid_number, '石川県野々市市柳町');
ok($zip->set_number('9218849')->is_valid_number, '石川県野々市市郷');
ok($zip->set_number('9220000')->is_valid_number, '石川県加賀市以下に掲載がない場合');
ok($zip->set_number('9220001')->is_valid_number, '石川県加賀市大聖寺上木町');
ok($zip->set_number('9220002')->is_valid_number, '石川県加賀市大聖寺下福田町');
ok($zip->set_number('9220003')->is_valid_number, '石川県加賀市大聖寺荻生町');
ok($zip->set_number('9220004')->is_valid_number, '石川県加賀市大聖寺朝日町');
ok($zip->set_number('9220004')->is_valid_number, '石川県加賀市大聖寺上福田町');
ok($zip->set_number('9220004')->is_valid_number, '石川県加賀市大聖寺新川町');
ok($zip->set_number('9220004')->is_valid_number, '石川県加賀市大聖寺畑町');
ok($zip->set_number('9220004')->is_valid_number, '石川県加賀市大聖寺畑山町');
ok($zip->set_number('9220004')->is_valid_number, '石川県加賀市大聖寺松島町');
ok($zip->set_number('9220004')->is_valid_number, '石川県加賀市豊町(ハ)');
ok($zip->set_number('9220005')->is_valid_number, '石川県加賀市大聖寺岡町');
ok($zip->set_number('9220006')->is_valid_number, '石川県加賀市大聖寺藤ノ木町');
ok($zip->set_number('9220007')->is_valid_number, '石川県加賀市大聖寺天神下町');
ok($zip->set_number('9220011')->is_valid_number, '石川県加賀市大聖寺春日町');
ok($zip->set_number('9220011')->is_valid_number, '石川県加賀市大聖寺敷地');
ok($zip->set_number('9220011')->is_valid_number, '石川県加賀市大聖寺東敷地町');
ok($zip->set_number('9220011')->is_valid_number, '石川県加賀市大聖寺平床');
ok($zip->set_number('9220012')->is_valid_number, '石川県加賀市下河崎町');
ok($zip->set_number('9220013')->is_valid_number, '石川県加賀市上河崎町');
ok($zip->set_number('9220014')->is_valid_number, '石川県加賀市中代町');
ok($zip->set_number('9220015')->is_valid_number, '石川県加賀市保賀町');
ok($zip->set_number('9220021')->is_valid_number, '石川県加賀市大聖寺新栄町');
ok($zip->set_number('9220022')->is_valid_number, '石川県加賀市大聖寺曙町');
ok($zip->set_number('9220023')->is_valid_number, '石川県加賀市大聖寺大名竹町');
ok($zip->set_number('9220024')->is_valid_number, '石川県加賀市大聖寺永町');
ok($zip->set_number('9220025')->is_valid_number, '石川県加賀市大聖寺耳聞山仲町');
ok($zip->set_number('9220026')->is_valid_number, '石川県加賀市大聖寺亀町');
ok($zip->set_number('9220027')->is_valid_number, '石川県加賀市大聖寺耳聞山町');
ok($zip->set_number('9220028')->is_valid_number, '石川県加賀市大聖寺麻畠町');
ok($zip->set_number('9220031')->is_valid_number, '石川県加賀市大聖寺木呂場町');
ok($zip->set_number('9220032')->is_valid_number, '石川県加賀市大聖寺金子町');
ok($zip->set_number('9220033')->is_valid_number, '石川県加賀市大聖寺法華坊町');
ok($zip->set_number('9220034')->is_valid_number, '石川県加賀市大聖寺荒町');
ok($zip->set_number('9220035')->is_valid_number, '石川県加賀市大聖寺鉄砲町');
ok($zip->set_number('9220036')->is_valid_number, '石川県加賀市大聖寺一本橋町');
ok($zip->set_number('9220037')->is_valid_number, '石川県加賀市大聖寺鍛冶町');
ok($zip->set_number('9220038')->is_valid_number, '石川県加賀市大聖寺山田町');
ok($zip->set_number('9220041')->is_valid_number, '石川県加賀市大聖寺本町');
ok($zip->set_number('9220042')->is_valid_number, '石川県加賀市大聖寺魚町');
ok($zip->set_number('9220043')->is_valid_number, '石川県加賀市大聖寺五軒町');
ok($zip->set_number('9220044')->is_valid_number, '石川県加賀市大聖寺東横町');
ok($zip->set_number('9220045')->is_valid_number, '石川県加賀市大聖寺十一町');
ok($zip->set_number('9220046')->is_valid_number, '石川県加賀市大聖寺観音町');
ok($zip->set_number('9220047')->is_valid_number, '石川県加賀市大聖寺中町');
ok($zip->set_number('9220048')->is_valid_number, '石川県加賀市大聖寺馬場町');
ok($zip->set_number('9220051')->is_valid_number, '石川県加賀市大聖寺仲町');
ok($zip->set_number('9220052')->is_valid_number, '石川県加賀市大聖寺福田町');
ok($zip->set_number('9220053')->is_valid_number, '石川県加賀市大聖寺鷹匠町');
ok($zip->set_number('9220054')->is_valid_number, '石川県加賀市大聖寺寺町');
ok($zip->set_number('9220055')->is_valid_number, '石川県加賀市大聖寺京町');
ok($zip->set_number('9220056')->is_valid_number, '石川県加賀市大聖寺片原町');
ok($zip->set_number('9220057')->is_valid_number, '石川県加賀市大聖寺八間道');
ok($zip->set_number('9220061')->is_valid_number, '石川県加賀市大聖寺相生町');
ok($zip->set_number('9220062')->is_valid_number, '石川県加賀市大聖寺松ケ根町');
ok($zip->set_number('9220063')->is_valid_number, '石川県加賀市大聖寺新町');
ok($zip->set_number('9220064')->is_valid_number, '石川県加賀市大聖寺北片原町');
ok($zip->set_number('9220065')->is_valid_number, '石川県加賀市大聖寺新旗陽町');
ok($zip->set_number('9220066')->is_valid_number, '石川県加賀市大聖寺殿町');
ok($zip->set_number('9220067')->is_valid_number, '石川県加賀市大聖寺番場町');
ok($zip->set_number('9220068')->is_valid_number, '石川県加賀市大聖寺新組町');
ok($zip->set_number('9220101')->is_valid_number, '石川県加賀市山中温泉中田町');
ok($zip->set_number('9220101')->is_valid_number, '石川県加賀市山中温泉二天町');
ok($zip->set_number('9220102')->is_valid_number, '石川県加賀市山中温泉長谷田町(日の出団地)');
ok($zip->set_number('9220103')->is_valid_number, '石川県加賀市山中温泉長谷田町(その他)');
ok($zip->set_number('9220104')->is_valid_number, '石川県加賀市山中温泉旭町');
ok($zip->set_number('9220105')->is_valid_number, '石川県加賀市山中温泉泉町');
ok($zip->set_number('9220106')->is_valid_number, '石川県加賀市山中温泉上原町(その他)');
ok($zip->set_number('9220107')->is_valid_number, '石川県加賀市山中温泉上原町(漆器団地)');
ok($zip->set_number('9220108')->is_valid_number, '石川県加賀市山中温泉上原町(しらさぎ団地)');
ok($zip->set_number('9220109')->is_valid_number, '石川県加賀市山中温泉宮の杜');
ok($zip->set_number('9220111')->is_valid_number, '石川県加賀市山中温泉塚谷町');
ok($zip->set_number('9220112')->is_valid_number, '石川県加賀市山中温泉西桂木町');
ok($zip->set_number('9220113')->is_valid_number, '石川県加賀市山中温泉東桂木町');
ok($zip->set_number('9220114')->is_valid_number, '石川県加賀市山中温泉東町');
ok($zip->set_number('9220115')->is_valid_number, '石川県加賀市山中温泉本町');
ok($zip->set_number('9220116')->is_valid_number, '石川県加賀市山中温泉白山町');
ok($zip->set_number('9220117')->is_valid_number, '石川県加賀市山中温泉上野町(緑ケ丘)');
ok($zip->set_number('9220117')->is_valid_number, '石川県加賀市山中温泉上野町(その他)');
ok($zip->set_number('9220118')->is_valid_number, '石川県加賀市山中温泉加美谷台');
ok($zip->set_number('9220121')->is_valid_number, '石川県加賀市山中温泉富士見町');
ok($zip->set_number('9220122')->is_valid_number, '石川県加賀市山中温泉湯の本町');
ok($zip->set_number('9220123')->is_valid_number, '石川県加賀市山中温泉薬師町');
ok($zip->set_number('9220124')->is_valid_number, '石川県加賀市山中温泉湯の出町');
ok($zip->set_number('9220125')->is_valid_number, '石川県加賀市山中温泉栄町');
ok($zip->set_number('9220126')->is_valid_number, '石川県加賀市山中温泉河鹿町');
ok($zip->set_number('9220127')->is_valid_number, '石川県加賀市山中温泉下谷町');
ok($zip->set_number('9220128')->is_valid_number, '石川県加賀市山中温泉こおろぎ町');
ok($zip->set_number('9220129')->is_valid_number, '石川県加賀市山中温泉南町');
ok($zip->set_number('9220131')->is_valid_number, '石川県加賀市山中温泉四十九院町');
ok($zip->set_number('9220132')->is_valid_number, '石川県加賀市山中温泉中津原町');
ok($zip->set_number('9220133')->is_valid_number, '石川県加賀市山中温泉滝町');
ok($zip->set_number('9220134')->is_valid_number, '石川県加賀市山中温泉荒谷町');
ok($zip->set_number('9220134')->is_valid_number, '石川県加賀市山中温泉菅生谷町');
ok($zip->set_number('9220135')->is_valid_number, '石川県加賀市山中温泉今立町');
ok($zip->set_number('9220135')->is_valid_number, '石川県加賀市山中温泉大土町');
ok($zip->set_number('9220136')->is_valid_number, '石川県加賀市山中温泉枯淵町');
ok($zip->set_number('9220136')->is_valid_number, '石川県加賀市山中温泉九谷町');
ok($zip->set_number('9220136')->is_valid_number, '石川県加賀市山中温泉坂下町');
ok($zip->set_number('9220136')->is_valid_number, '石川県加賀市山中温泉杉水町');
ok($zip->set_number('9220136')->is_valid_number, '石川県加賀市山中温泉片谷町');
ok($zip->set_number('9220136')->is_valid_number, '石川県加賀市山中温泉真砂町');
ok($zip->set_number('9220137')->is_valid_number, '石川県加賀市山中温泉風谷町');
ok($zip->set_number('9220137')->is_valid_number, '石川県加賀市山中温泉我谷町');
ok($zip->set_number('9220138')->is_valid_number, '石川県加賀市山中温泉栢野町');
ok($zip->set_number('9220139')->is_valid_number, '石川県加賀市山中温泉菅谷町');
ok($zip->set_number('9220221')->is_valid_number, '石川県加賀市丸山町');
ok($zip->set_number('9220222')->is_valid_number, '石川県加賀市上野町(丸山)');
ok($zip->set_number('9220241')->is_valid_number, '石川県加賀市加茂町');
ok($zip->set_number('9220242')->is_valid_number, '石川県加賀市山代温泉');
ok($zip->set_number('9220243')->is_valid_number, '石川県加賀市山代温泉(北部)');
ok($zip->set_number('9220244')->is_valid_number, '石川県加賀市山代温泉(神明町)');
ok($zip->set_number('9220245')->is_valid_number, '石川県加賀市山代温泉(山背台)');
ok($zip->set_number('9220246')->is_valid_number, '石川県加賀市山代温泉(八幡)');
ok($zip->set_number('9220247')->is_valid_number, '石川県加賀市山代温泉(上宮)');
ok($zip->set_number('9220250')->is_valid_number, '石川県加賀市山代温泉桜町');
ok($zip->set_number('9220251')->is_valid_number, '石川県加賀市山代温泉(大和町)');
ok($zip->set_number('9220252')->is_valid_number, '石川県加賀市山代温泉(九谷町)');
ok($zip->set_number('9220253')->is_valid_number, '石川県加賀市山代温泉(東山町)');
ok($zip->set_number('9220254')->is_valid_number, '石川県加賀市山代温泉(温泉通り)');
ok($zip->set_number('9220255')->is_valid_number, '石川県加賀市山代温泉(幸町)');
ok($zip->set_number('9220256')->is_valid_number, '石川県加賀市山代温泉(万松園通)');
ok($zip->set_number('9220257')->is_valid_number, '石川県加賀市山代温泉(桔梗丘)');
ok($zip->set_number('9220258')->is_valid_number, '石川県加賀市山代温泉(南町)');
ok($zip->set_number('9220261')->is_valid_number, '石川県加賀市横北町');
ok($zip->set_number('9220262')->is_valid_number, '石川県加賀市柏野町');
ok($zip->set_number('9220263')->is_valid_number, '石川県加賀市塔尾町');
ok($zip->set_number('9220264')->is_valid_number, '石川県加賀市須谷町');
ok($zip->set_number('9220265')->is_valid_number, '石川県加賀市水田丸町');
ok($zip->set_number('9220266')->is_valid_number, '石川県加賀市小坂町');
ok($zip->set_number('9220267')->is_valid_number, '石川県加賀市二ツ屋町');
ok($zip->set_number('9220271')->is_valid_number, '石川県加賀市尾俣町');
ok($zip->set_number('9220273')->is_valid_number, '石川県加賀市桂谷町');
ok($zip->set_number('9220274')->is_valid_number, '石川県加賀市別所町');
ok($zip->set_number('9220275')->is_valid_number, '石川県加賀市別所町(富士見ケ丘)');
ok($zip->set_number('9220276')->is_valid_number, '石川県加賀市河南町(淀町)');
ok($zip->set_number('9220277')->is_valid_number, '石川県加賀市河南町');
ok($zip->set_number('9220278')->is_valid_number, '石川県加賀市荒木町');
ok($zip->set_number('9220301')->is_valid_number, '石川県加賀市高塚町');
ok($zip->set_number('9220302')->is_valid_number, '石川県加賀市打越町');
ok($zip->set_number('9220303')->is_valid_number, '石川県加賀市箱宮町');
ok($zip->set_number('9220304')->is_valid_number, '石川県加賀市分校町');
ok($zip->set_number('9220305')->is_valid_number, '石川県加賀市梶井町');
ok($zip->set_number('9220306')->is_valid_number, '石川県加賀市中島町');
ok($zip->set_number('9220307')->is_valid_number, '石川県加賀市干拓町');
ok($zip->set_number('9220311')->is_valid_number, '石川県加賀市栄谷町');
ok($zip->set_number('9220312')->is_valid_number, '石川県加賀市宇谷町');
ok($zip->set_number('9220313')->is_valid_number, '石川県加賀市勅使町');
ok($zip->set_number('9220314')->is_valid_number, '石川県加賀市河原町');
ok($zip->set_number('9220315')->is_valid_number, '石川県加賀市清水町');
ok($zip->set_number('9220316')->is_valid_number, '石川県加賀市松山町');
ok($zip->set_number('9220321')->is_valid_number, '石川県加賀市森町');
ok($zip->set_number('9220322')->is_valid_number, '石川県加賀市上野町(その他)');
ok($zip->set_number('9220323')->is_valid_number, '石川県加賀市若葉台');
ok($zip->set_number('9220324')->is_valid_number, '石川県加賀市七日市新町');
ok($zip->set_number('9220325')->is_valid_number, '石川県加賀市二子塚町');
ok($zip->set_number('9220326')->is_valid_number, '石川県加賀市桑原町');
ok($zip->set_number('9220331')->is_valid_number, '石川県加賀市動橋町');
ok($zip->set_number('9220332')->is_valid_number, '石川県加賀市庄町');
ok($zip->set_number('9220333')->is_valid_number, '石川県加賀市津波倉町');
ok($zip->set_number('9220334')->is_valid_number, '石川県加賀市西島町');
ok($zip->set_number('9220335')->is_valid_number, '石川県加賀市七日市町');
ok($zip->set_number('9220336')->is_valid_number, '石川県加賀市八日市町');
ok($zip->set_number('9220337')->is_valid_number, '石川県加賀市合河町');
ok($zip->set_number('9220401')->is_valid_number, '石川県加賀市新保町');
ok($zip->set_number('9220402')->is_valid_number, '石川県加賀市柴山町');
ok($zip->set_number('9220403')->is_valid_number, '石川県加賀市一白町');
ok($zip->set_number('9220404')->is_valid_number, '石川県加賀市源平町');
ok($zip->set_number('9220405')->is_valid_number, '石川県加賀市手塚町');
ok($zip->set_number('9220406')->is_valid_number, '石川県加賀市伊切町');
ok($zip->set_number('9220411')->is_valid_number, '石川県加賀市潮津町');
ok($zip->set_number('9220412')->is_valid_number, '石川県加賀市片山津温泉');
ok($zip->set_number('9220413')->is_valid_number, '石川県加賀市湖城町');
ok($zip->set_number('9220414')->is_valid_number, '石川県加賀市片山津町');
ok($zip->set_number('9220421')->is_valid_number, '石川県加賀市冨塚町');
ok($zip->set_number('9220422')->is_valid_number, '石川県加賀市弓波町');
ok($zip->set_number('9220423')->is_valid_number, '石川県加賀市作見町');
ok($zip->set_number('9220424')->is_valid_number, '石川県加賀市小菅波町');
ok($zip->set_number('9220425')->is_valid_number, '石川県加賀市大菅波町');
ok($zip->set_number('9220426')->is_valid_number, '石川県加賀市天日町');
ok($zip->set_number('9220427')->is_valid_number, '石川県加賀市ときわ台');
ok($zip->set_number('9220428')->is_valid_number, '石川県加賀市尾中町');
ok($zip->set_number('9220431')->is_valid_number, '石川県加賀市山田町');
ok($zip->set_number('9220432')->is_valid_number, '石川県加賀市東山田町');
ok($zip->set_number('9220433')->is_valid_number, '石川県加賀市西山田町');
ok($zip->set_number('9220434')->is_valid_number, '石川県加賀市北山田町');
ok($zip->set_number('9220435')->is_valid_number, '石川県加賀市希望が丘');
ok($zip->set_number('9220436')->is_valid_number, '石川県加賀市松が丘');
ok($zip->set_number('9220437')->is_valid_number, '石川県加賀市白山台');
ok($zip->set_number('9220441')->is_valid_number, '石川県加賀市篠原新町');
ok($zip->set_number('9220442')->is_valid_number, '石川県加賀市篠原町');
ok($zip->set_number('9220443')->is_valid_number, '石川県加賀市野田町');
ok($zip->set_number('9220444')->is_valid_number, '石川県加賀市宮地町');
ok($zip->set_number('9220445')->is_valid_number, '石川県加賀市小塩辻町');
ok($zip->set_number('9220446')->is_valid_number, '石川県加賀市塩浜町');
ok($zip->set_number('9220551')->is_valid_number, '石川県加賀市美岬町');
ok($zip->set_number('9220552')->is_valid_number, '石川県加賀市田尻町');
ok($zip->set_number('9220553')->is_valid_number, '石川県加賀市小塩町');
ok($zip->set_number('9220554')->is_valid_number, '石川県加賀市橋立町');
ok($zip->set_number('9220561')->is_valid_number, '石川県加賀市宮町');
ok($zip->set_number('9220562')->is_valid_number, '石川県加賀市高尾町');
ok($zip->set_number('9220563')->is_valid_number, '石川県加賀市豊町');
ok($zip->set_number('9220564')->is_valid_number, '石川県加賀市片野町');
ok($zip->set_number('9220565')->is_valid_number, '石川県加賀市黒崎町');
ok($zip->set_number('9220566')->is_valid_number, '石川県加賀市深田町');
ok($zip->set_number('9220671')->is_valid_number, '石川県加賀市大聖寺瀬越町');
ok($zip->set_number('9220672')->is_valid_number, '石川県加賀市吉崎町');
ok($zip->set_number('9220673')->is_valid_number, '石川県加賀市塩屋町');
ok($zip->set_number('9220679')->is_valid_number, '福井県あわら市吉崎');
ok($zip->set_number('9220801')->is_valid_number, '石川県加賀市大聖寺関町');
ok($zip->set_number('9220802')->is_valid_number, '石川県加賀市大聖寺越前町');
ok($zip->set_number('9220803')->is_valid_number, '石川県加賀市大聖寺越前三ツ屋町');
ok($zip->set_number('9220803')->is_valid_number, '石川県加賀市大聖寺三ツ屋町');
ok($zip->set_number('9220804')->is_valid_number, '石川県加賀市大聖寺中新道');
ok($zip->set_number('9220805')->is_valid_number, '石川県加賀市大聖寺新屋敷町');
ok($zip->set_number('9220806')->is_valid_number, '石川県加賀市大聖寺大新道');
ok($zip->set_number('9220807')->is_valid_number, '石川県加賀市大聖寺神明町');
ok($zip->set_number('9220811')->is_valid_number, '石川県加賀市大聖寺南町');
ok($zip->set_number('9220812')->is_valid_number, '石川県加賀市大聖寺田原町');
ok($zip->set_number('9220813')->is_valid_number, '石川県加賀市大聖寺弓町');
ok($zip->set_number('9220814')->is_valid_number, '石川県加賀市大聖寺菅生町');
ok($zip->set_number('9220815')->is_valid_number, '石川県加賀市大聖寺菅生');
ok($zip->set_number('9220816')->is_valid_number, '石川県加賀市大聖寺東町');
ok($zip->set_number('9220821')->is_valid_number, '石川県加賀市南郷町');
ok($zip->set_number('9220822')->is_valid_number, '石川県加賀市吸坂町');
ok($zip->set_number('9220823')->is_valid_number, '石川県加賀市黒瀬町');
ok($zip->set_number('9220824')->is_valid_number, '石川県加賀市日谷町');
ok($zip->set_number('9220825')->is_valid_number, '石川県加賀市直下町');
ok($zip->set_number('9220831')->is_valid_number, '石川県加賀市幸町');
ok($zip->set_number('9220832')->is_valid_number, '石川県加賀市百々町');
ok($zip->set_number('9220833')->is_valid_number, '石川県加賀市曾宇町');
ok($zip->set_number('9220834')->is_valid_number, '石川県加賀市美谷が丘');
ok($zip->set_number('9220835')->is_valid_number, '石川県加賀市細坪町');
ok($zip->set_number('9220836')->is_valid_number, '石川県加賀市白鳥町');
ok($zip->set_number('9220841')->is_valid_number, '石川県加賀市大聖寺下屋敷町');
ok($zip->set_number('9220842')->is_valid_number, '石川県加賀市熊坂町');
ok($zip->set_number('9220843')->is_valid_number, '石川県加賀市大同町');
ok($zip->set_number('9220844')->is_valid_number, '石川県加賀市白望台町');
ok($zip->set_number('9220851')->is_valid_number, '石川県加賀市大聖寺錦城ケ丘');
ok($zip->set_number('9220852')->is_valid_number, '石川県加賀市大聖寺緑ケ丘');
ok($zip->set_number('9220853')->is_valid_number, '石川県加賀市大聖寺三ツ町');
ok($zip->set_number('9220854')->is_valid_number, '石川県加賀市三木町');
ok($zip->set_number('9220855')->is_valid_number, '石川県加賀市橘町');
ok($zip->set_number('9220856')->is_valid_number, '石川県加賀市奥谷町');
ok($zip->set_number('9220857')->is_valid_number, '石川県加賀市永井町');
ok($zip->set_number('9220861')->is_valid_number, '石川県加賀市大聖寺地方町');
ok($zip->set_number('9220862')->is_valid_number, '石川県加賀市大聖寺錦町');
ok($zip->set_number('9220863')->is_valid_number, '石川県加賀市大聖寺今出町');
ok($zip->set_number('9220864')->is_valid_number, '石川県加賀市大聖寺西栄町');
ok($zip->set_number('9220865')->is_valid_number, '石川県加賀市大聖寺西町');
ok($zip->set_number('9230000')->is_valid_number, '石川県小松市以下に掲載がない場合');
ok($zip->set_number('9230001')->is_valid_number, '石川県小松市大島町');
ok($zip->set_number('9230002')->is_valid_number, '石川県小松市小島町');
ok($zip->set_number('9230003')->is_valid_number, '石川県小松市安宅町');
ok($zip->set_number('9230004')->is_valid_number, '石川県小松市長崎町');
ok($zip->set_number('9230005')->is_valid_number, '石川県小松市坊丸町');
ok($zip->set_number('9230011')->is_valid_number, '石川県小松市蛭川町');
ok($zip->set_number('9230012')->is_valid_number, '石川県小松市東蛭川町');
ok($zip->set_number('9230013')->is_valid_number, '石川県小松市城北町');
ok($zip->set_number('9230014')->is_valid_number, '石川県小松市松梨町');
ok($zip->set_number('9230015')->is_valid_number, '石川県小松市犬丸町');
ok($zip->set_number('9230016')->is_valid_number, '石川県小松市御館町');
ok($zip->set_number('9230021')->is_valid_number, '石川県小松市島田町');
ok($zip->set_number('9230022')->is_valid_number, '石川県小松市美原町');
ok($zip->set_number('9230023')->is_valid_number, '石川県小松市梅田町');
ok($zip->set_number('9230024')->is_valid_number, '石川県小松市茶屋町');
ok($zip->set_number('9230025')->is_valid_number, '石川県小松市天神町');
ok($zip->set_number('9230026')->is_valid_number, '石川県小松市下牧町');
ok($zip->set_number('9230027')->is_valid_number, '石川県小松市上牧町');
ok($zip->set_number('9230028')->is_valid_number, '石川県小松市梯町');
ok($zip->set_number('9230031')->is_valid_number, '石川県小松市高堂町');
ok($zip->set_number('9230032')->is_valid_number, '石川県小松市荒屋町');
ok($zip->set_number('9230033')->is_valid_number, '石川県小松市野田町');
ok($zip->set_number('9230034')->is_valid_number, '石川県小松市長田町');
ok($zip->set_number('9230035')->is_valid_number, '石川県小松市あけぼの町');
ok($zip->set_number('9230036')->is_valid_number, '石川県小松市平面町');
ok($zip->set_number('9230037')->is_valid_number, '石川県小松市問屋町');
ok($zip->set_number('9230041')->is_valid_number, '石川県小松市千代町');
ok($zip->set_number('9230042')->is_valid_number, '石川県小松市能美町');
ok($zip->set_number('9230043')->is_valid_number, '石川県小松市一針町');
ok($zip->set_number('9230044')->is_valid_number, '石川県小松市川辺町');
ok($zip->set_number('9230051')->is_valid_number, '石川県小松市上八里町');
ok($zip->set_number('9230052')->is_valid_number, '石川県小松市下八里町');
ok($zip->set_number('9230053')->is_valid_number, '石川県小松市河田町');
ok($zip->set_number('9230054')->is_valid_number, '石川県小松市小野町');
ok($zip->set_number('9230055')->is_valid_number, '石川県小松市古府町');
ok($zip->set_number('9230056')->is_valid_number, '石川県小松市八里台');
ok($zip->set_number('9230061')->is_valid_number, '石川県小松市国府台');
ok($zip->set_number('9230062')->is_valid_number, '石川県小松市里川町');
ok($zip->set_number('9230063')->is_valid_number, '石川県小松市鵜川町');
ok($zip->set_number('9230064')->is_valid_number, '石川県小松市遊泉寺町');
ok($zip->set_number('9230065')->is_valid_number, '石川県小松市立明寺町');
ok($zip->set_number('9230066')->is_valid_number, '石川県小松市埴田町');
ok($zip->set_number('9230071')->is_valid_number, '石川県小松市中海町');
ok($zip->set_number('9230072')->is_valid_number, '石川県小松市みどり町');
ok($zip->set_number('9230073')->is_valid_number, '石川県小松市岩渕町');
ok($zip->set_number('9230074')->is_valid_number, '石川県小松市桂町');
ok($zip->set_number('9230075')->is_valid_number, '石川県小松市原町');
ok($zip->set_number('9230076')->is_valid_number, '石川県小松市麦口町');
ok($zip->set_number('9230077')->is_valid_number, '石川県小松市上麦口町');
ok($zip->set_number('9230078')->is_valid_number, '石川県小松市嵐町');
ok($zip->set_number('9230078')->is_valid_number, '石川県小松市中ノ峠町');
ok($zip->set_number('9230151')->is_valid_number, '石川県小松市正蓮寺町');
ok($zip->set_number('9230152')->is_valid_number, '石川県小松市五国寺町');
ok($zip->set_number('9230153')->is_valid_number, '石川県小松市金平町');
ok($zip->set_number('9230154')->is_valid_number, '石川県小松市金野町');
ok($zip->set_number('9230155')->is_valid_number, '石川県小松市江指町');
ok($zip->set_number('9230156')->is_valid_number, '石川県小松市大野町');
ok($zip->set_number('9230157')->is_valid_number, '石川県小松市花坂町');
ok($zip->set_number('9230161')->is_valid_number, '石川県小松市池城町');
ok($zip->set_number('9230162')->is_valid_number, '石川県小松市波佐羅町');
ok($zip->set_number('9230163')->is_valid_number, '石川県小松市塩原町');
ok($zip->set_number('9230164')->is_valid_number, '石川県小松市布橋町');
ok($zip->set_number('9230165')->is_valid_number, '石川県小松市沢町');
ok($zip->set_number('9230166')->is_valid_number, '石川県小松市松岡町');
ok($zip->set_number('9230171')->is_valid_number, '石川県小松市観音下町');
ok($zip->set_number('9230172')->is_valid_number, '石川県小松市尾小屋町');
ok($zip->set_number('9230173')->is_valid_number, '石川県小松市丸山町');
ok($zip->set_number('9230174')->is_valid_number, '石川県小松市花立町');
ok($zip->set_number('9230175')->is_valid_number, '石川県小松市新保町');
ok($zip->set_number('9230176')->is_valid_number, '石川県小松市西俣町');
ok($zip->set_number('9230177')->is_valid_number, '石川県小松市岩上町');
ok($zip->set_number('9230181')->is_valid_number, '石川県小松市長谷町');
ok($zip->set_number('9230182')->is_valid_number, '石川県小松市波佐谷町');
ok($zip->set_number('9230183')->is_valid_number, '石川県小松市瀬領町');
ok($zip->set_number('9230184')->is_valid_number, '石川県小松市打木町');
ok($zip->set_number('9230185')->is_valid_number, '石川県小松市赤瀬町');
ok($zip->set_number('9230186')->is_valid_number, '石川県小松市大杉町');
ok($zip->set_number('9230187')->is_valid_number, '石川県小松市上リ江町');
ok($zip->set_number('9230301')->is_valid_number, '石川県小松市矢崎町');
ok($zip->set_number('9230302')->is_valid_number, '石川県小松市符津町');
ok($zip->set_number('9230303')->is_valid_number, '石川県小松市島町');
ok($zip->set_number('9230304')->is_valid_number, '石川県小松市下粟津町');
ok($zip->set_number('9230305')->is_valid_number, '石川県小松市蓑輪町');
ok($zip->set_number('9230306')->is_valid_number, '石川県小松市松生町');
ok($zip->set_number('9230311')->is_valid_number, '石川県小松市木場町');
ok($zip->set_number('9230312')->is_valid_number, '石川県小松市木場台');
ok($zip->set_number('9230313')->is_valid_number, '石川県小松市津波倉町');
ok($zip->set_number('9230314')->is_valid_number, '石川県小松市おびし町');
ok($zip->set_number('9230315')->is_valid_number, '石川県小松市小山田町');
ok($zip->set_number('9230316')->is_valid_number, '石川県小松市井口町');
ok($zip->set_number('9230321')->is_valid_number, '石川県小松市白山田町');
ok($zip->set_number('9230322')->is_valid_number, '石川県小松市牧口町');
ok($zip->set_number('9230323')->is_valid_number, '石川県小松市西荒谷町');
ok($zip->set_number('9230324')->is_valid_number, '石川県小松市日用町');
ok($zip->set_number('9230325')->is_valid_number, '石川県小松市西原町');
ok($zip->set_number('9230326')->is_valid_number, '石川県小松市粟津温泉');
ok($zip->set_number('9230326')->is_valid_number, '石川県小松市粟津町');
ok($zip->set_number('9230327')->is_valid_number, '石川県小松市戸津町');
ok($zip->set_number('9230328')->is_valid_number, '石川県小松市南陽町');
ok($zip->set_number('9230331')->is_valid_number, '石川県小松市上荒屋町');
ok($zip->set_number('9230332')->is_valid_number, '石川県小松市湯上町');
ok($zip->set_number('9230333')->is_valid_number, '石川県小松市馬場町');
ok($zip->set_number('9230334')->is_valid_number, '石川県小松市菩提町');
ok($zip->set_number('9230335')->is_valid_number, '石川県小松市滝ケ原町');
ok($zip->set_number('9230336')->is_valid_number, '石川県小松市那谷町');
ok($zip->set_number('9230341')->is_valid_number, '石川県小松市春日町');
ok($zip->set_number('9230342')->is_valid_number, '石川県小松市矢田野町');
ok($zip->set_number('9230343')->is_valid_number, '石川県小松市矢沢町');
ok($zip->set_number('9230344')->is_valid_number, '石川県小松市林町');
ok($zip->set_number('9230345')->is_valid_number, '石川県小松市二ツ梨町');
ok($zip->set_number('9230801')->is_valid_number, '石川県小松市園町');
ok($zip->set_number('9230802')->is_valid_number, '石川県小松市上小松町');
ok($zip->set_number('9230803')->is_valid_number, '石川県小松市宝町');
ok($zip->set_number('9230804')->is_valid_number, '石川県小松市光町');
ok($zip->set_number('9230805')->is_valid_number, '石川県小松市御宮町');
ok($zip->set_number('9230806')->is_valid_number, '石川県小松市小寺町');
ok($zip->set_number('9230811')->is_valid_number, '石川県小松市白江町');
ok($zip->set_number('9230812')->is_valid_number, '石川県小松市漆町');
ok($zip->set_number('9230812')->is_valid_number, '石川県小松市金屋町');
ok($zip->set_number('9230813')->is_valid_number, '石川県小松市糸町');
ok($zip->set_number('9230814')->is_valid_number, '石川県小松市白松町');
ok($zip->set_number('9230821')->is_valid_number, '石川県小松市佐々木町');
ok($zip->set_number('9230822')->is_valid_number, '石川県小松市光陽町');
ok($zip->set_number('9230823')->is_valid_number, '石川県小松市荒木田町');
ok($zip->set_number('9230824')->is_valid_number, '石川県小松市軽海町');
ok($zip->set_number('9230825')->is_valid_number, '石川県小松市西軽海町');
ok($zip->set_number('9230826')->is_valid_number, '石川県小松市希望丘');
ok($zip->set_number('9230831')->is_valid_number, '石川県小松市打越町');
ok($zip->set_number('9230832')->is_valid_number, '石川県小松市若杉町');
ok($zip->set_number('9230833')->is_valid_number, '石川県小松市八幡(加賀八幡)');
ok($zip->set_number('9230834')->is_valid_number, '石川県小松市千木野町');
ok($zip->set_number('9230835')->is_valid_number, '石川県小松市吉竹町');
ok($zip->set_number('9230836')->is_valid_number, '石川県小松市鹿町');
ok($zip->set_number('9230841')->is_valid_number, '石川県小松市本江町');
ok($zip->set_number('9230842')->is_valid_number, '石川県小松市東山町');
ok($zip->set_number('9230843')->is_valid_number, '石川県小松市蓮代寺町');
ok($zip->set_number('9230844')->is_valid_number, '石川県小松市三谷町');
ok($zip->set_number('9230851')->is_valid_number, '石川県小松市北浅井町');
ok($zip->set_number('9230852')->is_valid_number, '石川県小松市南浅井町');
ok($zip->set_number('9230853')->is_valid_number, '石川県小松市扇町');
ok($zip->set_number('9230854')->is_valid_number, '石川県小松市大領町');
ok($zip->set_number('9230861')->is_valid_number, '石川県小松市沖町');
ok($zip->set_number('9230862')->is_valid_number, '石川県小松市清六町');
ok($zip->set_number('9230862')->is_valid_number, '石川県小松市三田町');
ok($zip->set_number('9230863')->is_valid_number, '石川県小松市不動島町');
ok($zip->set_number('9230864')->is_valid_number, '石川県小松市有明町');
ok($zip->set_number('9230865')->is_valid_number, '石川県小松市福乃宮町');
ok($zip->set_number('9230866')->is_valid_number, '石川県小松市白嶺町');
ok($zip->set_number('9230867')->is_valid_number, '石川県小松市幸町');
ok($zip->set_number('9230868')->is_valid_number, '石川県小松市日の出町');
ok($zip->set_number('9230868')->is_valid_number, '石川県小松市八日市町地方');
ok($zip->set_number('9230869')->is_valid_number, '石川県小松市こまつの杜');
ok($zip->set_number('9230901')->is_valid_number, '石川県小松市泉町');
ok($zip->set_number('9230902')->is_valid_number, '石川県小松市古城町');
ok($zip->set_number('9230903')->is_valid_number, '石川県小松市丸の内公園町');
ok($zip->set_number('9230903')->is_valid_number, '石川県小松市丸の内町');
ok($zip->set_number('9230903')->is_valid_number, '石川県小松市丸内町');
ok($zip->set_number('9230904')->is_valid_number, '石川県小松市小馬出町');
ok($zip->set_number('9230905')->is_valid_number, '石川県小松市地子町');
ok($zip->set_number('9230905')->is_valid_number, '石川県小松市鷹匠町');
ok($zip->set_number('9230906')->is_valid_number, '石川県小松市新大工町');
ok($zip->set_number('9230907')->is_valid_number, '石川県小松市浜田町');
ok($zip->set_number('9230908')->is_valid_number, '石川県小松市浮城町');
ok($zip->set_number('9230911')->is_valid_number, '石川県小松市大川町');
ok($zip->set_number('9230912')->is_valid_number, '石川県小松市新町');
ok($zip->set_number('9230913')->is_valid_number, '石川県小松市松任町');
ok($zip->set_number('9230914')->is_valid_number, '石川県小松市新鍛冶町');
ok($zip->set_number('9230915')->is_valid_number, '石川県小松市細工町');
ok($zip->set_number('9230916')->is_valid_number, '石川県小松市材木町');
ok($zip->set_number('9230917')->is_valid_number, '石川県小松市中町');
ok($zip->set_number('9230918')->is_valid_number, '石川県小松市京町');
ok($zip->set_number('9230919')->is_valid_number, '石川県小松市殿町');
ok($zip->set_number('9230921')->is_valid_number, '石川県小松市土居原町');
ok($zip->set_number('9230922')->is_valid_number, '石川県小松市飴屋町');
ok($zip->set_number('9230923')->is_valid_number, '石川県小松市東町');
ok($zip->set_number('9230924')->is_valid_number, '石川県小松市三日市町');
ok($zip->set_number('9230925')->is_valid_number, '石川県小松市八日市町');
ok($zip->set_number('9230926')->is_valid_number, '石川県小松市龍助町');
ok($zip->set_number('9230927')->is_valid_number, '石川県小松市西町');
ok($zip->set_number('9230931')->is_valid_number, '石川県小松市大文字町');
ok($zip->set_number('9230932')->is_valid_number, '石川県小松市寺町');
ok($zip->set_number('9230933')->is_valid_number, '石川県小松市本鍛冶町');
ok($zip->set_number('9230934')->is_valid_number, '石川県小松市栄町');
ok($zip->set_number('9230935')->is_valid_number, '石川県小松市上寺町');
ok($zip->set_number('9230936')->is_valid_number, '石川県小松市本大工町');
ok($zip->set_number('9230937')->is_valid_number, '石川県小松市本町');
ok($zip->set_number('9230938')->is_valid_number, '石川県小松市芦田町');
ok($zip->set_number('9230941')->is_valid_number, '石川県小松市城南町');
ok($zip->set_number('9230942')->is_valid_number, '石川県小松市桜木町');
ok($zip->set_number('9230943')->is_valid_number, '石川県小松市育成町');
ok($zip->set_number('9230944')->is_valid_number, '石川県小松市古河町');
ok($zip->set_number('9230945')->is_valid_number, '石川県小松市末広町');
ok($zip->set_number('9230946')->is_valid_number, '石川県小松市相生町');
ok($zip->set_number('9230947')->is_valid_number, '石川県小松市日吉町');
ok($zip->set_number('9230948')->is_valid_number, '石川県小松市錦町');
ok($zip->set_number('9230951')->is_valid_number, '石川県小松市白山町');
ok($zip->set_number('9230952')->is_valid_number, '石川県小松市大和町');
ok($zip->set_number('9230953')->is_valid_number, '石川県小松市旭町');
ok($zip->set_number('9230954')->is_valid_number, '石川県小松市八幡町');
ok($zip->set_number('9230955')->is_valid_number, '石川県小松市上本折町');
ok($zip->set_number('9230956')->is_valid_number, '石川県小松市西本折町');
ok($zip->set_number('9230957')->is_valid_number, '石川県小松市本折町');
ok($zip->set_number('9230958')->is_valid_number, '石川県小松市清水町');
ok($zip->set_number('9230961')->is_valid_number, '石川県小松市向本折町');
ok($zip->set_number('9230962')->is_valid_number, '石川県小松市大領中町');
ok($zip->set_number('9230963')->is_valid_number, '石川県小松市須天町');
ok($zip->set_number('9230964')->is_valid_number, '石川県小松市今江町');
ok($zip->set_number('9230965')->is_valid_number, '石川県小松市串町');
ok($zip->set_number('9230965')->is_valid_number, '石川県小松市野立町');
ok($zip->set_number('9230966')->is_valid_number, '石川県小松市串茶屋町');
ok($zip->set_number('9230967')->is_valid_number, '石川県小松市青路町');
ok($zip->set_number('9230968')->is_valid_number, '石川県小松市村松町');
ok($zip->set_number('9230971')->is_valid_number, '石川県小松市四丁町');
ok($zip->set_number('9230972')->is_valid_number, '石川県小松市月津町');
ok($zip->set_number('9230973')->is_valid_number, '石川県小松市扇原町');
ok($zip->set_number('9230974')->is_valid_number, '石川県小松市月美丘');
ok($zip->set_number('9230975')->is_valid_number, '石川県小松市矢田町');
ok($zip->set_number('9230976')->is_valid_number, '石川県小松市矢田新町');
ok($zip->set_number('9230977')->is_valid_number, '石川県小松市額見町');
ok($zip->set_number('9230981')->is_valid_number, '石川県小松市拓栄町');
ok($zip->set_number('9230982')->is_valid_number, '石川県小松市松崎町');
ok($zip->set_number('9230983')->is_valid_number, '石川県小松市日末町');
ok($zip->set_number('9230984')->is_valid_number, '石川県小松市佐美町');
ok($zip->set_number('9230985')->is_valid_number, '石川県小松市浜佐美町');
ok($zip->set_number('9230991')->is_valid_number, '石川県小松市木曽町');
ok($zip->set_number('9230992')->is_valid_number, '石川県小松市鶴ケ島町');
ok($zip->set_number('9230993')->is_valid_number, '石川県小松市浮柳町');
ok($zip->set_number('9230994')->is_valid_number, '石川県小松市工業団地');
ok($zip->set_number('9230995')->is_valid_number, '石川県小松市安宅新町');
ok($zip->set_number('9230996')->is_valid_number, '石川県小松市草野町');
ok($zip->set_number('9230997')->is_valid_number, '石川県小松市浜佐美本町');
ok($zip->set_number('9230998')->is_valid_number, '石川県小松市義仲町');
ok($zip->set_number('9231100')->is_valid_number, '石川県能美市以下に掲載がない場合');
ok($zip->set_number('9231101')->is_valid_number, '石川県能美市粟生町');
ok($zip->set_number('9231102')->is_valid_number, '石川県能美市新保町');
ok($zip->set_number('9231103')->is_valid_number, '石川県能美市秋常町');
ok($zip->set_number('9231104')->is_valid_number, '石川県能美市湯谷町');
ok($zip->set_number('9231105')->is_valid_number, '石川県能美市石子町');
ok($zip->set_number('9231106')->is_valid_number, '石川県能美市和田町');
ok($zip->set_number('9231107')->is_valid_number, '石川県能美市末寺町');
ok($zip->set_number('9231111')->is_valid_number, '石川県能美市泉台町');
ok($zip->set_number('9231112')->is_valid_number, '石川県能美市佐野町');
ok($zip->set_number('9231113')->is_valid_number, '石川県能美市牛島町');
ok($zip->set_number('9231114')->is_valid_number, '石川県能美市小杉町');
ok($zip->set_number('9231115')->is_valid_number, '石川県能美市大長野町');
ok($zip->set_number('9231116')->is_valid_number, '石川県能美市小長野町');
ok($zip->set_number('9231117')->is_valid_number, '石川県能美市末信町');
ok($zip->set_number('9231121')->is_valid_number, '石川県能美市寺井町');
ok($zip->set_number('9231122')->is_valid_number, '石川県能美市東任田町');
ok($zip->set_number('9231123')->is_valid_number, '石川県能美市吉光町');
ok($zip->set_number('9231124')->is_valid_number, '石川県能美市三道山町');
ok($zip->set_number('9231200')->is_valid_number, '石川県能美郡川北町以下に掲載がない場合');
ok($zip->set_number('9231201')->is_valid_number, '石川県能美市岩内町');
ok($zip->set_number('9231202')->is_valid_number, '石川県能美市莇生町');
ok($zip->set_number('9231203')->is_valid_number, '石川県能美市三ツ口町');
ok($zip->set_number('9231204')->is_valid_number, '石川県能美市長滝町');
ok($zip->set_number('9231205')->is_valid_number, '石川県能美市宮竹町');
ok($zip->set_number('9231206')->is_valid_number, '石川県能美市灯台笹町');
ok($zip->set_number('9231207')->is_valid_number, '石川県能美市岩本町');
ok($zip->set_number('9231208')->is_valid_number, '石川県能美市和佐谷町');
ok($zip->set_number('9231211')->is_valid_number, '石川県能美市旭台');
ok($zip->set_number('9231212')->is_valid_number, '石川県能美市大口町');
ok($zip->set_number('9231213')->is_valid_number, '石川県能美市坪野町');
ok($zip->set_number('9231214')->is_valid_number, '石川県能美市金剛寺町');
ok($zip->set_number('9231215')->is_valid_number, '石川県能美市舘町');
ok($zip->set_number('9231216')->is_valid_number, '石川県能美市鍋谷町');
ok($zip->set_number('9231217')->is_valid_number, '石川県能美市仏大寺町');
ok($zip->set_number('9231221')->is_valid_number, '石川県能美市湯屋町');
ok($zip->set_number('9231222')->is_valid_number, '石川県能美市徳山町');
ok($zip->set_number('9231223')->is_valid_number, '石川県能美市寺畠町');
ok($zip->set_number('9231224')->is_valid_number, '石川県能美市和気町');
ok($zip->set_number('9231225')->is_valid_number, '石川県能美市松が岡');
ok($zip->set_number('9231226')->is_valid_number, '石川県能美市緑が丘');
ok($zip->set_number('9231227')->is_valid_number, '石川県能美市和光台');
ok($zip->set_number('9231231')->is_valid_number, '石川県能美市上開発町');
ok($zip->set_number('9231232')->is_valid_number, '石川県能美市下開発町');
ok($zip->set_number('9231233')->is_valid_number, '石川県能美市荒屋町');
ok($zip->set_number('9231234')->is_valid_number, '石川県能美市高座町');
ok($zip->set_number('9231235')->is_valid_number, '石川県能美市徳久町');
ok($zip->set_number('9231236')->is_valid_number, '石川県能美市北市町');
ok($zip->set_number('9231237')->is_valid_number, '石川県能美市上清水町');
ok($zip->set_number('9231238')->is_valid_number, '石川県能美市下清水町');
ok($zip->set_number('9231241')->is_valid_number, '石川県能美市山田町');
ok($zip->set_number('9231242')->is_valid_number, '石川県能美市火釜町');
ok($zip->set_number('9231243')->is_valid_number, '石川県能美市三ツ屋町');
ok($zip->set_number('9231244')->is_valid_number, '石川県能美市来丸町');
ok($zip->set_number('9231245')->is_valid_number, '石川県能美市辰口町');
ok($zip->set_number('9231246')->is_valid_number, '石川県能美市倉重町');
ok($zip->set_number('9231247')->is_valid_number, '石川県能美市出口町');
ok($zip->set_number('9231251')->is_valid_number, '石川県能美郡川北町藤蔵');
ok($zip->set_number('9231252')->is_valid_number, '石川県能美郡川北町中島');
ok($zip->set_number('9231253')->is_valid_number, '石川県能美郡川北町三反田');
ok($zip->set_number('9231254')->is_valid_number, '石川県能美郡川北町サンコーポラス');
ok($zip->set_number('9231261')->is_valid_number, '石川県能美郡川北町土室');
ok($zip->set_number('9231262')->is_valid_number, '石川県能美郡川北町草深');
ok($zip->set_number('9231263')->is_valid_number, '石川県能美郡川北町下土室');
ok($zip->set_number('9231264')->is_valid_number, '石川県能美郡川北町山田先出');
ok($zip->set_number('9231265')->is_valid_number, '石川県能美郡川北町上先出');
ok($zip->set_number('9231266')->is_valid_number, '石川県能美郡川北町下先出');
ok($zip->set_number('9231267')->is_valid_number, '石川県能美郡川北町壱ツ屋');
ok($zip->set_number('9231268')->is_valid_number, '石川県能美郡川北町与九郎島');
ok($zip->set_number('9231269')->is_valid_number, '石川県能美郡川北町上田子島');
ok($zip->set_number('9231271')->is_valid_number, '石川県能美郡川北町田子島');
ok($zip->set_number('9231272')->is_valid_number, '石川県能美郡川北町下田子島');
ok($zip->set_number('9231273')->is_valid_number, '石川県能美郡川北町舟場島');
ok($zip->set_number('9231274')->is_valid_number, '石川県能美郡川北町木呂場');
ok($zip->set_number('9231275')->is_valid_number, '石川県能美郡川北町木呂場新');
ok($zip->set_number('9231276')->is_valid_number, '石川県能美郡川北町橘');
ok($zip->set_number('9231277')->is_valid_number, '石川県能美郡川北町橘新');
ok($zip->set_number('9231278')->is_valid_number, '石川県能美郡川北町朝日');
ok($zip->set_number('9240000')->is_valid_number, '石川県白山市以下に掲載がない場合');
ok($zip->set_number('9240001')->is_valid_number, '石川県白山市八田町');
ok($zip->set_number('9240002')->is_valid_number, '石川県白山市八田中町');
ok($zip->set_number('9240003')->is_valid_number, '石川県白山市中新保町');
ok($zip->set_number('9240004')->is_valid_number, '石川県白山市旭丘');
ok($zip->set_number('9240005')->is_valid_number, '石川県白山市一塚町');
ok($zip->set_number('9240006')->is_valid_number, '石川県白山市村井新町');
ok($zip->set_number('9240007')->is_valid_number, '石川県白山市倉部町');
ok($zip->set_number('9240011')->is_valid_number, '石川県白山市横江町');
ok($zip->set_number('9240012')->is_valid_number, '石川県白山市福増町');
ok($zip->set_number('9240013')->is_valid_number, '石川県白山市番匠町');
ok($zip->set_number('9240014')->is_valid_number, '石川県白山市五歩市町');
ok($zip->set_number('9240015')->is_valid_number, '石川県白山市新田町');
ok($zip->set_number('9240016')->is_valid_number, '石川県白山市宮永市町');
ok($zip->set_number('9240017')->is_valid_number, '石川県白山市宮永町');
ok($zip->set_number('9240018')->is_valid_number, '石川県白山市宮永新町');
ok($zip->set_number('9240019')->is_valid_number, '石川県白山市あさひ荘苑');
ok($zip->set_number('9240020')->is_valid_number, '石川県白山市新成');
ok($zip->set_number('9240021')->is_valid_number, '石川県白山市竹松町');
ok($zip->set_number('9240022')->is_valid_number, '石川県白山市相木町');
ok($zip->set_number('9240023')->is_valid_number, '石川県白山市成町');
ok($zip->set_number('9240024')->is_valid_number, '石川県白山市北安田町');
ok($zip->set_number('9240025')->is_valid_number, '石川県白山市蕪城');
ok($zip->set_number('9240026')->is_valid_number, '石川県白山市平木町');
ok($zip->set_number('9240027')->is_valid_number, '石川県白山市相川町');
ok($zip->set_number('9240028')->is_valid_number, '石川県白山市相川新町');
ok($zip->set_number('9240029')->is_valid_number, '石川県白山市中成');
ok($zip->set_number('9240030')->is_valid_number, '石川県白山市北成町');
ok($zip->set_number('9240031')->is_valid_number, '石川県白山市村井東');
ok($zip->set_number('9240032')->is_valid_number, '石川県白山市村井町');
ok($zip->set_number('9240033')->is_valid_number, '石川県白山市宮丸町');
ok($zip->set_number('9240034')->is_valid_number, '石川県白山市小上町');
ok($zip->set_number('9240035')->is_valid_number, '石川県白山市上柏野町');
ok($zip->set_number('9240036')->is_valid_number, '石川県白山市中柏野町');
ok($zip->set_number('9240037')->is_valid_number, '石川県白山市荒屋柏野町');
ok($zip->set_number('9240038')->is_valid_number, '石川県白山市下柏野町');
ok($zip->set_number('9240039')->is_valid_number, '石川県白山市北安田西');
ok($zip->set_number('9240041')->is_valid_number, '石川県白山市東美沢野町');
ok($zip->set_number('9240042')->is_valid_number, '石川県白山市東柏町');
ok($zip->set_number('9240043')->is_valid_number, '石川県白山市柏町');
ok($zip->set_number('9240044')->is_valid_number, '石川県白山市西柏町');
ok($zip->set_number('9240045')->is_valid_number, '石川県白山市西柏');
ok($zip->set_number('9240046')->is_valid_number, '石川県白山市西美沢野');
ok($zip->set_number('9240047')->is_valid_number, '石川県白山市西美沢野町');
ok($zip->set_number('9240048')->is_valid_number, '石川県白山市美沢野町');
ok($zip->set_number('9240051')->is_valid_number, '石川県白山市福留町');
ok($zip->set_number('9240052')->is_valid_number, '石川県白山市源兵島町');
ok($zip->set_number('9240053')->is_valid_number, '石川県白山市水澄町');
ok($zip->set_number('9240054')->is_valid_number, '石川県白山市米光町');
ok($zip->set_number('9240055')->is_valid_number, '石川県白山市北島町');
ok($zip->set_number('9240056')->is_valid_number, '石川県白山市阿弥陀島町');
ok($zip->set_number('9240057')->is_valid_number, '石川県白山市松本町');
ok($zip->set_number('9240058')->is_valid_number, '石川県白山市石立町');
ok($zip->set_number('9240059')->is_valid_number, '石川県白山市福留南');
ok($zip->set_number('9240061')->is_valid_number, '石川県白山市宮保町');
ok($zip->set_number('9240062')->is_valid_number, '石川県白山市笠間新');
ok($zip->set_number('9240063')->is_valid_number, '石川県白山市笠間町');
ok($zip->set_number('9240064')->is_valid_number, '石川県白山市黒瀬町');
ok($zip->set_number('9240065')->is_valid_number, '石川県白山市七郎町');
ok($zip->set_number('9240066')->is_valid_number, '石川県白山市上小川町');
ok($zip->set_number('9240067')->is_valid_number, '石川県白山市小川町');
ok($zip->set_number('9240068')->is_valid_number, '石川県白山市宮保新町');
ok($zip->set_number('9240069')->is_valid_number, '石川県白山市宮原町');
ok($zip->set_number('9240071')->is_valid_number, '石川県白山市徳光町');
ok($zip->set_number('9240072')->is_valid_number, '石川県白山市千代野西');
ok($zip->set_number('9240073')->is_valid_number, '石川県白山市千代野東');
ok($zip->set_number('9240074')->is_valid_number, '石川県白山市千代野南');
ok($zip->set_number('9240075')->is_valid_number, '石川県白山市米永町');
ok($zip->set_number('9240076')->is_valid_number, '石川県白山市法仏町');
ok($zip->set_number('9240081')->is_valid_number, '石川県白山市相木');
ok($zip->set_number('9240801')->is_valid_number, '石川県白山市田中町');
ok($zip->set_number('9240802')->is_valid_number, '石川県白山市専福寺町');
ok($zip->set_number('9240803')->is_valid_number, '石川県白山市乾町');
ok($zip->set_number('9240804')->is_valid_number, '石川県白山市徳丸町');
ok($zip->set_number('9240805')->is_valid_number, '石川県白山市若宮');
ok($zip->set_number('9240806')->is_valid_number, '石川県白山市石同新町');
ok($zip->set_number('9240807')->is_valid_number, '石川県白山市石同町');
ok($zip->set_number('9240808')->is_valid_number, '石川県白山市布市');
ok($zip->set_number('9240810')->is_valid_number, '石川県白山市菜の花');
ok($zip->set_number('9240811')->is_valid_number, '石川県白山市長竹町');
ok($zip->set_number('9240812')->is_valid_number, '石川県白山市橋爪町');
ok($zip->set_number('9240813')->is_valid_number, '石川県白山市福正寺町');
ok($zip->set_number('9240814')->is_valid_number, '石川県白山市橋爪新町');
ok($zip->set_number('9240815')->is_valid_number, '石川県白山市三浦町');
ok($zip->set_number('9240816')->is_valid_number, '石川県白山市三幸町');
ok($zip->set_number('9240817')->is_valid_number, '石川県白山市幸明町');
ok($zip->set_number('9240818')->is_valid_number, '石川県白山市中奥町');
ok($zip->set_number('9240819')->is_valid_number, '石川県白山市青葉台');
ok($zip->set_number('9240820')->is_valid_number, '石川県白山市美里町');
ok($zip->set_number('9240821')->is_valid_number, '石川県白山市木津町');
ok($zip->set_number('9240822')->is_valid_number, '石川県白山市みずほ');
ok($zip->set_number('9240823')->is_valid_number, '石川県白山市坊丸町');
ok($zip->set_number('9240824')->is_valid_number, '石川県白山市田地町');
ok($zip->set_number('9240825')->is_valid_number, '石川県白山市菅波町');
ok($zip->set_number('9240826')->is_valid_number, '石川県白山市乙丸町');
ok($zip->set_number('9240827')->is_valid_number, '石川県白山市今平町');
ok($zip->set_number('9240828')->is_valid_number, '石川県白山市上二口町');
ok($zip->set_number('9240831')->is_valid_number, '石川県白山市藤波');
ok($zip->set_number('9240832')->is_valid_number, '石川県白山市藤木町');
ok($zip->set_number('9240833')->is_valid_number, '石川県白山市向島町');
ok($zip->set_number('9240834')->is_valid_number, '石川県白山市矢頃島町');
ok($zip->set_number('9240835')->is_valid_number, '石川県白山市漆島町');
ok($zip->set_number('9240836')->is_valid_number, '石川県白山市山島台');
ok($zip->set_number('9240837')->is_valid_number, '石川県白山市吉田町');
ok($zip->set_number('9240838')->is_valid_number, '石川県白山市八束穂');
ok($zip->set_number('9240841')->is_valid_number, '石川県白山市平松町');
ok($zip->set_number('9240842')->is_valid_number, '石川県白山市剣崎町');
ok($zip->set_number('9240843')->is_valid_number, '石川県白山市安吉町');
ok($zip->set_number('9240844')->is_valid_number, '石川県白山市寄新保町');
ok($zip->set_number('9240845')->is_valid_number, '石川県白山市島田町');
ok($zip->set_number('9240846')->is_valid_number, '石川県白山市上島田町');
ok($zip->set_number('9240847')->is_valid_number, '石川県白山市内方新保町');
ok($zip->set_number('9240848')->is_valid_number, '石川県白山市長島町');
ok($zip->set_number('9240851')->is_valid_number, '石川県白山市御影堂町');
ok($zip->set_number('9240852')->is_valid_number, '石川県白山市四ツ屋町');
ok($zip->set_number('9240853')->is_valid_number, '石川県白山市上安田町');
ok($zip->set_number('9240854')->is_valid_number, '石川県白山市出合島町');
ok($zip->set_number('9240855')->is_valid_number, '石川県白山市水島町');
ok($zip->set_number('9240856')->is_valid_number, '石川県白山市番田町');
ok($zip->set_number('9240857')->is_valid_number, '石川県白山市福永町');
ok($zip->set_number('9240858')->is_valid_number, '石川県白山市福新町');
ok($zip->set_number('9240861')->is_valid_number, '石川県白山市横町');
ok($zip->set_number('9240862')->is_valid_number, '石川県白山市安田町');
ok($zip->set_number('9240863')->is_valid_number, '石川県白山市博労');
ok($zip->set_number('9240864')->is_valid_number, '石川県白山市馬場');
ok($zip->set_number('9240865')->is_valid_number, '石川県白山市倉光');
ok($zip->set_number('9240866')->is_valid_number, '石川県白山市倉光西');
ok($zip->set_number('9240867')->is_valid_number, '石川県白山市茶屋');
ok($zip->set_number('9240871')->is_valid_number, '石川県白山市西新町');
ok($zip->set_number('9240872')->is_valid_number, '石川県白山市古城町');
ok($zip->set_number('9240873')->is_valid_number, '石川県白山市八日市町');
ok($zip->set_number('9240874')->is_valid_number, '石川県白山市四日市町');
ok($zip->set_number('9240875')->is_valid_number, '石川県白山市辰巳町');
ok($zip->set_number('9240876')->is_valid_number, '石川県白山市鍛治町');
ok($zip->set_number('9240877')->is_valid_number, '石川県白山市中町');
ok($zip->set_number('9240878')->is_valid_number, '石川県白山市末広');
ok($zip->set_number('9240881')->is_valid_number, '石川県白山市八ツ矢新町');
ok($zip->set_number('9240882')->is_valid_number, '石川県白山市八ツ矢町');
ok($zip->set_number('9240883')->is_valid_number, '石川県白山市東一番町');
ok($zip->set_number('9240884')->is_valid_number, '石川県白山市東新町');
ok($zip->set_number('9240885')->is_valid_number, '石川県白山市殿町');
ok($zip->set_number('9240886')->is_valid_number, '石川県白山市東二番町');
ok($zip->set_number('9240887')->is_valid_number, '石川県白山市東三番町');
ok($zip->set_number('9240888')->is_valid_number, '石川県白山市旭町');
ok($zip->set_number('9250000')->is_valid_number, '石川県羽咋市以下に掲載がない場合');
ok($zip->set_number('9250001')->is_valid_number, '石川県羽咋市柴垣町');
ok($zip->set_number('9250002')->is_valid_number, '石川県羽咋市滝谷町');
ok($zip->set_number('9250003')->is_valid_number, '石川県羽咋市寺家町');
ok($zip->set_number('9250004')->is_valid_number, '石川県羽咋市一ノ宮町');
ok($zip->set_number('9250005')->is_valid_number, '石川県羽咋市滝町');
ok($zip->set_number('9250011')->is_valid_number, '石川県羽咋市上中山町');
ok($zip->set_number('9250012')->is_valid_number, '石川県羽咋市千路町');
ok($zip->set_number('9250013')->is_valid_number, '石川県羽咋市東釜屋町');
ok($zip->set_number('9250014')->is_valid_number, '石川県羽咋市釜屋町');
ok($zip->set_number('9250015')->is_valid_number, '石川県羽咋市大川町');
ok($zip->set_number('9250016')->is_valid_number, '石川県羽咋市羽咋町');
ok($zip->set_number('9250017')->is_valid_number, '石川県羽咋市西釜屋町');
ok($zip->set_number('9250018')->is_valid_number, '石川県羽咋市柳田町');
ok($zip->set_number('9250021')->is_valid_number, '石川県羽咋市吉崎町');
ok($zip->set_number('9250022')->is_valid_number, '石川県羽咋市深江町');
ok($zip->set_number('9250023')->is_valid_number, '石川県羽咋市若草町');
ok($zip->set_number('9250024')->is_valid_number, '石川県羽咋市三ツ屋町');
ok($zip->set_number('9250025')->is_valid_number, '石川県羽咋市太田町');
ok($zip->set_number('9250026')->is_valid_number, '石川県羽咋市石野町');
ok($zip->set_number('9250027')->is_valid_number, '石川県羽咋市鶴多町');
ok($zip->set_number('9250028')->is_valid_number, '石川県羽咋市次場町');
ok($zip->set_number('9250031')->is_valid_number, '石川県羽咋市東的場町');
ok($zip->set_number('9250032')->is_valid_number, '石川県羽咋市東川原町');
ok($zip->set_number('9250033')->is_valid_number, '石川県羽咋市川原町');
ok($zip->set_number('9250034')->is_valid_number, '石川県羽咋市旭町');
ok($zip->set_number('9250035')->is_valid_number, '石川県羽咋市本町');
ok($zip->set_number('9250036')->is_valid_number, '石川県羽咋市的場町');
ok($zip->set_number('9250041')->is_valid_number, '石川県羽咋市立開町');
ok($zip->set_number('9250042')->is_valid_number, '石川県羽咋市土橋町');
ok($zip->set_number('9250043')->is_valid_number, '石川県羽咋市粟原町');
ok($zip->set_number('9250044')->is_valid_number, '石川県羽咋市新保町');
ok($zip->set_number('9250045')->is_valid_number, '石川県羽咋市粟生町');
ok($zip->set_number('9250046')->is_valid_number, '石川県羽咋市兵庫町');
ok($zip->set_number('9250047')->is_valid_number, '石川県羽咋市御坊山町');
ok($zip->set_number('9250048')->is_valid_number, '石川県羽咋市松ケ下町');
ok($zip->set_number('9250049')->is_valid_number, '石川県羽咋市柳橋町');
ok($zip->set_number('9250051')->is_valid_number, '石川県羽咋市島出町');
ok($zip->set_number('9250052')->is_valid_number, '石川県羽咋市中央町');
ok($zip->set_number('9250053')->is_valid_number, '石川県羽咋市南中央町');
ok($zip->set_number('9250054')->is_valid_number, '石川県羽咋市千里浜町');
ok($zip->set_number('9250071')->is_valid_number, '石川県羽咋市下曽祢町');
ok($zip->set_number('9250072')->is_valid_number, '石川県羽咋市大町');
ok($zip->set_number('9250073')->is_valid_number, '石川県羽咋市四柳町');
ok($zip->set_number('9250074')->is_valid_number, '石川県羽咋市酒井町');
ok($zip->set_number('9250075')->is_valid_number, '石川県羽咋市金丸出町');
ok($zip->set_number('9250076')->is_valid_number, '石川県羽咋市鹿島路町');
ok($zip->set_number('9250077')->is_valid_number, '石川県羽咋市東潟町');
ok($zip->set_number('9250100')->is_valid_number, '石川県羽咋郡志賀町以下に掲載がない場合');
ok($zip->set_number('9250121')->is_valid_number, '石川県羽咋郡志賀町安津見');
ok($zip->set_number('9250122')->is_valid_number, '石川県羽咋郡志賀町倉垣');
ok($zip->set_number('9250123')->is_valid_number, '石川県羽咋郡志賀町矢駄');
ok($zip->set_number('9250124')->is_valid_number, '石川県羽咋郡志賀町西山');
ok($zip->set_number('9250125')->is_valid_number, '石川県羽咋郡志賀町西山台');
ok($zip->set_number('9250131')->is_valid_number, '石川県羽咋郡志賀町米浜');
ok($zip->set_number('9250132')->is_valid_number, '石川県羽咋郡志賀町穴口');
ok($zip->set_number('9250133')->is_valid_number, '石川県羽咋郡志賀町大坂');
ok($zip->set_number('9250134')->is_valid_number, '石川県羽咋郡志賀町上棚');
ok($zip->set_number('9250135')->is_valid_number, '石川県羽咋郡志賀町二所宮');
ok($zip->set_number('9250136')->is_valid_number, '石川県羽咋郡志賀町舘');
ok($zip->set_number('9250137')->is_valid_number, '石川県羽咋郡志賀町福井');
ok($zip->set_number('9250141')->is_valid_number, '石川県羽咋郡志賀町高浜町');
ok($zip->set_number('9250142')->is_valid_number, '石川県羽咋郡志賀町福野');
ok($zip->set_number('9250143')->is_valid_number, '石川県羽咋郡志賀町宿女');
ok($zip->set_number('9250144')->is_valid_number, '石川県羽咋郡志賀町坪野');
ok($zip->set_number('9250145')->is_valid_number, '石川県羽咋郡志賀町岩田');
ok($zip->set_number('9250146')->is_valid_number, '石川県羽咋郡志賀町甘田');
ok($zip->set_number('9250147')->is_valid_number, '石川県羽咋郡志賀町大島');
ok($zip->set_number('9250148')->is_valid_number, '石川県羽咋郡志賀町長沢');
ok($zip->set_number('9250151')->is_valid_number, '石川県羽咋郡志賀町梨谷小山');
ok($zip->set_number('9250152')->is_valid_number, '石川県羽咋郡志賀町北吉田');
ok($zip->set_number('9250153')->is_valid_number, '石川県羽咋郡志賀町清水今江');
ok($zip->set_number('9250154')->is_valid_number, '石川県羽咋郡志賀町末吉');
ok($zip->set_number('9250155')->is_valid_number, '石川県羽咋郡志賀町神代');
ok($zip->set_number('9250156')->is_valid_number, '石川県羽咋郡志賀町矢蔵谷');
ok($zip->set_number('9250157')->is_valid_number, '石川県羽咋郡志賀町堀松');
ok($zip->set_number('9250161')->is_valid_number, '石川県羽咋郡志賀町赤住');
ok($zip->set_number('9250162')->is_valid_number, '石川県羽咋郡志賀町百浦');
ok($zip->set_number('9250163')->is_valid_number, '石川県羽咋郡志賀町小浦');
ok($zip->set_number('9250164')->is_valid_number, '石川県羽咋郡志賀町大津');
ok($zip->set_number('9250165')->is_valid_number, '石川県羽咋郡志賀町上野');
ok($zip->set_number('9250166')->is_valid_number, '石川県羽咋郡志賀町安部屋');
ok($zip->set_number('9250167')->is_valid_number, '石川県羽咋郡志賀町町');
ok($zip->set_number('9250168')->is_valid_number, '石川県羽咋郡志賀町川尻');
ok($zip->set_number('9250201')->is_valid_number, '石川県羽咋郡志賀町印内');
ok($zip->set_number('9250202')->is_valid_number, '石川県羽咋郡志賀町代田');
ok($zip->set_number('9250203')->is_valid_number, '石川県羽咋郡志賀町新林');
ok($zip->set_number('9250204')->is_valid_number, '石川県羽咋郡志賀町牧山');
ok($zip->set_number('9250205')->is_valid_number, '石川県羽咋郡志賀町仏木');
ok($zip->set_number('9250206')->is_valid_number, '石川県羽咋郡志賀町谷屋');
ok($zip->set_number('9250207')->is_valid_number, '石川県羽咋郡志賀町栗山');
ok($zip->set_number('9250211')->is_valid_number, '石川県羽咋郡志賀町矢田');
ok($zip->set_number('9250212')->is_valid_number, '石川県羽咋郡志賀町徳田');
ok($zip->set_number('9250213')->is_valid_number, '石川県羽咋郡志賀町舘開');
ok($zip->set_number('9250214')->is_valid_number, '石川県羽咋郡志賀町火打谷');
ok($zip->set_number('9250215')->is_valid_number, '石川県羽咋郡志賀町出雲');
ok($zip->set_number('9250301')->is_valid_number, '石川県羽咋郡志賀町日用');
ok($zip->set_number('9250302')->is_valid_number, '石川県羽咋郡志賀町町居');
ok($zip->set_number('9250303')->is_valid_number, '石川県羽咋郡志賀町日下田');
ok($zip->set_number('9250304')->is_valid_number, '石川県羽咋郡志賀町中山');
ok($zip->set_number('9250305')->is_valid_number, '石川県羽咋郡志賀町豊後名');
ok($zip->set_number('9250306')->is_valid_number, '石川県羽咋郡志賀町草木');
ok($zip->set_number('9250307')->is_valid_number, '石川県羽咋郡志賀町荒屋');
ok($zip->set_number('9250311')->is_valid_number, '石川県羽咋郡志賀町谷神');
ok($zip->set_number('9250312')->is_valid_number, '石川県羽咋郡志賀町六実');
ok($zip->set_number('9250313')->is_valid_number, '石川県羽咋郡志賀町三明');
ok($zip->set_number('9250314')->is_valid_number, '石川県羽咋郡志賀町中畠');
ok($zip->set_number('9250315')->is_valid_number, '石川県羽咋郡志賀町福浦港');
ok($zip->set_number('9250345')->is_valid_number, '石川県羽咋郡志賀町富来牛下(巌門)');
ok($zip->set_number('9250371')->is_valid_number, '石川県羽咋郡志賀町釈迦堂');
ok($zip->set_number('9250372')->is_valid_number, '石川県羽咋郡志賀町直海');
ok($zip->set_number('9250373')->is_valid_number, '石川県羽咋郡志賀町小室');
ok($zip->set_number('9250374')->is_valid_number, '石川県羽咋郡志賀町松木');
ok($zip->set_number('9250375')->is_valid_number, '石川県羽咋郡志賀町若葉台');
ok($zip->set_number('9250376')->is_valid_number, '石川県羽咋郡志賀町長田');
ok($zip->set_number('9250381')->is_valid_number, '石川県羽咋郡志賀町田原');
ok($zip->set_number('9250382')->is_valid_number, '石川県羽咋郡志賀町米町');
ok($zip->set_number('9250383')->is_valid_number, '石川県羽咋郡志賀町大笹');
ok($zip->set_number('9250384')->is_valid_number, '石川県羽咋郡志賀町五里峠');
ok($zip->set_number('9250385')->is_valid_number, '石川県羽咋郡志賀町牛ケ首');
ok($zip->set_number('9250421')->is_valid_number, '石川県羽咋郡志賀町切留');
ok($zip->set_number('9250422')->is_valid_number, '石川県羽咋郡志賀町地保');
ok($zip->set_number('9250423')->is_valid_number, '石川県羽咋郡志賀町鵜野屋');
ok($zip->set_number('9250424')->is_valid_number, '石川県羽咋郡志賀町入釜');
ok($zip->set_number('9250425')->is_valid_number, '石川県羽咋郡志賀町灯');
ok($zip->set_number('9250426')->is_valid_number, '石川県羽咋郡志賀町阿川');
ok($zip->set_number('9250427')->is_valid_number, '石川県羽咋郡志賀町楚和');
ok($zip->set_number('9250431')->is_valid_number, '石川県羽咋郡志賀町尊保');
ok($zip->set_number('9250432')->is_valid_number, '石川県羽咋郡志賀町今田');
ok($zip->set_number('9250433')->is_valid_number, '石川県羽咋郡志賀町和田');
ok($zip->set_number('9250434')->is_valid_number, '石川県羽咋郡志賀町大西');
ok($zip->set_number('9250435')->is_valid_number, '石川県羽咋郡志賀町江添');
ok($zip->set_number('9250436')->is_valid_number, '石川県羽咋郡志賀町貝田');
ok($zip->set_number('9250437')->is_valid_number, '石川県羽咋郡志賀町田中');
ok($zip->set_number('9250438')->is_valid_number, '石川県羽咋郡志賀町八千代');
ok($zip->set_number('9250441')->is_valid_number, '石川県羽咋郡志賀町広地');
ok($zip->set_number('9250442')->is_valid_number, '石川県羽咋郡志賀町東小室');
ok($zip->set_number('9250443')->is_valid_number, '石川県羽咋郡志賀町富来七海');
ok($zip->set_number('9250444')->is_valid_number, '石川県羽咋郡志賀町富来生神');
ok($zip->set_number('9250445')->is_valid_number, '石川県羽咋郡志賀町富来牛下(その他)');
ok($zip->set_number('9250446')->is_valid_number, '石川県羽咋郡志賀町富来地頭町');
ok($zip->set_number('9250447')->is_valid_number, '石川県羽咋郡志賀町富来領家町');
ok($zip->set_number('9250448')->is_valid_number, '石川県羽咋郡志賀町富来高田');
ok($zip->set_number('9250451')->is_valid_number, '石川県羽咋郡志賀町八幡');
ok($zip->set_number('9250452')->is_valid_number, '石川県羽咋郡志賀町中泉');
ok($zip->set_number('9250452')->is_valid_number, '石川県羽咋郡志賀町八幡座主');
ok($zip->set_number('9250453')->is_valid_number, '石川県羽咋郡志賀町里本江');
ok($zip->set_number('9250454')->is_valid_number, '石川県羽咋郡志賀町相神');
ok($zip->set_number('9250455')->is_valid_number, '石川県羽咋郡志賀町中浜');
ok($zip->set_number('9250456')->is_valid_number, '石川県羽咋郡志賀町草江');
ok($zip->set_number('9250457')->is_valid_number, '石川県羽咋郡志賀町給分');
ok($zip->set_number('9250561')->is_valid_number, '石川県羽咋郡志賀町大福寺');
ok($zip->set_number('9250562')->is_valid_number, '石川県羽咋郡志賀町栢木');
ok($zip->set_number('9250563')->is_valid_number, '石川県羽咋郡志賀町稲敷');
ok($zip->set_number('9250564')->is_valid_number, '石川県羽咋郡志賀町酒見');
ok($zip->set_number('9250565')->is_valid_number, '石川県羽咋郡志賀町香能');
ok($zip->set_number('9250566')->is_valid_number, '石川県羽咋郡志賀町西海風戸');
ok($zip->set_number('9250571')->is_valid_number, '石川県羽咋郡志賀町西海風無');
ok($zip->set_number('9250572')->is_valid_number, '石川県羽咋郡志賀町西海千ノ浦');
ok($zip->set_number('9250573')->is_valid_number, '石川県羽咋郡志賀町西海久喜');
ok($zip->set_number('9250574')->is_valid_number, '石川県羽咋郡志賀町赤崎');
ok($zip->set_number('9250575')->is_valid_number, '石川県羽咋郡志賀町小窪');
ok($zip->set_number('9250576')->is_valid_number, '石川県羽咋郡志賀町鹿頭');
ok($zip->set_number('9250577')->is_valid_number, '石川県羽咋郡志賀町笹波');
ok($zip->set_number('9250578')->is_valid_number, '石川県羽咋郡志賀町前浜');
ok($zip->set_number('9250601')->is_valid_number, '石川県羽咋市菅池町');
ok($zip->set_number('9250602')->is_valid_number, '石川県羽咋市千石町');
ok($zip->set_number('9250603')->is_valid_number, '石川県羽咋市福水町');
ok($zip->set_number('9250604')->is_valid_number, '石川県羽咋市白石町');
ok($zip->set_number('9250605')->is_valid_number, '石川県羽咋市宇土野町');
ok($zip->set_number('9250606')->is_valid_number, '石川県羽咋市白瀬町');
ok($zip->set_number('9250607')->is_valid_number, '石川県羽咋市上白瀬町');
ok($zip->set_number('9250608')->is_valid_number, '石川県羽咋市神子原町');
ok($zip->set_number('9250611')->is_valid_number, '石川県羽咋市上江町');
ok($zip->set_number('9250612')->is_valid_number, '石川県羽咋市垣内田町');
ok($zip->set_number('9250613')->is_valid_number, '石川県羽咋市飯山町');
ok($zip->set_number('9250614')->is_valid_number, '石川県羽咋市中川町');
ok($zip->set_number('9250615')->is_valid_number, '石川県羽咋市千代町');
ok($zip->set_number('9250616')->is_valid_number, '石川県羽咋市四町');
ok($zip->set_number('9250617')->is_valid_number, '石川県羽咋市円井町');
ok($zip->set_number('9250621')->is_valid_number, '石川県羽咋市菱分町');
ok($zip->set_number('9250622')->is_valid_number, '石川県羽咋市堀替新町');
ok($zip->set_number('9250623')->is_valid_number, '石川県羽咋市本江町');
ok($zip->set_number('9250624')->is_valid_number, '石川県羽咋市志々見町');
ok($zip->set_number('9250625')->is_valid_number, '石川県羽咋市尾長町');
ok($zip->set_number('9250626')->is_valid_number, '石川県羽咋市千田町');
ok($zip->set_number('9260000')->is_valid_number, '石川県七尾市以下に掲載がない場合');
ok($zip->set_number('9260001')->is_valid_number, '石川県七尾市鵜浦町');
ok($zip->set_number('9260002')->is_valid_number, '石川県七尾市湯川町');
ok($zip->set_number('9260003')->is_valid_number, '石川県七尾市沢野町');
ok($zip->set_number('9260004')->is_valid_number, '石川県七尾市殿町');
ok($zip->set_number('9260005')->is_valid_number, '石川県七尾市岡町');
ok($zip->set_number('9260006')->is_valid_number, '石川県七尾市大田新町');
ok($zip->set_number('9260006')->is_valid_number, '石川県七尾市大田町');
ok($zip->set_number('9260007')->is_valid_number, '石川県七尾市三室町');
ok($zip->set_number('9260011')->is_valid_number, '石川県七尾市佐味町');
ok($zip->set_number('9260012')->is_valid_number, '石川県七尾市報国町');
ok($zip->set_number('9260012')->is_valid_number, '石川県七尾市万行町');
ok($zip->set_number('9260013')->is_valid_number, '石川県七尾市佐野町');
ok($zip->set_number('9260014')->is_valid_number, '石川県七尾市緑ケ丘町');
ok($zip->set_number('9260014')->is_valid_number, '石川県七尾市矢田町');
ok($zip->set_number('9260015')->is_valid_number, '石川県七尾市矢田新町');
ok($zip->set_number('9260016')->is_valid_number, '石川県七尾市大和町');
ok($zip->set_number('9260017')->is_valid_number, '石川県七尾市万行');
ok($zip->set_number('9260021')->is_valid_number, '石川県七尾市巴町');
ok($zip->set_number('9260021')->is_valid_number, '石川県七尾市本府中町');
ok($zip->set_number('9260022')->is_valid_number, '石川県七尾市天神川原町');
ok($zip->set_number('9260023')->is_valid_number, '石川県七尾市竹町');
ok($zip->set_number('9260024')->is_valid_number, '石川県七尾市古屋敷町');
ok($zip->set_number('9260025')->is_valid_number, '石川県七尾市古城町');
ok($zip->set_number('9260026')->is_valid_number, '石川県七尾市小池川原町');
ok($zip->set_number('9260027')->is_valid_number, '石川県七尾市後畠町');
ok($zip->set_number('9260028')->is_valid_number, '石川県七尾市藤野町');
ok($zip->set_number('9260031')->is_valid_number, '石川県七尾市古府町');
ok($zip->set_number('9260032')->is_valid_number, '石川県七尾市南ケ丘町');
ok($zip->set_number('9260033')->is_valid_number, '石川県七尾市千野町');
ok($zip->set_number('9260034')->is_valid_number, '石川県七尾市多根町');
ok($zip->set_number('9260035')->is_valid_number, '石川県七尾市八田町');
ok($zip->set_number('9260036')->is_valid_number, '石川県七尾市中挾町');
ok($zip->set_number('9260037')->is_valid_number, '石川県七尾市国下町');
ok($zip->set_number('9260038')->is_valid_number, '石川県七尾市八幡町');
ok($zip->set_number('9260041')->is_valid_number, '石川県七尾市府中町');
ok($zip->set_number('9260042')->is_valid_number, '石川県七尾市作事町');
ok($zip->set_number('9260043')->is_valid_number, '石川県七尾市橘町');
ok($zip->set_number('9260044')->is_valid_number, '石川県七尾市相生町');
ok($zip->set_number('9260045')->is_valid_number, '石川県七尾市袖ケ江町');
ok($zip->set_number('9260046')->is_valid_number, '石川県七尾市神明町');
ok($zip->set_number('9260047')->is_valid_number, '石川県七尾市大手町');
ok($zip->set_number('9260048')->is_valid_number, '石川県七尾市桧物町');
ok($zip->set_number('9260051')->is_valid_number, '石川県七尾市郡町');
ok($zip->set_number('9260052')->is_valid_number, '石川県七尾市山王町');
ok($zip->set_number('9260053')->is_valid_number, '石川県七尾市上府中町');
ok($zip->set_number('9260054')->is_valid_number, '石川県七尾市川原町');
ok($zip->set_number('9260055')->is_valid_number, '石川県七尾市今町');
ok($zip->set_number('9260056')->is_valid_number, '石川県七尾市塗師町');
ok($zip->set_number('9260057')->is_valid_number, '石川県七尾市鍛冶町');
ok($zip->set_number('9260058')->is_valid_number, '石川県七尾市湊町');
ok($zip->set_number('9260171')->is_valid_number, '石川県七尾市石崎町');
ok($zip->set_number('9260172')->is_valid_number, '石川県七尾市石崎町(東)');
ok($zip->set_number('9260173')->is_valid_number, '石川県七尾市石崎町(西)');
ok($zip->set_number('9260174')->is_valid_number, '石川県七尾市奥原町');
ok($zip->set_number('9260175')->is_valid_number, '石川県七尾市和倉町');
ok($zip->set_number('9260176')->is_valid_number, '石川県七尾市和倉町ひばり');
ok($zip->set_number('9260177')->is_valid_number, '石川県七尾市光陽台');
ok($zip->set_number('9260178')->is_valid_number, '石川県七尾市石崎町(香島)');
ok($zip->set_number('9260179')->is_valid_number, '石川県七尾市泉南台');
ok($zip->set_number('9260201')->is_valid_number, '石川県七尾市能登島祖母ケ浦町');
ok($zip->set_number('9260202')->is_valid_number, '石川県七尾市能登島八ケ崎町');
ok($zip->set_number('9260203')->is_valid_number, '石川県七尾市能登島えの目町');
ok($zip->set_number('9260204')->is_valid_number, '石川県七尾市能登島長崎町');
ok($zip->set_number('9260205')->is_valid_number, '石川県七尾市能登島野崎町');
ok($zip->set_number('9260206')->is_valid_number, '石川県七尾市能登島日出ケ島町');
ok($zip->set_number('9260207')->is_valid_number, '石川県七尾市能登島二穴町');
ok($zip->set_number('9260208')->is_valid_number, '石川県七尾市能登島小浦町');
ok($zip->set_number('9260211')->is_valid_number, '石川県七尾市能登島向田町');
ok($zip->set_number('9260212')->is_valid_number, '石川県七尾市能登島佐波町');
ok($zip->set_number('9260213')->is_valid_number, '石川県七尾市能登島須曽町');
ok($zip->set_number('9260214')->is_valid_number, '石川県七尾市能登島別所町');
ok($zip->set_number('9260215')->is_valid_number, '石川県七尾市能登島南町');
ok($zip->set_number('9260216')->is_valid_number, '石川県七尾市能登島曲町');
ok($zip->set_number('9260221')->is_valid_number, '石川県七尾市能登島無関町');
ok($zip->set_number('9260222')->is_valid_number, '石川県七尾市能登島閨町');
ok($zip->set_number('9260223')->is_valid_number, '石川県七尾市能登島半浦町');
ok($zip->set_number('9260224')->is_valid_number, '石川県七尾市能登島百万石町');
ok($zip->set_number('9260225')->is_valid_number, '石川県七尾市能登島通町');
ok($zip->set_number('9260226')->is_valid_number, '石川県七尾市能登島田尻町');
ok($zip->set_number('9260227')->is_valid_number, '石川県七尾市能登島久木町');
ok($zip->set_number('9260361')->is_valid_number, '石川県七尾市江泊町(日室町)');
ok($zip->set_number('9260362')->is_valid_number, '石川県七尾市大野木町');
ok($zip->set_number('9260363')->is_valid_number, '石川県七尾市江泊町');
ok($zip->set_number('9260364')->is_valid_number, '石川県七尾市庵町(白鳥町)');
ok($zip->set_number('9260364')->is_valid_number, '石川県七尾市江泊町(白鳥町)');
ok($zip->set_number('9260365')->is_valid_number, '石川県七尾市庵町(百海町)');
ok($zip->set_number('9260366')->is_valid_number, '石川県七尾市庵町');
ok($zip->set_number('9260367')->is_valid_number, '石川県七尾市庵町(虫崎町)');
ok($zip->set_number('9260371')->is_valid_number, '石川県七尾市佐々波町');
ok($zip->set_number('9260372')->is_valid_number, '石川県七尾市麻生町');
ok($zip->set_number('9260373')->is_valid_number, '石川県七尾市小栗町');
ok($zip->set_number('9260374')->is_valid_number, '石川県七尾市清水平町');
ok($zip->set_number('9260375')->is_valid_number, '石川県七尾市柑子町');
ok($zip->set_number('9260376')->is_valid_number, '石川県七尾市外林町');
ok($zip->set_number('9260381')->is_valid_number, '石川県七尾市黒崎町');
ok($zip->set_number('9260382')->is_valid_number, '石川県七尾市花園町');
ok($zip->set_number('9260383')->is_valid_number, '石川県七尾市東浜町');
ok($zip->set_number('9260384')->is_valid_number, '石川県七尾市大泊町');
ok($zip->set_number('9260385')->is_valid_number, '石川県七尾市山崎町');
ok($zip->set_number('9260386')->is_valid_number, '石川県七尾市山崎町(小川内町)');
ok($zip->set_number('9260387')->is_valid_number, '石川県七尾市熊淵町');
ok($zip->set_number('9260388')->is_valid_number, '石川県七尾市熊淵町(水上町)');
ok($zip->set_number('9260389')->is_valid_number, '石川県七尾市熊淵町(滝の尻町)');
ok($zip->set_number('9260801')->is_valid_number, '石川県七尾市昭和町');
ok($zip->set_number('9260802')->is_valid_number, '石川県七尾市三島町');
ok($zip->set_number('9260803')->is_valid_number, '石川県七尾市米町');
ok($zip->set_number('9260804')->is_valid_number, '石川県七尾市生駒町');
ok($zip->set_number('9260805')->is_valid_number, '石川県七尾市亀山町');
ok($zip->set_number('9260806')->is_valid_number, '石川県七尾市一本杉町');
ok($zip->set_number('9260807')->is_valid_number, '石川県七尾市阿良町');
ok($zip->set_number('9260808')->is_valid_number, '石川県七尾市木町');
ok($zip->set_number('9260811')->is_valid_number, '石川県七尾市御祓町');
ok($zip->set_number('9260812')->is_valid_number, '石川県七尾市北藤橋町');
ok($zip->set_number('9260813')->is_valid_number, '石川県七尾市南藤橋町');
ok($zip->set_number('9260814')->is_valid_number, '石川県七尾市所口町');
ok($zip->set_number('9260815')->is_valid_number, '石川県七尾市栄町');
ok($zip->set_number('9260816')->is_valid_number, '石川県七尾市岩屋町');
ok($zip->set_number('9260816')->is_valid_number, '石川県七尾市藤橋町');
ok($zip->set_number('9260817')->is_valid_number, '石川県七尾市西藤橋町');
ok($zip->set_number('9260818')->is_valid_number, '石川県七尾市馬出町');
ok($zip->set_number('9260821')->is_valid_number, '石川県七尾市国分町');
ok($zip->set_number('9260822')->is_valid_number, '石川県七尾市細口町');
ok($zip->set_number('9260823')->is_valid_number, '石川県七尾市青葉台町');
ok($zip->set_number('9260824')->is_valid_number, '石川県七尾市下町');
ok($zip->set_number('9260824')->is_valid_number, '石川県七尾市徳田町');
ok($zip->set_number('9260825')->is_valid_number, '石川県七尾市江曽町');
ok($zip->set_number('9260826')->is_valid_number, '石川県七尾市飯川町');
ok($zip->set_number('9260827')->is_valid_number, '石川県七尾市若林町');
ok($zip->set_number('9260828')->is_valid_number, '石川県七尾市白馬町');
ok($zip->set_number('9260829')->is_valid_number, '石川県七尾市徳田新町');
ok($zip->set_number('9260831')->is_valid_number, '石川県七尾市青山町');
ok($zip->set_number('9260831')->is_valid_number, '石川県七尾市池崎町');
ok($zip->set_number('9260832')->is_valid_number, '石川県七尾市盤若野町');
ok($zip->set_number('9260833')->is_valid_number, '石川県七尾市旭町');
ok($zip->set_number('9260834')->is_valid_number, '石川県七尾市東三階町');
ok($zip->set_number('9260835')->is_valid_number, '石川県七尾市西三階町');
ok($zip->set_number('9260836')->is_valid_number, '石川県七尾市町屋町');
ok($zip->set_number('9260837')->is_valid_number, '石川県七尾市温井町');
ok($zip->set_number('9260838')->is_valid_number, '石川県七尾市満仁町');
ok($zip->set_number('9260841')->is_valid_number, '石川県七尾市松百町');
ok($zip->set_number('9260842')->is_valid_number, '石川県七尾市松百新町');
ok($zip->set_number('9260843')->is_valid_number, '石川県七尾市赤浦町');
ok($zip->set_number('9260844')->is_valid_number, '石川県七尾市直津町');
ok($zip->set_number('9260845')->is_valid_number, '石川県七尾市新保町');
ok($zip->set_number('9260846')->is_valid_number, '石川県七尾市祖浜町');
ok($zip->set_number('9260851')->is_valid_number, '石川県七尾市つつじが浜');
ok($zip->set_number('9260852')->is_valid_number, '石川県七尾市小島町');
ok($zip->set_number('9260853')->is_valid_number, '石川県七尾市津向町');
ok($zip->set_number('9260854')->is_valid_number, '石川県七尾市なぎの浦');
ok($zip->set_number('9260855')->is_valid_number, '石川県七尾市小丸山台');
ok($zip->set_number('9260861')->is_valid_number, '石川県七尾市寿町');
ok($zip->set_number('9260862')->is_valid_number, '石川県七尾市常盤町');
ok($zip->set_number('9260863')->is_valid_number, '石川県七尾市白銀町');
ok($zip->set_number('9260864')->is_valid_number, '石川県七尾市魚町');
ok($zip->set_number('9260865')->is_valid_number, '石川県七尾市松本町');
ok($zip->set_number('9260866')->is_valid_number, '石川県七尾市富岡町');
ok($zip->set_number('9260867')->is_valid_number, '石川県七尾市桜町');
ok($zip->set_number('9270000')->is_valid_number, '石川県鳳珠郡穴水町以下に掲載がない場合');
ok($zip->set_number('9270001')->is_valid_number, '石川県鳳珠郡穴水町樟谷');
ok($zip->set_number('9270002')->is_valid_number, '石川県鳳珠郡穴水町菅谷');
ok($zip->set_number('9270003')->is_valid_number, '石川県鳳珠郡穴水町伊久留');
ok($zip->set_number('9270004')->is_valid_number, '石川県鳳珠郡穴水町曽山');
ok($zip->set_number('9270005')->is_valid_number, '石川県鳳珠郡穴水町東中谷');
ok($zip->set_number('9270006')->is_valid_number, '石川県鳳珠郡穴水町旭ケ丘');
ok($zip->set_number('9270007')->is_valid_number, '石川県鳳珠郡穴水町岩車');
ok($zip->set_number('9270008')->is_valid_number, '石川県鳳珠郡穴水町川尻');
ok($zip->set_number('9270009')->is_valid_number, '石川県鳳珠郡穴水町比良');
ok($zip->set_number('9270011')->is_valid_number, '石川県鳳珠郡穴水町木原');
ok($zip->set_number('9270012')->is_valid_number, '石川県鳳珠郡穴水町藤巻');
ok($zip->set_number('9270013')->is_valid_number, '石川県鳳珠郡穴水町瑞鳳');
ok($zip->set_number('9270014')->is_valid_number, '石川県鳳珠郡穴水町梶');
ok($zip->set_number('9270015')->is_valid_number, '石川県鳳珠郡穴水町中居');
ok($zip->set_number('9270016')->is_valid_number, '石川県鳳珠郡穴水町中居南');
ok($zip->set_number('9270017')->is_valid_number, '石川県鳳珠郡穴水町波志借');
ok($zip->set_number('9270021')->is_valid_number, '石川県鳳珠郡穴水町七海');
ok($zip->set_number('9270022')->is_valid_number, '石川県鳳珠郡穴水町北七海');
ok($zip->set_number('9270023')->is_valid_number, '石川県鳳珠郡穴水町麦ケ浦');
ok($zip->set_number('9270024')->is_valid_number, '石川県鳳珠郡穴水町由比ケ丘');
ok($zip->set_number('9270025')->is_valid_number, '石川県鳳珠郡穴水町内浦');
ok($zip->set_number('9270026')->is_valid_number, '石川県鳳珠郡穴水町大町');
ok($zip->set_number('9270027')->is_valid_number, '石川県鳳珠郡穴水町川島');
ok($zip->set_number('9270031')->is_valid_number, '石川県鳳珠郡穴水町鵜島');
ok($zip->set_number('9270032')->is_valid_number, '石川県鳳珠郡穴水町乙ケ崎');
ok($zip->set_number('9270033')->is_valid_number, '石川県鳳珠郡穴水町緑ケ丘');
ok($zip->set_number('9270034')->is_valid_number, '石川県鳳珠郡穴水町新崎');
ok($zip->set_number('9270035')->is_valid_number, '石川県鳳珠郡穴水町志ケ浦');
ok($zip->set_number('9270036')->is_valid_number, '石川県鳳珠郡穴水町望洋台');
ok($zip->set_number('9270037')->is_valid_number, '石川県鳳珠郡穴水町根木');
ok($zip->set_number('9270038')->is_valid_number, '石川県鳳珠郡穴水町鹿島');
ok($zip->set_number('9270039')->is_valid_number, '石川県鳳珠郡穴水町曽福');
ok($zip->set_number('9270041')->is_valid_number, '石川県鳳珠郡穴水町天神谷');
ok($zip->set_number('9270042')->is_valid_number, '石川県鳳珠郡穴水町宇留地');
ok($zip->set_number('9270043')->is_valid_number, '石川県鳳珠郡穴水町越の原');
ok($zip->set_number('9270044')->is_valid_number, '石川県鳳珠郡穴水町鹿路');
ok($zip->set_number('9270045')->is_valid_number, '石川県鳳珠郡穴水町河内');
ok($zip->set_number('9270046')->is_valid_number, '石川県鳳珠郡穴水町越渡');
ok($zip->set_number('9270046')->is_valid_number, '石川県鳳珠郡穴水町汁谷');
ok($zip->set_number('9270047')->is_valid_number, '石川県鳳珠郡穴水町上中');
ok($zip->set_number('9270048')->is_valid_number, '石川県鳳珠郡穴水町大角間');
ok($zip->set_number('9270049')->is_valid_number, '石川県鳳珠郡穴水町桂谷');
ok($zip->set_number('9270051')->is_valid_number, '石川県鳳珠郡穴水町小又');
ok($zip->set_number('9270052')->is_valid_number, '石川県鳳珠郡穴水町平野');
ok($zip->set_number('9270053')->is_valid_number, '石川県鳳珠郡穴水町此木');
ok($zip->set_number('9270054')->is_valid_number, '石川県鳳珠郡穴水町上野');
ok($zip->set_number('9270055')->is_valid_number, '石川県鳳珠郡穴水町地蔵坊');
ok($zip->set_number('9270056')->is_valid_number, '石川県鳳珠郡穴水町上唐川');
ok($zip->set_number('9270057')->is_valid_number, '石川県鳳珠郡穴水町下唐川');
ok($zip->set_number('9270058')->is_valid_number, '石川県鳳珠郡穴水町挾石');
ok($zip->set_number('9270201')->is_valid_number, '石川県鳳珠郡穴水町竹太');
ok($zip->set_number('9270202')->is_valid_number, '石川県鳳珠郡穴水町古君');
ok($zip->set_number('9270203')->is_valid_number, '石川県鳳珠郡穴水町花園');
ok($zip->set_number('9270204')->is_valid_number, '石川県鳳珠郡穴水町明千寺');
ok($zip->set_number('9270205')->is_valid_number, '石川県鳳珠郡穴水町宇加川');
ok($zip->set_number('9270206')->is_valid_number, '石川県鳳珠郡穴水町前波');
ok($zip->set_number('9270207')->is_valid_number, '石川県鳳珠郡穴水町沖波');
ok($zip->set_number('9270211')->is_valid_number, '石川県鳳珠郡穴水町甲');
ok($zip->set_number('9270212')->is_valid_number, '石川県鳳珠郡穴水町黒崎');
ok($zip->set_number('9270213')->is_valid_number, '石川県鳳珠郡穴水町至誠');
ok($zip->set_number('9270214')->is_valid_number, '石川県鳳珠郡穴水町小甲');
ok($zip->set_number('9270215')->is_valid_number, '石川県鳳珠郡穴水町大甲');
ok($zip->set_number('9270221')->is_valid_number, '石川県鳳珠郡穴水町曽良');
ok($zip->set_number('9270222')->is_valid_number, '石川県鳳珠郡穴水町大郷');
ok($zip->set_number('9270223')->is_valid_number, '石川県鳳珠郡穴水町鹿波');
ok($zip->set_number('9270224')->is_valid_number, '石川県鳳珠郡穴水町鹿上');
ok($zip->set_number('9270225')->is_valid_number, '石川県鳳珠郡穴水町野並');
ok($zip->set_number('9270231')->is_valid_number, '石川県鳳珠郡穴水町山中');
ok($zip->set_number('9270232')->is_valid_number, '石川県鳳珠郡穴水町東山');
ok($zip->set_number('9270233')->is_valid_number, '石川県鳳珠郡穴水町女良川');
ok($zip->set_number('9270234')->is_valid_number, '石川県鳳珠郡穴水町小又(山中)');
ok($zip->set_number('9270235')->is_valid_number, '石川県鳳珠郡穴水町市ノ坂');
ok($zip->set_number('9270301')->is_valid_number, '石川県鳳珠郡能登町七見');
ok($zip->set_number('9270302')->is_valid_number, '石川県鳳珠郡能登町鵜川');
ok($zip->set_number('9270303')->is_valid_number, '石川県鳳珠郡能登町小垣');
ok($zip->set_number('9270304')->is_valid_number, '石川県鳳珠郡能登町柿生');
ok($zip->set_number('9270305')->is_valid_number, '石川県鳳珠郡能登町武連');
ok($zip->set_number('9270311')->is_valid_number, '石川県鳳珠郡能登町瑞穂');
ok($zip->set_number('9270312')->is_valid_number, '石川県鳳珠郡能登町本木');
ok($zip->set_number('9270313')->is_valid_number, '石川県鳳珠郡能登町木住');
ok($zip->set_number('9270314')->is_valid_number, '石川県鳳珠郡能登町山田');
ok($zip->set_number('9270315')->is_valid_number, '石川県鳳珠郡能登町豊ケ丘');
ok($zip->set_number('9270321')->is_valid_number, '石川県鳳珠郡能登町爼倉');
ok($zip->set_number('9270322')->is_valid_number, '石川県鳳珠郡能登町宮地');
ok($zip->set_number('9270323')->is_valid_number, '石川県鳳珠郡能登町鮭尾');
ok($zip->set_number('9270324')->is_valid_number, '石川県鳳珠郡能登町柏木');
ok($zip->set_number('9270325')->is_valid_number, '石川県鳳珠郡能登町太田原');
ok($zip->set_number('9270400')->is_valid_number, '石川県鳳珠郡能登町以下に掲載がない場合');
ok($zip->set_number('9270431')->is_valid_number, '石川県鳳珠郡能登町宇出津山分');
ok($zip->set_number('9270432')->is_valid_number, '石川県鳳珠郡能登町宇出津新');
ok($zip->set_number('9270433')->is_valid_number, '石川県鳳珠郡能登町宇出津');
ok($zip->set_number('9270434')->is_valid_number, '石川県鳳珠郡能登町崎山');
ok($zip->set_number('9270435')->is_valid_number, '石川県鳳珠郡能登町宇出津新港');
ok($zip->set_number('9270441')->is_valid_number, '石川県鳳珠郡能登町藤波');
ok($zip->set_number('9270442')->is_valid_number, '石川県鳳珠郡能登町波並');
ok($zip->set_number('9270443')->is_valid_number, '石川県鳳珠郡能登町矢波');
ok($zip->set_number('9270444')->is_valid_number, '石川県鳳珠郡能登町猪平');
ok($zip->set_number('9270451')->is_valid_number, '石川県鳳珠郡能登町藤ノ瀬');
ok($zip->set_number('9270452')->is_valid_number, '石川県鳳珠郡能登町宇加塚');
ok($zip->set_number('9270453')->is_valid_number, '石川県鳳珠郡能登町鶴町');
ok($zip->set_number('9270454')->is_valid_number, '石川県鳳珠郡能登町曽又');
ok($zip->set_number('9270551')->is_valid_number, '石川県鳳珠郡能登町明野');
ok($zip->set_number('9270552')->is_valid_number, '石川県鳳珠郡能登町越坂');
ok($zip->set_number('9270553')->is_valid_number, '石川県鳳珠郡能登町小木');
ok($zip->set_number('9270554')->is_valid_number, '石川県鳳珠郡能登町市之瀬');
ok($zip->set_number('9270555')->is_valid_number, '石川県鳳珠郡能登町羽生(ろ)');
ok($zip->set_number('9270561')->is_valid_number, '石川県鳳珠郡能登町羽生(い)');
ok($zip->set_number('9270562')->is_valid_number, '石川県鳳珠郡能登町真脇');
ok($zip->set_number('9270563')->is_valid_number, '石川県鳳珠郡能登町姫');
ok($zip->set_number('9270564')->is_valid_number, '石川県鳳珠郡能登町小浦');
ok($zip->set_number('9270565')->is_valid_number, '石川県鳳珠郡能登町羽根');
ok($zip->set_number('9270601')->is_valid_number, '石川県鳳珠郡能登町恋路');
ok($zip->set_number('9270602')->is_valid_number, '石川県鳳珠郡能登町松波');
ok($zip->set_number('9270602')->is_valid_number, '石川県鳳珠郡能登町明生');
ok($zip->set_number('9270603')->is_valid_number, '石川県鳳珠郡能登町布浦');
ok($zip->set_number('9270604')->is_valid_number, '石川県鳳珠郡能登町九里川尻');
ok($zip->set_number('9270605')->is_valid_number, '石川県鳳珠郡能登町立壁');
ok($zip->set_number('9270606')->is_valid_number, '石川県鳳珠郡能登町四方山');
ok($zip->set_number('9270607')->is_valid_number, '石川県鳳珠郡能登町白丸');
ok($zip->set_number('9270608')->is_valid_number, '石川県鳳珠郡能登町内浦長尾');
ok($zip->set_number('9270609')->is_valid_number, '石川県鳳珠郡能登町新保');
ok($zip->set_number('9270611')->is_valid_number, '石川県鳳珠郡能登町清真');
ok($zip->set_number('9270612')->is_valid_number, '石川県鳳珠郡能登町秋吉');
ok($zip->set_number('9270613')->is_valid_number, '石川県鳳珠郡能登町河ケ谷');
ok($zip->set_number('9270614')->is_valid_number, '石川県鳳珠郡能登町満泉寺');
ok($zip->set_number('9270614')->is_valid_number, '石川県鳳珠郡能登町山中');
ok($zip->set_number('9270615')->is_valid_number, '石川県鳳珠郡能登町宮犬');
ok($zip->set_number('9270621')->is_valid_number, '石川県鳳珠郡能登町上');
ok($zip->set_number('9270622')->is_valid_number, '石川県鳳珠郡能登町不動寺');
ok($zip->set_number('9270623')->is_valid_number, '石川県鳳珠郡能登町行延');
ok($zip->set_number('9270624')->is_valid_number, '石川県鳳珠郡能登町時長');
ok($zip->set_number('9270625')->is_valid_number, '石川県鳳珠郡能登町国重');
ok($zip->set_number('9270626')->is_valid_number, '石川県鳳珠郡能登町泉');
ok($zip->set_number('9270626')->is_valid_number, '石川県鳳珠郡能登町駒渡');
ok($zip->set_number('9270626')->is_valid_number, '石川県鳳珠郡能登町田代');
ok($zip->set_number('9270627')->is_valid_number, '石川県鳳珠郡能登町滝之坊');
ok($zip->set_number('9270627')->is_valid_number, '石川県鳳珠郡能登町福光');
ok($zip->set_number('9271200')->is_valid_number, '石川県珠洲市以下に掲載がない場合');
ok($zip->set_number('9271201')->is_valid_number, '石川県珠洲市正院町岡田');
ok($zip->set_number('9271202')->is_valid_number, '石川県珠洲市正院町飯塚');
ok($zip->set_number('9271203')->is_valid_number, '石川県珠洲市正院町平床');
ok($zip->set_number('9271204')->is_valid_number, '石川県珠洲市蛸島町');
ok($zip->set_number('9271205')->is_valid_number, '石川県珠洲市正院町川尻');
ok($zip->set_number('9271206')->is_valid_number, '石川県珠洲市正院町正院');
ok($zip->set_number('9271207')->is_valid_number, '石川県珠洲市正院町小路');
ok($zip->set_number('9271211')->is_valid_number, '石川県珠洲市岩坂町');
ok($zip->set_number('9271212')->is_valid_number, '石川県珠洲市熊谷町');
ok($zip->set_number('9271213')->is_valid_number, '石川県珠洲市野々江町');
ok($zip->set_number('9271214')->is_valid_number, '石川県珠洲市飯田町');
ok($zip->set_number('9271215')->is_valid_number, '石川県珠洲市上戸町北方');
ok($zip->set_number('9271216')->is_valid_number, '石川県珠洲市上戸町寺社');
ok($zip->set_number('9271217')->is_valid_number, '石川県珠洲市上戸町南方');
ok($zip->set_number('9271221')->is_valid_number, '石川県珠洲市宝立町春日野');
ok($zip->set_number('9271221')->is_valid_number, '石川県珠洲市宝立町金峰寺');
ok($zip->set_number('9271222')->is_valid_number, '石川県珠洲市宝立町鵜飼');
ok($zip->set_number('9271223')->is_valid_number, '石川県珠洲市宝立町鵜島');
ok($zip->set_number('9271224')->is_valid_number, '石川県珠洲市宝立町南黒丸');
ok($zip->set_number('9271225')->is_valid_number, '石川県珠洲市宝立町宗玄');
ok($zip->set_number('9271226')->is_valid_number, '石川県珠洲市宝立町馬渡');
ok($zip->set_number('9271227')->is_valid_number, '石川県珠洲市宝立町大町泥木');
ok($zip->set_number('9271227')->is_valid_number, '石川県珠洲市宝立町二艘丹');
ok($zip->set_number('9271228')->is_valid_number, '石川県珠洲市宝立町柏原');
ok($zip->set_number('9271228')->is_valid_number, '石川県珠洲市宝立町黒峰');
ok($zip->set_number('9271231')->is_valid_number, '石川県珠洲市若山町鈴内');
ok($zip->set_number('9271232')->is_valid_number, '石川県珠洲市若山町広栗');
ok($zip->set_number('9271233')->is_valid_number, '石川県珠洲市若山町出田');
ok($zip->set_number('9271234')->is_valid_number, '石川県珠洲市若山町経念');
ok($zip->set_number('9271235')->is_valid_number, '石川県珠洲市若山町中田');
ok($zip->set_number('9271235')->is_valid_number, '石川県珠洲市若山町向');
ok($zip->set_number('9271236')->is_valid_number, '石川県珠洲市若山町中');
ok($zip->set_number('9271237')->is_valid_number, '石川県珠洲市若山町宇都山');
ok($zip->set_number('9271237')->is_valid_number, '石川県珠洲市若山町大坊');
ok($zip->set_number('9271238')->is_valid_number, '石川県珠洲市若山町延武');
ok($zip->set_number('9271238')->is_valid_number, '石川県珠洲市若山町火宮');
ok($zip->set_number('9271239')->is_valid_number, '石川県珠洲市若山町古蔵');
ok($zip->set_number('9271301')->is_valid_number, '石川県珠洲市高屋町');
ok($zip->set_number('9271302')->is_valid_number, '石川県珠洲市笹波町');
ok($zip->set_number('9271303')->is_valid_number, '石川県珠洲市石神町');
ok($zip->set_number('9271304')->is_valid_number, '石川県珠洲市馬緤町');
ok($zip->set_number('9271311')->is_valid_number, '石川県珠洲市若山町上正力');
ok($zip->set_number('9271312')->is_valid_number, '石川県珠洲市若山町二子');
ok($zip->set_number('9271313')->is_valid_number, '石川県珠洲市若山町宗末');
ok($zip->set_number('9271314')->is_valid_number, '石川県珠洲市若山町上黒丸');
ok($zip->set_number('9271315')->is_valid_number, '石川県珠洲市若山町白滝');
ok($zip->set_number('9271315')->is_valid_number, '石川県珠洲市若山町南山');
ok($zip->set_number('9271316')->is_valid_number, '石川県珠洲市若山町洲巻');
ok($zip->set_number('9271317')->is_valid_number, '石川県珠洲市若山町上山');
ok($zip->set_number('9271318')->is_valid_number, '石川県珠洲市若山町北山');
ok($zip->set_number('9271319')->is_valid_number, '石川県珠洲市若山町吉ケ池');
ok($zip->set_number('9271321')->is_valid_number, '石川県珠洲市大谷町');
ok($zip->set_number('9271322')->is_valid_number, '石川県珠洲市長橋町');
ok($zip->set_number('9271323')->is_valid_number, '石川県珠洲市片岩町');
ok($zip->set_number('9271324')->is_valid_number, '石川県珠洲市清水町');
ok($zip->set_number('9271325')->is_valid_number, '石川県珠洲市仁江町');
ok($zip->set_number('9271326')->is_valid_number, '石川県珠洲市真浦町');
ok($zip->set_number('9271441')->is_valid_number, '石川県珠洲市狼煙町');
ok($zip->set_number('9271442')->is_valid_number, '石川県珠洲市狼煙新町');
ok($zip->set_number('9271443')->is_valid_number, '石川県珠洲市東山中町');
ok($zip->set_number('9271444')->is_valid_number, '石川県珠洲市唐笠町八ケ山');
ok($zip->set_number('9271445')->is_valid_number, '石川県珠洲市唐笠町');
ok($zip->set_number('9271446')->is_valid_number, '石川県珠洲市折戸町');
ok($zip->set_number('9271447')->is_valid_number, '石川県珠洲市川浦町');
ok($zip->set_number('9271451')->is_valid_number, '石川県珠洲市三崎町寺家');
ok($zip->set_number('9271452')->is_valid_number, '石川県珠洲市三崎町粟津');
ok($zip->set_number('9271453')->is_valid_number, '石川県珠洲市三崎町森腰');
ok($zip->set_number('9271454')->is_valid_number, '石川県珠洲市三崎町宇治');
ok($zip->set_number('9271455')->is_valid_number, '石川県珠洲市三崎町引砂');
ok($zip->set_number('9271456')->is_valid_number, '石川県珠洲市三崎町高波');
ok($zip->set_number('9271457')->is_valid_number, '石川県珠洲市三崎町大屋');
ok($zip->set_number('9271461')->is_valid_number, '石川県珠洲市三崎町伏見');
ok($zip->set_number('9271462')->is_valid_number, '石川県珠洲市三崎町小泊');
ok($zip->set_number('9271463')->is_valid_number, '石川県珠洲市三崎町雲津');
ok($zip->set_number('9271464')->is_valid_number, '石川県珠洲市三崎町細屋');
ok($zip->set_number('9271465')->is_valid_number, '石川県珠洲市三崎町二本松');
ok($zip->set_number('9271466')->is_valid_number, '石川県珠洲市三崎町杉山');
ok($zip->set_number('9271467')->is_valid_number, '石川県珠洲市三崎町本');
ok($zip->set_number('9271468')->is_valid_number, '石川県珠洲市三崎町内方');
ok($zip->set_number('9272101')->is_valid_number, '石川県輪島市門前町西円山');
ok($zip->set_number('9272102')->is_valid_number, '石川県輪島市門前町浦上');
ok($zip->set_number('9272102')->is_valid_number, '石川県輪島市門前町八幡');
ok($zip->set_number('9272103')->is_valid_number, '石川県輪島市門前町宮古場');
ok($zip->set_number('9272104')->is_valid_number, '石川県輪島市門前町山辺');
ok($zip->set_number('9272105')->is_valid_number, '石川県輪島市門前町田村');
ok($zip->set_number('9272106')->is_valid_number, '石川県輪島市門前町浅生田');
ok($zip->set_number('9272107')->is_valid_number, '石川県輪島市門前町安代原');
ok($zip->set_number('9272108')->is_valid_number, '石川県輪島市門前町中野屋');
ok($zip->set_number('9272111')->is_valid_number, '石川県輪島市門前町滝上');
ok($zip->set_number('9272112')->is_valid_number, '石川県輪島市門前町四位');
ok($zip->set_number('9272113')->is_valid_number, '石川県輪島市門前町俊兼');
ok($zip->set_number('9272113')->is_valid_number, '石川県輪島市門前町嶺');
ok($zip->set_number('9272114')->is_valid_number, '石川県輪島市門前町谷口');
ok($zip->set_number('9272115')->is_valid_number, '石川県輪島市門前町本内');
ok($zip->set_number('9272121')->is_valid_number, '石川県輪島市門前町貝吹');
ok($zip->set_number('9272122')->is_valid_number, '石川県輪島市門前町原');
ok($zip->set_number('9272123')->is_valid_number, '石川県輪島市門前町荒屋');
ok($zip->set_number('9272124')->is_valid_number, '石川県輪島市門前町東大町');
ok($zip->set_number('9272125')->is_valid_number, '石川県輪島市門前町別所');
ok($zip->set_number('9272126')->is_valid_number, '石川県輪島市門前町能納屋');
ok($zip->set_number('9272127')->is_valid_number, '石川県輪島市門前町二又川');
ok($zip->set_number('9272131')->is_valid_number, '石川県輪島市門前町平');
ok($zip->set_number('9272132')->is_valid_number, '石川県輪島市門前町長井坂');
ok($zip->set_number('9272133')->is_valid_number, '石川県輪島市門前町定広');
ok($zip->set_number('9272134')->is_valid_number, '石川県輪島市門前町地原');
ok($zip->set_number('9272135')->is_valid_number, '石川県輪島市門前町百成');
ok($zip->set_number('9272136')->is_valid_number, '石川県輪島市門前町鑓川');
ok($zip->set_number('9272137')->is_valid_number, '石川県輪島市門前町内保');
ok($zip->set_number('9272138')->is_valid_number, '石川県輪島市門前町堀腰');
ok($zip->set_number('9272141')->is_valid_number, '石川県輪島市門前町小石');
ok($zip->set_number('9272142')->is_valid_number, '石川県輪島市門前町上河内');
ok($zip->set_number('9272143')->is_valid_number, '石川県輪島市門前町風原');
ok($zip->set_number('9272144')->is_valid_number, '石川県輪島市門前町猿橋');
ok($zip->set_number('9272145')->is_valid_number, '石川県輪島市門前町小滝');
ok($zip->set_number('9272146')->is_valid_number, '石川県輪島市門前町西中尾');
ok($zip->set_number('9272147')->is_valid_number, '石川県輪島市門前町鬼屋');
ok($zip->set_number('9272151')->is_valid_number, '石川県輪島市門前町走出');
ok($zip->set_number('9272152')->is_valid_number, '石川県輪島市門前町広瀬');
ok($zip->set_number('9272153')->is_valid_number, '石川県輪島市門前町深田');
ok($zip->set_number('9272154')->is_valid_number, '石川県輪島市門前町栃木');
ok($zip->set_number('9272155')->is_valid_number, '石川県輪島市門前町日野尾');
ok($zip->set_number('9272156')->is_valid_number, '石川県輪島市門前町門前');
ok($zip->set_number('9272161')->is_valid_number, '石川県輪島市門前町六郎木');
ok($zip->set_number('9272162')->is_valid_number, '石川県輪島市門前町勝田');
ok($zip->set_number('9272163')->is_valid_number, '石川県輪島市門前町大生');
ok($zip->set_number('9272164')->is_valid_number, '石川県輪島市門前町道下');
ok($zip->set_number('9272165')->is_valid_number, '石川県輪島市門前町黒島町');
ok($zip->set_number('9272166')->is_valid_number, '石川県輪島市門前町鹿磯');
ok($zip->set_number('9272167')->is_valid_number, '石川県輪島市門前町深見');
ok($zip->set_number('9272171')->is_valid_number, '石川県輪島市門前町本市');
ok($zip->set_number('9272172')->is_valid_number, '石川県輪島市門前町高根尾');
ok($zip->set_number('9272173')->is_valid_number, '石川県輪島市門前町舘');
ok($zip->set_number('9272174')->is_valid_number, '石川県輪島市門前町広岡');
ok($zip->set_number('9272175')->is_valid_number, '石川県輪島市門前町清水');
ok($zip->set_number('9272176')->is_valid_number, '石川県輪島市門前町和田');
ok($zip->set_number('9272271')->is_valid_number, '石川県輪島市門前町皆月');
ok($zip->set_number('9272272')->is_valid_number, '石川県輪島市門前町樽見');
ok($zip->set_number('9272273')->is_valid_number, '石川県輪島市門前町暮坂');
ok($zip->set_number('9272274')->is_valid_number, '石川県輪島市門前町井守上坂');
ok($zip->set_number('9272275')->is_valid_number, '石川県輪島市門前町薄野');
ok($zip->set_number('9272276')->is_valid_number, '石川県輪島市門前町百成大角間');
ok($zip->set_number('9272277')->is_valid_number, '石川県輪島市門前町餅田');
ok($zip->set_number('9272281')->is_valid_number, '石川県輪島市門前町鵜山');
ok($zip->set_number('9272282')->is_valid_number, '石川県輪島市門前町大滝');
ok($zip->set_number('9272283')->is_valid_number, '石川県輪島市門前町中谷内');
ok($zip->set_number('9272284')->is_valid_number, '石川県輪島市門前町矢徳');
ok($zip->set_number('9272285')->is_valid_number, '石川県輪島市門前町吉浦');
ok($zip->set_number('9272286')->is_valid_number, '石川県輪島市門前町五十洲');
ok($zip->set_number('9272301')->is_valid_number, '石川県輪島市門前町二又');
ok($zip->set_number('9272302')->is_valid_number, '石川県輪島市門前町山是清');
ok($zip->set_number('9272303')->is_valid_number, '石川県輪島市門前町江崎');
ok($zip->set_number('9272304')->is_valid_number, '石川県輪島市門前町白禿');
ok($zip->set_number('9272305')->is_valid_number, '石川県輪島市門前町大切');
ok($zip->set_number('9272311')->is_valid_number, '石川県輪島市門前町切狭');
ok($zip->set_number('9272312')->is_valid_number, '石川県輪島市門前町西中谷');
ok($zip->set_number('9272313')->is_valid_number, '石川県輪島市門前町清沢');
ok($zip->set_number('9272314')->is_valid_number, '石川県輪島市門前町飯川谷');
ok($zip->set_number('9272321')->is_valid_number, '石川県輪島市門前町久川');
ok($zip->set_number('9272322')->is_valid_number, '石川県輪島市門前町窕');
ok($zip->set_number('9272323')->is_valid_number, '石川県輪島市門前町神明原');
ok($zip->set_number('9272324')->is_valid_number, '石川県輪島市門前町馬渡');
ok($zip->set_number('9272325')->is_valid_number, '石川県輪島市門前町滝町');
ok($zip->set_number('9272331')->is_valid_number, '石川県輪島市門前町渡瀬');
ok($zip->set_number('9272332')->is_valid_number, '石川県輪島市門前町木原月');
ok($zip->set_number('9272333')->is_valid_number, '石川県輪島市門前町館分');
ok($zip->set_number('9272333')->is_valid_number, '石川県輪島市門前町馬場');
ok($zip->set_number('9272334')->is_valid_number, '石川県輪島市門前町上代');
ok($zip->set_number('9272335')->is_valid_number, '石川県輪島市門前町黒岩');
ok($zip->set_number('9272336')->is_valid_number, '石川県輪島市門前町入山');
ok($zip->set_number('9272341')->is_valid_number, '石川県輪島市門前町大釜');
ok($zip->set_number('9272342')->is_valid_number, '石川県輪島市門前町剱地');
ok($zip->set_number('9272343')->is_valid_number, '石川県輪島市門前町大泊');
ok($zip->set_number('9272344')->is_valid_number, '石川県輪島市門前町腰細');
ok($zip->set_number('9272345')->is_valid_number, '石川県輪島市門前町赤神');
ok($zip->set_number('9272351')->is_valid_number, '石川県輪島市門前町千代');
ok($zip->set_number('9272352')->is_valid_number, '石川県輪島市門前町北川');
ok($zip->set_number('9272353')->is_valid_number, '石川県輪島市門前町是清');
ok($zip->set_number('9272354')->is_valid_number, '石川県輪島市門前町池田');
ok($zip->set_number('9272355')->is_valid_number, '石川県輪島市門前町藤浜');
ok($zip->set_number('9272361')->is_valid_number, '石川県輪島市門前町小山');
ok($zip->set_number('9272362')->is_valid_number, '石川県輪島市門前町椎木');
ok($zip->set_number('9272363')->is_valid_number, '石川県輪島市門前町新町分');
ok($zip->set_number('9272364')->is_valid_number, '石川県輪島市門前町鍛治屋');
ok($zip->set_number('9272365')->is_valid_number, '石川県輪島市門前町南');
ok($zip->set_number('9272366')->is_valid_number, '石川県輪島市門前町中田');
ok($zip->set_number('9280000')->is_valid_number, '石川県輪島市以下に掲載がない場合');
ok($zip->set_number('9280001')->is_valid_number, '石川県輪島市河井町');
ok($zip->set_number('9280002')->is_valid_number, '石川県輪島市久手川町');
ok($zip->set_number('9280003')->is_valid_number, '石川県輪島市塚田町');
ok($zip->set_number('9280004')->is_valid_number, '石川県輪島市稲舟町');
ok($zip->set_number('9280005')->is_valid_number, '石川県輪島市大野町');
ok($zip->set_number('9280006')->is_valid_number, '石川県輪島市惣領町');
ok($zip->set_number('9280007')->is_valid_number, '石川県輪島市深見町');
ok($zip->set_number('9280008')->is_valid_number, '石川県輪島市マリンタウン');
ok($zip->set_number('9280011')->is_valid_number, '石川県輪島市杉平町');
ok($zip->set_number('9280012')->is_valid_number, '石川県輪島市横地町');
ok($zip->set_number('9280013')->is_valid_number, '石川県輪島市石休場町');
ok($zip->set_number('9280014')->is_valid_number, '石川県輪島市山ノ上町');
ok($zip->set_number('9280015')->is_valid_number, '石川県輪島市市ノ瀬町');
ok($zip->set_number('9280016')->is_valid_number, '石川県輪島市熊野町');
ok($zip->set_number('9280021')->is_valid_number, '石川県輪島市二ツ屋町');
ok($zip->set_number('9280022')->is_valid_number, '石川県輪島市宅田町');
ok($zip->set_number('9280023')->is_valid_number, '石川県輪島市気勝平町');
ok($zip->set_number('9280024')->is_valid_number, '石川県輪島市山岸町');
ok($zip->set_number('9280025')->is_valid_number, '石川県輪島市東中尾町');
ok($zip->set_number('9280026')->is_valid_number, '石川県輪島市西脇町');
ok($zip->set_number('9280027')->is_valid_number, '石川県輪島市北谷町');
ok($zip->set_number('9280028')->is_valid_number, '石川県輪島市打越町');
ok($zip->set_number('9280031')->is_valid_number, '石川県輪島市二勢町');
ok($zip->set_number('9280032')->is_valid_number, '石川県輪島市小伊勢町');
ok($zip->set_number('9280033')->is_valid_number, '石川県輪島市稲屋町');
ok($zip->set_number('9280034')->is_valid_number, '石川県輪島市長井町');
ok($zip->set_number('9280035')->is_valid_number, '石川県輪島市別所谷町');
ok($zip->set_number('9280036')->is_valid_number, '石川県輪島市滝又町');
ok($zip->set_number('9280037')->is_valid_number, '石川県輪島市空熊町');
ok($zip->set_number('9280041')->is_valid_number, '石川県輪島市中段町');
ok($zip->set_number('9280042')->is_valid_number, '石川県輪島市山本町');
ok($zip->set_number('9280043')->is_valid_number, '石川県輪島市房田町');
ok($zip->set_number('9280044')->is_valid_number, '石川県輪島市下黒川町');
ok($zip->set_number('9280045')->is_valid_number, '石川県輪島市上黒川町');
ok($zip->set_number('9280046')->is_valid_number, '石川県輪島市二俣町');
ok($zip->set_number('9280047')->is_valid_number, '石川県輪島市繩又町');
ok($zip->set_number('9280051')->is_valid_number, '石川県輪島市小池町');
ok($zip->set_number('9280052')->is_valid_number, '石川県輪島市下山町');
ok($zip->set_number('9280053')->is_valid_number, '石川県輪島市赤崎町');
ok($zip->set_number('9280054')->is_valid_number, '石川県輪島市大沢町');
ok($zip->set_number('9280055')->is_valid_number, '石川県輪島市上大沢町');
ok($zip->set_number('9280056')->is_valid_number, '石川県輪島市西二又町');
ok($zip->set_number('9280057')->is_valid_number, '石川県輪島市上山町');
ok($zip->set_number('9280061')->is_valid_number, '石川県輪島市新橋通');
ok($zip->set_number('9280062')->is_valid_number, '石川県輪島市堀町');
ok($zip->set_number('9280062')->is_valid_number, '石川県輪島市南町');
ok($zip->set_number('9280063')->is_valid_number, '石川県輪島市水守町');
ok($zip->set_number('9280064')->is_valid_number, '石川県輪島市釜屋谷町');
ok($zip->set_number('9280065')->is_valid_number, '石川県輪島市鵜入町');
ok($zip->set_number('9280066')->is_valid_number, '石川県輪島市美谷町');
ok($zip->set_number('9280067')->is_valid_number, '石川県輪島市光浦町');
ok($zip->set_number('9280068')->is_valid_number, '石川県輪島市平成町');
ok($zip->set_number('9280071')->is_valid_number, '石川県輪島市輪島崎町');
ok($zip->set_number('9280072')->is_valid_number, '石川県輪島市海士町');
ok($zip->set_number('9280072')->is_valid_number, '石川県輪島市海士町(舳倉島)');
ok($zip->set_number('9280073')->is_valid_number, '石川県輪島市鳳至町');
ok($zip->set_number('9280073')->is_valid_number, '石川県輪島市鳳至町(袖ケ浜)');
ok($zip->set_number('9280074')->is_valid_number, '石川県輪島市鳳至町(鳳至丁)');
ok($zip->set_number('9280075')->is_valid_number, '石川県輪島市鳳至町(下町)');
ok($zip->set_number('9280076')->is_valid_number, '石川県輪島市鳳至町(石浦町)');
ok($zip->set_number('9280077')->is_valid_number, '石川県輪島市鳳至町(上町)');
ok($zip->set_number('9280077')->is_valid_number, '石川県輪島市鳳至町(堂金田)');
ok($zip->set_number('9280078')->is_valid_number, '石川県輪島市鳳至町(稲荷町)');
ok($zip->set_number('9280079')->is_valid_number, '石川県輪島市鳳至町(畠田)');
ok($zip->set_number('9280201')->is_valid_number, '石川県輪島市町野町広江');
ok($zip->set_number('9280202')->is_valid_number, '石川県輪島市町野町寺地');
ok($zip->set_number('9280203')->is_valid_number, '石川県輪島市町野町敷戸');
ok($zip->set_number('9280204')->is_valid_number, '石川県輪島市町野町南時国');
ok($zip->set_number('9280205')->is_valid_number, '石川県輪島市町野町西時国');
ok($zip->set_number('9280206')->is_valid_number, '石川県輪島市町野町曽々木');
ok($zip->set_number('9280211')->is_valid_number, '石川県輪島市町野町牛尾');
ok($zip->set_number('9280212')->is_valid_number, '石川県輪島市町野町寺山');
ok($zip->set_number('9280213')->is_valid_number, '石川県輪島市町野町舞谷');
ok($zip->set_number('9280214')->is_valid_number, '石川県輪島市町野町佐野');
ok($zip->set_number('9280215')->is_valid_number, '石川県輪島市町野町粟蔵');
ok($zip->set_number('9280216')->is_valid_number, '石川県輪島市町野町桶戸');
ok($zip->set_number('9280217')->is_valid_number, '石川県輪島市町野町井面');
ok($zip->set_number('9280218')->is_valid_number, '石川県輪島市町野町鈴屋');
ok($zip->set_number('9280221')->is_valid_number, '石川県輪島市町野町真久');
ok($zip->set_number('9280222')->is_valid_number, '石川県輪島市町野町東');
ok($zip->set_number('9280223')->is_valid_number, '石川県輪島市町野町北円山');
ok($zip->set_number('9280224')->is_valid_number, '石川県輪島市町野町麦生野');
ok($zip->set_number('9280225')->is_valid_number, '石川県輪島市町野町徳成谷内');
ok($zip->set_number('9280226')->is_valid_number, '石川県輪島市町野町徳成');
ok($zip->set_number('9280231')->is_valid_number, '石川県輪島市町野町大川');
ok($zip->set_number('9280232')->is_valid_number, '石川県輪島市町野町伏戸');
ok($zip->set_number('9280233')->is_valid_number, '石川県輪島市町野町東大野');
ok($zip->set_number('9280234')->is_valid_number, '石川県輪島市町野町真喜野');
ok($zip->set_number('9280235')->is_valid_number, '石川県輪島市町野町川西');
ok($zip->set_number('9280236')->is_valid_number, '石川県輪島市町野町金蔵');
ok($zip->set_number('9280241')->is_valid_number, '石川県輪島市渋田町');
ok($zip->set_number('9280242')->is_valid_number, '石川県輪島市東印内町');
ok($zip->set_number('9280243')->is_valid_number, '石川県輪島市西山町');
ok($zip->set_number('9280244')->is_valid_number, '石川県輪島市西院内町');
ok($zip->set_number('9280245')->is_valid_number, '石川県輪島市東山町');
ok($zip->set_number('9280246')->is_valid_number, '石川県輪島市里町');
ok($zip->set_number('9280251')->is_valid_number, '石川県輪島市小田屋町');
ok($zip->set_number('9280252')->is_valid_number, '石川県輪島市忍町');
ok($zip->set_number('9280253')->is_valid_number, '石川県輪島市尊利地町');
ok($zip->set_number('9280254')->is_valid_number, '石川県輪島市名舟町');
ok($zip->set_number('9280255')->is_valid_number, '石川県輪島市野田町');
ok($zip->set_number('9280256')->is_valid_number, '石川県輪島市白米町');
ok($zip->set_number('9280301')->is_valid_number, '石川県鳳珠郡能登町上長尾');
ok($zip->set_number('9280302')->is_valid_number, '石川県鳳珠郡能登町小間生');
ok($zip->set_number('9280303')->is_valid_number, '石川県鳳珠郡能登町桐畑');
ok($zip->set_number('9280304')->is_valid_number, '石川県鳳珠郡能登町鈴ケ嶺');
ok($zip->set_number('9280305')->is_valid_number, '石川県鳳珠郡能登町久田');
ok($zip->set_number('9280306')->is_valid_number, '石川県鳳珠郡能登町石井');
ok($zip->set_number('9280307')->is_valid_number, '石川県鳳珠郡能登町国光');
ok($zip->set_number('9280308')->is_valid_number, '石川県鳳珠郡能登町鴨川');
ok($zip->set_number('9280311')->is_valid_number, '石川県鳳珠郡能登町合鹿');
ok($zip->set_number('9280312')->is_valid_number, '石川県鳳珠郡能登町上町');
ok($zip->set_number('9280313')->is_valid_number, '石川県鳳珠郡能登町天坂');
ok($zip->set_number('9280314')->is_valid_number, '石川県鳳珠郡能登町笹川');
ok($zip->set_number('9280321')->is_valid_number, '石川県鳳珠郡能登町十郎原');
ok($zip->set_number('9280322')->is_valid_number, '石川県鳳珠郡能登町寺分');
ok($zip->set_number('9280323')->is_valid_number, '石川県鳳珠郡能登町五郎左エ門分');
ok($zip->set_number('9280324')->is_valid_number, '石川県鳳珠郡能登町中斉');
ok($zip->set_number('9280325')->is_valid_number, '石川県鳳珠郡能登町神和住');
ok($zip->set_number('9280326')->is_valid_number, '石川県鳳珠郡能登町斉和');
ok($zip->set_number('9280331')->is_valid_number, '石川県鳳珠郡能登町柳田');
ok($zip->set_number('9280332')->is_valid_number, '石川県鳳珠郡能登町五十里');
ok($zip->set_number('9280333')->is_valid_number, '石川県鳳珠郡能登町黒川');
ok($zip->set_number('9280334')->is_valid_number, '石川県鳳珠郡能登町当目');
ok($zip->set_number('9280335')->is_valid_number, '石川県鳳珠郡能登町大箱');
ok($zip->set_number('9280336')->is_valid_number, '石川県鳳珠郡能登町北河内');
ok($zip->set_number('9290101')->is_valid_number, '石川県能美市赤井町');
ok($zip->set_number('9290102')->is_valid_number, '石川県能美市西任田町');
ok($zip->set_number('9290103')->is_valid_number, '石川県能美市五間堂町');
ok($zip->set_number('9290104')->is_valid_number, '石川県能美市中庄町');
ok($zip->set_number('9290105')->is_valid_number, '石川県能美市中ノ江町');
ok($zip->set_number('9290106')->is_valid_number, '石川県能美市西二口町');
ok($zip->set_number('9290107')->is_valid_number, '石川県能美市福岡町');
ok($zip->set_number('9290108')->is_valid_number, '石川県能美市能美');
ok($zip->set_number('9290111')->is_valid_number, '石川県能美市吉原町');
ok($zip->set_number('9290112')->is_valid_number, '石川県能美市福島町');
ok($zip->set_number('9290113')->is_valid_number, '石川県能美市大成町');
ok($zip->set_number('9290114')->is_valid_number, '石川県能美市浜開発町');
ok($zip->set_number('9290115')->is_valid_number, '石川県能美市下ノ江町');
ok($zip->set_number('9290116')->is_valid_number, '石川県能美市高坂町');
ok($zip->set_number('9290116')->is_valid_number, '石川県能美市根上町');
ok($zip->set_number('9290121')->is_valid_number, '石川県能美市吉原釜屋町');
ok($zip->set_number('9290122')->is_valid_number, '石川県能美市大浜町');
ok($zip->set_number('9290123')->is_valid_number, '石川県能美市中町');
ok($zip->set_number('9290124')->is_valid_number, '石川県能美市浜町');
ok($zip->set_number('9290125')->is_valid_number, '石川県能美市道林町');
ok($zip->set_number('9290126')->is_valid_number, '石川県能美市山口町');
ok($zip->set_number('9290201')->is_valid_number, '石川県白山市鹿島町');
ok($zip->set_number('9290202')->is_valid_number, '石川県白山市西米光町');
ok($zip->set_number('9290203')->is_valid_number, '石川県白山市若草町');
ok($zip->set_number('9290204')->is_valid_number, '石川県白山市平加町');
ok($zip->set_number('9290205')->is_valid_number, '石川県白山市蓮池町');
ok($zip->set_number('9290206')->is_valid_number, '石川県白山市鹿島平');
ok($zip->set_number('9290211')->is_valid_number, '石川県白山市井関町');
ok($zip->set_number('9290212')->is_valid_number, '石川県白山市手取町');
ok($zip->set_number('9290213')->is_valid_number, '石川県白山市末正町');
ok($zip->set_number('9290214')->is_valid_number, '石川県白山市長屋町');
ok($zip->set_number('9290215')->is_valid_number, '石川県白山市美川南町');
ok($zip->set_number('9290216')->is_valid_number, '石川県白山市美川本吉町');
ok($zip->set_number('9290217')->is_valid_number, '石川県白山市湊町');
ok($zip->set_number('9290221')->is_valid_number, '石川県白山市美川今町');
ok($zip->set_number('9290222')->is_valid_number, '石川県白山市美川新町');
ok($zip->set_number('9290223')->is_valid_number, '石川県白山市美川北町');
ok($zip->set_number('9290224')->is_valid_number, '石川県白山市美川中町');
ok($zip->set_number('9290231')->is_valid_number, '石川県白山市美川和波町');
ok($zip->set_number('9290232')->is_valid_number, '石川県白山市美川末広町');
ok($zip->set_number('9290233')->is_valid_number, '石川県白山市美川浜町');
ok($zip->set_number('9290234')->is_valid_number, '石川県白山市美川神幸町');
ok($zip->set_number('9290235')->is_valid_number, '石川県白山市美川永代町');
ok($zip->set_number('9290300')->is_valid_number, '石川県河北郡津幡町以下に掲載がない場合');
ok($zip->set_number('9290301')->is_valid_number, '石川県河北郡津幡町瓜生');
ok($zip->set_number('9290302')->is_valid_number, '石川県河北郡津幡町木ノ窪');
ok($zip->set_number('9290303')->is_valid_number, '石川県河北郡津幡町牛首');
ok($zip->set_number('9290304')->is_valid_number, '石川県河北郡津幡町上河合');
ok($zip->set_number('9290305')->is_valid_number, '石川県河北郡津幡町下河合');
ok($zip->set_number('9290306')->is_valid_number, '石川県河北郡津幡町興津');
ok($zip->set_number('9290307')->is_valid_number, '石川県河北郡津幡町種');
ok($zip->set_number('9290307')->is_valid_number, '石川県河北郡津幡町平野');
ok($zip->set_number('9290308')->is_valid_number, '石川県河北郡津幡町菩提寺');
ok($zip->set_number('9290309')->is_valid_number, '石川県河北郡津幡町上大田');
ok($zip->set_number('9290311')->is_valid_number, '石川県河北郡津幡町池ケ原');
ok($zip->set_number('9290312')->is_valid_number, '石川県河北郡津幡町小熊');
ok($zip->set_number('9290313')->is_valid_number, '石川県河北郡津幡町中山');
ok($zip->set_number('9290314')->is_valid_number, '石川県河北郡津幡町上矢田');
ok($zip->set_number('9290315')->is_valid_number, '石川県河北郡津幡町下矢田');
ok($zip->set_number('9290316')->is_valid_number, '石川県河北郡津幡町御門');
ok($zip->set_number('9290317')->is_valid_number, '石川県河北郡津幡町谷内');
ok($zip->set_number('9290318')->is_valid_number, '石川県河北郡津幡町領家');
ok($zip->set_number('9290319')->is_valid_number, '石川県河北郡津幡町能瀬');
ok($zip->set_number('9290321')->is_valid_number, '石川県河北郡津幡町加茂');
ok($zip->set_number('9290322')->is_valid_number, '石川県河北郡津幡町緑が丘');
ok($zip->set_number('9290323')->is_valid_number, '石川県河北郡津幡町津幡');
ok($zip->set_number('9290324')->is_valid_number, '石川県河北郡津幡町浅田');
ok($zip->set_number('9290325')->is_valid_number, '石川県河北郡津幡町加賀爪');
ok($zip->set_number('9290326')->is_valid_number, '石川県河北郡津幡町清水');
ok($zip->set_number('9290327')->is_valid_number, '石川県河北郡津幡町庄');
ok($zip->set_number('9290328')->is_valid_number, '石川県河北郡津幡町湖東');
ok($zip->set_number('9290328')->is_valid_number, '石川県河北郡津幡町舟橋');
ok($zip->set_number('9290331')->is_valid_number, '石川県河北郡津幡町中橋');
ok($zip->set_number('9290332')->is_valid_number, '石川県河北郡津幡町中須加');
ok($zip->set_number('9290333')->is_valid_number, '石川県河北郡津幡町五反田');
ok($zip->set_number('9290334')->is_valid_number, '石川県河北郡津幡町川尻');
ok($zip->set_number('9290335')->is_valid_number, '石川県河北郡津幡町井上の荘');
ok($zip->set_number('9290341')->is_valid_number, '石川県河北郡津幡町横浜');
ok($zip->set_number('9290342')->is_valid_number, '石川県河北郡津幡町北中条');
ok($zip->set_number('9290343')->is_valid_number, '石川県河北郡津幡町南中条');
ok($zip->set_number('9290344')->is_valid_number, '石川県河北郡津幡町浅谷');
ok($zip->set_number('9290345')->is_valid_number, '石川県河北郡津幡町太田');
ok($zip->set_number('9290346')->is_valid_number, '石川県河北郡津幡町潟端');
ok($zip->set_number('9290401')->is_valid_number, '石川県河北郡津幡町彦太郎畠');
ok($zip->set_number('9290402')->is_valid_number, '石川県河北郡津幡町笠池ケ原');
ok($zip->set_number('9290403')->is_valid_number, '石川県河北郡津幡町莇谷');
ok($zip->set_number('9290404')->is_valid_number, '石川県河北郡津幡町大畠');
ok($zip->set_number('9290405')->is_valid_number, '石川県河北郡津幡町上野');
ok($zip->set_number('9290406')->is_valid_number, '石川県河北郡津幡町籠月');
ok($zip->set_number('9290407')->is_valid_number, '石川県河北郡津幡町鳥屋尾');
ok($zip->set_number('9290411')->is_valid_number, '石川県河北郡津幡町河内');
ok($zip->set_number('9290412')->is_valid_number, '石川県河北郡津幡町九折');
ok($zip->set_number('9290413')->is_valid_number, '石川県河北郡津幡町倶利伽羅');
ok($zip->set_number('9290414')->is_valid_number, '石川県河北郡津幡町山森');
ok($zip->set_number('9290415')->is_valid_number, '石川県河北郡津幡町越中坂');
ok($zip->set_number('9290416')->is_valid_number, '石川県河北郡津幡町刈安');
ok($zip->set_number('9290417')->is_valid_number, '石川県河北郡津幡町坂戸');
ok($zip->set_number('9290421')->is_valid_number, '石川県河北郡津幡町原');
ok($zip->set_number('9290422')->is_valid_number, '石川県河北郡津幡町上藤又');
ok($zip->set_number('9290423')->is_valid_number, '石川県河北郡津幡町下中');
ok($zip->set_number('9290424')->is_valid_number, '石川県河北郡津幡町下藤又');
ok($zip->set_number('9290425')->is_valid_number, '石川県河北郡津幡町七野');
ok($zip->set_number('9290426')->is_valid_number, '石川県河北郡津幡町竹橋');
ok($zip->set_number('9290427')->is_valid_number, '石川県河北郡津幡町富田');
ok($zip->set_number('9290431')->is_valid_number, '石川県河北郡津幡町大窪');
ok($zip->set_number('9290432')->is_valid_number, '石川県河北郡津幡町北横根');
ok($zip->set_number('9290433')->is_valid_number, '石川県河北郡津幡町南横根');
ok($zip->set_number('9290434')->is_valid_number, '石川県河北郡津幡町常徳');
ok($zip->set_number('9290434')->is_valid_number, '石川県河北郡津幡町舟尾');
ok($zip->set_number('9290435')->is_valid_number, '石川県河北郡津幡町材木');
ok($zip->set_number('9290436')->is_valid_number, '石川県河北郡津幡町朝日畑');
ok($zip->set_number('9290437')->is_valid_number, '石川県河北郡津幡町相窪');
ok($zip->set_number('9290441')->is_valid_number, '石川県河北郡津幡町東荒屋');
ok($zip->set_number('9290442')->is_valid_number, '石川県河北郡津幡町大坪');
ok($zip->set_number('9290443')->is_valid_number, '石川県河北郡津幡町別所');
ok($zip->set_number('9290444')->is_valid_number, '石川県河北郡津幡町仮生');
ok($zip->set_number('9290445')->is_valid_number, '石川県河北郡津幡町井野河内');
ok($zip->set_number('9290446')->is_valid_number, '石川県河北郡津幡町明神');
ok($zip->set_number('9290447')->is_valid_number, '石川県河北郡津幡町旭山');
ok($zip->set_number('9290451')->is_valid_number, '石川県河北郡津幡町宮田');
ok($zip->set_number('9290452')->is_valid_number, '石川県河北郡津幡町田屋');
ok($zip->set_number('9290453')->is_valid_number, '石川県河北郡津幡町岩崎');
ok($zip->set_number('9290454')->is_valid_number, '石川県河北郡津幡町杉瀬');
ok($zip->set_number('9290455')->is_valid_number, '石川県河北郡津幡町倉見');
ok($zip->set_number('9290456')->is_valid_number, '石川県河北郡津幡町七黒');
ok($zip->set_number('9290461')->is_valid_number, '石川県河北郡津幡町八ノ谷');
ok($zip->set_number('9290462')->is_valid_number, '石川県河北郡津幡町市谷');
ok($zip->set_number('9290463')->is_valid_number, '石川県河北郡津幡町蓮花寺');
ok($zip->set_number('9290464')->is_valid_number, '石川県河北郡津幡町山北');
ok($zip->set_number('9290465')->is_valid_number, '石川県河北郡津幡町鳥越');
ok($zip->set_number('9290466')->is_valid_number, '石川県河北郡津幡町吉倉');
ok($zip->set_number('9290467')->is_valid_number, '石川県河北郡津幡町大熊');
ok($zip->set_number('9291100')->is_valid_number, '石川県かほく市以下に掲載がない場合');
ok($zip->set_number('9291101')->is_valid_number, '石川県かほく市余地');
ok($zip->set_number('9291102')->is_valid_number, '石川県かほく市上田名');
ok($zip->set_number('9291103')->is_valid_number, '石川県かほく市谷');
ok($zip->set_number('9291104')->is_valid_number, '石川県かほく市笠島');
ok($zip->set_number('9291105')->is_valid_number, '石川県かほく市横山');
ok($zip->set_number('9291111')->is_valid_number, '石川県かほく市気屋');
ok($zip->set_number('9291112')->is_valid_number, '石川県かほく市多田');
ok($zip->set_number('9291113')->is_valid_number, '石川県かほく市指江');
ok($zip->set_number('9291114')->is_valid_number, '石川県かほく市狩鹿野');
ok($zip->set_number('9291115')->is_valid_number, '石川県かほく市上山田');
ok($zip->set_number('9291116')->is_valid_number, '石川県かほく市下山田');
ok($zip->set_number('9291117')->is_valid_number, '石川県かほく市鉢伏');
ok($zip->set_number('9291121')->is_valid_number, '石川県かほく市宇気');
ok($zip->set_number('9291122')->is_valid_number, '石川県かほく市七窪');
ok($zip->set_number('9291123')->is_valid_number, '石川県かほく市森');
ok($zip->set_number('9291125')->is_valid_number, '石川県かほく市宇野気');
ok($zip->set_number('9291126')->is_valid_number, '石川県かほく市内日角');
ok($zip->set_number('9291127')->is_valid_number, '石川県かほく市大崎');
ok($zip->set_number('9291171')->is_valid_number, '石川県かほく市木津');
ok($zip->set_number('9291172')->is_valid_number, '石川県かほく市松浜');
ok($zip->set_number('9291173')->is_valid_number, '石川県かほく市遠塚');
ok($zip->set_number('9291174')->is_valid_number, '石川県かほく市浜北');
ok($zip->set_number('9291175')->is_valid_number, '石川県かほく市秋浜');
ok($zip->set_number('9291176')->is_valid_number, '石川県かほく市外日角');
ok($zip->set_number('9291177')->is_valid_number, '石川県かほく市白尾');
ok($zip->set_number('9291201')->is_valid_number, '石川県かほく市野寺');
ok($zip->set_number('9291202')->is_valid_number, '石川県かほく市八野');
ok($zip->set_number('9291203')->is_valid_number, '石川県かほく市黒川');
ok($zip->set_number('9291204')->is_valid_number, '石川県かほく市箕打');
ok($zip->set_number('9291205')->is_valid_number, '石川県かほく市若緑');
ok($zip->set_number('9291206')->is_valid_number, '石川県かほく市元女');
ok($zip->set_number('9291207')->is_valid_number, '石川県かほく市夏栗');
ok($zip->set_number('9291208')->is_valid_number, '石川県かほく市瀬戸町');
ok($zip->set_number('9291210')->is_valid_number, '石川県かほく市学園台');
ok($zip->set_number('9291211')->is_valid_number, '石川県かほく市二ツ屋');
ok($zip->set_number('9291212')->is_valid_number, '石川県かほく市中沼');
ok($zip->set_number('9291213')->is_valid_number, '石川県かほく市長柄町');
ok($zip->set_number('9291214')->is_valid_number, '石川県かほく市内高松');
ok($zip->set_number('9291215')->is_valid_number, '石川県かほく市高松');
ok($zip->set_number('9291300')->is_valid_number, '石川県羽咋郡宝達志水町以下に掲載がない場合');
ok($zip->set_number('9291301')->is_valid_number, '石川県羽咋郡宝達志水町宝達');
ok($zip->set_number('9291302')->is_valid_number, '石川県羽咋郡宝達志水町山崎');
ok($zip->set_number('9291303')->is_valid_number, '石川県羽咋郡宝達志水町河原');
ok($zip->set_number('9291304')->is_valid_number, '石川県羽咋郡宝達志水町南吉田');
ok($zip->set_number('9291305')->is_valid_number, '石川県羽咋郡宝達志水町竹生野');
ok($zip->set_number('9291311')->is_valid_number, '石川県羽咋郡宝達志水町門前');
ok($zip->set_number('9291312')->is_valid_number, '石川県羽咋郡宝達志水町上田');
ok($zip->set_number('9291313')->is_valid_number, '石川県羽咋郡宝達志水町東間');
ok($zip->set_number('9291314')->is_valid_number, '石川県羽咋郡宝達志水町紺屋町');
ok($zip->set_number('9291315')->is_valid_number, '石川県羽咋郡宝達志水町東野');
ok($zip->set_number('9291316')->is_valid_number, '石川県羽咋郡宝達志水町中野');
ok($zip->set_number('9291321')->is_valid_number, '石川県羽咋郡宝達志水町上田出');
ok($zip->set_number('9291322')->is_valid_number, '石川県羽咋郡宝達志水町三日町');
ok($zip->set_number('9291323')->is_valid_number, '石川県羽咋郡宝達志水町御舘');
ok($zip->set_number('9291324')->is_valid_number, '石川県羽咋郡宝達志水町正友');
ok($zip->set_number('9291325')->is_valid_number, '石川県羽咋郡宝達志水町坪山');
ok($zip->set_number('9291326')->is_valid_number, '石川県羽咋郡宝達志水町冬野');
ok($zip->set_number('9291327')->is_valid_number, '石川県羽咋郡宝達志水町森本');
ok($zip->set_number('9291331')->is_valid_number, '石川県羽咋郡宝達志水町米出');
ok($zip->set_number('9291332')->is_valid_number, '石川県羽咋郡宝達志水町北川尻');
ok($zip->set_number('9291333')->is_valid_number, '石川県羽咋郡宝達志水町免田');
ok($zip->set_number('9291341')->is_valid_number, '石川県羽咋郡宝達志水町宿');
ok($zip->set_number('9291342')->is_valid_number, '石川県羽咋郡宝達志水町麦生');
ok($zip->set_number('9291343')->is_valid_number, '石川県羽咋郡宝達志水町小川');
ok($zip->set_number('9291344')->is_valid_number, '石川県羽咋郡宝達志水町今浜');
ok($zip->set_number('9291345')->is_valid_number, '石川県羽咋郡宝達志水町今浜新');
ok($zip->set_number('9291401')->is_valid_number, '石川県羽咋郡宝達志水町向瀬');
ok($zip->set_number('9291402')->is_valid_number, '石川県羽咋郡宝達志水町清水原');
ok($zip->set_number('9291402')->is_valid_number, '石川県羽咋郡宝達志水町走入');
ok($zip->set_number('9291402')->is_valid_number, '石川県羽咋郡宝達志水町見砂');
ok($zip->set_number('9291403')->is_valid_number, '石川県羽咋郡宝達志水町所司原');
ok($zip->set_number('9291404')->is_valid_number, '石川県羽咋郡宝達志水町新宮');
ok($zip->set_number('9291404')->is_valid_number, '石川県羽咋郡宝達志水町当熊');
ok($zip->set_number('9291404')->is_valid_number, '石川県羽咋郡宝達志水町原');
ok($zip->set_number('9291405')->is_valid_number, '石川県羽咋郡宝達志水町海老坂');
ok($zip->set_number('9291405')->is_valid_number, '石川県羽咋郡宝達志水町針山');
ok($zip->set_number('9291405')->is_valid_number, '石川県羽咋郡宝達志水町聖川');
ok($zip->set_number('9291405')->is_valid_number, '石川県羽咋郡宝達志水町平床');
ok($zip->set_number('9291406')->is_valid_number, '石川県羽咋郡宝達志水町石坂');
ok($zip->set_number('9291406')->is_valid_number, '石川県羽咋郡宝達志水町下石');
ok($zip->set_number('9291406')->is_valid_number, '石川県羽咋郡宝達志水町散田');
ok($zip->set_number('9291411')->is_valid_number, '石川県羽咋郡宝達志水町柳瀬');
ok($zip->set_number('9291412')->is_valid_number, '石川県羽咋郡宝達志水町荻島');
ok($zip->set_number('9291413')->is_valid_number, '石川県羽咋郡宝達志水町荻谷');
ok($zip->set_number('9291414')->is_valid_number, '石川県羽咋郡宝達志水町敷波');
ok($zip->set_number('9291415')->is_valid_number, '石川県羽咋郡宝達志水町敷浪');
ok($zip->set_number('9291416')->is_valid_number, '石川県羽咋郡宝達志水町出浜');
ok($zip->set_number('9291421')->is_valid_number, '石川県羽咋郡宝達志水町二口');
ok($zip->set_number('9291422')->is_valid_number, '石川県羽咋郡宝達志水町杉野屋');
ok($zip->set_number('9291423')->is_valid_number, '石川県羽咋郡宝達志水町菅原');
ok($zip->set_number('9291424')->is_valid_number, '石川県羽咋郡宝達志水町吉野屋');
ok($zip->set_number('9291425')->is_valid_number, '石川県羽咋郡宝達志水町子浦');
ok($zip->set_number('9291426')->is_valid_number, '石川県羽咋郡宝達志水町荻市');
ok($zip->set_number('9291601')->is_valid_number, '石川県鹿島郡中能登町西馬場');
ok($zip->set_number('9291602')->is_valid_number, '石川県鹿島郡中能登町能登部上');
ok($zip->set_number('9291603')->is_valid_number, '石川県鹿島郡中能登町徳丸');
ok($zip->set_number('9291604')->is_valid_number, '石川県鹿島郡中能登町能登部下');
ok($zip->set_number('9291605')->is_valid_number, '石川県鹿島郡中能登町下後山');
ok($zip->set_number('9291606')->is_valid_number, '石川県鹿島郡中能登町上後山');
ok($zip->set_number('9291621')->is_valid_number, '石川県鹿島郡中能登町金丸');
ok($zip->set_number('9291631')->is_valid_number, '石川県鹿島郡中能登町久江');
ok($zip->set_number('9291632')->is_valid_number, '石川県鹿島郡中能登町小田中');
ok($zip->set_number('9291633')->is_valid_number, '石川県鹿島郡中能登町藤井');
ok($zip->set_number('9291634')->is_valid_number, '石川県鹿島郡中能登町福田');
ok($zip->set_number('9291635')->is_valid_number, '石川県鹿島郡中能登町高畠');
ok($zip->set_number('9291636')->is_valid_number, '石川県鹿島郡中能登町小金森');
ok($zip->set_number('9291637')->is_valid_number, '石川県鹿島郡中能登町曽祢');
ok($zip->set_number('9291700')->is_valid_number, '石川県鹿島郡中能登町以下に掲載がない場合');
ok($zip->set_number('9291701')->is_valid_number, '石川県鹿島郡中能登町川田');
ok($zip->set_number('9291702')->is_valid_number, '石川県鹿島郡中能登町大槻');
ok($zip->set_number('9291703')->is_valid_number, '石川県鹿島郡中能登町春木');
ok($zip->set_number('9291704')->is_valid_number, '石川県鹿島郡中能登町末坂');
ok($zip->set_number('9291705')->is_valid_number, '石川県鹿島郡中能登町花見月');
ok($zip->set_number('9291706')->is_valid_number, '石川県鹿島郡中能登町瀬戸');
ok($zip->set_number('9291711')->is_valid_number, '石川県鹿島郡中能登町廿九日');
ok($zip->set_number('9291712')->is_valid_number, '石川県鹿島郡中能登町新庄');
ok($zip->set_number('9291713')->is_valid_number, '石川県鹿島郡中能登町今羽坂');
ok($zip->set_number('9291714')->is_valid_number, '石川県鹿島郡中能登町羽坂');
ok($zip->set_number('9291715')->is_valid_number, '石川県鹿島郡中能登町一青');
ok($zip->set_number('9291716')->is_valid_number, '石川県鹿島郡中能登町黒氏');
ok($zip->set_number('9291717')->is_valid_number, '石川県鹿島郡中能登町良川');
ok($zip->set_number('9291721')->is_valid_number, '石川県鹿島郡中能登町井田');
ok($zip->set_number('9291722')->is_valid_number, '石川県鹿島郡中能登町小竹');
ok($zip->set_number('9291723')->is_valid_number, '石川県鹿島郡中能登町水白');
ok($zip->set_number('9291724')->is_valid_number, '石川県鹿島郡中能登町尾崎');
ok($zip->set_number('9291725')->is_valid_number, '石川県鹿島郡中能登町東馬場');
ok($zip->set_number('9291726')->is_valid_number, '石川県鹿島郡中能登町最勝講');
ok($zip->set_number('9291801')->is_valid_number, '石川県鹿島郡中能登町久乃木');
ok($zip->set_number('9291802')->is_valid_number, '石川県鹿島郡中能登町武部');
ok($zip->set_number('9291803')->is_valid_number, '石川県鹿島郡中能登町西');
ok($zip->set_number('9291804')->is_valid_number, '石川県鹿島郡中能登町在江');
ok($zip->set_number('9291805')->is_valid_number, '石川県鹿島郡中能登町坪川');
ok($zip->set_number('9291811')->is_valid_number, '石川県鹿島郡中能登町二宮');
ok($zip->set_number('9291812')->is_valid_number, '石川県鹿島郡中能登町石動山');
ok($zip->set_number('9291813')->is_valid_number, '石川県鹿島郡中能登町蟻ケ原');
ok($zip->set_number('9291814')->is_valid_number, '石川県鹿島郡中能登町原山');
ok($zip->set_number('9291815')->is_valid_number, '石川県鹿島郡中能登町芹川');
ok($zip->set_number('9291816')->is_valid_number, '石川県鹿島郡中能登町浅井');
ok($zip->set_number('9291817')->is_valid_number, '石川県鹿島郡中能登町徳前');
ok($zip->set_number('9291818')->is_valid_number, '石川県鹿島郡中能登町二宮あおば台');
ok($zip->set_number('9292101')->is_valid_number, '石川県七尾市川尻町');
ok($zip->set_number('9292102')->is_valid_number, '石川県七尾市舟尾町');
ok($zip->set_number('9292103')->is_valid_number, '石川県七尾市東山町');
ok($zip->set_number('9292104')->is_valid_number, '石川県七尾市垣吉町');
ok($zip->set_number('9292105')->is_valid_number, '石川県七尾市新屋町');
ok($zip->set_number('9292111')->is_valid_number, '石川県七尾市高田町');
ok($zip->set_number('9292112')->is_valid_number, '石川県七尾市杉森町');
ok($zip->set_number('9292113')->is_valid_number, '石川県七尾市西下町');
ok($zip->set_number('9292114')->is_valid_number, '石川県七尾市伊久留町');
ok($zip->set_number('9292115')->is_valid_number, '石川県七尾市七原町');
ok($zip->set_number('9292116')->is_valid_number, '石川県七尾市吉田町');
ok($zip->set_number('9292121')->is_valid_number, '石川県七尾市田鶴浜町');
ok($zip->set_number('9292122')->is_valid_number, '石川県七尾市上野ケ丘町');
ok($zip->set_number('9292123')->is_valid_number, '石川県七尾市三引町');
ok($zip->set_number('9292124')->is_valid_number, '石川県七尾市白浜町');
ok($zip->set_number('9292125')->is_valid_number, '石川県七尾市深見町');
ok($zip->set_number('9292126')->is_valid_number, '石川県七尾市大津町');
ok($zip->set_number('9292201')->is_valid_number, '石川県七尾市中島町河内');
ok($zip->set_number('9292202')->is_valid_number, '石川県七尾市中島町別所');
ok($zip->set_number('9292203')->is_valid_number, '石川県七尾市中島町北免田');
ok($zip->set_number('9292204')->is_valid_number, '石川県七尾市中島町上畠');
ok($zip->set_number('9292205')->is_valid_number, '石川県七尾市中島町町屋');
ok($zip->set_number('9292206')->is_valid_number, '石川県七尾市中島町鳥越');
ok($zip->set_number('9292207')->is_valid_number, '石川県七尾市中島町大平');
ok($zip->set_number('9292208')->is_valid_number, '石川県七尾市中島町古江');
ok($zip->set_number('9292209')->is_valid_number, '石川県七尾市中島町西谷内');
ok($zip->set_number('9292211')->is_valid_number, '石川県七尾市中島町横見');
ok($zip->set_number('9292212')->is_valid_number, '石川県七尾市中島町田岸');
ok($zip->set_number('9292213')->is_valid_number, '石川県七尾市中島町外');
ok($zip->set_number('9292214')->is_valid_number, '石川県七尾市中島町小牧');
ok($zip->set_number('9292215')->is_valid_number, '石川県七尾市中島町深浦');
ok($zip->set_number('9292216')->is_valid_number, '石川県七尾市中島町長浦');
ok($zip->set_number('9292217')->is_valid_number, '石川県七尾市中島町鹿島台');
ok($zip->set_number('9292218')->is_valid_number, '石川県七尾市中島町瀬嵐');
ok($zip->set_number('9292221')->is_valid_number, '石川県七尾市中島町谷内');
ok($zip->set_number('9292222')->is_valid_number, '石川県七尾市中島町中島');
ok($zip->set_number('9292223')->is_valid_number, '石川県七尾市中島町上町');
ok($zip->set_number('9292224')->is_valid_number, '石川県七尾市中島町山戸田');
ok($zip->set_number('9292225')->is_valid_number, '石川県七尾市中島町宮前');
ok($zip->set_number('9292226')->is_valid_number, '石川県七尾市中島町横田');
ok($zip->set_number('9292227')->is_valid_number, '石川県七尾市中島町藤瀬');
ok($zip->set_number('9292231')->is_valid_number, '石川県七尾市中島町奥吉田');
ok($zip->set_number('9292232')->is_valid_number, '石川県七尾市中島町筆染');
ok($zip->set_number('9292233')->is_valid_number, '石川県七尾市中島町笠師');
ok($zip->set_number('9292234')->is_valid_number, '石川県七尾市中島町塩津');
ok($zip->set_number('9292241')->is_valid_number, '石川県七尾市中島町浜田');
ok($zip->set_number('9292242')->is_valid_number, '石川県七尾市中島町崎山');
ok($zip->set_number('9292243')->is_valid_number, '石川県七尾市中島町河崎');
ok($zip->set_number('9292244')->is_valid_number, '石川県七尾市中島町豊田町');
ok($zip->set_number('9292245')->is_valid_number, '石川県七尾市中島町豊田');
ok($zip->set_number('9292246')->is_valid_number, '石川県七尾市中島町土川');
ok($zip->set_number('9292247')->is_valid_number, '石川県七尾市中島町外原');
ok($zip->set_number('9292361')->is_valid_number, '石川県輪島市三井町与呂見');
ok($zip->set_number('9292362')->is_valid_number, '石川県輪島市三井町中');
ok($zip->set_number('9292363')->is_valid_number, '石川県輪島市三井町興徳寺');
ok($zip->set_number('9292364')->is_valid_number, '石川県輪島市大和町');
ok($zip->set_number('9292365')->is_valid_number, '石川県輪島市三井町渡合');
ok($zip->set_number('9292366')->is_valid_number, '石川県輪島市三井町本江');
ok($zip->set_number('9292367')->is_valid_number, '石川県輪島市三井町仁行');
ok($zip->set_number('9292371')->is_valid_number, '石川県輪島市三井町三洲穂');
ok($zip->set_number('9292372')->is_valid_number, '石川県輪島市三井町洲衛');
ok($zip->set_number('9292373')->is_valid_number, '石川県輪島市三井町市ノ坂');
ok($zip->set_number('9292374')->is_valid_number, '石川県輪島市三井町内屋');
ok($zip->set_number('9292375')->is_valid_number, '石川県輪島市三井町細屋');
ok($zip->set_number('9292376')->is_valid_number, '石川県輪島市三井町新保');
ok($zip->set_number('9292377')->is_valid_number, '石川県輪島市三井町漆原');
ok($zip->set_number('9292378')->is_valid_number, '石川県輪島市三井町小泉');
ok($zip->set_number('9292379')->is_valid_number, '石川県輪島市三井町長沢');
ok($zip->set_number('9300001')->is_valid_number, '富山県富山市明輪町');
ok($zip->set_number('9300002')->is_valid_number, '富山県富山市新富町');
ok($zip->set_number('9300003')->is_valid_number, '富山県富山市桜町');
ok($zip->set_number('9300004')->is_valid_number, '富山県富山市桜橋通り');
ok($zip->set_number('9300005')->is_valid_number, '富山県富山市新桜町');
ok($zip->set_number('9300006')->is_valid_number, '富山県富山市新総曲輪');
ok($zip->set_number('9300007')->is_valid_number, '富山県富山市宝町');
ok($zip->set_number('9300008')->is_valid_number, '富山県富山市神通本町');
ok($zip->set_number('9300009')->is_valid_number, '富山県富山市神通町');
ok($zip->set_number('9300010')->is_valid_number, '富山県富山市稲荷元町');
ok($zip->set_number('9300012')->is_valid_number, '富山県富山市稲荷町');
ok($zip->set_number('9300014')->is_valid_number, '富山県富山市館出町');
ok($zip->set_number('9300015')->is_valid_number, '富山県富山市於保多町');
ok($zip->set_number('9300016')->is_valid_number, '富山県富山市柳町');
ok($zip->set_number('9300017')->is_valid_number, '富山県富山市東田地方町');
ok($zip->set_number('9300018')->is_valid_number, '富山県富山市千歳町');
ok($zip->set_number('9300019')->is_valid_number, '富山県富山市弥生町');
ok($zip->set_number('9300021')->is_valid_number, '富山県富山市今木町');
ok($zip->set_number('9300022')->is_valid_number, '富山県富山市小島町');
ok($zip->set_number('9300023')->is_valid_number, '富山県富山市北新町');
ok($zip->set_number('9300024')->is_valid_number, '富山県富山市新川原町');
ok($zip->set_number('9300025')->is_valid_number, '富山県富山市日之出町');
ok($zip->set_number('9300026')->is_valid_number, '富山県富山市八人町');
ok($zip->set_number('9300027')->is_valid_number, '富山県富山市蛯町');
ok($zip->set_number('9300028')->is_valid_number, '富山県富山市荒町');
ok($zip->set_number('9300029')->is_valid_number, '富山県富山市本町');
ok($zip->set_number('9300031')->is_valid_number, '富山県富山市住吉町');
ok($zip->set_number('9300032')->is_valid_number, '富山県富山市栄町');
ok($zip->set_number('9300033')->is_valid_number, '富山県富山市元町');
ok($zip->set_number('9300034')->is_valid_number, '富山県富山市清水元町');
ok($zip->set_number('9300035')->is_valid_number, '富山県富山市清水中町');
ok($zip->set_number('9300036')->is_valid_number, '富山県富山市清水町');
ok($zip->set_number('9300037')->is_valid_number, '富山県富山市音羽町');
ok($zip->set_number('9300038')->is_valid_number, '富山県富山市緑町');
ok($zip->set_number('9300039')->is_valid_number, '富山県富山市東町');
ok($zip->set_number('9300041')->is_valid_number, '富山県富山市向川原町');
ok($zip->set_number('9300042')->is_valid_number, '富山県富山市泉町');
ok($zip->set_number('9300043')->is_valid_number, '富山県富山市石倉町');
ok($zip->set_number('9300044')->is_valid_number, '富山県富山市中央通り');
ok($zip->set_number('9300045')->is_valid_number, '富山県富山市砂町');
ok($zip->set_number('9300046')->is_valid_number, '富山県富山市堤町通り');
ok($zip->set_number('9300047')->is_valid_number, '富山県富山市常盤町');
ok($zip->set_number('9300048')->is_valid_number, '富山県富山市白銀町');
ok($zip->set_number('9300049')->is_valid_number, '富山県富山市豊川町');
ok($zip->set_number('9300051')->is_valid_number, '富山県富山市室町通り');
ok($zip->set_number('9300052')->is_valid_number, '富山県富山市五番町');
ok($zip->set_number('9300053')->is_valid_number, '富山県富山市辰巳町');
ok($zip->set_number('9300054')->is_valid_number, '富山県富山市南新町');
ok($zip->set_number('9300055')->is_valid_number, '富山県富山市梅沢町');
ok($zip->set_number('9300056')->is_valid_number, '富山県富山市南田町');
ok($zip->set_number('9300057')->is_valid_number, '富山県富山市上本町');
ok($zip->set_number('9300058')->is_valid_number, '富山県富山市古鍛冶町');
ok($zip->set_number('9300059')->is_valid_number, '富山県富山市三番町');
ok($zip->set_number('9300061')->is_valid_number, '富山県富山市一番町');
ok($zip->set_number('9300062')->is_valid_number, '富山県富山市西町');
ok($zip->set_number('9300063')->is_valid_number, '富山県富山市太田口通り');
ok($zip->set_number('9300064')->is_valid_number, '富山県富山市山王町');
ok($zip->set_number('9300065')->is_valid_number, '富山県富山市星井町');
ok($zip->set_number('9300066')->is_valid_number, '富山県富山市千石町');
ok($zip->set_number('9300067')->is_valid_number, '富山県富山市越前町');
ok($zip->set_number('9300068')->is_valid_number, '富山県富山市西四十物町');
ok($zip->set_number('9300069')->is_valid_number, '富山県富山市旅籠町');
ok($zip->set_number('9300071')->is_valid_number, '富山県富山市平吹町');
ok($zip->set_number('9300072')->is_valid_number, '富山県富山市桃井町');
ok($zip->set_number('9300073')->is_valid_number, '富山県富山市西山王町');
ok($zip->set_number('9300074')->is_valid_number, '富山県富山市堀端町');
ok($zip->set_number('9300075')->is_valid_number, '富山県富山市相生町');
ok($zip->set_number('9300076')->is_valid_number, '富山県富山市長柄町');
ok($zip->set_number('9300077')->is_valid_number, '富山県富山市磯部町');
ok($zip->set_number('9300078')->is_valid_number, '富山県富山市土居原町');
ok($zip->set_number('9300081')->is_valid_number, '富山県富山市本丸');
ok($zip->set_number('9300082')->is_valid_number, '富山県富山市桜木町');
ok($zip->set_number('9300083')->is_valid_number, '富山県富山市総曲輪');
ok($zip->set_number('9300084')->is_valid_number, '富山県富山市大手町');
ok($zip->set_number('9300085')->is_valid_number, '富山県富山市丸の内');
ok($zip->set_number('9300086')->is_valid_number, '富山県富山市鹿島町');
ok($zip->set_number('9300087')->is_valid_number, '富山県富山市安野屋町');
ok($zip->set_number('9300088')->is_valid_number, '富山県富山市諏訪川原');
ok($zip->set_number('9300089')->is_valid_number, '富山県富山市七軒町');
ok($zip->set_number('9300091')->is_valid_number, '富山県富山市愛宕町');
ok($zip->set_number('9300092')->is_valid_number, '富山県富山市安田町');
ok($zip->set_number('9300093')->is_valid_number, '富山県富山市内幸町');
ok($zip->set_number('9300094')->is_valid_number, '富山県富山市安住町');
ok($zip->set_number('9300095')->is_valid_number, '富山県富山市舟橋南町');
ok($zip->set_number('9300096')->is_valid_number, '富山県富山市舟橋北町');
ok($zip->set_number('9300097')->is_valid_number, '富山県富山市芝園町');
ok($zip->set_number('9300098')->is_valid_number, '富山県富山市舟橋今町');
ok($zip->set_number('9300101')->is_valid_number, '富山県富山市中沖');
ok($zip->set_number('9300102')->is_valid_number, '富山県富山市呉羽野田');
ok($zip->set_number('9300103')->is_valid_number, '富山県富山市北代');
ok($zip->set_number('9300103')->is_valid_number, '富山県富山市北代中部');
ok($zip->set_number('9300103')->is_valid_number, '富山県富山市北代東部');
ok($zip->set_number('9300103')->is_valid_number, '富山県富山市北代北部');
ok($zip->set_number('9300104')->is_valid_number, '富山県富山市北代新');
ok($zip->set_number('9300105')->is_valid_number, '富山県富山市北代藤ケ丘');
ok($zip->set_number('9300106')->is_valid_number, '富山県富山市高木');
ok($zip->set_number('9300106')->is_valid_number, '富山県富山市高木東');
ok($zip->set_number('9300106')->is_valid_number, '富山県富山市高木西');
ok($zip->set_number('9300106')->is_valid_number, '富山県富山市高木南');
ok($zip->set_number('9300107')->is_valid_number, '富山県富山市大塚');
ok($zip->set_number('9300107')->is_valid_number, '富山県富山市大塚東');
ok($zip->set_number('9300107')->is_valid_number, '富山県富山市大塚西');
ok($zip->set_number('9300107')->is_valid_number, '富山県富山市大塚南');
ok($zip->set_number('9300107')->is_valid_number, '富山県富山市大塚北');
ok($zip->set_number('9300108')->is_valid_number, '富山県富山市本郷');
ok($zip->set_number('9300108')->is_valid_number, '富山県富山市本郷中部');
ok($zip->set_number('9300108')->is_valid_number, '富山県富山市本郷東部');
ok($zip->set_number('9300108')->is_valid_number, '富山県富山市本郷西部');
ok($zip->set_number('9300108')->is_valid_number, '富山県富山市本郷北部');
ok($zip->set_number('9300111')->is_valid_number, '富山県富山市長岡');
ok($zip->set_number('9300112')->is_valid_number, '富山県富山市八ケ山');
ok($zip->set_number('9300113')->is_valid_number, '富山県富山市長岡新');
ok($zip->set_number('9300114')->is_valid_number, '富山県富山市茶屋新町');
ok($zip->set_number('9300115')->is_valid_number, '富山県富山市茶屋町');
ok($zip->set_number('9300116')->is_valid_number, '富山県富山市追分茶屋');
ok($zip->set_number('9300121')->is_valid_number, '富山県富山市呉羽苑');
ok($zip->set_number('9300122')->is_valid_number, '富山県富山市呉羽新富田町');
ok($zip->set_number('9300123')->is_valid_number, '富山県富山市呉羽富田町');
ok($zip->set_number('9300124')->is_valid_number, '富山県富山市呉羽水上町');
ok($zip->set_number('9300125')->is_valid_number, '富山県富山市呉羽つつじが丘');
ok($zip->set_number('9300126')->is_valid_number, '富山県富山市呉羽東町');
ok($zip->set_number('9300127')->is_valid_number, '富山県富山市呉羽丸富町');
ok($zip->set_number('9300131')->is_valid_number, '富山県富山市呉羽昭和町');
ok($zip->set_number('9300132')->is_valid_number, '富山県富山市呉羽姫本');
ok($zip->set_number('9300133')->is_valid_number, '富山県富山市呉羽川西');
ok($zip->set_number('9300134')->is_valid_number, '富山県富山市呉羽貴船巻');
ok($zip->set_number('9300135')->is_valid_number, '富山県富山市呉羽中の町');
ok($zip->set_number('9300136')->is_valid_number, '富山県富山市呉羽三ツ塚');
ok($zip->set_number('9300137')->is_valid_number, '富山県富山市呉羽本町');
ok($zip->set_number('9300138')->is_valid_number, '富山県富山市呉羽町');
ok($zip->set_number('9300138')->is_valid_number, '富山県富山市呉羽町西');
ok($zip->set_number('9300138')->is_valid_number, '富山県富山市呉羽町北');
ok($zip->set_number('9300141')->is_valid_number, '富山県富山市吉作新町');
ok($zip->set_number('9300142')->is_valid_number, '富山県富山市吉作');
ok($zip->set_number('9300143')->is_valid_number, '富山県富山市西金屋');
ok($zip->set_number('9300144')->is_valid_number, '富山県富山市住吉');
ok($zip->set_number('9300151')->is_valid_number, '富山県富山市古沢');
ok($zip->set_number('9300152')->is_valid_number, '富山県富山市杉谷');
ok($zip->set_number('9300153')->is_valid_number, '富山県富山市境野新');
ok($zip->set_number('9300154')->is_valid_number, '富山県富山市平岡');
ok($zip->set_number('9300155')->is_valid_number, '富山県富山市三熊');
ok($zip->set_number('9300156')->is_valid_number, '富山県富山市坂下新');
ok($zip->set_number('9300156')->is_valid_number, '富山県富山市山本');
ok($zip->set_number('9300157')->is_valid_number, '富山県富山市開ケ丘');
ok($zip->set_number('9300158')->is_valid_number, '富山県富山市池多');
ok($zip->set_number('9300161')->is_valid_number, '富山県富山市東老田');
ok($zip->set_number('9300162')->is_valid_number, '富山県富山市花木');
ok($zip->set_number('9300163')->is_valid_number, '富山県富山市栃谷');
ok($zip->set_number('9300164')->is_valid_number, '富山県富山市北押川');
ok($zip->set_number('9300165')->is_valid_number, '富山県富山市西押川');
ok($zip->set_number('9300166')->is_valid_number, '富山県富山市中老田');
ok($zip->set_number('9300171')->is_valid_number, '富山県富山市野々上');
ok($zip->set_number('9300172')->is_valid_number, '富山県富山市北二ツ屋');
ok($zip->set_number('9300173')->is_valid_number, '富山県富山市野口');
ok($zip->set_number('9300173')->is_valid_number, '富山県富山市野口南部');
ok($zip->set_number('9300173')->is_valid_number, '富山県富山市野口北部');
ok($zip->set_number('9300174')->is_valid_number, '富山県富山市野町');
ok($zip->set_number('9300175')->is_valid_number, '富山県富山市願海寺');
ok($zip->set_number('9300176')->is_valid_number, '富山県富山市願海寺新町');
ok($zip->set_number('9300177')->is_valid_number, '富山県富山市西二俣');
ok($zip->set_number('9300200')->is_valid_number, '富山県中新川郡舟橋村以下に掲載がない場合');
ok($zip->set_number('9300200')->is_valid_number, '富山県中新川郡立山町以下に掲載がない場合');
ok($zip->set_number('9300201')->is_valid_number, '富山県中新川郡立山町泉');
ok($zip->set_number('9300202')->is_valid_number, '富山県中新川郡立山町若宮');
ok($zip->set_number('9300203')->is_valid_number, '富山県中新川郡立山町若林');
ok($zip->set_number('9300204')->is_valid_number, '富山県中新川郡立山町寺田');
ok($zip->set_number('9300205')->is_valid_number, '富山県中新川郡立山町寺田新');
ok($zip->set_number('9300206')->is_valid_number, '富山県中新川郡立山町竹鼻新');
ok($zip->set_number('9300207')->is_valid_number, '富山県中新川郡立山町浦田新');
ok($zip->set_number('9300208')->is_valid_number, '富山県中新川郡立山町浦田');
ok($zip->set_number('9300209')->is_valid_number, '富山県中新川郡立山町寺田ことぶき町');
ok($zip->set_number('9300211')->is_valid_number, '富山県中新川郡立山町辻');
ok($zip->set_number('9300212')->is_valid_number, '富山県中新川郡立山町沢端');
ok($zip->set_number('9300213')->is_valid_number, '富山県中新川郡立山町野口新');
ok($zip->set_number('9300214')->is_valid_number, '富山県中新川郡立山町五百石');
ok($zip->set_number('9300215')->is_valid_number, '富山県中新川郡立山町宮成');
ok($zip->set_number('9300216')->is_valid_number, '富山県中新川郡立山町大窪');
ok($zip->set_number('9300217')->is_valid_number, '富山県中新川郡立山町野口');
ok($zip->set_number('9300218')->is_valid_number, '富山県中新川郡立山町二ツ塚');
ok($zip->set_number('9300219')->is_valid_number, '富山県中新川郡立山町田添');
ok($zip->set_number('9300220')->is_valid_number, '富山県中新川郡立山町前沢中央町');
ok($zip->set_number('9300221')->is_valid_number, '富山県中新川郡立山町前沢');
ok($zip->set_number('9300222')->is_valid_number, '富山県中新川郡立山町貫田');
ok($zip->set_number('9300223')->is_valid_number, '富山県中新川郡立山町上鉾木');
ok($zip->set_number('9300224')->is_valid_number, '富山県中新川郡立山町西芦原');
ok($zip->set_number('9300225')->is_valid_number, '富山県中新川郡立山町本郷島');
ok($zip->set_number('9300226')->is_valid_number, '富山県中新川郡立山町道新');
ok($zip->set_number('9300227')->is_valid_number, '富山県中新川郡立山町草野');
ok($zip->set_number('9300228')->is_valid_number, '富山県中新川郡立山町手屋');
ok($zip->set_number('9300229')->is_valid_number, '富山県中新川郡立山町前沢新町');
ok($zip->set_number('9300231')->is_valid_number, '富山県中新川郡立山町坂井沢');
ok($zip->set_number('9300232')->is_valid_number, '富山県中新川郡立山町金剛寺');
ok($zip->set_number('9300233')->is_valid_number, '富山県中新川郡立山町上金剛寺');
ok($zip->set_number('9300234')->is_valid_number, '富山県中新川郡立山町下段');
ok($zip->set_number('9300235')->is_valid_number, '富山県中新川郡立山町榎');
ok($zip->set_number('9300236')->is_valid_number, '富山県中新川郡立山町新堀');
ok($zip->set_number('9300237')->is_valid_number, '富山県中新川郡立山町柿の木沢');
ok($zip->set_number('9300241')->is_valid_number, '富山県中新川郡立山町道源寺');
ok($zip->set_number('9300242')->is_valid_number, '富山県中新川郡立山町寺坪');
ok($zip->set_number('9300243')->is_valid_number, '富山県中新川郡立山町米道(その他)');
ok($zip->set_number('9300244')->is_valid_number, '富山県中新川郡立山町末谷口');
ok($zip->set_number('9300245')->is_valid_number, '富山県中新川郡立山町沢中山');
ok($zip->set_number('9300245')->is_valid_number, '富山県中新川郡立山町中山');
ok($zip->set_number('9300246')->is_valid_number, '富山県中新川郡立山町鋳物師沢');
ok($zip->set_number('9300247')->is_valid_number, '富山県中新川郡立山町末三賀');
ok($zip->set_number('9300248')->is_valid_number, '富山県中新川郡立山町野村');
ok($zip->set_number('9300251')->is_valid_number, '富山県中新川郡立山町大島');
ok($zip->set_number('9300252')->is_valid_number, '富山県中新川郡立山町日俣');
ok($zip->set_number('9300253')->is_valid_number, '富山県中新川郡立山町大窪開');
ok($zip->set_number('9300254')->is_valid_number, '富山県中新川郡立山町古川');
ok($zip->set_number('9300255')->is_valid_number, '富山県中新川郡立山町向新庄');
ok($zip->set_number('9300256')->is_valid_number, '富山県中新川郡立山町一本木');
ok($zip->set_number('9300257')->is_valid_number, '富山県中新川郡立山町川原木');
ok($zip->set_number('9300261')->is_valid_number, '富山県中新川郡立山町大石原');
ok($zip->set_number('9300262')->is_valid_number, '富山県中新川郡立山町蔵本新');
ok($zip->set_number('9300263')->is_valid_number, '富山県中新川郡立山町大清水');
ok($zip->set_number('9300264')->is_valid_number, '富山県中新川郡立山町東大森');
ok($zip->set_number('9300265')->is_valid_number, '富山県中新川郡立山町泊新');
ok($zip->set_number('9300266')->is_valid_number, '富山県中新川郡立山町三ツ塚');
ok($zip->set_number('9300266')->is_valid_number, '富山県中新川郡立山町三ツ塚新');
ok($zip->set_number('9300267')->is_valid_number, '富山県中新川郡立山町西大森');
ok($zip->set_number('9300268')->is_valid_number, '富山県中新川郡立山町高原八ツ屋');
ok($zip->set_number('9300269')->is_valid_number, '富山県中新川郡立山町半屋');
ok($zip->set_number('9300271')->is_valid_number, '富山県中新川郡立山町浅生');
ok($zip->set_number('9300272')->is_valid_number, '富山県中新川郡立山町塚越');
ok($zip->set_number('9300273')->is_valid_number, '富山県中新川郡立山町横沢');
ok($zip->set_number('9300274')->is_valid_number, '富山県中新川郡立山町五郎丸');
ok($zip->set_number('9300275')->is_valid_number, '富山県中新川郡立山町利田');
ok($zip->set_number('9300276')->is_valid_number, '富山県中新川郡立山町鉾木');
ok($zip->set_number('9300281')->is_valid_number, '富山県中新川郡舟橋村舟橋');
ok($zip->set_number('9300282')->is_valid_number, '富山県中新川郡舟橋村仏生寺');
ok($zip->set_number('9300283')->is_valid_number, '富山県中新川郡舟橋村海老江');
ok($zip->set_number('9300284')->is_valid_number, '富山県中新川郡舟橋村竹鼻');
ok($zip->set_number('9300285')->is_valid_number, '富山県中新川郡舟橋村古海老江');
ok($zip->set_number('9300286')->is_valid_number, '富山県中新川郡舟橋村東芦原');
ok($zip->set_number('9300287')->is_valid_number, '富山県中新川郡舟橋村稲荷');
ok($zip->set_number('9300288')->is_valid_number, '富山県中新川郡舟橋村国重');
ok($zip->set_number('9300289')->is_valid_number, '富山県中新川郡舟橋村竹内');
ok($zip->set_number('9300300')->is_valid_number, '富山県中新川郡上市町以下に掲載がない場合');
ok($zip->set_number('9300301')->is_valid_number, '富山県中新川郡上市町竹鼻');
ok($zip->set_number('9300302')->is_valid_number, '富山県中新川郡上市町石仏');
ok($zip->set_number('9300303')->is_valid_number, '富山県中新川郡上市町大永田');
ok($zip->set_number('9300304')->is_valid_number, '富山県中新川郡上市町森尻');
ok($zip->set_number('9300305')->is_valid_number, '富山県中新川郡上市町荒田');
ok($zip->set_number('9300311')->is_valid_number, '富山県中新川郡上市町弥市');
ok($zip->set_number('9300312')->is_valid_number, '富山県中新川郡上市町東江上');
ok($zip->set_number('9300313')->is_valid_number, '富山県中新川郡上市町中江上');
ok($zip->set_number('9300314')->is_valid_number, '富山県中新川郡上市町若杉');
ok($zip->set_number('9300315')->is_valid_number, '富山県中新川郡上市町若杉新');
ok($zip->set_number('9300316')->is_valid_number, '富山県中新川郡上市町中小泉');
ok($zip->set_number('9300317')->is_valid_number, '富山県中新川郡上市町江又');
ok($zip->set_number('9300318')->is_valid_number, '富山県中新川郡上市町江上');
ok($zip->set_number('9300321')->is_valid_number, '富山県中新川郡上市町天神町');
ok($zip->set_number('9300322')->is_valid_number, '富山県中新川郡上市町栄町');
ok($zip->set_number('9300323')->is_valid_number, '富山県中新川郡上市町西町');
ok($zip->set_number('9300324')->is_valid_number, '富山県中新川郡上市町新町');
ok($zip->set_number('9300325')->is_valid_number, '富山県中新川郡上市町三日市');
ok($zip->set_number('9300326')->is_valid_number, '富山県中新川郡上市町柳町');
ok($zip->set_number('9300331')->is_valid_number, '富山県中新川郡上市町旭町');
ok($zip->set_number('9300332')->is_valid_number, '富山県中新川郡上市町石浦町');
ok($zip->set_number('9300333')->is_valid_number, '富山県中新川郡上市町上中町');
ok($zip->set_number('9300334')->is_valid_number, '富山県中新川郡上市町西中町');
ok($zip->set_number('9300335')->is_valid_number, '富山県中新川郡上市町幸町');
ok($zip->set_number('9300336')->is_valid_number, '富山県中新川郡上市町松和町');
ok($zip->set_number('9300341')->is_valid_number, '富山県中新川郡上市町錦町');
ok($zip->set_number('9300342')->is_valid_number, '富山県中新川郡上市町神明町');
ok($zip->set_number('9300343')->is_valid_number, '富山県中新川郡上市町東町');
ok($zip->set_number('9300344')->is_valid_number, '富山県中新川郡上市町森元町');
ok($zip->set_number('9300345')->is_valid_number, '富山県中新川郡上市町南町');
ok($zip->set_number('9300346')->is_valid_number, '富山県中新川郡上市町鍵町');
ok($zip->set_number('9300347')->is_valid_number, '富山県中新川郡上市町熊野町');
ok($zip->set_number('9300351')->is_valid_number, '富山県中新川郡上市町北島');
ok($zip->set_number('9300352')->is_valid_number, '富山県中新川郡上市町上法音寺');
ok($zip->set_number('9300353')->is_valid_number, '富山県中新川郡上市町法音寺');
ok($zip->set_number('9300354')->is_valid_number, '富山県中新川郡上市町大坪');
ok($zip->set_number('9300355')->is_valid_number, '富山県中新川郡上市町横法音寺');
ok($zip->set_number('9300356')->is_valid_number, '富山県中新川郡上市町上正');
ok($zip->set_number('9300357')->is_valid_number, '富山県中新川郡上市町正印');
ok($zip->set_number('9300358')->is_valid_number, '富山県中新川郡上市町正印新');
ok($zip->set_number('9300359')->is_valid_number, '富山県中新川郡上市町四葉台');
ok($zip->set_number('9300361')->is_valid_number, '富山県中新川郡上市町湯上野');
ok($zip->set_number('9300362')->is_valid_number, '富山県中新川郡上市町稗田');
ok($zip->set_number('9300363')->is_valid_number, '富山県中新川郡上市町和合');
ok($zip->set_number('9300364')->is_valid_number, '富山県中新川郡上市町横越');
ok($zip->set_number('9300365')->is_valid_number, '富山県中新川郡上市町神田');
ok($zip->set_number('9300366')->is_valid_number, '富山県中新川郡上市町新村');
ok($zip->set_number('9300367')->is_valid_number, '富山県中新川郡上市町野福');
ok($zip->set_number('9300368')->is_valid_number, '富山県中新川郡上市町川原田');
ok($zip->set_number('9300371')->is_valid_number, '富山県中新川郡上市町中開発');
ok($zip->set_number('9300372')->is_valid_number, '富山県中新川郡上市町上経田');
ok($zip->set_number('9300373')->is_valid_number, '富山県中新川郡上市町下経田');
ok($zip->set_number('9300374')->is_valid_number, '富山県中新川郡上市町相ノ木新町');
ok($zip->set_number('9300375')->is_valid_number, '富山県中新川郡上市町上荒又');
ok($zip->set_number('9300376')->is_valid_number, '富山県中新川郡上市町下荒又');
ok($zip->set_number('9300377')->is_valid_number, '富山県中新川郡上市町新清水');
ok($zip->set_number('9300378')->is_valid_number, '富山県中新川郡上市町放士ケ瀬');
ok($zip->set_number('9300379')->is_valid_number, '富山県中新川郡上市町放士ケ瀬新');
ok($zip->set_number('9300381')->is_valid_number, '富山県中新川郡上市町久金');
ok($zip->set_number('9300382')->is_valid_number, '富山県中新川郡上市町下青出');
ok($zip->set_number('9300383')->is_valid_number, '富山県中新川郡上市町上条沖');
ok($zip->set_number('9300384')->is_valid_number, '富山県中新川郡上市町青出新');
ok($zip->set_number('9300385')->is_valid_number, '富山県中新川郡上市町飯坂');
ok($zip->set_number('9300386')->is_valid_number, '富山県中新川郡上市町中青出');
ok($zip->set_number('9300387')->is_valid_number, '富山県中新川郡上市町飯坂新');
ok($zip->set_number('9300388')->is_valid_number, '富山県中新川郡上市町久金新');
ok($zip->set_number('9300401')->is_valid_number, '富山県中新川郡上市町広野新');
ok($zip->set_number('9300402')->is_valid_number, '富山県中新川郡上市町広市新');
ok($zip->set_number('9300403')->is_valid_number, '富山県中新川郡上市町野開発');
ok($zip->set_number('9300404')->is_valid_number, '富山県中新川郡上市町三杉町');
ok($zip->set_number('9300405')->is_valid_number, '富山県中新川郡上市町郷柿沢');
ok($zip->set_number('9300406')->is_valid_number, '富山県中新川郡上市町柿沢新');
ok($zip->set_number('9300411')->is_valid_number, '富山県中新川郡上市町砂林開');
ok($zip->set_number('9300412')->is_valid_number, '富山県中新川郡上市町広野');
ok($zip->set_number('9300413')->is_valid_number, '富山県中新川郡上市町一の越');
ok($zip->set_number('9300414')->is_valid_number, '富山県中新川郡上市町永代');
ok($zip->set_number('9300415')->is_valid_number, '富山県中新川郡上市町松原野');
ok($zip->set_number('9300416')->is_valid_number, '富山県中新川郡上市町黒川');
ok($zip->set_number('9300417')->is_valid_number, '富山県中新川郡上市町五位尾');
ok($zip->set_number('9300421')->is_valid_number, '富山県中新川郡上市町片地');
ok($zip->set_number('9300422')->is_valid_number, '富山県中新川郡上市町眼目');
ok($zip->set_number('9300423')->is_valid_number, '富山県中新川郡上市町野島');
ok($zip->set_number('9300424')->is_valid_number, '富山県中新川郡上市町斉ノ神新');
ok($zip->set_number('9300425')->is_valid_number, '富山県中新川郡上市町田島野');
ok($zip->set_number('9300431')->is_valid_number, '富山県中新川郡上市町釈泉寺');
ok($zip->set_number('9300432')->is_valid_number, '富山県中新川郡上市町稲村');
ok($zip->set_number('9300433')->is_valid_number, '富山県中新川郡上市町中村');
ok($zip->set_number('9300434')->is_valid_number, '富山県中新川郡上市町下田');
ok($zip->set_number('9300435')->is_valid_number, '富山県中新川郡上市町折戸');
ok($zip->set_number('9300436')->is_valid_number, '富山県中新川郡上市町蓬沢');
ok($zip->set_number('9300437')->is_valid_number, '富山県中新川郡上市町伊折');
ok($zip->set_number('9300438')->is_valid_number, '富山県中新川郡上市町馬場島');
ok($zip->set_number('9300441')->is_valid_number, '富山県中新川郡上市町東種');
ok($zip->set_number('9300442')->is_valid_number, '富山県中新川郡上市町千石');
ok($zip->set_number('9300443')->is_valid_number, '富山県中新川郡上市町骨原');
ok($zip->set_number('9300444')->is_valid_number, '富山県中新川郡上市町西種');
ok($zip->set_number('9300445')->is_valid_number, '富山県中新川郡上市町水上');
ok($zip->set_number('9300451')->is_valid_number, '富山県中新川郡上市町極楽寺');
ok($zip->set_number('9300452')->is_valid_number, '富山県中新川郡上市町須山');
ok($zip->set_number('9300453')->is_valid_number, '富山県中新川郡上市町堤谷');
ok($zip->set_number('9300454')->is_valid_number, '富山県中新川郡上市町湯神子');
ok($zip->set_number('9300455')->is_valid_number, '富山県中新川郡上市町湯崎野');
ok($zip->set_number('9300456')->is_valid_number, '富山県中新川郡上市町丸山');
ok($zip->set_number('9300457')->is_valid_number, '富山県中新川郡上市町湯神子野');
ok($zip->set_number('9300458')->is_valid_number, '富山県中新川郡上市町眼目新');
ok($zip->set_number('9300461')->is_valid_number, '富山県中新川郡上市町大松新');
ok($zip->set_number('9300462')->is_valid_number, '富山県中新川郡上市町大松');
ok($zip->set_number('9300463')->is_valid_number, '富山県中新川郡上市町大岩');
ok($zip->set_number('9300464')->is_valid_number, '富山県中新川郡上市町浅生');
ok($zip->set_number('9300465')->is_valid_number, '富山県中新川郡上市町大沢');
ok($zip->set_number('9300466')->is_valid_number, '富山県中新川郡上市町桧谷');
ok($zip->set_number('9300467')->is_valid_number, '富山県中新川郡上市町塩谷');
ok($zip->set_number('9300471')->is_valid_number, '富山県中新川郡上市町新屋');
ok($zip->set_number('9300472')->is_valid_number, '富山県中新川郡上市町女川');
ok($zip->set_number('9300473')->is_valid_number, '富山県中新川郡上市町柿沢');
ok($zip->set_number('9300474')->is_valid_number, '富山県中新川郡上市町舘');
ok($zip->set_number('9300801')->is_valid_number, '富山県富山市中島');
ok($zip->set_number('9300802')->is_valid_number, '富山県富山市下新北町');
ok($zip->set_number('9300803')->is_valid_number, '富山県富山市下新本町');
ok($zip->set_number('9300804')->is_valid_number, '富山県富山市下新町');
ok($zip->set_number('9300805')->is_valid_number, '富山県富山市湊入船町');
ok($zip->set_number('9300806')->is_valid_number, '富山県富山市木場町');
ok($zip->set_number('9300807')->is_valid_number, '富山県富山市下新西町');
ok($zip->set_number('9300808')->is_valid_number, '富山県富山市下新日曹町');
ok($zip->set_number('9300809')->is_valid_number, '富山県富山市興人町');
ok($zip->set_number('9300811')->is_valid_number, '富山県富山市千代田町');
ok($zip->set_number('9300812')->is_valid_number, '富山県富山市松若町');
ok($zip->set_number('9300813')->is_valid_number, '富山県富山市下赤江町');
ok($zip->set_number('9300814')->is_valid_number, '富山県富山市下冨居');
ok($zip->set_number('9300815')->is_valid_number, '富山県富山市千成町');
ok($zip->set_number('9300816')->is_valid_number, '富山県富山市上赤江町');
ok($zip->set_number('9300817')->is_valid_number, '富山県富山市下奥井');
ok($zip->set_number('9300818')->is_valid_number, '富山県富山市奥田町');
ok($zip->set_number('9300819')->is_valid_number, '富山県富山市奥田本町');
ok($zip->set_number('9300821')->is_valid_number, '富山県富山市飯野');
ok($zip->set_number('9300822')->is_valid_number, '富山県富山市新屋');
ok($zip->set_number('9300823')->is_valid_number, '富山県富山市新屋新町');
ok($zip->set_number('9300824')->is_valid_number, '富山県富山市鶴ケ丘町');
ok($zip->set_number('9300825')->is_valid_number, '富山県富山市上飯野新町');
ok($zip->set_number('9300826')->is_valid_number, '富山県富山市上庄町');
ok($zip->set_number('9300827')->is_valid_number, '富山県富山市上飯野');
ok($zip->set_number('9300830')->is_valid_number, '富山県富山市中冨居新町');
ok($zip->set_number('9300831')->is_valid_number, '富山県富山市鍋田');
ok($zip->set_number('9300832')->is_valid_number, '富山県富山市中冨居');
ok($zip->set_number('9300833')->is_valid_number, '富山県富山市冨居栄町');
ok($zip->set_number('9300834')->is_valid_number, '富山県富山市問屋町');
ok($zip->set_number('9300835')->is_valid_number, '富山県富山市上冨居');
ok($zip->set_number('9300836')->is_valid_number, '富山県富山市上冨居新町');
ok($zip->set_number('9300837')->is_valid_number, '富山県富山市上赤江');
ok($zip->set_number('9300838')->is_valid_number, '富山県富山市下赤江');
ok($zip->set_number('9300839')->is_valid_number, '富山県富山市新冨居');
ok($zip->set_number('9300841')->is_valid_number, '富山県富山市四ツ葉町');
ok($zip->set_number('9300842')->is_valid_number, '富山県富山市窪新町');
ok($zip->set_number('9300843')->is_valid_number, '富山県富山市窪本町');
ok($zip->set_number('9300845')->is_valid_number, '富山県富山市綾田町');
ok($zip->set_number('9300846')->is_valid_number, '富山県富山市奥井町');
ok($zip->set_number('9300847')->is_valid_number, '富山県富山市曙町');
ok($zip->set_number('9300848')->is_valid_number, '富山県富山市久方町');
ok($zip->set_number('9300849')->is_valid_number, '富山県富山市稲荷園町');
ok($zip->set_number('9300851')->is_valid_number, '富山県富山市奥田双葉町');
ok($zip->set_number('9300852')->is_valid_number, '富山県富山市奥田寿町');
ok($zip->set_number('9300853')->is_valid_number, '富山県富山市永楽町');
ok($zip->set_number('9300854')->is_valid_number, '富山県富山市城北町');
ok($zip->set_number('9300855')->is_valid_number, '富山県富山市赤江町');
ok($zip->set_number('9300856')->is_valid_number, '富山県富山市牛島新町');
ok($zip->set_number('9300857')->is_valid_number, '富山県富山市奥田新町');
ok($zip->set_number('9300858')->is_valid_number, '富山県富山市牛島町');
ok($zip->set_number('9300859')->is_valid_number, '富山県富山市牛島本町');
ok($zip->set_number('9300861')->is_valid_number, '富山県富山市有沢新町');
ok($zip->set_number('9300862')->is_valid_number, '富山県富山市有沢');
ok($zip->set_number('9300863')->is_valid_number, '富山県富山市有明町');
ok($zip->set_number('9300864')->is_valid_number, '富山県富山市羽根');
ok($zip->set_number('9300865')->is_valid_number, '富山県富山市久郷');
ok($zip->set_number('9300866')->is_valid_number, '富山県富山市高田');
ok($zip->set_number('9300867')->is_valid_number, '富山県富山市庄高田');
ok($zip->set_number('9300871')->is_valid_number, '富山県富山市下野');
ok($zip->set_number('9300872')->is_valid_number, '富山県富山市下野新');
ok($zip->set_number('9300873')->is_valid_number, '富山県富山市金屋');
ok($zip->set_number('9300874')->is_valid_number, '富山県富山市寺町');
ok($zip->set_number('9300875')->is_valid_number, '富山県富山市寺町けや木台');
ok($zip->set_number('9300876')->is_valid_number, '富山県富山市文京町');
ok($zip->set_number('9300881')->is_valid_number, '富山県富山市安養坊');
ok($zip->set_number('9300882')->is_valid_number, '富山県富山市五艘');
ok($zip->set_number('9300883')->is_valid_number, '富山県富山市五福新町');
ok($zip->set_number('9300884')->is_valid_number, '富山県富山市五福末広町');
ok($zip->set_number('9300885')->is_valid_number, '富山県富山市鵯島');
ok($zip->set_number('9300886')->is_valid_number, '富山県富山市ひよどり南台');
ok($zip->set_number('9300887')->is_valid_number, '富山県富山市五福');
ok($zip->set_number('9300891')->is_valid_number, '富山県富山市石坂新');
ok($zip->set_number('9300892')->is_valid_number, '富山県富山市石坂');
ok($zip->set_number('9300893')->is_valid_number, '富山県富山市石坂東町');
ok($zip->set_number('9300894')->is_valid_number, '富山県富山市田刈屋新町');
ok($zip->set_number('9300895')->is_valid_number, '富山県富山市駒見');
ok($zip->set_number('9300896')->is_valid_number, '富山県富山市畑中');
ok($zip->set_number('9300897')->is_valid_number, '富山県富山市田刈屋');
ok($zip->set_number('9300898')->is_valid_number, '富山県富山市桜谷みどり町');
ok($zip->set_number('9300901')->is_valid_number, '富山県富山市手屋');
ok($zip->set_number('9300902')->is_valid_number, '富山県富山市宮成新');
ok($zip->set_number('9300903')->is_valid_number, '富山県富山市中野新');
ok($zip->set_number('9300904')->is_valid_number, '富山県富山市一本木');
ok($zip->set_number('9300905')->is_valid_number, '富山県富山市五本榎');
ok($zip->set_number('9300906')->is_valid_number, '富山県富山市金泉寺');
ok($zip->set_number('9300911')->is_valid_number, '富山県富山市本郷島');
ok($zip->set_number('9300912')->is_valid_number, '富山県富山市日俣');
ok($zip->set_number('9300913')->is_valid_number, '富山県富山市荏原新町');
ok($zip->set_number('9300914')->is_valid_number, '富山県富山市荏原');
ok($zip->set_number('9300915')->is_valid_number, '富山県富山市荏原駅前通り');
ok($zip->set_number('9300916')->is_valid_number, '富山県富山市向新庄');
ok($zip->set_number('9300916')->is_valid_number, '富山県富山市向新庄町');
ok($zip->set_number('9300921')->is_valid_number, '富山県富山市中間島');
ok($zip->set_number('9300922')->is_valid_number, '富山県富山市大江干');
ok($zip->set_number('9300923')->is_valid_number, '富山県富山市町新');
ok($zip->set_number('9300924')->is_valid_number, '富山県富山市新金代');
ok($zip->set_number('9300925')->is_valid_number, '富山県富山市栄新町');
ok($zip->set_number('9300926')->is_valid_number, '富山県富山市金代');
ok($zip->set_number('9300927')->is_valid_number, '富山県富山市大江干新町');
ok($zip->set_number('9300928')->is_valid_number, '富山県富山市富岡町');
ok($zip->set_number('9300931')->is_valid_number, '富山県富山市朝日');
ok($zip->set_number('9300932')->is_valid_number, '富山県富山市藤木新町');
ok($zip->set_number('9300933')->is_valid_number, '富山県富山市藤木新');
ok($zip->set_number('9300934')->is_valid_number, '富山県富山市藤の木台');
ok($zip->set_number('9300935')->is_valid_number, '富山県富山市藤見町');
ok($zip->set_number('9300936')->is_valid_number, '富山県富山市藤木');
ok($zip->set_number('9300941')->is_valid_number, '富山県富山市藤木中町');
ok($zip->set_number('9300942')->is_valid_number, '富山県富山市藤の木園町');
ok($zip->set_number('9300943')->is_valid_number, '富山県富山市藤代町');
ok($zip->set_number('9300944')->is_valid_number, '富山県富山市開');
ok($zip->set_number('9300951')->is_valid_number, '富山県富山市経堂');
ok($zip->set_number('9300952')->is_valid_number, '富山県富山市町村');
ok($zip->set_number('9300953')->is_valid_number, '富山県富山市秋吉');
ok($zip->set_number('9300954')->is_valid_number, '富山県富山市秋吉新町');
ok($zip->set_number('9300955')->is_valid_number, '富山県富山市天正寺');
ok($zip->set_number('9300956')->is_valid_number, '富山県富山市経堂新町');
ok($zip->set_number('9300961')->is_valid_number, '富山県富山市西長江本町');
ok($zip->set_number('9300962')->is_valid_number, '富山県富山市長江本町');
ok($zip->set_number('9300963')->is_valid_number, '富山県富山市不二越町');
ok($zip->set_number('9300964')->is_valid_number, '富山県富山市東石金町');
ok($zip->set_number('9300965')->is_valid_number, '富山県富山市不二越本町');
ok($zip->set_number('9300966')->is_valid_number, '富山県富山市石金');
ok($zip->set_number('9300971')->is_valid_number, '富山県富山市双代町');
ok($zip->set_number('9300972')->is_valid_number, '富山県富山市長江新町');
ok($zip->set_number('9300973')->is_valid_number, '富山県富山市長江東町');
ok($zip->set_number('9300974')->is_valid_number, '富山県富山市長江');
ok($zip->set_number('9300975')->is_valid_number, '富山県富山市西長江');
ok($zip->set_number('9300981')->is_valid_number, '富山県富山市西新庄');
ok($zip->set_number('9300982')->is_valid_number, '富山県富山市荒川');
ok($zip->set_number('9300983')->is_valid_number, '富山県富山市荒川常盤台');
ok($zip->set_number('9300983')->is_valid_number, '富山県富山市常盤台');
ok($zip->set_number('9300984')->is_valid_number, '富山県富山市荒川新町');
ok($zip->set_number('9300985')->is_valid_number, '富山県富山市田中町');
ok($zip->set_number('9300991')->is_valid_number, '富山県富山市新庄銀座');
ok($zip->set_number('9300992')->is_valid_number, '富山県富山市新庄町');
ok($zip->set_number('9300993')->is_valid_number, '富山県富山市新園町');
ok($zip->set_number('9300994')->is_valid_number, '富山県富山市新庄新町');
ok($zip->set_number('9300995')->is_valid_number, '富山県富山市新庄中央町');
ok($zip->set_number('9300996')->is_valid_number, '富山県富山市新庄本町');
ok($zip->set_number('9300997')->is_valid_number, '富山県富山市新庄北町');
ok($zip->set_number('9301261')->is_valid_number, '富山県富山市東福沢(津毛)');
ok($zip->set_number('9301262')->is_valid_number, '富山県富山市東黒牧');
ok($zip->set_number('9301263')->is_valid_number, '富山県富山市東黒牧(上野)');
ok($zip->set_number('9301264')->is_valid_number, '富山県富山市大山布目');
ok($zip->set_number('9301265')->is_valid_number, '富山県富山市小谷');
ok($zip->set_number('9301266')->is_valid_number, '富山県富山市砂見');
ok($zip->set_number('9301267')->is_valid_number, '富山県富山市砂見(芋平)');
ok($zip->set_number('9301268')->is_valid_number, '富山県富山市楜ケ原');
ok($zip->set_number('9301271')->is_valid_number, '富山県富山市石渕');
ok($zip->set_number('9301272')->is_valid_number, '富山県富山市下双嶺');
ok($zip->set_number('9301273')->is_valid_number, '富山県富山市小坂');
ok($zip->set_number('9301274')->is_valid_number, '富山県富山市大双嶺');
ok($zip->set_number('9301275')->is_valid_number, '富山県富山市大清水');
ok($zip->set_number('9301276')->is_valid_number, '富山県富山市折谷');
ok($zip->set_number('9301281')->is_valid_number, '富山県富山市東福沢');
ok($zip->set_number('9301282')->is_valid_number, '富山県富山市牧野');
ok($zip->set_number('9301283')->is_valid_number, '富山県富山市日尾');
ok($zip->set_number('9301284')->is_valid_number, '富山県富山市馬瀬');
ok($zip->set_number('9301285')->is_valid_number, '富山県富山市瀬戸');
ok($zip->set_number('9301286')->is_valid_number, '富山県富山市小佐波');
ok($zip->set_number('9301287')->is_valid_number, '富山県富山市東福沢(火土呂)');
ok($zip->set_number('9301301')->is_valid_number, '富山県富山市馬瀬口');
ok($zip->set_number('9301302')->is_valid_number, '富山県富山市馬瀬口(殿様林)');
ok($zip->set_number('9301303')->is_valid_number, '富山県富山市善名');
ok($zip->set_number('9301304')->is_valid_number, '富山県富山市南大場');
ok($zip->set_number('9301305')->is_valid_number, '富山県富山市下番');
ok($zip->set_number('9301311')->is_valid_number, '富山県富山市大山北新町');
ok($zip->set_number('9301312')->is_valid_number, '富山県富山市上滝');
ok($zip->set_number('9301313')->is_valid_number, '富山県富山市中滝');
ok($zip->set_number('9301314')->is_valid_number, '富山県富山市三室荒屋');
ok($zip->set_number('9301315')->is_valid_number, '富山県富山市中番');
ok($zip->set_number('9301316')->is_valid_number, '富山県富山市中番(新栄町)');
ok($zip->set_number('9301316')->is_valid_number, '富山県富山市三室荒屋(新栄町)');
ok($zip->set_number('9301321')->is_valid_number, '富山県富山市新町');
ok($zip->set_number('9301321')->is_valid_number, '富山県富山市大山上野');
ok($zip->set_number('9301322')->is_valid_number, '富山県富山市岡田');
ok($zip->set_number('9301323')->is_valid_number, '富山県富山市東小俣');
ok($zip->set_number('9301324')->is_valid_number, '富山県富山市西小俣');
ok($zip->set_number('9301325')->is_valid_number, '富山県富山市文珠寺');
ok($zip->set_number('9301326')->is_valid_number, '富山県富山市花崎');
ok($zip->set_number('9301327')->is_valid_number, '富山県富山市大栗');
ok($zip->set_number('9301328')->is_valid_number, '富山県富山市小原屋');
ok($zip->set_number('9301331')->is_valid_number, '富山県富山市田畠');
ok($zip->set_number('9301332')->is_valid_number, '富山県富山市津羽見');
ok($zip->set_number('9301333')->is_valid_number, '富山県富山市上大浦');
ok($zip->set_number('9301334')->is_valid_number, '富山県富山市中大浦');
ok($zip->set_number('9301335')->is_valid_number, '富山県富山市下大浦');
ok($zip->set_number('9301336')->is_valid_number, '富山県富山市桑原');
ok($zip->set_number('9301337')->is_valid_number, '富山県富山市田畠(風見台)');
ok($zip->set_number('9301338')->is_valid_number, '富山県富山市田畠(明日美野)');
ok($zip->set_number('9301361')->is_valid_number, '富山県中新川郡立山町伊豆林');
ok($zip->set_number('9301361')->is_valid_number, '富山県中新川郡立山町下田');
ok($zip->set_number('9301362')->is_valid_number, '富山県中新川郡立山町吉峰野開');
ok($zip->set_number('9301362')->is_valid_number, '富山県中新川郡立山町米道(谷内、東谷)');
ok($zip->set_number('9301363')->is_valid_number, '富山県中新川郡立山町栃津');
ok($zip->set_number('9301364')->is_valid_number, '富山県中新川郡立山町天林');
ok($zip->set_number('9301365')->is_valid_number, '富山県中新川郡立山町東中野新');
ok($zip->set_number('9301366')->is_valid_number, '富山県中新川郡立山町横江野開');
ok($zip->set_number('9301367')->is_valid_number, '富山県中新川郡立山町宮路');
ok($zip->set_number('9301368')->is_valid_number, '富山県中新川郡立山町岩峅寺');
ok($zip->set_number('9301369')->is_valid_number, '富山県中新川郡立山町岩峅野');
ok($zip->set_number('9301377')->is_valid_number, '富山県中新川郡立山町横江(立山地区)');
ok($zip->set_number('9301401')->is_valid_number, '富山県中新川郡立山町称名');
ok($zip->set_number('9301402')->is_valid_number, '富山県中新川郡立山町桂台');
ok($zip->set_number('9301403')->is_valid_number, '富山県中新川郡立山町ブナ坂');
ok($zip->set_number('9301404')->is_valid_number, '富山県中新川郡立山町藤橋');
ok($zip->set_number('9301405')->is_valid_number, '富山県中新川郡立山町千寿ケ原');
ok($zip->set_number('9301406')->is_valid_number, '富山県中新川郡立山町芦峅寺');
ok($zip->set_number('9301407')->is_valid_number, '富山県中新川郡立山町前谷');
ok($zip->set_number('9301408')->is_valid_number, '富山県中新川郡立山町千垣');
ok($zip->set_number('9301411')->is_valid_number, '富山県中新川郡立山町美女平');
ok($zip->set_number('9301412')->is_valid_number, '富山県中新川郡立山町弥陀ケ原');
ok($zip->set_number('9301413')->is_valid_number, '富山県中新川郡立山町天狗平');
ok($zip->set_number('9301414')->is_valid_number, '富山県中新川郡立山町室堂');
ok($zip->set_number('9301415')->is_valid_number, '富山県中新川郡立山町雷鳥沢');
ok($zip->set_number('9301416')->is_valid_number, '富山県中新川郡立山町剣御前');
ok($zip->set_number('9301417')->is_valid_number, '富山県中新川郡立山町剣沢');
ok($zip->set_number('9301418')->is_valid_number, '富山県中新川郡立山町立山頂上');
ok($zip->set_number('9301451')->is_valid_number, '富山県富山市本宮(粟巣野)');
ok($zip->set_number('9301452')->is_valid_number, '富山県富山市本宮(花切割)');
ok($zip->set_number('9301453')->is_valid_number, '富山県富山市原(極楽坂)');
ok($zip->set_number('9301454')->is_valid_number, '富山県富山市原');
ok($zip->set_number('9301455')->is_valid_number, '富山県富山市本宮');
ok($zip->set_number('9301456')->is_valid_number, '富山県富山市小見');
ok($zip->set_number('9301457')->is_valid_number, '富山県富山市有峰(太郎平)');
ok($zip->set_number('9301458')->is_valid_number, '富山県富山市有峰');
ok($zip->set_number('9301459')->is_valid_number, '富山県富山市亀谷');
ok($zip->set_number('9301461')->is_valid_number, '富山県富山市和田');
ok($zip->set_number('9301462')->is_valid_number, '富山県富山市中地山');
ok($zip->set_number('9301463')->is_valid_number, '富山県富山市水須');
ok($zip->set_number('9301464')->is_valid_number, '富山県富山市才覚地');
ok($zip->set_number('9301465')->is_valid_number, '富山県富山市牧');
ok($zip->set_number('9301466')->is_valid_number, '富山県富山市大山松木');
ok($zip->set_number('9302101')->is_valid_number, '富山県富山市山田中瀬');
ok($zip->set_number('9302102')->is_valid_number, '富山県富山市山田宿坊');
ok($zip->set_number('9302103')->is_valid_number, '富山県富山市山田宿坊(柳川)');
ok($zip->set_number('9302104')->is_valid_number, '富山県富山市山田宿坊(沢連)');
ok($zip->set_number('9302105')->is_valid_number, '富山県富山市山田湯');
ok($zip->set_number('9302106')->is_valid_number, '富山県富山市山田北山');
ok($zip->set_number('9302107')->is_valid_number, '富山県富山市山田中瀬(竹の内)');
ok($zip->set_number('9302108')->is_valid_number, '富山県富山市山田中瀬(上中瀬)');
ok($zip->set_number('9302111')->is_valid_number, '富山県富山市山田鎌倉');
ok($zip->set_number('9302112')->is_valid_number, '富山県富山市山田若土');
ok($zip->set_number('9302113')->is_valid_number, '富山県富山市山田谷');
ok($zip->set_number('9302114')->is_valid_number, '富山県富山市山田居舟');
ok($zip->set_number('9302114')->is_valid_number, '富山県富山市山田鍋谷');
ok($zip->set_number('9302115')->is_valid_number, '富山県富山市山田小谷');
ok($zip->set_number('9302116')->is_valid_number, '富山県富山市山田小谷(中根)');
ok($zip->set_number('9302117')->is_valid_number, '富山県富山市山田赤目谷');
ok($zip->set_number('9302121')->is_valid_number, '富山県富山市山田白井谷');
ok($zip->set_number('9302122')->is_valid_number, '富山県富山市山田小島(城山)');
ok($zip->set_number('9302123')->is_valid_number, '富山県富山市山田小島');
ok($zip->set_number('9302124')->is_valid_number, '富山県富山市山田中村');
ok($zip->set_number('9302125')->is_valid_number, '富山県富山市山田今山田');
ok($zip->set_number('9302126')->is_valid_number, '富山県富山市山田清水');
ok($zip->set_number('9302127')->is_valid_number, '富山県富山市山田牧');
ok($zip->set_number('9302128')->is_valid_number, '富山県富山市山田沼又');
ok($zip->set_number('9302201')->is_valid_number, '富山県富山市草島');
ok($zip->set_number('9302202')->is_valid_number, '富山県富山市富浦町');
ok($zip->set_number('9302203')->is_valid_number, '富山県富山市新千原崎');
ok($zip->set_number('9302204')->is_valid_number, '富山県富山市金山新桜ケ丘');
ok($zip->set_number('9302205')->is_valid_number, '富山県富山市金山新東');
ok($zip->set_number('9302206')->is_valid_number, '富山県富山市金山新');
ok($zip->set_number('9302206')->is_valid_number, '富山県富山市金山新中');
ok($zip->set_number('9302206')->is_valid_number, '富山県富山市金山新西');
ok($zip->set_number('9302206')->is_valid_number, '富山県富山市金山新南');
ok($zip->set_number('9302206')->is_valid_number, '富山県富山市金山新北');
ok($zip->set_number('9302207')->is_valid_number, '富山県富山市草島新町');
ok($zip->set_number('9302208')->is_valid_number, '富山県富山市古川');
ok($zip->set_number('9302211')->is_valid_number, '富山県富山市宮尾');
ok($zip->set_number('9302212')->is_valid_number, '富山県富山市松木新');
ok($zip->set_number('9302213')->is_valid_number, '富山県富山市松木');
ok($zip->set_number('9302214')->is_valid_number, '富山県富山市百塚');
ok($zip->set_number('9302215')->is_valid_number, '富山県富山市山岸');
ok($zip->set_number('9302221')->is_valid_number, '富山県富山市今市');
ok($zip->set_number('9302222')->is_valid_number, '富山県富山市八幡');
ok($zip->set_number('9302223')->is_valid_number, '富山県富山市八幡新町');
ok($zip->set_number('9302224')->is_valid_number, '富山県富山市田尻');
ok($zip->set_number('9302224')->is_valid_number, '富山県富山市田尻東');
ok($zip->set_number('9302224')->is_valid_number, '富山県富山市田尻西');
ok($zip->set_number('9302224')->is_valid_number, '富山県富山市田尻南');
ok($zip->set_number('9302225')->is_valid_number, '富山県富山市寺島');
ok($zip->set_number('9302226')->is_valid_number, '富山県富山市八町');
ok($zip->set_number('9302226')->is_valid_number, '富山県富山市八町中');
ok($zip->set_number('9302226')->is_valid_number, '富山県富山市八町東');
ok($zip->set_number('9302226')->is_valid_number, '富山県富山市八町西');
ok($zip->set_number('9302226')->is_valid_number, '富山県富山市八町南');
ok($zip->set_number('9302226')->is_valid_number, '富山県富山市八町北');
ok($zip->set_number('9302227')->is_valid_number, '富山県富山市利波');
ok($zip->set_number('9302231')->is_valid_number, '富山県富山市布目東町');
ok($zip->set_number('9302232')->is_valid_number, '富山県富山市布目南町');
ok($zip->set_number('9302233')->is_valid_number, '富山県富山市布目');
ok($zip->set_number('9302233')->is_valid_number, '富山県富山市布目西');
ok($zip->set_number('9302233')->is_valid_number, '富山県富山市布目北');
ok($zip->set_number('9302234')->is_valid_number, '富山県富山市布目緑町');
ok($zip->set_number('9302235')->is_valid_number, '富山県富山市布目新町');
ok($zip->set_number('9302236')->is_valid_number, '富山県富山市布目旭');
ok($zip->set_number('9302237')->is_valid_number, '富山県富山市打出');
ok($zip->set_number('9302238')->is_valid_number, '富山県富山市打出新');
ok($zip->set_number('9302239')->is_valid_number, '富山県富山市つばめ野');
ok($zip->set_number('9302241')->is_valid_number, '富山県富山市四方西岩瀬');
ok($zip->set_number('9302242')->is_valid_number, '富山県富山市四方北窪');
ok($zip->set_number('9302243')->is_valid_number, '富山県富山市四方');
ok($zip->set_number('9302243')->is_valid_number, '富山県富山市四方荒屋');
ok($zip->set_number('9302244')->is_valid_number, '富山県富山市四方茶園町');
ok($zip->set_number('9302245')->is_valid_number, '富山県富山市四方江代町');
ok($zip->set_number('9302246')->is_valid_number, '富山県富山市四方新');
ok($zip->set_number('9302247')->is_valid_number, '富山県富山市四方新出町');
ok($zip->set_number('9302248')->is_valid_number, '富山県富山市四方南町');
ok($zip->set_number('9302251')->is_valid_number, '富山県富山市四方東野割町');
ok($zip->set_number('9302252')->is_valid_number, '富山県富山市四方西野割町');
ok($zip->set_number('9302252')->is_valid_number, '富山県富山市四方野割町');
ok($zip->set_number('9302253')->is_valid_number, '富山県富山市四方田町');
ok($zip->set_number('9302254')->is_valid_number, '富山県富山市四方神明町');
ok($zip->set_number('9302255')->is_valid_number, '富山県富山市四方一番町');
ok($zip->set_number('9302256')->is_valid_number, '富山県富山市四方港町');
ok($zip->set_number('9302257')->is_valid_number, '富山県富山市四方二番町');
ok($zip->set_number('9302258')->is_valid_number, '富山県富山市四方恵比須町');
ok($zip->set_number('9303201')->is_valid_number, '富山県中新川郡立山町高原');
ok($zip->set_number('9303202')->is_valid_number, '富山県中新川郡立山町女川新');
ok($zip->set_number('9303203')->is_valid_number, '富山県中新川郡立山町上福来');
ok($zip->set_number('9303204')->is_valid_number, '富山県中新川郡立山町東野');
ok($zip->set_number('9303205')->is_valid_number, '富山県中新川郡立山町福来');
ok($zip->set_number('9303206')->is_valid_number, '富山県中新川郡立山町竹林');
ok($zip->set_number('9303208')->is_valid_number, '富山県中新川郡立山町下新');
ok($zip->set_number('9303211')->is_valid_number, '富山県中新川郡立山町日中');
ok($zip->set_number('9303212')->is_valid_number, '富山県中新川郡立山町柴山');
ok($zip->set_number('9303213')->is_valid_number, '富山県中新川郡立山町日中上野');
ok($zip->set_number('9303214')->is_valid_number, '富山県中新川郡立山町下白岩');
ok($zip->set_number('9303215')->is_valid_number, '富山県中新川郡立山町石坂');
ok($zip->set_number('9303216')->is_valid_number, '富山県中新川郡立山町福田');
ok($zip->set_number('9303217')->is_valid_number, '富山県中新川郡立山町野沢');
ok($zip->set_number('9303221')->is_valid_number, '富山県中新川郡立山町四谷尾');
ok($zip->set_number('9303222')->is_valid_number, '富山県中新川郡立山町谷口');
ok($zip->set_number('9303223')->is_valid_number, '富山県中新川郡立山町虫谷');
ok($zip->set_number('9303224')->is_valid_number, '富山県中新川郡立山町白岩');
ok($zip->set_number('9303231')->is_valid_number, '富山県中新川郡立山町六郎谷');
ok($zip->set_number('9303232')->is_valid_number, '富山県中新川郡立山町目桑');
ok($zip->set_number('9303233')->is_valid_number, '富山県中新川郡立山町谷');
ok($zip->set_number('9303234')->is_valid_number, '富山県中新川郡立山町伊勢屋');
ok($zip->set_number('9303235')->is_valid_number, '富山県中新川郡立山町長倉');
ok($zip->set_number('9303236')->is_valid_number, '富山県中新川郡立山町小又');
ok($zip->set_number('9303237')->is_valid_number, '富山県中新川郡立山町松倉');
ok($zip->set_number('9303238')->is_valid_number, '富山県中新川郡立山町座主坊');
ok($zip->set_number('9303239')->is_valid_number, '富山県中新川郡立山町池田');
ok($zip->set_number('9303241')->is_valid_number, '富山県中新川郡立山町下沢');
ok($zip->set_number('9303242')->is_valid_number, '富山県中新川郡立山町芦見');
ok($zip->set_number('9303243')->is_valid_number, '富山県中新川郡立山町下瀬戸');
ok($zip->set_number('9303244')->is_valid_number, '富山県中新川郡立山町上瀬戸');
ok($zip->set_number('9303245')->is_valid_number, '富山県中新川郡立山町上末');
ok($zip->set_number('9303246')->is_valid_number, '富山県中新川郡立山町中林');
ok($zip->set_number('9303247')->is_valid_number, '富山県中新川郡立山町瀬戸新');
ok($zip->set_number('9303248')->is_valid_number, '富山県中新川郡立山町新瀬戸');
ok($zip->set_number('9303251')->is_valid_number, '富山県中新川郡立山町上中');
ok($zip->set_number('9303252')->is_valid_number, '富山県中新川郡立山町末上野');
ok($zip->set_number('9303253')->is_valid_number, '富山県中新川郡立山町長屋');
ok($zip->set_number('9303254')->is_valid_number, '富山県中新川郡立山町上宮');
ok($zip->set_number('9303255')->is_valid_number, '富山県中新川郡立山町小林');
ok($zip->set_number('9303261')->is_valid_number, '富山県中新川郡立山町野町');
ok($zip->set_number('9303262')->is_valid_number, '富山県中新川郡立山町金剛新');
ok($zip->set_number('9303263')->is_valid_number, '富山県中新川郡立山町渕上');
ok($zip->set_number('9303264')->is_valid_number, '富山県中新川郡立山町沢新');
ok($zip->set_number('9303265')->is_valid_number, '富山県中新川郡立山町米沢');
ok($zip->set_number('9303266')->is_valid_number, '富山県中新川郡立山町前沢新');
ok($zip->set_number('9303267')->is_valid_number, '富山県中新川郡立山町江崎');
ok($zip->set_number('9303277')->is_valid_number, '富山県中新川郡立山町横江(高野地区)');
ok($zip->set_number('9318301')->is_valid_number, '富山県富山市水落');
ok($zip->set_number('9318302')->is_valid_number, '富山県富山市緑陽町');
ok($zip->set_number('9318303')->is_valid_number, '富山県富山市米田');
ok($zip->set_number('9318304')->is_valid_number, '富山県富山市米田町');
ok($zip->set_number('9318305')->is_valid_number, '富山県富山市豊若町');
ok($zip->set_number('9318306')->is_valid_number, '富山県富山市米田すずかけ台');
ok($zip->set_number('9318311')->is_valid_number, '富山県富山市豊田');
ok($zip->set_number('9318312')->is_valid_number, '富山県富山市豊田本町');
ok($zip->set_number('9318313')->is_valid_number, '富山県富山市豊田町');
ok($zip->set_number('9318314')->is_valid_number, '富山県富山市粟島町');
ok($zip->set_number('9318315')->is_valid_number, '富山県富山市高園町');
ok($zip->set_number('9318316')->is_valid_number, '富山県富山市豊丘町');
ok($zip->set_number('9318321')->is_valid_number, '富山県富山市犬島');
ok($zip->set_number('9318322')->is_valid_number, '富山県富山市豊島町');
ok($zip->set_number('9318323')->is_valid_number, '富山県富山市豊城新町');
ok($zip->set_number('9318324')->is_valid_number, '富山県富山市豊城町');
ok($zip->set_number('9318325')->is_valid_number, '富山県富山市城川原');
ok($zip->set_number('9318326')->is_valid_number, '富山県富山市上野新町');
ok($zip->set_number('9318327')->is_valid_number, '富山県富山市上野新');
ok($zip->set_number('9318328')->is_valid_number, '富山県富山市犬島新町');
ok($zip->set_number('9318331')->is_valid_number, '富山県富山市森住町');
ok($zip->set_number('9318332')->is_valid_number, '富山県富山市森');
ok($zip->set_number('9318333')->is_valid_number, '富山県富山市蓮町');
ok($zip->set_number('9318334')->is_valid_number, '富山県富山市千原崎');
ok($zip->set_number('9318335')->is_valid_number, '富山県富山市西宮町');
ok($zip->set_number('9318336')->is_valid_number, '富山県富山市高畠町');
ok($zip->set_number('9318337')->is_valid_number, '富山県富山市森若町');
ok($zip->set_number('9318341')->is_valid_number, '富山県富山市岩瀬御蔵町');
ok($zip->set_number('9318342')->is_valid_number, '富山県富山市岩瀬神明町');
ok($zip->set_number('9318343')->is_valid_number, '富山県富山市岩瀬幸町');
ok($zip->set_number('9318344')->is_valid_number, '富山県富山市岩瀬新町');
ok($zip->set_number('9318345')->is_valid_number, '富山県富山市西宮');
ok($zip->set_number('9318346')->is_valid_number, '富山県富山市岩瀬荒木町');
ok($zip->set_number('9318347')->is_valid_number, '富山県富山市岩瀬土場町');
ok($zip->set_number('9318351')->is_valid_number, '富山県富山市岩瀬堺町');
ok($zip->set_number('9318352')->is_valid_number, '富山県富山市岩瀬表町');
ok($zip->set_number('9318353')->is_valid_number, '富山県富山市岩瀬文化町');
ok($zip->set_number('9318354')->is_valid_number, '富山県富山市岩瀬祇園町');
ok($zip->set_number('9318355')->is_valid_number, '富山県富山市岩瀬新川町');
ok($zip->set_number('9318356')->is_valid_number, '富山県富山市岩瀬大町');
ok($zip->set_number('9318357')->is_valid_number, '富山県富山市岩瀬福来町');
ok($zip->set_number('9318358')->is_valid_number, '富山県富山市東岩瀬町');
ok($zip->set_number('9318359')->is_valid_number, '富山県富山市東岩瀬村');
ok($zip->set_number('9318361')->is_valid_number, '富山県富山市岩瀬白山町');
ok($zip->set_number('9318362')->is_valid_number, '富山県富山市岩瀬梅本町');
ok($zip->set_number('9318363')->is_valid_number, '富山県富山市岩瀬仲町');
ok($zip->set_number('9318364')->is_valid_number, '富山県富山市岩瀬港町');
ok($zip->set_number('9318365')->is_valid_number, '富山県富山市岩瀬入船町');
ok($zip->set_number('9318366')->is_valid_number, '富山県富山市岩瀬萩浦町');
ok($zip->set_number('9318367')->is_valid_number, '富山県富山市岩瀬松原町');
ok($zip->set_number('9318371')->is_valid_number, '富山県富山市岩瀬古志町');
ok($zip->set_number('9318372')->is_valid_number, '富山県富山市岩瀬天池町');
ok($zip->set_number('9318373')->is_valid_number, '富山県富山市岩瀬前田町');
ok($zip->set_number('9318374')->is_valid_number, '富山県富山市岩瀬赤田町');
ok($zip->set_number('9318375')->is_valid_number, '富山県富山市岩瀬高畠町');
ok($zip->set_number('9318376')->is_valid_number, '富山県富山市岩瀬池田町');
ok($zip->set_number('9318377')->is_valid_number, '富山県富山市岩瀬諏訪町');
ok($zip->set_number('9318378')->is_valid_number, '富山県富山市岩瀬天神町');
ok($zip->set_number('9318401')->is_valid_number, '富山県富山市田畑新町');
ok($zip->set_number('9318402')->is_valid_number, '富山県富山市田畑北部');
ok($zip->set_number('9318403')->is_valid_number, '富山県富山市田畑');
ok($zip->set_number('9318404')->is_valid_number, '富山県富山市加古町');
ok($zip->set_number('9318405')->is_valid_number, '富山県富山市海岸通');
ok($zip->set_number('9318406')->is_valid_number, '富山県富山市松浦町');
ok($zip->set_number('9318407')->is_valid_number, '富山県富山市海岸通新町');
ok($zip->set_number('9318408')->is_valid_number, '富山県富山市那智町');
ok($zip->set_number('9318409')->is_valid_number, '富山県富山市清風町');
ok($zip->set_number('9318411')->is_valid_number, '富山県富山市高来');
ok($zip->set_number('9318412')->is_valid_number, '富山県富山市横越');
ok($zip->set_number('9318413')->is_valid_number, '富山県富山市野田');
ok($zip->set_number('9318414')->is_valid_number, '富山県富山市浜黒崎');
ok($zip->set_number('9318415')->is_valid_number, '富山県富山市針日');
ok($zip->set_number('9318416')->is_valid_number, '富山県富山市日方江');
ok($zip->set_number('9318417')->is_valid_number, '富山県富山市古志町');
ok($zip->set_number('9318421')->is_valid_number, '富山県富山市平榎');
ok($zip->set_number('9318422')->is_valid_number, '富山県富山市野中');
ok($zip->set_number('9318423')->is_valid_number, '富山県富山市町袋');
ok($zip->set_number('9318425')->is_valid_number, '富山県富山市宮成');
ok($zip->set_number('9318426')->is_valid_number, '富山県富山市宮成中部');
ok($zip->set_number('9318427')->is_valid_number, '富山県富山市宮条');
ok($zip->set_number('9318428')->is_valid_number, '富山県富山市野中新');
ok($zip->set_number('9318431')->is_valid_number, '富山県富山市針原中町');
ok($zip->set_number('9318432')->is_valid_number, '富山県富山市針原中');
ok($zip->set_number('9318433')->is_valid_number, '富山県富山市針原新町');
ok($zip->set_number('9318434')->is_valid_number, '富山県富山市三上');
ok($zip->set_number('9318435')->is_valid_number, '富山県富山市小西');
ok($zip->set_number('9318436')->is_valid_number, '富山県富山市宮園町');
ok($zip->set_number('9318437')->is_valid_number, '富山県富山市宮町');
ok($zip->set_number('9318441')->is_valid_number, '富山県富山市高島');
ok($zip->set_number('9318442')->is_valid_number, '富山県富山市楠木');
ok($zip->set_number('9318443')->is_valid_number, '富山県富山市下飯野');
ok($zip->set_number('9318444')->is_valid_number, '富山県富山市東ケ丘');
ok($zip->set_number('9318445')->is_valid_number, '富山県富山市道正');
ok($zip->set_number('9318451')->is_valid_number, '富山県富山市銀嶺町');
ok($zip->set_number('9318452')->is_valid_number, '富山県富山市東富山寿町');
ok($zip->set_number('9318453')->is_valid_number, '富山県富山市中田');
ok($zip->set_number('9318454')->is_valid_number, '富山県富山市住友町');
ok($zip->set_number('9318455')->is_valid_number, '富山県富山市晴海台');
ok($zip->set_number('9318456')->is_valid_number, '富山県富山市永久町');
ok($zip->set_number('9320000')->is_valid_number, '富山県小矢部市以下に掲載がない場合');
ok($zip->set_number('9320001')->is_valid_number, '富山県小矢部市久利須');
ok($zip->set_number('9320002')->is_valid_number, '富山県小矢部市森屋');
ok($zip->set_number('9320003')->is_valid_number, '富山県小矢部市北屋敷');
ok($zip->set_number('9320004')->is_valid_number, '富山県小矢部市二ノ滝');
ok($zip->set_number('9320005')->is_valid_number, '富山県小矢部市下屋敷');
ok($zip->set_number('9320006')->is_valid_number, '富山県小矢部市高坂');
ok($zip->set_number('9320007')->is_valid_number, '富山県小矢部市名ケ滝');
ok($zip->set_number('9320008')->is_valid_number, '富山県小矢部市菅ケ原');
ok($zip->set_number('9320011')->is_valid_number, '富山県小矢部市原牧');
ok($zip->set_number('9320012')->is_valid_number, '富山県小矢部市嶺');
ok($zip->set_number('9320013')->is_valid_number, '富山県小矢部市清原');
ok($zip->set_number('9320014')->is_valid_number, '富山県小矢部市岩崎');
ok($zip->set_number('9320015')->is_valid_number, '富山県小矢部市矢波');
ok($zip->set_number('9320016')->is_valid_number, '富山県小矢部市糠子島');
ok($zip->set_number('9320017')->is_valid_number, '富山県小矢部市了輪');
ok($zip->set_number('9320018')->is_valid_number, '富山県小矢部市別所滝');
ok($zip->set_number('9320021')->is_valid_number, '富山県小矢部市田川');
ok($zip->set_number('9320022')->is_valid_number, '富山県小矢部市桜町');
ok($zip->set_number('9320023')->is_valid_number, '富山県小矢部市横谷');
ok($zip->set_number('9320024')->is_valid_number, '富山県小矢部市屋波牧');
ok($zip->set_number('9320025')->is_valid_number, '富山県小矢部市宮中');
ok($zip->set_number('9320026')->is_valid_number, '富山県小矢部市宮須');
ok($zip->set_number('9320027')->is_valid_number, '富山県小矢部市法楽寺');
ok($zip->set_number('9320028')->is_valid_number, '富山県小矢部市畠中');
ok($zip->set_number('9320031')->is_valid_number, '富山県小矢部市岡');
ok($zip->set_number('9320032')->is_valid_number, '富山県小矢部市地崎');
ok($zip->set_number('9320033')->is_valid_number, '富山県小矢部市芹川');
ok($zip->set_number('9320034')->is_valid_number, '富山県小矢部市坂又');
ok($zip->set_number('9320035')->is_valid_number, '富山県小矢部市西中野');
ok($zip->set_number('9320036')->is_valid_number, '富山県小矢部市宇治新');
ok($zip->set_number('9320037')->is_valid_number, '富山県小矢部市石王丸');
ok($zip->set_number('9320041')->is_valid_number, '富山県小矢部市東福町');
ok($zip->set_number('9320042')->is_valid_number, '富山県小矢部市西福町');
ok($zip->set_number('9320043')->is_valid_number, '富山県小矢部市畠中町');
ok($zip->set_number('9320044')->is_valid_number, '富山県小矢部市新富町');
ok($zip->set_number('9320045')->is_valid_number, '富山県小矢部市中央町');
ok($zip->set_number('9320046')->is_valid_number, '富山県小矢部市観音町');
ok($zip->set_number('9320047')->is_valid_number, '富山県小矢部市城山町');
ok($zip->set_number('9320048')->is_valid_number, '富山県小矢部市八和町');
ok($zip->set_number('9320051')->is_valid_number, '富山県小矢部市今石動町');
ok($zip->set_number('9320052')->is_valid_number, '富山県小矢部市泉町');
ok($zip->set_number('9320053')->is_valid_number, '富山県小矢部市石動町');
ok($zip->set_number('9320054')->is_valid_number, '富山県小矢部市上野本');
ok($zip->set_number('9320055')->is_valid_number, '富山県小矢部市西町');
ok($zip->set_number('9320056')->is_valid_number, '富山県小矢部市小矢部');
ok($zip->set_number('9320057')->is_valid_number, '富山県小矢部市本町');
ok($zip->set_number('9320058')->is_valid_number, '富山県小矢部市小矢部町');
ok($zip->set_number('9320061')->is_valid_number, '富山県小矢部市道坪野');
ok($zip->set_number('9320062')->is_valid_number, '富山県小矢部市安楽寺');
ok($zip->set_number('9320063')->is_valid_number, '富山県小矢部市峰坪野');
ok($zip->set_number('9320064')->is_valid_number, '富山県小矢部市谷坪野');
ok($zip->set_number('9320065')->is_valid_number, '富山県小矢部市論田');
ok($zip->set_number('9320071')->is_valid_number, '富山県小矢部市荒間');
ok($zip->set_number('9320072')->is_valid_number, '富山県小矢部市峠');
ok($zip->set_number('9320073')->is_valid_number, '富山県小矢部市岩尾滝');
ok($zip->set_number('9320074')->is_valid_number, '富山県小矢部市千石');
ok($zip->set_number('9320075')->is_valid_number, '富山県小矢部市嘉例谷');
ok($zip->set_number('9320101')->is_valid_number, '富山県小矢部市下後亟');
ok($zip->set_number('9320102')->is_valid_number, '富山県小矢部市水島');
ok($zip->set_number('9320103')->is_valid_number, '富山県小矢部市経田');
ok($zip->set_number('9320104')->is_valid_number, '富山県小矢部市西川原');
ok($zip->set_number('9320105')->is_valid_number, '富山県小矢部市胡麻島');
ok($zip->set_number('9320106')->is_valid_number, '富山県小矢部市内御堂');
ok($zip->set_number('9320111')->is_valid_number, '富山県小矢部市新西');
ok($zip->set_number('9320112')->is_valid_number, '富山県小矢部市清沢');
ok($zip->set_number('9320113')->is_valid_number, '富山県小矢部市岩武');
ok($zip->set_number('9320114')->is_valid_number, '富山県小矢部市清水');
ok($zip->set_number('9320115')->is_valid_number, '富山県小矢部市津沢');
ok($zip->set_number('9320116')->is_valid_number, '富山県小矢部市西島');
ok($zip->set_number('9320121')->is_valid_number, '富山県小矢部市矢水町');
ok($zip->set_number('9320122')->is_valid_number, '富山県小矢部市浅地');
ok($zip->set_number('9320123')->is_valid_number, '富山県小矢部市高木');
ok($zip->set_number('9320124')->is_valid_number, '富山県小矢部市蓑輪');
ok($zip->set_number('9320125')->is_valid_number, '富山県小矢部市鴨島');
ok($zip->set_number('9320126')->is_valid_number, '富山県小矢部市下川崎');
ok($zip->set_number('9320127')->is_valid_number, '富山県小矢部市興法寺');
ok($zip->set_number('9320128')->is_valid_number, '富山県小矢部市戸久');
ok($zip->set_number('9320129')->is_valid_number, '富山県小矢部市安養寺');
ok($zip->set_number('9320131')->is_valid_number, '富山県小矢部市名畑');
ok($zip->set_number('9320132')->is_valid_number, '富山県小矢部市杉谷内');
ok($zip->set_number('9320133')->is_valid_number, '富山県小矢部市小森谷');
ok($zip->set_number('9320134')->is_valid_number, '富山県小矢部市平桜');
ok($zip->set_number('9320135')->is_valid_number, '富山県小矢部市藤森');
ok($zip->set_number('9320136')->is_valid_number, '富山県小矢部市平田');
ok($zip->set_number('9320137')->is_valid_number, '富山県小矢部市渋江');
ok($zip->set_number('9320201')->is_valid_number, '富山県南砺市高屋');
ok($zip->set_number('9320202')->is_valid_number, '富山県南砺市清水明');
ok($zip->set_number('9320203')->is_valid_number, '富山県南砺市岩屋');
ok($zip->set_number('9320204')->is_valid_number, '富山県南砺市飛騨屋');
ok($zip->set_number('9320205')->is_valid_number, '富山県南砺市井波軸屋');
ok($zip->set_number('9320206')->is_valid_number, '富山県南砺市安室');
ok($zip->set_number('9320206')->is_valid_number, '富山県南砺市利屋');
ok($zip->set_number('9320207')->is_valid_number, '富山県南砺市専勝寺');
ok($zip->set_number('9320211')->is_valid_number, '富山県南砺市井波');
ok($zip->set_number('9320212')->is_valid_number, '富山県南砺市山斐');
ok($zip->set_number('9320213')->is_valid_number, '富山県南砺市井波栄町');
ok($zip->set_number('9320214')->is_valid_number, '富山県南砺市今町');
ok($zip->set_number('9320215')->is_valid_number, '富山県南砺市山下');
ok($zip->set_number('9320216')->is_valid_number, '富山県南砺市井波末広町');
ok($zip->set_number('9320217')->is_valid_number, '富山県南砺市本町');
ok($zip->set_number('9320218')->is_valid_number, '富山県南砺市坪野');
ok($zip->set_number('9320221')->is_valid_number, '富山県南砺市木崎野');
ok($zip->set_number('9320222')->is_valid_number, '富山県南砺市坂ノ下');
ok($zip->set_number('9320223')->is_valid_number, '富山県南砺市松島');
ok($zip->set_number('9320224')->is_valid_number, '富山県南砺市藤橋');
ok($zip->set_number('9320225')->is_valid_number, '富山県南砺市畑方');
ok($zip->set_number('9320226')->is_valid_number, '富山県南砺市北川');
ok($zip->set_number('9320227')->is_valid_number, '富山県南砺市北新町');
ok($zip->set_number('9320228')->is_valid_number, '富山県南砺市井波東町');
ok($zip->set_number('9320231')->is_valid_number, '富山県南砺市山見');
ok($zip->set_number('9320232')->is_valid_number, '富山県南砺市京願町');
ok($zip->set_number('9320233')->is_valid_number, '富山県南砺市堀道');
ok($zip->set_number('9320234')->is_valid_number, '富山県南砺市八日町');
ok($zip->set_number('9320235')->is_valid_number, '富山県南砺市六日町');
ok($zip->set_number('9320236')->is_valid_number, '富山県南砺市三日町');
ok($zip->set_number('9320237')->is_valid_number, '富山県南砺市山見町並');
ok($zip->set_number('9320238')->is_valid_number, '富山県南砺市下新町');
ok($zip->set_number('9320241')->is_valid_number, '富山県南砺市川原崎');
ok($zip->set_number('9320242')->is_valid_number, '富山県南砺市谷');
ok($zip->set_number('9320243')->is_valid_number, '富山県南砺市志観寺');
ok($zip->set_number('9320244')->is_valid_number, '富山県南砺市連代寺');
ok($zip->set_number('9320245')->is_valid_number, '富山県南砺市清玄寺');
ok($zip->set_number('9320246')->is_valid_number, '富山県南砺市東城寺');
ok($zip->set_number('9320247')->is_valid_number, '富山県南砺市院瀬見');
ok($zip->set_number('9320248')->is_valid_number, '富山県南砺市沖');
ok($zip->set_number('9320251')->is_valid_number, '富山県南砺市野能原');
ok($zip->set_number('9320252')->is_valid_number, '富山県南砺市高瀬');
ok($zip->set_number('9320253')->is_valid_number, '富山県南砺市戸板');
ok($zip->set_number('9320254')->is_valid_number, '富山県南砺市五領');
ok($zip->set_number('9320255')->is_valid_number, '富山県南砺市五領島');
ok($zip->set_number('9320256')->is_valid_number, '富山県南砺市今里');
ok($zip->set_number('9320257')->is_valid_number, '富山県南砺市北市');
ok($zip->set_number('9320258')->is_valid_number, '富山県南砺市三清東');
ok($zip->set_number('9320301')->is_valid_number, '富山県砺波市庄川町三谷');
ok($zip->set_number('9320302')->is_valid_number, '富山県砺波市庄川町庄');
ok($zip->set_number('9320303')->is_valid_number, '富山県砺波市庄川町落シ');
ok($zip->set_number('9320303')->is_valid_number, '富山県砺波市庄川町隠尾');
ok($zip->set_number('9320303')->is_valid_number, '富山県砺波市庄川町名ケ原');
ok($zip->set_number('9320303')->is_valid_number, '富山県砺波市庄川町湯谷');
ok($zip->set_number('9320303')->is_valid_number, '富山県砺波市庄川町湯山');
ok($zip->set_number('9320303')->is_valid_number, '富山県砺波市庄川町横住');
ok($zip->set_number('9320304')->is_valid_number, '富山県砺波市庄川町小牧');
ok($zip->set_number('9320304')->is_valid_number, '富山県砺波市庄川町前山');
ok($zip->set_number('9320305')->is_valid_number, '富山県砺波市庄川町金屋');
ok($zip->set_number('9320311')->is_valid_number, '富山県砺波市庄川町古上野');
ok($zip->set_number('9320312')->is_valid_number, '富山県砺波市庄川町高儀新');
ok($zip->set_number('9320313')->is_valid_number, '富山県砺波市庄川町五ケ');
ok($zip->set_number('9320314')->is_valid_number, '富山県砺波市庄川町青島');
ok($zip->set_number('9320315')->is_valid_number, '富山県砺波市庄川町示野');
ok($zip->set_number('9320316')->is_valid_number, '富山県砺波市庄川町天正');
ok($zip->set_number('9320317')->is_valid_number, '富山県砺波市庄川町筏');
ok($zip->set_number('9320371')->is_valid_number, '富山県南砺市利賀村大牧');
ok($zip->set_number('9320371')->is_valid_number, '富山県南砺市利賀村北原');
ok($zip->set_number('9320371')->is_valid_number, '富山県南砺市利賀村下原');
ok($zip->set_number('9320371')->is_valid_number, '富山県南砺市利賀村栃原');
ok($zip->set_number('9320371')->is_valid_number, '富山県南砺市利賀村長崎');
ok($zip->set_number('9320801')->is_valid_number, '富山県小矢部市五社');
ok($zip->set_number('9320802')->is_valid_number, '富山県小矢部市七社');
ok($zip->set_number('9320803')->is_valid_number, '富山県小矢部市道明');
ok($zip->set_number('9320804')->is_valid_number, '富山県小矢部市下中');
ok($zip->set_number('9320805')->is_valid_number, '富山県小矢部市西中');
ok($zip->set_number('9320806')->is_valid_number, '富山県小矢部市水落');
ok($zip->set_number('9320807')->is_valid_number, '富山県小矢部市柳原');
ok($zip->set_number('9320808')->is_valid_number, '富山県小矢部市石名田');
ok($zip->set_number('9320811')->is_valid_number, '富山県小矢部市水牧');
ok($zip->set_number('9320812')->is_valid_number, '富山県小矢部市金屋本江');
ok($zip->set_number('9320813')->is_valid_number, '富山県小矢部市野寺');
ok($zip->set_number('9320814')->is_valid_number, '富山県小矢部市赤倉');
ok($zip->set_number('9320815')->is_valid_number, '富山県小矢部市高木出');
ok($zip->set_number('9320816')->is_valid_number, '富山県小矢部市福久');
ok($zip->set_number('9320817')->is_valid_number, '富山県小矢部市小神');
ok($zip->set_number('9320821')->is_valid_number, '富山県小矢部市鷲島');
ok($zip->set_number('9320822')->is_valid_number, '富山県小矢部市和沢');
ok($zip->set_number('9320823')->is_valid_number, '富山県小矢部市福上');
ok($zip->set_number('9320824')->is_valid_number, '富山県小矢部市下島');
ok($zip->set_number('9320825')->is_valid_number, '富山県小矢部市島');
ok($zip->set_number('9320826')->is_valid_number, '富山県小矢部市茄子島');
ok($zip->set_number('9320831')->is_valid_number, '富山県小矢部市後谷');
ok($zip->set_number('9320832')->is_valid_number, '富山県小矢部市野端');
ok($zip->set_number('9320833')->is_valid_number, '富山県小矢部市綾子');
ok($zip->set_number('9320834')->is_valid_number, '富山県小矢部市蓮沼');
ok($zip->set_number('9320835')->is_valid_number, '富山県小矢部市石坂');
ok($zip->set_number('9320836')->is_valid_number, '富山県小矢部市埴生');
ok($zip->set_number('9320837')->is_valid_number, '富山県小矢部市吉和台');
ok($zip->set_number('9320838')->is_valid_number, '富山県小矢部市メルヘンランド');
ok($zip->set_number('9320841')->is_valid_number, '富山県小矢部市道林寺');
ok($zip->set_number('9320842')->is_valid_number, '富山県小矢部市長');
ok($zip->set_number('9320843')->is_valid_number, '富山県小矢部市棚田');
ok($zip->set_number('9320844')->is_valid_number, '富山県小矢部市北一');
ok($zip->set_number('9320845')->is_valid_number, '富山県小矢部市松尾');
ok($zip->set_number('9320846')->is_valid_number, '富山県小矢部市松永');
ok($zip->set_number('9320851')->is_valid_number, '富山県小矢部市末友');
ok($zip->set_number('9320852')->is_valid_number, '富山県小矢部市安養寺新');
ok($zip->set_number('9320853')->is_valid_number, '富山県小矢部市臼谷');
ok($zip->set_number('9320854')->is_valid_number, '富山県小矢部市末沢新');
ok($zip->set_number('9320855')->is_valid_number, '富山県小矢部市川開新');
ok($zip->set_number('9320856')->is_valid_number, '富山県小矢部市フロンティアパーク');
ok($zip->set_number('9320861')->is_valid_number, '富山県小矢部市八講田');
ok($zip->set_number('9320862')->is_valid_number, '富山県小矢部市五郎丸');
ok($zip->set_number('9320863')->is_valid_number, '富山県小矢部市内山');
ok($zip->set_number('9320864')->is_valid_number, '富山県小矢部市八伏');
ok($zip->set_number('9330000')->is_valid_number, '富山県高岡市以下に掲載がない場合');
ok($zip->set_number('9330001')->is_valid_number, '富山県高岡市富岡町');
ok($zip->set_number('9330002')->is_valid_number, '富山県高岡市吉久');
ok($zip->set_number('9330003')->is_valid_number, '富山県高岡市能町');
ok($zip->set_number('9330004')->is_valid_number, '富山県高岡市能町東');
ok($zip->set_number('9330005')->is_valid_number, '富山県高岡市能町南');
ok($zip->set_number('9330006')->is_valid_number, '富山県高岡市角三島');
ok($zip->set_number('9330007')->is_valid_number, '富山県高岡市角');
ok($zip->set_number('9330008')->is_valid_number, '富山県高岡市材木町');
ok($zip->set_number('9330011')->is_valid_number, '富山県高岡市石瀬');
ok($zip->set_number('9330012')->is_valid_number, '富山県高岡市美原町');
ok($zip->set_number('9330013')->is_valid_number, '富山県高岡市三女子');
ok($zip->set_number('9330014')->is_valid_number, '富山県高岡市野村');
ok($zip->set_number('9330015')->is_valid_number, '富山県高岡市明園町');
ok($zip->set_number('9330016')->is_valid_number, '富山県高岡市大野');
ok($zip->set_number('9330017')->is_valid_number, '富山県高岡市前田町');
ok($zip->set_number('9330018')->is_valid_number, '富山県高岡市高陵町');
ok($zip->set_number('9330021')->is_valid_number, '富山県高岡市下関町');
ok($zip->set_number('9330022')->is_valid_number, '富山県高岡市白金町');
ok($zip->set_number('9330023')->is_valid_number, '富山県高岡市末広町');
ok($zip->set_number('9330024')->is_valid_number, '富山県高岡市宮脇町');
ok($zip->set_number('9330025')->is_valid_number, '富山県高岡市片原横町');
ok($zip->set_number('9330026')->is_valid_number, '富山県高岡市片原町');
ok($zip->set_number('9330027')->is_valid_number, '富山県高岡市片原中島町');
ok($zip->set_number('9330028')->is_valid_number, '富山県高岡市大福院');
ok($zip->set_number('9330029')->is_valid_number, '富山県高岡市御旅屋町');
ok($zip->set_number('9330030')->is_valid_number, '富山県高岡市中央町');
ok($zip->set_number('9330031')->is_valid_number, '富山県高岡市中川町');
ok($zip->set_number('9330032')->is_valid_number, '富山県高岡市定塚町');
ok($zip->set_number('9330033')->is_valid_number, '富山県高岡市東下関');
ok($zip->set_number('9330034')->is_valid_number, '富山県高岡市大仏町');
ok($zip->set_number('9330035')->is_valid_number, '富山県高岡市新横町');
ok($zip->set_number('9330036')->is_valid_number, '富山県高岡市桐木町');
ok($zip->set_number('9330037')->is_valid_number, '富山県高岡市定塚');
ok($zip->set_number('9330038')->is_valid_number, '富山県高岡市坂下町');
ok($zip->set_number('9330039')->is_valid_number, '富山県高岡市大手町');
ok($zip->set_number('9330041')->is_valid_number, '富山県高岡市城東');
ok($zip->set_number('9330042')->is_valid_number, '富山県高岡市中川栄町');
ok($zip->set_number('9330043')->is_valid_number, '富山県高岡市中川上町');
ok($zip->set_number('9330044')->is_valid_number, '富山県高岡市古城');
ok($zip->set_number('9330045')->is_valid_number, '富山県高岡市本丸町');
ok($zip->set_number('9330046')->is_valid_number, '富山県高岡市中川本町');
ok($zip->set_number('9330047')->is_valid_number, '富山県高岡市東中川町');
ok($zip->set_number('9330051')->is_valid_number, '富山県高岡市東野');
ok($zip->set_number('9330052')->is_valid_number, '富山県高岡市北定塚');
ok($zip->set_number('9330053')->is_valid_number, '富山県高岡市城北町');
ok($zip->set_number('9330054')->is_valid_number, '富山県高岡市古定塚');
ok($zip->set_number('9330055')->is_valid_number, '富山県高岡市中川園町');
ok($zip->set_number('9330056')->is_valid_number, '富山県高岡市中川');
ok($zip->set_number('9330057')->is_valid_number, '富山県高岡市広小路');
ok($zip->set_number('9330058')->is_valid_number, '富山県射水市川口宮袋');
ok($zip->set_number('9330061')->is_valid_number, '富山県高岡市青葉町');
ok($zip->set_number('9330062')->is_valid_number, '富山県高岡市江尻');
ok($zip->set_number('9330063')->is_valid_number, '富山県高岡市鶴寄町');
ok($zip->set_number('9330064')->is_valid_number, '富山県高岡市宝町');
ok($zip->set_number('9330065')->is_valid_number, '富山県高岡市江尻白山町');
ok($zip->set_number('9330066')->is_valid_number, '富山県高岡市春日丘');
ok($zip->set_number('9330067')->is_valid_number, '富山県高岡市高伏町');
ok($zip->set_number('9330068')->is_valid_number, '富山県高岡市志貴野しらとり台');
ok($zip->set_number('9330071')->is_valid_number, '富山県高岡市鷲北新');
ok($zip->set_number('9330072')->is_valid_number, '富山県高岡市旭ケ丘');
ok($zip->set_number('9330073')->is_valid_number, '富山県高岡市荻布');
ok($zip->set_number('9330074')->is_valid_number, '富山県高岡市荻布新町');
ok($zip->set_number('9330075')->is_valid_number, '富山県高岡市新能町');
ok($zip->set_number('9330076')->is_valid_number, '富山県高岡市米島');
ok($zip->set_number('9330077')->is_valid_number, '富山県高岡市能町駅南');
ok($zip->set_number('9330078')->is_valid_number, '富山県高岡市荻布四つ葉町');
ok($zip->set_number('9330101')->is_valid_number, '富山県高岡市伏木国分');
ok($zip->set_number('9330102')->is_valid_number, '富山県高岡市伏木磯町');
ok($zip->set_number('9330103')->is_valid_number, '富山県高岡市伏木中央町');
ok($zip->set_number('9330104')->is_valid_number, '富山県高岡市伏木湊町');
ok($zip->set_number('9330105')->is_valid_number, '富山県高岡市伏木錦町');
ok($zip->set_number('9330106')->is_valid_number, '富山県高岡市伏木本町');
ok($zip->set_number('9330111')->is_valid_number, '富山県高岡市伏木東一宮');
ok($zip->set_number('9330112')->is_valid_number, '富山県高岡市伏木古国府');
ok($zip->set_number('9330113')->is_valid_number, '富山県高岡市伏木');
ok($zip->set_number('9330114')->is_valid_number, '富山県高岡市伏木古府');
ok($zip->set_number('9330115')->is_valid_number, '富山県高岡市伏木古府元町');
ok($zip->set_number('9330116')->is_valid_number, '富山県高岡市伏木一宮');
ok($zip->set_number('9330121')->is_valid_number, '富山県高岡市伏木矢田新町');
ok($zip->set_number('9330122')->is_valid_number, '富山県高岡市伏木矢田上町');
ok($zip->set_number('9330123')->is_valid_number, '富山県高岡市伏木矢田');
ok($zip->set_number('9330124')->is_valid_number, '富山県高岡市高美町');
ok($zip->set_number('9330125')->is_valid_number, '富山県高岡市伏木矢田(万葉台)');
ok($zip->set_number('9330126')->is_valid_number, '富山県高岡市城光寺');
ok($zip->set_number('9330131')->is_valid_number, '富山県高岡市太田伊勢領');
ok($zip->set_number('9330132')->is_valid_number, '富山県高岡市太田(中村)');
ok($zip->set_number('9330133')->is_valid_number, '富山県高岡市太田');
ok($zip->set_number('9330134')->is_valid_number, '富山県高岡市太田(辰ノ口)');
ok($zip->set_number('9330134')->is_valid_number, '富山県高岡市太田(旦保)');
ok($zip->set_number('9330135')->is_valid_number, '富山県高岡市太田(雨晴)');
ok($zip->set_number('9330136')->is_valid_number, '富山県高岡市渋谷');
ok($zip->set_number('9330137')->is_valid_number, '富山県高岡市太田谷内');
ok($zip->set_number('9330137')->is_valid_number, '富山県高岡市西田');
ok($zip->set_number('9330138')->is_valid_number, '富山県高岡市太田山岸');
ok($zip->set_number('9330201')->is_valid_number, '富山県射水市山屋');
ok($zip->set_number('9330202')->is_valid_number, '富山県射水市下村三箇');
ok($zip->set_number('9330203')->is_valid_number, '富山県射水市加茂東部');
ok($zip->set_number('9330204')->is_valid_number, '富山県射水市加茂中部');
ok($zip->set_number('9330205')->is_valid_number, '富山県射水市加茂西部');
ok($zip->set_number('9330206')->is_valid_number, '富山県射水市倉垣小杉');
ok($zip->set_number('9330207')->is_valid_number, '富山県射水市白石');
ok($zip->set_number('9330208')->is_valid_number, '富山県射水市八講');
ok($zip->set_number('9330209')->is_valid_number, '富山県射水市摺出寺');
ok($zip->set_number('9330221')->is_valid_number, '富山県射水市堀岡新明神(その他)');
ok($zip->set_number('9330222')->is_valid_number, '富山県射水市海竜町');
ok($zip->set_number('9330223')->is_valid_number, '富山県射水市堀岡');
ok($zip->set_number('9330224')->is_valid_number, '富山県射水市堀岡古明神');
ok($zip->set_number('9330225')->is_valid_number, '富山県射水市草岡町');
ok($zip->set_number('9330226')->is_valid_number, '富山県射水市堀江千石');
ok($zip->set_number('9330227')->is_valid_number, '富山県射水市射水町');
ok($zip->set_number('9330228')->is_valid_number, '富山県射水市堀岡明神新');
ok($zip->set_number('9330231')->is_valid_number, '富山県射水市海老江浜開');
ok($zip->set_number('9330232')->is_valid_number, '富山県射水市浜開新町');
ok($zip->set_number('9330233')->is_valid_number, '富山県射水市海老江');
ok($zip->set_number('9330234')->is_valid_number, '富山県射水市海老江七軒');
ok($zip->set_number('9330235')->is_valid_number, '富山県射水市海老江練合');
ok($zip->set_number('9330236')->is_valid_number, '富山県射水市東明七軒');
ok($zip->set_number('9330237')->is_valid_number, '富山県射水市東明東町');
ok($zip->set_number('9330238')->is_valid_number, '富山県射水市東明中町');
ok($zip->set_number('9330239')->is_valid_number, '富山県射水市東明西町');
ok($zip->set_number('9330240')->is_valid_number, '富山県射水市かもめ台');
ok($zip->set_number('9330241')->is_valid_number, '富山県射水市足洗新町');
ok($zip->set_number('9330242')->is_valid_number, '富山県射水市本江針山開');
ok($zip->set_number('9330243')->is_valid_number, '富山県射水市本江(足洗)');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江北');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江三箇');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江中');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江西');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江後新');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江東');
ok($zip->set_number('9330244')->is_valid_number, '富山県射水市本江南');
ok($zip->set_number('9330245')->is_valid_number, '富山県射水市本江利波');
ok($zip->set_number('9330246')->is_valid_number, '富山県射水市本江(道番)');
ok($zip->set_number('9330247')->is_valid_number, '富山県射水市本江中新');
ok($zip->set_number('9330248')->is_valid_number, '富山県射水市本江針山');
ok($zip->set_number('9330249')->is_valid_number, '富山県射水市本江針山新');
ok($zip->set_number('9330251')->is_valid_number, '富山県射水市有磯');
ok($zip->set_number('9330252')->is_valid_number, '富山県射水市七美');
ok($zip->set_number('9330253')->is_valid_number, '富山県射水市七美中野');
ok($zip->set_number('9330301')->is_valid_number, '富山県高岡市勝木原');
ok($zip->set_number('9330302')->is_valid_number, '富山県高岡市西広谷');
ok($zip->set_number('9330303')->is_valid_number, '富山県高岡市山川');
ok($zip->set_number('9330304')->is_valid_number, '富山県高岡市境');
ok($zip->set_number('9330305')->is_valid_number, '富山県高岡市江道');
ok($zip->set_number('9330306')->is_valid_number, '富山県高岡市五十辺');
ok($zip->set_number('9330307')->is_valid_number, '富山県高岡市笹八口');
ok($zip->set_number('9330308')->is_valid_number, '富山県高岡市八口');
ok($zip->set_number('9330311')->is_valid_number, '富山県高岡市大源寺');
ok($zip->set_number('9330312')->is_valid_number, '富山県高岡市大源寺(大源寺新町)');
ok($zip->set_number('9330313')->is_valid_number, '富山県高岡市福田六家');
ok($zip->set_number('9330314')->is_valid_number, '富山県高岡市福栄町');
ok($zip->set_number('9330315')->is_valid_number, '富山県高岡市西園町');
ok($zip->set_number('9330316')->is_valid_number, '富山県高岡市新栄町');
ok($zip->set_number('9330317')->is_valid_number, '富山県高岡市蜂ケ島');
ok($zip->set_number('9330318')->is_valid_number, '富山県高岡市池田');
ok($zip->set_number('9330319')->is_valid_number, '富山県高岡市荒屋敷');
ok($zip->set_number('9330321')->is_valid_number, '富山県高岡市六家');
ok($zip->set_number('9330322')->is_valid_number, '富山県高岡市樋詰');
ok($zip->set_number('9330323')->is_valid_number, '富山県高岡市西高町');
ok($zip->set_number('9330324')->is_valid_number, '富山県高岡市立野(高池町)');
ok($zip->set_number('9330325')->is_valid_number, '富山県高岡市立野');
ok($zip->set_number('9330326')->is_valid_number, '富山県高岡市立野美鳥町');
ok($zip->set_number('9330327')->is_valid_number, '富山県高岡市柴野内島');
ok($zip->set_number('9330328')->is_valid_number, '富山県高岡市内島');
ok($zip->set_number('9330329')->is_valid_number, '富山県高岡市柴野内島(柴園町)');
ok($zip->set_number('9330331')->is_valid_number, '富山県高岡市中保');
ok($zip->set_number('9330331')->is_valid_number, '富山県高岡市若保町');
ok($zip->set_number('9330332')->is_valid_number, '富山県高岡市小竹');
ok($zip->set_number('9330333')->is_valid_number, '富山県高岡市本保');
ok($zip->set_number('9330334')->is_valid_number, '富山県高岡市三ケ');
ok($zip->set_number('9330335')->is_valid_number, '富山県高岡市今市');
ok($zip->set_number('9330336')->is_valid_number, '富山県高岡市上開発');
ok($zip->set_number('9330337')->is_valid_number, '富山県高岡市千鳥丘町');
ok($zip->set_number('9330338')->is_valid_number, '富山県高岡市駒方');
ok($zip->set_number('9330341')->is_valid_number, '富山県高岡市上渡');
ok($zip->set_number('9330342')->is_valid_number, '富山県高岡市東石堤');
ok($zip->set_number('9330343')->is_valid_number, '富山県高岡市宝来町');
ok($zip->set_number('9330344')->is_valid_number, '富山県高岡市笹川');
ok($zip->set_number('9330345')->is_valid_number, '富山県高岡市平成町');
ok($zip->set_number('9330351')->is_valid_number, '富山県高岡市四日市');
ok($zip->set_number('9330352')->is_valid_number, '富山県高岡市十日市');
ok($zip->set_number('9330353')->is_valid_number, '富山県高岡市麻生谷');
ok($zip->set_number('9330354')->is_valid_number, '富山県高岡市六日市');
ok($zip->set_number('9330355')->is_valid_number, '富山県高岡市石堤');
ok($zip->set_number('9330356')->is_valid_number, '富山県高岡市谷内');
ok($zip->set_number('9330357')->is_valid_number, '富山県高岡市柴野');
ok($zip->set_number('9330801')->is_valid_number, '富山県高岡市蓮花寺新町');
ok($zip->set_number('9330802')->is_valid_number, '富山県高岡市蓮花寺');
ok($zip->set_number('9330803')->is_valid_number, '富山県高岡市出来田');
ok($zip->set_number('9330804')->is_valid_number, '富山県高岡市問屋町');
ok($zip->set_number('9330805')->is_valid_number, '富山県高岡市赤江町');
ok($zip->set_number('9330806')->is_valid_number, '富山県高岡市赤祖父');
ok($zip->set_number('9330807')->is_valid_number, '富山県高岡市井口本江');
ok($zip->set_number('9330808')->is_valid_number, '富山県高岡市高園町');
ok($zip->set_number('9330809')->is_valid_number, '富山県高岡市出来田新町');
ok($zip->set_number('9330811')->is_valid_number, '富山県高岡市深沢');
ok($zip->set_number('9330812')->is_valid_number, '富山県高岡市明和町');
ok($zip->set_number('9330813')->is_valid_number, '富山県高岡市下伏間江');
ok($zip->set_number('9330814')->is_valid_number, '富山県高岡市上伏間江');
ok($zip->set_number('9330815')->is_valid_number, '富山県高岡市西広上');
ok($zip->set_number('9330816')->is_valid_number, '富山県高岡市二塚');
ok($zip->set_number('9330817')->is_valid_number, '富山県高岡市東藤平蔵');
ok($zip->set_number('9330818')->is_valid_number, '富山県高岡市林新');
ok($zip->set_number('9330821')->is_valid_number, '富山県高岡市下島町');
ok($zip->set_number('9330822')->is_valid_number, '富山県高岡市十二町島');
ok($zip->set_number('9330823')->is_valid_number, '富山県高岡市北蔵新');
ok($zip->set_number('9330824')->is_valid_number, '富山県高岡市西藤平蔵');
ok($zip->set_number('9330825')->is_valid_number, '富山県高岡市佐野緑町');
ok($zip->set_number('9330826')->is_valid_number, '富山県高岡市佐野');
ok($zip->set_number('9330827')->is_valid_number, '富山県高岡市泉が丘');
ok($zip->set_number('9330828')->is_valid_number, '富山県高岡市和田上町');
ok($zip->set_number('9330829')->is_valid_number, '富山県高岡市福田');
ok($zip->set_number('9330831')->is_valid_number, '富山県高岡市若富町');
ok($zip->set_number('9330832')->is_valid_number, '富山県高岡市和田');
ok($zip->set_number('9330833')->is_valid_number, '富山県高岡市荒見崎');
ok($zip->set_number('9330834')->is_valid_number, '富山県高岡市蔵野町');
ok($zip->set_number('9330835')->is_valid_number, '富山県高岡市辻');
ok($zip->set_number('9330836')->is_valid_number, '富山県高岡市石塚');
ok($zip->set_number('9330837')->is_valid_number, '富山県高岡市上北島');
ok($zip->set_number('9330838')->is_valid_number, '富山県高岡市北島');
ok($zip->set_number('9330839')->is_valid_number, '富山県高岡市和田西町');
ok($zip->set_number('9330841')->is_valid_number, '富山県高岡市金屋町');
ok($zip->set_number('9330842')->is_valid_number, '富山県高岡市横田町');
ok($zip->set_number('9330843')->is_valid_number, '富山県高岡市永楽町');
ok($zip->set_number('9330844')->is_valid_number, '富山県高岡市羽広');
ok($zip->set_number('9330845')->is_valid_number, '富山県高岡市松原町');
ok($zip->set_number('9330846')->is_valid_number, '富山県高岡市扇町');
ok($zip->set_number('9330847')->is_valid_number, '富山県高岡市千石町');
ok($zip->set_number('9330848')->is_valid_number, '富山県高岡市西町');
ok($zip->set_number('9330849')->is_valid_number, '富山県高岡市横田本町');
ok($zip->set_number('9330851')->is_valid_number, '富山県高岡市上関');
ok($zip->set_number('9330851')->is_valid_number, '富山県高岡市上関町');
ok($zip->set_number('9330852')->is_valid_number, '富山県高岡市下黒田');
ok($zip->set_number('9330853')->is_valid_number, '富山県高岡市上黒田');
ok($zip->set_number('9330853')->is_valid_number, '富山県高岡市上黒田新');
ok($zip->set_number('9330854')->is_valid_number, '富山県高岡市黒田新町');
ok($zip->set_number('9330855')->is_valid_number, '富山県高岡市市場通り');
ok($zip->set_number('9330856')->is_valid_number, '富山県高岡市鐘紡町');
ok($zip->set_number('9330857')->is_valid_number, '富山県高岡市木津');
ok($zip->set_number('9330858')->is_valid_number, '富山県高岡市泉町');
ok($zip->set_number('9330860')->is_valid_number, '富山県高岡市下関');
ok($zip->set_number('9330861')->is_valid_number, '富山県高岡市寺町');
ok($zip->set_number('9330862')->is_valid_number, '富山県高岡市新寺町');
ok($zip->set_number('9330863')->is_valid_number, '富山県高岡市関本町');
ok($zip->set_number('9330864')->is_valid_number, '富山県高岡市関町');
ok($zip->set_number('9330865')->is_valid_number, '富山県高岡市蓮美町');
ok($zip->set_number('9330866')->is_valid_number, '富山県高岡市清水町');
ok($zip->set_number('9330867')->is_valid_number, '富山県高岡市大鋸屋町');
ok($zip->set_number('9330868')->is_valid_number, '富山県高岡市大工中町');
ok($zip->set_number('9330869')->is_valid_number, '富山県高岡市関大町');
ok($zip->set_number('9330871')->is_valid_number, '富山県高岡市駅南');
ok($zip->set_number('9330872')->is_valid_number, '富山県高岡市芳野');
ok($zip->set_number('9330873')->is_valid_number, '富山県高岡市南田町');
ok($zip->set_number('9330874')->is_valid_number, '富山県高岡市京田');
ok($zip->set_number('9330875')->is_valid_number, '富山県高岡市神田新町');
ok($zip->set_number('9330876')->is_valid_number, '富山県高岡市神主町');
ok($zip->set_number('9330877')->is_valid_number, '富山県高岡市荒川町');
ok($zip->set_number('9330878')->is_valid_number, '富山県高岡市東上関');
ok($zip->set_number('9330879')->is_valid_number, '富山県高岡市八丁道');
ok($zip->set_number('9330901')->is_valid_number, '富山県高岡市向野本町');
ok($zip->set_number('9330902')->is_valid_number, '富山県高岡市向野町');
ok($zip->set_number('9330903')->is_valid_number, '富山県高岡市熊野町');
ok($zip->set_number('9330904')->is_valid_number, '富山県高岡市新成町');
ok($zip->set_number('9330905')->is_valid_number, '富山県高岡市明野町');
ok($zip->set_number('9330906')->is_valid_number, '富山県高岡市五福町');
ok($zip->set_number('9330907')->is_valid_number, '富山県高岡市地子木町');
ok($zip->set_number('9330908')->is_valid_number, '富山県高岡市木町');
ok($zip->set_number('9330909')->is_valid_number, '富山県高岡市開発本町');
ok($zip->set_number('9330910')->is_valid_number, '富山県高岡市袋町');
ok($zip->set_number('9330911')->is_valid_number, '富山県高岡市あわら町');
ok($zip->set_number('9330912')->is_valid_number, '富山県高岡市丸の内');
ok($zip->set_number('9330913')->is_valid_number, '富山県高岡市本町');
ok($zip->set_number('9330914')->is_valid_number, '富山県高岡市小馬出町');
ok($zip->set_number('9330915')->is_valid_number, '富山県高岡市千木屋町');
ok($zip->set_number('9330916')->is_valid_number, '富山県高岡市大町');
ok($zip->set_number('9330917')->is_valid_number, '富山県高岡市京町');
ok($zip->set_number('9330918')->is_valid_number, '富山県高岡市大坪町');
ok($zip->set_number('9330919')->is_valid_number, '富山県高岡市平米町');
ok($zip->set_number('9330921')->is_valid_number, '富山県高岡市源平町');
ok($zip->set_number('9330922')->is_valid_number, '富山県高岡市三番町');
ok($zip->set_number('9330923')->is_valid_number, '富山県高岡市一番町');
ok($zip->set_number('9330924')->is_valid_number, '富山県高岡市堀上町');
ok($zip->set_number('9330925')->is_valid_number, '富山県高岡市白銀町');
ok($zip->set_number('9330926')->is_valid_number, '富山県高岡市御馬出町');
ok($zip->set_number('9330927')->is_valid_number, '富山県高岡市利屋町');
ok($zip->set_number('9330928')->is_valid_number, '富山県高岡市守山町');
ok($zip->set_number('9330929')->is_valid_number, '富山県高岡市木舟町');
ok($zip->set_number('9330931')->is_valid_number, '富山県高岡市二番町');
ok($zip->set_number('9330932')->is_valid_number, '富山県高岡市鴨島町');
ok($zip->set_number('9330933')->is_valid_number, '富山県高岡市南幸町');
ok($zip->set_number('9330934')->is_valid_number, '富山県高岡市博労町');
ok($zip->set_number('9330935')->is_valid_number, '富山県高岡市博労本町');
ok($zip->set_number('9330936')->is_valid_number, '富山県高岡市旅篭町');
ok($zip->set_number('9330937')->is_valid_number, '富山県高岡市通町');
ok($zip->set_number('9330938')->is_valid_number, '富山県高岡市風呂屋町');
ok($zip->set_number('9330941')->is_valid_number, '富山県高岡市内免');
ok($zip->set_number('9330942')->is_valid_number, '富山県高岡市川原町');
ok($zip->set_number('9330943')->is_valid_number, '富山県高岡市川原本町');
ok($zip->set_number('9330944')->is_valid_number, '富山県高岡市中島町');
ok($zip->set_number('9330945')->is_valid_number, '富山県高岡市金屋本町');
ok($zip->set_number('9330946')->is_valid_number, '富山県高岡市昭和町');
ok($zip->set_number('9330947')->is_valid_number, '富山県高岡市本郷');
ok($zip->set_number('9330948')->is_valid_number, '富山県高岡市上四屋');
ok($zip->set_number('9330949')->is_valid_number, '富山県高岡市四屋');
ok($zip->set_number('9330951')->is_valid_number, '富山県高岡市長慶寺');
ok($zip->set_number('9330952')->is_valid_number, '富山県高岡市下窪');
ok($zip->set_number('9330953')->is_valid_number, '富山県高岡市横田');
ok($zip->set_number('9330954')->is_valid_number, '富山県高岡市美幸町');
ok($zip->set_number('9330955')->is_valid_number, '富山県高岡市瑞穂町');
ok($zip->set_number('9330956')->is_valid_number, '富山県高岡市宮田町');
ok($zip->set_number('9330957')->is_valid_number, '富山県高岡市早川');
ok($zip->set_number('9330958')->is_valid_number, '富山県高岡市波岡');
ok($zip->set_number('9330959')->is_valid_number, '富山県高岡市長江');
ok($zip->set_number('9330961')->is_valid_number, '富山県高岡市佐加野');
ok($zip->set_number('9330962')->is_valid_number, '富山県高岡市佐加野東');
ok($zip->set_number('9330963')->is_valid_number, '富山県高岡市上八ケ新');
ok($zip->set_number('9330964')->is_valid_number, '富山県高岡市答野島');
ok($zip->set_number('9330965')->is_valid_number, '富山県高岡市高辻');
ok($zip->set_number('9330966')->is_valid_number, '富山県高岡市月野谷');
ok($zip->set_number('9330967')->is_valid_number, '富山県高岡市手洗野');
ok($zip->set_number('9330968')->is_valid_number, '富山県高岡市国吉');
ok($zip->set_number('9330971')->is_valid_number, '富山県高岡市五十里西町');
ok($zip->set_number('9330972')->is_valid_number, '富山県高岡市五十里東町');
ok($zip->set_number('9330973')->is_valid_number, '富山県高岡市五十里');
ok($zip->set_number('9330974')->is_valid_number, '富山県高岡市岩坪');
ok($zip->set_number('9330975')->is_valid_number, '富山県高岡市答野出');
ok($zip->set_number('9330976')->is_valid_number, '富山県高岡市島崎');
ok($zip->set_number('9330977')->is_valid_number, '富山県高岡市細池');
ok($zip->set_number('9330978')->is_valid_number, '富山県高岡市頭川');
ok($zip->set_number('9330981')->is_valid_number, '富山県高岡市二上');
ok($zip->set_number('9330981')->is_valid_number, '富山県高岡市二上新');
ok($zip->set_number('9330981')->is_valid_number, '富山県高岡市二上町');
ok($zip->set_number('9330982')->is_valid_number, '富山県高岡市八ケ');
ok($zip->set_number('9330983')->is_valid_number, '富山県高岡市守護町');
ok($zip->set_number('9330983')->is_valid_number, '富山県高岡市守護町新');
ok($zip->set_number('9330984')->is_valid_number, '富山県高岡市守山');
ok($zip->set_number('9330985')->is_valid_number, '富山県高岡市須田');
ok($zip->set_number('9330986')->is_valid_number, '富山県高岡市西海老坂');
ok($zip->set_number('9330987')->is_valid_number, '富山県高岡市東海老坂');
ok($zip->set_number('9340001')->is_valid_number, '富山県射水市庄西町');
ok($zip->set_number('9340002')->is_valid_number, '富山県射水市港町');
ok($zip->set_number('9340003')->is_valid_number, '富山県射水市庄川本町');
ok($zip->set_number('9340004')->is_valid_number, '富山県射水市西新湊');
ok($zip->set_number('9340005')->is_valid_number, '富山県射水市善光寺');
ok($zip->set_number('9340011')->is_valid_number, '富山県射水市本町');
ok($zip->set_number('9340012')->is_valid_number, '富山県射水市中央町');
ok($zip->set_number('9340013')->is_valid_number, '富山県射水市立町');
ok($zip->set_number('9340014')->is_valid_number, '富山県射水市緑町');
ok($zip->set_number('9340015')->is_valid_number, '富山県射水市桜町');
ok($zip->set_number('9340016')->is_valid_number, '富山県射水市三日曽根');
ok($zip->set_number('9340021')->is_valid_number, '富山県射水市堀岡新明神(西浜)');
ok($zip->set_number('9340022')->is_valid_number, '富山県射水市放生津町');
ok($zip->set_number('9340023')->is_valid_number, '富山県射水市海王町');
ok($zip->set_number('9340024')->is_valid_number, '富山県射水市越の潟町');
ok($zip->set_number('9340025')->is_valid_number, '富山県射水市八幡町');
ok($zip->set_number('9340026')->is_valid_number, '富山県射水市二の丸町');
ok($zip->set_number('9340027')->is_valid_number, '富山県射水市中新湊');
ok($zip->set_number('9340031')->is_valid_number, '富山県射水市奈呉の江');
ok($zip->set_number('9340032')->is_valid_number, '富山県射水市片口');
ok($zip->set_number('9340033')->is_valid_number, '富山県射水市新片町');
ok($zip->set_number('9340034')->is_valid_number, '富山県射水市高場新町');
ok($zip->set_number('9340035')->is_valid_number, '富山県射水市新堀');
ok($zip->set_number('9340036')->is_valid_number, '富山県射水市片口高場');
ok($zip->set_number('9340037')->is_valid_number, '富山県射水市片口久々江');
ok($zip->set_number('9340038')->is_valid_number, '富山県射水市津幡江');
ok($zip->set_number('9340039')->is_valid_number, '富山県射水市久々湊');
ok($zip->set_number('9340040')->is_valid_number, '富山県射水市鏡宮弥生');
ok($zip->set_number('9340041')->is_valid_number, '富山県射水市作道(新生町)');
ok($zip->set_number('9340042')->is_valid_number, '富山県射水市作道(その他)');
ok($zip->set_number('9340043')->is_valid_number, '富山県射水市野村');
ok($zip->set_number('9340044')->is_valid_number, '富山県射水市殿村');
ok($zip->set_number('9340045')->is_valid_number, '富山県射水市沖');
ok($zip->set_number('9340046')->is_valid_number, '富山県射水市今井');
ok($zip->set_number('9340047')->is_valid_number, '富山県射水市高木');
ok($zip->set_number('9340048')->is_valid_number, '富山県射水市布目');
ok($zip->set_number('9340049')->is_valid_number, '富山県射水市鏡宮');
ok($zip->set_number('9340051')->is_valid_number, '富山県射水市宮袋');
ok($zip->set_number('9340052')->is_valid_number, '富山県射水市松木');
ok($zip->set_number('9340053')->is_valid_number, '富山県射水市朴木');
ok($zip->set_number('9340054')->is_valid_number, '富山県射水市神楽町');
ok($zip->set_number('9340055')->is_valid_number, '富山県射水市沖塚原');
ok($zip->set_number('9340056')->is_valid_number, '富山県射水市寺塚原');
ok($zip->set_number('9340057')->is_valid_number, '富山県射水市坂東');
ok($zip->set_number('9340058')->is_valid_number, '富山県射水市川口');
ok($zip->set_number('9340091')->is_valid_number, '富山県高岡市下牧野');
ok($zip->set_number('9340092')->is_valid_number, '富山県高岡市中曽根');
ok($zip->set_number('9340093')->is_valid_number, '富山県高岡市姫野');
ok($zip->set_number('9340093')->is_valid_number, '富山県高岡市放生津');
ok($zip->set_number('9340094')->is_valid_number, '富山県高岡市堀岡又新');
ok($zip->set_number('9340095')->is_valid_number, '富山県高岡市石丸');
ok($zip->set_number('9340096')->is_valid_number, '富山県高岡市金屋');
ok($zip->set_number('9340097')->is_valid_number, '富山県高岡市牧野金屋');
ok($zip->set_number('9340098')->is_valid_number, '富山県高岡市上牧野');
ok($zip->set_number('9340099')->is_valid_number, '富山県高岡市若葉町');
ok($zip->set_number('9350000')->is_valid_number, '富山県氷見市以下に掲載がない場合');
ok($zip->set_number('9350001')->is_valid_number, '富山県氷見市北八代');
ok($zip->set_number('9350002')->is_valid_number, '富山県氷見市阿尾');
ok($zip->set_number('9350003')->is_valid_number, '富山県氷見市間島');
ok($zip->set_number('9350004')->is_valid_number, '富山県氷見市北大町');
ok($zip->set_number('9350005')->is_valid_number, '富山県氷見市栄町');
ok($zip->set_number('9350006')->is_valid_number, '富山県氷見市稲積');
ok($zip->set_number('9350007')->is_valid_number, '富山県氷見市指崎');
ok($zip->set_number('9350011')->is_valid_number, '富山県氷見市中央町');
ok($zip->set_number('9350012')->is_valid_number, '富山県氷見市比美町');
ok($zip->set_number('9350013')->is_valid_number, '富山県氷見市南大町');
ok($zip->set_number('9350014')->is_valid_number, '富山県氷見市地蔵町');
ok($zip->set_number('9350015')->is_valid_number, '富山県氷見市伊勢大町');
ok($zip->set_number('9350016')->is_valid_number, '富山県氷見市本町');
ok($zip->set_number('9350017')->is_valid_number, '富山県氷見市丸の内');
ok($zip->set_number('9350021')->is_valid_number, '富山県氷見市幸町');
ok($zip->set_number('9350022')->is_valid_number, '富山県氷見市朝日本町');
ok($zip->set_number('9350023')->is_valid_number, '富山県氷見市朝日丘');
ok($zip->set_number('9350024')->is_valid_number, '富山県氷見市窪');
ok($zip->set_number('9350025')->is_valid_number, '富山県氷見市鞍川');
ok($zip->set_number('9350026')->is_valid_number, '富山県氷見市大野');
ok($zip->set_number('9350027')->is_valid_number, '富山県氷見市大野新');
ok($zip->set_number('9350031')->is_valid_number, '富山県氷見市柳田');
ok($zip->set_number('9350032')->is_valid_number, '富山県氷見市島尾');
ok($zip->set_number('9350033')->is_valid_number, '富山県氷見市宮田');
ok($zip->set_number('9350034')->is_valid_number, '富山県氷見市小竹');
ok($zip->set_number('9350035')->is_valid_number, '富山県氷見市上田子');
ok($zip->set_number('9350036')->is_valid_number, '富山県氷見市下田子');
ok($zip->set_number('9350037')->is_valid_number, '富山県氷見市上泉');
ok($zip->set_number('9350041')->is_valid_number, '富山県氷見市園');
ok($zip->set_number('9350042')->is_valid_number, '富山県氷見市湖光');
ok($zip->set_number('9350043')->is_valid_number, '富山県氷見市川崎');
ok($zip->set_number('9350044')->is_valid_number, '富山県氷見市川尻');
ok($zip->set_number('9350045')->is_valid_number, '富山県氷見市海津');
ok($zip->set_number('9350046')->is_valid_number, '富山県氷見市下久津呂');
ok($zip->set_number('9350047')->is_valid_number, '富山県氷見市上久津呂');
ok($zip->set_number('9350051')->is_valid_number, '富山県氷見市十二町');
ok($zip->set_number('9350052')->is_valid_number, '富山県氷見市坂津');
ok($zip->set_number('9350053')->is_valid_number, '富山県氷見市万尾');
ok($zip->set_number('9350054')->is_valid_number, '富山県氷見市粟原');
ok($zip->set_number('9350055')->is_valid_number, '富山県氷見市中谷内');
ok($zip->set_number('9350056')->is_valid_number, '富山県氷見市上田');
ok($zip->set_number('9350057')->is_valid_number, '富山県氷見市西朴木');
ok($zip->set_number('9350061')->is_valid_number, '富山県氷見市余川');
ok($zip->set_number('9350062')->is_valid_number, '富山県氷見市諏訪野');
ok($zip->set_number('9350063')->is_valid_number, '富山県氷見市加納');
ok($zip->set_number('9350064')->is_valid_number, '富山県氷見市中尾');
ok($zip->set_number('9350065')->is_valid_number, '富山県氷見市泉');
ok($zip->set_number('9350066')->is_valid_number, '富山県氷見市七分一');
ok($zip->set_number('9350067')->is_valid_number, '富山県氷見市柿谷');
ok($zip->set_number('9350101')->is_valid_number, '富山県氷見市大浦新町');
ok($zip->set_number('9350102')->is_valid_number, '富山県氷見市中島');
ok($zip->set_number('9350103')->is_valid_number, '富山県氷見市大浦');
ok($zip->set_number('9350104')->is_valid_number, '富山県氷見市堀田');
ok($zip->set_number('9350105')->is_valid_number, '富山県氷見市蒲田');
ok($zip->set_number('9350106')->is_valid_number, '富山県氷見市神代');
ok($zip->set_number('9350107')->is_valid_number, '富山県氷見市矢方');
ok($zip->set_number('9350111')->is_valid_number, '富山県氷見市布施');
ok($zip->set_number('9350112')->is_valid_number, '富山県氷見市飯久保');
ok($zip->set_number('9350113')->is_valid_number, '富山県氷見市惣領');
ok($zip->set_number('9350114')->is_valid_number, '富山県氷見市仏生寺');
ok($zip->set_number('9350115')->is_valid_number, '富山県氷見市鞍骨');
ok($zip->set_number('9350115')->is_valid_number, '富山県氷見市鉾根');
ok($zip->set_number('9350116')->is_valid_number, '富山県氷見市三田窪');
ok($zip->set_number('9350116')->is_valid_number, '富山県氷見市矢田部');
ok($zip->set_number('9350117')->is_valid_number, '富山県氷見市深原');
ok($zip->set_number('9350251')->is_valid_number, '富山県氷見市熊無');
ok($zip->set_number('9350252')->is_valid_number, '富山県氷見市中村');
ok($zip->set_number('9350253')->is_valid_number, '富山県氷見市谷屋');
ok($zip->set_number('9350254')->is_valid_number, '富山県氷見市新保');
ok($zip->set_number('9350255')->is_valid_number, '富山県氷見市早借');
ok($zip->set_number('9350256')->is_valid_number, '富山県氷見市田江');
ok($zip->set_number('9350257')->is_valid_number, '富山県氷見市小窪');
ok($zip->set_number('9350258')->is_valid_number, '富山県氷見市論田');
ok($zip->set_number('9350261')->is_valid_number, '富山県氷見市三尾');
ok($zip->set_number('9350262')->is_valid_number, '富山県氷見市日名田');
ok($zip->set_number('9350263')->is_valid_number, '富山県氷見市小久米');
ok($zip->set_number('9350264')->is_valid_number, '富山県氷見市日詰');
ok($zip->set_number('9350265')->is_valid_number, '富山県氷見市久目');
ok($zip->set_number('9350266')->is_valid_number, '富山県氷見市触坂');
ok($zip->set_number('9350267')->is_valid_number, '富山県氷見市見内');
ok($zip->set_number('9350268')->is_valid_number, '富山県氷見市葛葉');
ok($zip->set_number('9350269')->is_valid_number, '富山県氷見市床鍋');
ok($zip->set_number('9350271')->is_valid_number, '富山県氷見市老谷');
ok($zip->set_number('9350272')->is_valid_number, '富山県氷見市岩瀬');
ok($zip->set_number('9350273')->is_valid_number, '富山県氷見市桑院');
ok($zip->set_number('9350274')->is_valid_number, '富山県氷見市赤毛');
ok($zip->set_number('9350275')->is_valid_number, '富山県氷見市土倉');
ok($zip->set_number('9350276')->is_valid_number, '富山県氷見市坪池');
ok($zip->set_number('9350277')->is_valid_number, '富山県氷見市棚懸');
ok($zip->set_number('9350278')->is_valid_number, '富山県氷見市一の島');
ok($zip->set_number('9350331')->is_valid_number, '富山県氷見市角間');
ok($zip->set_number('9350332')->is_valid_number, '富山県氷見市森寺');
ok($zip->set_number('9350333')->is_valid_number, '富山県氷見市吉滝');
ok($zip->set_number('9350334')->is_valid_number, '富山県氷見市針木');
ok($zip->set_number('9350335')->is_valid_number, '富山県氷見市胡桃');
ok($zip->set_number('9350336')->is_valid_number, '富山県氷見市国見');
ok($zip->set_number('9350337')->is_valid_number, '富山県氷見市小滝');
ok($zip->set_number('9350338')->is_valid_number, '富山県氷見市磯辺');
ok($zip->set_number('9350341')->is_valid_number, '富山県氷見市一刎');
ok($zip->set_number('9350342')->is_valid_number, '富山県氷見市吉懸');
ok($zip->set_number('9350343')->is_valid_number, '富山県氷見市味川');
ok($zip->set_number('9350344')->is_valid_number, '富山県氷見市上余川');
ok($zip->set_number('9350345')->is_valid_number, '富山県氷見市寺尾');
ok($zip->set_number('9350346')->is_valid_number, '富山県氷見市懸札');
ok($zip->set_number('9350401')->is_valid_number, '富山県氷見市脇');
ok($zip->set_number('9350402')->is_valid_number, '富山県氷見市中波');
ok($zip->set_number('9350403')->is_valid_number, '富山県氷見市中田');
ok($zip->set_number('9350404')->is_valid_number, '富山県氷見市平沢');
ok($zip->set_number('9350405')->is_valid_number, '富山県氷見市吉岡');
ok($zip->set_number('9350406')->is_valid_number, '富山県氷見市平');
ok($zip->set_number('9350411')->is_valid_number, '富山県氷見市姿');
ok($zip->set_number('9350412')->is_valid_number, '富山県氷見市大境');
ok($zip->set_number('9350413')->is_valid_number, '富山県氷見市小境');
ok($zip->set_number('9350414')->is_valid_number, '富山県氷見市白川');
ok($zip->set_number('9350415')->is_valid_number, '富山県氷見市戸津宮');
ok($zip->set_number('9350416')->is_valid_number, '富山県氷見市大窪');
ok($zip->set_number('9350417')->is_valid_number, '富山県氷見市長坂');
ok($zip->set_number('9350421')->is_valid_number, '富山県氷見市脇方');
ok($zip->set_number('9350422')->is_valid_number, '富山県氷見市宇波');
ok($zip->set_number('9350423')->is_valid_number, '富山県氷見市泊');
ok($zip->set_number('9350424')->is_valid_number, '富山県氷見市小杉');
ok($zip->set_number('9350425')->is_valid_number, '富山県氷見市薮田');
ok($zip->set_number('9350426')->is_valid_number, '富山県氷見市五十谷');
ok($zip->set_number('9360000')->is_valid_number, '富山県滑川市以下に掲載がない場合');
ok($zip->set_number('9360001')->is_valid_number, '富山県滑川市三ケ');
ok($zip->set_number('9360002')->is_valid_number, '富山県滑川市中村');
ok($zip->set_number('9360003')->is_valid_number, '富山県滑川市吉浦');
ok($zip->set_number('9360004')->is_valid_number, '富山県滑川市笠木');
ok($zip->set_number('9360005')->is_valid_number, '富山県滑川市浜四ツ屋');
ok($zip->set_number('9360006')->is_valid_number, '富山県滑川市荒俣');
ok($zip->set_number('9360007')->is_valid_number, '富山県滑川市荒俣新町');
ok($zip->set_number('9360011')->is_valid_number, '富山県滑川市高塚');
ok($zip->set_number('9360012')->is_valid_number, '富山県滑川市高塚曙町');
ok($zip->set_number('9360013')->is_valid_number, '富山県滑川市高塚新市営住宅');
ok($zip->set_number('9360014')->is_valid_number, '富山県滑川市高塚新町');
ok($zip->set_number('9360015')->is_valid_number, '富山県滑川市高塚寿町');
ok($zip->set_number('9360016')->is_valid_number, '富山県滑川市曲渕');
ok($zip->set_number('9360017')->is_valid_number, '富山県滑川市二ツ破');
ok($zip->set_number('9360018')->is_valid_number, '富山県滑川市坪川');
ok($zip->set_number('9360019')->is_valid_number, '富山県滑川市坪川新');
ok($zip->set_number('9360021')->is_valid_number, '富山県滑川市中川原');
ok($zip->set_number('9360022')->is_valid_number, '富山県滑川市辰野新町');
ok($zip->set_number('9360023')->is_valid_number, '富山県滑川市柳原');
ok($zip->set_number('9360024')->is_valid_number, '富山県滑川市辰野');
ok($zip->set_number('9360025')->is_valid_number, '富山県滑川市柳原新町');
ok($zip->set_number('9360026')->is_valid_number, '富山県滑川市公園通り');
ok($zip->set_number('9360027')->is_valid_number, '富山県滑川市常盤町');
ok($zip->set_number('9360031')->is_valid_number, '富山県滑川市今町');
ok($zip->set_number('9360032')->is_valid_number, '富山県滑川市神明町');
ok($zip->set_number('9360033')->is_valid_number, '富山県滑川市吾妻町');
ok($zip->set_number('9360034')->is_valid_number, '富山県滑川市吾妻町(雇用促進住宅)');
ok($zip->set_number('9360035')->is_valid_number, '富山県滑川市四間町');
ok($zip->set_number('9360036')->is_valid_number, '富山県滑川市中町');
ok($zip->set_number('9360037')->is_valid_number, '富山県滑川市武平太町');
ok($zip->set_number('9360038')->is_valid_number, '富山県滑川市北町');
ok($zip->set_number('9360039')->is_valid_number, '富山県滑川市夷子町');
ok($zip->set_number('9360041')->is_valid_number, '富山県滑川市松原町');
ok($zip->set_number('9360042')->is_valid_number, '富山県滑川市荒町');
ok($zip->set_number('9360043')->is_valid_number, '富山県滑川市瓢町');
ok($zip->set_number('9360044')->is_valid_number, '富山県滑川市馬町');
ok($zip->set_number('9360045')->is_valid_number, '富山県滑川市七間町');
ok($zip->set_number('9360046')->is_valid_number, '富山県滑川市河浦町');
ok($zip->set_number('9360047')->is_valid_number, '富山県滑川市大町');
ok($zip->set_number('9360048')->is_valid_number, '富山県滑川市三穂町');
ok($zip->set_number('9360051')->is_valid_number, '富山県滑川市寺家町');
ok($zip->set_number('9360052')->is_valid_number, '富山県滑川市清水町');
ok($zip->set_number('9360053')->is_valid_number, '富山県滑川市上小泉');
ok($zip->set_number('9360054')->is_valid_number, '富山県滑川市上小泉(雇用促進住宅)');
ok($zip->set_number('9360055')->is_valid_number, '富山県滑川市泉ケ丘');
ok($zip->set_number('9360056')->is_valid_number, '富山県滑川市田中新町');
ok($zip->set_number('9360057')->is_valid_number, '富山県滑川市田中町');
ok($zip->set_number('9360058')->is_valid_number, '富山県滑川市下小泉町');
ok($zip->set_number('9360059')->is_valid_number, '富山県滑川市晒屋');
ok($zip->set_number('9360060')->is_valid_number, '富山県滑川市神家町');
ok($zip->set_number('9360061')->is_valid_number, '富山県滑川市浜町');
ok($zip->set_number('9360062')->is_valid_number, '富山県滑川市橋場町');
ok($zip->set_number('9360063')->is_valid_number, '富山県滑川市瀬羽町');
ok($zip->set_number('9360064')->is_valid_number, '富山県滑川市河端町');
ok($zip->set_number('9360065')->is_valid_number, '富山県滑川市下島');
ok($zip->set_number('9360066')->is_valid_number, '富山県滑川市菰原');
ok($zip->set_number('9360067')->is_valid_number, '富山県滑川市菰原台');
ok($zip->set_number('9360068')->is_valid_number, '富山県滑川市加島町');
ok($zip->set_number('9360069')->is_valid_number, '富山県滑川市山王町');
ok($zip->set_number('9360070')->is_valid_number, '富山県滑川市横町');
ok($zip->set_number('9360071')->is_valid_number, '富山県滑川市領家町');
ok($zip->set_number('9360072')->is_valid_number, '富山県滑川市緑町');
ok($zip->set_number('9360073')->is_valid_number, '富山県滑川市幸町');
ok($zip->set_number('9360074')->is_valid_number, '富山県滑川市新富町');
ok($zip->set_number('9360075')->is_valid_number, '富山県滑川市江尻');
ok($zip->set_number('9360076')->is_valid_number, '富山県滑川市高月南台');
ok($zip->set_number('9360077')->is_valid_number, '富山県滑川市魚躬');
ok($zip->set_number('9360078')->is_valid_number, '富山県滑川市高月町');
ok($zip->set_number('9360801')->is_valid_number, '富山県滑川市大島');
ok($zip->set_number('9360802')->is_valid_number, '富山県滑川市大掛');
ok($zip->set_number('9360803')->is_valid_number, '富山県滑川市栗山');
ok($zip->set_number('9360804')->is_valid_number, '富山県滑川市杉本');
ok($zip->set_number('9360805')->is_valid_number, '富山県滑川市大窪');
ok($zip->set_number('9360806')->is_valid_number, '富山県滑川市北野');
ok($zip->set_number('9360807')->is_valid_number, '富山県滑川市四ツ屋');
ok($zip->set_number('9360808')->is_valid_number, '富山県滑川市追分');
ok($zip->set_number('9360811')->is_valid_number, '富山県滑川市大浦');
ok($zip->set_number('9360811')->is_valid_number, '富山県滑川市上大浦');
ok($zip->set_number('9360811')->is_valid_number, '富山県滑川市下大浦');
ok($zip->set_number('9360812')->is_valid_number, '富山県滑川市堀内');
ok($zip->set_number('9360813')->is_valid_number, '富山県滑川市大日');
ok($zip->set_number('9360814')->is_valid_number, '富山県滑川市千鳥');
ok($zip->set_number('9360815')->is_valid_number, '富山県滑川市室山');
ok($zip->set_number('9360816')->is_valid_number, '富山県滑川市中野');
ok($zip->set_number('9360817')->is_valid_number, '富山県滑川市下野');
ok($zip->set_number('9360818')->is_valid_number, '富山県滑川市大林');
ok($zip->set_number('9360821')->is_valid_number, '富山県滑川市蓑輪');
ok($zip->set_number('9360822')->is_valid_number, '富山県滑川市小森');
ok($zip->set_number('9360823')->is_valid_number, '富山県滑川市東福寺野');
ok($zip->set_number('9360824')->is_valid_number, '富山県滑川市本江');
ok($zip->set_number('9360825')->is_valid_number, '富山県滑川市安田');
ok($zip->set_number('9360826')->is_valid_number, '富山県滑川市田林');
ok($zip->set_number('9360827')->is_valid_number, '富山県滑川市東福寺');
ok($zip->set_number('9360831')->is_valid_number, '富山県滑川市野尻');
ok($zip->set_number('9360832')->is_valid_number, '富山県滑川市森野新');
ok($zip->set_number('9360833')->is_valid_number, '富山県滑川市大崎野');
ok($zip->set_number('9360834')->is_valid_number, '富山県滑川市東福寺開');
ok($zip->set_number('9360835')->is_valid_number, '富山県滑川市開');
ok($zip->set_number('9360836')->is_valid_number, '富山県滑川市改養寺');
ok($zip->set_number('9360837')->is_valid_number, '富山県滑川市東金屋');
ok($zip->set_number('9360838')->is_valid_number, '富山県滑川市道寺');
ok($zip->set_number('9360841')->is_valid_number, '富山県滑川市柴');
ok($zip->set_number('9360842')->is_valid_number, '富山県滑川市赤浜栄町');
ok($zip->set_number('9360843')->is_valid_number, '富山県滑川市赤浜');
ok($zip->set_number('9360844')->is_valid_number, '富山県滑川市寺町');
ok($zip->set_number('9360845')->is_valid_number, '富山県滑川市森尻新');
ok($zip->set_number('9360846')->is_valid_number, '富山県滑川市堀江');
ok($zip->set_number('9360847')->is_valid_number, '富山県滑川市天望町');
ok($zip->set_number('9360848')->is_valid_number, '富山県滑川市常光寺');
ok($zip->set_number('9360849')->is_valid_number, '富山県滑川市高柳');
ok($zip->set_number('9360851')->is_valid_number, '富山県滑川市沖田新');
ok($zip->set_number('9360852')->is_valid_number, '富山県滑川市上島');
ok($zip->set_number('9360853')->is_valid_number, '富山県滑川市上梅沢');
ok($zip->set_number('9360854')->is_valid_number, '富山県滑川市小林');
ok($zip->set_number('9360855')->is_valid_number, '富山県滑川市有金');
ok($zip->set_number('9360856')->is_valid_number, '富山県滑川市大門');
ok($zip->set_number('9360857')->is_valid_number, '富山県滑川市下梅沢');
ok($zip->set_number('9360861')->is_valid_number, '富山県滑川市中新');
ok($zip->set_number('9360862')->is_valid_number, '富山県滑川市四屋新');
ok($zip->set_number('9360863')->is_valid_number, '富山県滑川市栃山');
ok($zip->set_number('9360864')->is_valid_number, '富山県滑川市金屋');
ok($zip->set_number('9360865')->is_valid_number, '富山県滑川市七口');
ok($zip->set_number('9360866')->is_valid_number, '富山県滑川市宮窪新');
ok($zip->set_number('9360867')->is_valid_number, '富山県滑川市宮窪台');
ok($zip->set_number('9360868')->is_valid_number, '富山県滑川市宮窪');
ok($zip->set_number('9360871')->is_valid_number, '富山県滑川市大島新');
ok($zip->set_number('9360872')->is_valid_number, '富山県滑川市二塚');
ok($zip->set_number('9360873')->is_valid_number, '富山県滑川市横道');
ok($zip->set_number('9360874')->is_valid_number, '富山県滑川市大榎');
ok($zip->set_number('9360875')->is_valid_number, '富山県滑川市中塚');
ok($zip->set_number('9360876')->is_valid_number, '富山県滑川市稲泉新');
ok($zip->set_number('9360877')->is_valid_number, '富山県滑川市稲泉');
ok($zip->set_number('9360881')->is_valid_number, '富山県滑川市藤栄');
ok($zip->set_number('9360882')->is_valid_number, '富山県滑川市中野島');
ok($zip->set_number('9360883')->is_valid_number, '富山県滑川市野町');
ok($zip->set_number('9360884')->is_valid_number, '富山県滑川市米島');
ok($zip->set_number('9360885')->is_valid_number, '富山県滑川市法花寺');
ok($zip->set_number('9360891')->is_valid_number, '富山県中新川郡上市町護摩堂');
ok($zip->set_number('9370000')->is_valid_number, '富山県魚津市以下に掲載がない場合');
ok($zip->set_number('9370001')->is_valid_number, '富山県魚津市浜経田');
ok($zip->set_number('9370002')->is_valid_number, '富山県魚津市平伝寺');
ok($zip->set_number('9370003')->is_valid_number, '富山県魚津市持光寺');
ok($zip->set_number('9370004')->is_valid_number, '富山県魚津市岡経田');
ok($zip->set_number('9370005')->is_valid_number, '富山県魚津市天王');
ok($zip->set_number('9370006')->is_valid_number, '富山県魚津市経田西町');
ok($zip->set_number('9370007')->is_valid_number, '富山県魚津市経田中町');
ok($zip->set_number('9370008')->is_valid_number, '富山県魚津市東町');
ok($zip->set_number('9370009')->is_valid_number, '富山県魚津市寿町');
ok($zip->set_number('9370010')->is_valid_number, '富山県魚津市新経田');
ok($zip->set_number('9370011')->is_valid_number, '富山県魚津市木下新');
ok($zip->set_number('9370012')->is_valid_number, '富山県魚津市東尾崎');
ok($zip->set_number('9370013')->is_valid_number, '富山県魚津市天神野新');
ok($zip->set_number('9370014')->is_valid_number, '富山県魚津市青柳');
ok($zip->set_number('9370015')->is_valid_number, '富山県魚津市東山');
ok($zip->set_number('9370016')->is_valid_number, '富山県魚津市立石');
ok($zip->set_number('9370017')->is_valid_number, '富山県魚津市江口');
ok($zip->set_number('9370018')->is_valid_number, '富山県魚津市西尾崎');
ok($zip->set_number('9370021')->is_valid_number, '富山県魚津市蛇田');
ok($zip->set_number('9370022')->is_valid_number, '富山県魚津市小川寺');
ok($zip->set_number('9370023')->is_valid_number, '富山県魚津市長引野');
ok($zip->set_number('9370024')->is_valid_number, '富山県魚津市布施爪');
ok($zip->set_number('9370025')->is_valid_number, '富山県魚津市黒沢');
ok($zip->set_number('9370026')->is_valid_number, '富山県魚津市大沢');
ok($zip->set_number('9370027')->is_valid_number, '富山県魚津市御影');
ok($zip->set_number('9370028')->is_valid_number, '富山県魚津市日尾');
ok($zip->set_number('9370031')->is_valid_number, '富山県魚津市道坂');
ok($zip->set_number('9370032')->is_valid_number, '富山県魚津市貝田新');
ok($zip->set_number('9370033')->is_valid_number, '富山県魚津市島尻');
ok($zip->set_number('9370034')->is_valid_number, '富山県魚津市東城');
ok($zip->set_number('9370035')->is_valid_number, '富山県魚津市黒谷');
ok($zip->set_number('9370036')->is_valid_number, '富山県魚津市山女');
ok($zip->set_number('9370037')->is_valid_number, '富山県魚津市東蔵');
ok($zip->set_number('9370038')->is_valid_number, '富山県魚津市平沢');
ok($zip->set_number('9370039')->is_valid_number, '富山県魚津市大菅沼');
ok($zip->set_number('9370041')->is_valid_number, '富山県魚津市吉島');
ok($zip->set_number('9370042')->is_valid_number, '富山県魚津市六郎丸');
ok($zip->set_number('9370043')->is_valid_number, '富山県魚津市袋');
ok($zip->set_number('9370044')->is_valid_number, '富山県魚津市横枕');
ok($zip->set_number('9370045')->is_valid_number, '富山県魚津市相木');
ok($zip->set_number('9370046')->is_valid_number, '富山県魚津市上村木');
ok($zip->set_number('9370047')->is_valid_number, '富山県魚津市相木新');
ok($zip->set_number('9370051')->is_valid_number, '富山県魚津市駅前新町');
ok($zip->set_number('9370052')->is_valid_number, '富山県魚津市緑町');
ok($zip->set_number('9370053')->is_valid_number, '富山県魚津市村木町');
ok($zip->set_number('9370054')->is_valid_number, '富山県魚津市金浦町');
ok($zip->set_number('9370055')->is_valid_number, '富山県魚津市中央通り');
ok($zip->set_number('9370056')->is_valid_number, '富山県魚津市諏訪町');
ok($zip->set_number('9370057')->is_valid_number, '富山県魚津市港町');
ok($zip->set_number('9370058')->is_valid_number, '富山県魚津市火の宮町');
ok($zip->set_number('9370059')->is_valid_number, '富山県魚津市末広町');
ok($zip->set_number('9370061')->is_valid_number, '富山県魚津市仏田');
ok($zip->set_number('9370062')->is_valid_number, '富山県魚津市仏又');
ok($zip->set_number('9370063')->is_valid_number, '富山県魚津市青島');
ok($zip->set_number('9370064')->is_valid_number, '富山県魚津市高畠');
ok($zip->set_number('9370065')->is_valid_number, '富山県魚津市北中');
ok($zip->set_number('9370066')->is_valid_number, '富山県魚津市北鬼江');
ok($zip->set_number('9370067')->is_valid_number, '富山県魚津市釈迦堂');
ok($zip->set_number('9370068')->is_valid_number, '富山県魚津市本新');
ok($zip->set_number('9370068')->is_valid_number, '富山県魚津市本新町');
ok($zip->set_number('9370801')->is_valid_number, '富山県魚津市新金屋');
ok($zip->set_number('9370802')->is_valid_number, '富山県魚津市下村木町');
ok($zip->set_number('9370803')->is_valid_number, '富山県魚津市本江新町');
ok($zip->set_number('9370804')->is_valid_number, '富山県魚津市並木町');
ok($zip->set_number('9370805')->is_valid_number, '富山県魚津市本江');
ok($zip->set_number('9370806')->is_valid_number, '富山県魚津市友道');
ok($zip->set_number('9370807')->is_valid_number, '富山県魚津市大光寺');
ok($zip->set_number('9370811')->is_valid_number, '富山県魚津市三田');
ok($zip->set_number('9370812')->is_valid_number, '富山県魚津市印田');
ok($zip->set_number('9370813')->is_valid_number, '富山県魚津市石垣新');
ok($zip->set_number('9370814')->is_valid_number, '富山県魚津市石垣');
ok($zip->set_number('9370815')->is_valid_number, '富山県魚津市大海寺新');
ok($zip->set_number('9370816')->is_valid_number, '富山県魚津市大海寺野');
ok($zip->set_number('9370821')->is_valid_number, '富山県魚津市出');
ok($zip->set_number('9370822')->is_valid_number, '富山県魚津市舛田');
ok($zip->set_number('9370823')->is_valid_number, '富山県魚津市湯上');
ok($zip->set_number('9370824')->is_valid_number, '富山県魚津市室田');
ok($zip->set_number('9370825')->is_valid_number, '富山県魚津市稗畠');
ok($zip->set_number('9370826')->is_valid_number, '富山県魚津市北山');
ok($zip->set_number('9370827')->is_valid_number, '富山県魚津市坪野');
ok($zip->set_number('9370828')->is_valid_number, '富山県魚津市池谷');
ok($zip->set_number('9370831')->is_valid_number, '富山県魚津市観音堂');
ok($zip->set_number('9370832')->is_valid_number, '富山県魚津市金山谷');
ok($zip->set_number('9370833')->is_valid_number, '富山県魚津市小菅沼');
ok($zip->set_number('9370834')->is_valid_number, '富山県魚津市鹿熊');
ok($zip->set_number('9370835')->is_valid_number, '富山県魚津市大熊');
ok($zip->set_number('9370836')->is_valid_number, '富山県魚津市鉢');
ok($zip->set_number('9370837')->is_valid_number, '富山県魚津市虎谷');
ok($zip->set_number('9370841')->is_valid_number, '富山県魚津市佐伯');
ok($zip->set_number('9370842')->is_valid_number, '富山県魚津市吉野');
ok($zip->set_number('9370843')->is_valid_number, '富山県魚津市上野');
ok($zip->set_number('9370844')->is_valid_number, '富山県魚津市下椿');
ok($zip->set_number('9370845')->is_valid_number, '富山県魚津市舛方');
ok($zip->set_number('9370846')->is_valid_number, '富山県魚津市有山');
ok($zip->set_number('9370847')->is_valid_number, '富山県魚津市浅生');
ok($zip->set_number('9370851')->is_valid_number, '富山県魚津市住吉');
ok($zip->set_number('9370852')->is_valid_number, '富山県魚津市慶野');
ok($zip->set_number('9370853')->is_valid_number, '富山県魚津市宮津');
ok($zip->set_number('9370854')->is_valid_number, '富山県魚津市弥源寺');
ok($zip->set_number('9370855')->is_valid_number, '富山県魚津市川原');
ok($zip->set_number('9370856')->is_valid_number, '富山県魚津市川縁');
ok($zip->set_number('9370857')->is_valid_number, '富山県魚津市三ケ');
ok($zip->set_number('9370861')->is_valid_number, '富山県魚津市鴨川町');
ok($zip->set_number('9370862')->is_valid_number, '富山県魚津市文化町');
ok($zip->set_number('9370863')->is_valid_number, '富山県魚津市新宿');
ok($zip->set_number('9370864')->is_valid_number, '富山県魚津市新角川');
ok($zip->set_number('9370865')->is_valid_number, '富山県魚津市上口');
ok($zip->set_number('9370866')->is_valid_number, '富山県魚津市本町');
ok($zip->set_number('9370867')->is_valid_number, '富山県魚津市真成寺町');
ok($zip->set_number('9370868')->is_valid_number, '富山県魚津市双葉町');
ok($zip->set_number('9380000')->is_valid_number, '富山県黒部市以下に掲載がない場合');
ok($zip->set_number('9380001')->is_valid_number, '富山県黒部市荒俣');
ok($zip->set_number('9380002')->is_valid_number, '富山県黒部市飛騨');
ok($zip->set_number('9380003')->is_valid_number, '富山県黒部市六天');
ok($zip->set_number('9380004')->is_valid_number, '富山県黒部市飯沢');
ok($zip->set_number('9380005')->is_valid_number, '富山県黒部市吉田');
ok($zip->set_number('9380006')->is_valid_number, '富山県黒部市大開');
ok($zip->set_number('9380011')->is_valid_number, '富山県黒部市黒部新');
ok($zip->set_number('9380012')->is_valid_number, '富山県黒部市出島');
ok($zip->set_number('9380013')->is_valid_number, '富山県黒部市沓掛');
ok($zip->set_number('9380014')->is_valid_number, '富山県黒部市植木');
ok($zip->set_number('9380015')->is_valid_number, '富山県黒部市北野');
ok($zip->set_number('9380021')->is_valid_number, '富山県黒部市古御堂');
ok($zip->set_number('9380022')->is_valid_number, '富山県黒部市金屋');
ok($zip->set_number('9380023')->is_valid_number, '富山県黒部市堀高');
ok($zip->set_number('9380024')->is_valid_number, '富山県黒部市高橋');
ok($zip->set_number('9380025')->is_valid_number, '富山県黒部市堀切新');
ok($zip->set_number('9380026')->is_valid_number, '富山県黒部市田家角内');
ok($zip->set_number('9380027')->is_valid_number, '富山県黒部市中新');
ok($zip->set_number('9380028')->is_valid_number, '富山県黒部市栃沢');
ok($zip->set_number('9380031')->is_valid_number, '富山県黒部市三日市');
ok($zip->set_number('9380032')->is_valid_number, '富山県黒部市天池');
ok($zip->set_number('9380033')->is_valid_number, '富山県黒部市中野道');
ok($zip->set_number('9380034')->is_valid_number, '富山県黒部市中野');
ok($zip->set_number('9380035')->is_valid_number, '富山県黒部市牧野');
ok($zip->set_number('9380036')->is_valid_number, '富山県黒部市北新');
ok($zip->set_number('9380037')->is_valid_number, '富山県黒部市新牧野');
ok($zip->set_number('9380038')->is_valid_number, '富山県黒部市新天');
ok($zip->set_number('9380039')->is_valid_number, '富山県黒部市堂田');
ok($zip->set_number('9380041')->is_valid_number, '富山県黒部市堀切');
ok($zip->set_number('9380042')->is_valid_number, '富山県黒部市天神新');
ok($zip->set_number('9380043')->is_valid_number, '富山県黒部市犬山');
ok($zip->set_number('9380044')->is_valid_number, '富山県黒部市荒町');
ok($zip->set_number('9380045')->is_valid_number, '富山県黒部市田家新');
ok($zip->set_number('9380046')->is_valid_number, '富山県黒部市神谷');
ok($zip->set_number('9380047')->is_valid_number, '富山県黒部市窪野');
ok($zip->set_number('9380048')->is_valid_number, '富山県黒部市阿古屋野');
ok($zip->set_number('9380049')->is_valid_number, '富山県黒部市山田');
ok($zip->set_number('9380051')->is_valid_number, '富山県黒部市立野');
ok($zip->set_number('9380052')->is_valid_number, '富山県黒部市経立野');
ok($zip->set_number('9380053')->is_valid_number, '富山県黒部市山立野');
ok($zip->set_number('9380054')->is_valid_number, '富山県黒部市岡');
ok($zip->set_number('9380055')->is_valid_number, '富山県黒部市浜石田');
ok($zip->set_number('9380056')->is_valid_number, '富山県黒部市新町');
ok($zip->set_number('9380057')->is_valid_number, '富山県黒部市石田新');
ok($zip->set_number('9380058')->is_valid_number, '富山県黒部市正光寺新');
ok($zip->set_number('9380059')->is_valid_number, '富山県黒部市石田');
ok($zip->set_number('9380061')->is_valid_number, '富山県黒部市生地神区');
ok($zip->set_number('9380062')->is_valid_number, '富山県黒部市生地(轟下)');
ok($zip->set_number('9380063')->is_valid_number, '富山県黒部市生地四ツ屋新');
ok($zip->set_number('9380064')->is_valid_number, '富山県黒部市生地(緑町)');
ok($zip->set_number('9380065')->is_valid_number, '富山県黒部市生地(神明町)');
ok($zip->set_number('9380066')->is_valid_number, '富山県黒部市生地');
ok($zip->set_number('9380071')->is_valid_number, '富山県黒部市生地山新');
ok($zip->set_number('9380072')->is_valid_number, '富山県黒部市生地中区');
ok($zip->set_number('9380073')->is_valid_number, '富山県黒部市生地(上町)');
ok($zip->set_number('9380074')->is_valid_number, '富山県黒部市生地(四十物町)');
ok($zip->set_number('9380075')->is_valid_number, '富山県黒部市生地(大町)');
ok($zip->set_number('9380076')->is_valid_number, '富山県黒部市生地(宮川町)');
ok($zip->set_number('9380081')->is_valid_number, '富山県黒部市生地経新');
ok($zip->set_number('9380082')->is_valid_number, '富山県黒部市生地芦区');
ok($zip->set_number('9380083')->is_valid_number, '富山県黒部市生地(阿弥陀堂)');
ok($zip->set_number('9380084')->is_valid_number, '富山県黒部市生地芦崎');
ok($zip->set_number('9380085')->is_valid_number, '富山県黒部市生地吉田');
ok($zip->set_number('9380086')->is_valid_number, '富山県黒部市生地吉田新');
ok($zip->set_number('9380101')->is_valid_number, '富山県下新川郡入善町今江');
ok($zip->set_number('9380102')->is_valid_number, '富山県下新川郡入善町古林');
ok($zip->set_number('9380103')->is_valid_number, '富山県下新川郡入善町舟見');
ok($zip->set_number('9380104')->is_valid_number, '富山県下新川郡入善町西中');
ok($zip->set_number('9380105')->is_valid_number, '富山県下新川郡入善町中沢');
ok($zip->set_number('9380106')->is_valid_number, '富山県下新川郡入善町野中');
ok($zip->set_number('9380161')->is_valid_number, '富山県下新川郡朝日町殿町');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎(岩崎)');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎(小在池)');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎(越)');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎(辻)');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎(花房)');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎(羽入)');
ok($zip->set_number('9380162')->is_valid_number, '富山県下新川郡朝日町山崎(坊)');
ok($zip->set_number('9380163')->is_valid_number, '富山県下新川郡朝日町湯ノ瀬');
ok($zip->set_number('9380164')->is_valid_number, '富山県下新川郡朝日町棚山');
ok($zip->set_number('9380165')->is_valid_number, '富山県下新川郡朝日町山崎新');
ok($zip->set_number('9380166')->is_valid_number, '富山県下新川郡朝日町細野');
ok($zip->set_number('9380167')->is_valid_number, '富山県下新川郡朝日町山王');
ok($zip->set_number('9380168')->is_valid_number, '富山県下新川郡朝日町藤塚(横道)');
ok($zip->set_number('9380169')->is_valid_number, '富山県下新川郡朝日町下野');
ok($zip->set_number('9380171')->is_valid_number, '富山県黒部市宇奈月町明日');
ok($zip->set_number('9380172')->is_valid_number, '富山県黒部市宇奈月町土山');
ok($zip->set_number('9380173')->is_valid_number, '富山県黒部市宇奈月町中谷');
ok($zip->set_number('9380174')->is_valid_number, '富山県黒部市宇奈月町音澤(1~999)');
ok($zip->set_number('9380175')->is_valid_number, '富山県黒部市宇奈月町愛本橋爪東官林地内');
ok($zip->set_number('9380176')->is_valid_number, '富山県黒部市宇奈月町中ノ口');
ok($zip->set_number('9380177')->is_valid_number, '富山県黒部市宇奈月町愛本新');
ok($zip->set_number('9380178')->is_valid_number, '富山県黒部市宇奈月町栗虫');
ok($zip->set_number('9380179')->is_valid_number, '富山県黒部市宇奈月町舟見');
ok($zip->set_number('9380274')->is_valid_number, '富山県黒部市宇奈月町音澤(1000~)');
ok($zip->set_number('9380281')->is_valid_number, '富山県黒部市宇奈月町内山');
ok($zip->set_number('9380282')->is_valid_number, '富山県黒部市宇奈月温泉');
ok($zip->set_number('9380283')->is_valid_number, '富山県黒部市黒部峡谷口');
ok($zip->set_number('9380801')->is_valid_number, '富山県黒部市荻生');
ok($zip->set_number('9380802')->is_valid_number, '富山県黒部市若栗');
ok($zip->set_number('9380803')->is_valid_number, '富山県黒部市栗寺');
ok($zip->set_number('9380804')->is_valid_number, '富山県黒部市宮野');
ok($zip->set_number('9380805')->is_valid_number, '富山県黒部市吉城寺');
ok($zip->set_number('9380806')->is_valid_number, '富山県黒部市前沢');
ok($zip->set_number('9380807')->is_valid_number, '富山県黒部市山田新');
ok($zip->set_number('9380808')->is_valid_number, '富山県黒部市新堂');
ok($zip->set_number('9380811')->is_valid_number, '富山県黒部市内生谷');
ok($zip->set_number('9380812')->is_valid_number, '富山県黒部市笠破');
ok($zip->set_number('9380813')->is_valid_number, '富山県黒部市田籾');
ok($zip->set_number('9380814')->is_valid_number, '富山県黒部市嘉例沢');
ok($zip->set_number('9380815')->is_valid_number, '富山県黒部市福平');
ok($zip->set_number('9380816')->is_valid_number, '富山県黒部市池尻');
ok($zip->set_number('9380821')->is_valid_number, '富山県黒部市柳沢');
ok($zip->set_number('9380822')->is_valid_number, '富山県黒部市別所');
ok($zip->set_number('9380823')->is_valid_number, '富山県黒部市釈迦堂');
ok($zip->set_number('9380824')->is_valid_number, '富山県黒部市阿弥陀堂');
ok($zip->set_number('9380825')->is_valid_number, '富山県黒部市尾山');
ok($zip->set_number('9380826')->is_valid_number, '富山県黒部市朴谷');
ok($zip->set_number('9380827')->is_valid_number, '富山県黒部市中陣');
ok($zip->set_number('9380831')->is_valid_number, '富山県黒部市宮沢');
ok($zip->set_number('9380832')->is_valid_number, '富山県黒部市枕野');
ok($zip->set_number('9380833')->is_valid_number, '富山県黒部市本野');
ok($zip->set_number('9380834')->is_valid_number, '富山県黒部市中山');
ok($zip->set_number('9380835')->is_valid_number, '富山県黒部市石田野');
ok($zip->set_number('9380836')->is_valid_number, '富山県黒部市鏡野');
ok($zip->set_number('9380837')->is_valid_number, '富山県黒部市田家野');
ok($zip->set_number('9380861')->is_valid_number, '富山県黒部市宇奈月町下立');
ok($zip->set_number('9380862')->is_valid_number, '富山県黒部市宇奈月町浦山');
ok($zip->set_number('9380863')->is_valid_number, '富山県黒部市宇奈月町熊野');
ok($zip->set_number('9380864')->is_valid_number, '富山県黒部市宇奈月町栃屋');
ok($zip->set_number('9390000')->is_valid_number, '富山県富山市以下に掲載がない場合');
ok($zip->set_number('9390101')->is_valid_number, '富山県高岡市福岡町赤丸');
ok($zip->set_number('9390102')->is_valid_number, '富山県高岡市福岡町三日市');
ok($zip->set_number('9390103')->is_valid_number, '富山県高岡市福岡町西');
ok($zip->set_number('9390104')->is_valid_number, '富山県高岡市福岡町加茂');
ok($zip->set_number('9390105')->is_valid_number, '富山県高岡市福岡町馬場');
ok($zip->set_number('9390106')->is_valid_number, '富山県高岡市福岡町舞谷');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡(旭町)');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡(大蔵町)');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡(清水町)');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡(中町)');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡新(旭町)');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡新(大蔵町)');
ok($zip->set_number('9390111')->is_valid_number, '富山県高岡市福岡町福岡新(清水町)');
ok($zip->set_number('9390112')->is_valid_number, '富山県高岡市福岡町荒屋敷(表元町)');
ok($zip->set_number('9390112')->is_valid_number, '富山県高岡市福岡町荒屋敷(中央通り)');
ok($zip->set_number('9390112')->is_valid_number, '富山県高岡市福岡町大滝(表元町)');
ok($zip->set_number('9390112')->is_valid_number, '富山県高岡市福岡町下蓑新(表元町)');
ok($zip->set_number('9390112')->is_valid_number, '富山県高岡市福岡町福岡(表元町)');
ok($zip->set_number('9390112')->is_valid_number, '富山県高岡市福岡町福岡新(中央通り)');
ok($zip->set_number('9390113')->is_valid_number, '富山県高岡市福岡町上蓑(末広町)');
ok($zip->set_number('9390113')->is_valid_number, '富山県高岡市福岡町下蓑(末広町)');
ok($zip->set_number('9390113')->is_valid_number, '富山県高岡市福岡町下蓑(中島町)');
ok($zip->set_number('9390113')->is_valid_number, '富山県高岡市福岡町下蓑(元町)');
ok($zip->set_number('9390113')->is_valid_number, '富山県高岡市福岡町下蓑新(末広町)');
ok($zip->set_number('9390113')->is_valid_number, '富山県高岡市福岡町福岡(中島町)');
ok($zip->set_number('9390115')->is_valid_number, '富山県高岡市福岡町下蓑(新栄町)');
ok($zip->set_number('9390115')->is_valid_number, '富山県高岡市福岡町下蓑新');
ok($zip->set_number('9390115')->is_valid_number, '富山県高岡市福岡町下蓑新(新栄町)');
ok($zip->set_number('9390115')->is_valid_number, '富山県高岡市福岡町福岡新(新栄町)');
ok($zip->set_number('9390116')->is_valid_number, '富山県高岡市福岡町下蓑');
ok($zip->set_number('9390117')->is_valid_number, '富山県高岡市福岡町大野(桜木町)');
ok($zip->set_number('9390117')->is_valid_number, '富山県高岡市福岡町大野(早稲田町)');
ok($zip->set_number('9390117')->is_valid_number, '富山県高岡市福岡町福岡新');
ok($zip->set_number('9390117')->is_valid_number, '富山県高岡市福岡町福岡新(桜木町)');
ok($zip->set_number('9390117')->is_valid_number, '富山県高岡市福岡町福岡新(西干場)');
ok($zip->set_number('9390117')->is_valid_number, '富山県高岡市福岡町福岡新(早稲田町)');
ok($zip->set_number('9390118')->is_valid_number, '富山県高岡市福岡町大野');
ok($zip->set_number('9390119')->is_valid_number, '富山県高岡市福岡町大滝(橋上町)');
ok($zip->set_number('9390119')->is_valid_number, '富山県高岡市福岡町福岡(西町)');
ok($zip->set_number('9390119')->is_valid_number, '富山県高岡市福岡町福岡(堀川町)');
ok($zip->set_number('9390119')->is_valid_number, '富山県高岡市福岡町福岡新(西町)');
ok($zip->set_number('9390119')->is_valid_number, '富山県高岡市福岡町福岡新(橋上町)');
ok($zip->set_number('9390119')->is_valid_number, '富山県高岡市福岡町福岡新(堀川町)');
ok($zip->set_number('9390121')->is_valid_number, '富山県高岡市福岡町下老子');
ok($zip->set_number('9390122')->is_valid_number, '富山県高岡市福岡町一歩二歩');
ok($zip->set_number('9390123')->is_valid_number, '富山県高岡市福岡町西川原島');
ok($zip->set_number('9390124')->is_valid_number, '富山県高岡市福岡町小伊勢領');
ok($zip->set_number('9390125')->is_valid_number, '富山県高岡市福岡町矢部');
ok($zip->set_number('9390126')->is_valid_number, '富山県高岡市福岡町蓑島');
ok($zip->set_number('9390127')->is_valid_number, '富山県高岡市福岡町上蓑');
ok($zip->set_number('9390128')->is_valid_number, '富山県高岡市福岡町江尻');
ok($zip->set_number('9390131')->is_valid_number, '富山県高岡市福岡町荒屋敷');
ok($zip->set_number('9390132')->is_valid_number, '富山県高岡市福岡町大滝');
ok($zip->set_number('9390132')->is_valid_number, '富山県高岡市福岡町大滝(木舟新)');
ok($zip->set_number('9390133')->is_valid_number, '富山県高岡市福岡町開ほつ');
ok($zip->set_number('9390134')->is_valid_number, '富山県高岡市福岡町木舟');
ok($zip->set_number('9390135')->is_valid_number, '富山県高岡市福岡町本領');
ok($zip->set_number('9390141')->is_valid_number, '富山県高岡市福岡町鳥倉');
ok($zip->set_number('9390142')->is_valid_number, '富山県高岡市福岡町土屋');
ok($zip->set_number('9390143')->is_valid_number, '富山県高岡市福岡町下向田');
ok($zip->set_number('9390144')->is_valid_number, '富山県高岡市福岡町上向田');
ok($zip->set_number('9390145')->is_valid_number, '富山県高岡市福岡町上野');
ok($zip->set_number('9390151')->is_valid_number, '富山県高岡市福岡町沢川');
ok($zip->set_number('9390152')->is_valid_number, '富山県高岡市福岡町五位');
ok($zip->set_number('9390153')->is_valid_number, '富山県高岡市福岡町花尾');
ok($zip->set_number('9390154')->is_valid_number, '富山県高岡市福岡町栃丘');
ok($zip->set_number('9390155')->is_valid_number, '富山県高岡市福岡町西明寺');
ok($zip->set_number('9390156')->is_valid_number, '富山県高岡市福岡町小野');
ok($zip->set_number('9390171')->is_valid_number, '石川県羽咋郡宝達志水町沢川');
ok($zip->set_number('9390231')->is_valid_number, '富山県射水市犬内');
ok($zip->set_number('9390232')->is_valid_number, '富山県射水市大門');
ok($zip->set_number('9390233')->is_valid_number, '富山県射水市大門新');
ok($zip->set_number('9390234')->is_valid_number, '富山県射水市二口');
ok($zip->set_number('9390235')->is_valid_number, '富山県射水市枇杷首');
ok($zip->set_number('9390241')->is_valid_number, '富山県射水市中村');
ok($zip->set_number('9390242')->is_valid_number, '富山県射水市安吉');
ok($zip->set_number('9390243')->is_valid_number, '富山県射水市下若');
ok($zip->set_number('9390244')->is_valid_number, '富山県射水市本田');
ok($zip->set_number('9390245')->is_valid_number, '富山県射水市棚田');
ok($zip->set_number('9390246')->is_valid_number, '富山県射水市大門本江');
ok($zip->set_number('9390247')->is_valid_number, '富山県射水市あおば台');
ok($zip->set_number('9390251')->is_valid_number, '富山県射水市土合');
ok($zip->set_number('9390252')->is_valid_number, '富山県射水市下条');
ok($zip->set_number('9390253')->is_valid_number, '富山県射水市堀内');
ok($zip->set_number('9390254')->is_valid_number, '富山県射水市島');
ok($zip->set_number('9390255')->is_valid_number, '富山県射水市上条');
ok($zip->set_number('9390256')->is_valid_number, '富山県射水市広上');
ok($zip->set_number('9390257')->is_valid_number, '富山県射水市西広上');
ok($zip->set_number('9390271')->is_valid_number, '富山県射水市大島北野');
ok($zip->set_number('9390272')->is_valid_number, '富山県射水市若杉');
ok($zip->set_number('9390273')->is_valid_number, '富山県射水市中野');
ok($zip->set_number('9390274')->is_valid_number, '富山県射水市小島');
ok($zip->set_number('9390275')->is_valid_number, '富山県射水市八塚');
ok($zip->set_number('9390276')->is_valid_number, '富山県射水市北野');
ok($zip->set_number('9390281')->is_valid_number, '富山県射水市北高木');
ok($zip->set_number('9390282')->is_valid_number, '富山県射水市南高木');
ok($zip->set_number('9390283')->is_valid_number, '富山県射水市鳥取');
ok($zip->set_number('9390284')->is_valid_number, '富山県射水市新開発');
ok($zip->set_number('9390285')->is_valid_number, '富山県射水市本開発');
ok($zip->set_number('9390286')->is_valid_number, '富山県射水市今開発');
ok($zip->set_number('9390287')->is_valid_number, '富山県射水市赤井');
ok($zip->set_number('9390288')->is_valid_number, '富山県射水市小林');
ok($zip->set_number('9390300')->is_valid_number, '富山県射水市以下に掲載がない場合');
ok($zip->set_number('9390301')->is_valid_number, '富山県射水市稲積');
ok($zip->set_number('9390302')->is_valid_number, '富山県射水市大江');
ok($zip->set_number('9390303')->is_valid_number, '富山県射水市西高木');
ok($zip->set_number('9390304')->is_valid_number, '富山県射水市小杉白石');
ok($zip->set_number('9390304')->is_valid_number, '富山県射水市小杉白石(小白石)');
ok($zip->set_number('9390305')->is_valid_number, '富山県射水市鷲塚');
ok($zip->set_number('9390306')->is_valid_number, '富山県射水市手崎');
ok($zip->set_number('9390307')->is_valid_number, '富山県射水市戸破(針原)');
ok($zip->set_number('9390311')->is_valid_number, '富山県射水市黒河');
ok($zip->set_number('9390311')->is_valid_number, '富山県射水市黒河新');
ok($zip->set_number('9390312')->is_valid_number, '富山県射水市中老田新');
ok($zip->set_number('9390313')->is_valid_number, '富山県射水市塚越');
ok($zip->set_number('9390314')->is_valid_number, '富山県射水市土代');
ok($zip->set_number('9390315')->is_valid_number, '富山県射水市椎土');
ok($zip->set_number('9390316')->is_valid_number, '富山県射水市小杉北野');
ok($zip->set_number('9390317')->is_valid_number, '富山県射水市山本新');
ok($zip->set_number('9390318')->is_valid_number, '富山県射水市池多');
ok($zip->set_number('9390319')->is_valid_number, '富山県射水市東太閤山');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市青井谷');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市青井谷(新屋敷)');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市青井谷(五官野)');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市青井谷(三野)');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市青井谷(西谷)');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市青井谷(水上谷)');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市宿屋');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市浄土寺');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市浄土寺(林寺)');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市浄土寺(東谷)');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市入会地');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市野手');
ok($zip->set_number('9390321')->is_valid_number, '富山県射水市流通センター(青井谷1、2丁目)');
ok($zip->set_number('9390322')->is_valid_number, '富山県射水市上野');
ok($zip->set_number('9390323')->is_valid_number, '富山県射水市平野');
ok($zip->set_number('9390331')->is_valid_number, '富山県射水市下条新');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市橋下条');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市橋下条(赤田)');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市橋下条(駅南通り)');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市橋下条(囲山)');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市橋下条(五歩一)');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市橋下条(大白)');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市橋下条(二の井)');
ok($zip->set_number('9390332')->is_valid_number, '富山県射水市日宮');
ok($zip->set_number('9390333')->is_valid_number, '富山県射水市一条');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(愛宕)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(伊勢領)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(一番町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(貝塚町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(上新町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(さくら町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(白銀町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(新三ケ)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(新富町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(水源町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(諏訪町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(高寺)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(田町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(常盤町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(錦町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(西町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(初音町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(本中町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(本丸町)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(水上)');
ok($zip->set_number('9390341')->is_valid_number, '富山県射水市三ケ(元町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(荒町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(江上)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(鍛治屋橋)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(神川町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(北手崎)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(木舟町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(栄町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(さくら町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(昭和通り)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(新栄町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(新町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(末永町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(高寺)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(高穂町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(宝町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(茶屋町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(中央通り)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(中町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(西楠町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(乗舟町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(平成町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(南通り)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(元町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(若葉町)');
ok($zip->set_number('9390351')->is_valid_number, '富山県射水市戸破(若宮町)');
ok($zip->set_number('9390361')->is_valid_number, '富山県射水市太閤町');
ok($zip->set_number('9390362')->is_valid_number, '富山県射水市太閤山');
ok($zip->set_number('9390363')->is_valid_number, '富山県射水市中太閤山');
ok($zip->set_number('9390364')->is_valid_number, '富山県射水市南太閤山');
ok($zip->set_number('9390401')->is_valid_number, '富山県射水市水戸田');
ok($zip->set_number('9390402')->is_valid_number, '富山県射水市流通センター水戸田');
ok($zip->set_number('9390403')->is_valid_number, '富山県射水市生源寺');
ok($zip->set_number('9390404')->is_valid_number, '富山県射水市市井');
ok($zip->set_number('9390405')->is_valid_number, '富山県射水市藤巻');
ok($zip->set_number('9390406')->is_valid_number, '富山県射水市開口');
ok($zip->set_number('9390407')->is_valid_number, '富山県射水市竹鼻');
ok($zip->set_number('9390408')->is_valid_number, '富山県射水市若林');
ok($zip->set_number('9390411')->is_valid_number, '富山県射水市円池');
ok($zip->set_number('9390412')->is_valid_number, '富山県射水市荒町');
ok($zip->set_number('9390413')->is_valid_number, '富山県射水市串田');
ok($zip->set_number('9390414')->is_valid_number, '富山県射水市生源寺新');
ok($zip->set_number('9390415')->is_valid_number, '富山県射水市梅木');
ok($zip->set_number('9390416')->is_valid_number, '富山県射水市串田新');
ok($zip->set_number('9390417')->is_valid_number, '富山県射水市小泉');
ok($zip->set_number('9390418')->is_valid_number, '富山県射水市布目沢');
ok($zip->set_number('9390501')->is_valid_number, '富山県富山市水橋東浜町');
ok($zip->set_number('9390502')->is_valid_number, '富山県富山市水橋地蔵町');
ok($zip->set_number('9390503')->is_valid_number, '富山県富山市水橋西出町');
ok($zip->set_number('9390504')->is_valid_number, '富山県富山市水橋田町');
ok($zip->set_number('9390505')->is_valid_number, '富山県富山市水橋東天神町');
ok($zip->set_number('9390506')->is_valid_number, '富山県富山市水橋大町(中部地区)');
ok($zip->set_number('9390506')->is_valid_number, '富山県富山市水橋中大町');
ok($zip->set_number('9390507')->is_valid_number, '富山県富山市水橋西天神町');
ok($zip->set_number('9390508')->is_valid_number, '富山県富山市水橋西浜町');
ok($zip->set_number('9390509')->is_valid_number, '富山県富山市水橋町');
ok($zip->set_number('9390511')->is_valid_number, '富山県富山市水橋朝日町');
ok($zip->set_number('9390511')->is_valid_number, '富山県富山市水橋魚躬');
ok($zip->set_number('9390511')->is_valid_number, '富山県富山市水橋高月');
ok($zip->set_number('9390512')->is_valid_number, '富山県富山市水橋東出町');
ok($zip->set_number('9390513')->is_valid_number, '富山県富山市水橋中出町');
ok($zip->set_number('9390514')->is_valid_number, '富山県富山市水橋稲荷町');
ok($zip->set_number('9390515')->is_valid_number, '富山県富山市水橋新町');
ok($zip->set_number('9390521')->is_valid_number, '富山県富山市水橋下段');
ok($zip->set_number('9390521')->is_valid_number, '富山県富山市水橋中村町');
ok($zip->set_number('9390522')->is_valid_number, '富山県富山市水橋中村栄町');
ok($zip->set_number('9390523')->is_valid_number, '富山県富山市水橋中村新町');
ok($zip->set_number('9390524')->is_valid_number, '富山県富山市水橋東舘町');
ok($zip->set_number('9390525')->is_valid_number, '富山県富山市水橋新舘町');
ok($zip->set_number('9390526')->is_valid_number, '富山県富山市水橋舘町');
ok($zip->set_number('9390527')->is_valid_number, '富山県富山市水橋新大町');
ok($zip->set_number('9390528')->is_valid_number, '富山県富山市水橋明治町');
ok($zip->set_number('9390531')->is_valid_number, '富山県富山市水橋市江');
ok($zip->set_number('9390532')->is_valid_number, '富山県富山市水橋市江新町');
ok($zip->set_number('9390533')->is_valid_number, '富山県富山市水橋高志園町');
ok($zip->set_number('9390534')->is_valid_number, '富山県富山市水橋狐塚');
ok($zip->set_number('9390535')->is_valid_number, '富山県富山市水橋開発町');
ok($zip->set_number('9390536')->is_valid_number, '富山県富山市水橋柳寺');
ok($zip->set_number('9390541')->is_valid_number, '富山県富山市水橋鏡田');
ok($zip->set_number('9390542')->is_valid_number, '富山県富山市水橋堅田');
ok($zip->set_number('9390543')->is_valid_number, '富山県富山市水橋五郎丸');
ok($zip->set_number('9390544')->is_valid_number, '富山県富山市水橋上砂子坂');
ok($zip->set_number('9390544')->is_valid_number, '富山県富山市水橋下砂子坂');
ok($zip->set_number('9390544')->is_valid_number, '富山県富山市水橋下砂子坂新');
ok($zip->set_number('9390545')->is_valid_number, '富山県富山市水橋伊勢領');
ok($zip->set_number('9390546')->is_valid_number, '富山県富山市水橋上桜木');
ok($zip->set_number('9390546')->is_valid_number, '富山県富山市水橋桜木');
ok($zip->set_number('9390547')->is_valid_number, '富山県富山市水橋小池');
ok($zip->set_number('9390551')->is_valid_number, '富山県富山市水橋石政');
ok($zip->set_number('9390552')->is_valid_number, '富山県富山市水橋恋塚');
ok($zip->set_number('9390553')->is_valid_number, '富山県富山市水橋小出');
ok($zip->set_number('9390554')->is_valid_number, '富山県富山市水橋専光寺');
ok($zip->set_number('9390555')->is_valid_number, '富山県富山市水橋高寺');
ok($zip->set_number('9390556')->is_valid_number, '富山県富山市水橋曲淵');
ok($zip->set_number('9390557')->is_valid_number, '富山県富山市水橋大正');
ok($zip->set_number('9390557')->is_valid_number, '富山県富山市水橋大正南部');
ok($zip->set_number('9390557')->is_valid_number, '富山県富山市水橋大正北部');
ok($zip->set_number('9390558')->is_valid_number, '富山県富山市水橋上条新町');
ok($zip->set_number('9390561')->is_valid_number, '富山県富山市水橋石割');
ok($zip->set_number('9390562')->is_valid_number, '富山県富山市水橋田伏');
ok($zip->set_number('9390563')->is_valid_number, '富山県富山市水橋佐野竹');
ok($zip->set_number('9390564')->is_valid_number, '富山県富山市水橋清水堂');
ok($zip->set_number('9390565')->is_valid_number, '富山県富山市水橋金広');
ok($zip->set_number('9390566')->is_valid_number, '富山県富山市水橋中馬場');
ok($zip->set_number('9390567')->is_valid_number, '富山県富山市水橋北馬場');
ok($zip->set_number('9390568')->is_valid_number, '富山県富山市水橋平塚');
ok($zip->set_number('9390600')->is_valid_number, '富山県下新川郡入善町以下に掲載がない場合');
ok($zip->set_number('9390611')->is_valid_number, '富山県下新川郡入善町古黒部');
ok($zip->set_number('9390612')->is_valid_number, '富山県下新川郡入善町藤原');
ok($zip->set_number('9390613')->is_valid_number, '富山県下新川郡入善町田の又');
ok($zip->set_number('9390614')->is_valid_number, '富山県下新川郡入善町君島');
ok($zip->set_number('9390615')->is_valid_number, '富山県下新川郡入善町八幡');
ok($zip->set_number('9390616')->is_valid_number, '富山県下新川郡入善町横山');
ok($zip->set_number('9390617')->is_valid_number, '富山県下新川郡入善町春日');
ok($zip->set_number('9390621')->is_valid_number, '富山県下新川郡入善町荒又');
ok($zip->set_number('9390622')->is_valid_number, '富山県下新川郡入善町日吉');
ok($zip->set_number('9390623')->is_valid_number, '富山県下新川郡入善町小杉');
ok($zip->set_number('9390624')->is_valid_number, '富山県下新川郡入善町青島');
ok($zip->set_number('9390625')->is_valid_number, '富山県下新川郡入善町神林');
ok($zip->set_number('9390626')->is_valid_number, '富山県下新川郡入善町入膳');
ok($zip->set_number('9390627')->is_valid_number, '富山県下新川郡入善町椚山');
ok($zip->set_number('9390628')->is_valid_number, '富山県下新川郡入善町椚山新');
ok($zip->set_number('9390631')->is_valid_number, '富山県下新川郡入善町下山');
ok($zip->set_number('9390632')->is_valid_number, '富山県下新川郡入善町墓ノ木');
ok($zip->set_number('9390633')->is_valid_number, '富山県下新川郡入善町浦山新');
ok($zip->set_number('9390634')->is_valid_number, '富山県下新川郡入善町小摺戸');
ok($zip->set_number('9390635')->is_valid_number, '富山県下新川郡入善町若栗新');
ok($zip->set_number('9390636')->is_valid_number, '富山県下新川郡入善町一宿');
ok($zip->set_number('9390637')->is_valid_number, '富山県下新川郡入善町新屋');
ok($zip->set_number('9390641')->is_valid_number, '富山県下新川郡入善町下上野');
ok($zip->set_number('9390642')->is_valid_number, '富山県下新川郡入善町上野');
ok($zip->set_number('9390643')->is_valid_number, '富山県下新川郡入善町青木');
ok($zip->set_number('9390644')->is_valid_number, '富山県下新川郡入善町福島新');
ok($zip->set_number('9390645')->is_valid_number, '富山県下新川郡入善町福島');
ok($zip->set_number('9390646')->is_valid_number, '富山県下新川郡入善町青木新');
ok($zip->set_number('9390647')->is_valid_number, '富山県下新川郡入善町道古');
ok($zip->set_number('9390651')->is_valid_number, '富山県下新川郡入善町上飯野新');
ok($zip->set_number('9390652')->is_valid_number, '富山県下新川郡入善町袖沢');
ok($zip->set_number('9390653')->is_valid_number, '富山県下新川郡入善町上飯野');
ok($zip->set_number('9390654')->is_valid_number, '富山県下新川郡入善町板屋');
ok($zip->set_number('9390655')->is_valid_number, '富山県下新川郡入善町五郎八');
ok($zip->set_number('9390656')->is_valid_number, '富山県下新川郡入善町笹原');
ok($zip->set_number('9390657')->is_valid_number, '富山県下新川郡入善町東狐');
ok($zip->set_number('9390661')->is_valid_number, '富山県下新川郡入善町高瀬');
ok($zip->set_number('9390662')->is_valid_number, '富山県下新川郡入善町下飯野新');
ok($zip->set_number('9390663')->is_valid_number, '富山県下新川郡入善町下飯野');
ok($zip->set_number('9390664')->is_valid_number, '富山県下新川郡入善町蛇沢');
ok($zip->set_number('9390665')->is_valid_number, '富山県下新川郡入善町本村');
ok($zip->set_number('9390666')->is_valid_number, '富山県下新川郡入善町高畠');
ok($zip->set_number('9390667')->is_valid_number, '富山県下新川郡入善町芦崎');
ok($zip->set_number('9390671')->is_valid_number, '富山県下新川郡入善町東五十里');
ok($zip->set_number('9390672')->is_valid_number, '富山県下新川郡入善町田中');
ok($zip->set_number('9390673')->is_valid_number, '富山県下新川郡入善町吉原東');
ok($zip->set_number('9390674')->is_valid_number, '富山県下新川郡入善町吉原');
ok($zip->set_number('9390675')->is_valid_number, '富山県下新川郡入善町道市');
ok($zip->set_number('9390676')->is_valid_number, '富山県下新川郡入善町目川');
ok($zip->set_number('9390677')->is_valid_number, '富山県下新川郡入善町木根');
ok($zip->set_number('9390678')->is_valid_number, '富山県下新川郡入善町神子沢');
ok($zip->set_number('9390679')->is_valid_number, '富山県下新川郡入善町五十里');
ok($zip->set_number('9390700')->is_valid_number, '富山県下新川郡朝日町以下に掲載がない場合');
ok($zip->set_number('9390701')->is_valid_number, '富山県下新川郡朝日町横尾');
ok($zip->set_number('9390702')->is_valid_number, '富山県下新川郡朝日町元屋敷');
ok($zip->set_number('9390703')->is_valid_number, '富山県下新川郡朝日町宮崎');
ok($zip->set_number('9390704')->is_valid_number, '富山県下新川郡朝日町境');
ok($zip->set_number('9390705')->is_valid_number, '富山県下新川郡朝日町大平');
ok($zip->set_number('9390711')->is_valid_number, '富山県下新川郡朝日町笹川');
ok($zip->set_number('9390712')->is_valid_number, '富山県下新川郡朝日町蛭谷');
ok($zip->set_number('9390713')->is_valid_number, '富山県下新川郡朝日町長野');
ok($zip->set_number('9390714')->is_valid_number, '富山県下新川郡朝日町桜町');
ok($zip->set_number('9390715')->is_valid_number, '富山県下新川郡朝日町南保');
ok($zip->set_number('9390716')->is_valid_number, '富山県下新川郡朝日町南保町');
ok($zip->set_number('9390717')->is_valid_number, '富山県下新川郡朝日町石谷');
ok($zip->set_number('9390721')->is_valid_number, '富山県下新川郡朝日町三枚橋');
ok($zip->set_number('9390722')->is_valid_number, '富山県下新川郡朝日町大家庄');
ok($zip->set_number('9390723')->is_valid_number, '富山県下新川郡朝日町不動堂');
ok($zip->set_number('9390724')->is_valid_number, '富山県下新川郡朝日町横水');
ok($zip->set_number('9390725')->is_valid_number, '富山県下新川郡朝日町高橋');
ok($zip->set_number('9390726')->is_valid_number, '富山県下新川郡朝日町下山新');
ok($zip->set_number('9390727')->is_valid_number, '富山県下新川郡朝日町金山');
ok($zip->set_number('9390728')->is_valid_number, '富山県下新川郡朝日町窪田');
ok($zip->set_number('9390729')->is_valid_number, '富山県下新川郡朝日町舟川新');
ok($zip->set_number('9390731')->is_valid_number, '富山県下新川郡朝日町東草野');
ok($zip->set_number('9390732')->is_valid_number, '富山県下新川郡朝日町中草野');
ok($zip->set_number('9390733')->is_valid_number, '富山県下新川郡朝日町月山');
ok($zip->set_number('9390734')->is_valid_number, '富山県下新川郡朝日町草野');
ok($zip->set_number('9390735')->is_valid_number, '富山県下新川郡朝日町赤川');
ok($zip->set_number('9390736')->is_valid_number, '富山県下新川郡朝日町浜草野');
ok($zip->set_number('9390737')->is_valid_number, '富山県下新川郡朝日町月山新');
ok($zip->set_number('9390741')->is_valid_number, '富山県下新川郡朝日町泊');
ok($zip->set_number('9390742')->is_valid_number, '富山県下新川郡朝日町沼保');
ok($zip->set_number('9390743')->is_valid_number, '富山県下新川郡朝日町道下');
ok($zip->set_number('9390744')->is_valid_number, '富山県下新川郡朝日町平柳');
ok($zip->set_number('9390745')->is_valid_number, '富山県下新川郡朝日町西町');
ok($zip->set_number('9390746')->is_valid_number, '富山県下新川郡朝日町荒川');
ok($zip->set_number('9390747')->is_valid_number, '富山県下新川郡朝日町大屋');
ok($zip->set_number('9390748')->is_valid_number, '富山県下新川郡朝日町大屋新');
ok($zip->set_number('9390749')->is_valid_number, '富山県下新川郡朝日町泊新');
ok($zip->set_number('9390751')->is_valid_number, '富山県下新川郡朝日町野新');
ok($zip->set_number('9391101')->is_valid_number, '富山県高岡市戸出市野瀬');
ok($zip->set_number('9391102')->is_valid_number, '富山県高岡市戸出曙町');
ok($zip->set_number('9391102')->is_valid_number, '富山県高岡市戸出狼');
ok($zip->set_number('9391103')->is_valid_number, '富山県高岡市戸出池田町');
ok($zip->set_number('9391104')->is_valid_number, '富山県高岡市戸出町');
ok($zip->set_number('9391105')->is_valid_number, '富山県高岡市戸出伊勢領');
ok($zip->set_number('9391110')->is_valid_number, '富山県高岡市ICパーク');
ok($zip->set_number('9391111')->is_valid_number, '富山県高岡市戸出徳市');
ok($zip->set_number('9391112')->is_valid_number, '富山県高岡市戸出春日');
ok($zip->set_number('9391113')->is_valid_number, '富山県高岡市戸出石代');
ok($zip->set_number('9391114')->is_valid_number, '富山県高岡市戸出西部金屋');
ok($zip->set_number('9391115')->is_valid_number, '富山県高岡市戸出吉住新');
ok($zip->set_number('9391116')->is_valid_number, '富山県高岡市戸出吉住');
ok($zip->set_number('9391117')->is_valid_number, '富山県高岡市戸出大清水');
ok($zip->set_number('9391118')->is_valid_number, '富山県高岡市戸出栄町');
ok($zip->set_number('9391119')->is_valid_number, '富山県高岡市オフィスパーク');
ok($zip->set_number('9391120')->is_valid_number, '富山県高岡市グリーンパーク');
ok($zip->set_number('9391121')->is_valid_number, '富山県高岡市戸出葵町');
ok($zip->set_number('9391121')->is_valid_number, '富山県高岡市戸出青園町');
ok($zip->set_number('9391121')->is_valid_number, '富山県高岡市戸出光明寺');
ok($zip->set_number('9391122')->is_valid_number, '富山県高岡市戸出古戸出');
ok($zip->set_number('9391123')->is_valid_number, '富山県高岡市戸出行兼');
ok($zip->set_number('9391124')->is_valid_number, '富山県高岡市戸出六十歩');
ok($zip->set_number('9391125')->is_valid_number, '富山県高岡市戸出岡御所');
ok($zip->set_number('9391131')->is_valid_number, '富山県高岡市醍醐');
ok($zip->set_number('9391132')->is_valid_number, '富山県高岡市戸出竹');
ok($zip->set_number('9391133')->is_valid_number, '富山県高岡市戸出放寺');
ok($zip->set_number('9391134')->is_valid_number, '富山県高岡市戸出放寺新');
ok($zip->set_number('9391135')->is_valid_number, '富山県高岡市戸出竹北');
ok($zip->set_number('9391136')->is_valid_number, '富山県高岡市戸出延島');
ok($zip->set_number('9391251')->is_valid_number, '富山県高岡市常国');
ok($zip->set_number('9391252')->is_valid_number, '富山県高岡市常国みどり台');
ok($zip->set_number('9391253')->is_valid_number, '富山県高岡市若杉');
ok($zip->set_number('9391254')->is_valid_number, '富山県高岡市滝新');
ok($zip->set_number('9391255')->is_valid_number, '富山県高岡市滝');
ok($zip->set_number('9391261')->is_valid_number, '富山県高岡市小泉新');
ok($zip->set_number('9391262')->is_valid_number, '富山県高岡市山下');
ok($zip->set_number('9391263')->is_valid_number, '富山県高岡市御坊山');
ok($zip->set_number('9391263')->is_valid_number, '富山県高岡市島新');
ok($zip->set_number('9391264')->is_valid_number, '富山県高岡市下山田');
ok($zip->set_number('9391265')->is_valid_number, '富山県高岡市東保新');
ok($zip->set_number('9391266')->is_valid_number, '富山県高岡市今泉新');
ok($zip->set_number('9391267')->is_valid_number, '富山県高岡市今泉');
ok($zip->set_number('9391271')->is_valid_number, '富山県高岡市下麻生伸町');
ok($zip->set_number('9391272')->is_valid_number, '富山県高岡市下麻生');
ok($zip->set_number('9391273')->is_valid_number, '富山県高岡市葦附');
ok($zip->set_number('9391274')->is_valid_number, '富山県高岡市上麻生');
ok($zip->set_number('9391275')->is_valid_number, '富山県高岡市中田');
ok($zip->set_number('9391300')->is_valid_number, '富山県砺波市以下に掲載がない場合');
ok($zip->set_number('9391301')->is_valid_number, '富山県砺波市石丸');
ok($zip->set_number('9391302')->is_valid_number, '富山県砺波市東石丸');
ok($zip->set_number('9391303')->is_valid_number, '富山県砺波市大窪');
ok($zip->set_number('9391304')->is_valid_number, '富山県砺波市秋元');
ok($zip->set_number('9391305')->is_valid_number, '富山県砺波市千保');
ok($zip->set_number('9391306')->is_valid_number, '富山県砺波市宮村');
ok($zip->set_number('9391307')->is_valid_number, '富山県砺波市堀内');
ok($zip->set_number('9391308')->is_valid_number, '富山県砺波市三郎丸');
ok($zip->set_number('9391311')->is_valid_number, '富山県砺波市下中条');
ok($zip->set_number('9391312')->is_valid_number, '富山県砺波市東開発');
ok($zip->set_number('9391313')->is_valid_number, '富山県砺波市柳瀬');
ok($zip->set_number('9391314')->is_valid_number, '富山県砺波市久泉');
ok($zip->set_number('9391315')->is_valid_number, '富山県砺波市太田');
ok($zip->set_number('9391316')->is_valid_number, '富山県砺波市大門');
ok($zip->set_number('9391317')->is_valid_number, '富山県砺波市矢木');
ok($zip->set_number('9391318')->is_valid_number, '富山県砺波市祖泉');
ok($zip->set_number('9391321')->is_valid_number, '富山県砺波市新明');
ok($zip->set_number('9391322')->is_valid_number, '富山県砺波市中野');
ok($zip->set_number('9391323')->is_valid_number, '富山県砺波市上中野');
ok($zip->set_number('9391324')->is_valid_number, '富山県砺波市荒高屋');
ok($zip->set_number('9391325')->is_valid_number, '富山県砺波市花島');
ok($zip->set_number('9391326')->is_valid_number, '富山県砺波市鹿島');
ok($zip->set_number('9391327')->is_valid_number, '富山県砺波市五郎丸');
ok($zip->set_number('9391328')->is_valid_number, '富山県砺波市大辻');
ok($zip->set_number('9391331')->is_valid_number, '富山県砺波市深江');
ok($zip->set_number('9391332')->is_valid_number, '富山県砺波市永福町');
ok($zip->set_number('9391333')->is_valid_number, '富山県砺波市苗加');
ok($zip->set_number('9391334')->is_valid_number, '富山県砺波市野村島');
ok($zip->set_number('9391335')->is_valid_number, '富山県砺波市鷹栖');
ok($zip->set_number('9391336')->is_valid_number, '富山県砺波市西中');
ok($zip->set_number('9391337')->is_valid_number, '富山県砺波市神島');
ok($zip->set_number('9391338')->is_valid_number, '富山県砺波市鷹栖出');
ok($zip->set_number('9391341')->is_valid_number, '富山県砺波市高波');
ok($zip->set_number('9391342')->is_valid_number, '富山県砺波市小島');
ok($zip->set_number('9391343')->is_valid_number, '富山県砺波市新富町');
ok($zip->set_number('9391344')->is_valid_number, '富山県砺波市中神');
ok($zip->set_number('9391345')->is_valid_number, '富山県砺波市林');
ok($zip->set_number('9391346')->is_valid_number, '富山県砺波市狐島');
ok($zip->set_number('9391347')->is_valid_number, '富山県砺波市下中');
ok($zip->set_number('9391348')->is_valid_number, '富山県砺波市東中');
ok($zip->set_number('9391351')->is_valid_number, '富山県砺波市千代');
ok($zip->set_number('9391352')->is_valid_number, '富山県砺波市宮丸');
ok($zip->set_number('9391353')->is_valid_number, '富山県砺波市十年明');
ok($zip->set_number('9391354')->is_valid_number, '富山県砺波市新栄町');
ok($zip->set_number('9391355')->is_valid_number, '富山県砺波市杉木');
ok($zip->set_number('9391356')->is_valid_number, '富山県砺波市若草町');
ok($zip->set_number('9391357')->is_valid_number, '富山県砺波市小杉');
ok($zip->set_number('9391358')->is_valid_number, '富山県砺波市木下');
ok($zip->set_number('9391361')->is_valid_number, '富山県砺波市平成町');
ok($zip->set_number('9391362')->is_valid_number, '富山県砺波市鍋島');
ok($zip->set_number('9391363')->is_valid_number, '富山県砺波市太郎丸');
ok($zip->set_number('9391364')->is_valid_number, '富山県砺波市豊町');
ok($zip->set_number('9391365')->is_valid_number, '富山県砺波市三島町');
ok($zip->set_number('9391366')->is_valid_number, '富山県砺波市表町');
ok($zip->set_number('9391367')->is_valid_number, '富山県砺波市広上町');
ok($zip->set_number('9391368')->is_valid_number, '富山県砺波市本町');
ok($zip->set_number('9391371')->is_valid_number, '富山県砺波市栄町');
ok($zip->set_number('9391372')->is_valid_number, '富山県砺波市新又');
ok($zip->set_number('9391373')->is_valid_number, '富山県砺波市一番町');
ok($zip->set_number('9391374')->is_valid_number, '富山県砺波市山王町');
ok($zip->set_number('9391375')->is_valid_number, '富山県砺波市中央町');
ok($zip->set_number('9391376')->is_valid_number, '富山県砺波市平和町');
ok($zip->set_number('9391377')->is_valid_number, '富山県砺波市寿町');
ok($zip->set_number('9391378')->is_valid_number, '富山県砺波市春日町');
ok($zip->set_number('9391379')->is_valid_number, '富山県砺波市出町中央');
ok($zip->set_number('9391381')->is_valid_number, '富山県砺波市中村');
ok($zip->set_number('9391382')->is_valid_number, '富山県砺波市花園町');
ok($zip->set_number('9391383')->is_valid_number, '富山県砺波市高道');
ok($zip->set_number('9391384')->is_valid_number, '富山県砺波市坪内');
ok($zip->set_number('9391385')->is_valid_number, '富山県砺波市東幸町');
ok($zip->set_number('9391386')->is_valid_number, '富山県砺波市幸町');
ok($zip->set_number('9391387')->is_valid_number, '富山県砺波市となみ町');
ok($zip->set_number('9391388')->is_valid_number, '富山県砺波市宮沢町');
ok($zip->set_number('9391401')->is_valid_number, '富山県砺波市東保');
ok($zip->set_number('9391401')->is_valid_number, '富山県砺波市本小林');
ok($zip->set_number('9391402')->is_valid_number, '富山県砺波市増山');
ok($zip->set_number('9391403')->is_valid_number, '富山県砺波市宮新');
ok($zip->set_number('9391404')->is_valid_number, '富山県砺波市宮森新');
ok($zip->set_number('9391405')->is_valid_number, '富山県砺波市福岡');
ok($zip->set_number('9391406')->is_valid_number, '富山県砺波市宮森');
ok($zip->set_number('9391407')->is_valid_number, '富山県砺波市権正寺');
ok($zip->set_number('9391408')->is_valid_number, '富山県砺波市八十歩');
ok($zip->set_number('9391411')->is_valid_number, '富山県砺波市上和田');
ok($zip->set_number('9391412')->is_valid_number, '富山県砺波市正権寺');
ok($zip->set_number('9391413')->is_valid_number, '富山県砺波市市谷');
ok($zip->set_number('9391414')->is_valid_number, '富山県砺波市坪野');
ok($zip->set_number('9391415')->is_valid_number, '富山県砺波市池原');
ok($zip->set_number('9391416')->is_valid_number, '富山県砺波市芹谷');
ok($zip->set_number('9391417')->is_valid_number, '富山県砺波市頼成新');
ok($zip->set_number('9391421')->is_valid_number, '富山県砺波市東別所新');
ok($zip->set_number('9391422')->is_valid_number, '富山県砺波市浅谷');
ok($zip->set_number('9391423')->is_valid_number, '富山県砺波市東別所');
ok($zip->set_number('9391424')->is_valid_number, '富山県砺波市栃上');
ok($zip->set_number('9391425')->is_valid_number, '富山県砺波市井栗谷');
ok($zip->set_number('9391426')->is_valid_number, '富山県砺波市川内');
ok($zip->set_number('9391427')->is_valid_number, '富山県砺波市伏木谷');
ok($zip->set_number('9391428')->is_valid_number, '富山県砺波市五谷');
ok($zip->set_number('9391429')->is_valid_number, '富山県砺波市寺尾');
ok($zip->set_number('9391431')->is_valid_number, '富山県砺波市頼成');
ok($zip->set_number('9391432')->is_valid_number, '富山県砺波市徳万');
ok($zip->set_number('9391433')->is_valid_number, '富山県砺波市徳万新');
ok($zip->set_number('9391434')->is_valid_number, '富山県砺波市三合');
ok($zip->set_number('9391435')->is_valid_number, '富山県砺波市三合新');
ok($zip->set_number('9391436')->is_valid_number, '富山県砺波市福山');
ok($zip->set_number('9391437')->is_valid_number, '富山県砺波市茶ノ木');
ok($zip->set_number('9391438')->is_valid_number, '富山県砺波市安川');
ok($zip->set_number('9391501')->is_valid_number, '富山県南砺市本江');
ok($zip->set_number('9391502')->is_valid_number, '富山県南砺市野尻');
ok($zip->set_number('9391503')->is_valid_number, '富山県南砺市岩武新');
ok($zip->set_number('9391504')->is_valid_number, '富山県南砺市川除新');
ok($zip->set_number('9391505')->is_valid_number, '富山県南砺市長源寺');
ok($zip->set_number('9391506')->is_valid_number, '富山県南砺市高儀');
ok($zip->set_number('9391507')->is_valid_number, '富山県南砺市二日町');
ok($zip->set_number('9391511')->is_valid_number, '富山県南砺市高堀');
ok($zip->set_number('9391512')->is_valid_number, '富山県南砺市上野');
ok($zip->set_number('9391513')->is_valid_number, '富山県南砺市野尻野');
ok($zip->set_number('9391514')->is_valid_number, '富山県南砺市年代');
ok($zip->set_number('9391515')->is_valid_number, '富山県南砺市福野軸屋');
ok($zip->set_number('9391516')->is_valid_number, '富山県南砺市焼野');
ok($zip->set_number('9391517')->is_valid_number, '富山県南砺市百町');
ok($zip->set_number('9391518')->is_valid_number, '富山県南砺市松原');
ok($zip->set_number('9391521')->is_valid_number, '富山県南砺市苗島');
ok($zip->set_number('9391522')->is_valid_number, '富山県南砺市野新');
ok($zip->set_number('9391523')->is_valid_number, '富山県南砺市野原');
ok($zip->set_number('9391524')->is_valid_number, '富山県南砺市雨潜');
ok($zip->set_number('9391525')->is_valid_number, '富山県南砺市三清西');
ok($zip->set_number('9391526')->is_valid_number, '富山県南砺市江田');
ok($zip->set_number('9391527')->is_valid_number, '富山県南砺市森清');
ok($zip->set_number('9391528')->is_valid_number, '富山県南砺市安清');
ok($zip->set_number('9391531')->is_valid_number, '富山県南砺市院林');
ok($zip->set_number('9391532')->is_valid_number, '富山県南砺市寺家');
ok($zip->set_number('9391533')->is_valid_number, '富山県南砺市八塚');
ok($zip->set_number('9391534')->is_valid_number, '富山県南砺市広安');
ok($zip->set_number('9391535')->is_valid_number, '富山県南砺市石田');
ok($zip->set_number('9391536')->is_valid_number, '富山県南砺市東石田');
ok($zip->set_number('9391537')->is_valid_number, '富山県南砺市田屋');
ok($zip->set_number('9391538')->is_valid_number, '富山県南砺市田尻');
ok($zip->set_number('9391541')->is_valid_number, '富山県南砺市晩田');
ok($zip->set_number('9391542')->is_valid_number, '富山県南砺市梅ケ島');
ok($zip->set_number('9391543')->is_valid_number, '富山県南砺市下吉江');
ok($zip->set_number('9391544')->is_valid_number, '富山県南砺市新邸');
ok($zip->set_number('9391545')->is_valid_number, '富山県南砺市布袋');
ok($zip->set_number('9391546')->is_valid_number, '富山県南砺市森');
ok($zip->set_number('9391547')->is_valid_number, '富山県南砺市三ツ屋');
ok($zip->set_number('9391548')->is_valid_number, '富山県南砺市桐木');
ok($zip->set_number('9391549')->is_valid_number, '富山県南砺市前田');
ok($zip->set_number('9391551')->is_valid_number, '富山県南砺市上津');
ok($zip->set_number('9391552')->is_valid_number, '富山県南砺市柴田屋');
ok($zip->set_number('9391553')->is_valid_number, '富山県南砺市上川崎');
ok($zip->set_number('9391554')->is_valid_number, '富山県南砺市安居');
ok($zip->set_number('9391555')->is_valid_number, '富山県南砺市七村滝寺');
ok($zip->set_number('9391561')->is_valid_number, '富山県南砺市福野');
ok($zip->set_number('9391562')->is_valid_number, '富山県南砺市福野(浦町)');
ok($zip->set_number('9391563')->is_valid_number, '富山県南砺市福野(辰巳町)');
ok($zip->set_number('9391564')->is_valid_number, '富山県南砺市福野(御蔵町)');
ok($zip->set_number('9391565')->is_valid_number, '富山県南砺市福野(新町)');
ok($zip->set_number('9391566')->is_valid_number, '富山県南砺市福野(田中町)');
ok($zip->set_number('9391567')->is_valid_number, '富山県南砺市福野(上町)');
ok($zip->set_number('9391568')->is_valid_number, '富山県南砺市福野(横町)');
ok($zip->set_number('9391571')->is_valid_number, '富山県南砺市松原新');
ok($zip->set_number('9391572')->is_valid_number, '富山県南砺市福野(駅前通り)');
ok($zip->set_number('9391573')->is_valid_number, '富山県南砺市福野(南町)');
ok($zip->set_number('9391574')->is_valid_number, '富山県南砺市福野(七ツ屋)');
ok($zip->set_number('9391575')->is_valid_number, '富山県南砺市上三日市');
ok($zip->set_number('9391576')->is_valid_number, '富山県南砺市やかた');
ok($zip->set_number('9391577')->is_valid_number, '富山県南砺市寺家新屋敷');
ok($zip->set_number('9391600')->is_valid_number, '富山県南砺市以下に掲載がない場合');
ok($zip->set_number('9391601')->is_valid_number, '富山県南砺市人母');
ok($zip->set_number('9391602')->is_valid_number, '富山県南砺市高窪');
ok($zip->set_number('9391603')->is_valid_number, '富山県南砺市砂子谷');
ok($zip->set_number('9391604')->is_valid_number, '富山県南砺市土山');
ok($zip->set_number('9391605')->is_valid_number, '富山県南砺市小又');
ok($zip->set_number('9391606')->is_valid_number, '富山県南砺市能美');
ok($zip->set_number('9391610')->is_valid_number, '富山県南砺市福光');
ok($zip->set_number('9391611')->is_valid_number, '富山県南砺市岩安');
ok($zip->set_number('9391612')->is_valid_number, '富山県南砺市岩木');
ok($zip->set_number('9391613')->is_valid_number, '富山県南砺市川西');
ok($zip->set_number('9391614')->is_valid_number, '富山県南砺市蔵原');
ok($zip->set_number('9391615')->is_valid_number, '富山県南砺市湯谷');
ok($zip->set_number('9391621')->is_valid_number, '富山県南砺市和泉');
ok($zip->set_number('9391622')->is_valid_number, '富山県南砺市遊部川原');
ok($zip->set_number('9391623')->is_valid_number, '富山県南砺市松木');
ok($zip->set_number('9391624')->is_valid_number, '富山県南砺市八幡');
ok($zip->set_number('9391625')->is_valid_number, '富山県南砺市中ノ江');
ok($zip->set_number('9391626')->is_valid_number, '富山県南砺市法林寺');
ok($zip->set_number('9391631')->is_valid_number, '富山県南砺市福光(旭町)');
ok($zip->set_number('9391632')->is_valid_number, '富山県南砺市福光(観音町)');
ok($zip->set_number('9391633')->is_valid_number, '富山県南砺市福光(東町)');
ok($zip->set_number('9391634')->is_valid_number, '富山県南砺市福光(寺町)');
ok($zip->set_number('9391635')->is_valid_number, '富山県南砺市福光(中央通り)');
ok($zip->set_number('9391636')->is_valid_number, '富山県南砺市福光(神田町)');
ok($zip->set_number('9391637')->is_valid_number, '富山県南砺市福光(西町)');
ok($zip->set_number('9391641')->is_valid_number, '富山県南砺市福光(川原町)');
ok($zip->set_number('9391642')->is_valid_number, '富山県南砺市福光(味噌屋町)');
ok($zip->set_number('9391643')->is_valid_number, '富山県南砺市福光(本町)');
ok($zip->set_number('9391644')->is_valid_number, '富山県南砺市福光(五宝町)');
ok($zip->set_number('9391645')->is_valid_number, '富山県南砺市福光(中荒町)');
ok($zip->set_number('9391646')->is_valid_number, '富山県南砺市福光(荒町)');
ok($zip->set_number('9391651')->is_valid_number, '富山県南砺市福光(東新町)');
ok($zip->set_number('9391652')->is_valid_number, '富山県南砺市福光新町');
ok($zip->set_number('9391653')->is_valid_number, '富山県南砺市福光(宮脇町)');
ok($zip->set_number('9391654')->is_valid_number, '富山県南砺市福光(栄町)');
ok($zip->set_number('9391655')->is_valid_number, '富山県南砺市坂本');
ok($zip->set_number('9391661')->is_valid_number, '富山県南砺市天神');
ok($zip->set_number('9391662')->is_valid_number, '富山県南砺市福光(天神町)');
ok($zip->set_number('9391664')->is_valid_number, '富山県南砺市竹内');
ok($zip->set_number('9391665')->is_valid_number, '富山県南砺市小山');
ok($zip->set_number('9391666')->is_valid_number, '富山県南砺市山本');
ok($zip->set_number('9391667')->is_valid_number, '富山県南砺市開発');
ok($zip->set_number('9391671')->is_valid_number, '富山県南砺市小坂');
ok($zip->set_number('9391672')->is_valid_number, '富山県南砺市広谷');
ok($zip->set_number('9391673')->is_valid_number, '富山県南砺市糸谷新');
ok($zip->set_number('9391674')->is_valid_number, '富山県南砺市香城寺');
ok($zip->set_number('9391675')->is_valid_number, '富山県南砺市祖谷');
ok($zip->set_number('9391676')->is_valid_number, '富山県南砺市舘');
ok($zip->set_number('9391681')->is_valid_number, '富山県南砺市才川七');
ok($zip->set_number('9391682')->is_valid_number, '富山県南砺市小二又');
ok($zip->set_number('9391684')->is_valid_number, '富山県南砺市小院瀬見');
ok($zip->set_number('9391701')->is_valid_number, '富山県南砺市遊部');
ok($zip->set_number('9391702')->is_valid_number, '富山県南砺市吉江中');
ok($zip->set_number('9391703')->is_valid_number, '富山県南砺市一日市');
ok($zip->set_number('9391704')->is_valid_number, '富山県南砺市田中');
ok($zip->set_number('9391711')->is_valid_number, '富山県南砺市在房');
ok($zip->set_number('9391712')->is_valid_number, '富山県南砺市久戸');
ok($zip->set_number('9391713')->is_valid_number, '富山県南砺市神成');
ok($zip->set_number('9391714')->is_valid_number, '富山県南砺市高畠');
ok($zip->set_number('9391715')->is_valid_number, '富山県南砺市宗守');
ok($zip->set_number('9391716')->is_valid_number, '富山県南砺市荒見崎');
ok($zip->set_number('9391716')->is_valid_number, '富山県南砺市梅原');
ok($zip->set_number('9391721')->is_valid_number, '富山県南砺市東殿');
ok($zip->set_number('9391722')->is_valid_number, '富山県南砺市徳成');
ok($zip->set_number('9391723')->is_valid_number, '富山県南砺市利波河');
ok($zip->set_number('9391724')->is_valid_number, '富山県南砺市梅野');
ok($zip->set_number('9391725')->is_valid_number, '富山県南砺市鍛治');
ok($zip->set_number('9391732')->is_valid_number, '富山県南砺市荒木');
ok($zip->set_number('9391733')->is_valid_number, '富山県南砺市下野');
ok($zip->set_number('9391734')->is_valid_number, '富山県南砺市竹林');
ok($zip->set_number('9391735')->is_valid_number, '富山県南砺市小林');
ok($zip->set_number('9391735')->is_valid_number, '富山県南砺市神宮寺');
ok($zip->set_number('9391741')->is_valid_number, '富山県南砺市高宮');
ok($zip->set_number('9391742')->is_valid_number, '富山県南砺市吉江野');
ok($zip->set_number('9391743')->is_valid_number, '富山県南砺市大塚');
ok($zip->set_number('9391744')->is_valid_number, '富山県南砺市天池');
ok($zip->set_number('9391745')->is_valid_number, '富山県南砺市縄蔵');
ok($zip->set_number('9391746')->is_valid_number, '富山県南砺市出村');
ok($zip->set_number('9391747')->is_valid_number, '富山県南砺市山田');
ok($zip->set_number('9391751')->is_valid_number, '富山県南砺市赤坂');
ok($zip->set_number('9391752')->is_valid_number, '富山県南砺市大西');
ok($zip->set_number('9391754')->is_valid_number, '富山県南砺市嫁兼');
ok($zip->set_number('9391755')->is_valid_number, '富山県南砺市立野原西');
ok($zip->set_number('9391756')->is_valid_number, '富山県南砺市土生新');
ok($zip->set_number('9391757')->is_valid_number, '富山県南砺市土生');
ok($zip->set_number('9391758')->is_valid_number, '富山県南砺市殿');
ok($zip->set_number('9391761')->is_valid_number, '富山県南砺市太美');
ok($zip->set_number('9391762')->is_valid_number, '富山県南砺市七曲');
ok($zip->set_number('9391763')->is_valid_number, '富山県南砺市樋瀬戸');
ok($zip->set_number('9391764')->is_valid_number, '富山県南砺市吉見');
ok($zip->set_number('9391765')->is_valid_number, '富山県南砺市綱掛');
ok($zip->set_number('9391766')->is_valid_number, '富山県南砺市立野脇');
ok($zip->set_number('9391766')->is_valid_number, '富山県南砺市刀利');
ok($zip->set_number('9391801')->is_valid_number, '富山県南砺市北野(長楽寺)');
ok($zip->set_number('9391802')->is_valid_number, '富山県南砺市北野(次郎丸)');
ok($zip->set_number('9391803')->is_valid_number, '富山県南砺市東西原');
ok($zip->set_number('9391804')->is_valid_number, '富山県南砺市西明');
ok($zip->set_number('9391805')->is_valid_number, '富山県南砺市細野');
ok($zip->set_number('9391806')->is_valid_number, '富山県南砺市北野(吉松)');
ok($zip->set_number('9391807')->is_valid_number, '富山県南砺市北野');
ok($zip->set_number('9391811')->is_valid_number, '富山県南砺市理休');
ok($zip->set_number('9391812')->is_valid_number, '富山県南砺市蓑谷');
ok($zip->set_number('9391813')->is_valid_number, '富山県南砺市正谷');
ok($zip->set_number('9391814')->is_valid_number, '富山県南砺市大宮野');
ok($zip->set_number('9391814')->is_valid_number, '富山県南砺市城端(大宮野)');
ok($zip->set_number('9391815')->is_valid_number, '富山県南砺市城端(東新田)');
ok($zip->set_number('9391816')->is_valid_number, '富山県南砺市城端(東上)');
ok($zip->set_number('9391817')->is_valid_number, '富山県南砺市城端(東下)');
ok($zip->set_number('9391818')->is_valid_number, '富山県南砺市城端(川島)');
ok($zip->set_number('9391821')->is_valid_number, '富山県南砺市泉沢');
ok($zip->set_number('9391822')->is_valid_number, '富山県南砺市林道');
ok($zip->set_number('9391823')->is_valid_number, '富山県南砺市打尾');
ok($zip->set_number('9391824')->is_valid_number, '富山県南砺市上田');
ok($zip->set_number('9391824')->is_valid_number, '富山県南砺市大鋸屋');
ok($zip->set_number('9391825')->is_valid_number, '富山県南砺市大鋸屋(大谷島)');
ok($zip->set_number('9391826')->is_valid_number, '富山県南砺市瀬戸');
ok($zip->set_number('9391827')->is_valid_number, '富山県南砺市盛新');
ok($zip->set_number('9391828')->is_valid_number, '富山県南砺市中尾');
ok($zip->set_number('9391831')->is_valid_number, '富山県南砺市千福');
ok($zip->set_number('9391831')->is_valid_number, '富山県南砺市千福新');
ok($zip->set_number('9391832')->is_valid_number, '富山県南砺市塔尾');
ok($zip->set_number('9391833')->is_valid_number, '富山県南砺市上見');
ok($zip->set_number('9391834')->is_valid_number, '富山県南砺市上原');
ok($zip->set_number('9391835')->is_valid_number, '富山県南砺市京塚');
ok($zip->set_number('9391835')->is_valid_number, '富山県南砺市立野原東');
ok($zip->set_number('9391835')->is_valid_number, '富山県南砺市南原');
ok($zip->set_number('9391836')->is_valid_number, '富山県南砺市雁巻島');
ok($zip->set_number('9391837')->is_valid_number, '富山県南砺市大宮野新');
ok($zip->set_number('9391837')->is_valid_number, '富山県南砺市西原');
ok($zip->set_number('9391841')->is_valid_number, '富山県南砺市細木');
ok($zip->set_number('9391842')->is_valid_number, '富山県南砺市野田');
ok($zip->set_number('9391843')->is_valid_number, '富山県南砺市金戸');
ok($zip->set_number('9391844')->is_valid_number, '富山県南砺市野口');
ok($zip->set_number('9391845')->is_valid_number, '富山県南砺市示野');
ok($zip->set_number('9391846')->is_valid_number, '富山県南砺市経塚野');
ok($zip->set_number('9391846')->is_valid_number, '富山県南砺市国広');
ok($zip->set_number('9391851')->is_valid_number, '富山県南砺市信末');
ok($zip->set_number('9391852')->is_valid_number, '富山県南砺市是安');
ok($zip->set_number('9391853')->is_valid_number, '富山県南砺市城端(出丸)');
ok($zip->set_number('9391854')->is_valid_number, '富山県南砺市城端(栄町)');
ok($zip->set_number('9391855')->is_valid_number, '富山県南砺市大窪');
ok($zip->set_number('9391856')->is_valid_number, '富山県南砺市是安(末広町)');
ok($zip->set_number('9391861')->is_valid_number, '富山県南砺市城端');
ok($zip->set_number('9391862')->is_valid_number, '富山県南砺市城端(西下)');
ok($zip->set_number('9391863')->is_valid_number, '富山県南砺市城端(西上)');
ok($zip->set_number('9391864')->is_valid_number, '富山県南砺市城端(大工町)');
ok($zip->set_number('9391865')->is_valid_number, '富山県南砺市城端(新町)');
ok($zip->set_number('9391866')->is_valid_number, '富山県南砺市城端(南町)');
ok($zip->set_number('9391867')->is_valid_number, '富山県南砺市城端(野下)');
ok($zip->set_number('9391868')->is_valid_number, '富山県南砺市城端(西新田)');
ok($zip->set_number('9391871')->is_valid_number, '富山県南砺市池尻');
ok($zip->set_number('9391872')->is_valid_number, '富山県南砺市久保');
ok($zip->set_number('9391873')->is_valid_number, '富山県南砺市池田');
ok($zip->set_number('9391874')->is_valid_number, '富山県南砺市蛇喰');
ok($zip->set_number('9391875')->is_valid_number, '富山県南砺市大野');
ok($zip->set_number('9391876')->is_valid_number, '富山県南砺市川上中');
ok($zip->set_number('9391877')->is_valid_number, '富山県南砺市井口');
ok($zip->set_number('9391878')->is_valid_number, '富山県南砺市上広安');
ok($zip->set_number('9391879')->is_valid_number, '富山県南砺市宮後');
ok($zip->set_number('9391901')->is_valid_number, '富山県南砺市祖山');
ok($zip->set_number('9391902')->is_valid_number, '富山県南砺市大崩島');
ok($zip->set_number('9391903')->is_valid_number, '富山県南砺市寿川');
ok($zip->set_number('9391904')->is_valid_number, '富山県南砺市入谷');
ok($zip->set_number('9391905')->is_valid_number, '富山県南砺市東中江');
ok($zip->set_number('9391906')->is_valid_number, '富山県南砺市高草嶺');
ok($zip->set_number('9391907')->is_valid_number, '富山県南砺市夏焼');
ok($zip->set_number('9391908')->is_valid_number, '富山県南砺市下出');
ok($zip->set_number('9391911')->is_valid_number, '富山県南砺市篭渡');
ok($zip->set_number('9391912')->is_valid_number, '富山県南砺市大島');
ok($zip->set_number('9391913')->is_valid_number, '富山県南砺市田向');
ok($zip->set_number('9391914')->is_valid_number, '富山県南砺市上梨');
ok($zip->set_number('9391915')->is_valid_number, '富山県南砺市相倉');
ok($zip->set_number('9391916')->is_valid_number, '富山県南砺市見座');
ok($zip->set_number('9391921')->is_valid_number, '富山県南砺市杉尾');
ok($zip->set_number('9391922')->is_valid_number, '富山県南砺市渡原');
ok($zip->set_number('9391923')->is_valid_number, '富山県南砺市下梨');
ok($zip->set_number('9391924')->is_valid_number, '富山県南砺市中畑');
ok($zip->set_number('9391925')->is_valid_number, '富山県南砺市来栖');
ok($zip->set_number('9391926')->is_valid_number, '富山県南砺市小来栖');
ok($zip->set_number('9391927')->is_valid_number, '富山県南砺市梨谷');
ok($zip->set_number('9391928')->is_valid_number, '富山県南砺市上松尾');
ok($zip->set_number('9391961')->is_valid_number, '富山県南砺市皆葎');
ok($zip->set_number('9391962')->is_valid_number, '富山県南砺市猪谷');
ok($zip->set_number('9391963')->is_valid_number, '富山県南砺市成出');
ok($zip->set_number('9391964')->is_valid_number, '富山県南砺市楮');
ok($zip->set_number('9391965')->is_valid_number, '富山県南砺市真木');
ok($zip->set_number('9391966')->is_valid_number, '富山県南砺市東赤尾');
ok($zip->set_number('9391967')->is_valid_number, '富山県南砺市小原');
ok($zip->set_number('9391968')->is_valid_number, '富山県南砺市上平細島');
ok($zip->set_number('9391969')->is_valid_number, '富山県南砺市桂');
ok($zip->set_number('9391971')->is_valid_number, '富山県南砺市小瀬');
ok($zip->set_number('9391972')->is_valid_number, '富山県南砺市葎島');
ok($zip->set_number('9391973')->is_valid_number, '富山県南砺市菅沼');
ok($zip->set_number('9391974')->is_valid_number, '富山県南砺市田下');
ok($zip->set_number('9391975')->is_valid_number, '富山県南砺市上中田');
ok($zip->set_number('9391976')->is_valid_number, '富山県南砺市新屋');
ok($zip->set_number('9391977')->is_valid_number, '富山県南砺市西赤尾町');
ok($zip->set_number('9391978')->is_valid_number, '富山県南砺市下島');
ok($zip->set_number('9391979')->is_valid_number, '富山県南砺市漆谷');
ok($zip->set_number('9392161')->is_valid_number, '富山県富山市芦生');
ok($zip->set_number('9392162')->is_valid_number, '富山県富山市今生津');
ok($zip->set_number('9392163')->is_valid_number, '富山県富山市布尻');
ok($zip->set_number('9392164')->is_valid_number, '富山県富山市町長');
ok($zip->set_number('9392165')->is_valid_number, '富山県富山市寺津');
ok($zip->set_number('9392171')->is_valid_number, '富山県富山市薄波');
ok($zip->set_number('9392171')->is_valid_number, '富山県富山市太田薄波');
ok($zip->set_number('9392172')->is_valid_number, '富山県富山市吉野');
ok($zip->set_number('9392173')->is_valid_number, '富山県富山市伏木');
ok($zip->set_number('9392174')->is_valid_number, '富山県富山市小糸');
ok($zip->set_number('9392175')->is_valid_number, '富山県富山市東猪谷');
ok($zip->set_number('9392176')->is_valid_number, '富山県富山市舟渡');
ok($zip->set_number('9392181')->is_valid_number, '富山県富山市西笹津');
ok($zip->set_number('9392182')->is_valid_number, '富山県富山市岩稲');
ok($zip->set_number('9392183')->is_valid_number, '富山県富山市割山');
ok($zip->set_number('9392184')->is_valid_number, '富山県富山市楡原');
ok($zip->set_number('9392185')->is_valid_number, '富山県富山市庵谷');
ok($zip->set_number('9392186')->is_valid_number, '富山県富山市片掛');
ok($zip->set_number('9392187')->is_valid_number, '富山県富山市猪谷');
ok($zip->set_number('9392188')->is_valid_number, '富山県富山市蟹寺');
ok($zip->set_number('9392189')->is_valid_number, '富山県富山市加賀沢');
ok($zip->set_number('9392201')->is_valid_number, '富山県富山市合田');
ok($zip->set_number('9392201')->is_valid_number, '富山県富山市新村');
ok($zip->set_number('9392202')->is_valid_number, '富山県富山市小黒');
ok($zip->set_number('9392203')->is_valid_number, '富山県富山市松野');
ok($zip->set_number('9392204')->is_valid_number, '富山県富山市万願寺');
ok($zip->set_number('9392205')->is_valid_number, '富山県富山市二松');
ok($zip->set_number('9392206')->is_valid_number, '富山県富山市坂本');
ok($zip->set_number('9392207')->is_valid_number, '富山県富山市大野');
ok($zip->set_number('9392208')->is_valid_number, '富山県富山市南野田');
ok($zip->set_number('9392209')->is_valid_number, '富山県富山市東大久保');
ok($zip->set_number('9392211')->is_valid_number, '富山県富山市市場');
ok($zip->set_number('9392212')->is_valid_number, '富山県富山市舟倉');
ok($zip->set_number('9392213')->is_valid_number, '富山県富山市牛ケ増');
ok($zip->set_number('9392214')->is_valid_number, '富山県富山市寺家');
ok($zip->set_number('9392215')->is_valid_number, '富山県富山市直坂');
ok($zip->set_number('9392216')->is_valid_number, '富山県富山市横樋');
ok($zip->set_number('9392221')->is_valid_number, '富山県富山市西大沢');
ok($zip->set_number('9392222')->is_valid_number, '富山県富山市笹津(押上)');
ok($zip->set_number('9392223')->is_valid_number, '富山県富山市笹津');
ok($zip->set_number('9392224')->is_valid_number, '富山県富山市春日');
ok($zip->set_number('9392225')->is_valid_number, '富山県富山市長走');
ok($zip->set_number('9392226')->is_valid_number, '富山県富山市下タ林');
ok($zip->set_number('9392231')->is_valid_number, '富山県富山市稲代');
ok($zip->set_number('9392231')->is_valid_number, '富山県富山市稲代(幸町)');
ok($zip->set_number('9392232')->is_valid_number, '富山県富山市小羽');
ok($zip->set_number('9392233')->is_valid_number, '富山県富山市長川原');
ok($zip->set_number('9392234')->is_valid_number, '富山県富山市須原');
ok($zip->set_number('9392235')->is_valid_number, '富山県富山市下伏');
ok($zip->set_number('9392236')->is_valid_number, '富山県富山市土');
ok($zip->set_number('9392237')->is_valid_number, '富山県富山市根上');
ok($zip->set_number('9392238')->is_valid_number, '富山県富山市葛原');
ok($zip->set_number('9392241')->is_valid_number, '富山県富山市神通');
ok($zip->set_number('9392242')->is_valid_number, '富山県富山市塩');
ok($zip->set_number('9392243')->is_valid_number, '富山県富山市中大久保');
ok($zip->set_number('9392244')->is_valid_number, '富山県富山市西塩野');
ok($zip->set_number('9392245')->is_valid_number, '富山県富山市加納');
ok($zip->set_number('9392246')->is_valid_number, '富山県富山市岩木');
ok($zip->set_number('9392247')->is_valid_number, '富山県富山市岩木新');
ok($zip->set_number('9392251')->is_valid_number, '富山県富山市大久保新町');
ok($zip->set_number('9392251')->is_valid_number, '富山県富山市下大久保');
ok($zip->set_number('9392251')->is_valid_number, '富山県富山市下大久保(若草町)');
ok($zip->set_number('9392251')->is_valid_number, '富山県富山市下大久保新町');
ok($zip->set_number('9392251')->is_valid_number, '富山県富山市下大久保東ケ丘');
ok($zip->set_number('9392251')->is_valid_number, '富山県富山市下大久保緑町');
ok($zip->set_number('9392252')->is_valid_number, '富山県富山市上大久保');
ok($zip->set_number('9392252')->is_valid_number, '富山県富山市上大久保泉町');
ok($zip->set_number('9392252')->is_valid_number, '富山県富山市上大久保北新町');
ok($zip->set_number('9392252')->is_valid_number, '富山県富山市上大久保栄町');
ok($zip->set_number('9392252')->is_valid_number, '富山県富山市上大久保東新町');
ok($zip->set_number('9392253')->is_valid_number, '富山県富山市八木山');
ok($zip->set_number('9392254')->is_valid_number, '富山県富山市高内');
ok($zip->set_number('9392255')->is_valid_number, '富山県富山市長附');
ok($zip->set_number('9392256')->is_valid_number, '富山県富山市上二杉');
ok($zip->set_number('9392257')->is_valid_number, '富山県富山市南花園町');
ok($zip->set_number('9392301')->is_valid_number, '富山県富山市八尾町寺家');
ok($zip->set_number('9392302')->is_valid_number, '富山県富山市八尾町杉田');
ok($zip->set_number('9392303')->is_valid_number, '富山県富山市八尾町大杉');
ok($zip->set_number('9392304')->is_valid_number, '富山県富山市八尾町黒田');
ok($zip->set_number('9392305')->is_valid_number, '富山県富山市八尾町井田新');
ok($zip->set_number('9392306')->is_valid_number, '富山県富山市八尾町井田');
ok($zip->set_number('9392311')->is_valid_number, '富山県富山市八尾町中神通');
ok($zip->set_number('9392311')->is_valid_number, '富山県富山市八尾町西神通');
ok($zip->set_number('9392312')->is_valid_number, '富山県富山市八尾町薄島');
ok($zip->set_number('9392313')->is_valid_number, '富山県富山市八尾町滅鬼');
ok($zip->set_number('9392314')->is_valid_number, '富山県富山市八尾町城生');
ok($zip->set_number('9392314')->is_valid_number, '富山県富山市八尾町野飼');
ok($zip->set_number('9392315')->is_valid_number, '富山県富山市八尾町井栗谷');
ok($zip->set_number('9392316')->is_valid_number, '富山県富山市八尾町深谷');
ok($zip->set_number('9392317')->is_valid_number, '富山県富山市八尾町丸山');
ok($zip->set_number('9392321')->is_valid_number, '富山県富山市八尾町小長谷');
ok($zip->set_number('9392322')->is_valid_number, '富山県富山市八尾町小長谷新');
ok($zip->set_number('9392323')->is_valid_number, '富山県富山市八尾町村杉');
ok($zip->set_number('9392324')->is_valid_number, '富山県富山市八尾町北谷');
ok($zip->set_number('9392324')->is_valid_number, '富山県富山市八尾町東坂下');
ok($zip->set_number('9392325')->is_valid_number, '富山県富山市八尾町外堀');
ok($zip->set_number('9392325')->is_valid_number, '富山県富山市八尾町宮腰');
ok($zip->set_number('9392326')->is_valid_number, '富山県富山市八尾町岩屋');
ok($zip->set_number('9392327')->is_valid_number, '富山県富山市八尾町樫尾');
ok($zip->set_number('9392331')->is_valid_number, '富山県富山市八尾町下笹原');
ok($zip->set_number('9392332')->is_valid_number, '富山県富山市八尾町掛畑');
ok($zip->set_number('9392332')->is_valid_number, '富山県富山市八尾町上黒瀬');
ok($zip->set_number('9392333')->is_valid_number, '富山県富山市八尾町桐谷');
ok($zip->set_number('9392333')->is_valid_number, '富山県富山市八尾町小井波');
ok($zip->set_number('9392333')->is_valid_number, '富山県富山市八尾町滝脇');
ok($zip->set_number('9392334')->is_valid_number, '富山県富山市八尾町上笹原');
ok($zip->set_number('9392335')->is_valid_number, '富山県富山市八尾町茗ケ原');
ok($zip->set_number('9392336')->is_valid_number, '富山県富山市八尾町角間');
ok($zip->set_number('9392337')->is_valid_number, '富山県富山市八尾町梅苑町');
ok($zip->set_number('9392341')->is_valid_number, '富山県富山市八尾町鏡町');
ok($zip->set_number('9392342')->is_valid_number, '富山県富山市八尾町上新町');
ok($zip->set_number('9392343')->is_valid_number, '富山県富山市八尾町諏訪町');
ok($zip->set_number('9392344')->is_valid_number, '富山県富山市八尾町東新町');
ok($zip->set_number('9392345')->is_valid_number, '富山県富山市八尾町西新町');
ok($zip->set_number('9392351')->is_valid_number, '富山県富山市八尾町天満町');
ok($zip->set_number('9392352')->is_valid_number, '富山県富山市八尾町下新町');
ok($zip->set_number('9392353')->is_valid_number, '富山県富山市八尾町今町');
ok($zip->set_number('9392354')->is_valid_number, '富山県富山市八尾町東町');
ok($zip->set_number('9392355')->is_valid_number, '富山県富山市八尾町西町');
ok($zip->set_number('9392361')->is_valid_number, '富山県富山市八尾町三田');
ok($zip->set_number('9392362')->is_valid_number, '富山県富山市八尾町奥田');
ok($zip->set_number('9392363')->is_valid_number, '富山県富山市八尾町新田');
ok($zip->set_number('9392364')->is_valid_number, '富山県富山市八尾町水谷');
ok($zip->set_number('9392365')->is_valid_number, '富山県富山市八尾町妙川寺');
ok($zip->set_number('9392366')->is_valid_number, '富山県富山市八尾町保内');
ok($zip->set_number('9392367')->is_valid_number, '富山県富山市八尾町平林');
ok($zip->set_number('9392367')->is_valid_number, '富山県富山市八尾町松原');
ok($zip->set_number('9392371')->is_valid_number, '富山県富山市八尾町田中');
ok($zip->set_number('9392371')->is_valid_number, '富山県富山市八尾町翠尾');
ok($zip->set_number('9392372')->is_valid_number, '富山県富山市八尾町舘本郷');
ok($zip->set_number('9392373')->is_valid_number, '富山県富山市八尾町高善寺');
ok($zip->set_number('9392374')->is_valid_number, '富山県富山市八尾町上高善寺');
ok($zip->set_number('9392375')->is_valid_number, '富山県富山市八尾町石戸');
ok($zip->set_number('9392376')->is_valid_number, '富山県富山市八尾町福島');
ok($zip->set_number('9392401')->is_valid_number, '富山県富山市八尾町油');
ok($zip->set_number('9392401')->is_valid_number, '富山県富山市八尾町西葛坂');
ok($zip->set_number('9392401')->is_valid_number, '富山県富山市八尾町東葛坂');
ok($zip->set_number('9392402')->is_valid_number, '富山県富山市八尾町上田池');
ok($zip->set_number('9392402')->is_valid_number, '富山県富山市八尾町下田池');
ok($zip->set_number('9392402')->is_valid_number, '富山県富山市八尾町八十島');
ok($zip->set_number('9392403')->is_valid_number, '富山県富山市八尾町道畑下中山');
ok($zip->set_number('9392403')->is_valid_number, '富山県富山市八尾町宮ノ下');
ok($zip->set_number('9392404')->is_valid_number, '富山県富山市八尾町上ケ島');
ok($zip->set_number('9392404')->is_valid_number, '富山県富山市八尾町水口');
ok($zip->set_number('9392405')->is_valid_number, '富山県富山市八尾町青根');
ok($zip->set_number('9392405')->is_valid_number, '富山県富山市八尾町岩島');
ok($zip->set_number('9392406')->is_valid_number, '富山県富山市八尾町高峯');
ok($zip->set_number('9392406')->is_valid_number, '富山県富山市八尾町乗嶺');
ok($zip->set_number('9392407')->is_valid_number, '富山県富山市八尾町下乗嶺');
ok($zip->set_number('9392407')->is_valid_number, '富山県富山市八尾町新名');
ok($zip->set_number('9392411')->is_valid_number, '富山県富山市八尾町東川倉');
ok($zip->set_number('9392412')->is_valid_number, '富山県富山市八尾町東布谷');
ok($zip->set_number('9392413')->is_valid_number, '富山県富山市八尾町赤石');
ok($zip->set_number('9392414')->is_valid_number, '富山県富山市八尾町東松瀬');
ok($zip->set_number('9392414')->is_valid_number, '富山県富山市八尾町猟師ケ原');
ok($zip->set_number('9392415')->is_valid_number, '富山県富山市八尾町桂原');
ok($zip->set_number('9392415')->is_valid_number, '富山県富山市八尾町西松瀬');
ok($zip->set_number('9392416')->is_valid_number, '富山県富山市八尾町谷折');
ok($zip->set_number('9392416')->is_valid_number, '富山県富山市八尾町布谷');
ok($zip->set_number('9392417')->is_valid_number, '富山県富山市八尾町川住');
ok($zip->set_number('9392417')->is_valid_number, '富山県富山市八尾町下牧');
ok($zip->set_number('9392417')->is_valid_number, '富山県富山市八尾町西川倉');
ok($zip->set_number('9392421')->is_valid_number, '富山県富山市八尾町田頭');
ok($zip->set_number('9392422')->is_valid_number, '富山県富山市八尾町西原');
ok($zip->set_number('9392423')->is_valid_number, '富山県富山市八尾町新屋');
ok($zip->set_number('9392424')->is_valid_number, '富山県富山市八尾町東原');
ok($zip->set_number('9392425')->is_valid_number, '富山県富山市八尾町庵谷');
ok($zip->set_number('9392426')->is_valid_number, '富山県富山市八尾町切詰');
ok($zip->set_number('9392431')->is_valid_number, '富山県富山市八尾町栗須');
ok($zip->set_number('9392431')->is_valid_number, '富山県富山市八尾町栃折');
ok($zip->set_number('9392432')->is_valid_number, '富山県富山市八尾町薄尾');
ok($zip->set_number('9392432')->is_valid_number, '富山県富山市八尾町中山');
ok($zip->set_number('9392433')->is_valid_number, '富山県富山市八尾町清水');
ok($zip->set_number('9392433')->is_valid_number, '富山県富山市八尾町花房');
ok($zip->set_number('9392434')->is_valid_number, '富山県富山市八尾町島地');
ok($zip->set_number('9392435')->is_valid_number, '富山県富山市八尾町上牧');
ok($zip->set_number('9392435')->is_valid_number, '富山県富山市八尾町下島');
ok($zip->set_number('9392436')->is_valid_number, '富山県富山市八尾町内名');
ok($zip->set_number('9392436')->is_valid_number, '富山県富山市八尾町中島');
ok($zip->set_number('9392437')->is_valid_number, '富山県富山市八尾町高野');
ok($zip->set_number('9392437')->is_valid_number, '富山県富山市八尾町水無');
ok($zip->set_number('9392441')->is_valid_number, '富山県富山市八尾町大下');
ok($zip->set_number('9392442')->is_valid_number, '富山県富山市八尾町下仁歩');
ok($zip->set_number('9392443')->is_valid_number, '富山県富山市八尾町中仁歩');
ok($zip->set_number('9392444')->is_valid_number, '富山県富山市八尾町上仁歩');
ok($zip->set_number('9392445')->is_valid_number, '富山県富山市八尾町入谷');
ok($zip->set_number('9392446')->is_valid_number, '富山県富山市八尾町草連坂');
ok($zip->set_number('9392447')->is_valid_number, '富山県富山市八尾町鼠谷');
ok($zip->set_number('9392451')->is_valid_number, '富山県富山市八尾町平沢');
ok($zip->set_number('9392452')->is_valid_number, '富山県富山市八尾町三ツ松');
ok($zip->set_number('9392453')->is_valid_number, '富山県富山市八尾町倉ケ谷');
ok($zip->set_number('9392454')->is_valid_number, '富山県富山市八尾町尾畑');
ok($zip->set_number('9392454')->is_valid_number, '富山県富山市八尾町武道原');
ok($zip->set_number('9392455')->is_valid_number, '富山県富山市八尾町大玉生');
ok($zip->set_number('9392456')->is_valid_number, '富山県富山市八尾町正間');
ok($zip->set_number('9392456')->is_valid_number, '富山県富山市八尾町茗ケ島');
ok($zip->set_number('9392461')->is_valid_number, '富山県富山市八尾町高熊');
ok($zip->set_number('9392462')->is_valid_number, '富山県富山市八尾町柴橋');
ok($zip->set_number('9392462')->is_valid_number, '富山県富山市八尾町高橋');
ok($zip->set_number('9392463')->is_valid_number, '富山県富山市八尾町中');
ok($zip->set_number('9392463')->is_valid_number, '富山県富山市八尾町谷内');
ok($zip->set_number('9392464')->is_valid_number, '富山県富山市八尾町竹ノ内');
ok($zip->set_number('9392464')->is_valid_number, '富山県富山市八尾町宮ケ島');
ok($zip->set_number('9392465')->is_valid_number, '富山県富山市八尾町尾久');
ok($zip->set_number('9392465')->is_valid_number, '富山県富山市八尾町窪');
ok($zip->set_number('9392466')->is_valid_number, '富山県富山市八尾町天池');
ok($zip->set_number('9392467')->is_valid_number, '富山県富山市八尾町追分');
ok($zip->set_number('9392467')->is_valid_number, '富山県富山市八尾町高瀬');
ok($zip->set_number('9392471')->is_valid_number, '富山県富山市八尾町坂ノ下');
ok($zip->set_number('9392471')->is_valid_number, '富山県富山市八尾町高尾');
ok($zip->set_number('9392472')->is_valid_number, '富山県富山市八尾町野須郷');
ok($zip->set_number('9392472')->is_valid_number, '富山県富山市八尾町和山');
ok($zip->set_number('9392473')->is_valid_number, '富山県富山市八尾町上ノ名');
ok($zip->set_number('9392473')->is_valid_number, '富山県富山市八尾町峯');
ok($zip->set_number('9392474')->is_valid_number, '富山県富山市八尾町下ノ名');
ok($zip->set_number('9392474')->is_valid_number, '富山県富山市八尾町須郷');
ok($zip->set_number('9392475')->is_valid_number, '富山県富山市八尾町足谷');
ok($zip->set_number('9392475')->is_valid_number, '富山県富山市八尾町柚木');
ok($zip->set_number('9392476')->is_valid_number, '富山県富山市八尾町細滝');
ok($zip->set_number('9392477')->is_valid_number, '富山県富山市八尾町上野');
ok($zip->set_number('9392501')->is_valid_number, '富山県南砺市利賀村栗当');
ok($zip->set_number('9392502')->is_valid_number, '富山県南砺市利賀村高沼');
ok($zip->set_number('9392503')->is_valid_number, '富山県南砺市利賀村草嶺');
ok($zip->set_number('9392504')->is_valid_number, '富山県南砺市利賀村押場');
ok($zip->set_number('9392505')->is_valid_number, '富山県南砺市利賀村北豆谷');
ok($zip->set_number('9392506')->is_valid_number, '富山県南砺市利賀村大豆谷');
ok($zip->set_number('9392507')->is_valid_number, '富山県南砺市利賀村');
ok($zip->set_number('9392508')->is_valid_number, '富山県南砺市利賀村岩渕');
ok($zip->set_number('9392509')->is_valid_number, '富山県南砺市利賀村北島');
ok($zip->set_number('9392511')->is_valid_number, '富山県南砺市利賀村百瀬川');
ok($zip->set_number('9392512')->is_valid_number, '富山県南砺市利賀村中村');
ok($zip->set_number('9392513')->is_valid_number, '富山県南砺市利賀村上百瀬');
ok($zip->set_number('9392514')->is_valid_number, '富山県南砺市利賀村上畠');
ok($zip->set_number('9392515')->is_valid_number, '富山県南砺市利賀村細島');
ok($zip->set_number('9392516')->is_valid_number, '富山県南砺市利賀村坂上');
ok($zip->set_number('9392517')->is_valid_number, '富山県南砺市利賀村阿別当');
ok($zip->set_number('9392518')->is_valid_number, '富山県南砺市利賀村大勘場');
ok($zip->set_number('9392519')->is_valid_number, '富山県南砺市利賀村水無');
ok($zip->set_number('9392601')->is_valid_number, '富山県富山市婦中町小長沢');
ok($zip->set_number('9392602')->is_valid_number, '富山県富山市婦中町下邑');
ok($zip->set_number('9392603')->is_valid_number, '富山県富山市婦中町羽根');
ok($zip->set_number('9392604')->is_valid_number, '富山県富山市婦中町小野島');
ok($zip->set_number('9392604')->is_valid_number, '富山県富山市婦中町富川');
ok($zip->set_number('9392605')->is_valid_number, '富山県富山市婦中町河原町');
ok($zip->set_number('9392606')->is_valid_number, '富山県富山市婦中町長沢');
ok($zip->set_number('9392606')->is_valid_number, '富山県富山市婦中町ひまわり台');
ok($zip->set_number('9392607')->is_valid_number, '富山県富山市婦中町新町');
ok($zip->set_number('9392611')->is_valid_number, '富山県富山市婦中町かたかご台');
ok($zip->set_number('9392611')->is_valid_number, '富山県富山市婦中町下吉川');
ok($zip->set_number('9392611')->is_valid_number, '富山県富山市婦中町高田');
ok($zip->set_number('9392612')->is_valid_number, '富山県富山市婦中町上吉川');
ok($zip->set_number('9392612')->is_valid_number, '富山県富山市婦中町上吉川ニュータウン');
ok($zip->set_number('9392613')->is_valid_number, '富山県富山市婦中町高日附');
ok($zip->set_number('9392614')->is_valid_number, '富山県富山市婦中町上井沢');
ok($zip->set_number('9392615')->is_valid_number, '富山県富山市婦中町熊野道');
ok($zip->set_number('9392616')->is_valid_number, '富山県富山市婦中町小倉');
ok($zip->set_number('9392617')->is_valid_number, '富山県富山市婦中町島田');
ok($zip->set_number('9392621')->is_valid_number, '富山県富山市婦中町富崎');
ok($zip->set_number('9392622')->is_valid_number, '富山県富山市婦中町沢田');
ok($zip->set_number('9392622')->is_valid_number, '富山県富山市婦中町千里');
ok($zip->set_number('9392622')->is_valid_number, '富山県富山市婦中町鉾木');
ok($zip->set_number('9392623')->is_valid_number, '富山県富山市婦中町蓮花寺');
ok($zip->set_number('9392624')->is_valid_number, '富山県富山市婦中町下瀬');
ok($zip->set_number('9392625')->is_valid_number, '富山県富山市婦中町上瀬');
ok($zip->set_number('9392625')->is_valid_number, '富山県富山市婦中町三瀬');
ok($zip->set_number('9392625')->is_valid_number, '富山県富山市婦中町高山');
ok($zip->set_number('9392626')->is_valid_number, '富山県富山市婦中町道島');
ok($zip->set_number('9392627')->is_valid_number, '富山県富山市婦中町上野');
ok($zip->set_number('9392627')->is_valid_number, '富山県富山市婦中町皆杓');
ok($zip->set_number('9392631')->is_valid_number, '富山県富山市婦中町高塚');
ok($zip->set_number('9392631')->is_valid_number, '富山県富山市婦中町宮ケ谷');
ok($zip->set_number('9392632')->is_valid_number, '富山県富山市婦中町外輪野');
ok($zip->set_number('9392632')->is_valid_number, '富山県富山市婦中町吉住');
ok($zip->set_number('9392633')->is_valid_number, '富山県富山市婦中町東谷');
ok($zip->set_number('9392634')->is_valid_number, '富山県富山市婦中町牛滑');
ok($zip->set_number('9392635')->is_valid_number, '富山県富山市婦中町大瀬谷');
ok($zip->set_number('9392636')->is_valid_number, '富山県富山市婦中町東山');
ok($zip->set_number('9392636')->is_valid_number, '富山県富山市婦中町葎原');
ok($zip->set_number('9392637')->is_valid_number, '富山県富山市婦中町鶚谷');
ok($zip->set_number('9392638')->is_valid_number, '富山県富山市婦中町細谷');
ok($zip->set_number('9392638')->is_valid_number, '富山県富山市婦中町吉谷');
ok($zip->set_number('9392639')->is_valid_number, '富山県富山市婦中町平等');
ok($zip->set_number('9392649')->is_valid_number, '富山県富山市婦中町余川(西余川)');
ok($zip->set_number('9392701')->is_valid_number, '富山県富山市婦中町西本郷');
ok($zip->set_number('9392702')->is_valid_number, '富山県富山市婦中町田島');
ok($zip->set_number('9392703')->is_valid_number, '富山県富山市婦中町希望ケ丘');
ok($zip->set_number('9392704')->is_valid_number, '富山県富山市婦中町羽根新');
ok($zip->set_number('9392705')->is_valid_number, '富山県富山市婦中町宮ケ島');
ok($zip->set_number('9392706')->is_valid_number, '富山県富山市婦中町速星');
ok($zip->set_number('9392707')->is_valid_number, '富山県富山市婦中町東本郷');
ok($zip->set_number('9392708')->is_valid_number, '富山県富山市婦中町島本郷');
ok($zip->set_number('9392709')->is_valid_number, '富山県富山市婦中町夢ケ丘');
ok($zip->set_number('9392711')->is_valid_number, '富山県富山市婦中町鵜坂');
ok($zip->set_number('9392712')->is_valid_number, '富山県富山市婦中町塚原');
ok($zip->set_number('9392713')->is_valid_number, '富山県富山市婦中町上轡田');
ok($zip->set_number('9392714')->is_valid_number, '富山県富山市婦中町増田');
ok($zip->set_number('9392715')->is_valid_number, '富山県富山市婦中町下坂倉');
ok($zip->set_number('9392716')->is_valid_number, '富山県富山市婦中町下轡田');
ok($zip->set_number('9392717')->is_valid_number, '富山県富山市婦中町上田島');
ok($zip->set_number('9392718')->is_valid_number, '富山県富山市婦中町分田');
ok($zip->set_number('9392719')->is_valid_number, '富山県富山市婦中町西ヶ丘');
ok($zip->set_number('9392721')->is_valid_number, '富山県富山市婦中町板倉');
ok($zip->set_number('9392721')->is_valid_number, '富山県富山市婦中町板倉新');
ok($zip->set_number('9392722')->is_valid_number, '富山県富山市婦中町添島');
ok($zip->set_number('9392723')->is_valid_number, '富山県富山市婦中町萩島');
ok($zip->set_number('9392724')->is_valid_number, '富山県富山市婦中町ねむの木');
ok($zip->set_number('9392725')->is_valid_number, '富山県富山市婦中町持田');
ok($zip->set_number('9392726')->is_valid_number, '富山県富山市婦中町蔵島');
ok($zip->set_number('9392727')->is_valid_number, '富山県富山市婦中町砂子田');
ok($zip->set_number('9392728')->is_valid_number, '富山県富山市婦中町蛍川');
ok($zip->set_number('9392729')->is_valid_number, '富山県富山市婦中町響の杜');
ok($zip->set_number('9392731')->is_valid_number, '富山県富山市婦中町青島');
ok($zip->set_number('9392732')->is_valid_number, '富山県富山市婦中町横野');
ok($zip->set_number('9392733')->is_valid_number, '富山県富山市婦中町成子');
ok($zip->set_number('9392734')->is_valid_number, '富山県富山市婦中町新屋');
ok($zip->set_number('9392735')->is_valid_number, '富山県富山市婦中町為成新');
ok($zip->set_number('9392736')->is_valid_number, '富山県富山市婦中町上新屋');
ok($zip->set_number('9392737')->is_valid_number, '富山県富山市婦中町十五丁');
ok($zip->set_number('9392738')->is_valid_number, '富山県富山市婦中町道喜島');
ok($zip->set_number('9392741')->is_valid_number, '富山県富山市婦中町中名');
ok($zip->set_number('9392742')->is_valid_number, '富山県富山市婦中町堀');
ok($zip->set_number('9392743')->is_valid_number, '富山県富山市婦中町清水島');
ok($zip->set_number('9392744')->is_valid_number, '富山県富山市婦中町地角');
ok($zip->set_number('9392745')->is_valid_number, '富山県富山市婦中町広田');
ok($zip->set_number('9392746')->is_valid_number, '富山県富山市婦中町浜子');
ok($zip->set_number('9392747')->is_valid_number, '富山県富山市婦中町中島');
ok($zip->set_number('9392748')->is_valid_number, '富山県富山市婦中町田屋');
ok($zip->set_number('9392748')->is_valid_number, '富山県富山市婦中町田屋新');
ok($zip->set_number('9392749')->is_valid_number, '富山県富山市婦中町余川(東余川)');
ok($zip->set_number('9392751')->is_valid_number, '富山県富山市婦中町安田');
ok($zip->set_number('9392752')->is_valid_number, '富山県富山市婦中町小泉');
ok($zip->set_number('9392753')->is_valid_number, '富山県富山市婦中町笹倉');
ok($zip->set_number('9392754')->is_valid_number, '富山県富山市婦中町麦島');
ok($zip->set_number('9392755')->is_valid_number, '富山県富山市婦中町袋');
ok($zip->set_number('9392756')->is_valid_number, '富山県富山市婦中町下井沢');
ok($zip->set_number('9392757')->is_valid_number, '富山県富山市婦中町道場');
ok($zip->set_number('9392758')->is_valid_number, '富山県富山市婦中町下条');
ok($zip->set_number('9392759')->is_valid_number, '富山県富山市婦中町友坂');
ok($zip->set_number('9393501')->is_valid_number, '富山県富山市水橋印田町');
ok($zip->set_number('9393502')->is_valid_number, '富山県富山市水橋川原町');
ok($zip->set_number('9393503')->is_valid_number, '富山県富山市水橋立山町');
ok($zip->set_number('9393504')->is_valid_number, '富山県富山市水橋今町');
ok($zip->set_number('9393505')->is_valid_number, '富山県富山市水橋浜町');
ok($zip->set_number('9393506')->is_valid_number, '富山県富山市水橋山王町');
ok($zip->set_number('9393511')->is_valid_number, '富山県富山市水橋中町');
ok($zip->set_number('9393512')->is_valid_number, '富山県富山市水橋大町(西部地区)');
ok($zip->set_number('9393512')->is_valid_number, '富山県富山市水橋西大町');
ok($zip->set_number('9393513')->is_valid_number, '富山県富山市水橋大正町');
ok($zip->set_number('9393514')->is_valid_number, '富山県富山市水橋新堂町');
ok($zip->set_number('9393515')->is_valid_number, '富山県富山市水橋辻ケ堂');
ok($zip->set_number('9393516')->is_valid_number, '富山県富山市水橋荒町');
ok($zip->set_number('9393521')->is_valid_number, '富山県富山市水橋畠等');
ok($zip->set_number('9393522')->is_valid_number, '富山県富山市水橋花の井町');
ok($zip->set_number('9393523')->is_valid_number, '富山県富山市水橋池田舘');
ok($zip->set_number('9393524')->is_valid_number, '富山県富山市水橋伊勢屋');
ok($zip->set_number('9393525')->is_valid_number, '富山県富山市水橋駅前');
ok($zip->set_number('9393526')->is_valid_number, '富山県富山市水橋昭和町');
ok($zip->set_number('9393531')->is_valid_number, '富山県富山市水橋池田町');
ok($zip->set_number('9393532')->is_valid_number, '富山県富山市水橋二ツ屋');
ok($zip->set_number('9393533')->is_valid_number, '富山県富山市水橋高堂');
ok($zip->set_number('9393534')->is_valid_number, '富山県富山市水橋金尾');
ok($zip->set_number('9393534')->is_valid_number, '富山県富山市水橋番頭名');
ok($zip->set_number('9393535')->is_valid_number, '富山県富山市水橋新堀');
ok($zip->set_number('9393536')->is_valid_number, '富山県富山市水橋金尾新');
ok($zip->set_number('9393541')->is_valid_number, '富山県富山市水橋沖');
ok($zip->set_number('9393542')->is_valid_number, '富山県富山市水橋開発');
ok($zip->set_number('9393543')->is_valid_number, '富山県富山市水橋常願寺');
ok($zip->set_number('9393544')->is_valid_number, '富山県富山市水橋入江');
ok($zip->set_number('9393545')->is_valid_number, '富山県富山市水橋入部町');
ok($zip->set_number('9393546')->is_valid_number, '富山県富山市水橋二杉');
ok($zip->set_number('9393547')->is_valid_number, '富山県富山市水橋柴草');
ok($zip->set_number('9393548')->is_valid_number, '富山県富山市三郷');
ok($zip->set_number('9393551')->is_valid_number, '富山県富山市水橋中村');
ok($zip->set_number('9393552')->is_valid_number, '富山県富山市水橋肘崎');
ok($zip->set_number('9393553')->is_valid_number, '富山県富山市水橋上的場');
ok($zip->set_number('9393553')->is_valid_number, '富山県富山市水橋的場');
ok($zip->set_number('9393554')->is_valid_number, '富山県富山市水橋小路');
ok($zip->set_number('9393555')->is_valid_number, '富山県富山市水橋市田袋');
ok($zip->set_number('9393556')->is_valid_number, '富山県富山市水橋中新町');
ok($zip->set_number('9393557')->is_valid_number, '富山県富山市水橋新保');
ok($zip->set_number('9393557')->is_valid_number, '富山県富山市水橋新保新町');
ok($zip->set_number('9393557')->is_valid_number, '富山県富山市水橋平榎');
ok($zip->set_number('9393557')->is_valid_number, '富山県富山市水橋町袋');
ok($zip->set_number('9398001')->is_valid_number, '富山県富山市大泉東部');
ok($zip->set_number('9398002')->is_valid_number, '富山県富山市公文名');
ok($zip->set_number('9398003')->is_valid_number, '富山県富山市西公文名町');
ok($zip->set_number('9398004')->is_valid_number, '富山県富山市西公文名');
ok($zip->set_number('9398005')->is_valid_number, '富山県富山市中市');
ok($zip->set_number('9398006')->is_valid_number, '富山県富山市山室');
ok($zip->set_number('9398007')->is_valid_number, '富山県富山市山室向陽台');
ok($zip->set_number('9398008')->is_valid_number, '富山県富山市山室新町');
ok($zip->set_number('9398011')->is_valid_number, '富山県富山市不二栄町');
ok($zip->set_number('9398012')->is_valid_number, '富山県富山市高原本町');
ok($zip->set_number('9398013')->is_valid_number, '富山県富山市高原町');
ok($zip->set_number('9398014')->is_valid_number, '富山県富山市中川原新町');
ok($zip->set_number('9398015')->is_valid_number, '富山県富山市中川原');
ok($zip->set_number('9398016')->is_valid_number, '富山県富山市中川原台');
ok($zip->set_number('9398017')->is_valid_number, '富山県富山市松ケ丘');
ok($zip->set_number('9398021')->is_valid_number, '富山県富山市若葉台');
ok($zip->set_number('9398022')->is_valid_number, '富山県富山市山室荒屋');
ok($zip->set_number('9398023')->is_valid_number, '富山県富山市古寺');
ok($zip->set_number('9398024')->is_valid_number, '富山県富山市古寺新町');
ok($zip->set_number('9398025')->is_valid_number, '富山県富山市大島');
ok($zip->set_number('9398026')->is_valid_number, '富山県富山市山室荒屋新町');
ok($zip->set_number('9398031')->is_valid_number, '富山県富山市東流杉');
ok($zip->set_number('9398032')->is_valid_number, '富山県富山市流杉');
ok($zip->set_number('9398033')->is_valid_number, '富山県富山市横内');
ok($zip->set_number('9398034')->is_valid_number, '富山県富山市新横内町');
ok($zip->set_number('9398035')->is_valid_number, '富山県富山市大宮町');
ok($zip->set_number('9398036')->is_valid_number, '富山県富山市高屋敷');
ok($zip->set_number('9398041')->is_valid_number, '富山県富山市太田中区');
ok($zip->set_number('9398042')->is_valid_number, '富山県富山市太田北区');
ok($zip->set_number('9398043')->is_valid_number, '富山県富山市太田向陽台');
ok($zip->set_number('9398044')->is_valid_number, '富山県富山市太田南町');
ok($zip->set_number('9398045')->is_valid_number, '富山県富山市本郷町');
ok($zip->set_number('9398046')->is_valid_number, '富山県富山市本郷新');
ok($zip->set_number('9398047')->is_valid_number, '富山県富山市清住町');
ok($zip->set_number('9398048')->is_valid_number, '富山県富山市太田');
ok($zip->set_number('9398049')->is_valid_number, '富山県富山市堀川本郷');
ok($zip->set_number('9398051')->is_valid_number, '富山県富山市大泉中部');
ok($zip->set_number('9398052')->is_valid_number, '富山県富山市大泉1区南部');
ok($zip->set_number('9398053')->is_valid_number, '富山県富山市堀川天山町');
ok($zip->set_number('9398054')->is_valid_number, '富山県富山市新堀町');
ok($zip->set_number('9398055')->is_valid_number, '富山県富山市下堀');
ok($zip->set_number('9398056')->is_valid_number, '富山県富山市上堀町');
ok($zip->set_number('9398057')->is_valid_number, '富山県富山市堀');
ok($zip->set_number('9398058')->is_valid_number, '富山県富山市大泉');
ok($zip->set_number('9398061')->is_valid_number, '富山県富山市上新保');
ok($zip->set_number('9398062')->is_valid_number, '富山県富山市上堀南町');
ok($zip->set_number('9398063')->is_valid_number, '富山県富山市小杉');
ok($zip->set_number('9398064')->is_valid_number, '富山県富山市赤田');
ok($zip->set_number('9398065')->is_valid_number, '富山県富山市赤田新町');
ok($zip->set_number('9398066')->is_valid_number, '富山県富山市朝菜町');
ok($zip->set_number('9398071')->is_valid_number, '富山県富山市上袋');
ok($zip->set_number('9398072')->is_valid_number, '富山県富山市堀川町');
ok($zip->set_number('9398073')->is_valid_number, '富山県富山市大町');
ok($zip->set_number('9398074')->is_valid_number, '富山県富山市大町南台');
ok($zip->set_number('9398075')->is_valid_number, '富山県富山市今泉');
ok($zip->set_number('9398076')->is_valid_number, '富山県富山市太郎丸');
ok($zip->set_number('9398077')->is_valid_number, '富山県富山市春日町');
ok($zip->set_number('9398081')->is_valid_number, '富山県富山市堀川小泉町');
ok($zip->set_number('9398082')->is_valid_number, '富山県富山市小泉町');
ok($zip->set_number('9398083')->is_valid_number, '富山県富山市西中野本町');
ok($zip->set_number('9398084')->is_valid_number, '富山県富山市西中野町');
ok($zip->set_number('9398085')->is_valid_number, '富山県富山市中野新町');
ok($zip->set_number('9398086')->is_valid_number, '富山県富山市東中野町');
ok($zip->set_number('9398087')->is_valid_number, '富山県富山市大泉町');
ok($zip->set_number('9398091')->is_valid_number, '富山県富山市旭町');
ok($zip->set_number('9398092')->is_valid_number, '富山県富山市雄山町');
ok($zip->set_number('9398093')->is_valid_number, '富山県富山市大泉東町');
ok($zip->set_number('9398094')->is_valid_number, '富山県富山市大泉本町');
ok($zip->set_number('9398095')->is_valid_number, '富山県富山市大泉中町');
ok($zip->set_number('9398096')->is_valid_number, '富山県富山市西大泉');
ok($zip->set_number('9398097')->is_valid_number, '富山県富山市大泉北町');
ok($zip->set_number('9398101')->is_valid_number, '富山県富山市西野新');
ok($zip->set_number('9398102')->is_valid_number, '富山県富山市昭和新町');
ok($zip->set_number('9398103')->is_valid_number, '富山県富山市大場');
ok($zip->set_number('9398104')->is_valid_number, '富山県富山市西番');
ok($zip->set_number('9398111')->is_valid_number, '富山県富山市城新町');
ok($zip->set_number('9398112')->is_valid_number, '富山県富山市城ケ丘');
ok($zip->set_number('9398113')->is_valid_number, '富山県富山市城若町');
ok($zip->set_number('9398114')->is_valid_number, '富山県富山市城村');
ok($zip->set_number('9398115')->is_valid_number, '富山県富山市城村新町');
ok($zip->set_number('9398121')->is_valid_number, '富山県富山市石屋');
ok($zip->set_number('9398122')->is_valid_number, '富山県富山市新名');
ok($zip->set_number('9398123')->is_valid_number, '富山県富山市関');
ok($zip->set_number('9398124')->is_valid_number, '富山県富山市八川');
ok($zip->set_number('9398131')->is_valid_number, '富山県富山市中屋');
ok($zip->set_number('9398132')->is_valid_number, '富山県富山市月岡町');
ok($zip->set_number('9398133')->is_valid_number, '富山県富山市月見が丘');
ok($zip->set_number('9398134')->is_valid_number, '富山県富山市上千俵町');
ok($zip->set_number('9398135')->is_valid_number, '富山県富山市千俵町');
ok($zip->set_number('9398136')->is_valid_number, '富山県富山市月見町');
ok($zip->set_number('9398137')->is_valid_number, '富山県富山市開発');
ok($zip->set_number('9398138')->is_valid_number, '富山県富山市上千俵');
ok($zip->set_number('9398139')->is_valid_number, '富山県富山市月岡新');
ok($zip->set_number('9398141')->is_valid_number, '富山県富山市月岡東緑町');
ok($zip->set_number('9398142')->is_valid_number, '富山県富山市月岡西緑町');
ok($zip->set_number('9398143')->is_valid_number, '富山県富山市上布目');
ok($zip->set_number('9398144')->is_valid_number, '富山県富山市上今町');
ok($zip->set_number('9398145')->is_valid_number, '富山県富山市大井');
ok($zip->set_number('9398146')->is_valid_number, '富山県富山市中布目');
ok($zip->set_number('9398151')->is_valid_number, '富山県富山市上栄');
ok($zip->set_number('9398152')->is_valid_number, '富山県富山市経力');
ok($zip->set_number('9398153')->is_valid_number, '富山県富山市吉岡');
ok($zip->set_number('9398154')->is_valid_number, '富山県富山市森田');
ok($zip->set_number('9398155')->is_valid_number, '富山県富山市江本');
ok($zip->set_number('9398156')->is_valid_number, '富山県富山市珠泉東町');
ok($zip->set_number('9398157')->is_valid_number, '富山県富山市珠泉西町');
ok($zip->set_number('9398161')->is_valid_number, '富山県富山市牧田');
ok($zip->set_number('9398162')->is_valid_number, '富山県富山市青柳');
ok($zip->set_number('9398163')->is_valid_number, '富山県富山市青柳新');
ok($zip->set_number('9398164')->is_valid_number, '富山県富山市林崎');
ok($zip->set_number('9398165')->is_valid_number, '富山県富山市杉瀬');
ok($zip->set_number('9398166')->is_valid_number, '富山県富山市上熊野');
ok($zip->set_number('9398171')->is_valid_number, '富山県富山市宮保');
ok($zip->set_number('9398172')->is_valid_number, '富山県富山市辰尾');
ok($zip->set_number('9398173')->is_valid_number, '富山県富山市辰尾新町');
ok($zip->set_number('9398174')->is_valid_number, '富山県富山市下栗山');
ok($zip->set_number('9398175')->is_valid_number, '富山県富山市上栗山');
ok($zip->set_number('9398176')->is_valid_number, '富山県富山市南栗山');
ok($zip->set_number('9398177')->is_valid_number, '富山県富山市安養寺');
ok($zip->set_number('9398178')->is_valid_number, '富山県富山市栗山');
ok($zip->set_number('9398181')->is_valid_number, '富山県富山市若竹町');
ok($zip->set_number('9398182')->is_valid_number, '富山県富山市悪王寺');
ok($zip->set_number('9398183')->is_valid_number, '富山県富山市小中');
ok($zip->set_number('9398184')->is_valid_number, '富山県富山市二俣新町');
ok($zip->set_number('9398185')->is_valid_number, '富山県富山市二俣');
ok($zip->set_number('9398191')->is_valid_number, '富山県富山市布市');
ok($zip->set_number('9398192')->is_valid_number, '富山県富山市布市新町');
ok($zip->set_number('9398193')->is_valid_number, '富山県富山市石田');
ok($zip->set_number('9398194')->is_valid_number, '富山県富山市南金屋');
ok($zip->set_number('9398195')->is_valid_number, '富山県富山市上野');
ok($zip->set_number('9398196')->is_valid_number, '富山県富山市上野南町');
ok($zip->set_number('9398197')->is_valid_number, '富山県富山市上野寿町');
ok($zip->set_number('9398201')->is_valid_number, '富山県富山市花園町');
ok($zip->set_number('9398202')->is_valid_number, '富山県富山市西田地方町');
ok($zip->set_number('9398203')->is_valid_number, '富山県富山市西田地方');
ok($zip->set_number('9398204')->is_valid_number, '富山県富山市根塚町');
ok($zip->set_number('9398205')->is_valid_number, '富山県富山市新根塚町');
ok($zip->set_number('9398206')->is_valid_number, '富山県富山市布瀬町');
ok($zip->set_number('9398207')->is_valid_number, '富山県富山市布瀬本町');
ok($zip->set_number('9398208')->is_valid_number, '富山県富山市布瀬町南');
ok($zip->set_number('9398211')->is_valid_number, '富山県富山市二口町');
ok($zip->set_number('9398212')->is_valid_number, '富山県富山市掛尾町');
ok($zip->set_number('9398213')->is_valid_number, '富山県富山市黒瀬');
ok($zip->set_number('9398214')->is_valid_number, '富山県富山市黒崎');
ok($zip->set_number('9398215')->is_valid_number, '富山県富山市掛尾栄町');
ok($zip->set_number('9398216')->is_valid_number, '富山県富山市黒瀬北町');
ok($zip->set_number('9398221')->is_valid_number, '富山県富山市八日町');
ok($zip->set_number('9398222')->is_valid_number, '富山県富山市蜷川');
ok($zip->set_number('9398223')->is_valid_number, '富山県富山市島田');
ok($zip->set_number('9398224')->is_valid_number, '富山県富山市友杉');
ok($zip->set_number('9398225')->is_valid_number, '富山県富山市上八日町');
ok($zip->set_number('9398231')->is_valid_number, '富山県富山市下熊野');
ok($zip->set_number('9398232')->is_valid_number, '富山県富山市南央町');
ok($zip->set_number('9398233')->is_valid_number, '富山県富山市任海');
ok($zip->set_number('9398234')->is_valid_number, '富山県富山市南中田');
ok($zip->set_number('9398241')->is_valid_number, '富山県富山市惣在寺');
ok($zip->set_number('9398242')->is_valid_number, '富山県富山市福居');
ok($zip->set_number('9398243')->is_valid_number, '富山県富山市押上');
ok($zip->set_number('9398244')->is_valid_number, '富山県富山市吉倉');
ok($zip->set_number('9398251')->is_valid_number, '富山県富山市西荒屋');
ok($zip->set_number('9398252')->is_valid_number, '富山県富山市秋ケ島');
ok($zip->set_number('9398253')->is_valid_number, '富山県富山市新保');
ok($zip->set_number('9398254')->is_valid_number, '富山県富山市別名');
ok($zip->set_number('9398261')->is_valid_number, '富山県富山市萩原');
ok($zip->set_number('9398262')->is_valid_number, '富山県富山市塚原');
ok($zip->set_number('9398263')->is_valid_number, '富山県富山市才覚寺');
ok($zip->set_number('9398264')->is_valid_number, '富山県富山市経田');
ok($zip->set_number('9398271')->is_valid_number, '富山県富山市太郎丸西町');
ok($zip->set_number('9398272')->is_valid_number, '富山県富山市太郎丸本町');
ok($zip->set_number('9398281')->is_valid_number, '富山県富山市今泉西部町');
ok($zip->set_number('9398282')->is_valid_number, '富山県富山市今泉北部町');
ok($zip->set_number('9400000')->is_valid_number, '新潟県長岡市以下に掲載がない場合');
ok($zip->set_number('9400001')->is_valid_number, '新潟県長岡市川辺町');
ok($zip->set_number('9400002')->is_valid_number, '新潟県長岡市十二潟町');
ok($zip->set_number('9400003')->is_valid_number, '新潟県長岡市高見');
ok($zip->set_number('9400004')->is_valid_number, '新潟県長岡市高見町');
ok($zip->set_number('9400006')->is_valid_number, '新潟県長岡市東高見');
ok($zip->set_number('9400007')->is_valid_number, '新潟県長岡市黒津町');
ok($zip->set_number('9400008')->is_valid_number, '新潟県長岡市天神町');
ok($zip->set_number('9400011')->is_valid_number, '新潟県長岡市下々条町');
ok($zip->set_number('9400012')->is_valid_number, '新潟県長岡市下々条');
ok($zip->set_number('9400013')->is_valid_number, '新潟県長岡市原町');
ok($zip->set_number('9400014')->is_valid_number, '新潟県長岡市北園町');
ok($zip->set_number('9400015')->is_valid_number, '新潟県長岡市寿');
ok($zip->set_number('9400016')->is_valid_number, '新潟県長岡市宝');
ok($zip->set_number('9400017')->is_valid_number, '新潟県長岡市中瀬');
ok($zip->set_number('9400021')->is_valid_number, '新潟県長岡市城岡');
ok($zip->set_number('9400022')->is_valid_number, '新潟県長岡市東新町');
ok($zip->set_number('9400023')->is_valid_number, '新潟県長岡市新町');
ok($zip->set_number('9400024')->is_valid_number, '新潟県長岡市西新町');
ok($zip->set_number('9400025')->is_valid_number, '新潟県長岡市泉');
ok($zip->set_number('9400026')->is_valid_number, '新潟県長岡市石内');
ok($zip->set_number('9400027')->is_valid_number, '新潟県長岡市西蔵王');
ok($zip->set_number('9400028')->is_valid_number, '新潟県長岡市蔵王');
ok($zip->set_number('9400029')->is_valid_number, '新潟県長岡市東蔵王');
ok($zip->set_number('9400031')->is_valid_number, '新潟県長岡市地蔵');
ok($zip->set_number('9400032')->is_valid_number, '新潟県長岡市干場');
ok($zip->set_number('9400033')->is_valid_number, '新潟県長岡市今朝白');
ok($zip->set_number('9400034')->is_valid_number, '新潟県長岡市福住');
ok($zip->set_number('9400035')->is_valid_number, '新潟県長岡市東神田');
ok($zip->set_number('9400036')->is_valid_number, '新潟県長岡市愛宕');
ok($zip->set_number('9400037')->is_valid_number, '新潟県長岡市東栄');
ok($zip->set_number('9400038')->is_valid_number, '新潟県長岡市琴平');
ok($zip->set_number('9400041')->is_valid_number, '新潟県長岡市学校町');
ok($zip->set_number('9400042')->is_valid_number, '新潟県長岡市前田');
ok($zip->set_number('9400043')->is_valid_number, '新潟県長岡市土合');
ok($zip->set_number('9400044')->is_valid_number, '新潟県長岡市住吉');
ok($zip->set_number('9400045')->is_valid_number, '新潟県長岡市金房');
ok($zip->set_number('9400046')->is_valid_number, '新潟県長岡市四郎丸');
ok($zip->set_number('9400047')->is_valid_number, '新潟県長岡市弓町');
ok($zip->set_number('9400048')->is_valid_number, '新潟県長岡市台町');
ok($zip->set_number('9400051')->is_valid_number, '新潟県長岡市西神田町');
ok($zip->set_number('9400052')->is_valid_number, '新潟県長岡市神田町');
ok($zip->set_number('9400053')->is_valid_number, '新潟県長岡市長町');
ok($zip->set_number('9400054')->is_valid_number, '新潟県長岡市稽古町');
ok($zip->set_number('9400055')->is_valid_number, '新潟県長岡市袋町');
ok($zip->set_number('9400056')->is_valid_number, '新潟県長岡市呉服町');
ok($zip->set_number('9400061')->is_valid_number, '新潟県長岡市城内町');
ok($zip->set_number('9400062')->is_valid_number, '新潟県長岡市大手通');
ok($zip->set_number('9400063')->is_valid_number, '新潟県長岡市旭町');
ok($zip->set_number('9400064')->is_valid_number, '新潟県長岡市殿町');
ok($zip->set_number('9400065')->is_valid_number, '新潟県長岡市坂之上町');
ok($zip->set_number('9400066')->is_valid_number, '新潟県長岡市東坂之上町');
ok($zip->set_number('9400067')->is_valid_number, '新潟県長岡市関東町');
ok($zip->set_number('9400071')->is_valid_number, '新潟県長岡市表町');
ok($zip->set_number('9400072')->is_valid_number, '新潟県長岡市柳原町');
ok($zip->set_number('9400073')->is_valid_number, '新潟県長岡市船江町');
ok($zip->set_number('9400074')->is_valid_number, '新潟県長岡市上田町');
ok($zip->set_number('9400075')->is_valid_number, '新潟県長岡市渡里町');
ok($zip->set_number('9400076')->is_valid_number, '新潟県長岡市本町');
ok($zip->set_number('9400081')->is_valid_number, '新潟県長岡市南町');
ok($zip->set_number('9400082')->is_valid_number, '新潟県長岡市千歳');
ok($zip->set_number('9400083')->is_valid_number, '新潟県長岡市宮原');
ok($zip->set_number('9400084')->is_valid_number, '新潟県長岡市幸町');
ok($zip->set_number('9400085')->is_valid_number, '新潟県長岡市草生津');
ok($zip->set_number('9400086')->is_valid_number, '新潟県長岡市西千手');
ok($zip->set_number('9400087')->is_valid_number, '新潟県長岡市千手');
ok($zip->set_number('9400088')->is_valid_number, '新潟県長岡市柏町');
ok($zip->set_number('9400091')->is_valid_number, '新潟県長岡市松葉');
ok($zip->set_number('9400092')->is_valid_number, '新潟県長岡市昭和');
ok($zip->set_number('9400093')->is_valid_number, '新潟県長岡市水道町');
ok($zip->set_number('9400094')->is_valid_number, '新潟県長岡市中島');
ok($zip->set_number('9400095')->is_valid_number, '新潟県長岡市日赤町');
ok($zip->set_number('9400096')->is_valid_number, '新潟県長岡市春日');
ok($zip->set_number('9400097')->is_valid_number, '新潟県長岡市山田');
ok($zip->set_number('9400098')->is_valid_number, '新潟県長岡市信濃');
ok($zip->set_number('9400101')->is_valid_number, '新潟県長岡市文納');
ok($zip->set_number('9400102')->is_valid_number, '新潟県長岡市人面');
ok($zip->set_number('9400103')->is_valid_number, '新潟県長岡市二ツ郷屋');
ok($zip->set_number('9400104')->is_valid_number, '新潟県長岡市山屋');
ok($zip->set_number('9400105')->is_valid_number, '新潟県長岡市明戸');
ok($zip->set_number('9400106')->is_valid_number, '新潟県長岡市水沢');
ok($zip->set_number('9400111')->is_valid_number, '新潟県長岡市下塩');
ok($zip->set_number('9400112')->is_valid_number, '新潟県長岡市二日町');
ok($zip->set_number('9400113')->is_valid_number, '新潟県長岡市熊袋');
ok($zip->set_number('9400114')->is_valid_number, '新潟県長岡市山口');
ok($zip->set_number('9400115')->is_valid_number, '新潟県長岡市下樫出');
ok($zip->set_number('9400116')->is_valid_number, '新潟県長岡市上樫出');
ok($zip->set_number('9400121')->is_valid_number, '新潟県長岡市九川');
ok($zip->set_number('9400122')->is_valid_number, '新潟県長岡市塩中');
ok($zip->set_number('9400123')->is_valid_number, '新潟県長岡市梅野俣');
ok($zip->set_number('9400124')->is_valid_number, '新潟県長岡市平中野俣');
ok($zip->set_number('9400125')->is_valid_number, '新潟県長岡市葎谷');
ok($zip->set_number('9400126')->is_valid_number, '新潟県長岡市山葵谷');
ok($zip->set_number('9400127')->is_valid_number, '新潟県長岡市滝之口');
ok($zip->set_number('9400128')->is_valid_number, '新潟県長岡市上塩');
ok($zip->set_number('9400129')->is_valid_number, '新潟県長岡市塩新町');
ok($zip->set_number('9400131')->is_valid_number, '新潟県長岡市吉水');
ok($zip->set_number('9400132')->is_valid_number, '新潟県長岡市栃尾原');
ok($zip->set_number('9400133')->is_valid_number, '新潟県長岡市巻渕');
ok($zip->set_number('9400134')->is_valid_number, '新潟県長岡市栃尾原町');
ok($zip->set_number('9400135')->is_valid_number, '新潟県長岡市金沢');
ok($zip->set_number('9400136')->is_valid_number, '新潟県長岡市東が丘');
ok($zip->set_number('9400137')->is_valid_number, '新潟県長岡市平');
ok($zip->set_number('9400141')->is_valid_number, '新潟県長岡市栃尾島田');
ok($zip->set_number('9400142')->is_valid_number, '新潟県長岡市本所');
ok($zip->set_number('9400143')->is_valid_number, '新潟県長岡市入塩川');
ok($zip->set_number('9400144')->is_valid_number, '新潟県長岡市菅畑');
ok($zip->set_number('9400145')->is_valid_number, '新潟県長岡市栃堀');
ok($zip->set_number('9400146')->is_valid_number, '新潟県長岡市小向');
ok($zip->set_number('9400147')->is_valid_number, '新潟県長岡市赤谷');
ok($zip->set_number('9400148')->is_valid_number, '新潟県長岡市大川戸');
ok($zip->set_number('9400149')->is_valid_number, '新潟県長岡市栃倉');
ok($zip->set_number('9400151')->is_valid_number, '新潟県長岡市吹谷');
ok($zip->set_number('9400152')->is_valid_number, '新潟県長岡市来伝');
ok($zip->set_number('9400153')->is_valid_number, '新潟県長岡市寒沢');
ok($zip->set_number('9400154')->is_valid_number, '新潟県長岡市松尾');
ok($zip->set_number('9400155')->is_valid_number, '新潟県長岡市栗山沢');
ok($zip->set_number('9400201')->is_valid_number, '新潟県長岡市鴉ケ島');
ok($zip->set_number('9400202')->is_valid_number, '新潟県長岡市栃尾岩野外新田');
ok($zip->set_number('9400203')->is_valid_number, '新潟県長岡市楡原');
ok($zip->set_number('9400204')->is_valid_number, '新潟県長岡市新栄町');
ok($zip->set_number('9400205')->is_valid_number, '新潟県長岡市栄町');
ok($zip->set_number('9400211')->is_valid_number, '新潟県長岡市小貫');
ok($zip->set_number('9400212')->is_valid_number, '新潟県長岡市土ケ谷');
ok($zip->set_number('9400213')->is_valid_number, '新潟県長岡市栃尾山田町');
ok($zip->set_number('9400214')->is_valid_number, '新潟県長岡市栃尾山田');
ok($zip->set_number('9400215')->is_valid_number, '新潟県長岡市栃尾町');
ok($zip->set_number('9400216')->is_valid_number, '新潟県長岡市栃尾新町');
ok($zip->set_number('9400217')->is_valid_number, '新潟県長岡市栃尾大町');
ok($zip->set_number('9400218')->is_valid_number, '新潟県長岡市栃尾表町');
ok($zip->set_number('9400221')->is_valid_number, '新潟県長岡市金町');
ok($zip->set_number('9400222')->is_valid_number, '新潟県長岡市中央公園');
ok($zip->set_number('9400223')->is_valid_number, '新潟県長岡市栃尾本町');
ok($zip->set_number('9400224')->is_valid_number, '新潟県長岡市東町');
ok($zip->set_number('9400225')->is_valid_number, '新潟県長岡市仲子町');
ok($zip->set_number('9400226')->is_valid_number, '新潟県長岡市滝の下町');
ok($zip->set_number('9400227')->is_valid_number, '新潟県長岡市谷内');
ok($zip->set_number('9400231')->is_valid_number, '新潟県長岡市栃尾旭町');
ok($zip->set_number('9400232')->is_valid_number, '新潟県長岡市天下島');
ok($zip->set_number('9400233')->is_valid_number, '新潟県長岡市栃尾宮沢');
ok($zip->set_number('9400234')->is_valid_number, '新潟県長岡市栃尾泉');
ok($zip->set_number('9400235')->is_valid_number, '新潟県長岡市栃尾大野');
ok($zip->set_number('9400236')->is_valid_number, '新潟県長岡市栃尾大野町');
ok($zip->set_number('9400237')->is_valid_number, '新潟県長岡市上の原町');
ok($zip->set_number('9400241')->is_valid_number, '新潟県長岡市北荷頃');
ok($zip->set_number('9400242')->is_valid_number, '新潟県長岡市一之貝');
ok($zip->set_number('9400243')->is_valid_number, '新潟県長岡市軽井沢');
ok($zip->set_number('9400244')->is_valid_number, '新潟県長岡市比礼');
ok($zip->set_number('9400245')->is_valid_number, '新潟県長岡市本津川');
ok($zip->set_number('9400251')->is_valid_number, '新潟県長岡市田之口');
ok($zip->set_number('9400252')->is_valid_number, '新潟県長岡市西野俣');
ok($zip->set_number('9400253')->is_valid_number, '新潟県長岡市中');
ok($zip->set_number('9400254')->is_valid_number, '新潟県長岡市木山沢');
ok($zip->set_number('9400255')->is_valid_number, '新潟県長岡市東中野俣');
ok($zip->set_number('9400256')->is_valid_number, '新潟県長岡市西中野俣');
ok($zip->set_number('9400257')->is_valid_number, '新潟県長岡市森上');
ok($zip->set_number('9400258')->is_valid_number, '新潟県長岡市半蔵金');
ok($zip->set_number('9400801')->is_valid_number, '新潟県長岡市亀崎町');
ok($zip->set_number('9400802')->is_valid_number, '新潟県長岡市桂町');
ok($zip->set_number('9400803')->is_valid_number, '新潟県長岡市加津保町');
ok($zip->set_number('9400804')->is_valid_number, '新潟県長岡市水穴町');
ok($zip->set_number('9400805')->is_valid_number, '新潟県長岡市浦瀬町');
ok($zip->set_number('9400806')->is_valid_number, '新潟県長岡市麻生田町');
ok($zip->set_number('9400811')->is_valid_number, '新潟県長岡市宮路町');
ok($zip->set_number('9400812')->is_valid_number, '新潟県長岡市乙吉町');
ok($zip->set_number('9400813')->is_valid_number, '新潟県長岡市川中');
ok($zip->set_number('9400814')->is_valid_number, '新潟県長岡市成願寺町');
ok($zip->set_number('9400816')->is_valid_number, '新潟県長岡市東片貝町');
ok($zip->set_number('9400817')->is_valid_number, '新潟県長岡市西片貝町');
ok($zip->set_number('9400819')->is_valid_number, '新潟県長岡市千代栄町');
ok($zip->set_number('9400821')->is_valid_number, '新潟県長岡市栖吉町');
ok($zip->set_number('9400822')->is_valid_number, '新潟県長岡市柿町');
ok($zip->set_number('9400824')->is_valid_number, '新潟県長岡市高町');
ok($zip->set_number('9400825')->is_valid_number, '新潟県長岡市高畑町');
ok($zip->set_number('9400826')->is_valid_number, '新潟県長岡市長倉町');
ok($zip->set_number('9400827')->is_valid_number, '新潟県長岡市悠久町');
ok($zip->set_number('9400828')->is_valid_number, '新潟県長岡市御山町');
ok($zip->set_number('9400829')->is_valid_number, '新潟県長岡市長倉');
ok($zip->set_number('9400831')->is_valid_number, '新潟県長岡市上条町');
ok($zip->set_number('9400832')->is_valid_number, '新潟県長岡市曙');
ok($zip->set_number('9400833')->is_valid_number, '新潟県長岡市笹崎');
ok($zip->set_number('9400834')->is_valid_number, '新潟県長岡市末広');
ok($zip->set_number('9400835')->is_valid_number, '新潟県長岡市錦');
ok($zip->set_number('9400836')->is_valid_number, '新潟県長岡市豊田町');
ok($zip->set_number('9400840')->is_valid_number, '新潟県長岡市旭岡');
ok($zip->set_number('9400841')->is_valid_number, '新潟県長岡市花園南');
ok($zip->set_number('9400842')->is_valid_number, '新潟県長岡市鉢伏町');
ok($zip->set_number('9400843')->is_valid_number, '新潟県長岡市東大町');
ok($zip->set_number('9400844')->is_valid_number, '新潟県長岡市大町');
ok($zip->set_number('9400845')->is_valid_number, '新潟県長岡市花園');
ok($zip->set_number('9400846')->is_valid_number, '新潟県長岡市花園東');
ok($zip->set_number('9400847')->is_valid_number, '新潟県長岡市土合町');
ok($zip->set_number('9400848')->is_valid_number, '新潟県長岡市長倉南町');
ok($zip->set_number('9400849')->is_valid_number, '新潟県長岡市長倉西町');
ok($zip->set_number('9400851')->is_valid_number, '新潟県長岡市若草町');
ok($zip->set_number('9400852')->is_valid_number, '新潟県長岡市中貫町');
ok($zip->set_number('9400853')->is_valid_number, '新潟県長岡市中沢');
ok($zip->set_number('9400854')->is_valid_number, '新潟県長岡市中沢町');
ok($zip->set_number('9400856')->is_valid_number, '新潟県長岡市美沢');
ok($zip->set_number('9400857')->is_valid_number, '新潟県長岡市沖田');
ok($zip->set_number('9400861')->is_valid_number, '新潟県長岡市川崎町');
ok($zip->set_number('9400864')->is_valid_number, '新潟県長岡市川崎');
ok($zip->set_number('9400865')->is_valid_number, '新潟県長岡市四郎丸町');
ok($zip->set_number('9400866')->is_valid_number, '新潟県長岡市美園');
ok($zip->set_number('9400867')->is_valid_number, '新潟県長岡市豊');
ok($zip->set_number('9400868')->is_valid_number, '新潟県長岡市堀金');
ok($zip->set_number('9400871')->is_valid_number, '新潟県長岡市北陽');
ok($zip->set_number('9400872')->is_valid_number, '新潟県長岡市稲葉町');
ok($zip->set_number('9400873')->is_valid_number, '新潟県長岡市永田町');
ok($zip->set_number('9400874')->is_valid_number, '新潟県長岡市永田');
ok($zip->set_number('9400875')->is_valid_number, '新潟県長岡市新保');
ok($zip->set_number('9400876')->is_valid_number, '新潟県長岡市新保町');
ok($zip->set_number('9400877')->is_valid_number, '新潟県長岡市稲保');
ok($zip->set_number('9400878')->is_valid_number, '新潟県長岡市稲保南');
ok($zip->set_number('9400881')->is_valid_number, '新潟県長岡市富島町');
ok($zip->set_number('9400882')->is_valid_number, '新潟県長岡市宮下町');
ok($zip->set_number('9400883')->is_valid_number, '新潟県長岡市小曽根町');
ok($zip->set_number('9400884')->is_valid_number, '新潟県長岡市亀貝町');
ok($zip->set_number('9400891')->is_valid_number, '新潟県長岡市四ツ屋町');
ok($zip->set_number('9400892')->is_valid_number, '新潟県長岡市百束町');
ok($zip->set_number('9400893')->is_valid_number, '新潟県長岡市福井町');
ok($zip->set_number('9400894')->is_valid_number, '新潟県長岡市七軒町');
ok($zip->set_number('9400895')->is_valid_number, '新潟県長岡市大黒町');
ok($zip->set_number('9400896')->is_valid_number, '新潟県長岡市福島町');
ok($zip->set_number('9400897')->is_valid_number, '新潟県長岡市新組町');
ok($zip->set_number('9400898')->is_valid_number, '新潟県長岡市新組南町');
ok($zip->set_number('9401101')->is_valid_number, '新潟県長岡市沢田');
ok($zip->set_number('9401102')->is_valid_number, '新潟県長岡市東宮内町');
ok($zip->set_number('9401103')->is_valid_number, '新潟県長岡市曲新町');
ok($zip->set_number('9401104')->is_valid_number, '新潟県長岡市摂田屋町');
ok($zip->set_number('9401105')->is_valid_number, '新潟県長岡市摂田屋');
ok($zip->set_number('9401106')->is_valid_number, '新潟県長岡市宮内');
ok($zip->set_number('9401111')->is_valid_number, '新潟県長岡市町田町');
ok($zip->set_number('9401112')->is_valid_number, '新潟県長岡市青木町');
ok($zip->set_number('9401113')->is_valid_number, '新潟県長岡市鷺巣町');
ok($zip->set_number('9401114')->is_valid_number, '新潟県長岡市釜沢町');
ok($zip->set_number('9401115')->is_valid_number, '新潟県長岡市村松町');
ok($zip->set_number('9401116')->is_valid_number, '新潟県長岡市竹町');
ok($zip->set_number('9401117')->is_valid_number, '新潟県長岡市横枕町');
ok($zip->set_number('9401121')->is_valid_number, '新潟県長岡市濁沢町');
ok($zip->set_number('9401122')->is_valid_number, '新潟県長岡市蓬平町');
ok($zip->set_number('9401123')->is_valid_number, '新潟県長岡市竹之高地町');
ok($zip->set_number('9401131')->is_valid_number, '新潟県長岡市十日町');
ok($zip->set_number('9401132')->is_valid_number, '新潟県長岡市渡沢町');
ok($zip->set_number('9401133')->is_valid_number, '新潟県長岡市六日市町');
ok($zip->set_number('9401134')->is_valid_number, '新潟県長岡市妙見町');
ok($zip->set_number('9401135')->is_valid_number, '新潟県長岡市中潟町');
ok($zip->set_number('9401136')->is_valid_number, '新潟県長岡市三俵野町');
ok($zip->set_number('9401137')->is_valid_number, '新潟県長岡市大川原町');
ok($zip->set_number('9401138')->is_valid_number, '新潟県長岡市滝谷町');
ok($zip->set_number('9401139')->is_valid_number, '新潟県長岡市高島町');
ok($zip->set_number('9401140')->is_valid_number, '新潟県長岡市上前島');
ok($zip->set_number('9401141')->is_valid_number, '新潟県長岡市定明町');
ok($zip->set_number('9401142')->is_valid_number, '新潟県長岡市豊詰町');
ok($zip->set_number('9401143')->is_valid_number, '新潟県長岡市片田町');
ok($zip->set_number('9401144')->is_valid_number, '新潟県長岡市上前島町');
ok($zip->set_number('9401145')->is_valid_number, '新潟県長岡市青島町');
ok($zip->set_number('9401146')->is_valid_number, '新潟県長岡市下条町');
ok($zip->set_number('9401147')->is_valid_number, '新潟県長岡市前島町');
ok($zip->set_number('9401148')->is_valid_number, '新潟県長岡市青山町');
ok($zip->set_number('9401149')->is_valid_number, '新潟県長岡市青山新町');
ok($zip->set_number('9401151')->is_valid_number, '新潟県長岡市三和');
ok($zip->set_number('9401152')->is_valid_number, '新潟県長岡市三和町');
ok($zip->set_number('9401153')->is_valid_number, '新潟県長岡市要町');
ok($zip->set_number('9401154')->is_valid_number, '新潟県長岡市宮栄');
ok($zip->set_number('9401155')->is_valid_number, '新潟県長岡市宮内町');
ok($zip->set_number('9401161')->is_valid_number, '新潟県長岡市左近');
ok($zip->set_number('9401161')->is_valid_number, '新潟県長岡市左近町');
ok($zip->set_number('9401162')->is_valid_number, '新潟県長岡市西宮内');
ok($zip->set_number('9401163')->is_valid_number, '新潟県長岡市平島');
ok($zip->set_number('9401163')->is_valid_number, '新潟県長岡市平島町');
ok($zip->set_number('9401164')->is_valid_number, '新潟県長岡市南陽');
ok($zip->set_number('9401165')->is_valid_number, '新潟県長岡市水梨町');
ok($zip->set_number('9401166')->is_valid_number, '新潟県長岡市今井');
ok($zip->set_number('9401167')->is_valid_number, '新潟県長岡市大宮町');
ok($zip->set_number('9401171')->is_valid_number, '新潟県長岡市岩野(仲島)');
ok($zip->set_number('9401172')->is_valid_number, '新潟県長岡市釜ケ島(土手畑・藤場)');
ok($zip->set_number('9402001')->is_valid_number, '新潟県長岡市槇下町');
ok($zip->set_number('9402002')->is_valid_number, '新潟県長岡市槇山町');
ok($zip->set_number('9402003')->is_valid_number, '新潟県長岡市渡場町');
ok($zip->set_number('9402004')->is_valid_number, '新潟県長岡市上野町');
ok($zip->set_number('9402005')->is_valid_number, '新潟県長岡市巻島');
ok($zip->set_number('9402011')->is_valid_number, '新潟県長岡市藤沢');
ok($zip->set_number('9402012')->is_valid_number, '新潟県長岡市荻野');
ok($zip->set_number('9402013')->is_valid_number, '新潟県長岡市下柳');
ok($zip->set_number('9402014')->is_valid_number, '新潟県長岡市堤町');
ok($zip->set_number('9402015')->is_valid_number, '新潟県長岡市江陽');
ok($zip->set_number('9402021')->is_valid_number, '新潟県長岡市宮関');
ok($zip->set_number('9402022')->is_valid_number, '新潟県長岡市鉄工町');
ok($zip->set_number('9402023')->is_valid_number, '新潟県長岡市蓮潟');
ok($zip->set_number('9402024')->is_valid_number, '新潟県長岡市堺町');
ok($zip->set_number('9402025')->is_valid_number, '新潟県長岡市高瀬町');
ok($zip->set_number('9402026')->is_valid_number, '新潟県長岡市堺東町');
ok($zip->set_number('9402031')->is_valid_number, '新潟県長岡市宝地町');
ok($zip->set_number('9402032')->is_valid_number, '新潟県長岡市石動町');
ok($zip->set_number('9402033')->is_valid_number, '新潟県長岡市上除町');
ok($zip->set_number('9402034')->is_valid_number, '新潟県長岡市上除町西');
ok($zip->set_number('9402035')->is_valid_number, '新潟県長岡市関原町');
ok($zip->set_number('9402036')->is_valid_number, '新潟県長岡市五反田町');
ok($zip->set_number('9402037')->is_valid_number, '新潟県長岡市関原西町');
ok($zip->set_number('9402038')->is_valid_number, '新潟県長岡市関原東町');
ok($zip->set_number('9402039')->is_valid_number, '新潟県長岡市関原南');
ok($zip->set_number('9402041')->is_valid_number, '新潟県長岡市白鳥町');
ok($zip->set_number('9402042')->is_valid_number, '新潟県長岡市宮本町');
ok($zip->set_number('9402043')->is_valid_number, '新潟県長岡市宮本東方町');
ok($zip->set_number('9402044')->is_valid_number, '新潟県長岡市宮本堀之内町');
ok($zip->set_number('9402045')->is_valid_number, '新潟県長岡市西陵町');
ok($zip->set_number('9402046')->is_valid_number, '新潟県長岡市雲出町');
ok($zip->set_number('9402051')->is_valid_number, '新潟県長岡市高野町');
ok($zip->set_number('9402052')->is_valid_number, '新潟県長岡市福戸町');
ok($zip->set_number('9402053')->is_valid_number, '新潟県長岡市福道町');
ok($zip->set_number('9402054')->is_valid_number, '新潟県長岡市南新保町');
ok($zip->set_number('9402055')->is_valid_number, '新潟県長岡市雨池町');
ok($zip->set_number('9402056')->is_valid_number, '新潟県長岡市王番田町');
ok($zip->set_number('9402057')->is_valid_number, '新潟県長岡市寺宝町');
ok($zip->set_number('9402058')->is_valid_number, '新潟県長岡市河根川町');
ok($zip->set_number('9402059')->is_valid_number, '新潟県長岡市大荒戸町');
ok($zip->set_number('9402101')->is_valid_number, '新潟県長岡市寺島町');
ok($zip->set_number('9402102')->is_valid_number, '新潟県長岡市小沢町');
ok($zip->set_number('9402103')->is_valid_number, '新潟県長岡市古正寺町');
ok($zip->set_number('9402104')->is_valid_number, '新潟県長岡市大島新町');
ok($zip->set_number('9402105')->is_valid_number, '新潟県長岡市緑町');
ok($zip->set_number('9402106')->is_valid_number, '新潟県長岡市古正寺');
ok($zip->set_number('9402108')->is_valid_number, '新潟県長岡市千秋');
ok($zip->set_number('9402111')->is_valid_number, '新潟県長岡市三ツ郷屋');
ok($zip->set_number('9402112')->is_valid_number, '新潟県長岡市大島本町');
ok($zip->set_number('9402113')->is_valid_number, '新潟県長岡市大山');
ok($zip->set_number('9402114')->is_valid_number, '新潟県長岡市北山');
ok($zip->set_number('9402115')->is_valid_number, '新潟県長岡市下山');
ok($zip->set_number('9402116')->is_valid_number, '新潟県長岡市南七日町');
ok($zip->set_number('9402117')->is_valid_number, '新潟県長岡市石動南町');
ok($zip->set_number('9402121')->is_valid_number, '新潟県長岡市喜多町');
ok($zip->set_number('9402122')->is_valid_number, '新潟県長岡市福山町');
ok($zip->set_number('9402123')->is_valid_number, '新潟県長岡市七日町');
ok($zip->set_number('9402124')->is_valid_number, '新潟県長岡市希望が丘');
ok($zip->set_number('9402125')->is_valid_number, '新潟県長岡市希望が丘南');
ok($zip->set_number('9402126')->is_valid_number, '新潟県長岡市西津町');
ok($zip->set_number('9402127')->is_valid_number, '新潟県長岡市新産');
ok($zip->set_number('9402128')->is_valid_number, '新潟県長岡市新産東町');
ok($zip->set_number('9402131')->is_valid_number, '新潟県長岡市才津東町');
ok($zip->set_number('9402132')->is_valid_number, '新潟県長岡市才津南町');
ok($zip->set_number('9402133')->is_valid_number, '新潟県長岡市才津西町');
ok($zip->set_number('9402134')->is_valid_number, '新潟県長岡市親沢町');
ok($zip->set_number('9402135')->is_valid_number, '新潟県長岡市深沢町');
ok($zip->set_number('9402136')->is_valid_number, '新潟県長岡市上富岡');
ok($zip->set_number('9402137')->is_valid_number, '新潟県長岡市上富岡町');
ok($zip->set_number('9402138')->is_valid_number, '新潟県長岡市日越');
ok($zip->set_number('9402141')->is_valid_number, '新潟県長岡市藤橋');
ok($zip->set_number('9402142')->is_valid_number, '新潟県長岡市長峰町');
ok($zip->set_number('9402143')->is_valid_number, '新潟県長岡市高寺町');
ok($zip->set_number('9402144')->is_valid_number, '新潟県長岡市高頭町');
ok($zip->set_number('9402145')->is_valid_number, '新潟県長岡市青葉台');
ok($zip->set_number('9402146')->is_valid_number, '新潟県長岡市大積町');
ok($zip->set_number('9402147')->is_valid_number, '新潟県長岡市新陽');
ok($zip->set_number('9402148')->is_valid_number, '新潟県長岡市陽光台');
ok($zip->set_number('9402151')->is_valid_number, '新潟県長岡市大積灰下町');
ok($zip->set_number('9402152')->is_valid_number, '新潟県長岡市大積高鳥町');
ok($zip->set_number('9402153')->is_valid_number, '新潟県長岡市大積千本町');
ok($zip->set_number('9402154')->is_valid_number, '新潟県長岡市大積田代町');
ok($zip->set_number('9402155')->is_valid_number, '新潟県長岡市大積熊上町');
ok($zip->set_number('9402156')->is_valid_number, '新潟県長岡市大積折渡町');
ok($zip->set_number('9402157')->is_valid_number, '新潟県長岡市大積三島谷町');
ok($zip->set_number('9402158')->is_valid_number, '新潟県長岡市大積善間町');
ok($zip->set_number('9402301')->is_valid_number, '新潟県長岡市宮沢');
ok($zip->set_number('9402302')->is_valid_number, '新潟県長岡市藤川');
ok($zip->set_number('9402303')->is_valid_number, '新潟県長岡市瓜生');
ok($zip->set_number('9402304')->is_valid_number, '新潟県長岡市下河根川');
ok($zip->set_number('9402305')->is_valid_number, '新潟県長岡市大野');
ok($zip->set_number('9402306')->is_valid_number, '新潟県長岡市脇野町');
ok($zip->set_number('9402311')->is_valid_number, '新潟県長岡市三島新保');
ok($zip->set_number('9402312')->is_valid_number, '新潟県長岡市三島中条');
ok($zip->set_number('9402313')->is_valid_number, '新潟県長岡市吉崎');
ok($zip->set_number('9402314')->is_valid_number, '新潟県長岡市上岩井');
ok($zip->set_number('9402315')->is_valid_number, '新潟県長岡市七日市');
ok($zip->set_number('9402316')->is_valid_number, '新潟県長岡市鳥越');
ok($zip->set_number('9402321')->is_valid_number, '新潟県長岡市逆谷');
ok($zip->set_number('9402322')->is_valid_number, '新潟県長岡市気比宮');
ok($zip->set_number('9402323')->is_valid_number, '新潟県長岡市三島上条');
ok($zip->set_number('9402324')->is_valid_number, '新潟県長岡市中永');
ok($zip->set_number('9402325')->is_valid_number, '新潟県長岡市蓮花寺');
ok($zip->set_number('9402401')->is_valid_number, '新潟県長岡市与板町東与板');
ok($zip->set_number('9402402')->is_valid_number, '新潟県長岡市与板町与板');
ok($zip->set_number('9402403')->is_valid_number, '新潟県長岡市与板町本与板');
ok($zip->set_number('9402404')->is_valid_number, '新潟県長岡市与板町馬越');
ok($zip->set_number('9402405')->is_valid_number, '新潟県長岡市与板町岩方');
ok($zip->set_number('9402406')->is_valid_number, '新潟県長岡市与板町江西');
ok($zip->set_number('9402407')->is_valid_number, '新潟県長岡市与板町城山');
ok($zip->set_number('9402411')->is_valid_number, '新潟県長岡市与板町蔦都');
ok($zip->set_number('9402412')->is_valid_number, '新潟県長岡市与板町広野');
ok($zip->set_number('9402413')->is_valid_number, '新潟県長岡市与板町吉津');
ok($zip->set_number('9402414')->is_valid_number, '新潟県長岡市与板町中田');
ok($zip->set_number('9402415')->is_valid_number, '新潟県長岡市与板町南中');
ok($zip->set_number('9402416')->is_valid_number, '新潟県長岡市与板町槇原');
ok($zip->set_number('9402417')->is_valid_number, '新潟県長岡市与板町山沢');
ok($zip->set_number('9402461')->is_valid_number, '新潟県長岡市脇川新田町(その他)');
ok($zip->set_number('9402462')->is_valid_number, '新潟県長岡市李崎町');
ok($zip->set_number('9402463')->is_valid_number, '新潟県長岡市川袋町');
ok($zip->set_number('9402464')->is_valid_number, '新潟県長岡市新開町');
ok($zip->set_number('9402465')->is_valid_number, '新潟県長岡市成沢町');
ok($zip->set_number('9402471')->is_valid_number, '新潟県長岡市上柳町');
ok($zip->set_number('9402472')->is_valid_number, '新潟県長岡市三之宮町');
ok($zip->set_number('9402473')->is_valid_number, '新潟県長岡市芹川町');
ok($zip->set_number('9402474')->is_valid_number, '新潟県長岡市雁島町');
ok($zip->set_number('9402475')->is_valid_number, '新潟県長岡市花井町');
ok($zip->set_number('9402501')->is_valid_number, '新潟県長岡市寺泊野積');
ok($zip->set_number('9402502')->is_valid_number, '新潟県長岡市寺泊');
ok($zip->set_number('9402503')->is_valid_number, '新潟県長岡市寺泊大地');
ok($zip->set_number('9402504')->is_valid_number, '新潟県長岡市寺泊弁才天');
ok($zip->set_number('9402505')->is_valid_number, '新潟県長岡市寺泊本弁');
ok($zip->set_number('9402506')->is_valid_number, '新潟県長岡市寺泊本山');
ok($zip->set_number('9402507')->is_valid_number, '新潟県長岡市寺泊吉');
ok($zip->set_number('9402508')->is_valid_number, '新潟県長岡市寺泊引岡');
ok($zip->set_number('9402511')->is_valid_number, '新潟県長岡市寺泊円上寺');
ok($zip->set_number('9402512')->is_valid_number, '新潟県長岡市寺泊京ケ入');
ok($zip->set_number('9402513')->is_valid_number, '新潟県長岡市寺泊当新田');
ok($zip->set_number('9402514')->is_valid_number, '新潟県長岡市寺泊蛇塚');
ok($zip->set_number('9402515')->is_valid_number, '新潟県長岡市寺泊中曽根');
ok($zip->set_number('9402516')->is_valid_number, '新潟県長岡市寺泊下曽根');
ok($zip->set_number('9402517')->is_valid_number, '新潟県長岡市寺泊川崎');
ok($zip->set_number('9402518')->is_valid_number, '新潟県長岡市寺泊戸崎');
ok($zip->set_number('9402521')->is_valid_number, '新潟県長岡市寺泊年友');
ok($zip->set_number('9402522')->is_valid_number, '新潟県長岡市寺泊夏戸');
ok($zip->set_number('9402523')->is_valid_number, '新潟県長岡市寺泊田頭');
ok($zip->set_number('9402524')->is_valid_number, '新潟県長岡市寺泊松田');
ok($zip->set_number('9402525')->is_valid_number, '新潟県長岡市寺泊明ケ谷');
ok($zip->set_number('9402526')->is_valid_number, '新潟県長岡市寺泊山田');
ok($zip->set_number('9402527')->is_valid_number, '新潟県長岡市寺泊志戸橋');
ok($zip->set_number('9402528')->is_valid_number, '新潟県長岡市寺泊郷本');
ok($zip->set_number('9402529')->is_valid_number, '新潟県長岡市寺泊大和田');
ok($zip->set_number('9410000')->is_valid_number, '新潟県糸魚川市以下に掲載がない場合');
ok($zip->set_number('9410001')->is_valid_number, '新潟県糸魚川市間脇');
ok($zip->set_number('9410002')->is_valid_number, '新潟県糸魚川市中浜');
ok($zip->set_number('9410003')->is_valid_number, '新潟県糸魚川市中宿');
ok($zip->set_number('9410004')->is_valid_number, '新潟県糸魚川市梶屋敷');
ok($zip->set_number('9410005')->is_valid_number, '新潟県糸魚川市厚田');
ok($zip->set_number('9410006')->is_valid_number, '新潟県糸魚川市竹ケ花');
ok($zip->set_number('9410007')->is_valid_number, '新潟県糸魚川市大和川');
ok($zip->set_number('9410008')->is_valid_number, '新潟県糸魚川市田伏');
ok($zip->set_number('9410011')->is_valid_number, '新潟県糸魚川市滝川原');
ok($zip->set_number('9410012')->is_valid_number, '新潟県糸魚川市上出');
ok($zip->set_number('9410013')->is_valid_number, '新潟県糸魚川市下出');
ok($zip->set_number('9410014')->is_valid_number, '新潟県糸魚川市日光寺');
ok($zip->set_number('9410015')->is_valid_number, '新潟県糸魚川市清水山');
ok($zip->set_number('9410016')->is_valid_number, '新潟県糸魚川市四ツ屋');
ok($zip->set_number('9410019')->is_valid_number, '新潟県糸魚川市道明');
ok($zip->set_number('9410021')->is_valid_number, '新潟県糸魚川市東海');
ok($zip->set_number('9410022')->is_valid_number, '新潟県糸魚川市新町');
ok($zip->set_number('9410023')->is_valid_number, '新潟県糸魚川市上覚');
ok($zip->set_number('9410024')->is_valid_number, '新潟県糸魚川市西谷内');
ok($zip->set_number('9410025')->is_valid_number, '新潟県糸魚川市堀切');
ok($zip->set_number('9410026')->is_valid_number, '新潟県糸魚川市田屋');
ok($zip->set_number('9410027')->is_valid_number, '新潟県糸魚川市東川原');
ok($zip->set_number('9410031')->is_valid_number, '新潟県糸魚川市粟倉');
ok($zip->set_number('9410032')->is_valid_number, '新潟県糸魚川市来海沢');
ok($zip->set_number('9410033')->is_valid_number, '新潟県糸魚川市御前山');
ok($zip->set_number('9410034')->is_valid_number, '新潟県糸魚川市市野々');
ok($zip->set_number('9410035')->is_valid_number, '新潟県糸魚川市真木');
ok($zip->set_number('9410036')->is_valid_number, '新潟県糸魚川市釜沢');
ok($zip->set_number('9410037')->is_valid_number, '新潟県糸魚川市道平');
ok($zip->set_number('9410041')->is_valid_number, '新潟県糸魚川市真光寺');
ok($zip->set_number('9410042')->is_valid_number, '新潟県糸魚川市川島');
ok($zip->set_number('9410043')->is_valid_number, '新潟県糸魚川市田中');
ok($zip->set_number('9410044')->is_valid_number, '新潟県糸魚川市水保');
ok($zip->set_number('9410045')->is_valid_number, '新潟県糸魚川市成沢');
ok($zip->set_number('9410046')->is_valid_number, '新潟県糸魚川市羽生');
ok($zip->set_number('9410047')->is_valid_number, '新潟県糸魚川市平牛');
ok($zip->set_number('9410051')->is_valid_number, '新潟県糸魚川市押上');
ok($zip->set_number('9410052')->is_valid_number, '新潟県糸魚川市南押上');
ok($zip->set_number('9410053')->is_valid_number, '新潟県糸魚川市東寺町');
ok($zip->set_number('9410054')->is_valid_number, '新潟県糸魚川市京ケ峰');
ok($zip->set_number('9410055')->is_valid_number, '新潟県糸魚川市蓮台寺');
ok($zip->set_number('9410056')->is_valid_number, '新潟県糸魚川市一の宮');
ok($zip->set_number('9410057')->is_valid_number, '新潟県糸魚川市南寺町');
ok($zip->set_number('9410058')->is_valid_number, '新潟県糸魚川市寺町');
ok($zip->set_number('9410061')->is_valid_number, '新潟県糸魚川市大町');
ok($zip->set_number('9410062')->is_valid_number, '新潟県糸魚川市中央');
ok($zip->set_number('9410063')->is_valid_number, '新潟県糸魚川市清崎');
ok($zip->set_number('9410064')->is_valid_number, '新潟県糸魚川市上刈');
ok($zip->set_number('9410065')->is_valid_number, '新潟県糸魚川市新鉄');
ok($zip->set_number('9410066')->is_valid_number, '新潟県糸魚川市寺島');
ok($zip->set_number('9410067')->is_valid_number, '新潟県糸魚川市横町');
ok($zip->set_number('9410068')->is_valid_number, '新潟県糸魚川市本町');
ok($zip->set_number('9410069')->is_valid_number, '新潟県糸魚川市南寺島');
ok($zip->set_number('9410071')->is_valid_number, '新潟県糸魚川市大野');
ok($zip->set_number('9410072')->is_valid_number, '新潟県糸魚川市山本');
ok($zip->set_number('9410073')->is_valid_number, '新潟県糸魚川市西川原');
ok($zip->set_number('9410074')->is_valid_number, '新潟県糸魚川市大谷内');
ok($zip->set_number('9410075')->is_valid_number, '新潟県糸魚川市中谷内');
ok($zip->set_number('9410076')->is_valid_number, '新潟県糸魚川市西中');
ok($zip->set_number('9410077')->is_valid_number, '新潟県糸魚川市頭山');
ok($zip->set_number('9410078')->is_valid_number, '新潟県糸魚川市岩木');
ok($zip->set_number('9420001')->is_valid_number, '新潟県上越市中央');
ok($zip->set_number('9420002')->is_valid_number, '新潟県上越市住吉町');
ok($zip->set_number('9420003')->is_valid_number, '新潟県上越市東町');
ok($zip->set_number('9420004')->is_valid_number, '新潟県上越市西本町');
ok($zip->set_number('9420011')->is_valid_number, '新潟県上越市港町');
ok($zip->set_number('9420012')->is_valid_number, '新潟県上越市高崎新田');
ok($zip->set_number('9420013')->is_valid_number, '新潟県上越市黒井');
ok($zip->set_number('9420014')->is_valid_number, '新潟県上越市日之出町');
ok($zip->set_number('9420021')->is_valid_number, '新潟県上越市上荒浜');
ok($zip->set_number('9420022')->is_valid_number, '新潟県上越市下荒浜');
ok($zip->set_number('9420023')->is_valid_number, '新潟県上越市石橋新田');
ok($zip->set_number('9420024')->is_valid_number, '新潟県上越市遊光寺浜');
ok($zip->set_number('9420025')->is_valid_number, '新潟県上越市夷浜');
ok($zip->set_number('9420026')->is_valid_number, '新潟県上越市西ケ窪浜');
ok($zip->set_number('9420027')->is_valid_number, '新潟県上越市八千浦');
ok($zip->set_number('9420031')->is_valid_number, '新潟県上越市佐内');
ok($zip->set_number('9420031')->is_valid_number, '新潟県上越市佐内町');
ok($zip->set_number('9420032')->is_valid_number, '新潟県上越市福田');
ok($zip->set_number('9420033')->is_valid_number, '新潟県上越市福橋');
ok($zip->set_number('9420034')->is_valid_number, '新潟県上越市下真砂');
ok($zip->set_number('9420035')->is_valid_number, '新潟県上越市上千原');
ok($zip->set_number('9420036')->is_valid_number, '新潟県上越市東中島');
ok($zip->set_number('9420037')->is_valid_number, '新潟県上越市中真砂');
ok($zip->set_number('9420038')->is_valid_number, '新潟県上越市川端');
ok($zip->set_number('9420039')->is_valid_number, '新潟県上越市飯塚');
ok($zip->set_number('9420041')->is_valid_number, '新潟県上越市安江');
ok($zip->set_number('9420042')->is_valid_number, '新潟県上越市三ツ屋町');
ok($zip->set_number('9420043')->is_valid_number, '新潟県上越市三ツ橋');
ok($zip->set_number('9420044')->is_valid_number, '新潟県上越市三ツ橋新田');
ok($zip->set_number('9420045')->is_valid_number, '新潟県上越市横曾根');
ok($zip->set_number('9420046')->is_valid_number, '新潟県上越市田園');
ok($zip->set_number('9420051')->is_valid_number, '新潟県上越市下源入');
ok($zip->set_number('9420052')->is_valid_number, '新潟県上越市上源入');
ok($zip->set_number('9420053')->is_valid_number, '新潟県上越市三田新田');
ok($zip->set_number('9420054')->is_valid_number, '新潟県上越市三田');
ok($zip->set_number('9420055')->is_valid_number, '新潟県上越市小猿屋');
ok($zip->set_number('9420056')->is_valid_number, '新潟県上越市小猿屋新田');
ok($zip->set_number('9420061')->is_valid_number, '新潟県上越市春日新田');
ok($zip->set_number('9420062')->is_valid_number, '新潟県上越市松村新田');
ok($zip->set_number('9420063')->is_valid_number, '新潟県上越市下門前');
ok($zip->set_number('9420064')->is_valid_number, '新潟県上越市塩屋新田');
ok($zip->set_number('9420065')->is_valid_number, '新潟県上越市川原町');
ok($zip->set_number('9420071')->is_valid_number, '新潟県上越市東雲町');
ok($zip->set_number('9420072')->is_valid_number, '新潟県上越市栄町(1、2丁目)');
ok($zip->set_number('9420074')->is_valid_number, '新潟県上越市石橋');
ok($zip->set_number('9420081')->is_valid_number, '新潟県上越市五智');
ok($zip->set_number('9420082')->is_valid_number, '新潟県上越市国府');
ok($zip->set_number('9420083')->is_valid_number, '新潟県上越市大豆(1の2、3の2~6、4の2・4・6、11の1番地)');
ok($zip->set_number('9420084')->is_valid_number, '新潟県上越市五智新町');
ok($zip->set_number('9420085')->is_valid_number, '新潟県上越市五智国分');
ok($zip->set_number('9420086')->is_valid_number, '新潟県上越市加賀町');
ok($zip->set_number('9420087')->is_valid_number, '新潟県上越市虫生岩戸');
ok($zip->set_number('9420088')->is_valid_number, '新潟県上越市毘沙門国分寺');
ok($zip->set_number('9420089')->is_valid_number, '新潟県上越市大場');
ok($zip->set_number('9420091')->is_valid_number, '新潟県上越市頸城区西福島(1~225、227~288、1060番地)');
ok($zip->set_number('9420101')->is_valid_number, '新潟県上越市頸城区柳町新田');
ok($zip->set_number('9420102')->is_valid_number, '新潟県上越市頸城区岡田');
ok($zip->set_number('9420103')->is_valid_number, '新潟県上越市頸城区富田');
ok($zip->set_number('9420104')->is_valid_number, '新潟県上越市頸城区下池田');
ok($zip->set_number('9420105')->is_valid_number, '新潟県上越市頸城区戸口野');
ok($zip->set_number('9420106')->is_valid_number, '新潟県上越市頸城区上柳町');
ok($zip->set_number('9420107')->is_valid_number, '新潟県上越市頸城区中柳町');
ok($zip->set_number('9420108')->is_valid_number, '新潟県上越市頸城区下柳町');
ok($zip->set_number('9420109')->is_valid_number, '新潟県上越市頸城区寺田');
ok($zip->set_number('9420111')->is_valid_number, '新潟県上越市頸城区片津');
ok($zip->set_number('9420112')->is_valid_number, '新潟県上越市頸城区姥谷内');
ok($zip->set_number('9420113')->is_valid_number, '新潟県上越市頸城区中城');
ok($zip->set_number('9420114')->is_valid_number, '新潟県上越市頸城区柿野');
ok($zip->set_number('9420115')->is_valid_number, '新潟県上越市頸城区田中');
ok($zip->set_number('9420116')->is_valid_number, '新潟県上越市頸城区大坂井');
ok($zip->set_number('9420117')->is_valid_number, '新潟県上越市頸城区西湊');
ok($zip->set_number('9420121')->is_valid_number, '新潟県上越市頸城区鵜ノ木');
ok($zip->set_number('9420122')->is_valid_number, '新潟県上越市頸城区川袋');
ok($zip->set_number('9420123')->is_valid_number, '新潟県上越市頸城区下中村');
ok($zip->set_number('9420124')->is_valid_number, '新潟県上越市頸城区東俣');
ok($zip->set_number('9420125')->is_valid_number, '新潟県上越市頸城区飯田');
ok($zip->set_number('9420126')->is_valid_number, '新潟県上越市頸城区宮原');
ok($zip->set_number('9420127')->is_valid_number, '新潟県上越市頸城区百間町');
ok($zip->set_number('9420128')->is_valid_number, '新潟県上越市頸城区諏訪');
ok($zip->set_number('9420129')->is_valid_number, '新潟県上越市頸城区立崎');
ok($zip->set_number('9420131')->is_valid_number, '新潟県上越市頸城区千原');
ok($zip->set_number('9420132')->is_valid_number, '新潟県上越市頸城区北福崎');
ok($zip->set_number('9420133')->is_valid_number, '新潟県上越市頸城区上神原');
ok($zip->set_number('9420134')->is_valid_number, '新潟県上越市頸城区下神原');
ok($zip->set_number('9420135')->is_valid_number, '新潟県上越市頸城区五十嵐');
ok($zip->set_number('9420136')->is_valid_number, '新潟県上越市頸城区島田');
ok($zip->set_number('9420137')->is_valid_number, '新潟県上越市頸城区下千原');
ok($zip->set_number('9420138')->is_valid_number, '新潟県上越市頸城区望ケ丘');
ok($zip->set_number('9420139')->is_valid_number, '新潟県上越市頸城区美しが丘');
ok($zip->set_number('9420141')->is_valid_number, '新潟県上越市頸城区市村');
ok($zip->set_number('9420142')->is_valid_number, '新潟県上越市頸城区上三分一');
ok($zip->set_number('9420143')->is_valid_number, '新潟県上越市頸城区下三分一');
ok($zip->set_number('9420144')->is_valid_number, '新潟県上越市頸城区松本');
ok($zip->set_number('9420145')->is_valid_number, '新潟県上越市頸城区上吉');
ok($zip->set_number('9420146')->is_valid_number, '新潟県上越市頸城区下吉');
ok($zip->set_number('9420147')->is_valid_number, '新潟県上越市頸城区西福島(その他)');
ok($zip->set_number('9420151')->is_valid_number, '新潟県上越市頸城区北四ツ屋');
ok($zip->set_number('9420152')->is_valid_number, '新潟県上越市頸城区浮島');
ok($zip->set_number('9420153')->is_valid_number, '新潟県上越市頸城区下米岡');
ok($zip->set_number('9420154')->is_valid_number, '新潟県上越市頸城区榎井');
ok($zip->set_number('9420155')->is_valid_number, '新潟県上越市頸城区下中島');
ok($zip->set_number('9420156')->is_valid_number, '新潟県上越市頸城区松橋');
ok($zip->set_number('9420157')->is_valid_number, '新潟県上越市頸城区城野腰');
ok($zip->set_number('9420158')->is_valid_number, '新潟県上越市頸城区松橋新田');
ok($zip->set_number('9420161')->is_valid_number, '新潟県上越市頸城区手宮');
ok($zip->set_number('9420162')->is_valid_number, '新潟県上越市頸城区森下');
ok($zip->set_number('9420163')->is_valid_number, '新潟県上越市頸城区大谷内');
ok($zip->set_number('9420164')->is_valid_number, '新潟県上越市頸城区潟口');
ok($zip->set_number('9420165')->is_valid_number, '新潟県上越市頸城区青野');
ok($zip->set_number('9420171')->is_valid_number, '新潟県上越市頸城区北方');
ok($zip->set_number('9420172')->is_valid_number, '新潟県上越市頸城区宮本');
ok($zip->set_number('9420173')->is_valid_number, '新潟県上越市頸城区舟津');
ok($zip->set_number('9420181')->is_valid_number, '新潟県上越市大潟区潟守新田(53の1~60の9番地)');
ok($zip->set_number('9420201')->is_valid_number, '新潟県上越市頸城区大潟');
ok($zip->set_number('9420202')->is_valid_number, '新潟県上越市頸城区上池田');
ok($zip->set_number('9420203')->is_valid_number, '新潟県上越市頸城区上増田');
ok($zip->set_number('9420204')->is_valid_number, '新潟県上越市頸城区両毛');
ok($zip->set_number('9420205')->is_valid_number, '新潟県上越市頸城区中増田');
ok($zip->set_number('9420206')->is_valid_number, '新潟県上越市頸城区下増田');
ok($zip->set_number('9420207')->is_valid_number, '新潟県上越市頸城区手島');
ok($zip->set_number('9420208')->is_valid_number, '新潟県上越市頸城区潟');
ok($zip->set_number('9420211')->is_valid_number, '新潟県上越市頸城区畑ケ崎');
ok($zip->set_number('9420212')->is_valid_number, '新潟県上越市頸城区矢住');
ok($zip->set_number('9420213')->is_valid_number, '新潟県上越市頸城区中島');
ok($zip->set_number('9420214')->is_valid_number, '新潟県上越市頸城区大蒲生田');
ok($zip->set_number('9420215')->is_valid_number, '新潟県上越市頸城区玄僧');
ok($zip->set_number('9420216')->is_valid_number, '新潟県上越市頸城区日根津');
ok($zip->set_number('9420221')->is_valid_number, '新潟県上越市頸城区石神');
ok($zip->set_number('9420222')->is_valid_number, '新潟県上越市頸城区花ケ崎');
ok($zip->set_number('9420223')->is_valid_number, '新潟県上越市頸城区森本');
ok($zip->set_number('9420224')->is_valid_number, '新潟県上越市頸城区仁野分');
ok($zip->set_number('9420225')->is_valid_number, '新潟県上越市頸城区天ケ崎');
ok($zip->set_number('9420226')->is_valid_number, '新潟県上越市頸城区塔ケ崎');
ok($zip->set_number('9420231')->is_valid_number, '新潟県上越市下吉野');
ok($zip->set_number('9420232')->is_valid_number, '新潟県上越市福岡新田');
ok($zip->set_number('9420233')->is_valid_number, '新潟県上越市岡崎新田');
ok($zip->set_number('9420234')->is_valid_number, '新潟県上越市田沢新田');
ok($zip->set_number('9420238')->is_valid_number, '新潟県上越市青野');
ok($zip->set_number('9420241')->is_valid_number, '新潟県上越市上吉野');
ok($zip->set_number('9420242')->is_valid_number, '新潟県上越市石川');
ok($zip->set_number('9420243')->is_valid_number, '新潟県上越市五野井');
ok($zip->set_number('9420244')->is_valid_number, '新潟県上越市長岡新田');
ok($zip->set_number('9420245')->is_valid_number, '新潟県上越市長岡');
ok($zip->set_number('9420246')->is_valid_number, '新潟県上越市駒林');
ok($zip->set_number('9420247')->is_valid_number, '新潟県上越市下百々');
ok($zip->set_number('9420251')->is_valid_number, '新潟県上越市小泉');
ok($zip->set_number('9420252')->is_valid_number, '新潟県上越市上名柄');
ok($zip->set_number('9420253')->is_valid_number, '新潟県上越市下名柄');
ok($zip->set_number('9420254')->is_valid_number, '新潟県上越市上五貫野');
ok($zip->set_number('9420255')->is_valid_number, '新潟県上越市下五貫野');
ok($zip->set_number('9420261')->is_valid_number, '新潟県上越市三和区末野新田');
ok($zip->set_number('9420262')->is_valid_number, '新潟県上越市三和区末野');
ok($zip->set_number('9420263')->is_valid_number, '新潟県上越市三和区山腰新田');
ok($zip->set_number('9420264')->is_valid_number, '新潟県上越市三和区塔ノ輪');
ok($zip->set_number('9420265')->is_valid_number, '新潟県上越市三和区神田');
ok($zip->set_number('9420266')->is_valid_number, '新潟県上越市三和区越柳');
ok($zip->set_number('9420267')->is_valid_number, '新潟県上越市三和区沖柳');
ok($zip->set_number('9420268')->is_valid_number, '新潟県上越市三和区本郷');
ok($zip->set_number('9420271')->is_valid_number, '新潟県上越市三和区錦');
ok($zip->set_number('9420272')->is_valid_number, '新潟県上越市三和区柳林');
ok($zip->set_number('9420273')->is_valid_number, '新潟県上越市三和区上広田');
ok($zip->set_number('9420274')->is_valid_number, '新潟県上越市三和区下広田');
ok($zip->set_number('9420275')->is_valid_number, '新潟県上越市三和区岡木');
ok($zip->set_number('9420276')->is_valid_number, '新潟県上越市三和区米子');
ok($zip->set_number('9420277')->is_valid_number, '新潟県上越市三和区広井');
ok($zip->set_number('9420301')->is_valid_number, '新潟県上越市浦川原区上猪子田');
ok($zip->set_number('9420302')->is_valid_number, '新潟県上越市浦川原区小谷島');
ok($zip->set_number('9420303')->is_valid_number, '新潟県上越市浦川原区下猪子田');
ok($zip->set_number('9420304')->is_valid_number, '新潟県上越市浦川原区中猪子田');
ok($zip->set_number('9420305')->is_valid_number, '新潟県上越市浦川原区虫川');
ok($zip->set_number('9420306')->is_valid_number, '新潟県上越市浦川原区有島');
ok($zip->set_number('9420307')->is_valid_number, '新潟県上越市浦川原区釜淵');
ok($zip->set_number('9420308')->is_valid_number, '新潟県上越市浦川原区小蒲生田');
ok($zip->set_number('9420311')->is_valid_number, '新潟県上越市浦川原区上柿野');
ok($zip->set_number('9420312')->is_valid_number, '新潟県上越市浦川原区大栃山');
ok($zip->set_number('9420313')->is_valid_number, '新潟県上越市浦川原区下柿野');
ok($zip->set_number('9420314')->is_valid_number, '新潟県上越市浦川原区顕聖寺');
ok($zip->set_number('9420315')->is_valid_number, '新潟県上越市浦川原区横川');
ok($zip->set_number('9420316')->is_valid_number, '新潟県上越市浦川原区六日町');
ok($zip->set_number('9420317')->is_valid_number, '新潟県上越市浦川原区杉坪');
ok($zip->set_number('9420318')->is_valid_number, '新潟県上越市浦川原区上岡');
ok($zip->set_number('9420319')->is_valid_number, '新潟県上越市浦川原区東俣');
ok($zip->set_number('9420321')->is_valid_number, '新潟県上越市浦川原区熊沢');
ok($zip->set_number('9420322')->is_valid_number, '新潟県上越市浦川原区横住');
ok($zip->set_number('9420323')->is_valid_number, '新潟県上越市浦川原区真光寺');
ok($zip->set_number('9420324')->is_valid_number, '新潟県上越市浦川原区谷');
ok($zip->set_number('9420325')->is_valid_number, '新潟県上越市浦川原区坪野');
ok($zip->set_number('9420326')->is_valid_number, '新潟県上越市浦川原区法定寺');
ok($zip->set_number('9420327')->is_valid_number, '新潟県上越市浦川原区菱田');
ok($zip->set_number('9420331')->is_valid_number, '新潟県上越市浦川原区長走');
ok($zip->set_number('9420332')->is_valid_number, '新潟県上越市浦川原区岩室');
ok($zip->set_number('9420333')->is_valid_number, '新潟県上越市浦川原区桜島');
ok($zip->set_number('9420334')->is_valid_number, '新潟県上越市浦川原区山本');
ok($zip->set_number('9420335')->is_valid_number, '新潟県上越市浦川原区今熊');
ok($zip->set_number('9420336')->is_valid_number, '新潟県上越市浦川原区飯室');
ok($zip->set_number('9420337')->is_valid_number, '新潟県上越市浦川原区山印内');
ok($zip->set_number('9420338')->is_valid_number, '新潟県上越市浦川原区印内');
ok($zip->set_number('9420339')->is_valid_number, '新潟県上越市浦川原区日向');
ok($zip->set_number('9420401')->is_valid_number, '新潟県上越市安塚区細野');
ok($zip->set_number('9420402')->is_valid_number, '新潟県上越市安塚区坊金');
ok($zip->set_number('9420403')->is_valid_number, '新潟県上越市安塚区本郷');
ok($zip->set_number('9420404')->is_valid_number, '新潟県上越市安塚区石橋');
ok($zip->set_number('9420405')->is_valid_number, '新潟県上越市安塚区上方');
ok($zip->set_number('9420411')->is_valid_number, '新潟県上越市安塚区安塚');
ok($zip->set_number('9420412')->is_valid_number, '新潟県上越市安塚区牧野');
ok($zip->set_number('9420413')->is_valid_number, '新潟県上越市安塚区板尾');
ok($zip->set_number('9420414')->is_valid_number, '新潟県上越市安塚区袖山');
ok($zip->set_number('9420415')->is_valid_number, '新潟県上越市安塚区松崎');
ok($zip->set_number('9420521')->is_valid_number, '新潟県上越市安塚区行野');
ok($zip->set_number('9420522')->is_valid_number, '新潟県上越市安塚区大原');
ok($zip->set_number('9420523')->is_valid_number, '新潟県上越市安塚区戸沢');
ok($zip->set_number('9420524')->is_valid_number, '新潟県上越市安塚区芹田');
ok($zip->set_number('9420525')->is_valid_number, '新潟県上越市安塚区和田');
ok($zip->set_number('9420531')->is_valid_number, '新潟県上越市安塚区樽田');
ok($zip->set_number('9420532')->is_valid_number, '新潟県上越市安塚区下船倉');
ok($zip->set_number('9420533')->is_valid_number, '新潟県上越市安塚区上船倉');
ok($zip->set_number('9420534')->is_valid_number, '新潟県上越市安塚区須川');
ok($zip->set_number('9420535')->is_valid_number, '新潟県上越市安塚区真荻平');
ok($zip->set_number('9420536')->is_valid_number, '新潟県上越市安塚区信濃坂');
ok($zip->set_number('9420537')->is_valid_number, '新潟県上越市安塚区二本木');
ok($zip->set_number('9420538')->is_valid_number, '新潟県上越市安塚区高沢');
ok($zip->set_number('9420539')->is_valid_number, '新潟県上越市安塚区円平坊');
ok($zip->set_number('9420541')->is_valid_number, '新潟県上越市安塚区小黒');
ok($zip->set_number('9420542')->is_valid_number, '新潟県上越市安塚区切越');
ok($zip->set_number('9420543')->is_valid_number, '新潟県上越市安塚区菅沼');
ok($zip->set_number('9420544')->is_valid_number, '新潟県上越市安塚区朴ノ木');
ok($zip->set_number('9421101')->is_valid_number, '新潟県上越市大島区嶺');
ok($zip->set_number('9421102')->is_valid_number, '新潟県上越市大島区田麦');
ok($zip->set_number('9421103')->is_valid_number, '新潟県上越市大島区大平');
ok($zip->set_number('9421104')->is_valid_number, '新潟県上越市大島区下達');
ok($zip->set_number('9421105')->is_valid_number, '新潟県上越市大島区上達');
ok($zip->set_number('9421106')->is_valid_number, '新潟県上越市大島区岡');
ok($zip->set_number('9421107')->is_valid_number, '新潟県上越市大島区板山');
ok($zip->set_number('9421211')->is_valid_number, '新潟県上越市大島区大島');
ok($zip->set_number('9421212')->is_valid_number, '新潟県上越市大島区中野');
ok($zip->set_number('9421213')->is_valid_number, '新潟県上越市大島区棚岡');
ok($zip->set_number('9421214')->is_valid_number, '新潟県上越市大島区仁上');
ok($zip->set_number('9421215')->is_valid_number, '新潟県上越市大島区牛ケ鼻');
ok($zip->set_number('9421216')->is_valid_number, '新潟県上越市大島区菖蒲');
ok($zip->set_number('9421341')->is_valid_number, '新潟県十日町市松之山黒倉');
ok($zip->set_number('9421342')->is_valid_number, '新潟県十日町市浦田');
ok($zip->set_number('9421351')->is_valid_number, '新潟県十日町市峠');
ok($zip->set_number('9421352')->is_valid_number, '新潟県十日町市木和田原');
ok($zip->set_number('9421353')->is_valid_number, '新潟県十日町市室野');
ok($zip->set_number('9421354')->is_valid_number, '新潟県十日町市福島');
ok($zip->set_number('9421355')->is_valid_number, '新潟県十日町市奈良立');
ok($zip->set_number('9421356')->is_valid_number, '新潟県十日町市竹所');
ok($zip->set_number('9421401')->is_valid_number, '新潟県十日町市松之山水梨');
ok($zip->set_number('9421402')->is_valid_number, '新潟県十日町市松之山小谷');
ok($zip->set_number('9421403')->is_valid_number, '新潟県十日町市松之山大荒戸');
ok($zip->set_number('9421404')->is_valid_number, '新潟県十日町市松之山新山');
ok($zip->set_number('9421405')->is_valid_number, '新潟県十日町市松之山光間');
ok($zip->set_number('9421406')->is_valid_number, '新潟県十日町市松之山');
ok($zip->set_number('9421411')->is_valid_number, '新潟県十日町市松之山松口');
ok($zip->set_number('9421412')->is_valid_number, '新潟県十日町市松之山三桶');
ok($zip->set_number('9421413')->is_valid_number, '新潟県十日町市松之山沢口');
ok($zip->set_number('9421414')->is_valid_number, '新潟県十日町市松之山古戸');
ok($zip->set_number('9421415')->is_valid_number, '新潟県十日町市松之山観音寺');
ok($zip->set_number('9421416')->is_valid_number, '新潟県十日町市松之山坂下');
ok($zip->set_number('9421417')->is_valid_number, '新潟県十日町市松之山猪之名');
ok($zip->set_number('9421418')->is_valid_number, '新潟県十日町市松之山藤内名');
ok($zip->set_number('9421419')->is_valid_number, '新潟県十日町市松之山橋詰');
ok($zip->set_number('9421421')->is_valid_number, '新潟県十日町市松之山五十子平');
ok($zip->set_number('9421422')->is_valid_number, '新潟県十日町市松之山坪野');
ok($zip->set_number('9421423')->is_valid_number, '新潟県十日町市松之山赤倉');
ok($zip->set_number('9421424')->is_valid_number, '新潟県十日町市松之山東山');
ok($zip->set_number('9421425')->is_valid_number, '新潟県十日町市松之山下鰕池');
ok($zip->set_number('9421426')->is_valid_number, '新潟県十日町市松之山上鰕池');
ok($zip->set_number('9421427')->is_valid_number, '新潟県十日町市松之山東川');
ok($zip->set_number('9421428')->is_valid_number, '新潟県十日町市松之山中尾');
ok($zip->set_number('9421429')->is_valid_number, '新潟県十日町市松之山藤倉');
ok($zip->set_number('9421431')->is_valid_number, '新潟県十日町市松之山湯山');
ok($zip->set_number('9421432')->is_valid_number, '新潟県十日町市松之山湯本');
ok($zip->set_number('9421434')->is_valid_number, '新潟県十日町市松之山天水島');
ok($zip->set_number('9421435')->is_valid_number, '新潟県十日町市松之山天水越');
ok($zip->set_number('9421501')->is_valid_number, '新潟県十日町市滝沢');
ok($zip->set_number('9421502')->is_valid_number, '新潟県十日町市片桐山');
ok($zip->set_number('9421503')->is_valid_number, '新潟県十日町市孟地');
ok($zip->set_number('9421504')->is_valid_number, '新潟県十日町市犬伏');
ok($zip->set_number('9421505')->is_valid_number, '新潟県十日町市苧島');
ok($zip->set_number('9421506')->is_valid_number, '新潟県十日町市中子');
ok($zip->set_number('9421511')->is_valid_number, '新潟県十日町市海老');
ok($zip->set_number('9421512')->is_valid_number, '新潟県十日町市松代東山');
ok($zip->set_number('9421513')->is_valid_number, '新潟県十日町市松代下山');
ok($zip->set_number('9421514')->is_valid_number, '新潟県十日町市小屋丸');
ok($zip->set_number('9421515')->is_valid_number, '新潟県十日町市池之畑');
ok($zip->set_number('9421521')->is_valid_number, '新潟県十日町市菅刈');
ok($zip->set_number('9421522')->is_valid_number, '新潟県十日町市松代田沢');
ok($zip->set_number('9421523')->is_valid_number, '新潟県十日町市小荒戸');
ok($zip->set_number('9421524')->is_valid_number, '新潟県十日町市千年');
ok($zip->set_number('9421525')->is_valid_number, '新潟県十日町市池尻');
ok($zip->set_number('9421526')->is_valid_number, '新潟県十日町市松代');
ok($zip->set_number('9421527')->is_valid_number, '新潟県十日町市太平');
ok($zip->set_number('9421531')->is_valid_number, '新潟県十日町市莇平');
ok($zip->set_number('9421532')->is_valid_number, '新潟県十日町市仙納');
ok($zip->set_number('9421533')->is_valid_number, '新潟県十日町市田野倉');
ok($zip->set_number('9421534')->is_valid_number, '新潟県十日町市蒲生');
ok($zip->set_number('9421535')->is_valid_number, '新潟県十日町市名平');
ok($zip->set_number('9421536')->is_valid_number, '新潟県十日町市儀明');
ok($zip->set_number('9421537')->is_valid_number, '新潟県十日町市寺田');
ok($zip->set_number('9421538')->is_valid_number, '新潟県十日町市小池');
ok($zip->set_number('9421541')->is_valid_number, '新潟県十日町市桐山');
ok($zip->set_number('9421542')->is_valid_number, '新潟県十日町市清水');
ok($zip->set_number('9421543')->is_valid_number, '新潟県十日町市会沢');
ok($zip->set_number('9421544')->is_valid_number, '新潟県十日町市蓬平');
ok($zip->set_number('9430000')->is_valid_number, '新潟県上越市以下に掲載がない場合');
ok($zip->set_number('9430101')->is_valid_number, '新潟県上越市上真砂');
ok($zip->set_number('9430102')->is_valid_number, '新潟県上越市杉野袋');
ok($zip->set_number('9430103')->is_valid_number, '新潟県上越市米岡');
ok($zip->set_number('9430104')->is_valid_number, '新潟県上越市鶴町');
ok($zip->set_number('9430105')->is_valid_number, '新潟県上越市東原');
ok($zip->set_number('9430106')->is_valid_number, '新潟県上越市北田中');
ok($zip->set_number('9430107')->is_valid_number, '新潟県上越市諏訪');
ok($zip->set_number('9430108')->is_valid_number, '新潟県上越市南新保');
ok($zip->set_number('9430109')->is_valid_number, '新潟県上越市北新保');
ok($zip->set_number('9430111')->is_valid_number, '新潟県上越市下野田');
ok($zip->set_number('9430112')->is_valid_number, '新潟県上越市上野田');
ok($zip->set_number('9430113')->is_valid_number, '新潟県上越市上池部');
ok($zip->set_number('9430114')->is_valid_number, '新潟県上越市吉岡');
ok($zip->set_number('9430115')->is_valid_number, '新潟県上越市劔');
ok($zip->set_number('9430116')->is_valid_number, '新潟県上越市野尻');
ok($zip->set_number('9430117')->is_valid_number, '新潟県上越市稲');
ok($zip->set_number('9430118')->is_valid_number, '新潟県上越市東市野口');
ok($zip->set_number('9430119')->is_valid_number, '新潟県上越市下池部');
ok($zip->set_number('9430121')->is_valid_number, '新潟県上越市藤塚');
ok($zip->set_number('9430122')->is_valid_number, '新潟県上越市新保古新田');
ok($zip->set_number('9430123')->is_valid_number, '新潟県上越市本新保');
ok($zip->set_number('9430124')->is_valid_number, '新潟県上越市上雲寺');
ok($zip->set_number('9430125')->is_valid_number, '新潟県上越市下富川');
ok($zip->set_number('9430126')->is_valid_number, '新潟県上越市上富川');
ok($zip->set_number('9430127')->is_valid_number, '新潟県上越市熊塚');
ok($zip->set_number('9430128')->is_valid_number, '新潟県上越市池');
ok($zip->set_number('9430129')->is_valid_number, '新潟県上越市茨沢');
ok($zip->set_number('9430131')->is_valid_number, '新潟県上越市薮野');
ok($zip->set_number('9430132')->is_valid_number, '新潟県上越市辰尾新田');
ok($zip->set_number('9430133')->is_valid_number, '新潟県上越市東稲塚新田');
ok($zip->set_number('9430134')->is_valid_number, '新潟県上越市下稲塚');
ok($zip->set_number('9430135')->is_valid_number, '新潟県上越市下四ツ屋');
ok($zip->set_number('9430136')->is_valid_number, '新潟県上越市西松野木');
ok($zip->set_number('9430137')->is_valid_number, '新潟県上越市長者町');
ok($zip->set_number('9430138')->is_valid_number, '新潟県上越市本長者原');
ok($zip->set_number('9430139')->is_valid_number, '新潟県上越市天野原新田');
ok($zip->set_number('9430141')->is_valid_number, '新潟県上越市子安');
ok($zip->set_number('9430142')->is_valid_number, '新潟県上越市下新町');
ok($zip->set_number('9430143')->is_valid_number, '新潟県上越市上新町');
ok($zip->set_number('9430144')->is_valid_number, '新潟県上越市桜町');
ok($zip->set_number('9430145')->is_valid_number, '新潟県上越市今池');
ok($zip->set_number('9430146')->is_valid_number, '新潟県上越市とよば');
ok($zip->set_number('9430147')->is_valid_number, '新潟県上越市新南町');
ok($zip->set_number('9430148')->is_valid_number, '新潟県上越市子安新田');
ok($zip->set_number('9430151')->is_valid_number, '新潟県上越市平成町');
ok($zip->set_number('9430152')->is_valid_number, '新潟県上越市西市野口');
ok($zip->set_number('9430153')->is_valid_number, '新潟県上越市鴨島');
ok($zip->set_number('9430154')->is_valid_number, '新潟県上越市稲田');
ok($zip->set_number('9430155')->is_valid_number, '新潟県上越市四ケ所');
ok($zip->set_number('9430161')->is_valid_number, '新潟県上越市北田屋新田');
ok($zip->set_number('9430162')->is_valid_number, '新潟県上越市南田屋新田');
ok($zip->set_number('9430163')->is_valid_number, '新潟県上越市平岡');
ok($zip->set_number('9430164')->is_valid_number, '新潟県上越市中々村新田');
ok($zip->set_number('9430165')->is_valid_number, '新潟県上越市上島');
ok($zip->set_number('9430166')->is_valid_number, '新潟県上越市寺');
ok($zip->set_number('9430167')->is_valid_number, '新潟県上越市下稲田');
ok($zip->set_number('9430168')->is_valid_number, '新潟県上越市上稲田');
ok($zip->set_number('9430171')->is_valid_number, '新潟県上越市藤野新田');
ok($zip->set_number('9430172')->is_valid_number, '新潟県上越市大道福田');
ok($zip->set_number('9430173')->is_valid_number, '新潟県上越市富岡');
ok($zip->set_number('9430174')->is_valid_number, '新潟県上越市中田新田');
ok($zip->set_number('9430175')->is_valid_number, '新潟県上越市大日');
ok($zip->set_number('9430176')->is_valid_number, '新潟県上越市戸野目古新田');
ok($zip->set_number('9430177')->is_valid_number, '新潟県上越市門田新田');
ok($zip->set_number('9430178')->is_valid_number, '新潟県上越市戸野目');
ok($zip->set_number('9430181')->is_valid_number, '新潟県上越市虫川');
ok($zip->set_number('9430182')->is_valid_number, '新潟県上越市高森');
ok($zip->set_number('9430183')->is_valid_number, '新潟県上越市桐原');
ok($zip->set_number('9430184')->is_valid_number, '新潟県上越市本道');
ok($zip->set_number('9430185')->is_valid_number, '新潟県上越市長面');
ok($zip->set_number('9430186')->is_valid_number, '新潟県上越市市野江');
ok($zip->set_number('9430187')->is_valid_number, '新潟県上越市荒屋');
ok($zip->set_number('9430201')->is_valid_number, '新潟県上越市四辻町');
ok($zip->set_number('9430202')->is_valid_number, '新潟県上越市米町');
ok($zip->set_number('9430221')->is_valid_number, '新潟県上越市三和区稲原');
ok($zip->set_number('9430222')->is_valid_number, '新潟県上越市三和区下中');
ok($zip->set_number('9430223')->is_valid_number, '新潟県上越市三和区田');
ok($zip->set_number('9430224')->is_valid_number, '新潟県上越市三和区川浦');
ok($zip->set_number('9430225')->is_valid_number, '新潟県上越市三和区野');
ok($zip->set_number('9430226')->is_valid_number, '新潟県上越市三和区日和町');
ok($zip->set_number('9430227')->is_valid_number, '新潟県上越市三和区番町');
ok($zip->set_number('9430228')->is_valid_number, '新潟県上越市三和区神明町');
ok($zip->set_number('9430231')->is_valid_number, '新潟県上越市三和区鴨井');
ok($zip->set_number('9430232')->is_valid_number, '新潟県上越市三和区水吉');
ok($zip->set_number('9430233')->is_valid_number, '新潟県上越市三和区水科');
ok($zip->set_number('9430234')->is_valid_number, '新潟県上越市三和区法花寺');
ok($zip->set_number('9430235')->is_valid_number, '新潟県上越市三和区窪');
ok($zip->set_number('9430236')->is_valid_number, '新潟県上越市三和区中野');
ok($zip->set_number('9430301')->is_valid_number, '新潟県上越市三和区北代');
ok($zip->set_number('9430302')->is_valid_number, '新潟県上越市三和区払沢');
ok($zip->set_number('9430303')->is_valid_number, '新潟県上越市三和区山高津');
ok($zip->set_number('9430304')->is_valid_number, '新潟県上越市三和区桑曽根');
ok($zip->set_number('9430305')->is_valid_number, '新潟県上越市三和区岡田');
ok($zip->set_number('9430306')->is_valid_number, '新潟県上越市三和区所山田');
ok($zip->set_number('9430307')->is_valid_number, '新潟県上越市三和区下新保');
ok($zip->set_number('9430311')->is_valid_number, '新潟県上越市三和区島倉');
ok($zip->set_number('9430312')->is_valid_number, '新潟県上越市三和区下田島');
ok($zip->set_number('9430313')->is_valid_number, '新潟県上越市三和区今保');
ok($zip->set_number('9430314')->is_valid_number, '新潟県上越市三和区大');
ok($zip->set_number('9430315')->is_valid_number, '新潟県上越市三和区三村新田');
ok($zip->set_number('9430316')->is_valid_number, '新潟県上越市三和区井ノ口');
ok($zip->set_number('9430317')->is_valid_number, '新潟県上越市三和区浮島');
ok($zip->set_number('9430318')->is_valid_number, '新潟県上越市三和区宮崎新田');
ok($zip->set_number('9430411')->is_valid_number, '新潟県上越市妙油');
ok($zip->set_number('9430412')->is_valid_number, '新潟県上越市北方');
ok($zip->set_number('9430413')->is_valid_number, '新潟県上越市南方');
ok($zip->set_number('9430414')->is_valid_number, '新潟県上越市大口');
ok($zip->set_number('9430415')->is_valid_number, '新潟県上越市東京田');
ok($zip->set_number('9430416')->is_valid_number, '新潟県上越市十二ノ木');
ok($zip->set_number('9430417')->is_valid_number, '新潟県上越市森田');
ok($zip->set_number('9430421')->is_valid_number, '新潟県上越市高和町');
ok($zip->set_number('9430422')->is_valid_number, '新潟県上越市飯田');
ok($zip->set_number('9430423')->is_valid_number, '新潟県上越市高津');
ok($zip->set_number('9430424')->is_valid_number, '新潟県上越市上曾根');
ok($zip->set_number('9430425')->is_valid_number, '新潟県上越市稲谷');
ok($zip->set_number('9430426')->is_valid_number, '新潟県上越市下曾根');
ok($zip->set_number('9430427')->is_valid_number, '新潟県上越市元屋敷');
ok($zip->set_number('9430501')->is_valid_number, '新潟県上越市清里区岡野町');
ok($zip->set_number('9430502')->is_valid_number, '新潟県上越市清里区荒牧');
ok($zip->set_number('9430503')->is_valid_number, '新潟県上越市清里区上深沢');
ok($zip->set_number('9430504')->is_valid_number, '新潟県上越市清里区上田島');
ok($zip->set_number('9430505')->is_valid_number, '新潟県上越市清里区東福島');
ok($zip->set_number('9430506')->is_valid_number, '新潟県上越市清里区菅原');
ok($zip->set_number('9430507')->is_valid_number, '新潟県上越市清里区岡嶺新田');
ok($zip->set_number('9430508')->is_valid_number, '新潟県上越市清里区平成');
ok($zip->set_number('9430509')->is_valid_number, '新潟県上越市清里区弥生');
ok($zip->set_number('9430510')->is_valid_number, '新潟県上越市清里区みらい');
ok($zip->set_number('9430511')->is_valid_number, '新潟県上越市清里区塩曽根');
ok($zip->set_number('9430512')->is_valid_number, '新潟県上越市清里区馬屋');
ok($zip->set_number('9430513')->is_valid_number, '新潟県上越市清里区今曽根');
ok($zip->set_number('9430514')->is_valid_number, '新潟県上越市清里区南田中');
ok($zip->set_number('9430515')->is_valid_number, '新潟県上越市清里区武士');
ok($zip->set_number('9430516')->is_valid_number, '新潟県上越市清里区上稲塚');
ok($zip->set_number('9430521')->is_valid_number, '新潟県上越市清里区寺脇');
ok($zip->set_number('9430522')->is_valid_number, '新潟県上越市清里区東戸野');
ok($zip->set_number('9430523')->is_valid_number, '新潟県上越市清里区棚田');
ok($zip->set_number('9430524')->is_valid_number, '新潟県上越市清里区水草');
ok($zip->set_number('9430525')->is_valid_number, '新潟県上越市清里区北野');
ok($zip->set_number('9430526')->is_valid_number, '新潟県上越市清里区梨平');
ok($zip->set_number('9430527')->is_valid_number, '新潟県上越市清里区赤池');
ok($zip->set_number('9430531')->is_valid_number, '新潟県上越市清里区青柳');
ok($zip->set_number('9430532')->is_valid_number, '新潟県上越市清里区梨窪');
ok($zip->set_number('9430533')->is_valid_number, '新潟県上越市清里区鶯沢');
ok($zip->set_number('9430534')->is_valid_number, '新潟県上越市清里区上中条');
ok($zip->set_number('9430535')->is_valid_number, '新潟県上越市清里区鈴倉');
ok($zip->set_number('9430601')->is_valid_number, '新潟県上越市牧区坪山');
ok($zip->set_number('9430602')->is_valid_number, '新潟県上越市牧区平方');
ok($zip->set_number('9430603')->is_valid_number, '新潟県上越市牧区平山');
ok($zip->set_number('9430604')->is_valid_number, '新潟県上越市牧区七森');
ok($zip->set_number('9430605')->is_valid_number, '新潟県上越市牧区神谷');
ok($zip->set_number('9430606')->is_valid_number, '新潟県上越市牧区大月');
ok($zip->set_number('9430607')->is_valid_number, '新潟県上越市牧区川井沢');
ok($zip->set_number('9430611')->is_valid_number, '新潟県上越市牧区片町');
ok($zip->set_number('9430612')->is_valid_number, '新潟県上越市牧区吉坪');
ok($zip->set_number('9430613')->is_valid_number, '新潟県上越市牧区高谷');
ok($zip->set_number('9430614')->is_valid_number, '新潟県上越市牧区切光');
ok($zip->set_number('9430615')->is_valid_number, '新潟県上越市牧区今清水');
ok($zip->set_number('9430616')->is_valid_number, '新潟県上越市牧区樫谷');
ok($zip->set_number('9430617')->is_valid_number, '新潟県上越市牧区泉');
ok($zip->set_number('9430621')->is_valid_number, '新潟県上越市牧区高尾');
ok($zip->set_number('9430622')->is_valid_number, '新潟県上越市牧区棚広新田');
ok($zip->set_number('9430623')->is_valid_number, '新潟県上越市牧区宇津俣');
ok($zip->set_number('9430624')->is_valid_number, '新潟県上越市牧区府殿');
ok($zip->set_number('9430625')->is_valid_number, '新潟県上越市牧区上牧');
ok($zip->set_number('9430626')->is_valid_number, '新潟県上越市牧区倉下');
ok($zip->set_number('9430627')->is_valid_number, '新潟県上越市牧区原');
ok($zip->set_number('9430628')->is_valid_number, '新潟県上越市牧区棚広');
ok($zip->set_number('9430631')->is_valid_number, '新潟県上越市牧区下湯谷');
ok($zip->set_number('9430632')->is_valid_number, '新潟県上越市牧区上昆子');
ok($zip->set_number('9430633')->is_valid_number, '新潟県上越市牧区下昆子');
ok($zip->set_number('9430634')->is_valid_number, '新潟県上越市牧区田島');
ok($zip->set_number('9430635')->is_valid_number, '新潟県上越市牧区岩神');
ok($zip->set_number('9430636')->is_valid_number, '新潟県上越市牧区国川');
ok($zip->set_number('9430637')->is_valid_number, '新潟県上越市牧区桜滝');
ok($zip->set_number('9430641')->is_valid_number, '新潟県上越市牧区東松ノ木');
ok($zip->set_number('9430642')->is_valid_number, '新潟県上越市牧区荒井');
ok($zip->set_number('9430643')->is_valid_number, '新潟県上越市牧区山口');
ok($zip->set_number('9430644')->is_valid_number, '新潟県上越市牧区宮口');
ok($zip->set_number('9430645')->is_valid_number, '新潟県上越市牧区池舟');
ok($zip->set_number('9430646')->is_valid_number, '新潟県上越市牧区落田');
ok($zip->set_number('9430647')->is_valid_number, '新潟県上越市牧区柳島');
ok($zip->set_number('9430648')->is_valid_number, '新潟県上越市牧区小川');
ok($zip->set_number('9430801')->is_valid_number, '新潟県上越市中門前');
ok($zip->set_number('9430802')->is_valid_number, '新潟県上越市大豆(その他)');
ok($zip->set_number('9430803')->is_valid_number, '新潟県上越市春日野');
ok($zip->set_number('9430804')->is_valid_number, '新潟県上越市新光町');
ok($zip->set_number('9430805')->is_valid_number, '新潟県上越市木田');
ok($zip->set_number('9430806')->is_valid_number, '新潟県上越市木田新田');
ok($zip->set_number('9430807')->is_valid_number, '新潟県上越市春日山町');
ok($zip->set_number('9430808')->is_valid_number, '新潟県上越市宮野尾');
ok($zip->set_number('9430809')->is_valid_number, '新潟県上越市春日');
ok($zip->set_number('9430810')->is_valid_number, '新潟県上越市大学前');
ok($zip->set_number('9430811')->is_valid_number, '新潟県上越市上正善寺');
ok($zip->set_number('9430812')->is_valid_number, '新潟県上越市中正善寺');
ok($zip->set_number('9430813')->is_valid_number, '新潟県上越市下正善寺');
ok($zip->set_number('9430814')->is_valid_number, '新潟県上越市岩木');
ok($zip->set_number('9430815')->is_valid_number, '新潟県上越市山屋敷町');
ok($zip->set_number('9430816')->is_valid_number, '新潟県上越市藤新田');
ok($zip->set_number('9430817')->is_valid_number, '新潟県上越市藤巻');
ok($zip->set_number('9430818')->is_valid_number, '新潟県上越市宇津尾');
ok($zip->set_number('9430819')->is_valid_number, '新潟県上越市中屋敷');
ok($zip->set_number('9430821')->is_valid_number, '新潟県上越市土橋');
ok($zip->set_number('9430822')->is_valid_number, '新潟県上越市新町');
ok($zip->set_number('9430823')->is_valid_number, '新潟県上越市高土町');
ok($zip->set_number('9430824')->is_valid_number, '新潟県上越市北城町');
ok($zip->set_number('9430825')->is_valid_number, '新潟県上越市東本町');
ok($zip->set_number('9430826')->is_valid_number, '新潟県上越市幸町');
ok($zip->set_number('9430827')->is_valid_number, '新潟県上越市栄町(その他)');
ok($zip->set_number('9430828')->is_valid_number, '新潟県上越市北本町');
ok($zip->set_number('9430829')->is_valid_number, '新潟県上越市薄袋');
ok($zip->set_number('9430831')->is_valid_number, '新潟県上越市仲町');
ok($zip->set_number('9430832')->is_valid_number, '新潟県上越市本町');
ok($zip->set_number('9430833')->is_valid_number, '新潟県上越市大町');
ok($zip->set_number('9430834')->is_valid_number, '新潟県上越市西城町');
ok($zip->set_number('9430835')->is_valid_number, '新潟県上越市本城町');
ok($zip->set_number('9430836')->is_valid_number, '新潟県上越市東城町');
ok($zip->set_number('9430837')->is_valid_number, '新潟県上越市南城町');
ok($zip->set_number('9430838')->is_valid_number, '新潟県上越市大手町');
ok($zip->set_number('9430839')->is_valid_number, '新潟県上越市上湯谷');
ok($zip->set_number('9430841')->is_valid_number, '新潟県上越市南本町');
ok($zip->set_number('9430842')->is_valid_number, '新潟県上越市五ケ所新田');
ok($zip->set_number('9430843')->is_valid_number, '新潟県上越市下新田');
ok($zip->set_number('9430844')->is_valid_number, '新潟県上越市丸山新田');
ok($zip->set_number('9430845')->is_valid_number, '新潟県上越市高田新田');
ok($zip->set_number('9430846')->is_valid_number, '新潟県上越市南高田町');
ok($zip->set_number('9430847')->is_valid_number, '新潟県上越市南新町');
ok($zip->set_number('9430848')->is_valid_number, '新潟県上越市儀明');
ok($zip->set_number('9430849')->is_valid_number, '新潟県上越市塩荷谷');
ok($zip->set_number('9430851')->is_valid_number, '新潟県上越市下箱井');
ok($zip->set_number('9430852')->is_valid_number, '新潟県上越市島田下新田');
ok($zip->set_number('9430853')->is_valid_number, '新潟県上越市島田');
ok($zip->set_number('9430854')->is_valid_number, '新潟県上越市島田上新田');
ok($zip->set_number('9430855')->is_valid_number, '新潟県上越市木島');
ok($zip->set_number('9430856')->is_valid_number, '新潟県上越市上箱井');
ok($zip->set_number('9430857')->is_valid_number, '新潟県上越市中箱井');
ok($zip->set_number('9430858')->is_valid_number, '新潟県上越市岡原');
ok($zip->set_number('9430859')->is_valid_number, '新潟県上越市寺町(番地)');
ok($zip->set_number('9430861')->is_valid_number, '新潟県上越市大和');
ok($zip->set_number('9430862')->is_valid_number, '新潟県上越市荒町');
ok($zip->set_number('9430863')->is_valid_number, '新潟県上越市脇野田');
ok($zip->set_number('9430864')->is_valid_number, '新潟県上越市今泉');
ok($zip->set_number('9430865')->is_valid_number, '新潟県上越市七ケ所新田');
ok($zip->set_number('9430866')->is_valid_number, '新潟県上越市土合');
ok($zip->set_number('9430871')->is_valid_number, '新潟県上越市青木');
ok($zip->set_number('9430872')->is_valid_number, '新潟県上越市石沢');
ok($zip->set_number('9430873')->is_valid_number, '新潟県上越市西田中');
ok($zip->set_number('9430874')->is_valid_number, '新潟県上越市稲荷');
ok($zip->set_number('9430875')->is_valid_number, '新潟県上越市地頭方');
ok($zip->set_number('9430876')->is_valid_number, '新潟県上越市上門前');
ok($zip->set_number('9430877')->is_valid_number, '新潟県上越市小滝');
ok($zip->set_number('9430878')->is_valid_number, '新潟県上越市下馬場');
ok($zip->set_number('9430881')->is_valid_number, '新潟県上越市京田');
ok($zip->set_number('9430882')->is_valid_number, '新潟県上越市中田原');
ok($zip->set_number('9430883')->is_valid_number, '新潟県上越市中通町');
ok($zip->set_number('9430884')->is_valid_number, '新潟県上越市上中田');
ok($zip->set_number('9430885')->is_valid_number, '新潟県上越市黒田');
ok($zip->set_number('9430886')->is_valid_number, '新潟県上越市朝日');
ok($zip->set_number('9430887')->is_valid_number, '新潟県上越市灰塚');
ok($zip->set_number('9430888')->is_valid_number, '新潟県上越市向橋');
ok($zip->set_number('9430889')->is_valid_number, '新潟県上越市後谷');
ok($zip->set_number('9430891')->is_valid_number, '新潟県上越市昭和町');
ok($zip->set_number('9430892')->is_valid_number, '新潟県上越市寺町(丁目)');
ok($zip->set_number('9430893')->is_valid_number, '新潟県上越市大貫');
ok($zip->set_number('9430894')->is_valid_number, '新潟県上越市上昭和町');
ok($zip->set_number('9430895')->is_valid_number, '新潟県上越市御殿山町');
ok($zip->set_number('9430896')->is_valid_number, '新潟県上越市飯');
ok($zip->set_number('9430897')->is_valid_number, '新潟県上越市滝寺');
ok($zip->set_number('9430898')->is_valid_number, '新潟県上越市塚田新田');
ok($zip->set_number('9430899')->is_valid_number, '新潟県上越市下中田');
ok($zip->set_number('9440000')->is_valid_number, '新潟県妙高市以下に掲載がない場合');
ok($zip->set_number('9440001')->is_valid_number, '新潟県妙高市上百々');
ok($zip->set_number('9440002')->is_valid_number, '新潟県妙高市広島');
ok($zip->set_number('9440003')->is_valid_number, '新潟県妙高市月岡');
ok($zip->set_number('9440004')->is_valid_number, '新潟県妙高市国賀');
ok($zip->set_number('9440005')->is_valid_number, '新潟県妙高市新栄町');
ok($zip->set_number('9440005')->is_valid_number, '新潟県妙高市中川');
ok($zip->set_number('9440006')->is_valid_number, '新潟県妙高市稲塚');
ok($zip->set_number('9440006')->is_valid_number, '新潟県妙高市大崎町');
ok($zip->set_number('9440007')->is_valid_number, '新潟県妙高市栗原');
ok($zip->set_number('9440008')->is_valid_number, '新潟県妙高市柳井田町');
ok($zip->set_number('9440009')->is_valid_number, '新潟県妙高市東陽町');
ok($zip->set_number('9440011')->is_valid_number, '新潟県妙高市石塚町');
ok($zip->set_number('9440013')->is_valid_number, '新潟県妙高市高柳');
ok($zip->set_number('9440014')->is_valid_number, '新潟県妙高市関川町');
ok($zip->set_number('9440016')->is_valid_number, '新潟県妙高市美守');
ok($zip->set_number('9440017')->is_valid_number, '新潟県妙高市中央町');
ok($zip->set_number('9440018')->is_valid_number, '新潟県妙高市諏訪町');
ok($zip->set_number('9440019')->is_valid_number, '新潟県妙高市新工町');
ok($zip->set_number('9440020')->is_valid_number, '新潟県妙高市工団町');
ok($zip->set_number('9440021')->is_valid_number, '新潟県妙高市北条');
ok($zip->set_number('9440022')->is_valid_number, '新潟県妙高市吉木');
ok($zip->set_number('9440023')->is_valid_number, '新潟県妙高市西条');
ok($zip->set_number('9440024')->is_valid_number, '新潟県妙高市吉木新田');
ok($zip->set_number('9440025')->is_valid_number, '新潟県妙高市上新保');
ok($zip->set_number('9440026')->is_valid_number, '新潟県妙高市川上');
ok($zip->set_number('9440027')->is_valid_number, '新潟県妙高市中宿');
ok($zip->set_number('9440028')->is_valid_number, '新潟県妙高市姫川原(その他)');
ok($zip->set_number('9440031')->is_valid_number, '新潟県妙高市田町');
ok($zip->set_number('9440032')->is_valid_number, '新潟県妙高市小出雲');
ok($zip->set_number('9440033')->is_valid_number, '新潟県妙高市広田町');
ok($zip->set_number('9440034')->is_valid_number, '新潟県妙高市経塚町');
ok($zip->set_number('9440035')->is_valid_number, '新潟県妙高市渋江町');
ok($zip->set_number('9440036')->is_valid_number, '新潟県妙高市末広町');
ok($zip->set_number('9440037')->is_valid_number, '新潟県妙高市学校町');
ok($zip->set_number('9440041')->is_valid_number, '新潟県妙高市新井');
ok($zip->set_number('9440042')->is_valid_number, '新潟県妙高市東雲町');
ok($zip->set_number('9440043')->is_valid_number, '新潟県妙高市朝日町');
ok($zip->set_number('9440044')->is_valid_number, '新潟県妙高市栄町');
ok($zip->set_number('9440045')->is_valid_number, '新潟県妙高市中町');
ok($zip->set_number('9440046')->is_valid_number, '新潟県妙高市上町');
ok($zip->set_number('9440047')->is_valid_number, '新潟県妙高市白山町');
ok($zip->set_number('9440048')->is_valid_number, '新潟県妙高市下町');
ok($zip->set_number('9440051')->is_valid_number, '新潟県妙高市錦町');
ok($zip->set_number('9440052')->is_valid_number, '新潟県妙高市上中');
ok($zip->set_number('9440053')->is_valid_number, '新潟県妙高市三本木新田');
ok($zip->set_number('9440054')->is_valid_number, '新潟県妙高市新井新田');
ok($zip->set_number('9440055')->is_valid_number, '新潟県妙高市東志');
ok($zip->set_number('9440056')->is_valid_number, '新潟県妙高市志');
ok($zip->set_number('9440057')->is_valid_number, '新潟県妙高市菅沼');
ok($zip->set_number('9440058')->is_valid_number, '新潟県妙高市西菅沼新田');
ok($zip->set_number('9440061')->is_valid_number, '新潟県妙高市窪松原');
ok($zip->set_number('9440062')->is_valid_number, '新潟県妙高市両善寺');
ok($zip->set_number('9440063')->is_valid_number, '新潟県妙高市西野谷新田');
ok($zip->set_number('9440064')->is_valid_number, '新潟県妙高市西野谷');
ok($zip->set_number('9440071')->is_valid_number, '新潟県妙高市藤塚新田');
ok($zip->set_number('9440072')->is_valid_number, '新潟県妙高市小丸山新田');
ok($zip->set_number('9440073')->is_valid_number, '新潟県妙高市長森');
ok($zip->set_number('9440074')->is_valid_number, '新潟県妙高市三ツ俣');
ok($zip->set_number('9440075')->is_valid_number, '新潟県妙高市猪野山');
ok($zip->set_number('9440076')->is_valid_number, '新潟県妙高市土田');
ok($zip->set_number('9440077')->is_valid_number, '新潟県妙高市梨木');
ok($zip->set_number('9440081')->is_valid_number, '新潟県妙高市籠町');
ok($zip->set_number('9440082')->is_valid_number, '新潟県妙高市乙吉');
ok($zip->set_number('9440083')->is_valid_number, '新潟県妙高市上四ツ屋');
ok($zip->set_number('9440084')->is_valid_number, '新潟県妙高市五日市');
ok($zip->set_number('9440085')->is_valid_number, '新潟県妙高市谷内林新田');
ok($zip->set_number('9440086')->is_valid_number, '新潟県妙高市坂井新田');
ok($zip->set_number('9440087')->is_valid_number, '新潟県妙高市新保新田');
ok($zip->set_number('9440088')->is_valid_number, '新潟県妙高市上八幡新田');
ok($zip->set_number('9440091')->is_valid_number, '新潟県妙高市青田');
ok($zip->set_number('9440092')->is_valid_number, '新潟県妙高市飛田');
ok($zip->set_number('9440093')->is_valid_number, '新潟県妙高市飛田新田');
ok($zip->set_number('9440094')->is_valid_number, '新潟県妙高市岡崎新田');
ok($zip->set_number('9440095')->is_valid_number, '新潟県妙高市十日市');
ok($zip->set_number('9440096')->is_valid_number, '新潟県妙高市神宮寺');
ok($zip->set_number('9440097')->is_valid_number, '新潟県妙高市宮内');
ok($zip->set_number('9440098')->is_valid_number, '新潟県妙高市雪森');
ok($zip->set_number('9440101')->is_valid_number, '新潟県上越市板倉区稲増');
ok($zip->set_number('9440102')->is_valid_number, '新潟県上越市板倉区上福田新田');
ok($zip->set_number('9440103')->is_valid_number, '新潟県上越市板倉区南四ツ屋新田');
ok($zip->set_number('9440104')->is_valid_number, '新潟県上越市板倉区長塚');
ok($zip->set_number('9440105')->is_valid_number, '新潟県上越市板倉区田屋');
ok($zip->set_number('9440106')->is_valid_number, '新潟県上越市板倉区沢田');
ok($zip->set_number('9440107')->is_valid_number, '新潟県上越市板倉区坂井');
ok($zip->set_number('9440108')->is_valid_number, '新潟県上越市板倉区長嶺');
ok($zip->set_number('9440109')->is_valid_number, '新潟県上越市板倉区戸狩');
ok($zip->set_number('9440111')->is_valid_number, '新潟県上越市板倉区宮島');
ok($zip->set_number('9440112')->is_valid_number, '新潟県上越市板倉区中四ツ屋');
ok($zip->set_number('9440113')->is_valid_number, '新潟県上越市板倉区別所');
ok($zip->set_number('9440114')->is_valid_number, '新潟県上越市板倉区達野');
ok($zip->set_number('9440115')->is_valid_number, '新潟県上越市板倉区玄藤寺新田');
ok($zip->set_number('9440116')->is_valid_number, '新潟県上越市板倉区関田');
ok($zip->set_number('9440117')->is_valid_number, '新潟県上越市板倉区筒方');
ok($zip->set_number('9440118')->is_valid_number, '新潟県上越市板倉区栗沢');
ok($zip->set_number('9440119')->is_valid_number, '新潟県上越市板倉区大野新田');
ok($zip->set_number('9440121')->is_valid_number, '新潟県上越市板倉区山部');
ok($zip->set_number('9440122')->is_valid_number, '新潟県上越市板倉区中之宮');
ok($zip->set_number('9440123')->is_valid_number, '新潟県上越市板倉区釜塚');
ok($zip->set_number('9440124')->is_valid_number, '新潟県上越市板倉区久々野');
ok($zip->set_number('9440125')->is_valid_number, '新潟県上越市板倉区猿供養寺');
ok($zip->set_number('9440126')->is_valid_number, '新潟県上越市板倉区東山寺');
ok($zip->set_number('9440127')->is_valid_number, '新潟県上越市板倉区不動新田');
ok($zip->set_number('9440128')->is_valid_number, '新潟県上越市板倉区機織');
ok($zip->set_number('9440129')->is_valid_number, '新潟県上越市板倉区菰立');
ok($zip->set_number('9440131')->is_valid_number, '新潟県上越市板倉区針');
ok($zip->set_number('9440132')->is_valid_number, '新潟県上越市板倉区曽根田');
ok($zip->set_number('9440133')->is_valid_number, '新潟県上越市板倉区国川');
ok($zip->set_number('9440134')->is_valid_number, '新潟県上越市板倉区福王寺');
ok($zip->set_number('9440135')->is_valid_number, '新潟県上越市板倉区米増');
ok($zip->set_number('9440136')->is_valid_number, '新潟県上越市板倉区山越');
ok($zip->set_number('9440137')->is_valid_number, '新潟県上越市板倉区吉増');
ok($zip->set_number('9440138')->is_valid_number, '新潟県上越市板倉区熊川新田');
ok($zip->set_number('9440139')->is_valid_number, '新潟県上越市板倉区熊川');
ok($zip->set_number('9440141')->is_valid_number, '新潟県上越市板倉区田井');
ok($zip->set_number('9440142')->is_valid_number, '新潟県上越市板倉区高野');
ok($zip->set_number('9440143')->is_valid_number, '新潟県上越市板倉区関根');
ok($zip->set_number('9440144')->is_valid_number, '新潟県上越市板倉区下米沢');
ok($zip->set_number('9440145')->is_valid_number, '新潟県上越市板倉区南中島');
ok($zip->set_number('9440146')->is_valid_number, '新潟県上越市板倉区小石原');
ok($zip->set_number('9440147')->is_valid_number, '新潟県上越市板倉区上中島新田');
ok($zip->set_number('9440148')->is_valid_number, '新潟県上越市板倉区横町');
ok($zip->set_number('9440149')->is_valid_number, '新潟県上越市板倉区下田屋');
ok($zip->set_number('9440150')->is_valid_number, '新潟県上越市板倉区青葉');
ok($zip->set_number('9440151')->is_valid_number, '新潟県上越市板倉区緑ケ丘');
ok($zip->set_number('9440201')->is_valid_number, '新潟県妙高市姫川原(3838~3985番地)');
ok($zip->set_number('9440202')->is_valid_number, '新潟県妙高市巻淵');
ok($zip->set_number('9440203')->is_valid_number, '新潟県妙高市下濁川');
ok($zip->set_number('9440204')->is_valid_number, '新潟県妙高市除戸');
ok($zip->set_number('9440205')->is_valid_number, '新潟県妙高市上堀之内');
ok($zip->set_number('9440211')->is_valid_number, '新潟県妙高市和屋');
ok($zip->set_number('9440212')->is_valid_number, '新潟県妙高市上濁川');
ok($zip->set_number('9440213')->is_valid_number, '新潟県妙高市小局');
ok($zip->set_number('9440214')->is_valid_number, '新潟県妙高市東菅沼');
ok($zip->set_number('9440215')->is_valid_number, '新潟県妙高市大貝');
ok($zip->set_number('9440216')->is_valid_number, '新潟県妙高市大下');
ok($zip->set_number('9440217')->is_valid_number, '新潟県妙高市中横山');
ok($zip->set_number('9440221')->is_valid_number, '新潟県妙高市小濁');
ok($zip->set_number('9440222')->is_valid_number, '新潟県妙高市坪山');
ok($zip->set_number('9440223')->is_valid_number, '新潟県妙高市上小沢');
ok($zip->set_number('9440224')->is_valid_number, '新潟県妙高市大濁');
ok($zip->set_number('9440225')->is_valid_number, '新潟県妙高市上馬場');
ok($zip->set_number('9440226')->is_valid_number, '新潟県妙高市木成');
ok($zip->set_number('9440331')->is_valid_number, '新潟県妙高市小原新田');
ok($zip->set_number('9440332')->is_valid_number, '新潟県妙高市大原新田');
ok($zip->set_number('9440333')->is_valid_number, '新潟県妙高市大沢新田');
ok($zip->set_number('9440334')->is_valid_number, '新潟県妙高市楡島');
ok($zip->set_number('9440335')->is_valid_number, '新潟県妙高市東関');
ok($zip->set_number('9440341')->is_valid_number, '新潟県妙高市猿橋');
ok($zip->set_number('9440342')->is_valid_number, '新潟県妙高市長沢原');
ok($zip->set_number('9440343')->is_valid_number, '新潟県妙高市下平丸');
ok($zip->set_number('9440344')->is_valid_number, '新潟県妙高市上平丸');
ok($zip->set_number('9440345')->is_valid_number, '新潟県妙高市長沢');
ok($zip->set_number('9450000')->is_valid_number, '新潟県柏崎市以下に掲載がない場合');
ok($zip->set_number('9450011')->is_valid_number, '新潟県柏崎市松波');
ok($zip->set_number('9450012')->is_valid_number, '新潟県柏崎市橋場');
ok($zip->set_number('9450013')->is_valid_number, '新潟県柏崎市山本');
ok($zip->set_number('9450014')->is_valid_number, '新潟県柏崎市橋場町');
ok($zip->set_number('9450015')->is_valid_number, '新潟県柏崎市槇原町');
ok($zip->set_number('9450016')->is_valid_number, '新潟県柏崎市青山町');
ok($zip->set_number('9450017')->is_valid_number, '新潟県柏崎市荒浜');
ok($zip->set_number('9450021')->is_valid_number, '新潟県柏崎市上原');
ok($zip->set_number('9450022')->is_valid_number, '新潟県柏崎市東原町');
ok($zip->set_number('9450023')->is_valid_number, '新潟県柏崎市原町');
ok($zip->set_number('9450024')->is_valid_number, '新潟県柏崎市小金町');
ok($zip->set_number('9450025')->is_valid_number, '新潟県柏崎市柳田町');
ok($zip->set_number('9450026')->is_valid_number, '新潟県柏崎市藤元町');
ok($zip->set_number('9450027')->is_valid_number, '新潟県柏崎市北斗町');
ok($zip->set_number('9450031')->is_valid_number, '新潟県柏崎市新田畑');
ok($zip->set_number('9450032')->is_valid_number, '新潟県柏崎市田塚');
ok($zip->set_number('9450033')->is_valid_number, '新潟県柏崎市東長浜町');
ok($zip->set_number('9450034')->is_valid_number, '新潟県柏崎市三和町');
ok($zip->set_number('9450035')->is_valid_number, '新潟県柏崎市北半田');
ok($zip->set_number('9450036')->is_valid_number, '新潟県柏崎市東柳田');
ok($zip->set_number('9450041')->is_valid_number, '新潟県柏崎市松美');
ok($zip->set_number('9450042')->is_valid_number, '新潟県柏崎市長浜町');
ok($zip->set_number('9450043')->is_valid_number, '新潟県柏崎市日吉町');
ok($zip->set_number('9450044')->is_valid_number, '新潟県柏崎市扇町');
ok($zip->set_number('9450045')->is_valid_number, '新潟県柏崎市豊町');
ok($zip->set_number('9450046')->is_valid_number, '新潟県柏崎市四谷');
ok($zip->set_number('9450047')->is_valid_number, '新潟県柏崎市比角');
ok($zip->set_number('9450051')->is_valid_number, '新潟県柏崎市東本町');
ok($zip->set_number('9450052')->is_valid_number, '新潟県柏崎市錦町');
ok($zip->set_number('9450053')->is_valid_number, '新潟県柏崎市鏡町');
ok($zip->set_number('9450054')->is_valid_number, '新潟県柏崎市日石町');
ok($zip->set_number('9450055')->is_valid_number, '新潟県柏崎市駅前');
ok($zip->set_number('9450056')->is_valid_number, '新潟県柏崎市新橋');
ok($zip->set_number('9450061')->is_valid_number, '新潟県柏崎市栄町');
ok($zip->set_number('9450062')->is_valid_number, '新潟県柏崎市新花町');
ok($zip->set_number('9450063')->is_valid_number, '新潟県柏崎市諏訪町');
ok($zip->set_number('9450064')->is_valid_number, '新潟県柏崎市中央町');
ok($zip->set_number('9450065')->is_valid_number, '新潟県柏崎市学校町');
ok($zip->set_number('9450066')->is_valid_number, '新潟県柏崎市西本町');
ok($zip->set_number('9450067')->is_valid_number, '新潟県柏崎市西港町');
ok($zip->set_number('9450068')->is_valid_number, '新潟県柏崎市東港町');
ok($zip->set_number('9450071')->is_valid_number, '新潟県柏崎市安政町');
ok($zip->set_number('9450072')->is_valid_number, '新潟県柏崎市北園町');
ok($zip->set_number('9450073')->is_valid_number, '新潟県柏崎市桜木町');
ok($zip->set_number('9450074')->is_valid_number, '新潟県柏崎市春日');
ok($zip->set_number('9450075')->is_valid_number, '新潟県柏崎市大和町');
ok($zip->set_number('9450076')->is_valid_number, '新潟県柏崎市小倉町');
ok($zip->set_number('9450101')->is_valid_number, '新潟県柏崎市長崎');
ok($zip->set_number('9450102')->is_valid_number, '新潟県柏崎市長崎新田');
ok($zip->set_number('9450103')->is_valid_number, '新潟県柏崎市下大新田');
ok($zip->set_number('9450104')->is_valid_number, '新潟県柏崎市土合新田');
ok($zip->set_number('9450105')->is_valid_number, '新潟県柏崎市剣');
ok($zip->set_number('9450106')->is_valid_number, '新潟県柏崎市土合');
ok($zip->set_number('9450111')->is_valid_number, '新潟県柏崎市与三');
ok($zip->set_number('9450112')->is_valid_number, '新潟県柏崎市畔屋');
ok($zip->set_number('9450113')->is_valid_number, '新潟県柏崎市中田');
ok($zip->set_number('9450114')->is_valid_number, '新潟県柏崎市藤井');
ok($zip->set_number('9450211')->is_valid_number, '新潟県柏崎市小黒須');
ok($zip->set_number('9450212')->is_valid_number, '新潟県柏崎市五十土');
ok($zip->set_number('9450213')->is_valid_number, '新潟県柏崎市成沢');
ok($zip->set_number('9450214')->is_valid_number, '新潟県柏崎市曽地');
ok($zip->set_number('9450215')->is_valid_number, '新潟県柏崎市矢田');
ok($zip->set_number('9450216')->is_valid_number, '新潟県柏崎市吉井');
ok($zip->set_number('9450217')->is_valid_number, '新潟県柏崎市曽地新田');
ok($zip->set_number('9450218')->is_valid_number, '新潟県柏崎市花田');
ok($zip->set_number('9450219')->is_valid_number, '新潟県柏崎市飯塚');
ok($zip->set_number('9450300')->is_valid_number, '新潟県刈羽郡刈羽村以下に掲載がない場合');
ok($zip->set_number('9450301')->is_valid_number, '新潟県刈羽郡刈羽村入和田');
ok($zip->set_number('9450302')->is_valid_number, '新潟県刈羽郡刈羽村滝谷新田');
ok($zip->set_number('9450303')->is_valid_number, '新潟県刈羽郡刈羽村滝谷');
ok($zip->set_number('9450304')->is_valid_number, '新潟県刈羽郡刈羽村寺尾');
ok($zip->set_number('9450305')->is_valid_number, '新潟県刈羽郡刈羽村西元寺');
ok($zip->set_number('9450306')->is_valid_number, '新潟県刈羽郡刈羽村十日市');
ok($zip->set_number('9450307')->is_valid_number, '新潟県刈羽郡刈羽村刈羽');
ok($zip->set_number('9450308')->is_valid_number, '新潟県刈羽郡刈羽村割町新田');
ok($zip->set_number('9450311')->is_valid_number, '新潟県刈羽郡刈羽村井岡');
ok($zip->set_number('9450312')->is_valid_number, '新潟県刈羽郡刈羽村西谷');
ok($zip->set_number('9450313')->is_valid_number, '新潟県刈羽郡刈羽村大塚');
ok($zip->set_number('9450314')->is_valid_number, '新潟県刈羽郡刈羽村新屋敷');
ok($zip->set_number('9450315')->is_valid_number, '新潟県刈羽郡刈羽村上高町');
ok($zip->set_number('9450316')->is_valid_number, '新潟県刈羽郡刈羽村下高町');
ok($zip->set_number('9450317')->is_valid_number, '新潟県刈羽郡刈羽村正明寺');
ok($zip->set_number('9450321')->is_valid_number, '新潟県刈羽郡刈羽村油田');
ok($zip->set_number('9450322')->is_valid_number, '新潟県刈羽郡刈羽村黒川');
ok($zip->set_number('9450323')->is_valid_number, '新潟県刈羽郡刈羽村赤田町方');
ok($zip->set_number('9450324')->is_valid_number, '新潟県刈羽郡刈羽村枯木');
ok($zip->set_number('9450325')->is_valid_number, '新潟県刈羽郡刈羽村赤田北方');
ok($zip->set_number('9450401')->is_valid_number, '新潟県柏崎市椎谷');
ok($zip->set_number('9450402')->is_valid_number, '新潟県柏崎市宮川');
ok($zip->set_number('9450403')->is_valid_number, '新潟県柏崎市大湊');
ok($zip->set_number('9450811')->is_valid_number, '新潟県柏崎市岩上');
ok($zip->set_number('9450812')->is_valid_number, '新潟県柏崎市半田');
ok($zip->set_number('9450813')->is_valid_number, '新潟県柏崎市南半田');
ok($zip->set_number('9450814')->is_valid_number, '新潟県柏崎市朝日が丘');
ok($zip->set_number('9450815')->is_valid_number, '新潟県柏崎市希望が丘');
ok($zip->set_number('9450816')->is_valid_number, '新潟県柏崎市田中');
ok($zip->set_number('9450817')->is_valid_number, '新潟県柏崎市宝町');
ok($zip->set_number('9450821')->is_valid_number, '新潟県柏崎市幸町');
ok($zip->set_number('9450822')->is_valid_number, '新潟県柏崎市穂波町');
ok($zip->set_number('9450823')->is_valid_number, '新潟県柏崎市南光町');
ok($zip->set_number('9450824')->is_valid_number, '新潟県柏崎市枇杷島');
ok($zip->set_number('9450825')->is_valid_number, '新潟県柏崎市城東');
ok($zip->set_number('9450826')->is_valid_number, '新潟県柏崎市元城町');
ok($zip->set_number('9450827')->is_valid_number, '新潟県柏崎市宮場町');
ok($zip->set_number('9450831')->is_valid_number, '新潟県柏崎市柳橋町');
ok($zip->set_number('9450832')->is_valid_number, '新潟県柏崎市関町');
ok($zip->set_number('9450833')->is_valid_number, '新潟県柏崎市若葉町');
ok($zip->set_number('9450834')->is_valid_number, '新潟県柏崎市常盤台');
ok($zip->set_number('9450835')->is_valid_number, '新潟県柏崎市剣野町');
ok($zip->set_number('9450836')->is_valid_number, '新潟県柏崎市剣野');
ok($zip->set_number('9450837')->is_valid_number, '新潟県柏崎市三島町');
ok($zip->set_number('9450838')->is_valid_number, '新潟県柏崎市三島西');
ok($zip->set_number('9450841')->is_valid_number, '新潟県柏崎市緑町');
ok($zip->set_number('9450842')->is_valid_number, '新潟県柏崎市米山台');
ok($zip->set_number('9450843')->is_valid_number, '新潟県柏崎市米山台東');
ok($zip->set_number('9450844')->is_valid_number, '新潟県柏崎市米山台西');
ok($zip->set_number('9450845')->is_valid_number, '新潟県柏崎市新赤坂');
ok($zip->set_number('9450846')->is_valid_number, '新潟県柏崎市寿町');
ok($zip->set_number('9450847')->is_valid_number, '新潟県柏崎市赤坂町');
ok($zip->set_number('9450851')->is_valid_number, '新潟県柏崎市大久保');
ok($zip->set_number('9450852')->is_valid_number, '新潟県柏崎市中浜');
ok($zip->set_number('9450853')->is_valid_number, '新潟県柏崎市番神');
ok($zip->set_number('9450854')->is_valid_number, '新潟県柏崎市東の輪町');
ok($zip->set_number('9450855')->is_valid_number, '新潟県柏崎市鯨波');
ok($zip->set_number('9450857')->is_valid_number, '新潟県柏崎市谷根');
ok($zip->set_number('9450858')->is_valid_number, '新潟県柏崎市小杉');
ok($zip->set_number('9451101')->is_valid_number, '新潟県柏崎市横山');
ok($zip->set_number('9451102')->is_valid_number, '新潟県柏崎市向陽町');
ok($zip->set_number('9451103')->is_valid_number, '新潟県柏崎市藤橋');
ok($zip->set_number('9451104')->is_valid_number, '新潟県柏崎市下方');
ok($zip->set_number('9451105')->is_valid_number, '新潟県柏崎市長峰町');
ok($zip->set_number('9451106')->is_valid_number, '新潟県柏崎市ゆりが丘');
ok($zip->set_number('9451111')->is_valid_number, '新潟県柏崎市堀');
ok($zip->set_number('9451112')->is_valid_number, '新潟県柏崎市南下');
ok($zip->set_number('9451113')->is_valid_number, '新潟県柏崎市古町');
ok($zip->set_number('9451114')->is_valid_number, '新潟県柏崎市芋川');
ok($zip->set_number('9451115')->is_valid_number, '新潟県柏崎市佐水');
ok($zip->set_number('9451116')->is_valid_number, '新潟県柏崎市山口');
ok($zip->set_number('9451117')->is_valid_number, '新潟県柏崎市宮之窪');
ok($zip->set_number('9451118')->is_valid_number, '新潟県柏崎市上条');
ok($zip->set_number('9451121')->is_valid_number, '新潟県柏崎市上方');
ok($zip->set_number('9451122')->is_valid_number, '新潟県柏崎市新道');
ok($zip->set_number('9451123')->is_valid_number, '新潟県柏崎市貝渕');
ok($zip->set_number('9451124')->is_valid_number, '新潟県柏崎市黒滝');
ok($zip->set_number('9451125')->is_valid_number, '新潟県柏崎市小田山新田');
ok($zip->set_number('9451126')->is_valid_number, '新潟県柏崎市大河内新田');
ok($zip->set_number('9451241')->is_valid_number, '新潟県柏崎市野田');
ok($zip->set_number('9451242')->is_valid_number, '新潟県柏崎市細越');
ok($zip->set_number('9451243')->is_valid_number, '新潟県柏崎市久米');
ok($zip->set_number('9451244')->is_valid_number, '新潟県柏崎市水上');
ok($zip->set_number('9451245')->is_valid_number, '新潟県柏崎市宮川新田');
ok($zip->set_number('9451246')->is_valid_number, '新潟県柏崎市清水谷');
ok($zip->set_number('9451247')->is_valid_number, '新潟県柏崎市木沢');
ok($zip->set_number('9451248')->is_valid_number, '新潟県柏崎市田屋');
ok($zip->set_number('9451251')->is_valid_number, '新潟県柏崎市市野新田');
ok($zip->set_number('9451252')->is_valid_number, '新潟県柏崎市女谷');
ok($zip->set_number('9451253')->is_valid_number, '新潟県柏崎市折居');
ok($zip->set_number('9451341')->is_valid_number, '新潟県柏崎市茨目');
ok($zip->set_number('9451343')->is_valid_number, '新潟県柏崎市城塚');
ok($zip->set_number('9451344')->is_valid_number, '新潟県柏崎市両田尻');
ok($zip->set_number('9451345')->is_valid_number, '新潟県柏崎市下田尻');
ok($zip->set_number('9451351')->is_valid_number, '新潟県柏崎市上田尻');
ok($zip->set_number('9451352')->is_valid_number, '新潟県柏崎市安田');
ok($zip->set_number('9451353')->is_valid_number, '新潟県柏崎市平井');
ok($zip->set_number('9451354')->is_valid_number, '新潟県柏崎市佐藤池新田');
ok($zip->set_number('9451355')->is_valid_number, '新潟県柏崎市軽井川');
ok($zip->set_number('9451431')->is_valid_number, '新潟県柏崎市加納');
ok($zip->set_number('9451432')->is_valid_number, '新潟県柏崎市善根');
ok($zip->set_number('9451433')->is_valid_number, '新潟県柏崎市与板');
ok($zip->set_number('9451434')->is_valid_number, '新潟県柏崎市宮平');
ok($zip->set_number('9451435')->is_valid_number, '新潟県柏崎市森近');
ok($zip->set_number('9451436')->is_valid_number, '新潟県柏崎市石曽根');
ok($zip->set_number('9451437')->is_valid_number, '新潟県柏崎市山室');
ok($zip->set_number('9451438')->is_valid_number, '新潟県柏崎市大沢');
ok($zip->set_number('9451501')->is_valid_number, '新潟県柏崎市高柳町岡田');
ok($zip->set_number('9451502')->is_valid_number, '新潟県柏崎市高柳町岡野町');
ok($zip->set_number('9451503')->is_valid_number, '新潟県柏崎市高柳町山中');
ok($zip->set_number('9451504')->is_valid_number, '新潟県柏崎市高柳町栃ケ原');
ok($zip->set_number('9451505')->is_valid_number, '新潟県柏崎市高柳町高尾');
ok($zip->set_number('9451511')->is_valid_number, '新潟県柏崎市高柳町漆島');
ok($zip->set_number('9451512')->is_valid_number, '新潟県柏崎市高柳町荻ノ島');
ok($zip->set_number('9451513')->is_valid_number, '新潟県柏崎市高柳町門出');
ok($zip->set_number('9451514')->is_valid_number, '新潟県柏崎市高柳町田代');
ok($zip->set_number('9451515')->is_valid_number, '新潟県柏崎市高柳町石黒');
ok($zip->set_number('9460000')->is_valid_number, '新潟県魚沼市以下に掲載がない場合');
ok($zip->set_number('9460001')->is_valid_number, '新潟県魚沼市日渡新田');
ok($zip->set_number('9460002')->is_valid_number, '新潟県魚沼市稲荷町');
ok($zip->set_number('9460003')->is_valid_number, '新潟県魚沼市諏訪町');
ok($zip->set_number('9460004')->is_valid_number, '新潟県魚沼市大塚新田');
ok($zip->set_number('9460005')->is_valid_number, '新潟県魚沼市横町');
ok($zip->set_number('9460006')->is_valid_number, '新潟県魚沼市中ノ島');
ok($zip->set_number('9460007')->is_valid_number, '新潟県魚沼市四日町');
ok($zip->set_number('9460011')->is_valid_number, '新潟県魚沼市小出島');
ok($zip->set_number('9460012')->is_valid_number, '新潟県魚沼市浦町');
ok($zip->set_number('9460021')->is_valid_number, '新潟県魚沼市佐梨');
ok($zip->set_number('9460022')->is_valid_number, '新潟県魚沼市上原');
ok($zip->set_number('9460023')->is_valid_number, '新潟県魚沼市干溝');
ok($zip->set_number('9460024')->is_valid_number, '新潟県魚沼市中原');
ok($zip->set_number('9460025')->is_valid_number, '新潟県魚沼市古新田');
ok($zip->set_number('9460031')->is_valid_number, '新潟県魚沼市原虫野');
ok($zip->set_number('9460032')->is_valid_number, '新潟県魚沼市板木');
ok($zip->set_number('9460033')->is_valid_number, '新潟県魚沼市大浦');
ok($zip->set_number('9460034')->is_valid_number, '新潟県魚沼市大浦新田');
ok($zip->set_number('9460035')->is_valid_number, '新潟県魚沼市十日町');
ok($zip->set_number('9460036')->is_valid_number, '新潟県魚沼市岡新田');
ok($zip->set_number('9460037')->is_valid_number, '新潟県魚沼市虫野');
ok($zip->set_number('9460038')->is_valid_number, '新潟県魚沼市伊勢島');
ok($zip->set_number('9460041')->is_valid_number, '新潟県魚沼市本町');
ok($zip->set_number('9460042')->is_valid_number, '新潟県魚沼市柳原');
ok($zip->set_number('9460043')->is_valid_number, '新潟県魚沼市青島');
ok($zip->set_number('9460051')->is_valid_number, '新潟県魚沼市今泉');
ok($zip->set_number('9460052')->is_valid_number, '新潟県魚沼市江口');
ok($zip->set_number('9460052')->is_valid_number, '新潟県魚沼市江口新田');
ok($zip->set_number('9460053')->is_valid_number, '新潟県魚沼市長松');
ok($zip->set_number('9460054')->is_valid_number, '新潟県魚沼市米沢');
ok($zip->set_number('9460055')->is_valid_number, '新潟県魚沼市山田');
ok($zip->set_number('9460056')->is_valid_number, '新潟県魚沼市山田下');
ok($zip->set_number('9460057')->is_valid_number, '新潟県魚沼市中島');
ok($zip->set_number('9460058')->is_valid_number, '新潟県魚沼市中島新田');
ok($zip->set_number('9460061')->is_valid_number, '新潟県魚沼市新保');
ok($zip->set_number('9460061')->is_valid_number, '新潟県魚沼市新保新田');
ok($zip->set_number('9460062')->is_valid_number, '新潟県魚沼市一日市');
ok($zip->set_number('9460063')->is_valid_number, '新潟県魚沼市中家');
ok($zip->set_number('9460063')->is_valid_number, '新潟県魚沼市中家新田');
ok($zip->set_number('9460064')->is_valid_number, '新潟県魚沼市池平');
ok($zip->set_number('9460064')->is_valid_number, '新潟県魚沼市池平新田');
ok($zip->set_number('9460065')->is_valid_number, '新潟県魚沼市中子沢');
ok($zip->set_number('9460066')->is_valid_number, '新潟県魚沼市三ツ又');
ok($zip->set_number('9460071')->is_valid_number, '新潟県魚沼市七日市');
ok($zip->set_number('9460072')->is_valid_number, '新潟県魚沼市七日市新田');
ok($zip->set_number('9460073')->is_valid_number, '新潟県魚沼市大沢');
ok($zip->set_number('9460075')->is_valid_number, '新潟県魚沼市吉田');
ok($zip->set_number('9460076')->is_valid_number, '新潟県魚沼市井口新田');
ok($zip->set_number('9460081')->is_valid_number, '新潟県魚沼市葎沢');
ok($zip->set_number('9460082')->is_valid_number, '新潟県魚沼市湯之谷芋川');
ok($zip->set_number('9460083')->is_valid_number, '新潟県魚沼市蓑和田');
ok($zip->set_number('9460084')->is_valid_number, '新潟県魚沼市宇津野');
ok($zip->set_number('9460085')->is_valid_number, '新潟県魚沼市下折立');
ok($zip->set_number('9460086')->is_valid_number, '新潟県魚沼市折立又新田');
ok($zip->set_number('9460087')->is_valid_number, '新潟県魚沼市上折立');
ok($zip->set_number('9460088')->is_valid_number, '新潟県魚沼市大湯温泉');
ok($zip->set_number('9460101')->is_valid_number, '新潟県魚沼市小平尾');
ok($zip->set_number('9460102')->is_valid_number, '新潟県魚沼市外山');
ok($zip->set_number('9460103')->is_valid_number, '新潟県魚沼市滝之又');
ok($zip->set_number('9460104')->is_valid_number, '新潟県魚沼市栗山');
ok($zip->set_number('9460105')->is_valid_number, '新潟県魚沼市金ケ沢');
ok($zip->set_number('9460105')->is_valid_number, '新潟県魚沼市宮沢新田');
ok($zip->set_number('9460106')->is_valid_number, '新潟県魚沼市田中');
ok($zip->set_number('9460107')->is_valid_number, '新潟県魚沼市雁坂下');
ok($zip->set_number('9460107')->is_valid_number, '新潟県魚沼市清本');
ok($zip->set_number('9460107')->is_valid_number, '新潟県魚沼市下田');
ok($zip->set_number('9460107')->is_valid_number, '新潟県魚沼市長堀新田');
ok($zip->set_number('9460107')->is_valid_number, '新潟県魚沼市横瀬');
ok($zip->set_number('9460108')->is_valid_number, '新潟県魚沼市親柄');
ok($zip->set_number('9460109')->is_valid_number, '新潟県魚沼市和田');
ok($zip->set_number('9460111')->is_valid_number, '新潟県魚沼市並柳');
ok($zip->set_number('9460112')->is_valid_number, '新潟県魚沼市田尻');
ok($zip->set_number('9460113')->is_valid_number, '新潟県魚沼市東中');
ok($zip->set_number('9460114')->is_valid_number, '新潟県魚沼市泉沢');
ok($zip->set_number('9460115')->is_valid_number, '新潟県魚沼市山口');
ok($zip->set_number('9460121')->is_valid_number, '新潟県魚沼市小庭名');
ok($zip->set_number('9460121')->is_valid_number, '新潟県魚沼市小庭名新田');
ok($zip->set_number('9460121')->is_valid_number, '新潟県魚沼市吉平');
ok($zip->set_number('9460121')->is_valid_number, '新潟県魚沼市連日');
ok($zip->set_number('9460122')->is_valid_number, '新潟県魚沼市吉原');
ok($zip->set_number('9460123')->is_valid_number, '新潟県魚沼市水沢');
ok($zip->set_number('9460123')->is_valid_number, '新潟県魚沼市茂沢');
ok($zip->set_number('9460124')->is_valid_number, '新潟県魚沼市大芋川');
ok($zip->set_number('9460125')->is_valid_number, '新潟県魚沼市越又');
ok($zip->set_number('9460201')->is_valid_number, '新潟県魚沼市高倉');
ok($zip->set_number('9460202')->is_valid_number, '新潟県魚沼市東野名');
ok($zip->set_number('9460203')->is_valid_number, '新潟県魚沼市渋川');
ok($zip->set_number('9460204')->is_valid_number, '新潟県魚沼市西名');
ok($zip->set_number('9460205')->is_valid_number, '新潟県魚沼市宮椿新田');
ok($zip->set_number('9460206')->is_valid_number, '新潟県魚沼市西名新田');
ok($zip->set_number('9460207')->is_valid_number, '新潟県魚沼市福山新田');
ok($zip->set_number('9460211')->is_valid_number, '新潟県魚沼市上長鳥新田');
ok($zip->set_number('9460212')->is_valid_number, '新潟県魚沼市長鳥');
ok($zip->set_number('9460213')->is_valid_number, '新潟県魚沼市細野');
ok($zip->set_number('9460214')->is_valid_number, '新潟県魚沼市松川');
ok($zip->set_number('9460215')->is_valid_number, '新潟県魚沼市大原新田');
ok($zip->set_number('9460216')->is_valid_number, '新潟県魚沼市須原');
ok($zip->set_number('9460221')->is_valid_number, '新潟県魚沼市須川');
ok($zip->set_number('9460222')->is_valid_number, '新潟県魚沼市福田新田');
ok($zip->set_number('9460223')->is_valid_number, '新潟県魚沼市大倉沢');
ok($zip->set_number('9460224')->is_valid_number, '新潟県魚沼市赤土');
ok($zip->set_number('9460225')->is_valid_number, '新潟県魚沼市三渕沢');
ok($zip->set_number('9460226')->is_valid_number, '新潟県魚沼市大倉');
ok($zip->set_number('9460301')->is_valid_number, '新潟県魚沼市田小屋');
ok($zip->set_number('9460302')->is_valid_number, '新潟県魚沼市芋鞘');
ok($zip->set_number('9460303')->is_valid_number, '新潟県魚沼市大白川');
ok($zip->set_number('9460304')->is_valid_number, '新潟県魚沼市穴沢');
ok($zip->set_number('9460305')->is_valid_number, '新潟県魚沼市大栃山');
ok($zip->set_number('9460306')->is_valid_number, '新潟県魚沼市平野又');
ok($zip->set_number('9460307')->is_valid_number, '新潟県魚沼市横根');
ok($zip->set_number('9470000')->is_valid_number, '新潟県小千谷市以下に掲載がない場合');
ok($zip->set_number('9470001')->is_valid_number, '新潟県小千谷市浦柄');
ok($zip->set_number('9470002')->is_valid_number, '新潟県小千谷市横渡');
ok($zip->set_number('9470003')->is_valid_number, '新潟県小千谷市ひ生');
ok($zip->set_number('9470004')->is_valid_number, '新潟県小千谷市東栄');
ok($zip->set_number('9470005')->is_valid_number, '新潟県小千谷市旭町');
ok($zip->set_number('9470011')->is_valid_number, '新潟県小千谷市栄町');
ok($zip->set_number('9470012')->is_valid_number, '新潟県小千谷市山本');
ok($zip->set_number('9470013')->is_valid_number, '新潟県小千谷市上片貝');
ok($zip->set_number('9470014')->is_valid_number, '新潟県小千谷市西中');
ok($zip->set_number('9470015')->is_valid_number, '新潟県小千谷市谷内');
ok($zip->set_number('9470016')->is_valid_number, '新潟県小千谷市四ツ子');
ok($zip->set_number('9470017')->is_valid_number, '新潟県小千谷市東吉谷');
ok($zip->set_number('9470018')->is_valid_number, '新潟県小千谷市西吉谷');
ok($zip->set_number('9470021')->is_valid_number, '新潟県小千谷市本町');
ok($zip->set_number('9470022')->is_valid_number, '新潟県小千谷市元町');
ok($zip->set_number('9470023')->is_valid_number, '新潟県小千谷市日吉');
ok($zip->set_number('9470024')->is_valid_number, '新潟県小千谷市船岡');
ok($zip->set_number('9470025')->is_valid_number, '新潟県小千谷市稲荷町');
ok($zip->set_number('9470026')->is_valid_number, '新潟県小千谷市上ノ山');
ok($zip->set_number('9470027')->is_valid_number, '新潟県小千谷市平成');
ok($zip->set_number('9470028')->is_valid_number, '新潟県小千谷市城内');
ok($zip->set_number('9470031')->is_valid_number, '新潟県小千谷市土川');
ok($zip->set_number('9470032')->is_valid_number, '新潟県小千谷市薮川');
ok($zip->set_number('9470033')->is_valid_number, '新潟県小千谷市時水');
ok($zip->set_number('9470034')->is_valid_number, '新潟県小千谷市両新田');
ok($zip->set_number('9470035')->is_valid_number, '新潟県小千谷市桜町');
ok($zip->set_number('9470041')->is_valid_number, '新潟県小千谷市小粟田');
ok($zip->set_number('9470042')->is_valid_number, '新潟県小千谷市平沢');
ok($zip->set_number('9470042')->is_valid_number, '新潟県小千谷市平沢新田');
ok($zip->set_number('9470043')->is_valid_number, '新潟県小千谷市山谷');
ok($zip->set_number('9470044')->is_valid_number, '新潟県小千谷市坪野');
ok($zip->set_number('9470045')->is_valid_number, '新潟県小千谷市鴻巣町');
ok($zip->set_number('9470051')->is_valid_number, '新潟県小千谷市三仏生');
ok($zip->set_number('9470052')->is_valid_number, '新潟県小千谷市千谷');
ok($zip->set_number('9470053')->is_valid_number, '新潟県小千谷市千谷川');
ok($zip->set_number('9470054')->is_valid_number, '新潟県小千谷市若葉');
ok($zip->set_number('9470101')->is_valid_number, '新潟県小千谷市片貝町');
ok($zip->set_number('9470102')->is_valid_number, '新潟県小千谷市高梨町');
ok($zip->set_number('9470103')->is_valid_number, '新潟県小千谷市片貝山屋町');
ok($zip->set_number('9470201')->is_valid_number, '新潟県長岡市山古志種苧原');
ok($zip->set_number('9470202')->is_valid_number, '新潟県長岡市山古志南平');
ok($zip->set_number('9470203')->is_valid_number, '新潟県長岡市山古志東竹沢');
ok($zip->set_number('9470204')->is_valid_number, '新潟県長岡市山古志竹沢');
ok($zip->set_number('9470205')->is_valid_number, '新潟県長岡市山古志虫亀');
ok($zip->set_number('9470211')->is_valid_number, '新潟県小千谷市小栗山');
ok($zip->set_number('9470212')->is_valid_number, '新潟県小千谷市南荷頃');
ok($zip->set_number('9470213')->is_valid_number, '新潟県小千谷市塩谷');
ok($zip->set_number('9480000')->is_valid_number, '新潟県十日町市以下に掲載がない場合');
ok($zip->set_number('9480001')->is_valid_number, '新潟県十日町市五軒新田');
ok($zip->set_number('9480002')->is_valid_number, '新潟県十日町市三和町');
ok($zip->set_number('9480003')->is_valid_number, '新潟県十日町市本町(7丁目)');
ok($zip->set_number('9480003')->is_valid_number, '新潟県十日町市本町六の一丁目');
ok($zip->set_number('9480003')->is_valid_number, '新潟県十日町市本町六の二丁目');
ok($zip->set_number('9480003')->is_valid_number, '新潟県十日町市本町六の三丁目');
ok($zip->set_number('9480004')->is_valid_number, '新潟県十日町市下川原町');
ok($zip->set_number('9480005')->is_valid_number, '新潟県十日町市南新田町');
ok($zip->set_number('9480006')->is_valid_number, '新潟県十日町市四日町');
ok($zip->set_number('9480007')->is_valid_number, '新潟県十日町市四日町新田');
ok($zip->set_number('9480008')->is_valid_number, '新潟県十日町市尾崎');
ok($zip->set_number('9480011')->is_valid_number, '新潟県十日町市新座(第3、4)');
ok($zip->set_number('9480012')->is_valid_number, '新潟県十日町市新座(第1、2)');
ok($zip->set_number('9480013')->is_valid_number, '新潟県十日町市川原町');
ok($zip->set_number('9480014')->is_valid_number, '新潟県十日町市江道');
ok($zip->set_number('9480015')->is_valid_number, '新潟県十日町市猿倉');
ok($zip->set_number('9480016')->is_valid_number, '新潟県十日町市津池');
ok($zip->set_number('9480017')->is_valid_number, '新潟県十日町市菅沼');
ok($zip->set_number('9480018')->is_valid_number, '新潟県十日町市大池');
ok($zip->set_number('9480019')->is_valid_number, '新潟県十日町市十日町赤倉');
ok($zip->set_number('9480021')->is_valid_number, '新潟県十日町市田川町');
ok($zip->set_number('9480022')->is_valid_number, '新潟県十日町市学校町');
ok($zip->set_number('9480023')->is_valid_number, '新潟県十日町市宮下町西');
ok($zip->set_number('9480023')->is_valid_number, '新潟県十日町市宮下町東');
ok($zip->set_number('9480024')->is_valid_number, '新潟県十日町市諏訪町');
ok($zip->set_number('9480025')->is_valid_number, '新潟県十日町市神明町');
ok($zip->set_number('9480026')->is_valid_number, '新潟県十日町市水野町');
ok($zip->set_number('9480027')->is_valid_number, '新潟県十日町市若宮町');
ok($zip->set_number('9480028')->is_valid_number, '新潟県十日町市田中町西');
ok($zip->set_number('9480028')->is_valid_number, '新潟県十日町市田中町東');
ok($zip->set_number('9480028')->is_valid_number, '新潟県十日町市田中町本通り');
ok($zip->set_number('9480029')->is_valid_number, '新潟県十日町市上川町');
ok($zip->set_number('9480031')->is_valid_number, '新潟県十日町市山本町');
ok($zip->set_number('9480032')->is_valid_number, '新潟県十日町市関根');
ok($zip->set_number('9480033')->is_valid_number, '新潟県十日町市八箇');
ok($zip->set_number('9480034')->is_valid_number, '新潟県十日町市二ツ屋');
ok($zip->set_number('9480035')->is_valid_number, '新潟県十日町市川治下町');
ok($zip->set_number('9480036')->is_valid_number, '新潟県十日町市川治');
ok($zip->set_number('9480037')->is_valid_number, '新潟県十日町市妻有町');
ok($zip->set_number('9480038')->is_valid_number, '新潟県十日町市河内町');
ok($zip->set_number('9480039')->is_valid_number, '新潟県十日町市塩ノ又');
ok($zip->set_number('9480041')->is_valid_number, '新潟県十日町市北新田');
ok($zip->set_number('9480042')->is_valid_number, '新潟県十日町市中村');
ok($zip->set_number('9480043')->is_valid_number, '新潟県十日町市六箇山谷');
ok($zip->set_number('9480044')->is_valid_number, '新潟県十日町市田麦');
ok($zip->set_number('9480045')->is_valid_number, '新潟県十日町市麻畑');
ok($zip->set_number('9480046')->is_valid_number, '新潟県十日町市明石町');
ok($zip->set_number('9480047')->is_valid_number, '新潟県十日町市城之古');
ok($zip->set_number('9480048')->is_valid_number, '新潟県十日町市谷内丑');
ok($zip->set_number('9480049')->is_valid_number, '新潟県十日町市船坂');
ok($zip->set_number('9480051')->is_valid_number, '新潟県十日町市寿町');
ok($zip->set_number('9480052')->is_valid_number, '新潟県十日町市美雪町');
ok($zip->set_number('9480053')->is_valid_number, '新潟県十日町市錦町');
ok($zip->set_number('9480054')->is_valid_number, '新潟県十日町市塚原町');
ok($zip->set_number('9480055')->is_valid_number, '新潟県十日町市高山');
ok($zip->set_number('9480056')->is_valid_number, '新潟県十日町市高田町四丁目');
ok($zip->set_number('9480056')->is_valid_number, '新潟県十日町市高田町五丁目');
ok($zip->set_number('9480056')->is_valid_number, '新潟県十日町市高田町六丁目');
ok($zip->set_number('9480057')->is_valid_number, '新潟県十日町市春日町');
ok($zip->set_number('9480058')->is_valid_number, '新潟県十日町市桜木町');
ok($zip->set_number('9480061')->is_valid_number, '新潟県十日町市昭和町');
ok($zip->set_number('9480062')->is_valid_number, '新潟県十日町市泉町');
ok($zip->set_number('9480063')->is_valid_number, '新潟県十日町市高田町一丁目');
ok($zip->set_number('9480064')->is_valid_number, '新潟県十日町市高田町二丁目');
ok($zip->set_number('9480065')->is_valid_number, '新潟県十日町市高田町三丁目');
ok($zip->set_number('9480065')->is_valid_number, '新潟県十日町市高田町三丁目西');
ok($zip->set_number('9480065')->is_valid_number, '新潟県十日町市高田町三丁目南');
ok($zip->set_number('9480066')->is_valid_number, '新潟県十日町市袋町中');
ok($zip->set_number('9480066')->is_valid_number, '新潟県十日町市袋町西');
ok($zip->set_number('9480066')->is_valid_number, '新潟県十日町市袋町東');
ok($zip->set_number('9480067')->is_valid_number, '新潟県十日町市千歳町');
ok($zip->set_number('9480068')->is_valid_number, '新潟県十日町市栄町');
ok($zip->set_number('9480071')->is_valid_number, '新潟県十日町市八幡田町');
ok($zip->set_number('9480072')->is_valid_number, '新潟県十日町市西本町');
ok($zip->set_number('9480073')->is_valid_number, '新潟県十日町市稲荷町(3丁目本通り)');
ok($zip->set_number('9480073')->is_valid_number, '新潟県十日町市稲荷町一丁目');
ok($zip->set_number('9480073')->is_valid_number, '新潟県十日町市稲荷町二丁目');
ok($zip->set_number('9480073')->is_valid_number, '新潟県十日町市稲荷町三丁目東');
ok($zip->set_number('9480073')->is_valid_number, '新潟県十日町市稲荷町三丁目本通り');
ok($zip->set_number('9480073')->is_valid_number, '新潟県十日町市稲荷町四丁目');
ok($zip->set_number('9480073')->is_valid_number, '新潟県十日町市稲荷町西');
ok($zip->set_number('9480074')->is_valid_number, '新潟県十日町市西浦町西');
ok($zip->set_number('9480074')->is_valid_number, '新潟県十日町市西浦町東');
ok($zip->set_number('9480075')->is_valid_number, '新潟県十日町市丸山町');
ok($zip->set_number('9480076')->is_valid_number, '新潟県十日町市住吉町');
ok($zip->set_number('9480078')->is_valid_number, '新潟県十日町市千代田町');
ok($zip->set_number('9480079')->is_valid_number, '新潟県十日町市旭町');
ok($zip->set_number('9480081')->is_valid_number, '新潟県十日町市本町五丁目');
ok($zip->set_number('9480082')->is_valid_number, '新潟県十日町市本町二丁目');
ok($zip->set_number('9480082')->is_valid_number, '新潟県十日町市本町三丁目');
ok($zip->set_number('9480082')->is_valid_number, '新潟県十日町市本町四丁目');
ok($zip->set_number('9480083')->is_valid_number, '新潟県十日町市本町一丁目上');
ok($zip->set_number('9480083')->is_valid_number, '新潟県十日町市本町一丁目下');
ok($zip->set_number('9480083')->is_valid_number, '新潟県十日町市本町西一丁目');
ok($zip->set_number('9480083')->is_valid_number, '新潟県十日町市本町東一丁目');
ok($zip->set_number('9480084')->is_valid_number, '新潟県十日町市七軒町');
ok($zip->set_number('9480085')->is_valid_number, '新潟県十日町市西寺町');
ok($zip->set_number('9480086')->is_valid_number, '新潟県十日町市加賀糸屋町');
ok($zip->set_number('9480087')->is_valid_number, '新潟県十日町市関口樋口町');
ok($zip->set_number('9480088')->is_valid_number, '新潟県十日町市駅通り');
ok($zip->set_number('9480091')->is_valid_number, '新潟県十日町市稲荷町三丁目');
ok($zip->set_number('9480092')->is_valid_number, '新潟県十日町市稲荷町三丁目北');
ok($zip->set_number('9480093')->is_valid_number, '新潟県十日町市稲荷町三丁目南');
ok($zip->set_number('9480094')->is_valid_number, '新潟県十日町市上島');
ok($zip->set_number('9480095')->is_valid_number, '新潟県十日町市下島');
ok($zip->set_number('9480096')->is_valid_number, '新潟県十日町市内島');
ok($zip->set_number('9480101')->is_valid_number, '新潟県十日町市稲葉');
ok($zip->set_number('9480102')->is_valid_number, '新潟県十日町市山谷');
ok($zip->set_number('9480103')->is_valid_number, '新潟県十日町市小泉');
ok($zip->set_number('9480104')->is_valid_number, '新潟県十日町市樽沢');
ok($zip->set_number('9480105')->is_valid_number, '新潟県十日町市北鐙坂');
ok($zip->set_number('9480106')->is_valid_number, '新潟県十日町市南鐙坂');
ok($zip->set_number('9480107')->is_valid_number, '新潟県十日町市高島');
ok($zip->set_number('9480111')->is_valid_number, '新潟県十日町市真田甲');
ok($zip->set_number('9480112')->is_valid_number, '新潟県十日町市真田乙');
ok($zip->set_number('9480113')->is_valid_number, '新潟県十日町市真田丁');
ok($zip->set_number('9480114')->is_valid_number, '新潟県十日町市真田丙');
ok($zip->set_number('9480121')->is_valid_number, '新潟県十日町市新町新田');
ok($zip->set_number('9480122')->is_valid_number, '新潟県十日町市上野');
ok($zip->set_number('9480123')->is_valid_number, '新潟県十日町市下平新田');
ok($zip->set_number('9480124')->is_valid_number, '新潟県十日町市三領');
ok($zip->set_number('9480125')->is_valid_number, '新潟県十日町市小根岸');
ok($zip->set_number('9480131')->is_valid_number, '新潟県十日町市伊勢平治');
ok($zip->set_number('9480132')->is_valid_number, '新潟県十日町市友重');
ok($zip->set_number('9480133')->is_valid_number, '新潟県十日町市沖立');
ok($zip->set_number('9480134')->is_valid_number, '新潟県十日町市上新井');
ok($zip->set_number('9480135')->is_valid_number, '新潟県十日町市中屋敷');
ok($zip->set_number('9480136')->is_valid_number, '新潟県十日町市高原田');
ok($zip->set_number('9480141')->is_valid_number, '新潟県十日町市霜条');
ok($zip->set_number('9480142')->is_valid_number, '新潟県十日町市東善寺');
ok($zip->set_number('9480143')->is_valid_number, '新潟県十日町市山野田');
ok($zip->set_number('9480144')->is_valid_number, '新潟県十日町市水口沢');
ok($zip->set_number('9480145')->is_valid_number, '新潟県十日町市坪山');
ok($zip->set_number('9480146')->is_valid_number, '新潟県十日町市鶴吉');
ok($zip->set_number('9480211')->is_valid_number, '新潟県十日町市大倉');
ok($zip->set_number('9480212')->is_valid_number, '新潟県十日町市岩瀬');
ok($zip->set_number('9480213')->is_valid_number, '新潟県十日町市赤谷');
ok($zip->set_number('9480214')->is_valid_number, '新潟県十日町市中仙田');
ok($zip->set_number('9480215')->is_valid_number, '新潟県十日町市田戸');
ok($zip->set_number('9480216')->is_valid_number, '新潟県十日町市室島');
ok($zip->set_number('9480217')->is_valid_number, '新潟県十日町市高倉');
ok($zip->set_number('9480218')->is_valid_number, '新潟県十日町市小脇');
ok($zip->set_number('9480219')->is_valid_number, '新潟県十日町市越ケ沢');
ok($zip->set_number('9480301')->is_valid_number, '新潟県十日町市野口');
ok($zip->set_number('9480302')->is_valid_number, '新潟県十日町市仁田');
ok($zip->set_number('9480303')->is_valid_number, '新潟県十日町市寺ケ崎');
ok($zip->set_number('9480304')->is_valid_number, '新潟県十日町市木落');
ok($zip->set_number('9480305')->is_valid_number, '新潟県十日町市大白倉');
ok($zip->set_number('9480306')->is_valid_number, '新潟県十日町市小白倉');
ok($zip->set_number('9490111')->is_valid_number, '新潟県糸魚川市市振');
ok($zip->set_number('9490112')->is_valid_number, '新潟県糸魚川市上路');
ok($zip->set_number('9490301')->is_valid_number, '新潟県糸魚川市須沢');
ok($zip->set_number('9490302')->is_valid_number, '新潟県糸魚川市今村新田');
ok($zip->set_number('9490303')->is_valid_number, '新潟県糸魚川市田海');
ok($zip->set_number('9490304')->is_valid_number, '新潟県糸魚川市寺地');
ok($zip->set_number('9490305')->is_valid_number, '新潟県糸魚川市青海');
ok($zip->set_number('9490306')->is_valid_number, '新潟県糸魚川市橋立');
ok($zip->set_number('9490307')->is_valid_number, '新潟県糸魚川市歌');
ok($zip->set_number('9490308')->is_valid_number, '新潟県糸魚川市外波');
ok($zip->set_number('9490461')->is_valid_number, '新潟県糸魚川市西山(大前)');
ok($zip->set_number('9490462')->is_valid_number, '新潟県糸魚川市小滝');
ok($zip->set_number('9490463')->is_valid_number, '新潟県糸魚川市山之坊');
ok($zip->set_number('9490464')->is_valid_number, '新潟県糸魚川市大所');
ok($zip->set_number('9490531')->is_valid_number, '新潟県糸魚川市東中');
ok($zip->set_number('9490532')->is_valid_number, '新潟県糸魚川市上野');
ok($zip->set_number('9490533')->is_valid_number, '新潟県糸魚川市大工屋敷');
ok($zip->set_number('9490534')->is_valid_number, '新潟県糸魚川市和泉');
ok($zip->set_number('9490535')->is_valid_number, '新潟県糸魚川市栗山');
ok($zip->set_number('9490536')->is_valid_number, '新潟県糸魚川市根小屋');
ok($zip->set_number('9490541')->is_valid_number, '新潟県糸魚川市上沢');
ok($zip->set_number('9490542')->is_valid_number, '新潟県糸魚川市大神堂');
ok($zip->set_number('9490543')->is_valid_number, '新潟県糸魚川市山寺');
ok($zip->set_number('9490544')->is_valid_number, '新潟県糸魚川市梶山');
ok($zip->set_number('9490545')->is_valid_number, '新潟県糸魚川市大久保');
ok($zip->set_number('9490551')->is_valid_number, '新潟県糸魚川市上野山');
ok($zip->set_number('9490552')->is_valid_number, '新潟県糸魚川市蒲池');
ok($zip->set_number('9490553')->is_valid_number, '新潟県糸魚川市上横');
ok($zip->set_number('9490554')->is_valid_number, '新潟県糸魚川市山口');
ok($zip->set_number('9490555')->is_valid_number, '新潟県糸魚川市別所');
ok($zip->set_number('9490556')->is_valid_number, '新潟県糸魚川市杉之当');
ok($zip->set_number('9490557')->is_valid_number, '新潟県糸魚川市西山(その他)');
ok($zip->set_number('9490558')->is_valid_number, '新潟県糸魚川市余所');
ok($zip->set_number('9491201')->is_valid_number, '新潟県糸魚川市越');
ok($zip->set_number('9491202')->is_valid_number, '新潟県糸魚川市宮平');
ok($zip->set_number('9491203')->is_valid_number, '新潟県糸魚川市中野');
ok($zip->set_number('9491204')->is_valid_number, '新潟県糸魚川市中林');
ok($zip->set_number('9491205')->is_valid_number, '新潟県糸魚川市土塩');
ok($zip->set_number('9491206')->is_valid_number, '新潟県糸魚川市猿倉');
ok($zip->set_number('9491207')->is_valid_number, '新潟県糸魚川市吹原');
ok($zip->set_number('9491208')->is_valid_number, '新潟県糸魚川市坪野');
ok($zip->set_number('9491211')->is_valid_number, '新潟県糸魚川市五十原');
ok($zip->set_number('9491212')->is_valid_number, '新潟県糸魚川市東塚');
ok($zip->set_number('9491213')->is_valid_number, '新潟県糸魚川市西塚');
ok($zip->set_number('9491214')->is_valid_number, '新潟県糸魚川市見滝');
ok($zip->set_number('9491215')->is_valid_number, '新潟県糸魚川市谷根');
ok($zip->set_number('9491221')->is_valid_number, '新潟県糸魚川市大平');
ok($zip->set_number('9491222')->is_valid_number, '新潟県糸魚川市土倉');
ok($zip->set_number('9491223')->is_valid_number, '新潟県糸魚川市中川原新田');
ok($zip->set_number('9491224')->is_valid_number, '新潟県糸魚川市砂場');
ok($zip->set_number('9491225')->is_valid_number, '新潟県糸魚川市角間');
ok($zip->set_number('9491226')->is_valid_number, '新潟県糸魚川市北山');
ok($zip->set_number('9491301')->is_valid_number, '新潟県糸魚川市徳合');
ok($zip->set_number('9491302')->is_valid_number, '新潟県糸魚川市仙納');
ok($zip->set_number('9491303')->is_valid_number, '新潟県糸魚川市大洞');
ok($zip->set_number('9491304')->is_valid_number, '新潟県糸魚川市百川');
ok($zip->set_number('9491305')->is_valid_number, '新潟県糸魚川市藤崎');
ok($zip->set_number('9491306')->is_valid_number, '新潟県糸魚川市筒石');
ok($zip->set_number('9491311')->is_valid_number, '新潟県糸魚川市高倉');
ok($zip->set_number('9491312')->is_valid_number, '新潟県糸魚川市槙');
ok($zip->set_number('9491313')->is_valid_number, '新潟県糸魚川市下倉');
ok($zip->set_number('9491314')->is_valid_number, '新潟県糸魚川市中野口');
ok($zip->set_number('9491315')->is_valid_number, '新潟県糸魚川市指塩');
ok($zip->set_number('9491316')->is_valid_number, '新潟県糸魚川市柱道');
ok($zip->set_number('9491317')->is_valid_number, '新潟県糸魚川市大道寺');
ok($zip->set_number('9491318')->is_valid_number, '新潟県糸魚川市鷲尾');
ok($zip->set_number('9491319')->is_valid_number, '新潟県糸魚川市大王');
ok($zip->set_number('9491321')->is_valid_number, '新潟県糸魚川市東谷内');
ok($zip->set_number('9491322')->is_valid_number, '新潟県糸魚川市西飛山');
ok($zip->set_number('9491323')->is_valid_number, '新潟県糸魚川市田麦平');
ok($zip->set_number('9491324')->is_valid_number, '新潟県糸魚川市柵口');
ok($zip->set_number('9491325')->is_valid_number, '新潟県糸魚川市崩');
ok($zip->set_number('9491326')->is_valid_number, '新潟県糸魚川市物出');
ok($zip->set_number('9491327')->is_valid_number, '新潟県糸魚川市須川');
ok($zip->set_number('9491328')->is_valid_number, '新潟県糸魚川市溝尾');
ok($zip->set_number('9491329')->is_valid_number, '新潟県糸魚川市川詰');
ok($zip->set_number('9491331')->is_valid_number, '新潟県糸魚川市大沢');
ok($zip->set_number('9491332')->is_valid_number, '新潟県糸魚川市藤後');
ok($zip->set_number('9491333')->is_valid_number, '新潟県糸魚川市島道');
ok($zip->set_number('9491334')->is_valid_number, '新潟県糸魚川市平');
ok($zip->set_number('9491335')->is_valid_number, '新潟県糸魚川市小見');
ok($zip->set_number('9491336')->is_valid_number, '新潟県糸魚川市鶉石');
ok($zip->set_number('9491337')->is_valid_number, '新潟県糸魚川市桂');
ok($zip->set_number('9491338')->is_valid_number, '新潟県糸魚川市寺山');
ok($zip->set_number('9491341')->is_valid_number, '新潟県糸魚川市大平寺');
ok($zip->set_number('9491342')->is_valid_number, '新潟県糸魚川市木浦');
ok($zip->set_number('9491343')->is_valid_number, '新潟県糸魚川市鬼伏');
ok($zip->set_number('9491344')->is_valid_number, '新潟県糸魚川市鬼舞');
ok($zip->set_number('9491351')->is_valid_number, '新潟県糸魚川市能生小泊');
ok($zip->set_number('9491352')->is_valid_number, '新潟県糸魚川市能生');
ok($zip->set_number('9491353')->is_valid_number, '新潟県糸魚川市栄');
ok($zip->set_number('9491354')->is_valid_number, '新潟県糸魚川市桜木');
ok($zip->set_number('9491601')->is_valid_number, '新潟県上越市名立区名立小泊');
ok($zip->set_number('9491602')->is_valid_number, '新潟県上越市名立区名立大町');
ok($zip->set_number('9491603')->is_valid_number, '新潟県上越市名立区坪山');
ok($zip->set_number('9491604')->is_valid_number, '新潟県上越市名立区赤野俣');
ok($zip->set_number('9491605')->is_valid_number, '新潟県上越市名立区大菅');
ok($zip->set_number('9491606')->is_valid_number, '新潟県上越市名立区谷口');
ok($zip->set_number('9491607')->is_valid_number, '新潟県上越市名立区車路');
ok($zip->set_number('9491608')->is_valid_number, '新潟県上越市名立区躰畑');
ok($zip->set_number('9491609')->is_valid_number, '新潟県上越市名立区田野上');
ok($zip->set_number('9491611')->is_valid_number, '新潟県上越市名立区杉野瀬');
ok($zip->set_number('9491612')->is_valid_number, '新潟県上越市名立区丸田');
ok($zip->set_number('9491613')->is_valid_number, '新潟県上越市名立区濁沢');
ok($zip->set_number('9491614')->is_valid_number, '新潟県上越市名立区折居');
ok($zip->set_number('9491615')->is_valid_number, '新潟県上越市名立区峠');
ok($zip->set_number('9491616')->is_valid_number, '新潟県上越市名立区池田');
ok($zip->set_number('9491617')->is_valid_number, '新潟県上越市名立区森');
ok($zip->set_number('9491618')->is_valid_number, '新潟県上越市名立区桂谷');
ok($zip->set_number('9491619')->is_valid_number, '新潟県上越市名立区平谷');
ok($zip->set_number('9491621')->is_valid_number, '新潟県上越市名立区折戸');
ok($zip->set_number('9491622')->is_valid_number, '新潟県上越市名立区小田島');
ok($zip->set_number('9491623')->is_valid_number, '新潟県上越市名立区東蒲生田');
ok($zip->set_number('9491624')->is_valid_number, '新潟県上越市名立区西蒲生田');
ok($zip->set_number('9491625')->is_valid_number, '新潟県上越市名立区瀬戸');
ok($zip->set_number('9491626')->is_valid_number, '新潟県上越市名立区東飛山');
ok($zip->set_number('9491701')->is_valid_number, '新潟県上越市長浜');
ok($zip->set_number('9491702')->is_valid_number, '新潟県上越市有間川');
ok($zip->set_number('9491703')->is_valid_number, '新潟県上越市丹原');
ok($zip->set_number('9491704')->is_valid_number, '新潟県上越市鍋ケ浦');
ok($zip->set_number('9491705')->is_valid_number, '新潟県上越市吉浦');
ok($zip->set_number('9491706')->is_valid_number, '新潟県上越市茶屋ケ原');
ok($zip->set_number('9491711')->is_valid_number, '新潟県上越市西戸野');
ok($zip->set_number('9491712')->is_valid_number, '新潟県上越市鍛冶免分');
ok($zip->set_number('9491713')->is_valid_number, '新潟県上越市花立');
ok($zip->set_number('9491714')->is_valid_number, '新潟県上越市三伝');
ok($zip->set_number('9491715')->is_valid_number, '新潟県上越市中桑取');
ok($zip->set_number('9491716')->is_valid_number, '新潟県上越市高住');
ok($zip->set_number('9491721')->is_valid_number, '新潟県上越市下綱子');
ok($zip->set_number('9491722')->is_valid_number, '新潟県上越市西山寺');
ok($zip->set_number('9491723')->is_valid_number, '新潟県上越市小池');
ok($zip->set_number('9491724')->is_valid_number, '新潟県上越市小池新田');
ok($zip->set_number('9491725')->is_valid_number, '新潟県上越市西鳥越');
ok($zip->set_number('9491726')->is_valid_number, '新潟県上越市諏訪分');
ok($zip->set_number('9491727')->is_valid_number, '新潟県上越市西横山');
ok($zip->set_number('9491731')->is_valid_number, '新潟県上越市西吉尾');
ok($zip->set_number('9491732')->is_valid_number, '新潟県上越市東吉尾');
ok($zip->set_number('9491733')->is_valid_number, '新潟県上越市大渕');
ok($zip->set_number('9491734')->is_valid_number, '新潟県上越市増沢');
ok($zip->set_number('9491735')->is_valid_number, '新潟県上越市土口');
ok($zip->set_number('9491736')->is_valid_number, '新潟県上越市北谷');
ok($zip->set_number('9491737')->is_valid_number, '新潟県上越市西谷内');
ok($zip->set_number('9491738')->is_valid_number, '新潟県上越市皆口');
ok($zip->set_number('9491739')->is_valid_number, '新潟県上越市横畑');
ok($zip->set_number('9491741')->is_valid_number, '新潟県上越市上綱子');
ok($zip->set_number('9491742')->is_valid_number, '新潟県上越市中ノ俣');
ok($zip->set_number('9492101')->is_valid_number, '新潟県妙高市二俣');
ok($zip->set_number('9492102')->is_valid_number, '新潟県妙高市田切');
ok($zip->set_number('9492103')->is_valid_number, '新潟県妙高市蔵々');
ok($zip->set_number('9492104')->is_valid_number, '新潟県妙高市兼俣');
ok($zip->set_number('9492105')->is_valid_number, '新潟県妙高市毛祝坂');
ok($zip->set_number('9492106')->is_valid_number, '新潟県妙高市田口');
ok($zip->set_number('9492111')->is_valid_number, '新潟県妙高市赤倉');
ok($zip->set_number('9492112')->is_valid_number, '新潟県妙高市関川');
ok($zip->set_number('9492113')->is_valid_number, '新潟県妙高市杉野沢');
ok($zip->set_number('9492141')->is_valid_number, '新潟県妙高市関山(熊堂山、妙高山国有林第28班)');
ok($zip->set_number('9492201')->is_valid_number, '新潟県妙高市寺尾');
ok($zip->set_number('9492202')->is_valid_number, '新潟県妙高市坂下新田');
ok($zip->set_number('9492203')->is_valid_number, '新潟県妙高市北田屋新田');
ok($zip->set_number('9492204')->is_valid_number, '新潟県妙高市中原新田');
ok($zip->set_number('9492205')->is_valid_number, '新潟県妙高市上大塚新田');
ok($zip->set_number('9492206')->is_valid_number, '新潟県妙高市西田屋新田');
ok($zip->set_number('9492207')->is_valid_number, '新潟県妙高市窪田新田');
ok($zip->set_number('9492208')->is_valid_number, '新潟県妙高市今府');
ok($zip->set_number('9492209')->is_valid_number, '新潟県妙高市祖父竹');
ok($zip->set_number('9492211')->is_valid_number, '新潟県妙高市田中村新田');
ok($zip->set_number('9492212')->is_valid_number, '新潟県妙高市岡新田');
ok($zip->set_number('9492213')->is_valid_number, '新潟県妙高市東田屋新田');
ok($zip->set_number('9492214')->is_valid_number, '新潟県妙高市中島新田');
ok($zip->set_number('9492215')->is_valid_number, '新潟県妙高市橋本新田');
ok($zip->set_number('9492216')->is_valid_number, '新潟県妙高市東四ツ屋新田');
ok($zip->set_number('9492217')->is_valid_number, '新潟県妙高市東福田新田');
ok($zip->set_number('9492218')->is_valid_number, '新潟県妙高市花房');
ok($zip->set_number('9492219')->is_valid_number, '新潟県妙高市原通');
ok($zip->set_number('9492221')->is_valid_number, '新潟県妙高市大鹿');
ok($zip->set_number('9492222')->is_valid_number, '新潟県妙高市土路');
ok($zip->set_number('9492223')->is_valid_number, '新潟県妙高市樽本(その他)');
ok($zip->set_number('9492224')->is_valid_number, '新潟県妙高市桶海');
ok($zip->set_number('9492225')->is_valid_number, '新潟県妙高市大谷');
ok($zip->set_number('9492226')->is_valid_number, '新潟県妙高市住吉');
ok($zip->set_number('9492231')->is_valid_number, '新潟県妙高市米島新田');
ok($zip->set_number('9492232')->is_valid_number, '新潟県妙高市葎生');
ok($zip->set_number('9492233')->is_valid_number, '新潟県妙高市上中村新田');
ok($zip->set_number('9492234')->is_valid_number, '新潟県妙高市坂口新田');
ok($zip->set_number('9492235')->is_valid_number, '新潟県妙高市関山(その他)');
ok($zip->set_number('9492301')->is_valid_number, '新潟県上越市中郷区板橋');
ok($zip->set_number('9492302')->is_valid_number, '新潟県上越市中郷区藤沢');
ok($zip->set_number('9492303')->is_valid_number, '新潟県上越市中郷区坂本');
ok($zip->set_number('9492304')->is_valid_number, '新潟県上越市中郷区二本木');
ok($zip->set_number('9492305')->is_valid_number, '新潟県上越市中郷区四ツ屋');
ok($zip->set_number('9492306')->is_valid_number, '新潟県上越市中郷区八斗蒔');
ok($zip->set_number('9492311')->is_valid_number, '新潟県上越市中郷区松崎');
ok($zip->set_number('9492312')->is_valid_number, '新潟県上越市中郷区片貝');
ok($zip->set_number('9492313')->is_valid_number, '新潟県上越市中郷区福崎');
ok($zip->set_number('9492314')->is_valid_number, '新潟県上越市中郷区宮野原');
ok($zip->set_number('9492315')->is_valid_number, '新潟県上越市中郷区稲荷山');
ok($zip->set_number('9492316')->is_valid_number, '新潟県上越市中郷区江口');
ok($zip->set_number('9492317')->is_valid_number, '新潟県上越市中郷区市屋');
ok($zip->set_number('9492318')->is_valid_number, '新潟県上越市中郷区岡川');
ok($zip->set_number('9492321')->is_valid_number, '新潟県上越市中郷区福田');
ok($zip->set_number('9492322')->is_valid_number, '新潟県上越市中郷区岡沢');
ok($zip->set_number('9493101')->is_valid_number, '新潟県上越市大潟区雁子浜');
ok($zip->set_number('9493102')->is_valid_number, '新潟県上越市大潟区九戸浜');
ok($zip->set_number('9493103')->is_valid_number, '新潟県上越市大潟区潟町');
ok($zip->set_number('9493111')->is_valid_number, '新潟県上越市大潟区四ツ屋浜');
ok($zip->set_number('9493112')->is_valid_number, '新潟県上越市大潟区土底浜');
ok($zip->set_number('9493113')->is_valid_number, '新潟県上越市大潟区下小船津浜');
ok($zip->set_number('9493114')->is_valid_number, '新潟県上越市大潟区上小船津浜');
ok($zip->set_number('9493115')->is_valid_number, '新潟県上越市大潟区渋柿浜');
ok($zip->set_number('9493116')->is_valid_number, '新潟県上越市大潟区犀潟');
ok($zip->set_number('9493117')->is_valid_number, '新潟県上越市大潟区蜘ケ池');
ok($zip->set_number('9493121')->is_valid_number, '新潟県上越市大潟区潟田');
ok($zip->set_number('9493122')->is_valid_number, '新潟県上越市大潟区岩野古新田');
ok($zip->set_number('9493123')->is_valid_number, '新潟県上越市大潟区長崎');
ok($zip->set_number('9493124')->is_valid_number, '新潟県上越市大潟区吉崎新田');
ok($zip->set_number('9493125')->is_valid_number, '新潟県上越市大潟区山鵜島新田');
ok($zip->set_number('9493131')->is_valid_number, '新潟県上越市大潟区里鵜島新田');
ok($zip->set_number('9493132')->is_valid_number, '新潟県上越市大潟区米倉新田');
ok($zip->set_number('9493133')->is_valid_number, '新潟県上越市大潟区高橋新田');
ok($zip->set_number('9493134')->is_valid_number, '新潟県上越市大潟区和泉新田');
ok($zip->set_number('9493135')->is_valid_number, '新潟県上越市大潟区内雁子');
ok($zip->set_number('9493136')->is_valid_number, '新潟県上越市大潟区内雁子新田');
ok($zip->set_number('9493137')->is_valid_number, '新潟県上越市大潟区潟守新田(その他)');
ok($zip->set_number('9493201')->is_valid_number, '新潟県上越市柿崎区竹鼻');
ok($zip->set_number('9493211')->is_valid_number, '新潟県上越市柿崎区法音寺');
ok($zip->set_number('9493212')->is_valid_number, '新潟県上越市柿崎区山谷');
ok($zip->set_number('9493213')->is_valid_number, '新潟県上越市柿崎区川井');
ok($zip->set_number('9493214')->is_valid_number, '新潟県上越市柿崎区馬正面');
ok($zip->set_number('9493215')->is_valid_number, '新潟県上越市柿崎区直海浜');
ok($zip->set_number('9493216')->is_valid_number, '新潟県上越市柿崎区柿崎');
ok($zip->set_number('9493221')->is_valid_number, '新潟県上越市柿崎区小萱');
ok($zip->set_number('9493222')->is_valid_number, '新潟県上越市柿崎区栃窪');
ok($zip->set_number('9493223')->is_valid_number, '新潟県上越市柿崎区雁海');
ok($zip->set_number('9493224')->is_valid_number, '新潟県上越市柿崎区東谷内');
ok($zip->set_number('9493225')->is_valid_number, '新潟県上越市柿崎区金谷');
ok($zip->set_number('9493226')->is_valid_number, '新潟県上越市柿崎区下中山');
ok($zip->set_number('9493231')->is_valid_number, '新潟県上越市柿崎区上小野');
ok($zip->set_number('9493232')->is_valid_number, '新潟県上越市柿崎区下小野');
ok($zip->set_number('9493233')->is_valid_number, '新潟県上越市柿崎区柳ケ崎');
ok($zip->set_number('9493234')->is_valid_number, '新潟県上越市柿崎区高寺');
ok($zip->set_number('9493235')->is_valid_number, '新潟県上越市柿崎区荻谷');
ok($zip->set_number('9493236')->is_valid_number, '新潟県上越市柿崎区阿弥陀瀬');
ok($zip->set_number('9493237')->is_valid_number, '新潟県上越市柿崎区川田');
ok($zip->set_number('9493241')->is_valid_number, '新潟県上越市柿崎区百木');
ok($zip->set_number('9493242')->is_valid_number, '新潟県上越市柿崎区桜町新田');
ok($zip->set_number('9493243')->is_valid_number, '新潟県上越市柿崎区上金原');
ok($zip->set_number('9493244')->is_valid_number, '新潟県上越市柿崎区下金原');
ok($zip->set_number('9493245')->is_valid_number, '新潟県上越市柿崎区行法');
ok($zip->set_number('9493246')->is_valid_number, '新潟県上越市柿崎区落合');
ok($zip->set_number('9493247')->is_valid_number, '新潟県上越市柿崎区角取');
ok($zip->set_number('9493251')->is_valid_number, '新潟県上越市柿崎区下条');
ok($zip->set_number('9493252')->is_valid_number, '新潟県上越市柿崎区上直海');
ok($zip->set_number('9493253')->is_valid_number, '新潟県上越市柿崎区江島新田');
ok($zip->set_number('9493254')->is_valid_number, '新潟県上越市柿崎区坂田新田');
ok($zip->set_number('9493255')->is_valid_number, '新潟県上越市柿崎区上下浜');
ok($zip->set_number('9493256')->is_valid_number, '新潟県上越市柿崎区三ツ屋浜');
ok($zip->set_number('9493361')->is_valid_number, '新潟県上越市柿崎区城腰');
ok($zip->set_number('9493362')->is_valid_number, '新潟県上越市柿崎区黒岩');
ok($zip->set_number('9493363')->is_valid_number, '新潟県上越市柿崎区旭平');
ok($zip->set_number('9493364')->is_valid_number, '新潟県上越市柿崎区東横山');
ok($zip->set_number('9493365')->is_valid_number, '新潟県上越市柿崎区松留');
ok($zip->set_number('9493366')->is_valid_number, '新潟県上越市柿崎区上中山');
ok($zip->set_number('9493367')->is_valid_number, '新潟県上越市柿崎区猿毛');
ok($zip->set_number('9493371')->is_valid_number, '新潟県上越市柿崎区下牧');
ok($zip->set_number('9493372')->is_valid_number, '新潟県上越市柿崎区水野');
ok($zip->set_number('9493373')->is_valid_number, '新潟県上越市柿崎区米山寺');
ok($zip->set_number('9493374')->is_valid_number, '新潟県上越市柿崎区芋島');
ok($zip->set_number('9493375')->is_valid_number, '新潟県上越市柿崎区下灰庭新田');
ok($zip->set_number('9493376')->is_valid_number, '新潟県上越市柿崎区岩手');
ok($zip->set_number('9493377')->is_valid_number, '新潟県上越市柿崎区高畑');
ok($zip->set_number('9493378')->is_valid_number, '新潟県上越市柿崎区岩野');
ok($zip->set_number('9493379')->is_valid_number, '新潟県上越市柿崎区平沢');
ok($zip->set_number('9493401')->is_valid_number, '新潟県上越市吉川区後生寺');
ok($zip->set_number('9493402')->is_valid_number, '新潟県上越市吉川区伯母ケ沢');
ok($zip->set_number('9493403')->is_valid_number, '新潟県上越市吉川区平等寺');
ok($zip->set_number('9493404')->is_valid_number, '新潟県上越市吉川区東寺');
ok($zip->set_number('9493405')->is_valid_number, '新潟県上越市吉川区吉井');
ok($zip->set_number('9493406')->is_valid_number, '新潟県上越市吉川区下小沢');
ok($zip->set_number('9493407')->is_valid_number, '新潟県上越市吉川区下中条');
ok($zip->set_number('9493408')->is_valid_number, '新潟県上越市吉川区赤沢');
ok($zip->set_number('9493409')->is_valid_number, '新潟県上越市吉川区泉');
ok($zip->set_number('9493411')->is_valid_number, '新潟県上越市吉川区川崎');
ok($zip->set_number('9493412')->is_valid_number, '新潟県上越市吉川区泉谷');
ok($zip->set_number('9493413')->is_valid_number, '新潟県上越市吉川区土尻');
ok($zip->set_number('9493414')->is_valid_number, '新潟県上越市吉川区天林寺');
ok($zip->set_number('9493415')->is_valid_number, '新潟県上越市吉川区山口');
ok($zip->set_number('9493416')->is_valid_number, '新潟県上越市吉川区中谷内');
ok($zip->set_number('9493417')->is_valid_number, '新潟県上越市吉川区下深沢');
ok($zip->set_number('9493418')->is_valid_number, '新潟県上越市吉川区片田');
ok($zip->set_number('9493419')->is_valid_number, '新潟県上越市吉川区東鳥越');
ok($zip->set_number('9493421')->is_valid_number, '新潟県上越市吉川区入河沢');
ok($zip->set_number('9493422')->is_valid_number, '新潟県上越市吉川区国田');
ok($zip->set_number('9493423')->is_valid_number, '新潟県上越市吉川区東田中');
ok($zip->set_number('9493424')->is_valid_number, '新潟県上越市吉川区福平');
ok($zip->set_number('9493425')->is_valid_number, '新潟県上越市吉川区長坂');
ok($zip->set_number('9493426')->is_valid_number, '新潟県上越市吉川区道之下');
ok($zip->set_number('9493427')->is_valid_number, '新潟県上越市吉川区顕法寺');
ok($zip->set_number('9493428')->is_valid_number, '新潟県上越市吉川区十町歩');
ok($zip->set_number('9493429')->is_valid_number, '新潟県上越市吉川区河沢');
ok($zip->set_number('9493430')->is_valid_number, '新潟県上越市吉川区大滝');
ok($zip->set_number('9493431')->is_valid_number, '新潟県上越市吉川区田尻');
ok($zip->set_number('9493432')->is_valid_number, '新潟県上越市吉川区六万部');
ok($zip->set_number('9493433')->is_valid_number, '新潟県上越市吉川区町田');
ok($zip->set_number('9493434')->is_valid_number, '新潟県上越市吉川区西野島');
ok($zip->set_number('9493435')->is_valid_number, '新潟県上越市吉川区下八幡');
ok($zip->set_number('9493436')->is_valid_number, '新潟県上越市吉川区坪野内');
ok($zip->set_number('9493437')->is_valid_number, '新潟県上越市吉川区梶');
ok($zip->set_number('9493438')->is_valid_number, '新潟県上越市吉川区神田町');
ok($zip->set_number('9493439')->is_valid_number, '新潟県上越市吉川区長沢');
ok($zip->set_number('9493441')->is_valid_number, '新潟県上越市吉川区代石');
ok($zip->set_number('9493442')->is_valid_number, '新潟県上越市吉川区小苗代');
ok($zip->set_number('9493443')->is_valid_number, '新潟県上越市吉川区下町');
ok($zip->set_number('9493444')->is_valid_number, '新潟県上越市吉川区大乗寺');
ok($zip->set_number('9493445')->is_valid_number, '新潟県上越市吉川区原之町');
ok($zip->set_number('9493446')->is_valid_number, '新潟県上越市吉川区山方');
ok($zip->set_number('9493447')->is_valid_number, '新潟県上越市吉川区竹直');
ok($zip->set_number('9493448')->is_valid_number, '新潟県上越市吉川区長峰');
ok($zip->set_number('9493449')->is_valid_number, '新潟県上越市吉川区杜氏の郷');
ok($zip->set_number('9493551')->is_valid_number, '新潟県上越市吉川区坪野');
ok($zip->set_number('9493552')->is_valid_number, '新潟県上越市吉川区尾神');
ok($zip->set_number('9493553')->is_valid_number, '新潟県上越市吉川区川谷');
ok($zip->set_number('9493554')->is_valid_number, '新潟県上越市吉川区石谷');
ok($zip->set_number('9493555')->is_valid_number, '新潟県上越市吉川区上名木');
ok($zip->set_number('9493556')->is_valid_number, '新潟県上越市吉川区名木山');
ok($zip->set_number('9493557')->is_valid_number, '新潟県上越市吉川区高沢入');
ok($zip->set_number('9493561')->is_valid_number, '新潟県上越市吉川区山中');
ok($zip->set_number('9493562')->is_valid_number, '新潟県上越市吉川区山直海');
ok($zip->set_number('9493563')->is_valid_number, '新潟県上越市吉川区大賀');
ok($zip->set_number('9493564')->is_valid_number, '新潟県上越市吉川区岩沢');
ok($zip->set_number('9493565')->is_valid_number, '新潟県上越市吉川区米山');
ok($zip->set_number('9493661')->is_valid_number, '新潟県柏崎市青海川');
ok($zip->set_number('9493662')->is_valid_number, '新潟県柏崎市笠島');
ok($zip->set_number('9493663')->is_valid_number, '新潟県柏崎市上輪新田');
ok($zip->set_number('9493664')->is_valid_number, '新潟県柏崎市上輪');
ok($zip->set_number('9493671')->is_valid_number, '新潟県柏崎市蕨野');
ok($zip->set_number('9493672')->is_valid_number, '新潟県柏崎市大平');
ok($zip->set_number('9493673')->is_valid_number, '新潟県柏崎市高畔');
ok($zip->set_number('9493674')->is_valid_number, '新潟県柏崎市大清水');
ok($zip->set_number('9493675')->is_valid_number, '新潟県柏崎市米山町');
ok($zip->set_number('9493721')->is_valid_number, '新潟県柏崎市吉井黒川');
ok($zip->set_number('9493722')->is_valid_number, '新潟県柏崎市東長鳥');
ok($zip->set_number('9493723')->is_valid_number, '新潟県柏崎市西長鳥');
ok($zip->set_number('9493724')->is_valid_number, '新潟県柏崎市大広田');
ok($zip->set_number('9493725')->is_valid_number, '新潟県柏崎市旧広田');
ok($zip->set_number('9493726')->is_valid_number, '新潟県柏崎市山澗');
ok($zip->set_number('9493731')->is_valid_number, '新潟県柏崎市東条');
ok($zip->set_number('9493732')->is_valid_number, '新潟県柏崎市北条');
ok($zip->set_number('9493733')->is_valid_number, '新潟県柏崎市本条');
ok($zip->set_number('9493734')->is_valid_number, '新潟県柏崎市南条');
ok($zip->set_number('9493735')->is_valid_number, '新潟県柏崎市小島');
ok($zip->set_number('9494111')->is_valid_number, '新潟県柏崎市西山町別山');
ok($zip->set_number('9494112')->is_valid_number, '新潟県柏崎市西山町尾野内');
ok($zip->set_number('9494113')->is_valid_number, '新潟県柏崎市西山町上山田');
ok($zip->set_number('9494114')->is_valid_number, '新潟県柏崎市西山町灰爪');
ok($zip->set_number('9494121')->is_valid_number, '新潟県柏崎市西山町田沢');
ok($zip->set_number('9494122')->is_valid_number, '新潟県柏崎市西山町藤掛');
ok($zip->set_number('9494123')->is_valid_number, '新潟県柏崎市西山町池浦');
ok($zip->set_number('9494124')->is_valid_number, '新潟県柏崎市西山町礼拝');
ok($zip->set_number('9494125')->is_valid_number, '新潟県柏崎市西山町中央台');
ok($zip->set_number('9494126')->is_valid_number, '新潟県柏崎市西山町下山田');
ok($zip->set_number('9494127')->is_valid_number, '新潟県柏崎市西山町鎌田');
ok($zip->set_number('9494128')->is_valid_number, '新潟県柏崎市西山町伊毛');
ok($zip->set_number('9494131')->is_valid_number, '新潟県柏崎市西山町後谷');
ok($zip->set_number('9494132')->is_valid_number, '新潟県柏崎市西山町長嶺');
ok($zip->set_number('9494133')->is_valid_number, '新潟県柏崎市西山町鬼王');
ok($zip->set_number('9494134')->is_valid_number, '新潟県柏崎市西山町二田');
ok($zip->set_number('9494135')->is_valid_number, '新潟県柏崎市西山町坂田');
ok($zip->set_number('9494136')->is_valid_number, '新潟県柏崎市西山町緑が丘');
ok($zip->set_number('9494141')->is_valid_number, '新潟県柏崎市西山町西山');
ok($zip->set_number('9494142')->is_valid_number, '新潟県柏崎市西山町黒部');
ok($zip->set_number('9494143')->is_valid_number, '新潟県柏崎市西山町和田');
ok($zip->set_number('9494144')->is_valid_number, '新潟県柏崎市西山町新保');
ok($zip->set_number('9494145')->is_valid_number, '新潟県柏崎市西山町北野');
ok($zip->set_number('9494146')->is_valid_number, '新潟県柏崎市西山町妙法寺');
ok($zip->set_number('9494147')->is_valid_number, '新潟県柏崎市西山町大坪');
ok($zip->set_number('9494148')->is_valid_number, '新潟県柏崎市西山町内方');
ok($zip->set_number('9494149')->is_valid_number, '新潟県柏崎市西山町五日市');
ok($zip->set_number('9494201')->is_valid_number, '新潟県柏崎市西山町石地');
ok($zip->set_number('9494202')->is_valid_number, '新潟県柏崎市西山町尾町');
ok($zip->set_number('9494203')->is_valid_number, '新潟県柏崎市西山町大津');
ok($zip->set_number('9494204')->is_valid_number, '新潟県柏崎市西山町大崎');
ok($zip->set_number('9494205')->is_valid_number, '新潟県柏崎市西山町浜忠');
ok($zip->set_number('9494206')->is_valid_number, '新潟県柏崎市西山町甲田');
ok($zip->set_number('9494300')->is_valid_number, '新潟県三島郡出雲崎町以下に掲載がない場合');
ok($zip->set_number('9494301')->is_valid_number, '新潟県三島郡出雲崎町久田');
ok($zip->set_number('9494302')->is_valid_number, '新潟県三島郡出雲崎町井鼻');
ok($zip->set_number('9494303')->is_valid_number, '新潟県三島郡出雲崎町木折町');
ok($zip->set_number('9494304')->is_valid_number, '新潟県三島郡出雲崎町鳴滝町');
ok($zip->set_number('9494305')->is_valid_number, '新潟県三島郡出雲崎町羽黒町');
ok($zip->set_number('9494306')->is_valid_number, '新潟県三島郡出雲崎町石井町');
ok($zip->set_number('9494307')->is_valid_number, '新潟県三島郡出雲崎町住吉町');
ok($zip->set_number('9494308')->is_valid_number, '新潟県三島郡出雲崎町尼瀬');
ok($zip->set_number('9494309')->is_valid_number, '新潟県三島郡出雲崎町勝見');
ok($zip->set_number('9494311')->is_valid_number, '新潟県三島郡出雲崎町乙茂');
ok($zip->set_number('9494312')->is_valid_number, '新潟県三島郡出雲崎町大寺');
ok($zip->set_number('9494313')->is_valid_number, '新潟県三島郡出雲崎町馬草');
ok($zip->set_number('9494314')->is_valid_number, '新潟県三島郡出雲崎町藤巻');
ok($zip->set_number('9494315')->is_valid_number, '新潟県三島郡出雲崎町柿木');
ok($zip->set_number('9494316')->is_valid_number, '新潟県三島郡出雲崎町滝谷');
ok($zip->set_number('9494317')->is_valid_number, '新潟県三島郡出雲崎町吉川');
ok($zip->set_number('9494318')->is_valid_number, '新潟県三島郡出雲崎町神条');
ok($zip->set_number('9494321')->is_valid_number, '新潟県三島郡出雲崎町松本');
ok($zip->set_number('9494322')->is_valid_number, '新潟県三島郡出雲崎町小釜谷');
ok($zip->set_number('9494323')->is_valid_number, '新潟県三島郡出雲崎町大釜谷');
ok($zip->set_number('9494324')->is_valid_number, '新潟県三島郡出雲崎町吉水');
ok($zip->set_number('9494325')->is_valid_number, '新潟県三島郡出雲崎町相田');
ok($zip->set_number('9494326')->is_valid_number, '新潟県三島郡出雲崎町桂沢');
ok($zip->set_number('9494327')->is_valid_number, '新潟県三島郡出雲崎町別ケ谷');
ok($zip->set_number('9494328')->is_valid_number, '新潟県三島郡出雲崎町山谷');
ok($zip->set_number('9494331')->is_valid_number, '新潟県三島郡出雲崎町稲川');
ok($zip->set_number('9494332')->is_valid_number, '新潟県三島郡出雲崎町小木');
ok($zip->set_number('9494333')->is_valid_number, '新潟県三島郡出雲崎町常楽寺');
ok($zip->set_number('9494334')->is_valid_number, '新潟県三島郡出雲崎町豊橋');
ok($zip->set_number('9494335')->is_valid_number, '新潟県三島郡出雲崎町市野坪');
ok($zip->set_number('9494336')->is_valid_number, '新潟県三島郡出雲崎町船橋');
ok($zip->set_number('9494337')->is_valid_number, '新潟県三島郡出雲崎町田中');
ok($zip->set_number('9494341')->is_valid_number, '新潟県三島郡出雲崎町上中条');
ok($zip->set_number('9494342')->is_valid_number, '新潟県三島郡出雲崎町米田');
ok($zip->set_number('9494343')->is_valid_number, '新潟県三島郡出雲崎町立石');
ok($zip->set_number('9494344')->is_valid_number, '新潟県三島郡出雲崎町小竹');
ok($zip->set_number('9494345')->is_valid_number, '新潟県三島郡出雲崎町中山');
ok($zip->set_number('9494346')->is_valid_number, '新潟県三島郡出雲崎町上野山');
ok($zip->set_number('9494351')->is_valid_number, '新潟県三島郡出雲崎町沢田');
ok($zip->set_number('9494352')->is_valid_number, '新潟県三島郡出雲崎町大門');
ok($zip->set_number('9494353')->is_valid_number, '新潟県三島郡出雲崎町川西');
ok($zip->set_number('9494501')->is_valid_number, '新潟県長岡市上桐');
ok($zip->set_number('9494502')->is_valid_number, '新潟県長岡市黒坂');
ok($zip->set_number('9494503')->is_valid_number, '新潟県長岡市和島北野');
ok($zip->set_number('9494504')->is_valid_number, '新潟県長岡市三瀬ケ谷');
ok($zip->set_number('9494505')->is_valid_number, '新潟県長岡市根小屋');
ok($zip->set_number('9494506')->is_valid_number, '新潟県長岡市荒巻');
ok($zip->set_number('9494507')->is_valid_number, '新潟県長岡市下富岡');
ok($zip->set_number('9494511')->is_valid_number, '新潟県長岡市小島谷');
ok($zip->set_number('9494512')->is_valid_number, '新潟県長岡市若野浦');
ok($zip->set_number('9494513')->is_valid_number, '新潟県長岡市阿弥陀瀬');
ok($zip->set_number('9494514')->is_valid_number, '新潟県長岡市日野浦');
ok($zip->set_number('9494515')->is_valid_number, '新潟県長岡市和島高畑');
ok($zip->set_number('9494516')->is_valid_number, '新潟県長岡市和島中沢');
ok($zip->set_number('9494517')->is_valid_number, '新潟県長岡市梅田');
ok($zip->set_number('9494521')->is_valid_number, '新潟県長岡市東保内');
ok($zip->set_number('9494522')->is_valid_number, '新潟県長岡市村田');
ok($zip->set_number('9494523')->is_valid_number, '新潟県長岡市城之丘');
ok($zip->set_number('9494524')->is_valid_number, '新潟県長岡市両高');
ok($zip->set_number('9494525')->is_valid_number, '新潟県長岡市島崎');
ok($zip->set_number('9495121')->is_valid_number, '新潟県長岡市西谷');
ok($zip->set_number('9495122')->is_valid_number, '新潟県長岡市東谷');
ok($zip->set_number('9495123')->is_valid_number, '新潟県長岡市塚野山');
ok($zip->set_number('9495124')->is_valid_number, '新潟県長岡市千谷沢');
ok($zip->set_number('9495201')->is_valid_number, '新潟県長岡市小国町千谷沢');
ok($zip->set_number('9495211')->is_valid_number, '新潟県長岡市小国町七日町');
ok($zip->set_number('9495212')->is_valid_number, '新潟県長岡市小国町桐沢');
ok($zip->set_number('9495213')->is_valid_number, '新潟県長岡市小国町法坂');
ok($zip->set_number('9495214')->is_valid_number, '新潟県長岡市小国町上谷内新田');
ok($zip->set_number('9495215')->is_valid_number, '新潟県長岡市小国町新町');
ok($zip->set_number('9495216')->is_valid_number, '新潟県長岡市小国町相野原');
ok($zip->set_number('9495217')->is_valid_number, '新潟県長岡市小国町二本柳');
ok($zip->set_number('9495221')->is_valid_number, '新潟県長岡市小国町武石');
ok($zip->set_number('9495222')->is_valid_number, '新潟県長岡市小国町横沢');
ok($zip->set_number('9495223')->is_valid_number, '新潟県長岡市小国町八王子');
ok($zip->set_number('9495331')->is_valid_number, '新潟県長岡市小国町楢沢');
ok($zip->set_number('9495332')->is_valid_number, '新潟県長岡市小国町上岩田');
ok($zip->set_number('9495333')->is_valid_number, '新潟県長岡市小国町小国沢');
ok($zip->set_number('9495334')->is_valid_number, '新潟県長岡市小国町法末');
ok($zip->set_number('9495335')->is_valid_number, '新潟県長岡市小国町太郎丸');
ok($zip->set_number('9495336')->is_valid_number, '新潟県長岡市小国町諏訪井');
ok($zip->set_number('9495341')->is_valid_number, '新潟県長岡市小国町小栗山');
ok($zip->set_number('9495342')->is_valid_number, '新潟県長岡市小国町森光');
ok($zip->set_number('9495343')->is_valid_number, '新潟県長岡市小国町原');
ok($zip->set_number('9495344')->is_valid_number, '新潟県長岡市小国町苔野島');
ok($zip->set_number('9495345')->is_valid_number, '新潟県長岡市小国町三桶');
ok($zip->set_number('9495346')->is_valid_number, '新潟県長岡市小国町大貝');
ok($zip->set_number('9495347')->is_valid_number, '新潟県長岡市小国町山野田');
ok($zip->set_number('9495401')->is_valid_number, '新潟県長岡市飯島');
ok($zip->set_number('9495402')->is_valid_number, '新潟県長岡市篠花');
ok($zip->set_number('9495403')->is_valid_number, '新潟県長岡市越路中島');
ok($zip->set_number('9495404')->is_valid_number, '新潟県長岡市釜ケ島(その他)');
ok($zip->set_number('9495405')->is_valid_number, '新潟県長岡市岩野(その他)');
ok($zip->set_number('9495406')->is_valid_number, '新潟県長岡市浦');
ok($zip->set_number('9495407')->is_valid_number, '新潟県長岡市神谷');
ok($zip->set_number('9495408')->is_valid_number, '新潟県長岡市越路中沢');
ok($zip->set_number('9495409')->is_valid_number, '新潟県長岡市西野');
ok($zip->set_number('9495411')->is_valid_number, '新潟県長岡市来迎寺');
ok($zip->set_number('9495412')->is_valid_number, '新潟県長岡市朝日');
ok($zip->set_number('9495413')->is_valid_number, '新潟県長岡市沢下条');
ok($zip->set_number('9495414')->is_valid_number, '新潟県長岡市飯塚');
ok($zip->set_number('9495415')->is_valid_number, '新潟県長岡市岩田');
ok($zip->set_number('9495416')->is_valid_number, '新潟県長岡市不動沢');
ok($zip->set_number('9496100')->is_valid_number, '新潟県南魚沼郡湯沢町以下に掲載がない場合');
ok($zip->set_number('9496101')->is_valid_number, '新潟県南魚沼郡湯沢町湯沢');
ok($zip->set_number('9496102')->is_valid_number, '新潟県南魚沼郡湯沢町神立');
ok($zip->set_number('9496103')->is_valid_number, '新潟県南魚沼郡湯沢町土樽');
ok($zip->set_number('9496211')->is_valid_number, '新潟県南魚沼郡湯沢町三俣');
ok($zip->set_number('9496212')->is_valid_number, '新潟県南魚沼郡湯沢町三国');
ok($zip->set_number('9496361')->is_valid_number, '新潟県南魚沼市大沢');
ok($zip->set_number('9496362')->is_valid_number, '新潟県南魚沼市南田中');
ok($zip->set_number('9496363')->is_valid_number, '新潟県南魚沼市下一日市');
ok($zip->set_number('9496364')->is_valid_number, '新潟県南魚沼市上一日市');
ok($zip->set_number('9496365')->is_valid_number, '新潟県南魚沼市宮野下');
ok($zip->set_number('9496366')->is_valid_number, '新潟県南魚沼市君沢');
ok($zip->set_number('9496371')->is_valid_number, '新潟県南魚沼市関');
ok($zip->set_number('9496372')->is_valid_number, '新潟県南魚沼市石打');
ok($zip->set_number('9496373')->is_valid_number, '新潟県南魚沼市上野');
ok($zip->set_number('9496401')->is_valid_number, '新潟県南魚沼市栃窪');
ok($zip->set_number('9496402')->is_valid_number, '新潟県南魚沼市吉里');
ok($zip->set_number('9496403')->is_valid_number, '新潟県南魚沼市思川');
ok($zip->set_number('9496404')->is_valid_number, '新潟県南魚沼市片田');
ok($zip->set_number('9496405')->is_valid_number, '新潟県南魚沼市竹俣');
ok($zip->set_number('9496406')->is_valid_number, '新潟県南魚沼市竹俣新田');
ok($zip->set_number('9496407')->is_valid_number, '新潟県南魚沼市島新田');
ok($zip->set_number('9496408')->is_valid_number, '新潟県南魚沼市塩沢');
ok($zip->set_number('9496411')->is_valid_number, '新潟県南魚沼市上十日町');
ok($zip->set_number('9496412')->is_valid_number, '新潟県南魚沼市大里');
ok($zip->set_number('9496413')->is_valid_number, '新潟県南魚沼市小木六');
ok($zip->set_number('9496414')->is_valid_number, '新潟県南魚沼市八竜新田');
ok($zip->set_number('9496415')->is_valid_number, '新潟県南魚沼市小杉新田');
ok($zip->set_number('9496416')->is_valid_number, '新潟県南魚沼市大木六');
ok($zip->set_number('9496417')->is_valid_number, '新潟県南魚沼市吉山新田');
ok($zip->set_number('9496418')->is_valid_number, '新潟県南魚沼市仙石');
ok($zip->set_number('9496421')->is_valid_number, '新潟県南魚沼市中子新田甲');
ok($zip->set_number('9496422')->is_valid_number, '新潟県南魚沼市徳田新田');
ok($zip->set_number('9496423')->is_valid_number, '新潟県南魚沼市舞子');
ok($zip->set_number('9496424')->is_valid_number, '新潟県南魚沼市万条新田');
ok($zip->set_number('9496425')->is_valid_number, '新潟県南魚沼市姥島新田');
ok($zip->set_number('9496426')->is_valid_number, '新潟県南魚沼市丸池新田');
ok($zip->set_number('9496427')->is_valid_number, '新潟県南魚沼市中子新田乙');
ok($zip->set_number('9496428')->is_valid_number, '新潟県南魚沼市五郎丸');
ok($zip->set_number('9496431')->is_valid_number, '新潟県南魚沼市樺野沢');
ok($zip->set_number('9496432')->is_valid_number, '新潟県南魚沼市樺野沢新田');
ok($zip->set_number('9496433')->is_valid_number, '新潟県南魚沼市泉盛寺');
ok($zip->set_number('9496434')->is_valid_number, '新潟県南魚沼市天野沢');
ok($zip->set_number('9496435')->is_valid_number, '新潟県南魚沼市目来田');
ok($zip->set_number('9496436')->is_valid_number, '新潟県南魚沼市中');
ok($zip->set_number('9496437')->is_valid_number, '新潟県南魚沼市中野');
ok($zip->set_number('9496438')->is_valid_number, '新潟県南魚沼市大木六新田');
ok($zip->set_number('9496541')->is_valid_number, '新潟県南魚沼市三郎丸');
ok($zip->set_number('9496542')->is_valid_number, '新潟県南魚沼市雲洞');
ok($zip->set_number('9496543')->is_valid_number, '新潟県南魚沼市早川');
ok($zip->set_number('9496544')->is_valid_number, '新潟県南魚沼市枝吉');
ok($zip->set_number('9496545')->is_valid_number, '新潟県南魚沼市長崎');
ok($zip->set_number('9496551')->is_valid_number, '新潟県南魚沼市姥沢新田');
ok($zip->set_number('9496552')->is_valid_number, '新潟県南魚沼市蟹沢新田');
ok($zip->set_number('9496553')->is_valid_number, '新潟県南魚沼市清水');
ok($zip->set_number('9496554')->is_valid_number, '新潟県南魚沼市一之沢');
ok($zip->set_number('9496555')->is_valid_number, '新潟県南魚沼市滝谷');
ok($zip->set_number('9496556')->is_valid_number, '新潟県南魚沼市小松沢');
ok($zip->set_number('9496557')->is_valid_number, '新潟県南魚沼市台上');
ok($zip->set_number('9496600')->is_valid_number, '新潟県南魚沼市以下に掲載がない場合');
ok($zip->set_number('9496601')->is_valid_number, '新潟県南魚沼市君帰');
ok($zip->set_number('9496602')->is_valid_number, '新潟県南魚沼市欠之上');
ok($zip->set_number('9496603')->is_valid_number, '新潟県南魚沼市川窪');
ok($zip->set_number('9496605')->is_valid_number, '新潟県南魚沼市青木新田(695、729、992~1074番地)');
ok($zip->set_number('9496607')->is_valid_number, '新潟県南魚沼市宇津野新田(717、718番地)');
ok($zip->set_number('9496608')->is_valid_number, '新潟県南魚沼市美佐島');
ok($zip->set_number('9496609')->is_valid_number, '新潟県南魚沼市八幡');
ok($zip->set_number('9496611')->is_valid_number, '新潟県南魚沼市坂戸');
ok($zip->set_number('9496612')->is_valid_number, '新潟県南魚沼市東泉田');
ok($zip->set_number('9496615')->is_valid_number, '新潟県南魚沼市西泉田');
ok($zip->set_number('9496636')->is_valid_number, '新潟県南魚沼市小栗山');
ok($zip->set_number('9496680')->is_valid_number, '新潟県南魚沼市六日町');
ok($zip->set_number('9496681')->is_valid_number, '新潟県南魚沼市余川');
ok($zip->set_number('9496682')->is_valid_number, '新潟県南魚沼市大月');
ok($zip->set_number('9496741')->is_valid_number, '新潟県南魚沼市清水瀬');
ok($zip->set_number('9496742')->is_valid_number, '新潟県南魚沼市野中');
ok($zip->set_number('9496743')->is_valid_number, '新潟県南魚沼市舞台');
ok($zip->set_number('9496744')->is_valid_number, '新潟県南魚沼市土沢');
ok($zip->set_number('9496745')->is_valid_number, '新潟県南魚沼市小川');
ok($zip->set_number('9496746')->is_valid_number, '新潟県南魚沼市畔地');
ok($zip->set_number('9496751')->is_valid_number, '新潟県南魚沼市畔地新田');
ok($zip->set_number('9496753')->is_valid_number, '新潟県南魚沼市蛭窪');
ok($zip->set_number('9496754')->is_valid_number, '新潟県南魚沼市永松');
ok($zip->set_number('9496755')->is_valid_number, '新潟県南魚沼市原');
ok($zip->set_number('9496756')->is_valid_number, '新潟県南魚沼市京岡');
ok($zip->set_number('9496757')->is_valid_number, '新潟県南魚沼市京岡新田');
ok($zip->set_number('9496761')->is_valid_number, '新潟県南魚沼市中川');
ok($zip->set_number('9496762')->is_valid_number, '新潟県南魚沼市中川新田');
ok($zip->set_number('9496763')->is_valid_number, '新潟県南魚沼市山谷');
ok($zip->set_number('9496764')->is_valid_number, '新潟県南魚沼市宮村下新田');
ok($zip->set_number('9496765')->is_valid_number, '新潟県南魚沼市岩崎');
ok($zip->set_number('9496766')->is_valid_number, '新潟県南魚沼市津久野上新田');
ok($zip->set_number('9496771')->is_valid_number, '新潟県南魚沼市津久野');
ok($zip->set_number('9496772')->is_valid_number, '新潟県南魚沼市二日町');
ok($zip->set_number('9496773')->is_valid_number, '新潟県南魚沼市津久野下新田');
ok($zip->set_number('9496774')->is_valid_number, '新潟県南魚沼市深沢');
ok($zip->set_number('9496775')->is_valid_number, '新潟県南魚沼市宮');
ok($zip->set_number('9497101')->is_valid_number, '新潟県南魚沼市五日町');
ok($zip->set_number('9497102')->is_valid_number, '新潟県南魚沼市奥');
ok($zip->set_number('9497103')->is_valid_number, '新潟県南魚沼市大杉新田');
ok($zip->set_number('9497104')->is_valid_number, '新潟県南魚沼市寺尾');
ok($zip->set_number('9497111')->is_valid_number, '新潟県南魚沼市麓');
ok($zip->set_number('9497112')->is_valid_number, '新潟県南魚沼市長森');
ok($zip->set_number('9497113')->is_valid_number, '新潟県南魚沼市下原');
ok($zip->set_number('9497114')->is_valid_number, '新潟県南魚沼市泉');
ok($zip->set_number('9497115')->is_valid_number, '新潟県南魚沼市泉新田');
ok($zip->set_number('9497116')->is_valid_number, '新潟県南魚沼市下原新田');
ok($zip->set_number('9497117')->is_valid_number, '新潟県南魚沼市長森新田');
ok($zip->set_number('9497121')->is_valid_number, '新潟県南魚沼市山口');
ok($zip->set_number('9497122')->is_valid_number, '新潟県南魚沼市岡');
ok($zip->set_number('9497123')->is_valid_number, '新潟県南魚沼市妙音寺');
ok($zip->set_number('9497124')->is_valid_number, '新潟県南魚沼市上薬師堂');
ok($zip->set_number('9497125')->is_valid_number, '新潟県南魚沼市下薬師堂');
ok($zip->set_number('9497126')->is_valid_number, '新潟県南魚沼市上出浦');
ok($zip->set_number('9497127')->is_valid_number, '新潟県南魚沼市下出浦');
ok($zip->set_number('9497131')->is_valid_number, '新潟県南魚沼市野際');
ok($zip->set_number('9497132')->is_valid_number, '新潟県南魚沼市藤原');
ok($zip->set_number('9497133')->is_valid_number, '新潟県南魚沼市法音寺');
ok($zip->set_number('9497134')->is_valid_number, '新潟県南魚沼市田崎');
ok($zip->set_number('9497135')->is_valid_number, '新潟県南魚沼市新堀新田');
ok($zip->set_number('9497136')->is_valid_number, '新潟県南魚沼市新堀');
ok($zip->set_number('9497137')->is_valid_number, '新潟県南魚沼市上原');
ok($zip->set_number('9497138')->is_valid_number, '新潟県南魚沼市上原新田');
ok($zip->set_number('9497141')->is_valid_number, '新潟県南魚沼市青木新田(その他)');
ok($zip->set_number('9497142')->is_valid_number, '新潟県南魚沼市宇津野新田(その他)');
ok($zip->set_number('9497143')->is_valid_number, '新潟県南魚沼市北田中');
ok($zip->set_number('9497144')->is_valid_number, '新潟県南魚沼市野田');
ok($zip->set_number('9497145')->is_valid_number, '新潟県南魚沼市四十日');
ok($zip->set_number('9497221')->is_valid_number, '新潟県南魚沼市湯谷');
ok($zip->set_number('9497222')->is_valid_number, '新潟県南魚沼市芋赤');
ok($zip->set_number('9497223')->is_valid_number, '新潟県南魚沼市門前');
ok($zip->set_number('9497224')->is_valid_number, '新潟県南魚沼市大桑原');
ok($zip->set_number('9497225')->is_valid_number, '新潟県南魚沼市山崎');
ok($zip->set_number('9497226')->is_valid_number, '新潟県南魚沼市山崎新田');
ok($zip->set_number('9497227')->is_valid_number, '新潟県南魚沼市雷土新田');
ok($zip->set_number('9497228')->is_valid_number, '新潟県南魚沼市雷土');
ok($zip->set_number('9497229')->is_valid_number, '新潟県南魚沼市前原町');
ok($zip->set_number('9497231')->is_valid_number, '新潟県南魚沼市茗荷沢');
ok($zip->set_number('9497232')->is_valid_number, '新潟県南魚沼市堂島新田');
ok($zip->set_number('9497233')->is_valid_number, '新潟県南魚沼市桐沢');
ok($zip->set_number('9497234')->is_valid_number, '新潟県南魚沼市荒山');
ok($zip->set_number('9497235')->is_valid_number, '新潟県南魚沼市荒金');
ok($zip->set_number('9497236')->is_valid_number, '新潟県南魚沼市茗荷沢新田');
ok($zip->set_number('9497241')->is_valid_number, '新潟県南魚沼市黒土新田');
ok($zip->set_number('9497242')->is_valid_number, '新潟県南魚沼市黒土');
ok($zip->set_number('9497243')->is_valid_number, '新潟県南魚沼市大倉');
ok($zip->set_number('9497244')->is_valid_number, '新潟県南魚沼市船ケ沢新田');
ok($zip->set_number('9497245')->is_valid_number, '新潟県南魚沼市穴地');
ok($zip->set_number('9497246')->is_valid_number, '新潟県南魚沼市穴地新田');
ok($zip->set_number('9497247')->is_valid_number, '新潟県南魚沼市八色原');
ok($zip->set_number('9497248')->is_valid_number, '新潟県南魚沼市国際町');
ok($zip->set_number('9497251')->is_valid_number, '新潟県南魚沼市大崎');
ok($zip->set_number('9497252')->is_valid_number, '新潟県南魚沼市水尾');
ok($zip->set_number('9497253')->is_valid_number, '新潟県南魚沼市水尾新田');
ok($zip->set_number('9497254')->is_valid_number, '新潟県南魚沼市今町新田');
ok($zip->set_number('9497255')->is_valid_number, '新潟県南魚沼市柳古新田');
ok($zip->set_number('9497256')->is_valid_number, '新潟県南魚沼市海士ケ島新田');
ok($zip->set_number('9497301')->is_valid_number, '新潟県南魚沼市五箇');
ok($zip->set_number('9497302')->is_valid_number, '新潟県南魚沼市浦佐');
ok($zip->set_number('9497311')->is_valid_number, '新潟県南魚沼市芹田');
ok($zip->set_number('9497312')->is_valid_number, '新潟県南魚沼市九日町');
ok($zip->set_number('9497313')->is_valid_number, '新潟県南魚沼市今町');
ok($zip->set_number('9497314')->is_valid_number, '新潟県南魚沼市城山新田');
ok($zip->set_number('9497315')->is_valid_number, '新潟県南魚沼市名木沢');
ok($zip->set_number('9497316')->is_valid_number, '新潟県南魚沼市一村尾');
ok($zip->set_number('9497317')->is_valid_number, '新潟県南魚沼市市野江甲');
ok($zip->set_number('9497318')->is_valid_number, '新潟県南魚沼市市野江乙(後山)');
ok($zip->set_number('9497319')->is_valid_number, '新潟県南魚沼市市野江丙(辻又)');
ok($zip->set_number('9497401')->is_valid_number, '新潟県魚沼市下倉');
ok($zip->set_number('9497402')->is_valid_number, '新潟県魚沼市田戸');
ok($zip->set_number('9497403')->is_valid_number, '新潟県魚沼市根小屋');
ok($zip->set_number('9497404')->is_valid_number, '新潟県魚沼市竜光');
ok($zip->set_number('9497405')->is_valid_number, '新潟県魚沼市新道島');
ok($zip->set_number('9497411')->is_valid_number, '新潟県魚沼市大石');
ok($zip->set_number('9497412')->is_valid_number, '新潟県魚沼市与五郎新田');
ok($zip->set_number('9497413')->is_valid_number, '新潟県魚沼市堀之内');
ok($zip->set_number('9497414')->is_valid_number, '新潟県魚沼市和長島');
ok($zip->set_number('9497415')->is_valid_number, '新潟県魚沼市田川');
ok($zip->set_number('9497416')->is_valid_number, '新潟県魚沼市下島');
ok($zip->set_number('9497417')->is_valid_number, '新潟県魚沼市下新田');
ok($zip->set_number('9497418')->is_valid_number, '新潟県魚沼市徳田');
ok($zip->set_number('9497421')->is_valid_number, '新潟県魚沼市吉水');
ok($zip->set_number('9497422')->is_valid_number, '新潟県魚沼市原');
ok($zip->set_number('9497423')->is_valid_number, '新潟県魚沼市魚野地');
ok($zip->set_number('9497424')->is_valid_number, '新潟県魚沼市明神');
ok($zip->set_number('9497501')->is_valid_number, '新潟県長岡市川口峠');
ok($zip->set_number('9497502')->is_valid_number, '新潟県長岡市川口木沢');
ok($zip->set_number('9497503')->is_valid_number, '新潟県長岡市川口中山');
ok($zip->set_number('9497504')->is_valid_number, '新潟県長岡市東川口');
ok($zip->set_number('9497505')->is_valid_number, '新潟県長岡市川口牛ケ島(その他)');
ok($zip->set_number('9497506')->is_valid_number, '新潟県長岡市川口武道窪');
ok($zip->set_number('9497507')->is_valid_number, '新潟県長岡市川口相川');
ok($zip->set_number('9497508')->is_valid_number, '新潟県長岡市川口荒谷');
ok($zip->set_number('9497511')->is_valid_number, '新潟県長岡市川口和南津');
ok($zip->set_number('9497512')->is_valid_number, '新潟県長岡市川口田麦山');
ok($zip->set_number('9497513')->is_valid_number, '新潟県長岡市西川口');
ok($zip->set_number('9498121')->is_valid_number, '新潟県中魚沼郡津南町上郷上田乙(3244~3750番地)');
ok($zip->set_number('9498122')->is_valid_number, '新潟県中魚沼郡津南町上郷上田甲');
ok($zip->set_number('9498123')->is_valid_number, '新潟県中魚沼郡津南町上郷大井平');
ok($zip->set_number('9498124')->is_valid_number, '新潟県中魚沼郡津南町上郷子種新田');
ok($zip->set_number('9498125')->is_valid_number, '新潟県中魚沼郡津南町上郷宮野原');
ok($zip->set_number('9498126')->is_valid_number, '新潟県中魚沼郡津南町上郷寺石');
ok($zip->set_number('9498127')->is_valid_number, '新潟県中魚沼郡津南町結東(その他)');
ok($zip->set_number('9498200')->is_valid_number, '新潟県中魚沼郡津南町以下に掲載がない場合');
ok($zip->set_number('9498201')->is_valid_number, '新潟県中魚沼郡津南町下船渡');
ok($zip->set_number('9498202')->is_valid_number, '新潟県中魚沼郡津南町芦ケ崎(その他)');
ok($zip->set_number('9498203')->is_valid_number, '新潟県中魚沼郡津南町赤沢');
ok($zip->set_number('9498204')->is_valid_number, '新潟県中魚沼郡津南町谷内');
ok($zip->set_number('9498205')->is_valid_number, '新潟県中魚沼郡津南町上郷上田乙(その他)');
ok($zip->set_number('9498206')->is_valid_number, '新潟県中魚沼郡津南町外丸');
ok($zip->set_number('9498207')->is_valid_number, '新潟県中魚沼郡津南町三箇');
ok($zip->set_number('9498311')->is_valid_number, '新潟県中魚沼郡津南町中深見');
ok($zip->set_number('9498312')->is_valid_number, '新潟県中魚沼郡津南町米原');
ok($zip->set_number('9498313')->is_valid_number, '新潟県中魚沼郡津南町秋成');
ok($zip->set_number('9498314')->is_valid_number, '新潟県中魚沼郡津南町芦ケ崎(石坂)');
ok($zip->set_number('9498315')->is_valid_number, '新潟県中魚沼郡津南町穴藤');
ok($zip->set_number('9498316')->is_valid_number, '新潟県中魚沼郡津南町結東(逆巻・前倉・結東)');
ok($zip->set_number('9498317')->is_valid_number, '新潟県中魚沼郡津南町大赤沢');
ok($zip->set_number('9498321')->is_valid_number, '長野県下水内郡栄村堺(17500~18560番地)');
ok($zip->set_number('9498401')->is_valid_number, '新潟県十日町市上山');
ok($zip->set_number('9498402')->is_valid_number, '新潟県十日町市桂');
ok($zip->set_number('9498403')->is_valid_number, '新潟県十日町市田沢本村');
ok($zip->set_number('9498404')->is_valid_number, '新潟県十日町市如来寺');
ok($zip->set_number('9498405')->is_valid_number, '新潟県十日町市芋沢');
ok($zip->set_number('9498406')->is_valid_number, '新潟県十日町市山崎');
ok($zip->set_number('9498407')->is_valid_number, '新潟県十日町市田中');
ok($zip->set_number('9498408')->is_valid_number, '新潟県十日町市干溝');
ok($zip->set_number('9498409')->is_valid_number, '新潟県十日町市小原');
ok($zip->set_number('9498412')->is_valid_number, '新潟県十日町市倉俣');
ok($zip->set_number('9498413')->is_valid_number, '新潟県十日町市田代');
ok($zip->set_number('9498414')->is_valid_number, '新潟県十日町市荒屋');
ok($zip->set_number('9498415')->is_valid_number, '新潟県十日町市通り山');
ok($zip->set_number('9498416')->is_valid_number, '新潟県十日町市高道山');
ok($zip->set_number('9498417')->is_valid_number, '新潟県十日町市朴木沢');
ok($zip->set_number('9498418')->is_valid_number, '新潟県十日町市宮沢');
ok($zip->set_number('9498419')->is_valid_number, '新潟県十日町市桔梗原');
ok($zip->set_number('9498421')->is_valid_number, '新潟県十日町市芋川新田');
ok($zip->set_number('9498422')->is_valid_number, '新潟県十日町市市之越');
ok($zip->set_number('9498423')->is_valid_number, '新潟県十日町市鷹羽');
ok($zip->set_number('9498424')->is_valid_number, '新潟県十日町市東田沢');
ok($zip->set_number('9498425')->is_valid_number, '新潟県十日町市東田尻');
ok($zip->set_number('9498426')->is_valid_number, '新潟県十日町市程島');
ok($zip->set_number('9498427')->is_valid_number, '新潟県十日町市白羽毛');
ok($zip->set_number('9498431')->is_valid_number, '新潟県十日町市土倉');
ok($zip->set_number('9498432')->is_valid_number, '新潟県十日町市倉下');
ok($zip->set_number('9498433')->is_valid_number, '新潟県十日町市小出');
ok($zip->set_number('9498434')->is_valid_number, '新潟県十日町市葎沢');
ok($zip->set_number('9498435')->is_valid_number, '新潟県十日町市角間');
ok($zip->set_number('9498436')->is_valid_number, '新潟県十日町市西方');
ok($zip->set_number('9498437')->is_valid_number, '新潟県十日町市西田尻');
ok($zip->set_number('9498441')->is_valid_number, '新潟県十日町市芋川');
ok($zip->set_number('9498442')->is_valid_number, '新潟県十日町市重地');
ok($zip->set_number('9498443')->is_valid_number, '新潟県十日町市中里下山');
ok($zip->set_number('9498444')->is_valid_number, '新潟県十日町市清田山');
ok($zip->set_number('9498445')->is_valid_number, '新潟県十日町市新里');
ok($zip->set_number('9498446')->is_valid_number, '新潟県十日町市原町');
ok($zip->set_number('9498502')->is_valid_number, '新潟県十日町市新屋敷');
ok($zip->set_number('9498503')->is_valid_number, '新潟県十日町市本屋敷');
ok($zip->set_number('9498504')->is_valid_number, '新潟県十日町市堀之内');
ok($zip->set_number('9498505')->is_valid_number, '新潟県十日町市宮中');
ok($zip->set_number('9498521')->is_valid_number, '新潟県十日町市大黒沢');
ok($zip->set_number('9498522')->is_valid_number, '新潟県十日町市伊達');
ok($zip->set_number('9498523')->is_valid_number, '新潟県十日町市土市');
ok($zip->set_number('9498524')->is_valid_number, '新潟県十日町市太田島');
ok($zip->set_number('9498525')->is_valid_number, '新潟県十日町市幸町');
ok($zip->set_number('9498526')->is_valid_number, '新潟県十日町市新宮');
ok($zip->set_number('9498527')->is_valid_number, '新潟県十日町市小黒沢');
ok($zip->set_number('9498531')->is_valid_number, '新潟県十日町市天池');
ok($zip->set_number('9498532')->is_valid_number, '新潟県十日町市池之尻');
ok($zip->set_number('9498533')->is_valid_number, '新潟県十日町市漆島');
ok($zip->set_number('9498534')->is_valid_number, '新潟県十日町市細尾');
ok($zip->set_number('9498541')->is_valid_number, '新潟県十日町市池沢');
ok($zip->set_number('9498542')->is_valid_number, '新潟県十日町市源田');
ok($zip->set_number('9498543')->is_valid_number, '新潟県十日町市鍬柄沢');
ok($zip->set_number('9498544')->is_valid_number, '新潟県十日町市当間');
ok($zip->set_number('9498545')->is_valid_number, '新潟県十日町市野中');
ok($zip->set_number('9498551')->is_valid_number, '新潟県十日町市馬場');
ok($zip->set_number('9498552')->is_valid_number, '新潟県十日町市中在家');
ok($zip->set_number('9498554')->is_valid_number, '新潟県十日町市南雲');
ok($zip->set_number('9498555')->is_valid_number, '新潟県十日町市大石');
ok($zip->set_number('9498556')->is_valid_number, '新潟県十日町市珠川');
ok($zip->set_number('9498557')->is_valid_number, '新潟県十日町市水沢市之沢');
ok($zip->set_number('9498558')->is_valid_number, '新潟県十日町市水沢');
ok($zip->set_number('9498561')->is_valid_number, '新潟県十日町市姿');
ok($zip->set_number('9498562')->is_valid_number, '新潟県十日町市安養寺');
ok($zip->set_number('9498601')->is_valid_number, '新潟県十日町市東下組');
ok($zip->set_number('9498602')->is_valid_number, '新潟県十日町市上組');
ok($zip->set_number('9498603')->is_valid_number, '新潟県十日町市下条');
ok($zip->set_number('9498604')->is_valid_number, '新潟県十日町市下組');
ok($zip->set_number('9498611')->is_valid_number, '新潟県十日町市中条丁');
ok($zip->set_number('9498612')->is_valid_number, '新潟県十日町市新座乙');
ok($zip->set_number('9498613')->is_valid_number, '新潟県十日町市中条庚');
ok($zip->set_number('9498614')->is_valid_number, '新潟県十日町市中条丙');
ok($zip->set_number('9498615')->is_valid_number, '新潟県十日町市中条甲');
ok($zip->set_number('9498616')->is_valid_number, '新潟県十日町市中条乙');
ok($zip->set_number('9498617')->is_valid_number, '新潟県十日町市中条己');
ok($zip->set_number('9498618')->is_valid_number, '新潟県十日町市中条戊');
ok($zip->set_number('9498721')->is_valid_number, '新潟県小千谷市塩殿');
ok($zip->set_number('9498722')->is_valid_number, '新潟県小千谷市川井');
ok($zip->set_number('9498723')->is_valid_number, '新潟県小千谷市川井新田');
ok($zip->set_number('9498724')->is_valid_number, '新潟県小千谷市岩沢');
ok($zip->set_number('9498725')->is_valid_number, '新潟県小千谷市豊久新田');
ok($zip->set_number('9498726')->is_valid_number, '新潟県小千谷市真人町');
ok($zip->set_number('9498727')->is_valid_number, '新潟県小千谷市池中新田');
ok($zip->set_number('9498728')->is_valid_number, '新潟県小千谷市池ケ原');
ok($zip->set_number('9498731')->is_valid_number, '新潟県長岡市川口牛ケ島(鷲巣)');
ok($zip->set_number('9500000')->is_valid_number, '新潟県新潟市北区以下に掲載がない場合');
ok($zip->set_number('9500000')->is_valid_number, '新潟県新潟市東区以下に掲載がない場合');
ok($zip->set_number('9500000')->is_valid_number, '新潟県新潟市中央区以下に掲載がない場合');
ok($zip->set_number('9500000')->is_valid_number, '新潟県新潟市江南区以下に掲載がない場合');
ok($zip->set_number('9500000')->is_valid_number, '新潟県新潟市西区以下に掲載がない場合');
ok($zip->set_number('9500000')->is_valid_number, '新潟県新潟市西蒲区以下に掲載がない場合');
ok($zip->set_number('9500001')->is_valid_number, '新潟県新潟市東区松浜町');
ok($zip->set_number('9500002')->is_valid_number, '新潟県新潟市東区根室新町');
ok($zip->set_number('9500003')->is_valid_number, '新潟県新潟市東区下山');
ok($zip->set_number('9500004')->is_valid_number, '新潟県新潟市東区新川町');
ok($zip->set_number('9500005')->is_valid_number, '新潟県新潟市東区太平');
ok($zip->set_number('9500011')->is_valid_number, '新潟県新潟市東区向陽');
ok($zip->set_number('9500012')->is_valid_number, '新潟県新潟市東区有楽');
ok($zip->set_number('9500013')->is_valid_number, '新潟県新潟市東区白銀');
ok($zip->set_number('9500014')->is_valid_number, '新潟県新潟市東区松崎');
ok($zip->set_number('9500015')->is_valid_number, '新潟県新潟市東区河渡庚');
ok($zip->set_number('9500016')->is_valid_number, '新潟県新潟市東区河渡本町');
ok($zip->set_number('9500017')->is_valid_number, '新潟県新潟市東区新松崎');
ok($zip->set_number('9500021')->is_valid_number, '新潟県新潟市東区物見山');
ok($zip->set_number('9500022')->is_valid_number, '新潟県新潟市東区幸栄');
ok($zip->set_number('9500023')->is_valid_number, '新潟県新潟市東区松園');
ok($zip->set_number('9500024')->is_valid_number, '新潟県新潟市東区河渡');
ok($zip->set_number('9500025')->is_valid_number, '新潟県新潟市東区藤見町');
ok($zip->set_number('9500026')->is_valid_number, '新潟県新潟市東区小金町');
ok($zip->set_number('9500027')->is_valid_number, '新潟県新潟市東区松和町');
ok($zip->set_number('9500028')->is_valid_number, '新潟県新潟市東区小金台');
ok($zip->set_number('9500031')->is_valid_number, '新潟県新潟市東区船江町');
ok($zip->set_number('9500032')->is_valid_number, '新潟県新潟市東区河渡甲');
ok($zip->set_number('9500033')->is_valid_number, '新潟県新潟市東区河渡新町');
ok($zip->set_number('9500034')->is_valid_number, '新潟県新潟市東区浜谷町');
ok($zip->set_number('9500035')->is_valid_number, '新潟県新潟市東区平和町');
ok($zip->set_number('9500036')->is_valid_number, '新潟県新潟市東区空港西');
ok($zip->set_number('9500041')->is_valid_number, '新潟県新潟市東区臨港町');
ok($zip->set_number('9500042')->is_valid_number, '新潟県新潟市東区東臨港町');
ok($zip->set_number('9500043')->is_valid_number, '新潟県新潟市東区臨港');
ok($zip->set_number('9500044')->is_valid_number, '新潟県新潟市東区古湊町');
ok($zip->set_number('9500045')->is_valid_number, '新潟県新潟市東区神明町');
ok($zip->set_number('9500046')->is_valid_number, '新潟県新潟市東区浜町');
ok($zip->set_number('9500047')->is_valid_number, '新潟県新潟市東区臨海町');
ok($zip->set_number('9500051')->is_valid_number, '新潟県新潟市東区桃山町');
ok($zip->set_number('9500052')->is_valid_number, '新潟県新潟市東区秋葉通');
ok($zip->set_number('9500053')->is_valid_number, '新潟県新潟市東区宝町');
ok($zip->set_number('9500054')->is_valid_number, '新潟県新潟市東区秋葉');
ok($zip->set_number('9500055')->is_valid_number, '新潟県新潟市東区北葉町');
ok($zip->set_number('9500056')->is_valid_number, '新潟県新潟市東区古川町');
ok($zip->set_number('9500057')->is_valid_number, '新潟県新潟市東区山の下町');
ok($zip->set_number('9500061')->is_valid_number, '新潟県新潟市東区月見町');
ok($zip->set_number('9500062')->is_valid_number, '新潟県新潟市東区錦町');
ok($zip->set_number('9500063')->is_valid_number, '新潟県新潟市東区上王瀬町');
ok($zip->set_number('9500064')->is_valid_number, '新潟県新潟市東区松島');
ok($zip->set_number('9500065')->is_valid_number, '新潟県新潟市東区東新町');
ok($zip->set_number('9500066')->is_valid_number, '新潟県新潟市東区長者町');
ok($zip->set_number('9500067')->is_valid_number, '新潟県新潟市東区大山');
ok($zip->set_number('9500071')->is_valid_number, '新潟県新潟市東区末広町');
ok($zip->set_number('9500072')->is_valid_number, '新潟県新潟市中央区竜が島');
ok($zip->set_number('9500073')->is_valid_number, '新潟県新潟市中央区日の出');
ok($zip->set_number('9500074')->is_valid_number, '新潟県新潟市中央区鏡が岡');
ok($zip->set_number('9500075')->is_valid_number, '新潟県新潟市中央区沼垂東');
ok($zip->set_number('9500076')->is_valid_number, '新潟県新潟市中央区沼垂西');
ok($zip->set_number('9500077')->is_valid_number, '新潟県新潟市中央区天明町');
ok($zip->set_number('9500078')->is_valid_number, '新潟県新潟市中央区万代島');
ok($zip->set_number('9500081')->is_valid_number, '新潟県新潟市中央区三和町');
ok($zip->set_number('9500082')->is_valid_number, '新潟県新潟市中央区東万代町');
ok($zip->set_number('9500083')->is_valid_number, '新潟県新潟市中央区蒲原町');
ok($zip->set_number('9500084')->is_valid_number, '新潟県新潟市中央区明石');
ok($zip->set_number('9500085')->is_valid_number, '新潟県新潟市中央区長嶺町');
ok($zip->set_number('9500086')->is_valid_number, '新潟県新潟市中央区花園');
ok($zip->set_number('9500087')->is_valid_number, '新潟県新潟市中央区東大通');
ok($zip->set_number('9500088')->is_valid_number, '新潟県新潟市中央区万代');
ok($zip->set_number('9500101')->is_valid_number, '新潟県新潟市東区江口');
ok($zip->set_number('9500101')->is_valid_number, '新潟県新潟市江南区江口');
ok($zip->set_number('9500102')->is_valid_number, '新潟県新潟市北区細山');
ok($zip->set_number('9500102')->is_valid_number, '新潟県新潟市江南区細山');
ok($zip->set_number('9500103')->is_valid_number, '新潟県新潟市江南区蔵岡');
ok($zip->set_number('9500104')->is_valid_number, '新潟県新潟市江南区笹山');
ok($zip->set_number('9500105')->is_valid_number, '新潟県新潟市江南区大渕');
ok($zip->set_number('9500106')->is_valid_number, '新潟県新潟市東区西野');
ok($zip->set_number('9500106')->is_valid_number, '新潟県新潟市江南区西野');
ok($zip->set_number('9500107')->is_valid_number, '新潟県新潟市江南区三百地');
ok($zip->set_number('9500111')->is_valid_number, '新潟県新潟市江南区直り山');
ok($zip->set_number('9500112')->is_valid_number, '新潟県新潟市江南区松山');
ok($zip->set_number('9500113')->is_valid_number, '新潟県新潟市江南区西山');
ok($zip->set_number('9500114')->is_valid_number, '新潟県新潟市江南区茗荷谷');
ok($zip->set_number('9500115')->is_valid_number, '新潟県新潟市江南区丸山');
ok($zip->set_number('9500116')->is_valid_number, '新潟県新潟市東区北山');
ok($zip->set_number('9500116')->is_valid_number, '新潟県新潟市江南区北山');
ok($zip->set_number('9500117')->is_valid_number, '新潟県新潟市江南区丸山ノ内善之丞組');
ok($zip->set_number('9500121')->is_valid_number, '新潟県新潟市江南区亀田向陽');
ok($zip->set_number('9500122')->is_valid_number, '新潟県新潟市江南区稲葉');
ok($zip->set_number('9500123')->is_valid_number, '新潟県新潟市江南区亀田水道町');
ok($zip->set_number('9500124')->is_valid_number, '新潟県新潟市江南区亀田東町');
ok($zip->set_number('9500125')->is_valid_number, '新潟県新潟市江南区亀田新明町');
ok($zip->set_number('9500126')->is_valid_number, '新潟県新潟市江南区東本町');
ok($zip->set_number('9500127')->is_valid_number, '新潟県新潟市江南区諏訪');
ok($zip->set_number('9500129')->is_valid_number, '新潟県新潟市江南区三條岡');
ok($zip->set_number('9500130')->is_valid_number, '新潟県新潟市江南区砂山');
ok($zip->set_number('9500131')->is_valid_number, '新潟県新潟市江南区袋津');
ok($zip->set_number('9500132')->is_valid_number, '新潟県新潟市江南区砂岡');
ok($zip->set_number('9500133')->is_valid_number, '新潟県新潟市江南区砂崩');
ok($zip->set_number('9500134')->is_valid_number, '新潟県新潟市江南区曙町');
ok($zip->set_number('9500135')->is_valid_number, '新潟県新潟市江南区所島');
ok($zip->set_number('9500136')->is_valid_number, '新潟県新潟市江南区城所');
ok($zip->set_number('9500137')->is_valid_number, '新潟県新潟市江南区城山');
ok($zip->set_number('9500138')->is_valid_number, '新潟県新潟市江南区日水');
ok($zip->set_number('9500139')->is_valid_number, '新潟県新潟市江南区手代山');
ok($zip->set_number('9500140')->is_valid_number, '新潟県新潟市江南区梅見台');
ok($zip->set_number('9500141')->is_valid_number, '新潟県新潟市江南区亀田工業団地');
ok($zip->set_number('9500142')->is_valid_number, '新潟県新潟市江南区泥潟');
ok($zip->set_number('9500143')->is_valid_number, '新潟県新潟市江南区元町');
ok($zip->set_number('9500144')->is_valid_number, '新潟県新潟市江南区茅野山');
ok($zip->set_number('9500145')->is_valid_number, '新潟県新潟市中央区亀田早通');
ok($zip->set_number('9500145')->is_valid_number, '新潟県新潟市江南区亀田早通');
ok($zip->set_number('9500146')->is_valid_number, '新潟県新潟市江南区丸潟');
ok($zip->set_number('9500147')->is_valid_number, '新潟県新潟市江南区長潟(丁目)');
ok($zip->set_number('9500148')->is_valid_number, '新潟県新潟市江南区東早通');
ok($zip->set_number('9500149')->is_valid_number, '新潟県新潟市江南区下早通');
ok($zip->set_number('9500150')->is_valid_number, '新潟県新潟市江南区下早通柳田');
ok($zip->set_number('9500151')->is_valid_number, '新潟県新潟市江南区亀田四ツ興野');
ok($zip->set_number('9500152')->is_valid_number, '新潟県新潟市江南区亀田緑町');
ok($zip->set_number('9500153')->is_valid_number, '新潟県新潟市江南区船戸山');
ok($zip->set_number('9500154')->is_valid_number, '新潟県新潟市江南区荻曽根');
ok($zip->set_number('9500155')->is_valid_number, '新潟県新潟市江南区泉町');
ok($zip->set_number('9500156')->is_valid_number, '新潟県新潟市江南区早苗');
ok($zip->set_number('9500157')->is_valid_number, '新潟県新潟市中央区鵜ノ子');
ok($zip->set_number('9500157')->is_valid_number, '新潟県新潟市江南区鵜ノ子');
ok($zip->set_number('9500161')->is_valid_number, '新潟県新潟市東区亀田中島');
ok($zip->set_number('9500161')->is_valid_number, '新潟県新潟市江南区亀田中島');
ok($zip->set_number('9500162')->is_valid_number, '新潟県新潟市江南区亀田大月');
ok($zip->set_number('9500163')->is_valid_number, '新潟県新潟市江南区東船場');
ok($zip->set_number('9500164')->is_valid_number, '新潟県新潟市江南区亀田本町');
ok($zip->set_number('9500165')->is_valid_number, '新潟県新潟市江南区西町');
ok($zip->set_number('9500166')->is_valid_number, '新潟県新潟市江南区旭');
ok($zip->set_number('9500167')->is_valid_number, '新潟県新潟市江南区五月町');
ok($zip->set_number('9500168')->is_valid_number, '新潟県新潟市江南区早通');
ok($zip->set_number('9500169')->is_valid_number, '新潟県新潟市江南区亀田長潟');
ok($zip->set_number('9500201')->is_valid_number, '新潟県新潟市江南区駒込');
ok($zip->set_number('9500202')->is_valid_number, '新潟県新潟市江南区藤山');
ok($zip->set_number('9500203')->is_valid_number, '新潟県新潟市江南区小杉');
ok($zip->set_number('9500204')->is_valid_number, '新潟県新潟市江南区横越');
ok($zip->set_number('9500205')->is_valid_number, '新潟県新潟市江南区沢海');
ok($zip->set_number('9500206')->is_valid_number, '新潟県新潟市江南区木津');
ok($zip->set_number('9500207')->is_valid_number, '新潟県新潟市江南区二本木');
ok($zip->set_number('9500208')->is_valid_number, '新潟県新潟市江南区横越中央');
ok($zip->set_number('9500209')->is_valid_number, '新潟県新潟市江南区横越東町');
ok($zip->set_number('9500210')->is_valid_number, '新潟県新潟市江南区横越上町');
ok($zip->set_number('9500211')->is_valid_number, '新潟県新潟市江南区横越川根町');
ok($zip->set_number('9500212')->is_valid_number, '新潟県新潟市江南区茜ケ丘');
ok($zip->set_number('9500213')->is_valid_number, '新潟県新潟市江南区木津工業団地');
ok($zip->set_number('9500214')->is_valid_number, '新潟県新潟市江南区うぐいす');
ok($zip->set_number('9500215')->is_valid_number, '新潟県新潟市江南区平山');
ok($zip->set_number('9500217')->is_valid_number, '新潟県新潟市江南区阿賀野');
ok($zip->set_number('9500218')->is_valid_number, '新潟県新潟市江南区いぶき野');
ok($zip->set_number('9500321')->is_valid_number, '新潟県新潟市江南区割野');
ok($zip->set_number('9500322')->is_valid_number, '新潟県新潟市江南区両川');
ok($zip->set_number('9500323')->is_valid_number, '新潟県新潟市江南区嘉瀬');
ok($zip->set_number('9500324')->is_valid_number, '新潟県新潟市江南区酒屋町');
ok($zip->set_number('9500325')->is_valid_number, '新潟県新潟市江南区花ノ牧');
ok($zip->set_number('9500326')->is_valid_number, '新潟県新潟市江南区上和田');
ok($zip->set_number('9500327')->is_valid_number, '新潟県新潟市江南区和田');
ok($zip->set_number('9500328')->is_valid_number, '新潟県新潟市江南区舞潟');
ok($zip->set_number('9500329')->is_valid_number, '新潟県新潟市江南区平賀');
ok($zip->set_number('9500801')->is_valid_number, '新潟県新潟市東区津島屋');
ok($zip->set_number('9500802')->is_valid_number, '新潟県新潟市東区一日市');
ok($zip->set_number('9500803')->is_valid_number, '新潟県新潟市東区中興野');
ok($zip->set_number('9500804')->is_valid_number, '新潟県新潟市東区本所');
ok($zip->set_number('9500805')->is_valid_number, '新潟県新潟市東区石動');
ok($zip->set_number('9500806')->is_valid_number, '新潟県新潟市東区海老ケ瀬');
ok($zip->set_number('9500807')->is_valid_number, '新潟県新潟市東区木工新町');
ok($zip->set_number('9500808')->is_valid_number, '新潟県新潟市東区海老ケ瀬新町');
ok($zip->set_number('9500809')->is_valid_number, '新潟県新潟市東区柳ケ丘');
ok($zip->set_number('9500811')->is_valid_number, '新潟県新潟市東区材木町');
ok($zip->set_number('9500812')->is_valid_number, '新潟県新潟市東区豊');
ok($zip->set_number('9500813')->is_valid_number, '新潟県新潟市東区大形本町');
ok($zip->set_number('9500814')->is_valid_number, '新潟県新潟市東区逢谷内');
ok($zip->set_number('9500821')->is_valid_number, '新潟県新潟市東区岡山');
ok($zip->set_number('9500822')->is_valid_number, '新潟県新潟市東区新岡山');
ok($zip->set_number('9500823')->is_valid_number, '新潟県新潟市東区東中島');
ok($zip->set_number('9500824')->is_valid_number, '新潟県新潟市東区中島');
ok($zip->set_number('9500825')->is_valid_number, '新潟県新潟市東区児池');
ok($zip->set_number('9500831')->is_valid_number, '新潟県新潟市東区下場');
ok($zip->set_number('9500832')->is_valid_number, '新潟県新潟市東区下場新町');
ok($zip->set_number('9500833')->is_valid_number, '新潟県新潟市東区下場本町');
ok($zip->set_number('9500834')->is_valid_number, '新潟県新潟市東区石山団地');
ok($zip->set_number('9500835')->is_valid_number, '新潟県新潟市東区猿ケ馬場');
ok($zip->set_number('9500836')->is_valid_number, '新潟県新潟市東区東中野山');
ok($zip->set_number('9500837')->is_valid_number, '新潟県新潟市東区若葉町');
ok($zip->set_number('9500841')->is_valid_number, '新潟県新潟市東区中野山');
ok($zip->set_number('9500841')->is_valid_number, '新潟県新潟市江南区中野山');
ok($zip->set_number('9500842')->is_valid_number, '新潟県新潟市東区もえぎ野');
ok($zip->set_number('9500843')->is_valid_number, '新潟県新潟市東区粟山');
ok($zip->set_number('9500843')->is_valid_number, '新潟県新潟市江南区粟山');
ok($zip->set_number('9500851')->is_valid_number, '新潟県新潟市東区新石山');
ok($zip->set_number('9500852')->is_valid_number, '新潟県新潟市東区石山');
ok($zip->set_number('9500853')->is_valid_number, '新潟県新潟市東区東明');
ok($zip->set_number('9500854')->is_valid_number, '新潟県新潟市東区南紫竹');
ok($zip->set_number('9500855')->is_valid_number, '新潟県新潟市東区江南');
ok($zip->set_number('9500861')->is_valid_number, '新潟県新潟市東区中山');
ok($zip->set_number('9500862')->is_valid_number, '新潟県新潟市東区竹尾');
ok($zip->set_number('9500863')->is_valid_number, '新潟県新潟市東区卸新町');
ok($zip->set_number('9500864')->is_valid_number, '新潟県新潟市東区紫竹');
ok($zip->set_number('9500864')->is_valid_number, '新潟県新潟市中央区紫竹');
ok($zip->set_number('9500865')->is_valid_number, '新潟県新潟市中央区本馬越');
ok($zip->set_number('9500866')->is_valid_number, '新潟県新潟市中央区西馬越');
ok($zip->set_number('9500867')->is_valid_number, '新潟県新潟市東区竹尾卸新町');
ok($zip->set_number('9500868')->is_valid_number, '新潟県新潟市東区紫竹卸新町');
ok($zip->set_number('9500871')->is_valid_number, '新潟県新潟市東区山木戸');
ok($zip->set_number('9500871')->is_valid_number, '新潟県新潟市中央区山木戸');
ok($zip->set_number('9500872')->is_valid_number, '新潟県新潟市東区牡丹山');
ok($zip->set_number('9500881')->is_valid_number, '新潟県新潟市東区榎町');
ok($zip->set_number('9500882')->is_valid_number, '新潟県新潟市東区王瀬新町');
ok($zip->set_number('9500883')->is_valid_number, '新潟県新潟市東区鴎島町');
ok($zip->set_number('9500884')->is_valid_number, '新潟県新潟市東区榎');
ok($zip->set_number('9500885')->is_valid_number, '新潟県新潟市東区下木戸');
ok($zip->set_number('9500886')->is_valid_number, '新潟県新潟市東区中木戸');
ok($zip->set_number('9500891')->is_valid_number, '新潟県新潟市東区上木戸');
ok($zip->set_number('9500892')->is_valid_number, '新潟県新潟市東区寺山');
ok($zip->set_number('9500893')->is_valid_number, '新潟県新潟市東区はなみずき');
ok($zip->set_number('9500901')->is_valid_number, '新潟県新潟市中央区弁天');
ok($zip->set_number('9500902')->is_valid_number, '新潟県新潟市中央区南万代町');
ok($zip->set_number('9500903')->is_valid_number, '新潟県新潟市中央区春日町');
ok($zip->set_number('9500904')->is_valid_number, '新潟県新潟市中央区水島町');
ok($zip->set_number('9500905')->is_valid_number, '新潟県新潟市中央区天神尾');
ok($zip->set_number('9500906')->is_valid_number, '新潟県新潟市中央区東幸町');
ok($zip->set_number('9500907')->is_valid_number, '新潟県新潟市中央区幸町');
ok($zip->set_number('9500908')->is_valid_number, '新潟県新潟市中央区幸西');
ok($zip->set_number('9500909')->is_valid_number, '新潟県新潟市中央区八千代');
ok($zip->set_number('9500911')->is_valid_number, '新潟県新潟市中央区笹口');
ok($zip->set_number('9500912')->is_valid_number, '新潟県新潟市中央区南笹口');
ok($zip->set_number('9500913')->is_valid_number, '新潟県新潟市中央区鐙');
ok($zip->set_number('9500914')->is_valid_number, '新潟県新潟市東区紫竹山');
ok($zip->set_number('9500914')->is_valid_number, '新潟県新潟市中央区紫竹山');
ok($zip->set_number('9500915')->is_valid_number, '新潟県新潟市中央区鐙西');
ok($zip->set_number('9500916')->is_valid_number, '新潟県新潟市中央区米山');
ok($zip->set_number('9500917')->is_valid_number, '新潟県新潟市中央区天神');
ok($zip->set_number('9500921')->is_valid_number, '新潟県新潟市中央区京王');
ok($zip->set_number('9500922')->is_valid_number, '新潟県新潟市中央区山二ツ');
ok($zip->set_number('9500922')->is_valid_number, '新潟県新潟市江南区山二ツ');
ok($zip->set_number('9500923')->is_valid_number, '新潟県新潟市中央区姥ケ山');
ok($zip->set_number('9500923')->is_valid_number, '新潟県新潟市江南区姥ケ山');
ok($zip->set_number('9500924')->is_valid_number, '新潟県新潟市中央区美の里');
ok($zip->set_number('9500925')->is_valid_number, '新潟県新潟市中央区弁天橋通');
ok($zip->set_number('9500926')->is_valid_number, '新潟県新潟市中央区高志');
ok($zip->set_number('9500931')->is_valid_number, '新潟県新潟市中央区南長潟');
ok($zip->set_number('9500932')->is_valid_number, '新潟県新潟市中央区長潟');
ok($zip->set_number('9500932')->is_valid_number, '新潟県新潟市江南区長潟(番地)');
ok($zip->set_number('9500933')->is_valid_number, '新潟県新潟市中央区清五郎');
ok($zip->set_number('9500933')->is_valid_number, '新潟県新潟市江南区清五郎');
ok($zip->set_number('9500941')->is_valid_number, '新潟県新潟市中央区女池');
ok($zip->set_number('9500942')->is_valid_number, '新潟県新潟市中央区小張木');
ok($zip->set_number('9500943')->is_valid_number, '新潟県新潟市中央区女池神明');
ok($zip->set_number('9500944')->is_valid_number, '新潟県新潟市中央区愛宕');
ok($zip->set_number('9500945')->is_valid_number, '新潟県新潟市中央区女池上山');
ok($zip->set_number('9500946')->is_valid_number, '新潟県新潟市中央区女池西');
ok($zip->set_number('9500947')->is_valid_number, '新潟県新潟市中央区女池北');
ok($zip->set_number('9500948')->is_valid_number, '新潟県新潟市中央区女池南');
ok($zip->set_number('9500949')->is_valid_number, '新潟県新潟市中央区桜木町');
ok($zip->set_number('9500950')->is_valid_number, '新潟県新潟市中央区鳥屋野南');
ok($zip->set_number('9500951')->is_valid_number, '新潟県新潟市中央区鳥屋野');
ok($zip->set_number('9500952')->is_valid_number, '新潟県新潟市中央区親松');
ok($zip->set_number('9500953')->is_valid_number, '新潟県新潟市中央区大島');
ok($zip->set_number('9500954')->is_valid_number, '新潟県新潟市中央区美咲町');
ok($zip->set_number('9500961')->is_valid_number, '新潟県新潟市中央区東出来島');
ok($zip->set_number('9500962')->is_valid_number, '新潟県新潟市中央区出来島');
ok($zip->set_number('9500963')->is_valid_number, '新潟県新潟市中央区南出来島');
ok($zip->set_number('9500964')->is_valid_number, '新潟県新潟市中央区網川原');
ok($zip->set_number('9500965')->is_valid_number, '新潟県新潟市中央区新光町');
ok($zip->set_number('9500971')->is_valid_number, '新潟県新潟市中央区近江');
ok($zip->set_number('9500972')->is_valid_number, '新潟県新潟市中央区新和');
ok($zip->set_number('9500973')->is_valid_number, '新潟県新潟市中央区上近江');
ok($zip->set_number('9500981')->is_valid_number, '新潟県新潟市中央区堀之内');
ok($zip->set_number('9500982')->is_valid_number, '新潟県新潟市中央区堀之内南');
ok($zip->set_number('9500983')->is_valid_number, '新潟県新潟市中央区神道寺');
ok($zip->set_number('9500984')->is_valid_number, '新潟県新潟市中央区女池東');
ok($zip->set_number('9500985')->is_valid_number, '新潟県新潟市中央区和合町');
ok($zip->set_number('9500986')->is_valid_number, '新潟県新潟市中央区神道寺南');
ok($zip->set_number('9500991')->is_valid_number, '新潟県新潟市中央区下所島');
ok($zip->set_number('9500992')->is_valid_number, '新潟県新潟市中央区上所上');
ok($zip->set_number('9500993')->is_valid_number, '新潟県新潟市中央区上所中');
ok($zip->set_number('9500994')->is_valid_number, '新潟県新潟市中央区上所');
ok($zip->set_number('9501101')->is_valid_number, '新潟県新潟市西区山田');
ok($zip->set_number('9501102')->is_valid_number, '新潟県新潟市西区善久');
ok($zip->set_number('9501103')->is_valid_number, '新潟県新潟市西区立仏');
ok($zip->set_number('9501104')->is_valid_number, '新潟県新潟市西区寺地');
ok($zip->set_number('9501105')->is_valid_number, '新潟県新潟市西区ときめき東');
ok($zip->set_number('9501106')->is_valid_number, '新潟県新潟市西区ときめき西');
ok($zip->set_number('9501111')->is_valid_number, '新潟県新潟市西区大野町');
ok($zip->set_number('9501112')->is_valid_number, '新潟県新潟市西区金巻');
ok($zip->set_number('9501113')->is_valid_number, '新潟県新潟市西区鳥原新田');
ok($zip->set_number('9501114')->is_valid_number, '新潟県新潟市西区小平方');
ok($zip->set_number('9501115')->is_valid_number, '新潟県新潟市西区鳥原');
ok($zip->set_number('9501121')->is_valid_number, '新潟県新潟市西区板井');
ok($zip->set_number('9501122')->is_valid_number, '新潟県新潟市西区木場');
ok($zip->set_number('9501123')->is_valid_number, '新潟県新潟市西区黒鳥');
ok($zip->set_number('9501124')->is_valid_number, '新潟県新潟市西区緒立流通');
ok($zip->set_number('9501125')->is_valid_number, '新潟県新潟市西区流通');
ok($zip->set_number('9501126')->is_valid_number, '新潟県新潟市西区北場');
ok($zip->set_number('9501127')->is_valid_number, '新潟県新潟市西区大潟');
ok($zip->set_number('9501131')->is_valid_number, '新潟県新潟市中央区鍋潟新田');
ok($zip->set_number('9501131')->is_valid_number, '新潟県新潟市江南区鍋潟新田');
ok($zip->set_number('9501132')->is_valid_number, '新潟県新潟市中央区丸潟新田');
ok($zip->set_number('9501132')->is_valid_number, '新潟県新潟市江南区丸潟新田');
ok($zip->set_number('9501133')->is_valid_number, '新潟県新潟市中央区嘉木');
ok($zip->set_number('9501133')->is_valid_number, '新潟県新潟市江南区嘉木');
ok($zip->set_number('9501134')->is_valid_number, '新潟県新潟市江南区天野');
ok($zip->set_number('9501134')->is_valid_number, '新潟県新潟市南区天野');
ok($zip->set_number('9501135')->is_valid_number, '新潟県新潟市江南区曽野木');
ok($zip->set_number('9501136')->is_valid_number, '新潟県新潟市中央区曽川');
ok($zip->set_number('9501136')->is_valid_number, '新潟県新潟市江南区曽川');
ok($zip->set_number('9501141')->is_valid_number, '新潟県新潟市中央区鐘木');
ok($zip->set_number('9501141')->is_valid_number, '新潟県新潟市江南区鐘木');
ok($zip->set_number('9501142')->is_valid_number, '新潟県新潟市江南区楚川');
ok($zip->set_number('9501143')->is_valid_number, '新潟県新潟市中央区俵柳');
ok($zip->set_number('9501143')->is_valid_number, '新潟県新潟市江南区俵柳');
ok($zip->set_number('9501144')->is_valid_number, '新潟県新潟市中央区祖父興野');
ok($zip->set_number('9501144')->is_valid_number, '新潟県新潟市江南区祖父興野');
ok($zip->set_number('9501145')->is_valid_number, '新潟県新潟市中央区久蔵興野');
ok($zip->set_number('9501145')->is_valid_number, '新潟県新潟市江南区久蔵興野');
ok($zip->set_number('9501146')->is_valid_number, '新潟県新潟市中央区太右エ門新田');
ok($zip->set_number('9501146')->is_valid_number, '新潟県新潟市江南区太右エ門新田');
ok($zip->set_number('9501147')->is_valid_number, '新潟県新潟市中央区高美町');
ok($zip->set_number('9501148')->is_valid_number, '新潟県新潟市中央区上沼');
ok($zip->set_number('9501151')->is_valid_number, '新潟県新潟市中央区湖南');
ok($zip->set_number('9501200')->is_valid_number, '新潟県新潟市南区以下に掲載がない場合');
ok($zip->set_number('9501201')->is_valid_number, '新潟県新潟市南区大通');
ok($zip->set_number('9501202')->is_valid_number, '新潟県新潟市南区大通南');
ok($zip->set_number('9501203')->is_valid_number, '新潟県新潟市南区大通黄金');
ok($zip->set_number('9501204')->is_valid_number, '新潟県新潟市南区大通西');
ok($zip->set_number('9501208')->is_valid_number, '新潟県新潟市南区杉菜');
ok($zip->set_number('9501209')->is_valid_number, '新潟県新潟市南区親和町');
ok($zip->set_number('9501211')->is_valid_number, '新潟県新潟市南区白根古川');
ok($zip->set_number('9501212')->is_valid_number, '新潟県新潟市南区七軒');
ok($zip->set_number('9501213')->is_valid_number, '新潟県新潟市南区能登');
ok($zip->set_number('9501214')->is_valid_number, '新潟県新潟市南区上下諏訪木');
ok($zip->set_number('9501215')->is_valid_number, '新潟県新潟市南区助次右エ門組');
ok($zip->set_number('9501216')->is_valid_number, '新潟県新潟市南区白根ノ内七軒');
ok($zip->set_number('9501217')->is_valid_number, '新潟県新潟市南区白根');
ok($zip->set_number('9501218')->is_valid_number, '新潟県新潟市南区白根魚町');
ok($zip->set_number('9501221')->is_valid_number, '新潟県新潟市南区神屋');
ok($zip->set_number('9501222')->is_valid_number, '新潟県新潟市南区白根東町');
ok($zip->set_number('9501223')->is_valid_number, '新潟県新潟市南区白根日の出町');
ok($zip->set_number('9501224')->is_valid_number, '新潟県新潟市南区白根水道町');
ok($zip->set_number('9501225')->is_valid_number, '新潟県新潟市南区七軒町');
ok($zip->set_number('9501226')->is_valid_number, '新潟県新潟市南区白根四ツ興野');
ok($zip->set_number('9501227')->is_valid_number, '新潟県新潟市南区鰺潟');
ok($zip->set_number('9501231')->is_valid_number, '新潟県新潟市南区小坂');
ok($zip->set_number('9501232')->is_valid_number, '新潟県新潟市南区十五間');
ok($zip->set_number('9501233')->is_valid_number, '新潟県新潟市南区保坂');
ok($zip->set_number('9501234')->is_valid_number, '新潟県新潟市南区根岸');
ok($zip->set_number('9501235')->is_valid_number, '新潟県新潟市南区高井興野');
ok($zip->set_number('9501236')->is_valid_number, '新潟県新潟市南区高井東');
ok($zip->set_number('9501237')->is_valid_number, '新潟県新潟市南区北田中');
ok($zip->set_number('9501241')->is_valid_number, '新潟県新潟市南区下塩俵');
ok($zip->set_number('9501242')->is_valid_number, '新潟県新潟市南区中塩俵');
ok($zip->set_number('9501243')->is_valid_number, '新潟県新潟市南区松橋');
ok($zip->set_number('9501244')->is_valid_number, '新潟県新潟市南区上塩俵');
ok($zip->set_number('9501245')->is_valid_number, '新潟県新潟市南区新山崎町');
ok($zip->set_number('9501246')->is_valid_number, '新潟県新潟市南区下山崎');
ok($zip->set_number('9501247')->is_valid_number, '新潟県新潟市南区山崎興野');
ok($zip->set_number('9501251')->is_valid_number, '新潟県新潟市南区居宿');
ok($zip->set_number('9501252')->is_valid_number, '新潟県新潟市南区大倉');
ok($zip->set_number('9501253')->is_valid_number, '新潟県新潟市南区大倉新田');
ok($zip->set_number('9501254')->is_valid_number, '新潟県新潟市南区七穂');
ok($zip->set_number('9501255')->is_valid_number, '新潟県新潟市南区山王');
ok($zip->set_number('9501256')->is_valid_number, '新潟県新潟市南区山王新田');
ok($zip->set_number('9501257')->is_valid_number, '新潟県新潟市南区吉田新田');
ok($zip->set_number('9501258')->is_valid_number, '新潟県新潟市南区吉江');
ok($zip->set_number('9501261')->is_valid_number, '新潟県新潟市南区味方');
ok($zip->set_number('9501261')->is_valid_number, '新潟県新潟市西蒲区味方');
ok($zip->set_number('9501262')->is_valid_number, '新潟県新潟市南区西白根');
ok($zip->set_number('9501301')->is_valid_number, '新潟県新潟市南区下曲通');
ok($zip->set_number('9501302')->is_valid_number, '新潟県新潟市南区上曲通');
ok($zip->set_number('9501303')->is_valid_number, '新潟県新潟市南区西萱場');
ok($zip->set_number('9501304')->is_valid_number, '新潟県新潟市南区月潟');
ok($zip->set_number('9501305')->is_valid_number, '新潟県新潟市南区大別當');
ok($zip->set_number('9501311')->is_valid_number, '新潟県新潟市南区木滑');
ok($zip->set_number('9501312')->is_valid_number, '新潟県新潟市南区釣寄新');
ok($zip->set_number('9501312')->is_valid_number, '新潟県新潟市西蒲区釣寄新');
ok($zip->set_number('9501313')->is_valid_number, '新潟県新潟市南区釣寄');
ok($zip->set_number('9501313')->is_valid_number, '新潟県新潟市西蒲区釣寄');
ok($zip->set_number('9501314')->is_valid_number, '新潟県新潟市南区東長嶋');
ok($zip->set_number('9501321')->is_valid_number, '新潟県新潟市西蒲区針ケ曽根');
ok($zip->set_number('9501322')->is_valid_number, '新潟県新潟市西蒲区六分');
ok($zip->set_number('9501323')->is_valid_number, '新潟県新潟市西蒲区東小吉');
ok($zip->set_number('9501324')->is_valid_number, '新潟県新潟市西蒲区高野宮');
ok($zip->set_number('9501325')->is_valid_number, '新潟県新潟市西蒲区小吉');
ok($zip->set_number('9501326')->is_valid_number, '新潟県新潟市西蒲区東船越');
ok($zip->set_number('9501327')->is_valid_number, '新潟県新潟市西蒲区中之口');
ok($zip->set_number('9501328')->is_valid_number, '新潟県新潟市西蒲区門田');
ok($zip->set_number('9501331')->is_valid_number, '新潟県新潟市西蒲区東中');
ok($zip->set_number('9501332')->is_valid_number, '新潟県新潟市西蒲区長場');
ok($zip->set_number('9501333')->is_valid_number, '新潟県新潟市西蒲区潟浦新');
ok($zip->set_number('9501334')->is_valid_number, '新潟県新潟市西蒲区上小吉');
ok($zip->set_number('9501341')->is_valid_number, '新潟県新潟市西蒲区道上');
ok($zip->set_number('9501342')->is_valid_number, '新潟県新潟市西蒲区河間');
ok($zip->set_number('9501343')->is_valid_number, '新潟県新潟市西蒲区三ツ門');
ok($zip->set_number('9501344')->is_valid_number, '新潟県新潟市南区福島');
ok($zip->set_number('9501344')->is_valid_number, '新潟県新潟市西蒲区福島');
ok($zip->set_number('9501345')->is_valid_number, '新潟県新潟市西蒲区羽黒');
ok($zip->set_number('9501346')->is_valid_number, '新潟県新潟市西蒲区真木');
ok($zip->set_number('9501347')->is_valid_number, '新潟県新潟市西蒲区姥島');
ok($zip->set_number('9501348')->is_valid_number, '新潟県新潟市西蒲区打越');
ok($zip->set_number('9501349')->is_valid_number, '新潟県新潟市西蒲区牧ケ島');
ok($zip->set_number('9501401')->is_valid_number, '新潟県新潟市南区獺ヶ通');
ok($zip->set_number('9501402')->is_valid_number, '新潟県新潟市南区西酒屋');
ok($zip->set_number('9501403')->is_valid_number, '新潟県新潟市南区犬帰新田');
ok($zip->set_number('9501404')->is_valid_number, '新潟県新潟市南区大郷');
ok($zip->set_number('9501405')->is_valid_number, '新潟県新潟市南区東笠巻');
ok($zip->set_number('9501406')->is_valid_number, '新潟県新潟市南区東笠巻新田');
ok($zip->set_number('9501407')->is_valid_number, '新潟県新潟市南区鷲ノ木新田');
ok($zip->set_number('9501411')->is_valid_number, '新潟県新潟市南区赤渋');
ok($zip->set_number('9501412')->is_valid_number, '新潟県新潟市南区臼井');
ok($zip->set_number('9501413')->is_valid_number, '新潟県新潟市南区朝捲');
ok($zip->set_number('9501414')->is_valid_number, '新潟県新潟市南区小蔵子');
ok($zip->set_number('9501415')->is_valid_number, '新潟県新潟市南区引越');
ok($zip->set_number('9501416')->is_valid_number, '新潟県新潟市南区西笠巻');
ok($zip->set_number('9501417')->is_valid_number, '新潟県新潟市南区西笠巻新田');
ok($zip->set_number('9501421')->is_valid_number, '新潟県新潟市南区中山');
ok($zip->set_number('9501422')->is_valid_number, '新潟県新潟市南区堀掛');
ok($zip->set_number('9501423')->is_valid_number, '新潟県新潟市南区中小見');
ok($zip->set_number('9501424')->is_valid_number, '新潟県新潟市南区下八枚');
ok($zip->set_number('9501425')->is_valid_number, '新潟県新潟市南区戸石');
ok($zip->set_number('9501426')->is_valid_number, '新潟県新潟市南区新生町');
ok($zip->set_number('9501428')->is_valid_number, '新潟県新潟市南区上浦');
ok($zip->set_number('9501431')->is_valid_number, '新潟県新潟市南区上八枚');
ok($zip->set_number('9501432')->is_valid_number, '新潟県新潟市南区十二道島');
ok($zip->set_number('9501433')->is_valid_number, '新潟県新潟市南区次郎右エ門興野');
ok($zip->set_number('9501434')->is_valid_number, '新潟県新潟市南区櫛笥');
ok($zip->set_number('9501435')->is_valid_number, '新潟県新潟市南区万年');
ok($zip->set_number('9501436')->is_valid_number, '新潟県新潟市南区田尾');
ok($zip->set_number('9501437')->is_valid_number, '新潟県新潟市南区鍋潟');
ok($zip->set_number('9501441')->is_valid_number, '新潟県新潟市南区蜘手興野');
ok($zip->set_number('9501442')->is_valid_number, '新潟県新潟市南区鋳物師興野');
ok($zip->set_number('9501443')->is_valid_number, '新潟県新潟市南区菱潟');
ok($zip->set_number('9501444')->is_valid_number, '新潟県新潟市南区牛崎');
ok($zip->set_number('9501445')->is_valid_number, '新潟県新潟市南区菱潟新田');
ok($zip->set_number('9501446')->is_valid_number, '新潟県新潟市南区庄瀬');
ok($zip->set_number('9501447')->is_valid_number, '新潟県新潟市南区飯島');
ok($zip->set_number('9501451')->is_valid_number, '新潟県新潟市南区真木');
ok($zip->set_number('9501452')->is_valid_number, '新潟県新潟市南区古川新田');
ok($zip->set_number('9501453')->is_valid_number, '新潟県新潟市南区兎新田');
ok($zip->set_number('9501454')->is_valid_number, '新潟県新潟市南区上新田');
ok($zip->set_number('9501455')->is_valid_number, '新潟県新潟市南区新飯田');
ok($zip->set_number('9501456')->is_valid_number, '新潟県新潟市南区茨曽根');
ok($zip->set_number('9501457')->is_valid_number, '新潟県新潟市南区清水');
ok($zip->set_number('9501461')->is_valid_number, '新潟県新潟市南区平潟');
ok($zip->set_number('9501462')->is_valid_number, '新潟県新潟市南区蔵主');
ok($zip->set_number('9501463')->is_valid_number, '新潟県新潟市南区平潟新田');
ok($zip->set_number('9501464')->is_valid_number, '新潟県新潟市南区下道潟');
ok($zip->set_number('9501465')->is_valid_number, '新潟県新潟市南区上道潟');
ok($zip->set_number('9501466')->is_valid_number, '新潟県新潟市南区沖新保');
ok($zip->set_number('9501467')->is_valid_number, '新潟県新潟市南区東萱場');
ok($zip->set_number('9501471')->is_valid_number, '新潟県新潟市南区和泉');
ok($zip->set_number('9501472')->is_valid_number, '新潟県新潟市南区浦梨');
ok($zip->set_number('9501473')->is_valid_number, '新潟県新潟市南区下木山');
ok($zip->set_number('9501474')->is_valid_number, '新潟県新潟市南区上木山');
ok($zip->set_number('9501475')->is_valid_number, '新潟県新潟市南区戸頭');
ok($zip->set_number('9501476')->is_valid_number, '新潟県新潟市南区平成町');
ok($zip->set_number('9501477')->is_valid_number, '新潟県新潟市南区田中');
ok($zip->set_number('9502001')->is_valid_number, '新潟県新潟市西区浦山');
ok($zip->set_number('9502002')->is_valid_number, '新潟県新潟市西区青山');
ok($zip->set_number('9502003')->is_valid_number, '新潟県新潟市西区東青山');
ok($zip->set_number('9502004')->is_valid_number, '新潟県新潟市西区平島');
ok($zip->set_number('9502005')->is_valid_number, '新潟県新潟市西区青山水道');
ok($zip->set_number('9502006')->is_valid_number, '新潟県新潟市西区青山新町');
ok($zip->set_number('9502011')->is_valid_number, '新潟県新潟市西区小針上山');
ok($zip->set_number('9502012')->is_valid_number, '新潟県新潟市西区小針台');
ok($zip->set_number('9502013')->is_valid_number, '新潟県新潟市西区小針が丘');
ok($zip->set_number('9502014')->is_valid_number, '新潟県新潟市西区小針西');
ok($zip->set_number('9502015')->is_valid_number, '新潟県新潟市西区西小針台');
ok($zip->set_number('9502021')->is_valid_number, '新潟県新潟市西区小針藤山');
ok($zip->set_number('9502022')->is_valid_number, '新潟県新潟市西区小針');
ok($zip->set_number('9502023')->is_valid_number, '新潟県新潟市西区小新');
ok($zip->set_number('9502024')->is_valid_number, '新潟県新潟市西区小新西');
ok($zip->set_number('9502025')->is_valid_number, '新潟県新潟市西区小針南');
ok($zip->set_number('9502026')->is_valid_number, '新潟県新潟市西区小針南台');
ok($zip->set_number('9502027')->is_valid_number, '新潟県新潟市西区小新大通');
ok($zip->set_number('9502028')->is_valid_number, '新潟県新潟市西区小新南');
ok($zip->set_number('9502031')->is_valid_number, '新潟県新潟市西区流通センター');
ok($zip->set_number('9502032')->is_valid_number, '新潟県新潟市西区的場流通');
ok($zip->set_number('9502033')->is_valid_number, '新潟県新潟市西区亀貝');
ok($zip->set_number('9502034')->is_valid_number, '新潟県新潟市西区新田');
ok($zip->set_number('9502035')->is_valid_number, '新潟県新潟市西区新通');
ok($zip->set_number('9502036')->is_valid_number, '新潟県新潟市西区新通西');
ok($zip->set_number('9502037')->is_valid_number, '新潟県新潟市西区大野');
ok($zip->set_number('9502038')->is_valid_number, '新潟県新潟市西区新通南');
ok($zip->set_number('9502041')->is_valid_number, '新潟県新潟市西区坂井東');
ok($zip->set_number('9502042')->is_valid_number, '新潟県新潟市西区坂井');
ok($zip->set_number('9502043')->is_valid_number, '新潟県新潟市西区須賀');
ok($zip->set_number('9502044')->is_valid_number, '新潟県新潟市西区坂井砂山');
ok($zip->set_number('9502045')->is_valid_number, '新潟県新潟市西区五十嵐東');
ok($zip->set_number('9502051')->is_valid_number, '新潟県新潟市西区寺尾朝日通');
ok($zip->set_number('9502052')->is_valid_number, '新潟県新潟市西区寺尾');
ok($zip->set_number('9502053')->is_valid_number, '新潟県新潟市西区寺尾前通');
ok($zip->set_number('9502054')->is_valid_number, '新潟県新潟市西区寺尾東');
ok($zip->set_number('9502055')->is_valid_number, '新潟県新潟市西区寺尾上');
ok($zip->set_number('9502061')->is_valid_number, '新潟県新潟市西区寺尾北');
ok($zip->set_number('9502062')->is_valid_number, '新潟県新潟市西区寺尾中央公園');
ok($zip->set_number('9502063')->is_valid_number, '新潟県新潟市西区寺尾台');
ok($zip->set_number('9502064')->is_valid_number, '新潟県新潟市西区寺尾西');
ok($zip->set_number('9502071')->is_valid_number, '新潟県新潟市西区西有明町');
ok($zip->set_number('9502072')->is_valid_number, '新潟県新潟市西区松美台');
ok($zip->set_number('9502073')->is_valid_number, '新潟県新潟市西区有明町');
ok($zip->set_number('9502074')->is_valid_number, '新潟県新潟市西区真砂');
ok($zip->set_number('9502075')->is_valid_number, '新潟県新潟市西区松海が丘');
ok($zip->set_number('9502076')->is_valid_number, '新潟県新潟市西区上新栄町');
ok($zip->set_number('9502101')->is_valid_number, '新潟県新潟市西区五十嵐一の町');
ok($zip->set_number('9502102')->is_valid_number, '新潟県新潟市西区五十嵐二の町');
ok($zip->set_number('9502111')->is_valid_number, '新潟県新潟市西区大学南');
ok($zip->set_number('9502112')->is_valid_number, '新潟県新潟市西区内野町');
ok($zip->set_number('9502113')->is_valid_number, '新潟県新潟市西区内野山手');
ok($zip->set_number('9502121')->is_valid_number, '新潟県新潟市西区槇尾');
ok($zip->set_number('9502122')->is_valid_number, '新潟県新潟市西区高山');
ok($zip->set_number('9502123')->is_valid_number, '新潟県新潟市西区笠木');
ok($zip->set_number('9502124')->is_valid_number, '新潟県新潟市西区田潟');
ok($zip->set_number('9502125')->is_valid_number, '新潟県新潟市西区中野小屋');
ok($zip->set_number('9502126')->is_valid_number, '新潟県新潟市西区大友');
ok($zip->set_number('9502131')->is_valid_number, '新潟県新潟市西区早潟');
ok($zip->set_number('9502132')->is_valid_number, '新潟県新潟市西区小瀬');
ok($zip->set_number('9502133')->is_valid_number, '新潟県新潟市西区前野外新田');
ok($zip->set_number('9502134')->is_valid_number, '新潟県新潟市西区保古野木');
ok($zip->set_number('9502135')->is_valid_number, '新潟県新潟市西区明田');
ok($zip->set_number('9502136')->is_valid_number, '新潟県新潟市西区勘助郷屋');
ok($zip->set_number('9502137')->is_valid_number, '新潟県新潟市西区小見郷屋');
ok($zip->set_number('9502138')->is_valid_number, '新潟県新潟市西区藤野木');
ok($zip->set_number('9502141')->is_valid_number, '新潟県新潟市西区内野潟端');
ok($zip->set_number('9502142')->is_valid_number, '新潟県新潟市西区内野戸中才');
ok($zip->set_number('9502143')->is_valid_number, '新潟県新潟市西区内野早角');
ok($zip->set_number('9502144')->is_valid_number, '新潟県新潟市西区曽和');
ok($zip->set_number('9502145')->is_valid_number, '新潟県新潟市西区田島');
ok($zip->set_number('9502146')->is_valid_number, '新潟県新潟市西区金巻新田');
ok($zip->set_number('9502147')->is_valid_number, '新潟県新潟市西区道河原');
ok($zip->set_number('9502151')->is_valid_number, '新潟県新潟市西区内野西');
ok($zip->set_number('9502152')->is_valid_number, '新潟県新潟市西区五十嵐下崎山');
ok($zip->set_number('9502153')->is_valid_number, '新潟県新潟市西区内野崎山');
ok($zip->set_number('9502154')->is_valid_number, '新潟県新潟市西区内野潟向');
ok($zip->set_number('9502155')->is_valid_number, '新潟県新潟市西区五十嵐上崎山');
ok($zip->set_number('9502156')->is_valid_number, '新潟県新潟市西区内野関場');
ok($zip->set_number('9502157')->is_valid_number, '新潟県新潟市西区内野西が丘');
ok($zip->set_number('9502161')->is_valid_number, '新潟県新潟市西区五十嵐西');
ok($zip->set_number('9502162')->is_valid_number, '新潟県新潟市西区五十嵐中島');
ok($zip->set_number('9502163')->is_valid_number, '新潟県新潟市西区新中浜');
ok($zip->set_number('9502164')->is_valid_number, '新潟県新潟市西区内野中浜');
ok($zip->set_number('9502171')->is_valid_number, '新潟県新潟市西区五十嵐三の町');
ok($zip->set_number('9502172')->is_valid_number, '新潟県新潟市西区内野上新町');
ok($zip->set_number('9502173')->is_valid_number, '新潟県新潟市西区五十嵐三の町東');
ok($zip->set_number('9502174')->is_valid_number, '新潟県新潟市西区五十嵐三の町西');
ok($zip->set_number('9502175')->is_valid_number, '新潟県新潟市西区五十嵐三の町南');
ok($zip->set_number('9502176')->is_valid_number, '新潟県新潟市西区五十嵐三の町北');
ok($zip->set_number('9502177')->is_valid_number, '新潟県新潟市西区五十嵐三の町中');
ok($zip->set_number('9502201')->is_valid_number, '新潟県新潟市西区四ツ郷屋');
ok($zip->set_number('9502251')->is_valid_number, '新潟県新潟市西区中権寺');
ok($zip->set_number('9502252')->is_valid_number, '新潟県新潟市西区谷内');
ok($zip->set_number('9502253')->is_valid_number, '新潟県新潟市西区木山');
ok($zip->set_number('9502254')->is_valid_number, '新潟県新潟市西区東山');
ok($zip->set_number('9502255')->is_valid_number, '新潟県新潟市西区神山');
ok($zip->set_number('9502256')->is_valid_number, '新潟県新潟市西区山崎');
ok($zip->set_number('9502261')->is_valid_number, '新潟県新潟市西区赤塚');
ok($zip->set_number('9502262')->is_valid_number, '新潟県新潟市西区藤蔵新田');
ok($zip->set_number('9502263')->is_valid_number, '新潟県新潟市西区坂田');
ok($zip->set_number('9502264')->is_valid_number, '新潟県新潟市西区みずき野');
ok($zip->set_number('9503101')->is_valid_number, '新潟県新潟市北区太郎代');
ok($zip->set_number('9503102')->is_valid_number, '新潟県新潟市北区島見町');
ok($zip->set_number('9503103')->is_valid_number, '新潟県新潟市北区白勢町');
ok($zip->set_number('9503104')->is_valid_number, '新潟県新潟市北区東栄町');
ok($zip->set_number('9503105')->is_valid_number, '新潟県新潟市北区新富町');
ok($zip->set_number('9503111')->is_valid_number, '新潟県新潟市北区太夫浜新町');
ok($zip->set_number('9503112')->is_valid_number, '新潟県新潟市北区太夫浜');
ok($zip->set_number('9503113')->is_valid_number, '新潟県新潟市北区松栄町');
ok($zip->set_number('9503114')->is_valid_number, '新潟県新潟市北区名目所');
ok($zip->set_number('9503115')->is_valid_number, '新潟県新潟市北区松浜新町');
ok($zip->set_number('9503116')->is_valid_number, '新潟県新潟市北区神谷内');
ok($zip->set_number('9503121')->is_valid_number, '新潟県新潟市北区松浜町');
ok($zip->set_number('9503122')->is_valid_number, '新潟県新潟市北区西名目所');
ok($zip->set_number('9503123')->is_valid_number, '新潟県新潟市北区新元島町');
ok($zip->set_number('9503124')->is_valid_number, '新潟県新潟市北区三軒屋町');
ok($zip->set_number('9503125')->is_valid_number, '新潟県新潟市北区松浜本町');
ok($zip->set_number('9503126')->is_valid_number, '新潟県新潟市北区松浜');
ok($zip->set_number('9503127')->is_valid_number, '新潟県新潟市北区松浜みなと');
ok($zip->set_number('9503128')->is_valid_number, '新潟県新潟市北区松浜東町');
ok($zip->set_number('9503131')->is_valid_number, '新潟県新潟市北区濁川');
ok($zip->set_number('9503132')->is_valid_number, '新潟県新潟市北区松潟');
ok($zip->set_number('9503133')->is_valid_number, '新潟県新潟市北区すみれ野');
ok($zip->set_number('9503134')->is_valid_number, '新潟県新潟市北区新崎');
ok($zip->set_number('9503135')->is_valid_number, '新潟県新潟市北区つくし野');
ok($zip->set_number('9503301')->is_valid_number, '新潟県新潟市北区笹山');
ok($zip->set_number('9503302')->is_valid_number, '新潟県新潟市北区浜浦');
ok($zip->set_number('9503303')->is_valid_number, '新潟県新潟市北区横土居');
ok($zip->set_number('9503304')->is_valid_number, '新潟県新潟市北区木崎');
ok($zip->set_number('9503305')->is_valid_number, '新潟県新潟市北区浦ノ入');
ok($zip->set_number('9503306')->is_valid_number, '新潟県新潟市北区内島見');
ok($zip->set_number('9503307')->is_valid_number, '新潟県新潟市北区樋ノ入');
ok($zip->set_number('9503308')->is_valid_number, '新潟県新潟市北区下大谷内');
ok($zip->set_number('9503309')->is_valid_number, '新潟県新潟市北区北陽');
ok($zip->set_number('9503311')->is_valid_number, '新潟県新潟市北区横井');
ok($zip->set_number('9503312')->is_valid_number, '新潟県新潟市北区笠柳');
ok($zip->set_number('9503313')->is_valid_number, '新潟県新潟市北区太田');
ok($zip->set_number('9503314')->is_valid_number, '新潟県新潟市北区村新田');
ok($zip->set_number('9503315')->is_valid_number, '新潟県新潟市北区朝日町');
ok($zip->set_number('9503316')->is_valid_number, '新潟県新潟市北区鳥屋');
ok($zip->set_number('9503317')->is_valid_number, '新潟県新潟市北区かぶとやま');
ok($zip->set_number('9503321')->is_valid_number, '新潟県新潟市北区葛塚');
ok($zip->set_number('9503322')->is_valid_number, '新潟県新潟市北区嘉山');
ok($zip->set_number('9503323')->is_valid_number, '新潟県新潟市北区東栄町');
ok($zip->set_number('9503324')->is_valid_number, '新潟県新潟市北区前新田');
ok($zip->set_number('9503325')->is_valid_number, '新潟県新潟市北区白新町');
ok($zip->set_number('9503326')->is_valid_number, '新潟県新潟市北区柳原');
ok($zip->set_number('9503327')->is_valid_number, '新潟県新潟市北区石動');
ok($zip->set_number('9503328')->is_valid_number, '新潟県新潟市北区前新田沖');
ok($zip->set_number('9503331')->is_valid_number, '新潟県新潟市北区新鼻');
ok($zip->set_number('9503332')->is_valid_number, '新潟県新潟市北区新鼻甲');
ok($zip->set_number('9503333')->is_valid_number, '新潟県新潟市北区内沼');
ok($zip->set_number('9503334')->is_valid_number, '新潟県新潟市北区大月');
ok($zip->set_number('9503335')->is_valid_number, '新潟県新潟市北区上大月');
ok($zip->set_number('9503336')->is_valid_number, '新潟県新潟市北区岡新田');
ok($zip->set_number('9503337')->is_valid_number, '新潟県新潟市北区里飯野');
ok($zip->set_number('9503338')->is_valid_number, '新潟県新潟市北区長場');
ok($zip->set_number('9503339')->is_valid_number, '新潟県新潟市北区新鼻乙');
ok($zip->set_number('9503341')->is_valid_number, '新潟県新潟市北区川西');
ok($zip->set_number('9503342')->is_valid_number, '新潟県新潟市北区美里');
ok($zip->set_number('9503343')->is_valid_number, '新潟県新潟市北区上土地亀');
ok($zip->set_number('9503344')->is_valid_number, '新潟県新潟市北区浦木');
ok($zip->set_number('9503345')->is_valid_number, '新潟県新潟市北区長戸');
ok($zip->set_number('9503346')->is_valid_number, '新潟県新潟市北区下土地亀');
ok($zip->set_number('9503350')->is_valid_number, '新潟県新潟市北区横越');
ok($zip->set_number('9503351')->is_valid_number, '新潟県新潟市北区大瀬柳');
ok($zip->set_number('9503352')->is_valid_number, '新潟県新潟市北区長戸呂新田');
ok($zip->set_number('9503353')->is_valid_number, '新潟県新潟市北区長戸呂');
ok($zip->set_number('9503354')->is_valid_number, '新潟県新潟市北区十二');
ok($zip->set_number('9503355')->is_valid_number, '新潟県新潟市北区上堀田');
ok($zip->set_number('9503356')->is_valid_number, '新潟県新潟市北区山飯野');
ok($zip->set_number('9503357')->is_valid_number, '新潟県新潟市北区平林');
ok($zip->set_number('9503358')->is_valid_number, '新潟県新潟市北区灰塚');
ok($zip->set_number('9503359')->is_valid_number, '新潟県新潟市北区十二前');
ok($zip->set_number('9503360')->is_valid_number, '新潟県新潟市北区小杉');
ok($zip->set_number('9503361')->is_valid_number, '新潟県新潟市北区新井郷');
ok($zip->set_number('9503362')->is_valid_number, '新潟県新潟市北区高森新田');
ok($zip->set_number('9503363')->is_valid_number, '新潟県新潟市北区大久保');
ok($zip->set_number('9503364')->is_valid_number, '新潟県新潟市北区大迎');
ok($zip->set_number('9503365')->is_valid_number, '新潟県新潟市北区太子堂');
ok($zip->set_number('9503366')->is_valid_number, '新潟県新潟市北区三ツ屋');
ok($zip->set_number('9503367')->is_valid_number, '新潟県新潟市北区高森');
ok($zip->set_number('9503368')->is_valid_number, '新潟県新潟市北区森下');
ok($zip->set_number('9503369')->is_valid_number, '新潟県新潟市北区三ツ森川原');
ok($zip->set_number('9503371')->is_valid_number, '新潟県新潟市北区下早通');
ok($zip->set_number('9503372')->is_valid_number, '新潟県新潟市北区早通');
ok($zip->set_number('9503373')->is_valid_number, '新潟県新潟市北区須戸');
ok($zip->set_number('9503374')->is_valid_number, '新潟県新潟市北区仏伝');
ok($zip->set_number('9503375')->is_valid_number, '新潟県新潟市北区早通南');
ok($zip->set_number('9503376')->is_valid_number, '新潟県新潟市北区早通北');
ok($zip->set_number('9503377')->is_valid_number, '新潟県新潟市北区彩野');
ok($zip->set_number('9503381')->is_valid_number, '新潟県新潟市北区内沼沖');
ok($zip->set_number('9518001')->is_valid_number, '新潟県新潟市中央区海辺町');
ok($zip->set_number('9518002')->is_valid_number, '新潟県新潟市中央区船見町');
ok($zip->set_number('9518003')->is_valid_number, '新潟県新潟市中央区雲雀町');
ok($zip->set_number('9518004')->is_valid_number, '新潟県新潟市中央区山田町');
ok($zip->set_number('9518005')->is_valid_number, '新潟県新潟市中央区室町');
ok($zip->set_number('9518006')->is_valid_number, '新潟県新潟市中央区附船町');
ok($zip->set_number('9518007')->is_valid_number, '新潟県新潟市中央区忠蔵町');
ok($zip->set_number('9518008')->is_valid_number, '新潟県新潟市中央区窪田町');
ok($zip->set_number('9518011')->is_valid_number, '新潟県新潟市中央区入船町');
ok($zip->set_number('9518012')->is_valid_number, '新潟県新潟市中央区東入船町');
ok($zip->set_number('9518013')->is_valid_number, '新潟県新潟市中央区柳島町');
ok($zip->set_number('9518014')->is_valid_number, '新潟県新潟市中央区緑町');
ok($zip->set_number('9518015')->is_valid_number, '新潟県新潟市中央区松岡町');
ok($zip->set_number('9518016')->is_valid_number, '新潟県新潟市中央区田町');
ok($zip->set_number('9518017')->is_valid_number, '新潟県新潟市中央区艀川岸町');
ok($zip->set_number('9518018')->is_valid_number, '新潟県新潟市中央区稲荷町');
ok($zip->set_number('9518021')->is_valid_number, '新潟県新潟市中央区曙町');
ok($zip->set_number('9518022')->is_valid_number, '新潟県新潟市中央区横六番町');
ok($zip->set_number('9518023')->is_valid_number, '新潟県新潟市中央区夕栄町');
ok($zip->set_number('9518024')->is_valid_number, '新潟県新潟市中央区早川町');
ok($zip->set_number('9518025')->is_valid_number, '新潟県新潟市中央区赤坂町');
ok($zip->set_number('9518026')->is_valid_number, '新潟県新潟市中央区西湊町通');
ok($zip->set_number('9518027')->is_valid_number, '新潟県新潟市中央区湊町通');
ok($zip->set_number('9518028')->is_valid_number, '新潟県新潟市中央区東湊町通');
ok($zip->set_number('9518031')->is_valid_number, '新潟県新潟市中央区北毘沙門町');
ok($zip->set_number('9518032')->is_valid_number, '新潟県新潟市中央区見方町');
ok($zip->set_number('9518033')->is_valid_number, '新潟県新潟市中央区豊照町');
ok($zip->set_number('9518034')->is_valid_number, '新潟県新潟市中央区魁町');
ok($zip->set_number('9518035')->is_valid_number, '新潟県新潟市中央区船場町');
ok($zip->set_number('9518036')->is_valid_number, '新潟県新潟市中央区芳町');
ok($zip->set_number('9518037')->is_valid_number, '新潟県新潟市中央区相生町');
ok($zip->set_number('9518038')->is_valid_number, '新潟県新潟市中央区南毘沙門町');
ok($zip->set_number('9518041')->is_valid_number, '新潟県新潟市中央区本間町');
ok($zip->set_number('9518042')->is_valid_number, '新潟県新潟市中央区住吉町');
ok($zip->set_number('9518043')->is_valid_number, '新潟県新潟市中央区西厩島町');
ok($zip->set_number('9518044')->is_valid_number, '新潟県新潟市中央区東厩島町');
ok($zip->set_number('9518045')->is_valid_number, '新潟県新潟市中央区並木町');
ok($zip->set_number('9518046')->is_valid_number, '新潟県新潟市中央区秣川岸通');
ok($zip->set_number('9518047')->is_valid_number, '新潟県新潟市中央区南多門町');
ok($zip->set_number('9518048')->is_valid_number, '新潟県新潟市中央区北多門町');
ok($zip->set_number('9518051')->is_valid_number, '新潟県新潟市中央区新島町通');
ok($zip->set_number('9518052')->is_valid_number, '新潟県新潟市中央区下大川前通');
ok($zip->set_number('9518053')->is_valid_number, '新潟県新潟市中央区川端町');
ok($zip->set_number('9518054')->is_valid_number, '新潟県新潟市中央区礎町通上一ノ町');
ok($zip->set_number('9518055')->is_valid_number, '新潟県新潟市中央区礎町通');
ok($zip->set_number('9518056')->is_valid_number, '新潟県新潟市中央区花町');
ok($zip->set_number('9518057')->is_valid_number, '新潟県新潟市中央区月町');
ok($zip->set_number('9518058')->is_valid_number, '新潟県新潟市中央区雪町');
ok($zip->set_number('9518061')->is_valid_number, '新潟県新潟市中央区西堀通');
ok($zip->set_number('9518062')->is_valid_number, '新潟県新潟市中央区西堀前通');
ok($zip->set_number('9518063')->is_valid_number, '新潟県新潟市中央区古町通');
ok($zip->set_number('9518064')->is_valid_number, '新潟県新潟市中央区横一番町');
ok($zip->set_number('9518065')->is_valid_number, '新潟県新潟市中央区東堀通');
ok($zip->set_number('9518066')->is_valid_number, '新潟県新潟市中央区東堀前通');
ok($zip->set_number('9518067')->is_valid_number, '新潟県新潟市中央区本町通');
ok($zip->set_number('9518068')->is_valid_number, '新潟県新潟市中央区上大川前通');
ok($zip->set_number('9518071')->is_valid_number, '新潟県新潟市中央区栄町');
ok($zip->set_number('9518072')->is_valid_number, '新潟県新潟市中央区浮洲町');
ok($zip->set_number('9518073')->is_valid_number, '新潟県新潟市中央区寿町');
ok($zip->set_number('9518074')->is_valid_number, '新潟県新潟市中央区祝町');
ok($zip->set_number('9518075')->is_valid_number, '新潟県新潟市中央区元祝町');
ok($zip->set_number('9518076')->is_valid_number, '新潟県新潟市中央区翁町');
ok($zip->set_number('9518077')->is_valid_number, '新潟県新潟市中央区烏帽子町');
ok($zip->set_number('9518078')->is_valid_number, '新潟県新潟市中央区四ツ屋町');
ok($zip->set_number('9518081')->is_valid_number, '新潟県新潟市中央区寄附町');
ok($zip->set_number('9518082')->is_valid_number, '新潟県新潟市中央区西受地町');
ok($zip->set_number('9518083')->is_valid_number, '新潟県新潟市中央区横七番町通');
ok($zip->set_number('9518084')->is_valid_number, '新潟県新潟市中央区元下島町');
ok($zip->set_number('9518085')->is_valid_number, '新潟県新潟市中央区寺山町');
ok($zip->set_number('9518086')->is_valid_number, '新潟県新潟市中央区寄合町');
ok($zip->set_number('9518087')->is_valid_number, '新潟県新潟市中央区東受地町');
ok($zip->set_number('9518088')->is_valid_number, '新潟県新潟市中央区菅根町');
ok($zip->set_number('9518101')->is_valid_number, '新潟県新潟市中央区西船見町');
ok($zip->set_number('9518102')->is_valid_number, '新潟県新潟市中央区二葉町');
ok($zip->set_number('9518103')->is_valid_number, '新潟県新潟市中央区田中町');
ok($zip->set_number('9518104')->is_valid_number, '新潟県新潟市中央区西大畑町');
ok($zip->set_number('9518105')->is_valid_number, '新潟県新潟市中央区北大畑町');
ok($zip->set_number('9518106')->is_valid_number, '新潟県新潟市中央区東大畑通');
ok($zip->set_number('9518107')->is_valid_number, '新潟県新潟市中央区南大畑町');
ok($zip->set_number('9518108')->is_valid_number, '新潟県新潟市中央区中大畑町');
ok($zip->set_number('9518111')->is_valid_number, '新潟県新潟市中央区北浜通');
ok($zip->set_number('9518112')->is_valid_number, '新潟県新潟市中央区南浜通');
ok($zip->set_number('9518113')->is_valid_number, '新潟県新潟市中央区寄居町');
ok($zip->set_number('9518114')->is_valid_number, '新潟県新潟市中央区営所通');
ok($zip->set_number('9518115')->is_valid_number, '新潟県新潟市中央区寺裏通');
ok($zip->set_number('9518116')->is_valid_number, '新潟県新潟市中央区東中通');
ok($zip->set_number('9518117')->is_valid_number, '新潟県新潟市中央区南横堀町');
ok($zip->set_number('9518118')->is_valid_number, '新潟県新潟市中央区西中町');
ok($zip->set_number('9518121')->is_valid_number, '新潟県新潟市中央区水道町');
ok($zip->set_number('9518122')->is_valid_number, '新潟県新潟市中央区旭町通');
ok($zip->set_number('9518123')->is_valid_number, '新潟県新潟市中央区下旭町');
ok($zip->set_number('9518124')->is_valid_number, '新潟県新潟市中央区医学町通');
ok($zip->set_number('9518125')->is_valid_number, '新潟県新潟市中央区学校裏町');
ok($zip->set_number('9518126')->is_valid_number, '新潟県新潟市中央区学校町通');
ok($zip->set_number('9518127')->is_valid_number, '新潟県新潟市中央区関屋下川原町');
ok($zip->set_number('9518131')->is_valid_number, '新潟県新潟市中央区白山浦');
ok($zip->set_number('9518132')->is_valid_number, '新潟県新潟市中央区一番堀通町');
ok($zip->set_number('9518133')->is_valid_number, '新潟県新潟市中央区川岸町');
ok($zip->set_number('9518134')->is_valid_number, '新潟県新潟市中央区関屋');
ok($zip->set_number('9518134')->is_valid_number, '新潟県新潟市西区関屋');
ok($zip->set_number('9518135')->is_valid_number, '新潟県新潟市中央区関屋新町通');
ok($zip->set_number('9518136')->is_valid_number, '新潟県新潟市中央区関屋田町');
ok($zip->set_number('9518137')->is_valid_number, '新潟県新潟市中央区白山浦新町通');
ok($zip->set_number('9518141')->is_valid_number, '新潟県新潟市中央区関新');
ok($zip->set_number('9518142')->is_valid_number, '新潟県新潟市中央区関屋大川前');
ok($zip->set_number('9518143')->is_valid_number, '新潟県新潟市中央区関屋恵町');
ok($zip->set_number('9518144')->is_valid_number, '新潟県新潟市中央区関南町');
ok($zip->set_number('9518145')->is_valid_number, '新潟県新潟市中央区有明台');
ok($zip->set_number('9518146')->is_valid_number, '新潟県新潟市中央区有明大橋町');
ok($zip->set_number('9518147')->is_valid_number, '新潟県新潟市中央区弥生町');
ok($zip->set_number('9518151')->is_valid_number, '新潟県新潟市中央区浜浦町');
ok($zip->set_number('9518152')->is_valid_number, '新潟県新潟市中央区信濃町');
ok($zip->set_number('9518153')->is_valid_number, '新潟県新潟市中央区文京町');
ok($zip->set_number('9518154')->is_valid_number, '新潟県新潟市中央区堀割町');
ok($zip->set_number('9518155')->is_valid_number, '新潟県新潟市西区関屋堀割町');
ok($zip->set_number('9518156')->is_valid_number, '新潟県新潟市中央区汐見台');
ok($zip->set_number('9518161')->is_valid_number, '新潟県新潟市中央区関屋松波町');
ok($zip->set_number('9518162')->is_valid_number, '新潟県新潟市中央区関屋本村町');
ok($zip->set_number('9518163')->is_valid_number, '新潟県新潟市中央区関屋御船蔵町');
ok($zip->set_number('9518164')->is_valid_number, '新潟県新潟市中央区関屋昭和町');
ok($zip->set_number('9518165')->is_valid_number, '新潟県新潟市中央区関屋金鉢山町');
ok($zip->set_number('9518166')->is_valid_number, '新潟県新潟市中央区関屋浜松町');
ok($zip->set_number('9518167')->is_valid_number, '新潟県新潟市中央区関屋金衛町');
ok($zip->set_number('9520000')->is_valid_number, '新潟県佐渡市以下に掲載がない場合');
ok($zip->set_number('9520001')->is_valid_number, '新潟県佐渡市白瀬');
ok($zip->set_number('9520002')->is_valid_number, '新潟県佐渡市北五十里');
ok($zip->set_number('9520003')->is_valid_number, '新潟県佐渡市椿');
ok($zip->set_number('9520004')->is_valid_number, '新潟県佐渡市羽吉');
ok($zip->set_number('9520005')->is_valid_number, '新潟県佐渡市梅津');
ok($zip->set_number('9520006')->is_valid_number, '新潟県佐渡市春日');
ok($zip->set_number('9520007')->is_valid_number, '新潟県佐渡市浜田');
ok($zip->set_number('9520011')->is_valid_number, '新潟県佐渡市両津夷');
ok($zip->set_number('9520012')->is_valid_number, '新潟県佐渡市両津夷新');
ok($zip->set_number('9520013')->is_valid_number, '新潟県佐渡市両津福浦');
ok($zip->set_number('9520014')->is_valid_number, '新潟県佐渡市両津湊');
ok($zip->set_number('9520015')->is_valid_number, '新潟県佐渡市住吉');
ok($zip->set_number('9520016')->is_valid_number, '新潟県佐渡市原黒');
ok($zip->set_number('9520021')->is_valid_number, '新潟県佐渡市秋津');
ok($zip->set_number('9520022')->is_valid_number, '新潟県佐渡市旭');
ok($zip->set_number('9520023')->is_valid_number, '新潟県佐渡市潟端');
ok($zip->set_number('9520024')->is_valid_number, '新潟県佐渡市上横山');
ok($zip->set_number('9520025')->is_valid_number, '新潟県佐渡市下横山');
ok($zip->set_number('9520026')->is_valid_number, '新潟県佐渡市立野');
ok($zip->set_number('9520027')->is_valid_number, '新潟県佐渡市長江');
ok($zip->set_number('9520028')->is_valid_number, '新潟県佐渡市加茂歌代');
ok($zip->set_number('9520101')->is_valid_number, '新潟県佐渡市新穂長畝');
ok($zip->set_number('9520102')->is_valid_number, '新潟県佐渡市新穂青木');
ok($zip->set_number('9520103')->is_valid_number, '新潟県佐渡市新穂潟上');
ok($zip->set_number('9520104')->is_valid_number, '新潟県佐渡市新穂田野沢');
ok($zip->set_number('9520105')->is_valid_number, '新潟県佐渡市新穂正明寺');
ok($zip->set_number('9520106')->is_valid_number, '新潟県佐渡市新穂瓜生屋');
ok($zip->set_number('9520107')->is_valid_number, '新潟県佐渡市新穂井内');
ok($zip->set_number('9520108')->is_valid_number, '新潟県佐渡市上新穂');
ok($zip->set_number('9520109')->is_valid_number, '新潟県佐渡市新穂大野');
ok($zip->set_number('9520111')->is_valid_number, '新潟県佐渡市新穂武井');
ok($zip->set_number('9520112')->is_valid_number, '新潟県佐渡市新穂舟下');
ok($zip->set_number('9520113')->is_valid_number, '新潟県佐渡市新穂皆川');
ok($zip->set_number('9520114')->is_valid_number, '新潟県佐渡市下新穂');
ok($zip->set_number('9520115')->is_valid_number, '新潟県佐渡市新穂北方');
ok($zip->set_number('9520116')->is_valid_number, '新潟県佐渡市新穂');
ok($zip->set_number('9520201')->is_valid_number, '新潟県佐渡市目黒町');
ok($zip->set_number('9520202')->is_valid_number, '新潟県佐渡市栗野江');
ok($zip->set_number('9520203')->is_valid_number, '新潟県佐渡市坊ケ浦');
ok($zip->set_number('9520204')->is_valid_number, '新潟県佐渡市長谷');
ok($zip->set_number('9520205')->is_valid_number, '新潟県佐渡市小倉');
ok($zip->set_number('9520206')->is_valid_number, '新潟県佐渡市畑野');
ok($zip->set_number('9520207')->is_valid_number, '新潟県佐渡市寺田');
ok($zip->set_number('9520211')->is_valid_number, '新潟県佐渡市畉田');
ok($zip->set_number('9520212')->is_valid_number, '新潟県佐渡市宮川');
ok($zip->set_number('9520213')->is_valid_number, '新潟県佐渡市飯持');
ok($zip->set_number('9520214')->is_valid_number, '新潟県佐渡市大久保');
ok($zip->set_number('9520215')->is_valid_number, '新潟県佐渡市猿八');
ok($zip->set_number('9520216')->is_valid_number, '新潟県佐渡市三宮');
ok($zip->set_number('9520301')->is_valid_number, '新潟県佐渡市真野大川');
ok($zip->set_number('9520302')->is_valid_number, '新潟県佐渡市竹田');
ok($zip->set_number('9520303')->is_valid_number, '新潟県佐渡市阿仏坊');
ok($zip->set_number('9520304')->is_valid_number, '新潟県佐渡市国分寺');
ok($zip->set_number('9520305')->is_valid_number, '新潟県佐渡市長石');
ok($zip->set_number('9520306')->is_valid_number, '新潟県佐渡市四日町');
ok($zip->set_number('9520307')->is_valid_number, '新潟県佐渡市金丸');
ok($zip->set_number('9520311')->is_valid_number, '新潟県佐渡市名古屋');
ok($zip->set_number('9520312')->is_valid_number, '新潟県佐渡市吉岡');
ok($zip->set_number('9520313')->is_valid_number, '新潟県佐渡市真野');
ok($zip->set_number('9520314')->is_valid_number, '新潟県佐渡市滝脇');
ok($zip->set_number('9520315')->is_valid_number, '新潟県佐渡市大須');
ok($zip->set_number('9520316')->is_valid_number, '新潟県佐渡市背合');
ok($zip->set_number('9520317')->is_valid_number, '新潟県佐渡市豊田');
ok($zip->set_number('9520318')->is_valid_number, '新潟県佐渡市真野新町');
ok($zip->set_number('9520321')->is_valid_number, '新潟県佐渡市静平');
ok($zip->set_number('9520322')->is_valid_number, '新潟県佐渡市下黒山');
ok($zip->set_number('9520421')->is_valid_number, '新潟県佐渡市羽茂小泊(1~1699番地)');
ok($zip->set_number('9520422')->is_valid_number, '新潟県佐渡市羽茂亀脇');
ok($zip->set_number('9520431')->is_valid_number, '新潟県佐渡市大小');
ok($zip->set_number('9520432')->is_valid_number, '新潟県佐渡市大倉谷');
ok($zip->set_number('9520433')->is_valid_number, '新潟県佐渡市田切須');
ok($zip->set_number('9520434')->is_valid_number, '新潟県佐渡市西三川');
ok($zip->set_number('9520435')->is_valid_number, '新潟県佐渡市椿尾');
ok($zip->set_number('9520501')->is_valid_number, '新潟県佐渡市羽茂滝平');
ok($zip->set_number('9520502')->is_valid_number, '新潟県佐渡市羽茂大崎');
ok($zip->set_number('9520503')->is_valid_number, '新潟県佐渡市羽茂飯岡');
ok($zip->set_number('9520504')->is_valid_number, '新潟県佐渡市羽茂本郷');
ok($zip->set_number('9520505')->is_valid_number, '新潟県佐渡市羽茂三瀬');
ok($zip->set_number('9520511')->is_valid_number, '新潟県佐渡市羽茂大石');
ok($zip->set_number('9520512')->is_valid_number, '新潟県佐渡市羽茂大橋');
ok($zip->set_number('9520513')->is_valid_number, '新潟県佐渡市羽茂村山');
ok($zip->set_number('9520514')->is_valid_number, '新潟県佐渡市羽茂小泊(その他)');
ok($zip->set_number('9520515')->is_valid_number, '新潟県佐渡市羽茂上山田');
ok($zip->set_number('9520601')->is_valid_number, '新潟県佐渡市小木堂釜');
ok($zip->set_number('9520602')->is_valid_number, '新潟県佐渡市小比叡');
ok($zip->set_number('9520603')->is_valid_number, '新潟県佐渡市小木木野浦');
ok($zip->set_number('9520604')->is_valid_number, '新潟県佐渡市小木町');
ok($zip->set_number('9520605')->is_valid_number, '新潟県佐渡市小木');
ok($zip->set_number('9520606')->is_valid_number, '新潟県佐渡市琴浦');
ok($zip->set_number('9520611')->is_valid_number, '新潟県佐渡市小木金田新田');
ok($zip->set_number('9520612')->is_valid_number, '新潟県佐渡市宿根木');
ok($zip->set_number('9520613')->is_valid_number, '新潟県佐渡市小木強清水');
ok($zip->set_number('9520614')->is_valid_number, '新潟県佐渡市犬神平');
ok($zip->set_number('9520615')->is_valid_number, '新潟県佐渡市深浦');
ok($zip->set_number('9520621')->is_valid_number, '新潟県佐渡市沢崎');
ok($zip->set_number('9520622')->is_valid_number, '新潟県佐渡市江積');
ok($zip->set_number('9520623')->is_valid_number, '新潟県佐渡市田野浦');
ok($zip->set_number('9520624')->is_valid_number, '新潟県佐渡市木流');
ok($zip->set_number('9520625')->is_valid_number, '新潟県佐渡市小木大浦');
ok($zip->set_number('9520626')->is_valid_number, '新潟県佐渡市井坪');
ok($zip->set_number('9520701')->is_valid_number, '新潟県佐渡市下川茂');
ok($zip->set_number('9520702')->is_valid_number, '新潟県佐渡市上川茂');
ok($zip->set_number('9520703')->is_valid_number, '新潟県佐渡市外山');
ok($zip->set_number('9520704')->is_valid_number, '新潟県佐渡市莚場');
ok($zip->set_number('9520705')->is_valid_number, '新潟県佐渡市三川');
ok($zip->set_number('9520706')->is_valid_number, '新潟県佐渡市徳和');
ok($zip->set_number('9520711')->is_valid_number, '新潟県佐渡市赤泊');
ok($zip->set_number('9520712')->is_valid_number, '新潟県佐渡市真浦');
ok($zip->set_number('9520713')->is_valid_number, '新潟県佐渡市柳沢');
ok($zip->set_number('9520714')->is_valid_number, '新潟県佐渡市南新保');
ok($zip->set_number('9520715')->is_valid_number, '新潟県佐渡市杉野浦');
ok($zip->set_number('9520716')->is_valid_number, '新潟県佐渡市大杉');
ok($zip->set_number('9520821')->is_valid_number, '新潟県佐渡市松ケ崎');
ok($zip->set_number('9520822')->is_valid_number, '新潟県佐渡市多田');
ok($zip->set_number('9520823')->is_valid_number, '新潟県佐渡市浜河内');
ok($zip->set_number('9520824')->is_valid_number, '新潟県佐渡市丸山');
ok($zip->set_number('9520851')->is_valid_number, '新潟県佐渡市蚫');
ok($zip->set_number('9520852')->is_valid_number, '新潟県佐渡市赤玉');
ok($zip->set_number('9520853')->is_valid_number, '新潟県佐渡市立間');
ok($zip->set_number('9520854')->is_valid_number, '新潟県佐渡市豊岡');
ok($zip->set_number('9520855')->is_valid_number, '新潟県佐渡市柿野浦');
ok($zip->set_number('9520856')->is_valid_number, '新潟県佐渡市東鵜島');
ok($zip->set_number('9520857')->is_valid_number, '新潟県佐渡市岩首');
ok($zip->set_number('9521201')->is_valid_number, '新潟県佐渡市安養寺');
ok($zip->set_number('9521202')->is_valid_number, '新潟県佐渡市吉井本郷');
ok($zip->set_number('9521203')->is_valid_number, '新潟県佐渡市吉井');
ok($zip->set_number('9521204')->is_valid_number, '新潟県佐渡市三瀬川');
ok($zip->set_number('9521205')->is_valid_number, '新潟県佐渡市水渡田');
ok($zip->set_number('9521206')->is_valid_number, '新潟県佐渡市大和');
ok($zip->set_number('9521207')->is_valid_number, '新潟県佐渡市貝塚');
ok($zip->set_number('9521208')->is_valid_number, '新潟県佐渡市金井新保');
ok($zip->set_number('9521209')->is_valid_number, '新潟県佐渡市千種');
ok($zip->set_number('9521211')->is_valid_number, '新潟県佐渡市中興');
ok($zip->set_number('9521212')->is_valid_number, '新潟県佐渡市泉');
ok($zip->set_number('9521213')->is_valid_number, '新潟県佐渡市平清水');
ok($zip->set_number('9521301')->is_valid_number, '新潟県佐渡市真光寺');
ok($zip->set_number('9521302')->is_valid_number, '新潟県佐渡市市野沢');
ok($zip->set_number('9521303')->is_valid_number, '新潟県佐渡市上矢馳');
ok($zip->set_number('9521304')->is_valid_number, '新潟県佐渡市下長木');
ok($zip->set_number('9521305')->is_valid_number, '新潟県佐渡市上長木');
ok($zip->set_number('9521306')->is_valid_number, '新潟県佐渡市長木');
ok($zip->set_number('9521307')->is_valid_number, '新潟県佐渡市東大通');
ok($zip->set_number('9521308')->is_valid_number, '新潟県佐渡市二宮');
ok($zip->set_number('9521311')->is_valid_number, '新潟県佐渡市八幡');
ok($zip->set_number('9521312')->is_valid_number, '新潟県佐渡市八幡新町');
ok($zip->set_number('9521313')->is_valid_number, '新潟県佐渡市八幡町');
ok($zip->set_number('9521314')->is_valid_number, '新潟県佐渡市河原田本町');
ok($zip->set_number('9521315')->is_valid_number, '新潟県佐渡市河原田諏訪町');
ok($zip->set_number('9521321')->is_valid_number, '新潟県佐渡市山田');
ok($zip->set_number('9521322')->is_valid_number, '新潟県佐渡市石田');
ok($zip->set_number('9521323')->is_valid_number, '新潟県佐渡市鍛冶町');
ok($zip->set_number('9521324')->is_valid_number, '新潟県佐渡市中原');
ok($zip->set_number('9521325')->is_valid_number, '新潟県佐渡市窪田');
ok($zip->set_number('9521326')->is_valid_number, '新潟県佐渡市青野');
ok($zip->set_number('9521431')->is_valid_number, '新潟県佐渡市沢根炭屋町');
ok($zip->set_number('9521432')->is_valid_number, '新潟県佐渡市沢根五十里');
ok($zip->set_number('9521433')->is_valid_number, '新潟県佐渡市沢根篭町');
ok($zip->set_number('9521434')->is_valid_number, '新潟県佐渡市沢根町');
ok($zip->set_number('9521435')->is_valid_number, '新潟県佐渡市沢根');
ok($zip->set_number('9521501')->is_valid_number, '新潟県佐渡市下相川');
ok($zip->set_number('9521502')->is_valid_number, '新潟県佐渡市相川水金町');
ok($zip->set_number('9521503')->is_valid_number, '新潟県佐渡市相川柴町');
ok($zip->set_number('9521504')->is_valid_number, '新潟県佐渡市相川下山之神町');
ok($zip->set_number('9521505')->is_valid_number, '新潟県佐渡市相川坂下町');
ok($zip->set_number('9521506')->is_valid_number, '新潟県佐渡市相川炭屋町');
ok($zip->set_number('9521507')->is_valid_number, '新潟県佐渡市相川紙屋町');
ok($zip->set_number('9521508')->is_valid_number, '新潟県佐渡市相川大間町');
ok($zip->set_number('9521511')->is_valid_number, '新潟県佐渡市相川栄町');
ok($zip->set_number('9521512')->is_valid_number, '新潟県佐渡市相川板町');
ok($zip->set_number('9521513')->is_valid_number, '新潟県佐渡市相川濁川町');
ok($zip->set_number('9521514')->is_valid_number, '新潟県佐渡市相川小六町');
ok($zip->set_number('9521515')->is_valid_number, '新潟県佐渡市相川新西坂町');
ok($zip->set_number('9521516')->is_valid_number, '新潟県佐渡市相川西坂町');
ok($zip->set_number('9521517')->is_valid_number, '新潟県佐渡市相川石扣町');
ok($zip->set_number('9521518')->is_valid_number, '新潟県佐渡市相川材木町');
ok($zip->set_number('9521521')->is_valid_number, '新潟県佐渡市相川夕白町');
ok($zip->set_number('9521522')->is_valid_number, '新潟県佐渡市相川上京町');
ok($zip->set_number('9521523')->is_valid_number, '新潟県佐渡市相川新五郎町');
ok($zip->set_number('9521524')->is_valid_number, '新潟県佐渡市相川大工町');
ok($zip->set_number('9521525')->is_valid_number, '新潟県佐渡市相川諏訪町');
ok($zip->set_number('9521526')->is_valid_number, '新潟県佐渡市相川中寺町');
ok($zip->set_number('9521527')->is_valid_number, '新潟県佐渡市相川左門町');
ok($zip->set_number('9521528')->is_valid_number, '新潟県佐渡市相川六右衛門町');
ok($zip->set_number('9521531')->is_valid_number, '新潟県佐渡市相川広間町');
ok($zip->set_number('9521532')->is_valid_number, '新潟県佐渡市相川弥十郎町');
ok($zip->set_number('9521533')->is_valid_number, '新潟県佐渡市相川米屋町');
ok($zip->set_number('9521534')->is_valid_number, '新潟県佐渡市相川大床屋町');
ok($zip->set_number('9521535')->is_valid_number, '新潟県佐渡市相川中京町');
ok($zip->set_number('9521536')->is_valid_number, '新潟県佐渡市相川下京町');
ok($zip->set_number('9521537')->is_valid_number, '新潟県佐渡市相川会津町');
ok($zip->set_number('9521538')->is_valid_number, '新潟県佐渡市相川四十物町');
ok($zip->set_number('9521539')->is_valid_number, '新潟県佐渡市相川北沢町');
ok($zip->set_number('9521541')->is_valid_number, '新潟県佐渡市相川新材木町');
ok($zip->set_number('9521542')->is_valid_number, '新潟県佐渡市相川塩屋町');
ok($zip->set_number('9521543')->is_valid_number, '新潟県佐渡市相川長坂町');
ok($zip->set_number('9521544')->is_valid_number, '新潟県佐渡市相川味噌屋町');
ok($zip->set_number('9521545')->is_valid_number, '新潟県佐渡市相川八百屋町');
ok($zip->set_number('9521546')->is_valid_number, '新潟県佐渡市相川南沢町');
ok($zip->set_number('9521547')->is_valid_number, '新潟県佐渡市相川江戸沢町');
ok($zip->set_number('9521548')->is_valid_number, '新潟県佐渡市相川羽田町');
ok($zip->set_number('9521551')->is_valid_number, '新潟県佐渡市相川下寺町');
ok($zip->set_number('9521552')->is_valid_number, '新潟県佐渡市相川一町目裏町');
ok($zip->set_number('9521553')->is_valid_number, '新潟県佐渡市相川五郎左衛門町');
ok($zip->set_number('9521554')->is_valid_number, '新潟県佐渡市相川二町目新浜町');
ok($zip->set_number('9521555')->is_valid_number, '新潟県佐渡市相川二町目浜町');
ok($zip->set_number('9521556')->is_valid_number, '新潟県佐渡市相川一町目浜町');
ok($zip->set_number('9521557')->is_valid_number, '新潟県佐渡市相川一町目');
ok($zip->set_number('9521558')->is_valid_number, '新潟県佐渡市相川二町目');
ok($zip->set_number('9521561')->is_valid_number, '新潟県佐渡市相川三町目新浜町');
ok($zip->set_number('9521562')->is_valid_number, '新潟県佐渡市相川三町目浜町');
ok($zip->set_number('9521563')->is_valid_number, '新潟県佐渡市相川三町目');
ok($zip->set_number('9521564')->is_valid_number, '新潟県佐渡市相川四町目');
ok($zip->set_number('9521565')->is_valid_number, '新潟県佐渡市相川馬町');
ok($zip->set_number('9521566')->is_valid_number, '新潟県佐渡市相川市町');
ok($zip->set_number('9521567')->is_valid_number, '新潟県佐渡市相川四町目浜町');
ok($zip->set_number('9521568')->is_valid_number, '新潟県佐渡市相川新浜町');
ok($zip->set_number('9521571')->is_valid_number, '新潟県佐渡市相川下戸浜町');
ok($zip->set_number('9521572')->is_valid_number, '新潟県佐渡市相川羽田村');
ok($zip->set_number('9521573')->is_valid_number, '新潟県佐渡市相川下戸炭屋裏町');
ok($zip->set_number('9521574')->is_valid_number, '新潟県佐渡市相川海士町');
ok($zip->set_number('9521575')->is_valid_number, '新潟県佐渡市相川下戸町');
ok($zip->set_number('9521581')->is_valid_number, '新潟県佐渡市相川下戸炭屋町');
ok($zip->set_number('9521582')->is_valid_number, '新潟県佐渡市相川下戸村');
ok($zip->set_number('9521583')->is_valid_number, '新潟県佐渡市相川鹿伏');
ok($zip->set_number('9521584')->is_valid_number, '新潟県佐渡市相川下戸炭屋浜町');
ok($zip->set_number('9521641')->is_valid_number, '新潟県佐渡市二見');
ok($zip->set_number('9521642')->is_valid_number, '新潟県佐渡市米郷');
ok($zip->set_number('9521643')->is_valid_number, '新潟県佐渡市稲鯨');
ok($zip->set_number('9521644')->is_valid_number, '新潟県佐渡市橘');
ok($zip->set_number('9521645')->is_valid_number, '新潟県佐渡市高瀬');
ok($zip->set_number('9521646')->is_valid_number, '新潟県佐渡市相川大浦');
ok($zip->set_number('9522131')->is_valid_number, '新潟県佐渡市戸中');
ok($zip->set_number('9522132')->is_valid_number, '新潟県佐渡市戸地');
ok($zip->set_number('9522133')->is_valid_number, '新潟県佐渡市北狄');
ok($zip->set_number('9522134')->is_valid_number, '新潟県佐渡市姫津');
ok($zip->set_number('9522135')->is_valid_number, '新潟県佐渡市達者');
ok($zip->set_number('9522136')->is_valid_number, '新潟県佐渡市小川');
ok($zip->set_number('9522201')->is_valid_number, '新潟県佐渡市岩谷口');
ok($zip->set_number('9522202')->is_valid_number, '新潟県佐渡市五十浦');
ok($zip->set_number('9522203')->is_valid_number, '新潟県佐渡市関');
ok($zip->set_number('9522204')->is_valid_number, '新潟県佐渡市矢柄');
ok($zip->set_number('9522205')->is_valid_number, '新潟県佐渡市大倉');
ok($zip->set_number('9522206')->is_valid_number, '新潟県佐渡市小田');
ok($zip->set_number('9522211')->is_valid_number, '新潟県佐渡市石名');
ok($zip->set_number('9522212')->is_valid_number, '新潟県佐渡市小野見');
ok($zip->set_number('9522213')->is_valid_number, '新潟県佐渡市北田野浦');
ok($zip->set_number('9522214')->is_valid_number, '新潟県佐渡市高千');
ok($zip->set_number('9522215')->is_valid_number, '新潟県佐渡市入川');
ok($zip->set_number('9522221')->is_valid_number, '新潟県佐渡市北立島');
ok($zip->set_number('9522222')->is_valid_number, '新潟県佐渡市北川内');
ok($zip->set_number('9522223')->is_valid_number, '新潟県佐渡市後尾');
ok($zip->set_number('9522224')->is_valid_number, '新潟県佐渡市石花');
ok($zip->set_number('9522225')->is_valid_number, '新潟県佐渡市北片辺');
ok($zip->set_number('9522226')->is_valid_number, '新潟県佐渡市南片辺');
ok($zip->set_number('9523111')->is_valid_number, '新潟県佐渡市虫崎');
ok($zip->set_number('9523112')->is_valid_number, '新潟県佐渡市黒姫');
ok($zip->set_number('9523113')->is_valid_number, '新潟県佐渡市歌見');
ok($zip->set_number('9523114')->is_valid_number, '新潟県佐渡市浦川');
ok($zip->set_number('9523115')->is_valid_number, '新潟県佐渡市平松');
ok($zip->set_number('9523116')->is_valid_number, '新潟県佐渡市北松ケ崎');
ok($zip->set_number('9523117')->is_valid_number, '新潟県佐渡市馬首');
ok($zip->set_number('9523118')->is_valid_number, '新潟県佐渡市和木');
ok($zip->set_number('9523119')->is_valid_number, '新潟県佐渡市玉崎');
ok($zip->set_number('9523201')->is_valid_number, '新潟県佐渡市真更川');
ok($zip->set_number('9523202')->is_valid_number, '新潟県佐渡市北鵜島');
ok($zip->set_number('9523203')->is_valid_number, '新潟県佐渡市願');
ok($zip->set_number('9523204')->is_valid_number, '新潟県佐渡市藻浦');
ok($zip->set_number('9523205')->is_valid_number, '新潟県佐渡市鷲崎');
ok($zip->set_number('9523206')->is_valid_number, '新潟県佐渡市見立');
ok($zip->set_number('9523207')->is_valid_number, '新潟県佐渡市北小浦');
ok($zip->set_number('9523421')->is_valid_number, '新潟県佐渡市吾潟');
ok($zip->set_number('9523422')->is_valid_number, '新潟県佐渡市城腰');
ok($zip->set_number('9523423')->is_valid_number, '新潟県佐渡市久知河内');
ok($zip->set_number('9523424')->is_valid_number, '新潟県佐渡市下久知');
ok($zip->set_number('9523425')->is_valid_number, '新潟県佐渡市河崎');
ok($zip->set_number('9523431')->is_valid_number, '新潟県佐渡市真木');
ok($zip->set_number('9523432')->is_valid_number, '新潟県佐渡市椎泊');
ok($zip->set_number('9523433')->is_valid_number, '新潟県佐渡市両尾');
ok($zip->set_number('9523434')->is_valid_number, '新潟県佐渡市羽二生');
ok($zip->set_number('9523435')->is_valid_number, '新潟県佐渡市両津大川');
ok($zip->set_number('9523541')->is_valid_number, '新潟県佐渡市水津');
ok($zip->set_number('9523542')->is_valid_number, '新潟県佐渡市片野尾');
ok($zip->set_number('9523543')->is_valid_number, '新潟県佐渡市月布施');
ok($zip->set_number('9523544')->is_valid_number, '新潟県佐渡市野浦');
ok($zip->set_number('9523545')->is_valid_number, '新潟県佐渡市東強清水');
ok($zip->set_number('9523546')->is_valid_number, '新潟県佐渡市東立島');
ok($zip->set_number('9530011')->is_valid_number, '新潟県新潟市西蒲区角田浜');
ok($zip->set_number('9530012')->is_valid_number, '新潟県新潟市西蒲区越前浜');
ok($zip->set_number('9530013')->is_valid_number, '新潟県新潟市西蒲区巻大原');
ok($zip->set_number('9530014')->is_valid_number, '新潟県新潟市西蒲区新保');
ok($zip->set_number('9530015')->is_valid_number, '新潟県新潟市西蒲区松野尾');
ok($zip->set_number('9530016')->is_valid_number, '新潟県新潟市西蒲区松山');
ok($zip->set_number('9530021')->is_valid_number, '新潟県新潟市西蒲区布目');
ok($zip->set_number('9530022')->is_valid_number, '新潟県新潟市西蒲区仁箇');
ok($zip->set_number('9530023')->is_valid_number, '新潟県新潟市西蒲区竹野町');
ok($zip->set_number('9530024')->is_valid_number, '新潟県新潟市西蒲区平沢');
ok($zip->set_number('9530025')->is_valid_number, '新潟県新潟市西蒲区松郷屋');
ok($zip->set_number('9530026')->is_valid_number, '新潟県新潟市西蒲区伏部');
ok($zip->set_number('9530027')->is_valid_number, '新潟県新潟市西蒲区稲島');
ok($zip->set_number('9530031')->is_valid_number, '新潟県新潟市西蒲区羽田');
ok($zip->set_number('9530032')->is_valid_number, '新潟県新潟市西蒲区東汰上');
ok($zip->set_number('9530033')->is_valid_number, '新潟県新潟市西蒲区中郷屋');
ok($zip->set_number('9530034')->is_valid_number, '新潟県新潟市西蒲区葉萱場');
ok($zip->set_number('9530035')->is_valid_number, '新潟県新潟市西蒲区割前');
ok($zip->set_number('9530036')->is_valid_number, '新潟県新潟市西蒲区前田');
ok($zip->set_number('9530041')->is_valid_number, '新潟県新潟市西蒲区巻甲');
ok($zip->set_number('9530042')->is_valid_number, '新潟県新潟市西蒲区赤鏥');
ok($zip->set_number('9530043')->is_valid_number, '新潟県新潟市西蒲区堀山新田');
ok($zip->set_number('9530044')->is_valid_number, '新潟県新潟市西蒲区巻乙');
ok($zip->set_number('9530045')->is_valid_number, '新潟県新潟市西蒲区桔梗ケ丘');
ok($zip->set_number('9530051')->is_valid_number, '新潟県新潟市西蒲区河井');
ok($zip->set_number('9530052')->is_valid_number, '新潟県新潟市西蒲区山島');
ok($zip->set_number('9530053')->is_valid_number, '新潟県新潟市西蒲区巻東町');
ok($zip->set_number('9530054')->is_valid_number, '新潟県新潟市西蒲区漆山');
ok($zip->set_number('9530055')->is_valid_number, '新潟県新潟市西蒲区柿島');
ok($zip->set_number('9530061')->is_valid_number, '新潟県新潟市西蒲区馬堀');
ok($zip->set_number('9530062')->is_valid_number, '新潟県新潟市西蒲区並岡');
ok($zip->set_number('9530063')->is_valid_number, '新潟県新潟市西蒲区栄町');
ok($zip->set_number('9530064')->is_valid_number, '新潟県新潟市西蒲区桜林');
ok($zip->set_number('9530065')->is_valid_number, '新潟県新潟市西蒲区下和納');
ok($zip->set_number('9530066')->is_valid_number, '新潟県新潟市西蒲区安尻');
ok($zip->set_number('9530067')->is_valid_number, '新潟県新潟市西蒲区潟頭');
ok($zip->set_number('9530071')->is_valid_number, '新潟県新潟市西蒲区下木島');
ok($zip->set_number('9530072')->is_valid_number, '新潟県新潟市西蒲区鷲ノ木');
ok($zip->set_number('9530073')->is_valid_number, '新潟県新潟市西蒲区上木島');
ok($zip->set_number('9530074')->is_valid_number, '新潟県新潟市西蒲区舟戸');
ok($zip->set_number('9530075')->is_valid_number, '新潟県新潟市西蒲区峰岡');
ok($zip->set_number('9530076')->is_valid_number, '新潟県新潟市西蒲区福井');
ok($zip->set_number('9530077')->is_valid_number, '新潟県新潟市西蒲区角海浜');
ok($zip->set_number('9530078')->is_valid_number, '新潟県新潟市西蒲区五ケ浜');
ok($zip->set_number('9530101')->is_valid_number, '新潟県新潟市西蒲区樋曽');
ok($zip->set_number('9530102')->is_valid_number, '新潟県新潟市西蒲区栄');
ok($zip->set_number('9530103')->is_valid_number, '新潟県新潟市西蒲区橋本');
ok($zip->set_number('9530104')->is_valid_number, '新潟県新潟市西蒲区岩室温泉');
ok($zip->set_number('9530105')->is_valid_number, '新潟県新潟市西蒲区間瀬');
ok($zip->set_number('9530111')->is_valid_number, '新潟県新潟市西蒲区油島');
ok($zip->set_number('9530112')->is_valid_number, '新潟県新潟市西蒲区高畑');
ok($zip->set_number('9530113')->is_valid_number, '新潟県新潟市西蒲区西船越');
ok($zip->set_number('9530114')->is_valid_number, '新潟県新潟市西蒲区潟上');
ok($zip->set_number('9530115')->is_valid_number, '新潟県新潟市西蒲区横曽根');
ok($zip->set_number('9530116')->is_valid_number, '新潟県新潟市西蒲区新谷');
ok($zip->set_number('9530117')->is_valid_number, '新潟県新潟市西蒲区植野新田');
ok($zip->set_number('9530121')->is_valid_number, '新潟県新潟市西蒲区高橋');
ok($zip->set_number('9530122')->is_valid_number, '新潟県新潟市西蒲区富岡');
ok($zip->set_number('9530123')->is_valid_number, '新潟県新潟市西蒲区津雲田');
ok($zip->set_number('9530124')->is_valid_number, '新潟県新潟市西蒲区原');
ok($zip->set_number('9530125')->is_valid_number, '新潟県新潟市西蒲区和納');
ok($zip->set_number('9530131')->is_valid_number, '新潟県新潟市西蒲区西長島');
ok($zip->set_number('9530132')->is_valid_number, '新潟県新潟市西蒲区西中');
ok($zip->set_number('9530133')->is_valid_number, '新潟県新潟市西蒲区夏井');
ok($zip->set_number('9530134')->is_valid_number, '新潟県新潟市西蒲区北野');
ok($zip->set_number('9530135')->is_valid_number, '新潟県新潟市西蒲区南谷内');
ok($zip->set_number('9530136')->is_valid_number, '新潟県新潟市西蒲区白鳥');
ok($zip->set_number('9530141')->is_valid_number, '新潟県新潟市西蒲区石瀬');
ok($zip->set_number('9530142')->is_valid_number, '新潟県新潟市西蒲区久保田');
ok($zip->set_number('9530143')->is_valid_number, '新潟県新潟市西蒲区猿ケ瀬');
ok($zip->set_number('9530144')->is_valid_number, '新潟県新潟市西蒲区金池');
ok($zip->set_number('9540000')->is_valid_number, '新潟県見附市以下に掲載がない場合');
ok($zip->set_number('9540001')->is_valid_number, '新潟県見附市指出町');
ok($zip->set_number('9540002')->is_valid_number, '新潟県見附市小栗山町');
ok($zip->set_number('9540004')->is_valid_number, '新潟県見附市元町');
ok($zip->set_number('9540005')->is_valid_number, '新潟県見附市戸代新田町');
ok($zip->set_number('9540006')->is_valid_number, '新潟県見附市新潟町');
ok($zip->set_number('9540007')->is_valid_number, '新潟県見附市下鳥町');
ok($zip->set_number('9540008')->is_valid_number, '新潟県見附市内町');
ok($zip->set_number('9540011')->is_valid_number, '新潟県見附市山崎興野町');
ok($zip->set_number('9540012')->is_valid_number, '新潟県見附市島切窪町');
ok($zip->set_number('9540013')->is_valid_number, '新潟県見附市石地町');
ok($zip->set_number('9540014')->is_valid_number, '新潟県見附市堀溝町');
ok($zip->set_number('9540016')->is_valid_number, '新潟県見附市庄川町');
ok($zip->set_number('9540017')->is_valid_number, '新潟県見附市庄川平町');
ok($zip->set_number('9540021')->is_valid_number, '新潟県見附市池之島町');
ok($zip->set_number('9540022')->is_valid_number, '新潟県見附市杉澤町');
ok($zip->set_number('9540023')->is_valid_number, '新潟県見附市宮之原町');
ok($zip->set_number('9540024')->is_valid_number, '新潟県見附市河野町');
ok($zip->set_number('9540025')->is_valid_number, '新潟県見附市牛ケ嶺町');
ok($zip->set_number('9540026')->is_valid_number, '新潟県見附市神保町');
ok($zip->set_number('9540027')->is_valid_number, '新潟県見附市栃窪町');
ok($zip->set_number('9540031')->is_valid_number, '新潟県見附市太田町');
ok($zip->set_number('9540032')->is_valid_number, '新潟県見附市本明町');
ok($zip->set_number('9540033')->is_valid_number, '新潟県見附市明晶町');
ok($zip->set_number('9540034')->is_valid_number, '新潟県見附市月見台');
ok($zip->set_number('9540035')->is_valid_number, '新潟県見附市名木野町');
ok($zip->set_number('9540036')->is_valid_number, '新潟県見附市田井町');
ok($zip->set_number('9540037')->is_valid_number, '新潟県見附市椿澤町');
ok($zip->set_number('9540038')->is_valid_number, '新潟県見附市池之内町');
ok($zip->set_number('9540041')->is_valid_number, '新潟県見附市栃栄町');
ok($zip->set_number('9540042')->is_valid_number, '新潟県見附市山崎町');
ok($zip->set_number('9540043')->is_valid_number, '新潟県見附市耳取町');
ok($zip->set_number('9540044')->is_valid_number, '新潟県見附市鳥屋脇町');
ok($zip->set_number('9540045')->is_valid_number, '新潟県見附市緑町');
ok($zip->set_number('9540046')->is_valid_number, '新潟県見附市双葉町');
ok($zip->set_number('9540051')->is_valid_number, '新潟県見附市本所');
ok($zip->set_number('9540052')->is_valid_number, '新潟県見附市学校町');
ok($zip->set_number('9540053')->is_valid_number, '新潟県見附市本町');
ok($zip->set_number('9540054')->is_valid_number, '新潟県見附市細越');
ok($zip->set_number('9540055')->is_valid_number, '新潟県見附市嶺崎');
ok($zip->set_number('9540056')->is_valid_number, '新潟県見附市南本町');
ok($zip->set_number('9540057')->is_valid_number, '新潟県見附市新町');
ok($zip->set_number('9540058')->is_valid_number, '新潟県見附市葛巻');
ok($zip->set_number('9540059')->is_valid_number, '新潟県見附市昭和町');
ok($zip->set_number('9540061')->is_valid_number, '新潟県見附市熱田町');
ok($zip->set_number('9540062')->is_valid_number, '新潟県見附市下新町');
ok($zip->set_number('9540063')->is_valid_number, '新潟県見附市漆山町');
ok($zip->set_number('9540064')->is_valid_number, '新潟県見附市鹿熊町');
ok($zip->set_number('9540067')->is_valid_number, '新潟県見附市葛巻町');
ok($zip->set_number('9540068')->is_valid_number, '新潟県見附市仁嘉町');
ok($zip->set_number('9540071')->is_valid_number, '新潟県見附市傍所町');
ok($zip->set_number('9540072')->is_valid_number, '新潟県見附市北野町');
ok($zip->set_number('9540073')->is_valid_number, '新潟県見附市青木町');
ok($zip->set_number('9540074')->is_valid_number, '新潟県見附市山吉町');
ok($zip->set_number('9540075')->is_valid_number, '新潟県見附市速水町');
ok($zip->set_number('9540076')->is_valid_number, '新潟県見附市新幸町');
ok($zip->set_number('9540077')->is_valid_number, '新潟県見附市葛巻西町');
ok($zip->set_number('9540078')->is_valid_number, '新潟県見附市葛巻東町');
ok($zip->set_number('9540079')->is_valid_number, '新潟県見附市葛巻南町');
ok($zip->set_number('9540081')->is_valid_number, '新潟県見附市片桐町');
ok($zip->set_number('9540082')->is_valid_number, '新潟県見附市柳橋町');
ok($zip->set_number('9540083')->is_valid_number, '新潟県見附市市野坪町');
ok($zip->set_number('9540084')->is_valid_number, '新潟県見附市加坪川町');
ok($zip->set_number('9540085')->is_valid_number, '新潟県見附市反田町');
ok($zip->set_number('9540086')->is_valid_number, '新潟県見附市福島町');
ok($zip->set_number('9540087')->is_valid_number, '新潟県見附市芝野町');
ok($zip->set_number('9540088')->is_valid_number, '新潟県見附市新潟東町');
ok($zip->set_number('9540089')->is_valid_number, '新潟県見附市新潟西町');
ok($zip->set_number('9540091')->is_valid_number, '新潟県見附市美里町');
ok($zip->set_number('9540101')->is_valid_number, '新潟県見附市三林町');
ok($zip->set_number('9540102')->is_valid_number, '新潟県見附市釈迦塚町');
ok($zip->set_number('9540103')->is_valid_number, '新潟県見附市田之尻町');
ok($zip->set_number('9540104')->is_valid_number, '新潟県見附市坂井町');
ok($zip->set_number('9540105')->is_valid_number, '新潟県見附市下関町');
ok($zip->set_number('9540106')->is_valid_number, '新潟県見附市東今町');
ok($zip->set_number('9540107')->is_valid_number, '新潟県見附市西今町');
ok($zip->set_number('9540111')->is_valid_number, '新潟県見附市今町');
ok($zip->set_number('9540112')->is_valid_number, '新潟県見附市上新田町');
ok($zip->set_number('9540121')->is_valid_number, '新潟県長岡市野口');
ok($zip->set_number('9540122')->is_valid_number, '新潟県長岡市真弓');
ok($zip->set_number('9540123')->is_valid_number, '新潟県長岡市猫興野');
ok($zip->set_number('9540124')->is_valid_number, '新潟県長岡市中之島');
ok($zip->set_number('9540125')->is_valid_number, '新潟県長岡市藤山');
ok($zip->set_number('9540126')->is_valid_number, '新潟県長岡市五百刈');
ok($zip->set_number('9540131')->is_valid_number, '新潟県長岡市中興野');
ok($zip->set_number('9540132')->is_valid_number, '新潟県長岡市新栄');
ok($zip->set_number('9540133')->is_valid_number, '新潟県長岡市大曲戸新田');
ok($zip->set_number('9540134')->is_valid_number, '新潟県長岡市大曲戸');
ok($zip->set_number('9540135')->is_valid_number, '新潟県長岡市幸南');
ok($zip->set_number('9540136')->is_valid_number, '新潟県長岡市思川新田');
ok($zip->set_number('9540137')->is_valid_number, '新潟県長岡市押切新田');
ok($zip->set_number('9540138')->is_valid_number, '新潟県長岡市押切川原町');
ok($zip->set_number('9540141')->is_valid_number, '新潟県長岡市粕島');
ok($zip->set_number('9540142')->is_valid_number, '新潟県長岡市灰島新田');
ok($zip->set_number('9540143')->is_valid_number, '新潟県長岡市池之島');
ok($zip->set_number('9540144')->is_valid_number, '新潟県長岡市坪根');
ok($zip->set_number('9540145')->is_valid_number, '新潟県長岡市大口');
ok($zip->set_number('9540146')->is_valid_number, '新潟県長岡市大保');
ok($zip->set_number('9540147')->is_valid_number, '新潟県長岡市品之木');
ok($zip->set_number('9540151')->is_valid_number, '新潟県長岡市杉之森');
ok($zip->set_number('9540152')->is_valid_number, '新潟県長岡市中之島高畑');
ok($zip->set_number('9540153')->is_valid_number, '新潟県長岡市横山');
ok($zip->set_number('9540154')->is_valid_number, '新潟県長岡市関根');
ok($zip->set_number('9540155')->is_valid_number, '新潟県長岡市島田');
ok($zip->set_number('9540156')->is_valid_number, '新潟県長岡市長呂');
ok($zip->set_number('9540157')->is_valid_number, '新潟県長岡市中之島宮内');
ok($zip->set_number('9540161')->is_valid_number, '新潟県長岡市興野');
ok($zip->set_number('9540162')->is_valid_number, '新潟県長岡市狐興野');
ok($zip->set_number('9540163')->is_valid_number, '新潟県長岡市並木新田');
ok($zip->set_number('9540164')->is_valid_number, '新潟県長岡市末宝');
ok($zip->set_number('9540165')->is_valid_number, '新潟県長岡市福原');
ok($zip->set_number('9540166')->is_valid_number, '新潟県長岡市海老島勇次新田');
ok($zip->set_number('9540171')->is_valid_number, '新潟県長岡市稲島');
ok($zip->set_number('9540172')->is_valid_number, '新潟県長岡市鶴ケ曽根');
ok($zip->set_number('9540173')->is_valid_number, '新潟県長岡市中野東');
ok($zip->set_number('9540174')->is_valid_number, '新潟県長岡市中野中');
ok($zip->set_number('9540175')->is_valid_number, '新潟県長岡市中野西');
ok($zip->set_number('9540176')->is_valid_number, '新潟県長岡市横野');
ok($zip->set_number('9540177')->is_valid_number, '新潟県長岡市亀ケ谷新田');
ok($zip->set_number('9540181')->is_valid_number, '新潟県長岡市脇川新田町(970番地)');
ok($zip->set_number('9540201')->is_valid_number, '新潟県長岡市大沼新田');
ok($zip->set_number('9540202')->is_valid_number, '新潟県長岡市赤沼');
ok($zip->set_number('9540203')->is_valid_number, '新潟県長岡市小沼新田');
ok($zip->set_number('9540204')->is_valid_number, '新潟県長岡市中西');
ok($zip->set_number('9540205')->is_valid_number, '新潟県長岡市西高山新田');
ok($zip->set_number('9540206')->is_valid_number, '新潟県長岡市六所');
ok($zip->set_number('9540207')->is_valid_number, '新潟県長岡市上沼新田');
ok($zip->set_number('9540211')->is_valid_number, '新潟県長岡市西野新田');
ok($zip->set_number('9540212')->is_valid_number, '新潟県長岡市中之島西野');
ok($zip->set_number('9540213')->is_valid_number, '新潟県長岡市下沼新田');
ok($zip->set_number('9540214')->is_valid_number, '新潟県長岡市中条新田');
ok($zip->set_number('9540215')->is_valid_number, '新潟県長岡市真野代新田');
ok($zip->set_number('9540216')->is_valid_number, '新潟県長岡市中之島中条');
ok($zip->set_number('9540217')->is_valid_number, '新潟県長岡市松ケ崎新田');
ok($zip->set_number('9540218')->is_valid_number, '新潟県長岡市信条南');
ok($zip->set_number('9540221')->is_valid_number, '新潟県長岡市信条東');
ok($zip->set_number('9540222')->is_valid_number, '新潟県長岡市信条西');
ok($zip->set_number('9550000')->is_valid_number, '新潟県三条市以下に掲載がない場合');
ok($zip->set_number('9550001')->is_valid_number, '新潟県三条市三貫地新田');
ok($zip->set_number('9550002')->is_valid_number, '新潟県三条市柳川新田');
ok($zip->set_number('9550003')->is_valid_number, '新潟県三条市柳場新田');
ok($zip->set_number('9550004')->is_valid_number, '新潟県三条市須戸新田');
ok($zip->set_number('9550011')->is_valid_number, '新潟県三条市白山新田');
ok($zip->set_number('9550012')->is_valid_number, '新潟県三条市北野新田');
ok($zip->set_number('9550013')->is_valid_number, '新潟県三条市井栗');
ok($zip->set_number('9550014')->is_valid_number, '新潟県三条市西潟');
ok($zip->set_number('9550015')->is_valid_number, '新潟県三条市三柳');
ok($zip->set_number('9550016')->is_valid_number, '新潟県三条市牛ケ島');
ok($zip->set_number('9550021')->is_valid_number, '新潟県三条市下保内');
ok($zip->set_number('9550022')->is_valid_number, '新潟県三条市上保内');
ok($zip->set_number('9550022')->is_valid_number, '新潟県三条市みずほ');
ok($zip->set_number('9550024')->is_valid_number, '新潟県三条市柳沢');
ok($zip->set_number('9550025')->is_valid_number, '新潟県三条市上野原');
ok($zip->set_number('9550031')->is_valid_number, '新潟県三条市松ノ木町');
ok($zip->set_number('9550032')->is_valid_number, '新潟県三条市東大崎');
ok($zip->set_number('9550033')->is_valid_number, '新潟県三条市西大崎');
ok($zip->set_number('9550034')->is_valid_number, '新潟県三条市麻布');
ok($zip->set_number('9550035')->is_valid_number, '新潟県三条市中新');
ok($zip->set_number('9550036')->is_valid_number, '新潟県三条市篭場');
ok($zip->set_number('9550041')->is_valid_number, '新潟県三条市三竹');
ok($zip->set_number('9550042')->is_valid_number, '新潟県三条市下坂井');
ok($zip->set_number('9550043')->is_valid_number, '新潟県三条市北中');
ok($zip->set_number('9550044')->is_valid_number, '新潟県三条市田島');
ok($zip->set_number('9550045')->is_valid_number, '新潟県三条市一ノ門');
ok($zip->set_number('9550046')->is_valid_number, '新潟県三条市興野');
ok($zip->set_number('9550047')->is_valid_number, '新潟県三条市東三条');
ok($zip->set_number('9550051')->is_valid_number, '新潟県三条市鶴田');
ok($zip->set_number('9550053')->is_valid_number, '新潟県三条市北入蔵');
ok($zip->set_number('9550054')->is_valid_number, '新潟県三条市大宮新田');
ok($zip->set_number('9550055')->is_valid_number, '新潟県三条市塚野目');
ok($zip->set_number('9550056')->is_valid_number, '新潟県三条市嘉坪川');
ok($zip->set_number('9550057')->is_valid_number, '新潟県三条市新光町');
ok($zip->set_number('9550061')->is_valid_number, '新潟県三条市林町');
ok($zip->set_number('9550062')->is_valid_number, '新潟県三条市仲之町');
ok($zip->set_number('9550063')->is_valid_number, '新潟県三条市神明町');
ok($zip->set_number('9550064')->is_valid_number, '新潟県三条市横町');
ok($zip->set_number('9550065')->is_valid_number, '新潟県三条市旭町');
ok($zip->set_number('9550066')->is_valid_number, '新潟県三条市居島');
ok($zip->set_number('9550071')->is_valid_number, '新潟県三条市本町');
ok($zip->set_number('9550072')->is_valid_number, '新潟県三条市元町');
ok($zip->set_number('9550073')->is_valid_number, '新潟県三条市八幡町');
ok($zip->set_number('9550081')->is_valid_number, '新潟県三条市東裏館');
ok($zip->set_number('9550082')->is_valid_number, '新潟県三条市西裏館');
ok($zip->set_number('9550083')->is_valid_number, '新潟県三条市荒町');
ok($zip->set_number('9550084')->is_valid_number, '新潟県三条市石上');
ok($zip->set_number('9550085')->is_valid_number, '新潟県三条市栗林');
ok($zip->set_number('9550091')->is_valid_number, '新潟県三条市上須頃');
ok($zip->set_number('9550092')->is_valid_number, '新潟県三条市須頃');
ok($zip->set_number('9550093')->is_valid_number, '新潟県三条市下須頃');
ok($zip->set_number('9550094')->is_valid_number, '新潟県三条市大島');
ok($zip->set_number('9550095')->is_valid_number, '新潟県三条市代官島');
ok($zip->set_number('9550096')->is_valid_number, '新潟県三条市井戸場');
ok($zip->set_number('9550097')->is_valid_number, '新潟県三条市荻島');
ok($zip->set_number('9550101')->is_valid_number, '新潟県三条市曲谷');
ok($zip->set_number('9550102')->is_valid_number, '新潟県三条市牛ケ首');
ok($zip->set_number('9550103')->is_valid_number, '新潟県三条市落合');
ok($zip->set_number('9550104')->is_valid_number, '新潟県三条市江口');
ok($zip->set_number('9550105')->is_valid_number, '新潟県三条市島川原');
ok($zip->set_number('9550106')->is_valid_number, '新潟県三条市南中');
ok($zip->set_number('9550107')->is_valid_number, '新潟県三条市飯田');
ok($zip->set_number('9550108')->is_valid_number, '新潟県三条市鹿峠');
ok($zip->set_number('9550111')->is_valid_number, '新潟県三条市上谷地');
ok($zip->set_number('9550112')->is_valid_number, '新潟県三条市蝶名林');
ok($zip->set_number('9550113')->is_valid_number, '新潟県三条市中浦');
ok($zip->set_number('9550114')->is_valid_number, '新潟県三条市鹿熊');
ok($zip->set_number('9550115')->is_valid_number, '新潟県三条市院内');
ok($zip->set_number('9550116')->is_valid_number, '新潟県三条市森町');
ok($zip->set_number('9550117')->is_valid_number, '新潟県三条市田屋');
ok($zip->set_number('9550118')->is_valid_number, '新潟県三条市新屋');
ok($zip->set_number('9550121')->is_valid_number, '新潟県三条市北五百川');
ok($zip->set_number('9550122')->is_valid_number, '新潟県三条市大谷地');
ok($zip->set_number('9550123')->is_valid_number, '新潟県三条市笠堀');
ok($zip->set_number('9550124')->is_valid_number, '新潟県三条市大谷');
ok($zip->set_number('9550125')->is_valid_number, '新潟県三条市塩野渕');
ok($zip->set_number('9550126')->is_valid_number, '新潟県三条市栗山');
ok($zip->set_number('9550127')->is_valid_number, '新潟県三条市名下');
ok($zip->set_number('9550128')->is_valid_number, '新潟県三条市南五百川');
ok($zip->set_number('9550131')->is_valid_number, '新潟県三条市庭月');
ok($zip->set_number('9550132')->is_valid_number, '新潟県三条市長野');
ok($zip->set_number('9550133')->is_valid_number, '新潟県三条市牛野尾');
ok($zip->set_number('9550134')->is_valid_number, '新潟県三条市濁沢');
ok($zip->set_number('9550135')->is_valid_number, '新潟県三条市早水');
ok($zip->set_number('9550136')->is_valid_number, '新潟県三条市葎谷');
ok($zip->set_number('9550137')->is_valid_number, '新潟県三条市遅場');
ok($zip->set_number('9550141')->is_valid_number, '新潟県三条市荒沢');
ok($zip->set_number('9550142')->is_valid_number, '新潟県三条市小長沢');
ok($zip->set_number('9550143')->is_valid_number, '新潟県三条市棚鱗');
ok($zip->set_number('9550144')->is_valid_number, '新潟県三条市楢山');
ok($zip->set_number('9550145')->is_valid_number, '新潟県三条市大沢');
ok($zip->set_number('9550146')->is_valid_number, '新潟県三条市笹巻');
ok($zip->set_number('9550147')->is_valid_number, '新潟県三条市中野原');
ok($zip->set_number('9550148')->is_valid_number, '新潟県三条市花渕');
ok($zip->set_number('9550151')->is_valid_number, '新潟県三条市荻堀');
ok($zip->set_number('9550152')->is_valid_number, '新潟県三条市笹岡');
ok($zip->set_number('9550153')->is_valid_number, '新潟県三条市桑切');
ok($zip->set_number('9550154')->is_valid_number, '新潟県三条市大平');
ok($zip->set_number('9550155')->is_valid_number, '新潟県三条市広手');
ok($zip->set_number('9550156')->is_valid_number, '新潟県三条市駒込');
ok($zip->set_number('9550157')->is_valid_number, '新潟県三条市長沢');
ok($zip->set_number('9550158')->is_valid_number, '新潟県三条市原');
ok($zip->set_number('9550161')->is_valid_number, '新潟県三条市高岡');
ok($zip->set_number('9550162')->is_valid_number, '新潟県三条市福岡');
ok($zip->set_number('9550163')->is_valid_number, '新潟県三条市島潟');
ok($zip->set_number('9550164')->is_valid_number, '新潟県三条市滝谷');
ok($zip->set_number('9550165')->is_valid_number, '新潟県三条市高屋敷');
ok($zip->set_number('9550166')->is_valid_number, '新潟県三条市上大浦');
ok($zip->set_number('9550167')->is_valid_number, '新潟県三条市馬場');
ok($zip->set_number('9550168')->is_valid_number, '新潟県三条市下大浦');
ok($zip->set_number('9550801')->is_valid_number, '新潟県三条市諏訪');
ok($zip->set_number('9550803')->is_valid_number, '新潟県三条市月岡');
ok($zip->set_number('9550804')->is_valid_number, '新潟県三条市如法寺');
ok($zip->set_number('9550805')->is_valid_number, '新潟県三条市吉田');
ok($zip->set_number('9550806')->is_valid_number, '新潟県三条市長嶺');
ok($zip->set_number('9550807')->is_valid_number, '新潟県三条市片口');
ok($zip->set_number('9550808')->is_valid_number, '新潟県三条市新保');
ok($zip->set_number('9550811')->is_valid_number, '新潟県三条市南入蔵');
ok($zip->set_number('9550812')->is_valid_number, '新潟県三条市入蔵新田');
ok($zip->set_number('9550813')->is_valid_number, '新潟県三条市袋');
ok($zip->set_number('9550814')->is_valid_number, '新潟県三条市金子新田');
ok($zip->set_number('9550815')->is_valid_number, '新潟県三条市西鱈田');
ok($zip->set_number('9550816')->is_valid_number, '新潟県三条市東鱈田');
ok($zip->set_number('9550818')->is_valid_number, '新潟県三条市枝郷');
ok($zip->set_number('9550821')->is_valid_number, '新潟県三条市五明');
ok($zip->set_number('9550822')->is_valid_number, '新潟県三条市西中');
ok($zip->set_number('9550823')->is_valid_number, '新潟県三条市東本成寺');
ok($zip->set_number('9550824')->is_valid_number, '新潟県三条市下新田');
ok($zip->set_number('9550831')->is_valid_number, '新潟県三条市土場');
ok($zip->set_number('9550832')->is_valid_number, '新潟県三条市直江町');
ok($zip->set_number('9550833')->is_valid_number, '新潟県三条市大野畑');
ok($zip->set_number('9550841')->is_valid_number, '新潟県三条市由利');
ok($zip->set_number('9550842')->is_valid_number, '新潟県三条市島田');
ok($zip->set_number('9550843')->is_valid_number, '新潟県三条市条南町');
ok($zip->set_number('9550844')->is_valid_number, '新潟県三条市桜木町');
ok($zip->set_number('9550845')->is_valid_number, '新潟県三条市西本成寺');
ok($zip->set_number('9550845')->is_valid_number, '新潟県三条市緑ケ丘');
ok($zip->set_number('9550851')->is_valid_number, '新潟県三条市西四日町');
ok($zip->set_number('9550852')->is_valid_number, '新潟県三条市南四日町');
ok($zip->set_number('9550853')->is_valid_number, '新潟県三条市北四日町');
ok($zip->set_number('9550854')->is_valid_number, '新潟県三条市四日町');
ok($zip->set_number('9550861')->is_valid_number, '新潟県三条市北新保');
ok($zip->set_number('9550862')->is_valid_number, '新潟県三条市南新保');
ok($zip->set_number('9550863')->is_valid_number, '新潟県三条市東新保');
ok($zip->set_number('9550864')->is_valid_number, '新潟県三条市曲渕');
ok($zip->set_number('9560000')->is_valid_number, '新潟県新潟市秋葉区以下に掲載がない場合');
ok($zip->set_number('9560001')->is_valid_number, '新潟県新潟市秋葉区覚路津');
ok($zip->set_number('9560002')->is_valid_number, '新潟県新潟市秋葉区市之瀬');
ok($zip->set_number('9560003')->is_valid_number, '新潟県新潟市秋葉区長割');
ok($zip->set_number('9560004')->is_valid_number, '新潟県新潟市秋葉区大鹿');
ok($zip->set_number('9560005')->is_valid_number, '新潟県新潟市秋葉区栗宮');
ok($zip->set_number('9560006')->is_valid_number, '新潟県新潟市秋葉区小戸上組');
ok($zip->set_number('9560007')->is_valid_number, '新潟県新潟市秋葉区小戸下組');
ok($zip->set_number('9560011')->is_valid_number, '新潟県新潟市秋葉区車場');
ok($zip->set_number('9560012')->is_valid_number, '新潟県新潟市秋葉区荻野町');
ok($zip->set_number('9560013')->is_valid_number, '新潟県新潟市秋葉区田島');
ok($zip->set_number('9560014')->is_valid_number, '新潟県新潟市秋葉区福島');
ok($zip->set_number('9560015')->is_valid_number, '新潟県新潟市秋葉区川口');
ok($zip->set_number('9560016')->is_valid_number, '新潟県新潟市秋葉区こがね町');
ok($zip->set_number('9560017')->is_valid_number, '新潟県新潟市秋葉区あおば通');
ok($zip->set_number('9560021')->is_valid_number, '新潟県新潟市秋葉区北上新田');
ok($zip->set_number('9560022')->is_valid_number, '新潟県新潟市秋葉区さつき野');
ok($zip->set_number('9560023')->is_valid_number, '新潟県新潟市秋葉区美幸町');
ok($zip->set_number('9560024')->is_valid_number, '新潟県新潟市秋葉区山谷町');
ok($zip->set_number('9560025')->is_valid_number, '新潟県新潟市秋葉区古田');
ok($zip->set_number('9560026')->is_valid_number, '新潟県新潟市秋葉区北潟');
ok($zip->set_number('9560027')->is_valid_number, '新潟県新潟市秋葉区美善');
ok($zip->set_number('9560031')->is_valid_number, '新潟県新潟市秋葉区新津');
ok($zip->set_number('9560032')->is_valid_number, '新潟県新潟市秋葉区南町');
ok($zip->set_number('9560033')->is_valid_number, '新潟県新潟市秋葉区新栄町');
ok($zip->set_number('9560034')->is_valid_number, '新潟県新潟市秋葉区新津緑町');
ok($zip->set_number('9560035')->is_valid_number, '新潟県新潟市秋葉区程島');
ok($zip->set_number('9560036')->is_valid_number, '新潟県新潟市秋葉区中村');
ok($zip->set_number('9560037')->is_valid_number, '新潟県新潟市秋葉区西古津');
ok($zip->set_number('9560041')->is_valid_number, '新潟県新潟市秋葉区小屋場');
ok($zip->set_number('9560043')->is_valid_number, '新潟県新潟市秋葉区梅ノ木');
ok($zip->set_number('9560044')->is_valid_number, '新潟県新潟市秋葉区浦興野');
ok($zip->set_number('9560045')->is_valid_number, '新潟県新潟市秋葉区子成場');
ok($zip->set_number('9560046')->is_valid_number, '新潟県新潟市秋葉区出戸');
ok($zip->set_number('9560051')->is_valid_number, '新潟県新潟市秋葉区三枚潟');
ok($zip->set_number('9560052')->is_valid_number, '新潟県新潟市秋葉区三津屋');
ok($zip->set_number('9560053')->is_valid_number, '新潟県新潟市秋葉区野方');
ok($zip->set_number('9560054')->is_valid_number, '新潟県新潟市秋葉区大秋');
ok($zip->set_number('9560055')->is_valid_number, '新潟県新潟市秋葉区川根');
ok($zip->set_number('9560056')->is_valid_number, '新潟県新潟市秋葉区蕨曽根');
ok($zip->set_number('9560057')->is_valid_number, '新潟県新潟市秋葉区新津四ツ興野');
ok($zip->set_number('9560101')->is_valid_number, '新潟県新潟市秋葉区小須戸');
ok($zip->set_number('9560111')->is_valid_number, '新潟県新潟市秋葉区竜玄');
ok($zip->set_number('9560112')->is_valid_number, '新潟県新潟市秋葉区新保');
ok($zip->set_number('9560113')->is_valid_number, '新潟県新潟市秋葉区矢代田');
ok($zip->set_number('9560114')->is_valid_number, '新潟県新潟市秋葉区天ヶ沢');
ok($zip->set_number('9560115')->is_valid_number, '新潟県新潟市秋葉区鎌倉');
ok($zip->set_number('9560116')->is_valid_number, '新潟県新潟市秋葉区舟戸');
ok($zip->set_number('9560117')->is_valid_number, '新潟県新潟市秋葉区松ヶ丘');
ok($zip->set_number('9560121')->is_valid_number, '新潟県新潟市秋葉区横川浜');
ok($zip->set_number('9560122')->is_valid_number, '新潟県新潟市秋葉区小向');
ok($zip->set_number('9560123')->is_valid_number, '新潟県新潟市秋葉区水田');
ok($zip->set_number('9560801')->is_valid_number, '新潟県新潟市秋葉区大蔵');
ok($zip->set_number('9560802')->is_valid_number, '新潟県新潟市秋葉区七日町');
ok($zip->set_number('9560803')->is_valid_number, '新潟県新潟市秋葉区結');
ok($zip->set_number('9560804')->is_valid_number, '新潟県新潟市秋葉区荻島');
ok($zip->set_number('9560805')->is_valid_number, '新潟県新潟市秋葉区中野');
ok($zip->set_number('9560806')->is_valid_number, '新潟県新潟市秋葉区みそら野');
ok($zip->set_number('9560811')->is_valid_number, '新潟県新潟市秋葉区満願寺');
ok($zip->set_number('9560812')->is_valid_number, '新潟県新潟市秋葉区中新田');
ok($zip->set_number('9560813')->is_valid_number, '新潟県新潟市秋葉区大安寺');
ok($zip->set_number('9560814')->is_valid_number, '新潟県新潟市秋葉区東金沢');
ok($zip->set_number('9560815')->is_valid_number, '新潟県新潟市秋葉区新金沢町');
ok($zip->set_number('9560816')->is_valid_number, '新潟県新潟市秋葉区新津東町');
ok($zip->set_number('9560817')->is_valid_number, '新潟県新潟市秋葉区古田ノ内大野開');
ok($zip->set_number('9560818')->is_valid_number, '新潟県新潟市秋葉区西金沢');
ok($zip->set_number('9560821')->is_valid_number, '新潟県新潟市秋葉区六郷');
ok($zip->set_number('9560822')->is_valid_number, '新潟県新潟市秋葉区新郷屋');
ok($zip->set_number('9560823')->is_valid_number, '新潟県新潟市秋葉区金屋');
ok($zip->set_number('9560824')->is_valid_number, '新潟県新潟市秋葉区市新');
ok($zip->set_number('9560825')->is_valid_number, '新潟県新潟市秋葉区下新');
ok($zip->set_number('9560826')->is_valid_number, '新潟県新潟市秋葉区岡田');
ok($zip->set_number('9560827')->is_valid_number, '新潟県新潟市秋葉区大関');
ok($zip->set_number('9560828')->is_valid_number, '新潟県新潟市秋葉区北');
ok($zip->set_number('9560831')->is_valid_number, '新潟県新潟市秋葉区中沢町');
ok($zip->set_number('9560832')->is_valid_number, '新潟県新潟市秋葉区秋葉');
ok($zip->set_number('9560833')->is_valid_number, '新潟県新潟市秋葉区草水町');
ok($zip->set_number('9560834')->is_valid_number, '新潟県新潟市秋葉区小口');
ok($zip->set_number('9560835')->is_valid_number, '新潟県新潟市秋葉区朝日');
ok($zip->set_number('9560836')->is_valid_number, '新潟県新潟市秋葉区田家');
ok($zip->set_number('9560837')->is_valid_number, '新潟県新潟市秋葉区吉岡町');
ok($zip->set_number('9560841')->is_valid_number, '新潟県新潟市秋葉区東島');
ok($zip->set_number('9560842')->is_valid_number, '新潟県新潟市秋葉区西島');
ok($zip->set_number('9560843')->is_valid_number, '新潟県新潟市秋葉区割町');
ok($zip->set_number('9560844')->is_valid_number, '新潟県新潟市秋葉区塩谷');
ok($zip->set_number('9560845')->is_valid_number, '新潟県新潟市秋葉区金津');
ok($zip->set_number('9560846')->is_valid_number, '新潟県新潟市秋葉区蒲ヶ沢');
ok($zip->set_number('9560847')->is_valid_number, '新潟県新潟市秋葉区古津');
ok($zip->set_number('9560851')->is_valid_number, '新潟県新潟市秋葉区金沢町');
ok($zip->set_number('9560852')->is_valid_number, '新潟県新潟市秋葉区柄目木');
ok($zip->set_number('9560853')->is_valid_number, '新潟県新潟市秋葉区飯柳');
ok($zip->set_number('9560854')->is_valid_number, '新潟県新潟市秋葉区滝谷町');
ok($zip->set_number('9560855')->is_valid_number, '新潟県新潟市秋葉区滝谷本町');
ok($zip->set_number('9560861')->is_valid_number, '新潟県新潟市秋葉区北上');
ok($zip->set_number('9560862')->is_valid_number, '新潟県新潟市秋葉区新町');
ok($zip->set_number('9560863')->is_valid_number, '新潟県新潟市秋葉区日宝町');
ok($zip->set_number('9560864')->is_valid_number, '新潟県新潟市秋葉区新津本町');
ok($zip->set_number('9560865')->is_valid_number, '新潟県新潟市秋葉区善道町');
ok($zip->set_number('9560866')->is_valid_number, '新潟県新潟市秋葉区下興野町');
ok($zip->set_number('9560867')->is_valid_number, '新潟県新潟市秋葉区下興野');
ok($zip->set_number('9570000')->is_valid_number, '新潟県新発田市以下に掲載がない場合');
ok($zip->set_number('9570001')->is_valid_number, '新潟県新発田市道賀');
ok($zip->set_number('9570002')->is_valid_number, '新潟県新発田市中谷内');
ok($zip->set_number('9570003')->is_valid_number, '新潟県新発田市桑ノ口');
ok($zip->set_number('9570004')->is_valid_number, '新潟県新発田市西名柄');
ok($zip->set_number('9570005')->is_valid_number, '新潟県新発田市長畑');
ok($zip->set_number('9570006')->is_valid_number, '新潟県新発田市中田町');
ok($zip->set_number('9570007')->is_valid_number, '新潟県新発田市小舟町');
ok($zip->set_number('9570011')->is_valid_number, '新潟県新発田市島潟');
ok($zip->set_number('9570012')->is_valid_number, '新潟県新発田市東塚ノ目');
ok($zip->set_number('9570013')->is_valid_number, '新潟県新発田市板敷');
ok($zip->set_number('9570014')->is_valid_number, '新潟県新発田市金谷');
ok($zip->set_number('9570015')->is_valid_number, '新潟県新発田市東新町');
ok($zip->set_number('9570016')->is_valid_number, '新潟県新発田市豊町');
ok($zip->set_number('9570017')->is_valid_number, '新潟県新発田市新富町');
ok($zip->set_number('9570018')->is_valid_number, '新潟県新発田市緑町');
ok($zip->set_number('9570021')->is_valid_number, '新潟県新発田市五十公野');
ok($zip->set_number('9570022')->is_valid_number, '新潟県新発田市古寺');
ok($zip->set_number('9570023')->is_valid_number, '新潟県新発田市下新保');
ok($zip->set_number('9570024')->is_valid_number, '新潟県新発田市上新保');
ok($zip->set_number('9570025')->is_valid_number, '新潟県新発田市上内竹');
ok($zip->set_number('9570026')->is_valid_number, '新潟県新発田市下内竹');
ok($zip->set_number('9570027')->is_valid_number, '新潟県新発田市六日町');
ok($zip->set_number('9570028')->is_valid_number, '新潟県新発田市山崎');
ok($zip->set_number('9570031')->is_valid_number, '新潟県新発田市小友');
ok($zip->set_number('9570032')->is_valid_number, '新潟県新発田市八幡新田');
ok($zip->set_number('9570033')->is_valid_number, '新潟県新発田市八幡');
ok($zip->set_number('9570034')->is_valid_number, '新潟県新発田市小見');
ok($zip->set_number('9570035')->is_valid_number, '新潟県新発田市丑首');
ok($zip->set_number('9570036')->is_valid_number, '新潟県新発田市米倉');
ok($zip->set_number('9570037')->is_valid_number, '新潟県新発田市江口');
ok($zip->set_number('9570041')->is_valid_number, '新潟県新発田市浦新田');
ok($zip->set_number('9570042')->is_valid_number, '新潟県新発田市浦');
ok($zip->set_number('9570043')->is_valid_number, '新潟県新発田市大崎');
ok($zip->set_number('9570044')->is_valid_number, '新潟県新発田市松岡');
ok($zip->set_number('9570045')->is_valid_number, '新潟県新発田市荒川');
ok($zip->set_number('9570046')->is_valid_number, '新潟県新発田市上中山');
ok($zip->set_number('9570047')->is_valid_number, '新潟県新発田市法正橋');
ok($zip->set_number('9570048')->is_valid_number, '新潟県新発田市瑞波');
ok($zip->set_number('9570051')->is_valid_number, '新潟県新発田市城北町');
ok($zip->set_number('9570052')->is_valid_number, '新潟県新発田市大手町');
ok($zip->set_number('9570053')->is_valid_number, '新潟県新発田市中央町');
ok($zip->set_number('9570054')->is_valid_number, '新潟県新発田市本町');
ok($zip->set_number('9570055')->is_valid_number, '新潟県新発田市諏訪町');
ok($zip->set_number('9570056')->is_valid_number, '新潟県新発田市大栄町');
ok($zip->set_number('9570057')->is_valid_number, '新潟県新発田市御幸町');
ok($zip->set_number('9570058')->is_valid_number, '新潟県新発田市西園町');
ok($zip->set_number('9570061')->is_valid_number, '新潟県新発田市住吉町');
ok($zip->set_number('9570062')->is_valid_number, '新潟県新発田市富塚町');
ok($zip->set_number('9570063')->is_valid_number, '新潟県新発田市新栄町');
ok($zip->set_number('9570064')->is_valid_number, '新潟県新発田市奥山新保');
ok($zip->set_number('9570065')->is_valid_number, '新潟県新発田市舟入町');
ok($zip->set_number('9570066')->is_valid_number, '新潟県新発田市舟入');
ok($zip->set_number('9570067')->is_valid_number, '新潟県新発田市中曽根町');
ok($zip->set_number('9570071')->is_valid_number, '新潟県新発田市曽根');
ok($zip->set_number('9570072')->is_valid_number, '新潟県新発田市日渡');
ok($zip->set_number('9570073')->is_valid_number, '新潟県新発田市弓越');
ok($zip->set_number('9570074')->is_valid_number, '新潟県新発田市北蓑口');
ok($zip->set_number('9570075')->is_valid_number, '新潟県新発田市西蓑口');
ok($zip->set_number('9570076')->is_valid_number, '新潟県新発田市西宮内');
ok($zip->set_number('9570077')->is_valid_number, '新潟県新発田市則清');
ok($zip->set_number('9570078')->is_valid_number, '新潟県新発田市則清新田');
ok($zip->set_number('9570081')->is_valid_number, '新潟県新発田市上中沢');
ok($zip->set_number('9570082')->is_valid_number, '新潟県新発田市佐々木');
ok($zip->set_number('9570083')->is_valid_number, '新潟県新発田市下興野');
ok($zip->set_number('9570084')->is_valid_number, '新潟県新発田市飯島甲');
ok($zip->set_number('9570085')->is_valid_number, '新潟県新発田市飯島乙');
ok($zip->set_number('9570086')->is_valid_number, '新潟県新発田市飯島新田');
ok($zip->set_number('9570087')->is_valid_number, '新潟県新発田市砂山');
ok($zip->set_number('9570091')->is_valid_number, '新潟県新発田市太田新田');
ok($zip->set_number('9570092')->is_valid_number, '新潟県新発田市鳥穴');
ok($zip->set_number('9570100')->is_valid_number, '新潟県北蒲原郡聖籠町以下に掲載がない場合');
ok($zip->set_number('9570101')->is_valid_number, '新潟県北蒲原郡聖籠町東港');
ok($zip->set_number('9570102')->is_valid_number, '新潟県北蒲原郡聖籠町位守町');
ok($zip->set_number('9570103')->is_valid_number, '新潟県北蒲原郡聖籠町網代浜');
ok($zip->set_number('9570104')->is_valid_number, '新潟県北蒲原郡聖籠町亀塚');
ok($zip->set_number('9570105')->is_valid_number, '新潟県北蒲原郡聖籠町次第浜');
ok($zip->set_number('9570106')->is_valid_number, '新潟県北蒲原郡聖籠町蓮潟');
ok($zip->set_number('9570111')->is_valid_number, '新潟県北蒲原郡聖籠町真野');
ok($zip->set_number('9570112')->is_valid_number, '新潟県北蒲原郡聖籠町道賀新田');
ok($zip->set_number('9570113')->is_valid_number, '新潟県北蒲原郡聖籠町上大谷内');
ok($zip->set_number('9570114')->is_valid_number, '新潟県北蒲原郡聖籠町丸潟');
ok($zip->set_number('9570115')->is_valid_number, '新潟県北蒲原郡聖籠町桃山');
ok($zip->set_number('9570116')->is_valid_number, '新潟県北蒲原郡聖籠町山倉');
ok($zip->set_number('9570117')->is_valid_number, '新潟県北蒲原郡聖籠町諏訪山');
ok($zip->set_number('9570121')->is_valid_number, '新潟県北蒲原郡聖籠町大夫');
ok($zip->set_number('9570122')->is_valid_number, '新潟県北蒲原郡聖籠町三賀');
ok($zip->set_number('9570123')->is_valid_number, '新潟県北蒲原郡聖籠町二本松');
ok($zip->set_number('9570124')->is_valid_number, '新潟県北蒲原郡聖籠町蓮野');
ok($zip->set_number('9570125')->is_valid_number, '新潟県北蒲原郡聖籠町別條');
ok($zip->set_number('9570126')->is_valid_number, '新潟県北蒲原郡聖籠町大夫興野');
ok($zip->set_number('9570127')->is_valid_number, '新潟県北蒲原郡聖籠町藤寄');
ok($zip->set_number('9570201')->is_valid_number, '新潟県新発田市真中');
ok($zip->set_number('9570202')->is_valid_number, '新潟県新発田市古田');
ok($zip->set_number('9570203')->is_valid_number, '新潟県新発田市下中沢');
ok($zip->set_number('9570204')->is_valid_number, '新潟県新発田市稲荷岡');
ok($zip->set_number('9570205')->is_valid_number, '新潟県新発田市関井');
ok($zip->set_number('9570206')->is_valid_number, '新潟県新発田市福岡');
ok($zip->set_number('9570207')->is_valid_number, '新潟県新発田市富島');
ok($zip->set_number('9570212')->is_valid_number, '新潟県新発田市片桐');
ok($zip->set_number('9570213')->is_valid_number, '新潟県新発田市高島');
ok($zip->set_number('9570214')->is_valid_number, '新潟県新発田市中島');
ok($zip->set_number('9570215')->is_valid_number, '新潟県新発田市住吉');
ok($zip->set_number('9570216')->is_valid_number, '新潟県新発田市南成田');
ok($zip->set_number('9570217')->is_valid_number, '新潟県新発田市大中島');
ok($zip->set_number('9570221')->is_valid_number, '新潟県新発田市長者館');
ok($zip->set_number('9570222')->is_valid_number, '新潟県新発田市中野');
ok($zip->set_number('9570223')->is_valid_number, '新潟県新発田市長島');
ok($zip->set_number('9570224')->is_valid_number, '新潟県新発田市小川');
ok($zip->set_number('9570225')->is_valid_number, '新潟県新発田市米子');
ok($zip->set_number('9570226')->is_valid_number, '新潟県新発田市宮吉');
ok($zip->set_number('9570231')->is_valid_number, '新潟県新発田市藤塚浜');
ok($zip->set_number('9570232')->is_valid_number, '新潟県新発田市真野原外');
ok($zip->set_number('9570233')->is_valid_number, '新潟県新発田市真野原');
ok($zip->set_number('9570234')->is_valid_number, '新潟県新発田市二ツ山');
ok($zip->set_number('9570235')->is_valid_number, '新潟県新発田市人橋');
ok($zip->set_number('9570236')->is_valid_number, '新潟県新発田市元郷');
ok($zip->set_number('9570331')->is_valid_number, '新潟県新発田市上三光');
ok($zip->set_number('9570332')->is_valid_number, '新潟県新発田市虎丸');
ok($zip->set_number('9570333')->is_valid_number, '新潟県新発田市田貝');
ok($zip->set_number('9570334')->is_valid_number, '新潟県新発田市上楠川');
ok($zip->set_number('9570335')->is_valid_number, '新潟県新発田市下楠川');
ok($zip->set_number('9570336')->is_valid_number, '新潟県新発田市下三光');
ok($zip->set_number('9570341')->is_valid_number, '新潟県新発田市下羽津');
ok($zip->set_number('9570342')->is_valid_number, '新潟県新発田市本間新田');
ok($zip->set_number('9570343')->is_valid_number, '新潟県新発田市上羽津');
ok($zip->set_number('9570344')->is_valid_number, '新潟県新発田市板山');
ok($zip->set_number('9570345')->is_valid_number, '新潟県新発田市小戸');
ok($zip->set_number('9570346')->is_valid_number, '新潟県新発田市宮古木');
ok($zip->set_number('9570347')->is_valid_number, '新潟県新発田市大友');
ok($zip->set_number('9570351')->is_valid_number, '新潟県新発田市東姫田');
ok($zip->set_number('9570352')->is_valid_number, '新潟県新発田市南楯');
ok($zip->set_number('9570353')->is_valid_number, '新潟県新発田市石喜');
ok($zip->set_number('9570354')->is_valid_number, '新潟県新発田市下高関');
ok($zip->set_number('9570355')->is_valid_number, '新潟県新発田市敦賀');
ok($zip->set_number('9570356')->is_valid_number, '新潟県新発田市岡田');
ok($zip->set_number('9570357')->is_valid_number, '新潟県新発田市西姫田');
ok($zip->set_number('9570461')->is_valid_number, '新潟県新発田市中々山');
ok($zip->set_number('9570462')->is_valid_number, '新潟県新発田市滝谷');
ok($zip->set_number('9570463')->is_valid_number, '新潟県新発田市東赤谷');
ok($zip->set_number('9570464')->is_valid_number, '新潟県新発田市上赤谷');
ok($zip->set_number('9570465')->is_valid_number, '新潟県新発田市大槻');
ok($zip->set_number('9570466')->is_valid_number, '新潟県新発田市山内');
ok($zip->set_number('9580000')->is_valid_number, '新潟県村上市以下に掲載がない場合');
ok($zip->set_number('9580001')->is_valid_number, '新潟県村上市馬下');
ok($zip->set_number('9580002')->is_valid_number, '新潟県村上市早川');
ok($zip->set_number('9580003')->is_valid_number, '新潟県村上市吉浦');
ok($zip->set_number('9580004')->is_valid_number, '新潟県村上市柏尾');
ok($zip->set_number('9580005')->is_valid_number, '新潟県村上市間島');
ok($zip->set_number('9580006')->is_valid_number, '新潟県村上市野潟');
ok($zip->set_number('9580007')->is_valid_number, '新潟県村上市大月');
ok($zip->set_number('9580008')->is_valid_number, '新潟県村上市岩ケ崎');
ok($zip->set_number('9580011')->is_valid_number, '新潟県村上市滝の前');
ok($zip->set_number('9580012')->is_valid_number, '新潟県村上市大平');
ok($zip->set_number('9580013')->is_valid_number, '新潟県村上市羽下ケ渕');
ok($zip->set_number('9580014')->is_valid_number, '新潟県村上市下渡');
ok($zip->set_number('9580021')->is_valid_number, '新潟県村上市瀬波新田町');
ok($zip->set_number('9580022')->is_valid_number, '新潟県村上市瀬波横町');
ok($zip->set_number('9580023')->is_valid_number, '新潟県村上市瀬波上町');
ok($zip->set_number('9580024')->is_valid_number, '新潟県村上市瀬波中町');
ok($zip->set_number('9580025')->is_valid_number, '新潟県村上市松波町');
ok($zip->set_number('9580026')->is_valid_number, '新潟県村上市瀬波浜町');
ok($zip->set_number('9580031')->is_valid_number, '新潟県村上市学校町');
ok($zip->set_number('9580032')->is_valid_number, '新潟県村上市松原町');
ok($zip->set_number('9580033')->is_valid_number, '新潟県村上市緑町');
ok($zip->set_number('9580034')->is_valid_number, '新潟県村上市松山');
ok($zip->set_number('9580035')->is_valid_number, '新潟県村上市三面');
ok($zip->set_number('9580036')->is_valid_number, '新潟県村上市浦田');
ok($zip->set_number('9580037')->is_valid_number, '新潟県村上市瀬波温泉');
ok($zip->set_number('9580038')->is_valid_number, '新潟県村上市浜新田');
ok($zip->set_number('9580041')->is_valid_number, '新潟県村上市岩船三日市');
ok($zip->set_number('9580042')->is_valid_number, '新潟県村上市岩船北浜町');
ok($zip->set_number('9580043')->is_valid_number, '新潟県村上市岩船下大町');
ok($zip->set_number('9580044')->is_valid_number, '新潟県村上市岩船上大町');
ok($zip->set_number('9580045')->is_valid_number, '新潟県村上市岩船上浜町');
ok($zip->set_number('9580046')->is_valid_number, '新潟県村上市岩船下浜町');
ok($zip->set_number('9580047')->is_valid_number, '新潟県村上市岩船岸見寺町');
ok($zip->set_number('9580048')->is_valid_number, '新潟県村上市岩船地蔵町');
ok($zip->set_number('9580051')->is_valid_number, '新潟県村上市岩船上町');
ok($zip->set_number('9580052')->is_valid_number, '新潟県村上市八日市');
ok($zip->set_number('9580053')->is_valid_number, '新潟県村上市上の山');
ok($zip->set_number('9580054')->is_valid_number, '新潟県村上市岩船新田町');
ok($zip->set_number('9580055')->is_valid_number, '新潟県村上市岩船縦新町');
ok($zip->set_number('9580056')->is_valid_number, '新潟県村上市岩船中新町');
ok($zip->set_number('9580057')->is_valid_number, '新潟県村上市岩船横新町');
ok($zip->set_number('9580058')->is_valid_number, '新潟県村上市岩船港町');
ok($zip->set_number('9580061')->is_valid_number, '新潟県岩船郡粟島浦村粟島浦村一円');
ok($zip->set_number('9580201')->is_valid_number, '新潟県村上市蒲萄');
ok($zip->set_number('9580202')->is_valid_number, '新潟県村上市大須戸');
ok($zip->set_number('9580203')->is_valid_number, '新潟県村上市荒沢');
ok($zip->set_number('9580204')->is_valid_number, '新潟県村上市小須戸');
ok($zip->set_number('9580205')->is_valid_number, '新潟県村上市塩野町');
ok($zip->set_number('9580206')->is_valid_number, '新潟県村上市松岡');
ok($zip->set_number('9580211')->is_valid_number, '新潟県村上市高根');
ok($zip->set_number('9580212')->is_valid_number, '新潟県村上市北大平');
ok($zip->set_number('9580213')->is_valid_number, '新潟県村上市早稲田');
ok($zip->set_number('9580214')->is_valid_number, '新潟県村上市板屋越');
ok($zip->set_number('9580215')->is_valid_number, '新潟県村上市檜原');
ok($zip->set_number('9580221')->is_valid_number, '新潟県村上市薦川');
ok($zip->set_number('9580222')->is_valid_number, '新潟県村上市猿田');
ok($zip->set_number('9580223')->is_valid_number, '新潟県村上市中原');
ok($zip->set_number('9580224')->is_valid_number, '新潟県村上市黒田');
ok($zip->set_number('9580225')->is_valid_number, '新潟県村上市関口');
ok($zip->set_number('9580226')->is_valid_number, '新潟県村上市朝日中野');
ok($zip->set_number('9580231')->is_valid_number, '新潟県村上市布部');
ok($zip->set_number('9580232')->is_valid_number, '新潟県村上市新屋');
ok($zip->set_number('9580233')->is_valid_number, '新潟県村上市中新保');
ok($zip->set_number('9580234')->is_valid_number, '新潟県村上市堀野');
ok($zip->set_number('9580235')->is_valid_number, '新潟県村上市石住');
ok($zip->set_number('9580236')->is_valid_number, '新潟県村上市上中島');
ok($zip->set_number('9580241')->is_valid_number, '新潟県村上市岩崩');
ok($zip->set_number('9580242')->is_valid_number, '新潟県村上市茎太');
ok($zip->set_number('9580243')->is_valid_number, '新潟県村上市千縄');
ok($zip->set_number('9580244')->is_valid_number, '新潟県村上市小揚');
ok($zip->set_number('9580245')->is_valid_number, '新潟県村上市釜杭');
ok($zip->set_number('9580246')->is_valid_number, '新潟県村上市笹平');
ok($zip->set_number('9580251')->is_valid_number, '新潟県村上市岩沢');
ok($zip->set_number('9580252')->is_valid_number, '新潟県村上市下新保');
ok($zip->set_number('9580253')->is_valid_number, '新潟県村上市大場沢');
ok($zip->set_number('9580254')->is_valid_number, '新潟県村上市十川');
ok($zip->set_number('9580255')->is_valid_number, '新潟県村上市熊登');
ok($zip->set_number('9580261')->is_valid_number, '新潟県村上市猿沢');
ok($zip->set_number('9580262')->is_valid_number, '新潟県村上市上野');
ok($zip->set_number('9580263')->is_valid_number, '新潟県村上市川端');
ok($zip->set_number('9580264')->is_valid_number, '新潟県村上市鵜渡路');
ok($zip->set_number('9580265')->is_valid_number, '新潟県村上市下中島');
ok($zip->set_number('9580266')->is_valid_number, '新潟県村上市宮ノ下');
ok($zip->set_number('9580267')->is_valid_number, '新潟県村上市寺尾');
ok($zip->set_number('9580268')->is_valid_number, '新潟県村上市小川');
ok($zip->set_number('9580269')->is_valid_number, '新潟県村上市古渡路');
ok($zip->set_number('9580270')->is_valid_number, '新潟県村上市あけぼの');
ok($zip->set_number('9580801')->is_valid_number, '新潟県村上市西興屋');
ok($zip->set_number('9580802')->is_valid_number, '新潟県村上市四日市');
ok($zip->set_number('9580803')->is_valid_number, '新潟県村上市天神岡');
ok($zip->set_number('9580804')->is_valid_number, '新潟県村上市下山田');
ok($zip->set_number('9580805')->is_valid_number, '新潟県村上市上山田');
ok($zip->set_number('9580806')->is_valid_number, '新潟県村上市小谷');
ok($zip->set_number('9580807')->is_valid_number, '新潟県村上市日下');
ok($zip->set_number('9580808')->is_valid_number, '新潟県村上市上相川');
ok($zip->set_number('9580809')->is_valid_number, '新潟県村上市下相川');
ok($zip->set_number('9580811')->is_valid_number, '新潟県村上市高平');
ok($zip->set_number('9580812')->is_valid_number, '新潟県村上市大関');
ok($zip->set_number('9580813')->is_valid_number, '新潟県村上市鋳物師');
ok($zip->set_number('9580814')->is_valid_number, '新潟県村上市門前');
ok($zip->set_number('9580815')->is_valid_number, '新潟県村上市大栗田');
ok($zip->set_number('9580816')->is_valid_number, '新潟県村上市赤沢');
ok($zip->set_number('9580817')->is_valid_number, '新潟県村上市菅沼');
ok($zip->set_number('9580818')->is_valid_number, '新潟県村上市袋');
ok($zip->set_number('9580821')->is_valid_number, '新潟県村上市山辺里');
ok($zip->set_number('9580822')->is_valid_number, '新潟県村上市坪根');
ok($zip->set_number('9580823')->is_valid_number, '新潟県村上市仲間町');
ok($zip->set_number('9580824')->is_valid_number, '新潟県村上市本町');
ok($zip->set_number('9580831')->is_valid_number, '新潟県村上市杉原');
ok($zip->set_number('9580832')->is_valid_number, '新潟県村上市石原');
ok($zip->set_number('9580833')->is_valid_number, '新潟県村上市堀片');
ok($zip->set_number('9580834')->is_valid_number, '新潟県村上市新町');
ok($zip->set_number('9580835')->is_valid_number, '新潟県村上市二之町');
ok($zip->set_number('9580836')->is_valid_number, '新潟県村上市羽黒口');
ok($zip->set_number('9580837')->is_valid_number, '新潟県村上市三之町');
ok($zip->set_number('9580841')->is_valid_number, '新潟県村上市小町');
ok($zip->set_number('9580842')->is_valid_number, '新潟県村上市大町');
ok($zip->set_number('9580843')->is_valid_number, '新潟県村上市上町');
ok($zip->set_number('9580844')->is_valid_number, '新潟県村上市長井町');
ok($zip->set_number('9580845')->is_valid_number, '新潟県村上市細工町');
ok($zip->set_number('9580846')->is_valid_number, '新潟県村上市安良町');
ok($zip->set_number('9580847')->is_valid_number, '新潟県村上市大工町');
ok($zip->set_number('9580848')->is_valid_number, '新潟県村上市小国町');
ok($zip->set_number('9580849')->is_valid_number, '新潟県村上市寺町');
ok($zip->set_number('9580851')->is_valid_number, '新潟県村上市羽黒町');
ok($zip->set_number('9580852')->is_valid_number, '新潟県村上市南町');
ok($zip->set_number('9580853')->is_valid_number, '新潟県村上市山居町');
ok($zip->set_number('9580854')->is_valid_number, '新潟県村上市田端町');
ok($zip->set_number('9580855')->is_valid_number, '新潟県村上市飯野西');
ok($zip->set_number('9580856')->is_valid_number, '新潟県村上市飯野桜ケ丘');
ok($zip->set_number('9580857')->is_valid_number, '新潟県村上市飯野');
ok($zip->set_number('9580861')->is_valid_number, '新潟県村上市中川原団地');
ok($zip->set_number('9580862')->is_valid_number, '新潟県村上市若葉町');
ok($zip->set_number('9580863')->is_valid_number, '新潟県村上市鍛冶町');
ok($zip->set_number('9580864')->is_valid_number, '新潟県村上市肴町');
ok($zip->set_number('9580865')->is_valid_number, '新潟県村上市幸町');
ok($zip->set_number('9580866')->is_valid_number, '新潟県村上市村上');
ok($zip->set_number('9580867')->is_valid_number, '新潟県村上市大欠');
ok($zip->set_number('9580871')->is_valid_number, '新潟県村上市久保多町');
ok($zip->set_number('9580872')->is_valid_number, '新潟県村上市片町');
ok($zip->set_number('9580873')->is_valid_number, '新潟県村上市上片町');
ok($zip->set_number('9580874')->is_valid_number, '新潟県村上市庄内町');
ok($zip->set_number('9580875')->is_valid_number, '新潟県村上市加賀町');
ok($zip->set_number('9580876')->is_valid_number, '新潟県村上市塩町');
ok($zip->set_number('9580877')->is_valid_number, '新潟県村上市泉町');
ok($zip->set_number('9590101')->is_valid_number, '新潟県燕市佐善');
ok($zip->set_number('9590102')->is_valid_number, '新潟県燕市牧ケ花');
ok($zip->set_number('9590103')->is_valid_number, '新潟県燕市砂子塚');
ok($zip->set_number('9590104')->is_valid_number, '新潟県燕市分水弥生町');
ok($zip->set_number('9590105')->is_valid_number, '新潟県燕市中島');
ok($zip->set_number('9590106')->is_valid_number, '新潟県燕市分水東学校町');
ok($zip->set_number('9590107')->is_valid_number, '新潟県燕市分水旭町');
ok($zip->set_number('9590108')->is_valid_number, '新潟県燕市太田');
ok($zip->set_number('9590109')->is_valid_number, '新潟県燕市分水向陽');
ok($zip->set_number('9590111')->is_valid_number, '新潟県燕市横田');
ok($zip->set_number('9590112')->is_valid_number, '新潟県燕市熊森');
ok($zip->set_number('9590113')->is_valid_number, '新潟県燕市笈ケ島');
ok($zip->set_number('9590114')->is_valid_number, '新潟県燕市一ノ山');
ok($zip->set_number('9590115')->is_valid_number, '新潟県燕市分水学校町');
ok($zip->set_number('9590116')->is_valid_number, '新潟県燕市新興野');
ok($zip->set_number('9590117')->is_valid_number, '新潟県燕市笹曲');
ok($zip->set_number('9590118')->is_valid_number, '新潟県燕市分水向山');
ok($zip->set_number('9590119')->is_valid_number, '新潟県燕市分水大武');
ok($zip->set_number('9590120')->is_valid_number, '新潟県燕市分水栄町');
ok($zip->set_number('9590121')->is_valid_number, '新潟県燕市地蔵堂');
ok($zip->set_number('9590122')->is_valid_number, '新潟県燕市大武新田');
ok($zip->set_number('9590123')->is_valid_number, '新潟県燕市大川津');
ok($zip->set_number('9590124')->is_valid_number, '新潟県燕市五千石');
ok($zip->set_number('9590124')->is_valid_number, '新潟県燕市五千石荒川');
ok($zip->set_number('9590125')->is_valid_number, '新潟県燕市新長');
ok($zip->set_number('9590126')->is_valid_number, '新潟県燕市野中才');
ok($zip->set_number('9590127')->is_valid_number, '新潟県燕市分水文京町');
ok($zip->set_number('9590128')->is_valid_number, '新潟県燕市分水新町');
ok($zip->set_number('9590129')->is_valid_number, '新潟県燕市地蔵堂本町');
ok($zip->set_number('9590130')->is_valid_number, '新潟県燕市分水桜町');
ok($zip->set_number('9590131')->is_valid_number, '新潟県燕市泉新');
ok($zip->set_number('9590132')->is_valid_number, '新潟県燕市分水あけぼの');
ok($zip->set_number('9590133')->is_valid_number, '新潟県燕市新堀');
ok($zip->set_number('9590134')->is_valid_number, '新潟県燕市真木山');
ok($zip->set_number('9590135')->is_valid_number, '新潟県燕市渡部');
ok($zip->set_number('9590136')->is_valid_number, '新潟県燕市国上');
ok($zip->set_number('9590137')->is_valid_number, '新潟県燕市源八新田');
ok($zip->set_number('9590138')->is_valid_number, '新潟県燕市幕島');
ok($zip->set_number('9590139')->is_valid_number, '新潟県燕市長辰');
ok($zip->set_number('9590141')->is_valid_number, '新潟県長岡市寺泊敦ケ曽根');
ok($zip->set_number('9590142')->is_valid_number, '新潟県長岡市寺泊万善寺');
ok($zip->set_number('9590143')->is_valid_number, '新潟県長岡市寺泊高内');
ok($zip->set_number('9590144')->is_valid_number, '新潟県長岡市寺泊町軽井');
ok($zip->set_number('9590145')->is_valid_number, '新潟県長岡市寺泊平野新村新田');
ok($zip->set_number('9590146')->is_valid_number, '新潟県長岡市寺泊田尻');
ok($zip->set_number('9590147')->is_valid_number, '新潟県長岡市寺泊岩方');
ok($zip->set_number('9590148')->is_valid_number, '新潟県長岡市寺泊矢田');
ok($zip->set_number('9590149')->is_valid_number, '新潟県長岡市寺泊入軽井');
ok($zip->set_number('9590151')->is_valid_number, '新潟県長岡市寺泊求草');
ok($zip->set_number('9590152')->is_valid_number, '新潟県長岡市寺泊下桐');
ok($zip->set_number('9590153')->is_valid_number, '新潟県長岡市寺泊硲田');
ok($zip->set_number('9590154')->is_valid_number, '新潟県長岡市寺泊五分一');
ok($zip->set_number('9590155')->is_valid_number, '新潟県長岡市寺泊有信');
ok($zip->set_number('9590156')->is_valid_number, '新潟県長岡市寺泊木島');
ok($zip->set_number('9590157')->is_valid_number, '新潟県長岡市寺泊鰐口');
ok($zip->set_number('9590161')->is_valid_number, '新潟県長岡市寺泊竹森');
ok($zip->set_number('9590162')->is_valid_number, '新潟県長岡市寺泊小豆曽根');
ok($zip->set_number('9590163')->is_valid_number, '新潟県長岡市寺泊新長');
ok($zip->set_number('9590164')->is_valid_number, '新潟県長岡市寺泊下中条');
ok($zip->set_number('9590165')->is_valid_number, '新潟県長岡市寺泊北曽根');
ok($zip->set_number('9590171')->is_valid_number, '新潟県燕市溝古新');
ok($zip->set_number('9590172')->is_valid_number, '新潟県燕市溝');
ok($zip->set_number('9590181')->is_valid_number, '新潟県燕市上諏訪');
ok($zip->set_number('9590182')->is_valid_number, '新潟県燕市中諏訪');
ok($zip->set_number('9590183')->is_valid_number, '新潟県燕市下諏訪');
ok($zip->set_number('9590201')->is_valid_number, '新潟県燕市西槇');
ok($zip->set_number('9590202')->is_valid_number, '新潟県燕市佐渡山');
ok($zip->set_number('9590203')->is_valid_number, '新潟県燕市小島');
ok($zip->set_number('9590205')->is_valid_number, '新潟県燕市雀森');
ok($zip->set_number('9590206')->is_valid_number, '新潟県燕市米納津');
ok($zip->set_number('9590207')->is_valid_number, '新潟県燕市庚塚');
ok($zip->set_number('9590208')->is_valid_number, '新潟県燕市大保');
ok($zip->set_number('9590211')->is_valid_number, '新潟県燕市富永');
ok($zip->set_number('9590212')->is_valid_number, '新潟県燕市富永十兵衛新田');
ok($zip->set_number('9590213')->is_valid_number, '新潟県燕市吉田吉栄');
ok($zip->set_number('9590214')->is_valid_number, '新潟県燕市吉田法花堂');
ok($zip->set_number('9590215')->is_valid_number, '新潟県燕市吉田下中野');
ok($zip->set_number('9590216')->is_valid_number, '新潟県燕市吉田春日町');
ok($zip->set_number('9590217')->is_valid_number, '新潟県燕市吉田曙町');
ok($zip->set_number('9590221')->is_valid_number, '新潟県燕市吉田西太田');
ok($zip->set_number('9590222')->is_valid_number, '新潟県燕市下粟生津');
ok($zip->set_number('9590223')->is_valid_number, '新潟県燕市田中新');
ok($zip->set_number('9590224')->is_valid_number, '新潟県燕市野本');
ok($zip->set_number('9590225')->is_valid_number, '新潟県燕市上河原');
ok($zip->set_number('9590227')->is_valid_number, '新潟県燕市粟生津');
ok($zip->set_number('9590228')->is_valid_number, '新潟県燕市高木');
ok($zip->set_number('9590231')->is_valid_number, '新潟県燕市吉田日之出町');
ok($zip->set_number('9590232')->is_valid_number, '新潟県燕市吉田東栄町');
ok($zip->set_number('9590233')->is_valid_number, '新潟県燕市吉田栄町');
ok($zip->set_number('9590234')->is_valid_number, '新潟県燕市吉田水道町');
ok($zip->set_number('9590235')->is_valid_number, '新潟県燕市吉田旭町');
ok($zip->set_number('9590236')->is_valid_number, '新潟県燕市吉田松岡町');
ok($zip->set_number('9590237')->is_valid_number, '新潟県燕市吉田堤町');
ok($zip->set_number('9590241')->is_valid_number, '新潟県燕市吉田神田町');
ok($zip->set_number('9590242')->is_valid_number, '新潟県燕市吉田大保町');
ok($zip->set_number('9590243')->is_valid_number, '新潟県燕市吉田松岡新田');
ok($zip->set_number('9590244')->is_valid_number, '新潟県燕市吉田中町');
ok($zip->set_number('9590245')->is_valid_number, '新潟県燕市吉田上町');
ok($zip->set_number('9590246')->is_valid_number, '新潟県燕市吉田新町');
ok($zip->set_number('9590247')->is_valid_number, '新潟県燕市吉田新田町');
ok($zip->set_number('9590248')->is_valid_number, '新潟県燕市吉田浜首');
ok($zip->set_number('9590248')->is_valid_number, '新潟県燕市吉田浜首町');
ok($zip->set_number('9590250')->is_valid_number, '新潟県燕市吉田矢作');
ok($zip->set_number('9590251')->is_valid_number, '新潟県燕市吉田本所');
ok($zip->set_number('9590252')->is_valid_number, '新潟県燕市吉田学校町');
ok($zip->set_number('9590253')->is_valid_number, '新潟県燕市吉田下町');
ok($zip->set_number('9590254')->is_valid_number, '新潟県燕市吉田神明町');
ok($zip->set_number('9590255')->is_valid_number, '新潟県燕市吉田弥生町');
ok($zip->set_number('9590256')->is_valid_number, '新潟県燕市吉田寿町');
ok($zip->set_number('9590257')->is_valid_number, '新潟県燕市吉田幸町');
ok($zip->set_number('9590261')->is_valid_number, '新潟県燕市吉田鴻巣');
ok($zip->set_number('9590262')->is_valid_number, '新潟県燕市吉田若生町');
ok($zip->set_number('9590263')->is_valid_number, '新潟県燕市吉田(吉田桃山町)');
ok($zip->set_number('9590264')->is_valid_number, '新潟県燕市吉田(その他)');
ok($zip->set_number('9590265')->is_valid_number, '新潟県燕市吉田東町');
ok($zip->set_number('9590266')->is_valid_number, '新潟県燕市吉田文京町');
ok($zip->set_number('9590267')->is_valid_number, '新潟県燕市吉田宮小路');
ok($zip->set_number('9590268')->is_valid_number, '新潟県燕市吉田本町');
ok($zip->set_number('9590300')->is_valid_number, '新潟県西蒲原郡弥彦村以下に掲載がない場合');
ok($zip->set_number('9590301')->is_valid_number, '新潟県西蒲原郡弥彦村えび穴');
ok($zip->set_number('9590302')->is_valid_number, '新潟県西蒲原郡弥彦村田中新田');
ok($zip->set_number('9590303')->is_valid_number, '新潟県西蒲原郡弥彦村平野');
ok($zip->set_number('9590304')->is_valid_number, '新潟県西蒲原郡弥彦村荻野');
ok($zip->set_number('9590305')->is_valid_number, '新潟県西蒲原郡弥彦村矢作');
ok($zip->set_number('9590306')->is_valid_number, '新潟県西蒲原郡弥彦村浜首');
ok($zip->set_number('9590307')->is_valid_number, '新潟県西蒲原郡弥彦村川崎');
ok($zip->set_number('9590308')->is_valid_number, '新潟県西蒲原郡弥彦村大戸');
ok($zip->set_number('9590309')->is_valid_number, '新潟県西蒲原郡弥彦村峰見');
ok($zip->set_number('9590310')->is_valid_number, '新潟県西蒲原郡弥彦村美山');
ok($zip->set_number('9590311')->is_valid_number, '新潟県西蒲原郡弥彦村井田');
ok($zip->set_number('9590312')->is_valid_number, '新潟県西蒲原郡弥彦村中山');
ok($zip->set_number('9590313')->is_valid_number, '新潟県西蒲原郡弥彦村山崎');
ok($zip->set_number('9590314')->is_valid_number, '新潟県西蒲原郡弥彦村山岸');
ok($zip->set_number('9590315')->is_valid_number, '新潟県西蒲原郡弥彦村麓村新田');
ok($zip->set_number('9590316')->is_valid_number, '新潟県西蒲原郡弥彦村村山');
ok($zip->set_number('9590317')->is_valid_number, '新潟県西蒲原郡弥彦村境江');
ok($zip->set_number('9590318')->is_valid_number, '新潟県西蒲原郡弥彦村麓');
ok($zip->set_number('9590319')->is_valid_number, '新潟県西蒲原郡弥彦村観音寺');
ok($zip->set_number('9590321')->is_valid_number, '新潟県西蒲原郡弥彦村上泉');
ok($zip->set_number('9590322')->is_valid_number, '新潟県西蒲原郡弥彦村走出');
ok($zip->set_number('9590323')->is_valid_number, '新潟県西蒲原郡弥彦村弥彦');
ok($zip->set_number('9590401')->is_valid_number, '新潟県新潟市西区與兵衛野新田');
ok($zip->set_number('9590401')->is_valid_number, '新潟県新潟市西蒲区與兵衛野新田');
ok($zip->set_number('9590402')->is_valid_number, '新潟県新潟市西蒲区三角野新田');
ok($zip->set_number('9590403')->is_valid_number, '新潟県新潟市西蒲区貝柄');
ok($zip->set_number('9590404')->is_valid_number, '新潟県新潟市西蒲区貝柄新田');
ok($zip->set_number('9590405')->is_valid_number, '新潟県新潟市西蒲区堀上新田');
ok($zip->set_number('9590406')->is_valid_number, '新潟県新潟市西蒲区善光寺村受');
ok($zip->set_number('9590407')->is_valid_number, '新潟県新潟市西蒲区旗屋村受');
ok($zip->set_number('9590411')->is_valid_number, '新潟県新潟市西蒲区善光寺');
ok($zip->set_number('9590412')->is_valid_number, '新潟県新潟市西蒲区桑山');
ok($zip->set_number('9590413')->is_valid_number, '新潟県新潟市西蒲区升潟');
ok($zip->set_number('9590414')->is_valid_number, '新潟県新潟市西蒲区兵右衛門新田');
ok($zip->set_number('9590415')->is_valid_number, '新潟県新潟市西蒲区大潟');
ok($zip->set_number('9590416')->is_valid_number, '新潟県新潟市西蒲区浦村');
ok($zip->set_number('9590417')->is_valid_number, '新潟県新潟市西蒲区大関');
ok($zip->set_number('9590418')->is_valid_number, '新潟県新潟市西蒲区升岡');
ok($zip->set_number('9590421')->is_valid_number, '新潟県新潟市西蒲区鱸');
ok($zip->set_number('9590422')->is_valid_number, '新潟県新潟市西蒲区曽根');
ok($zip->set_number('9590423')->is_valid_number, '新潟県新潟市西蒲区旗屋');
ok($zip->set_number('9590424')->is_valid_number, '新潟県新潟市西蒲区松崎');
ok($zip->set_number('9590425')->is_valid_number, '新潟県新潟市西蒲区押付');
ok($zip->set_number('9590426')->is_valid_number, '新潟県新潟市西蒲区矢島');
ok($zip->set_number('9590431')->is_valid_number, '新潟県新潟市西蒲区平野');
ok($zip->set_number('9590432')->is_valid_number, '新潟県新潟市西蒲区川崎');
ok($zip->set_number('9590433')->is_valid_number, '新潟県新潟市西蒲区槇島');
ok($zip->set_number('9590434')->is_valid_number, '新潟県新潟市西蒲区天竺堂');
ok($zip->set_number('9590435')->is_valid_number, '新潟県新潟市西蒲区真田');
ok($zip->set_number('9590436')->is_valid_number, '新潟県新潟市西蒲区西汰上');
ok($zip->set_number('9590437')->is_valid_number, '新潟県新潟市西蒲区中島');
ok($zip->set_number('9590438')->is_valid_number, '新潟県新潟市西蒲区下山');
ok($zip->set_number('9590501')->is_valid_number, '新潟県新潟市西蒲区井随');
ok($zip->set_number('9590502')->is_valid_number, '新潟県新潟市西蒲区熊谷');
ok($zip->set_number('9590503')->is_valid_number, '新潟県新潟市西蒲区山口新田');
ok($zip->set_number('9590504')->is_valid_number, '新潟県新潟市西蒲区横戸');
ok($zip->set_number('9590505')->is_valid_number, '新潟県新潟市西蒲区三方');
ok($zip->set_number('9590506')->is_valid_number, '新潟県新潟市西蒲区遠藤');
ok($zip->set_number('9590507')->is_valid_number, '新潟県新潟市西蒲区卯八郎受');
ok($zip->set_number('9590508')->is_valid_number, '新潟県新潟市西蒲区五之上');
ok($zip->set_number('9590511')->is_valid_number, '新潟県新潟市西蒲区大原');
ok($zip->set_number('9590512')->is_valid_number, '新潟県新潟市西蒲区番屋');
ok($zip->set_number('9590513')->is_valid_number, '新潟県新潟市西蒲区茨島');
ok($zip->set_number('9590514')->is_valid_number, '新潟県新潟市西蒲区称名');
ok($zip->set_number('9590515')->is_valid_number, '新潟県新潟市西蒲区今井');
ok($zip->set_number('9590516')->is_valid_number, '新潟県新潟市西蒲区国見');
ok($zip->set_number('9590517')->is_valid_number, '新潟県新潟市西蒲区大曽根');
ok($zip->set_number('9590518')->is_valid_number, '新潟県新潟市西蒲区南');
ok($zip->set_number('9590519')->is_valid_number, '新潟県新潟市西蒲区美里');
ok($zip->set_number('9590521')->is_valid_number, '新潟県新潟市西蒲区鎧潟');
ok($zip->set_number('9591101')->is_valid_number, '新潟県三条市福島新田甲');
ok($zip->set_number('9591102')->is_valid_number, '新潟県三条市福島新田乙');
ok($zip->set_number('9591103')->is_valid_number, '新潟県三条市福島新田戊');
ok($zip->set_number('9591104')->is_valid_number, '新潟県三条市東光寺');
ok($zip->set_number('9591105')->is_valid_number, '新潟県三条市若宮新田');
ok($zip->set_number('9591106')->is_valid_number, '新潟県三条市吉野屋');
ok($zip->set_number('9591107')->is_valid_number, '新潟県三条市矢田');
ok($zip->set_number('9591108')->is_valid_number, '新潟県三条市北潟');
ok($zip->set_number('9591109')->is_valid_number, '新潟県三条市蔵内');
ok($zip->set_number('9591111')->is_valid_number, '新潟県三条市茅原');
ok($zip->set_number('9591112')->is_valid_number, '新潟県三条市安代');
ok($zip->set_number('9591113')->is_valid_number, '新潟県三条市大面');
ok($zip->set_number('9591114')->is_valid_number, '新潟県三条市高安寺');
ok($zip->set_number('9591115')->is_valid_number, '新潟県三条市小滝');
ok($zip->set_number('9591116')->is_valid_number, '新潟県三条市前谷内');
ok($zip->set_number('9591117')->is_valid_number, '新潟県三条市帯織');
ok($zip->set_number('9591118')->is_valid_number, '新潟県三条市山王');
ok($zip->set_number('9591119')->is_valid_number, '新潟県三条市戸口');
ok($zip->set_number('9591121')->is_valid_number, '新潟県三条市善久寺');
ok($zip->set_number('9591122')->is_valid_number, '新潟県三条市栄荻島');
ok($zip->set_number('9591123')->is_valid_number, '新潟県三条市九之曽根');
ok($zip->set_number('9591124')->is_valid_number, '新潟県三条市千把野新田');
ok($zip->set_number('9591125')->is_valid_number, '新潟県三条市中島');
ok($zip->set_number('9591126')->is_valid_number, '新潟県三条市小古瀬');
ok($zip->set_number('9591131')->is_valid_number, '新潟県三条市芹山');
ok($zip->set_number('9591132')->is_valid_number, '新潟県三条市渡前');
ok($zip->set_number('9591133')->is_valid_number, '新潟県三条市中曽根新田');
ok($zip->set_number('9591134')->is_valid_number, '新潟県三条市鬼木新田');
ok($zip->set_number('9591135')->is_valid_number, '新潟県三条市鬼木');
ok($zip->set_number('9591136')->is_valid_number, '新潟県三条市川通中町');
ok($zip->set_number('9591141')->is_valid_number, '新潟県三条市今井');
ok($zip->set_number('9591142')->is_valid_number, '新潟県三条市今井野新田');
ok($zip->set_number('9591143')->is_valid_number, '新潟県三条市泉新田');
ok($zip->set_number('9591144')->is_valid_number, '新潟県三条市貝喰新田');
ok($zip->set_number('9591145')->is_valid_number, '新潟県三条市福島新田丙');
ok($zip->set_number('9591146')->is_valid_number, '新潟県三条市半ノ木');
ok($zip->set_number('9591147')->is_valid_number, '新潟県三条市岡野新田');
ok($zip->set_number('9591148')->is_valid_number, '新潟県三条市尾崎');
ok($zip->set_number('9591151')->is_valid_number, '新潟県三条市猪子場新田');
ok($zip->set_number('9591152')->is_valid_number, '新潟県三条市一ツ屋敷新田');
ok($zip->set_number('9591153')->is_valid_number, '新潟県三条市新堀');
ok($zip->set_number('9591154')->is_valid_number, '新潟県三条市岩淵');
ok($zip->set_number('9591155')->is_valid_number, '新潟県三条市福島新田丁');
ok($zip->set_number('9591156')->is_valid_number, '新潟県三条市福島新田');
ok($zip->set_number('9591200')->is_valid_number, '新潟県燕市以下に掲載がない場合');
ok($zip->set_number('9591201')->is_valid_number, '新潟県燕市灰方');
ok($zip->set_number('9591202')->is_valid_number, '新潟県燕市松橋');
ok($zip->set_number('9591203')->is_valid_number, '新潟県燕市舘野');
ok($zip->set_number('9591204')->is_valid_number, '新潟県燕市長所');
ok($zip->set_number('9591205')->is_valid_number, '新潟県燕市長渡');
ok($zip->set_number('9591206')->is_valid_number, '新潟県燕市関崎');
ok($zip->set_number('9591207')->is_valid_number, '新潟県燕市三王渕');
ok($zip->set_number('9591211')->is_valid_number, '新潟県燕市小中川');
ok($zip->set_number('9591212')->is_valid_number, '新潟県燕市大船渡');
ok($zip->set_number('9591213')->is_valid_number, '新潟県燕市小古津新');
ok($zip->set_number('9591214')->is_valid_number, '新潟県燕市新生町');
ok($zip->set_number('9591215')->is_valid_number, '新潟県燕市又新');
ok($zip->set_number('9591216')->is_valid_number, '新潟県燕市二階堂');
ok($zip->set_number('9591217')->is_valid_number, '新潟県燕市勘新');
ok($zip->set_number('9591221')->is_valid_number, '新潟県燕市花園町');
ok($zip->set_number('9591222')->is_valid_number, '新潟県燕市次新');
ok($zip->set_number('9591223')->is_valid_number, '新潟県燕市上児木');
ok($zip->set_number('9591223')->is_valid_number, '新潟県燕市下児木');
ok($zip->set_number('9591224')->is_valid_number, '新潟県燕市四ツ屋');
ok($zip->set_number('9591225')->is_valid_number, '新潟県燕市中川');
ok($zip->set_number('9591226')->is_valid_number, '新潟県燕市小牧');
ok($zip->set_number('9591228')->is_valid_number, '新潟県燕市佐渡');
ok($zip->set_number('9591232')->is_valid_number, '新潟県燕市井土巻');
ok($zip->set_number('9591233')->is_valid_number, '新潟県燕市殿島');
ok($zip->set_number('9591234')->is_valid_number, '新潟県燕市南');
ok($zip->set_number('9591241')->is_valid_number, '新潟県燕市小高');
ok($zip->set_number('9591242')->is_valid_number, '新潟県燕市日之出町');
ok($zip->set_number('9591244')->is_valid_number, '新潟県燕市中央通');
ok($zip->set_number('9591246')->is_valid_number, '新潟県燕市新栄町');
ok($zip->set_number('9591251')->is_valid_number, '新潟県燕市白山町');
ok($zip->set_number('9591252')->is_valid_number, '新潟県燕市寿町');
ok($zip->set_number('9591253')->is_valid_number, '新潟県燕市本町');
ok($zip->set_number('9591254')->is_valid_number, '新潟県燕市幸町');
ok($zip->set_number('9591255')->is_valid_number, '新潟県燕市新町');
ok($zip->set_number('9591256')->is_valid_number, '新潟県燕市穀町');
ok($zip->set_number('9591257')->is_valid_number, '新潟県燕市宮町');
ok($zip->set_number('9591258')->is_valid_number, '新潟県燕市仲町');
ok($zip->set_number('9591261')->is_valid_number, '新潟県燕市秋葉町');
ok($zip->set_number('9591262')->is_valid_number, '新潟県燕市水道町');
ok($zip->set_number('9591263')->is_valid_number, '新潟県燕市大曲');
ok($zip->set_number('9591264')->is_valid_number, '新潟県燕市八王寺');
ok($zip->set_number('9591265')->is_valid_number, '新潟県燕市道金');
ok($zip->set_number('9591271')->is_valid_number, '新潟県燕市蔵関');
ok($zip->set_number('9591272')->is_valid_number, '新潟県燕市杉柳');
ok($zip->set_number('9591273')->is_valid_number, '新潟県燕市杉名');
ok($zip->set_number('9591274')->is_valid_number, '新潟県燕市柳山');
ok($zip->set_number('9591275')->is_valid_number, '新潟県燕市小池新町');
ok($zip->set_number('9591276')->is_valid_number, '新潟県燕市小池');
ok($zip->set_number('9591277')->is_valid_number, '新潟県燕市物流センター');
ok($zip->set_number('9591280')->is_valid_number, '新潟県燕市花見');
ok($zip->set_number('9591281')->is_valid_number, '新潟県燕市桜町');
ok($zip->set_number('9591284')->is_valid_number, '新潟県燕市杣木');
ok($zip->set_number('9591286')->is_valid_number, '新潟県燕市小関');
ok($zip->set_number('9591287')->is_valid_number, '新潟県燕市大関');
ok($zip->set_number('9591288')->is_valid_number, '新潟県燕市燕');
ok($zip->set_number('9591289')->is_valid_number, '新潟県燕市東太田');
ok($zip->set_number('9591300')->is_valid_number, '新潟県加茂市以下に掲載がない場合');
ok($zip->set_number('9591301')->is_valid_number, '新潟県加茂市北潟');
ok($zip->set_number('9591302')->is_valid_number, '新潟県加茂市五反田');
ok($zip->set_number('9591303')->is_valid_number, '新潟県加茂市後須田');
ok($zip->set_number('9591304')->is_valid_number, '新潟県加茂市前須田');
ok($zip->set_number('9591305')->is_valid_number, '新潟県加茂市砂押新田');
ok($zip->set_number('9591306')->is_valid_number, '新潟県加茂市鵜森');
ok($zip->set_number('9591307')->is_valid_number, '新潟県加茂市田中新田');
ok($zip->set_number('9591311')->is_valid_number, '新潟県加茂市加茂新田');
ok($zip->set_number('9591312')->is_valid_number, '新潟県加茂市石川');
ok($zip->set_number('9591313')->is_valid_number, '新潟県加茂市幸町');
ok($zip->set_number('9591314')->is_valid_number, '新潟県加茂市番田');
ok($zip->set_number('9591315')->is_valid_number, '新潟県加茂市天神林');
ok($zip->set_number('9591316')->is_valid_number, '新潟県加茂市山島新田');
ok($zip->set_number('9591321')->is_valid_number, '新潟県加茂市希望ケ丘');
ok($zip->set_number('9591322')->is_valid_number, '新潟県加茂市学校町');
ok($zip->set_number('9591323')->is_valid_number, '新潟県加茂市都ケ丘');
ok($zip->set_number('9591324')->is_valid_number, '新潟県加茂市赤谷');
ok($zip->set_number('9591325')->is_valid_number, '新潟県加茂市神明町');
ok($zip->set_number('9591326')->is_valid_number, '新潟県加茂市青海町');
ok($zip->set_number('9591327')->is_valid_number, '新潟県加茂市千刈');
ok($zip->set_number('9591328')->is_valid_number, '新潟県加茂市陣ケ峰');
ok($zip->set_number('9591331')->is_valid_number, '新潟県加茂市皆川');
ok($zip->set_number('9591332')->is_valid_number, '新潟県加茂市上条');
ok($zip->set_number('9591333')->is_valid_number, '新潟県加茂市八幡');
ok($zip->set_number('9591334')->is_valid_number, '新潟県加茂市狭口');
ok($zip->set_number('9591335')->is_valid_number, '新潟県加茂市長谷');
ok($zip->set_number('9591336')->is_valid_number, '新潟県加茂市黒水');
ok($zip->set_number('9591337')->is_valid_number, '新潟県加茂市西山');
ok($zip->set_number('9591341')->is_valid_number, '新潟県加茂市下土倉');
ok($zip->set_number('9591342')->is_valid_number, '新潟県加茂市上土倉');
ok($zip->set_number('9591343')->is_valid_number, '新潟県加茂市上大谷');
ok($zip->set_number('9591344')->is_valid_number, '新潟県加茂市下大谷');
ok($zip->set_number('9591345')->is_valid_number, '新潟県加茂市中大谷');
ok($zip->set_number('9591346')->is_valid_number, '新潟県加茂市下高柳');
ok($zip->set_number('9591347')->is_valid_number, '新潟県加茂市上高柳');
ok($zip->set_number('9591348')->is_valid_number, '新潟県加茂市宮寄上');
ok($zip->set_number('9591351')->is_valid_number, '新潟県加茂市仲町');
ok($zip->set_number('9591352')->is_valid_number, '新潟県加茂市上町');
ok($zip->set_number('9591353')->is_valid_number, '新潟県加茂市五番町');
ok($zip->set_number('9591354')->is_valid_number, '新潟県加茂市新町');
ok($zip->set_number('9591355')->is_valid_number, '新潟県加茂市若宮町');
ok($zip->set_number('9591356')->is_valid_number, '新潟県加茂市秋房');
ok($zip->set_number('9591357')->is_valid_number, '新潟県加茂市桜沢');
ok($zip->set_number('9591361')->is_valid_number, '新潟県加茂市下条');
ok($zip->set_number('9591362')->is_valid_number, '新潟県加茂市横江');
ok($zip->set_number('9591363')->is_valid_number, '新潟県加茂市芝野');
ok($zip->set_number('9591371')->is_valid_number, '新潟県加茂市穀町');
ok($zip->set_number('9591372')->is_valid_number, '新潟県加茂市本町');
ok($zip->set_number('9591373')->is_valid_number, '新潟県加茂市松坂町');
ok($zip->set_number('9591374')->is_valid_number, '新潟県加茂市矢立');
ok($zip->set_number('9591375')->is_valid_number, '新潟県加茂市小橋');
ok($zip->set_number('9591376')->is_valid_number, '新潟県加茂市中村');
ok($zip->set_number('9591377')->is_valid_number, '新潟県加茂市岡ノ町');
ok($zip->set_number('9591378')->is_valid_number, '新潟県加茂市駅前');
ok($zip->set_number('9591381')->is_valid_number, '新潟県加茂市新栄町');
ok($zip->set_number('9591382')->is_valid_number, '新潟県加茂市栄町');
ok($zip->set_number('9591383')->is_valid_number, '新潟県加茂市旭町');
ok($zip->set_number('9591384')->is_valid_number, '新潟県加茂市寿町');
ok($zip->set_number('9591385')->is_valid_number, '新潟県加茂市大郷町');
ok($zip->set_number('9591386')->is_valid_number, '新潟県加茂市柳町');
ok($zip->set_number('9591387')->is_valid_number, '新潟県加茂市高須町');
ok($zip->set_number('9591500')->is_valid_number, '新潟県南蒲原郡田上町以下に掲載がない場合');
ok($zip->set_number('9591501')->is_valid_number, '新潟県南蒲原郡田上町湯川');
ok($zip->set_number('9591502')->is_valid_number, '新潟県南蒲原郡田上町田上');
ok($zip->set_number('9591503')->is_valid_number, '新潟県南蒲原郡田上町原ケ崎新田');
ok($zip->set_number('9591511')->is_valid_number, '新潟県南蒲原郡田上町吉田新田');
ok($zip->set_number('9591512')->is_valid_number, '新潟県南蒲原郡田上町羽生田');
ok($zip->set_number('9591513')->is_valid_number, '新潟県南蒲原郡田上町川船河');
ok($zip->set_number('9591514')->is_valid_number, '新潟県南蒲原郡田上町坂田');
ok($zip->set_number('9591521')->is_valid_number, '新潟県南蒲原郡田上町石田新田');
ok($zip->set_number('9591522')->is_valid_number, '新潟県南蒲原郡田上町千苅新田');
ok($zip->set_number('9591523')->is_valid_number, '新潟県南蒲原郡田上町保明新田');
ok($zip->set_number('9591524')->is_valid_number, '新潟県南蒲原郡田上町横場新田');
ok($zip->set_number('9591525')->is_valid_number, '新潟県南蒲原郡田上町曽根新田');
ok($zip->set_number('9591600')->is_valid_number, '新潟県五泉市以下に掲載がない場合');
ok($zip->set_number('9591601')->is_valid_number, '新潟県五泉市一本杉');
ok($zip->set_number('9591602')->is_valid_number, '新潟県五泉市高山');
ok($zip->set_number('9591603')->is_valid_number, '新潟県五泉市荻野島');
ok($zip->set_number('9591604')->is_valid_number, '新潟県五泉市論瀬');
ok($zip->set_number('9591611')->is_valid_number, '新潟県五泉市笹堀');
ok($zip->set_number('9591612')->is_valid_number, '新潟県五泉市小搦');
ok($zip->set_number('9591613')->is_valid_number, '新潟県五泉市小流');
ok($zip->set_number('9591614')->is_valid_number, '新潟県五泉市馬下');
ok($zip->set_number('9591615')->is_valid_number, '新潟県五泉市佐取');
ok($zip->set_number('9591621')->is_valid_number, '新潟県五泉市尾白');
ok($zip->set_number('9591622')->is_valid_number, '新潟県五泉市小栗山');
ok($zip->set_number('9591623')->is_valid_number, '新潟県五泉市大谷');
ok($zip->set_number('9591624')->is_valid_number, '新潟県五泉市小山田');
ok($zip->set_number('9591625')->is_valid_number, '新潟県五泉市切畑');
ok($zip->set_number('9591631')->is_valid_number, '新潟県五泉市猿和田');
ok($zip->set_number('9591632')->is_valid_number, '新潟県五泉市中川新');
ok($zip->set_number('9591633')->is_valid_number, '新潟県五泉市大須郷');
ok($zip->set_number('9591634')->is_valid_number, '新潟県五泉市不動堂');
ok($zip->set_number('9591635')->is_valid_number, '新潟県五泉市柄沢');
ok($zip->set_number('9591636')->is_valid_number, '新潟県五泉市大蔵');
ok($zip->set_number('9591637')->is_valid_number, '新潟県五泉市菅出');
ok($zip->set_number('9591641')->is_valid_number, '新潟県五泉市赤羽');
ok($zip->set_number('9591642')->is_valid_number, '新潟県五泉市四ツ屋新');
ok($zip->set_number('9591643')->is_valid_number, '新潟県五泉市土堀');
ok($zip->set_number('9591644')->is_valid_number, '新潟県五泉市東四ツ屋');
ok($zip->set_number('9591701')->is_valid_number, '新潟県五泉市石曽根');
ok($zip->set_number('9591703')->is_valid_number, '新潟県五泉市矢津');
ok($zip->set_number('9591704')->is_valid_number, '新潟県五泉市村松甲');
ok($zip->set_number('9591705')->is_valid_number, '新潟県五泉市村松乙');
ok($zip->set_number('9591706')->is_valid_number, '新潟県五泉市村松丙');
ok($zip->set_number('9591707')->is_valid_number, '新潟県五泉市村松');
ok($zip->set_number('9591708')->is_valid_number, '新潟県五泉市上木越');
ok($zip->set_number('9591709')->is_valid_number, '新潟県五泉市木越荒屋');
ok($zip->set_number('9591711')->is_valid_number, '新潟県五泉市川内');
ok($zip->set_number('9591712')->is_valid_number, '新潟県五泉市土淵');
ok($zip->set_number('9591713')->is_valid_number, '新潟県五泉市水戸野');
ok($zip->set_number('9591714')->is_valid_number, '新潟県五泉市仙見谷');
ok($zip->set_number('9591715')->is_valid_number, '新潟県五泉市夏針');
ok($zip->set_number('9591716')->is_valid_number, '新潟県五泉市熊沢');
ok($zip->set_number('9591717')->is_valid_number, '新潟県五泉市阿弥陀瀬');
ok($zip->set_number('9591718')->is_valid_number, '新潟県五泉市下阿弥陀瀬');
ok($zip->set_number('9591721')->is_valid_number, '新潟県五泉市暮坪');
ok($zip->set_number('9591722')->is_valid_number, '新潟県五泉市松野');
ok($zip->set_number('9591723')->is_valid_number, '新潟県五泉市横渡');
ok($zip->set_number('9591724')->is_valid_number, '新潟県五泉市笹目');
ok($zip->set_number('9591725')->is_valid_number, '新潟県五泉市小面谷');
ok($zip->set_number('9591726')->is_valid_number, '新潟県五泉市上杉川');
ok($zip->set_number('9591727')->is_valid_number, '新潟県五泉市下杉川');
ok($zip->set_number('9591731')->is_valid_number, '新潟県五泉市大口');
ok($zip->set_number('9591732')->is_valid_number, '新潟県五泉市中島');
ok($zip->set_number('9591733')->is_valid_number, '新潟県五泉市安出');
ok($zip->set_number('9591734')->is_valid_number, '新潟県五泉市大原');
ok($zip->set_number('9591735')->is_valid_number, '新潟県五泉市蛭野');
ok($zip->set_number('9591736')->is_valid_number, '新潟県五泉市山谷');
ok($zip->set_number('9591737')->is_valid_number, '新潟県五泉市新屋');
ok($zip->set_number('9591738')->is_valid_number, '新潟県五泉市別所');
ok($zip->set_number('9591739')->is_valid_number, '新潟県五泉市村松工業団地');
ok($zip->set_number('9591741')->is_valid_number, '新潟県五泉市南田中');
ok($zip->set_number('9591742')->is_valid_number, '新潟県五泉市寺田');
ok($zip->set_number('9591743')->is_valid_number, '新潟県五泉市下大蒲原');
ok($zip->set_number('9591744')->is_valid_number, '新潟県五泉市上大蒲原');
ok($zip->set_number('9591745')->is_valid_number, '新潟県五泉市下戸倉');
ok($zip->set_number('9591746')->is_valid_number, '新潟県五泉市上戸倉');
ok($zip->set_number('9591747')->is_valid_number, '新潟県五泉市高松');
ok($zip->set_number('9591748')->is_valid_number, '新潟県五泉市牧');
ok($zip->set_number('9591749')->is_valid_number, '新潟県五泉市上野');
ok($zip->set_number('9591751')->is_valid_number, '新潟県五泉市中名沢');
ok($zip->set_number('9591752')->is_valid_number, '新潟県五泉市千原');
ok($zip->set_number('9591753')->is_valid_number, '新潟県五泉市笹野町');
ok($zip->set_number('9591754')->is_valid_number, '新潟県五泉市中野橋');
ok($zip->set_number('9591755')->is_valid_number, '新潟県五泉市青橋');
ok($zip->set_number('9591756')->is_valid_number, '新潟県五泉市刈羽');
ok($zip->set_number('9591757')->is_valid_number, '新潟県五泉市長橋');
ok($zip->set_number('9591758')->is_valid_number, '新潟県五泉市城下');
ok($zip->set_number('9591759')->is_valid_number, '新潟県五泉市美郷');
ok($zip->set_number('9591761')->is_valid_number, '新潟県五泉市本田屋');
ok($zip->set_number('9591762')->is_valid_number, '新潟県五泉市東石曽根');
ok($zip->set_number('9591763')->is_valid_number, '新潟県五泉市熊野堂');
ok($zip->set_number('9591764')->is_valid_number, '新潟県五泉市宮野下');
ok($zip->set_number('9591765')->is_valid_number, '新潟県五泉市愛宕');
ok($zip->set_number('9591766')->is_valid_number, '新潟県五泉市番坂');
ok($zip->set_number('9591767')->is_valid_number, '新潟県五泉市新田町');
ok($zip->set_number('9591801')->is_valid_number, '新潟県五泉市羽下');
ok($zip->set_number('9591802')->is_valid_number, '新潟県五泉市下新');
ok($zip->set_number('9591803')->is_valid_number, '新潟県五泉市下条');
ok($zip->set_number('9591804')->is_valid_number, '新潟県五泉市田屋');
ok($zip->set_number('9591805')->is_valid_number, '新潟県五泉市船越');
ok($zip->set_number('9591806')->is_valid_number, '新潟県五泉市猿橋');
ok($zip->set_number('9591807')->is_valid_number, '新潟県五泉市次屋');
ok($zip->set_number('9591811')->is_valid_number, '新潟県五泉市三本木');
ok($zip->set_number('9591812')->is_valid_number, '新潟県五泉市水島町');
ok($zip->set_number('9591813')->is_valid_number, '新潟県五泉市伊勢の川');
ok($zip->set_number('9591814')->is_valid_number, '新潟県五泉市北五泉駅前');
ok($zip->set_number('9591821')->is_valid_number, '新潟県五泉市赤海');
ok($zip->set_number('9591822')->is_valid_number, '新潟県五泉市緑町');
ok($zip->set_number('9591823')->is_valid_number, '新潟県五泉市駅前');
ok($zip->set_number('9591824')->is_valid_number, '新潟県五泉市吉沢');
ok($zip->set_number('9591825')->is_valid_number, '新潟県五泉市太田');
ok($zip->set_number('9591831')->is_valid_number, '新潟県五泉市曙町');
ok($zip->set_number('9591832')->is_valid_number, '新潟県五泉市川瀬');
ok($zip->set_number('9591833')->is_valid_number, '新潟県五泉市五十嵐新田');
ok($zip->set_number('9591834')->is_valid_number, '新潟県五泉市木越');
ok($zip->set_number('9591835')->is_valid_number, '新潟県五泉市今泉');
ok($zip->set_number('9591836')->is_valid_number, '新潟県五泉市南本町');
ok($zip->set_number('9591837')->is_valid_number, '新潟県五泉市寺沢');
ok($zip->set_number('9591841')->is_valid_number, '新潟県五泉市二ツ柳');
ok($zip->set_number('9591842')->is_valid_number, '新潟県五泉市能代');
ok($zip->set_number('9591843')->is_valid_number, '新潟県五泉市町屋');
ok($zip->set_number('9591844')->is_valid_number, '新潟県五泉市西四ツ屋');
ok($zip->set_number('9591845')->is_valid_number, '新潟県五泉市大沢');
ok($zip->set_number('9591846')->is_valid_number, '新潟県五泉市尻上');
ok($zip->set_number('9591847')->is_valid_number, '新潟県五泉市菅沢');
ok($zip->set_number('9591848')->is_valid_number, '新潟県五泉市橋田');
ok($zip->set_number('9591851')->is_valid_number, '新潟県五泉市五泉');
ok($zip->set_number('9591852')->is_valid_number, '新潟県五泉市荻曽根');
ok($zip->set_number('9591853')->is_valid_number, '新潟県五泉市土深');
ok($zip->set_number('9591854')->is_valid_number, '新潟県五泉市丸田');
ok($zip->set_number('9591855')->is_valid_number, '新潟県五泉市小熊');
ok($zip->set_number('9591856')->is_valid_number, '新潟県五泉市山崎');
ok($zip->set_number('9591857')->is_valid_number, '新潟県五泉市石倉');
ok($zip->set_number('9591861')->is_valid_number, '新潟県五泉市粟島');
ok($zip->set_number('9591862')->is_valid_number, '新潟県五泉市旭町');
ok($zip->set_number('9591863')->is_valid_number, '新潟県五泉市東本町');
ok($zip->set_number('9591864')->is_valid_number, '新潟県五泉市郷屋川');
ok($zip->set_number('9591865')->is_valid_number, '新潟県五泉市本町');
ok($zip->set_number('9591866')->is_valid_number, '新潟県五泉市学校町');
ok($zip->set_number('9591867')->is_valid_number, '新潟県五泉市大川前');
ok($zip->set_number('9591871')->is_valid_number, '新潟県五泉市白山');
ok($zip->set_number('9591872')->is_valid_number, '新潟県五泉市宮町');
ok($zip->set_number('9591873')->is_valid_number, '新潟県五泉市錦町');
ok($zip->set_number('9591874')->is_valid_number, '新潟県五泉市横町');
ok($zip->set_number('9591875')->is_valid_number, '新潟県五泉市馬場町');
ok($zip->set_number('9591876')->is_valid_number, '新潟県五泉市泉町');
ok($zip->set_number('9591901')->is_valid_number, '新潟県阿賀野市中ノ通');
ok($zip->set_number('9591902')->is_valid_number, '新潟県阿賀野市飯山新');
ok($zip->set_number('9591903')->is_valid_number, '新潟県阿賀野市藤屋');
ok($zip->set_number('9591904')->is_valid_number, '新潟県阿賀野市上西野');
ok($zip->set_number('9591905')->is_valid_number, '新潟県阿賀野市滝沢');
ok($zip->set_number('9591906')->is_valid_number, '新潟県阿賀野市村岡');
ok($zip->set_number('9591907')->is_valid_number, '新潟県阿賀野市熊堂');
ok($zip->set_number('9591908')->is_valid_number, '新潟県阿賀野市上蔵野');
ok($zip->set_number('9591909')->is_valid_number, '新潟県阿賀野市上高関');
ok($zip->set_number('9591910')->is_valid_number, '新潟県阿賀野市向中ノ通');
ok($zip->set_number('9591911')->is_valid_number, '新潟県阿賀野市長起');
ok($zip->set_number('9591912')->is_valid_number, '新潟県阿賀野市下一分');
ok($zip->set_number('9591913')->is_valid_number, '新潟県阿賀野市沢口');
ok($zip->set_number('9591914')->is_valid_number, '新潟県阿賀野市女堂');
ok($zip->set_number('9591915')->is_valid_number, '新潟県阿賀野市上一分');
ok($zip->set_number('9591916')->is_valid_number, '新潟県阿賀野市小栗山');
ok($zip->set_number('9591917')->is_valid_number, '新潟県阿賀野市堤');
ok($zip->set_number('9591918')->is_valid_number, '新潟県阿賀野市笹岡');
ok($zip->set_number('9591919')->is_valid_number, '新潟県阿賀野市山崎');
ok($zip->set_number('9591921')->is_valid_number, '新潟県阿賀野市折居');
ok($zip->set_number('9591921')->is_valid_number, '新潟県阿賀野市上西山');
ok($zip->set_number('9591922')->is_valid_number, '新潟県阿賀野市湯沢');
ok($zip->set_number('9591923')->is_valid_number, '新潟県阿賀野市勝屋');
ok($zip->set_number('9591924')->is_valid_number, '新潟県阿賀野市畑江');
ok($zip->set_number('9591925')->is_valid_number, '新潟県阿賀野市真光寺ヴィレッジ');
ok($zip->set_number('9591926')->is_valid_number, '新潟県阿賀野市出湯');
ok($zip->set_number('9591927')->is_valid_number, '新潟県阿賀野市今板');
ok($zip->set_number('9591928')->is_valid_number, '新潟県阿賀野市村杉');
ok($zip->set_number('9591929')->is_valid_number, '新潟県阿賀野市大日');
ok($zip->set_number('9591930')->is_valid_number, '新潟県阿賀野市大宮');
ok($zip->set_number('9591931')->is_valid_number, '新潟県阿賀野市山寺');
ok($zip->set_number('9591932')->is_valid_number, '新潟県阿賀野市上山田');
ok($zip->set_number('9591933')->is_valid_number, '新潟県阿賀野市上小中山');
ok($zip->set_number('9591934')->is_valid_number, '新潟県阿賀野市七浦');
ok($zip->set_number('9591935')->is_valid_number, '新潟県阿賀野市大室');
ok($zip->set_number('9591936')->is_valid_number, '新潟県阿賀野市十二神');
ok($zip->set_number('9591937')->is_valid_number, '新潟県阿賀野市福井');
ok($zip->set_number('9591938')->is_valid_number, '新潟県阿賀野市貝喰');
ok($zip->set_number('9591941')->is_valid_number, '新潟県阿賀野市羽黒');
ok($zip->set_number('9591942')->is_valid_number, '新潟県阿賀野市上坂町');
ok($zip->set_number('9591943')->is_valid_number, '新潟県阿賀野市次郎丸');
ok($zip->set_number('9591944')->is_valid_number, '新潟県阿賀野市金屋');
ok($zip->set_number('9591945')->is_valid_number, '新潟県阿賀野市上山屋');
ok($zip->set_number('9591946')->is_valid_number, '新潟県阿賀野市押切');
ok($zip->set_number('9591947')->is_valid_number, '新潟県阿賀野市宮下');
ok($zip->set_number('9591948')->is_valid_number, '新潟県阿賀野市宮島');
ok($zip->set_number('9591949')->is_valid_number, '新潟県阿賀野市川崎');
ok($zip->set_number('9591951')->is_valid_number, '新潟県阿賀野市下福岡');
ok($zip->set_number('9591952')->is_valid_number, '新潟県阿賀野市下山屋');
ok($zip->set_number('9591953')->is_valid_number, '新潟県阿賀野市発久');
ok($zip->set_number('9591954')->is_valid_number, '新潟県阿賀野市蒔田');
ok($zip->set_number('9591955')->is_valid_number, '新潟県阿賀野市赤水');
ok($zip->set_number('9591956')->is_valid_number, '新潟県阿賀野市須走');
ok($zip->set_number('9591957')->is_valid_number, '新潟県阿賀野市横山');
ok($zip->set_number('9591958')->is_valid_number, '新潟県阿賀野市野村');
ok($zip->set_number('9591959')->is_valid_number, '新潟県阿賀野市泉');
ok($zip->set_number('9591961')->is_valid_number, '新潟県阿賀野市山倉');
ok($zip->set_number('9591962')->is_valid_number, '新潟県阿賀野市上関口');
ok($zip->set_number('9591963')->is_valid_number, '新潟県阿賀野市南沖山');
ok($zip->set_number('9591964')->is_valid_number, '新潟県阿賀野市沖');
ok($zip->set_number('9591965')->is_valid_number, '新潟県阿賀野市島田');
ok($zip->set_number('9591966')->is_valid_number, '新潟県阿賀野市塚田');
ok($zip->set_number('9591967')->is_valid_number, '新潟県阿賀野市本明');
ok($zip->set_number('9591968')->is_valid_number, '新潟県阿賀野市榎船渡');
ok($zip->set_number('9591971')->is_valid_number, '新潟県阿賀野市高田');
ok($zip->set_number('9591972')->is_valid_number, '新潟県阿賀野市山倉新田');
ok($zip->set_number('9591973')->is_valid_number, '新潟県阿賀野市上高田');
ok($zip->set_number('9591974')->is_valid_number, '新潟県阿賀野市榎');
ok($zip->set_number('9591975')->is_valid_number, '新潟県阿賀野市荻島');
ok($zip->set_number('9591975')->is_valid_number, '新潟県阿賀野市上飯塚');
ok($zip->set_number('9591976')->is_valid_number, '新潟県阿賀野市船居');
ok($zip->set_number('9591977')->is_valid_number, '新潟県阿賀野市沖ノ館');
ok($zip->set_number('9591978')->is_valid_number, '新潟県阿賀野市川岡');
ok($zip->set_number('9592000')->is_valid_number, '新潟県阿賀野市以下に掲載がない場合');
ok($zip->set_number('9592001')->is_valid_number, '新潟県阿賀野市沖通');
ok($zip->set_number('9592002')->is_valid_number, '新潟県阿賀野市下条');
ok($zip->set_number('9592003')->is_valid_number, '新潟県阿賀野市安野町');
ok($zip->set_number('9592004')->is_valid_number, '新潟県阿賀野市南安野町');
ok($zip->set_number('9592005')->is_valid_number, '新潟県阿賀野市山口町');
ok($zip->set_number('9592006')->is_valid_number, '新潟県阿賀野市みそら野町');
ok($zip->set_number('9592007')->is_valid_number, '新潟県阿賀野市山口');
ok($zip->set_number('9592011')->is_valid_number, '新潟県阿賀野市千原');
ok($zip->set_number('9592012')->is_valid_number, '新潟県阿賀野市天神堂');
ok($zip->set_number('9592013')->is_valid_number, '新潟県阿賀野市水原');
ok($zip->set_number('9592014')->is_valid_number, '新潟県阿賀野市北園町');
ok($zip->set_number('9592015')->is_valid_number, '新潟県阿賀野市北本町');
ok($zip->set_number('9592021')->is_valid_number, '新潟県阿賀野市中央町');
ok($zip->set_number('9592022')->is_valid_number, '新潟県阿賀野市外城町');
ok($zip->set_number('9592023')->is_valid_number, '新潟県阿賀野市日の出町');
ok($zip->set_number('9592024')->is_valid_number, '新潟県阿賀野市中島');
ok($zip->set_number('9592024')->is_valid_number, '新潟県阿賀野市中島町');
ok($zip->set_number('9592025')->is_valid_number, '新潟県阿賀野市岡山町');
ok($zip->set_number('9592026')->is_valid_number, '新潟県阿賀野市下条町');
ok($zip->set_number('9592031')->is_valid_number, '新潟県阿賀野市金田町');
ok($zip->set_number('9592032')->is_valid_number, '新潟県阿賀野市学校町');
ok($zip->set_number('9592033')->is_valid_number, '新潟県阿賀野市百津町');
ok($zip->set_number('9592034')->is_valid_number, '新潟県阿賀野市緑町');
ok($zip->set_number('9592035')->is_valid_number, '新潟県阿賀野市稲荷町');
ok($zip->set_number('9592036')->is_valid_number, '新潟県阿賀野市若葉町');
ok($zip->set_number('9592037')->is_valid_number, '新潟県阿賀野市百津');
ok($zip->set_number('9592041')->is_valid_number, '新潟県阿賀野市原');
ok($zip->set_number('9592042')->is_valid_number, '新潟県阿賀野市境新田');
ok($zip->set_number('9592043')->is_valid_number, '新潟県阿賀野市大野地');
ok($zip->set_number('9592044')->is_valid_number, '新潟県阿賀野市金沢');
ok($zip->set_number('9592045')->is_valid_number, '新潟県阿賀野市里');
ok($zip->set_number('9592046')->is_valid_number, '新潟県阿賀野市庄ケ宮');
ok($zip->set_number('9592047')->is_valid_number, '新潟県阿賀野市上中');
ok($zip->set_number('9592048')->is_valid_number, '新潟県阿賀野市上中野目');
ok($zip->set_number('9592049')->is_valid_number, '新潟県阿賀野市深町');
ok($zip->set_number('9592051')->is_valid_number, '新潟県阿賀野市七石');
ok($zip->set_number('9592052')->is_valid_number, '新潟県阿賀野市田中');
ok($zip->set_number('9592053')->is_valid_number, '新潟県阿賀野市境新');
ok($zip->set_number('9592054')->is_valid_number, '新潟県阿賀野市越御堂');
ok($zip->set_number('9592055')->is_valid_number, '新潟県阿賀野市堀越');
ok($zip->set_number('9592056')->is_valid_number, '新潟県阿賀野市牧島');
ok($zip->set_number('9592057')->is_valid_number, '新潟県阿賀野市野地城');
ok($zip->set_number('9592061')->is_valid_number, '新潟県阿賀野市荒屋');
ok($zip->set_number('9592062')->is_valid_number, '新潟県阿賀野市市野山');
ok($zip->set_number('9592063')->is_valid_number, '新潟県阿賀野市土橋');
ok($zip->set_number('9592064')->is_valid_number, '新潟県阿賀野市福田');
ok($zip->set_number('9592065')->is_valid_number, '新潟県阿賀野市小境');
ok($zip->set_number('9592066')->is_valid_number, '新潟県阿賀野市中潟');
ok($zip->set_number('9592071')->is_valid_number, '新潟県阿賀野市水ケ曽根');
ok($zip->set_number('9592072')->is_valid_number, '新潟県阿賀野市西岡');
ok($zip->set_number('9592073')->is_valid_number, '新潟県阿賀野市上福岡');
ok($zip->set_number('9592074')->is_valid_number, '新潟県阿賀野市分田');
ok($zip->set_number('9592075')->is_valid_number, '新潟県阿賀野市東町');
ok($zip->set_number('9592081')->is_valid_number, '新潟県阿賀野市上江端');
ok($zip->set_number('9592082')->is_valid_number, '新潟県阿賀野市切梅新田');
ok($zip->set_number('9592083')->is_valid_number, '新潟県阿賀野市熊居新田');
ok($zip->set_number('9592085')->is_valid_number, '新潟県阿賀野市山本新');
ok($zip->set_number('9592086')->is_valid_number, '新潟県阿賀野市新座');
ok($zip->set_number('9592101')->is_valid_number, '新潟県阿賀野市駒林');
ok($zip->set_number('9592102')->is_valid_number, '新潟県阿賀野市五郎巻');
ok($zip->set_number('9592103')->is_valid_number, '新潟県阿賀野市金渕甲');
ok($zip->set_number('9592104')->is_valid_number, '新潟県阿賀野市法柳新田');
ok($zip->set_number('9592105')->is_valid_number, '新潟県阿賀野市金渕乙');
ok($zip->set_number('9592106')->is_valid_number, '新潟県阿賀野市法柳');
ok($zip->set_number('9592107')->is_valid_number, '新潟県阿賀野市深堀');
ok($zip->set_number('9592111')->is_valid_number, '新潟県阿賀野市猫山');
ok($zip->set_number('9592112')->is_valid_number, '新潟県阿賀野市曽郷');
ok($zip->set_number('9592113')->is_valid_number, '新潟県阿賀野市緑岡');
ok($zip->set_number('9592114')->is_valid_number, '新潟県阿賀野市城');
ok($zip->set_number('9592115')->is_valid_number, '新潟県阿賀野市田山');
ok($zip->set_number('9592116')->is_valid_number, '新潟県阿賀野市上黒瀬');
ok($zip->set_number('9592117')->is_valid_number, '新潟県阿賀野市下黒瀬');
ok($zip->set_number('9592121')->is_valid_number, '新潟県阿賀野市小里');
ok($zip->set_number('9592122')->is_valid_number, '新潟県阿賀野市飯森杉');
ok($zip->set_number('9592123')->is_valid_number, '新潟県阿賀野市姥ケ橋');
ok($zip->set_number('9592124')->is_valid_number, '新潟県阿賀野市下ノ橋');
ok($zip->set_number('9592125')->is_valid_number, '新潟県阿賀野市京ケ島');
ok($zip->set_number('9592126')->is_valid_number, '新潟県阿賀野市窪川原');
ok($zip->set_number('9592130')->is_valid_number, '新潟県阿賀野市六日野');
ok($zip->set_number('9592131')->is_valid_number, '新潟県阿賀野市月崎');
ok($zip->set_number('9592132')->is_valid_number, '新潟県阿賀野市前山');
ok($zip->set_number('9592133')->is_valid_number, '新潟県阿賀野市関屋');
ok($zip->set_number('9592134')->is_valid_number, '新潟県阿賀野市小河原');
ok($zip->set_number('9592135')->is_valid_number, '新潟県阿賀野市下里');
ok($zip->set_number('9592136')->is_valid_number, '新潟県阿賀野市京ケ瀬工業団地');
ok($zip->set_number('9592141')->is_valid_number, '新潟県阿賀野市七島');
ok($zip->set_number('9592142')->is_valid_number, '新潟県阿賀野市箸木免');
ok($zip->set_number('9592143')->is_valid_number, '新潟県阿賀野市川前');
ok($zip->set_number('9592144')->is_valid_number, '新潟県阿賀野市清野');
ok($zip->set_number('9592145')->is_valid_number, '新潟県阿賀野市寺社新');
ok($zip->set_number('9592146')->is_valid_number, '新潟県阿賀野市小島');
ok($zip->set_number('9592147')->is_valid_number, '新潟県阿賀野市粕島');
ok($zip->set_number('9592148')->is_valid_number, '新潟県阿賀野市嘉瀬島');
ok($zip->set_number('9592201')->is_valid_number, '新潟県阿賀野市羽多屋');
ok($zip->set_number('9592202')->is_valid_number, '新潟県阿賀野市籠田');
ok($zip->set_number('9592203')->is_valid_number, '新潟県阿賀野市丸山');
ok($zip->set_number('9592204')->is_valid_number, '新潟県阿賀野市福永');
ok($zip->set_number('9592205')->is_valid_number, '新潟県阿賀野市寺社');
ok($zip->set_number('9592206')->is_valid_number, '新潟県阿賀野市かがやき');
ok($zip->set_number('9592211')->is_valid_number, '新潟県阿賀野市沢田');
ok($zip->set_number('9592212')->is_valid_number, '新潟県阿賀野市久保');
ok($zip->set_number('9592213')->is_valid_number, '新潟県阿賀野市小松');
ok($zip->set_number('9592214')->is_valid_number, '新潟県阿賀野市草水');
ok($zip->set_number('9592215')->is_valid_number, '新潟県阿賀野市六野瀬');
ok($zip->set_number('9592216')->is_valid_number, '新潟県阿賀野市渡場');
ok($zip->set_number('9592217')->is_valid_number, '新潟県阿賀野市新保');
ok($zip->set_number('9592221')->is_valid_number, '新潟県阿賀野市保田');
ok($zip->set_number('9592222')->is_valid_number, '新潟県阿賀野市小浮');
ok($zip->set_number('9592223')->is_valid_number, '新潟県阿賀野市布目');
ok($zip->set_number('9592224')->is_valid_number, '新潟県阿賀野市千唐仁');
ok($zip->set_number('9592225')->is_valid_number, '新潟県阿賀野市嶋瀬');
ok($zip->set_number('9592226')->is_valid_number, '新潟県阿賀野市野田');
ok($zip->set_number('9592227')->is_valid_number, '新潟県阿賀野市大和');
ok($zip->set_number('9592301')->is_valid_number, '新潟県新発田市竹ケ花');
ok($zip->set_number('9592302')->is_valid_number, '新潟県新発田市二ツ堂');
ok($zip->set_number('9592303')->is_valid_number, '新潟県新発田市切梅');
ok($zip->set_number('9592304')->is_valid_number, '新潟県新発田市大伝');
ok($zip->set_number('9592305')->is_valid_number, '新潟県新発田市戸板沢');
ok($zip->set_number('9592311')->is_valid_number, '新潟県新発田市荒町');
ok($zip->set_number('9592312')->is_valid_number, '新潟県新発田市太斎');
ok($zip->set_number('9592313')->is_valid_number, '新潟県新発田市藤掛');
ok($zip->set_number('9592314')->is_valid_number, '新潟県新発田市赤橋');
ok($zip->set_number('9592315')->is_valid_number, '新潟県新発田市小坂');
ok($zip->set_number('9592321')->is_valid_number, '新潟県新発田市池ノ端');
ok($zip->set_number('9592322')->is_valid_number, '新潟県新発田市下中ノ目');
ok($zip->set_number('9592323')->is_valid_number, '新潟県新発田市乙次');
ok($zip->set_number('9592324')->is_valid_number, '新潟県新発田市吉浦');
ok($zip->set_number('9592325')->is_valid_number, '新潟県新発田市天王');
ok($zip->set_number('9592326')->is_valid_number, '新潟県新発田市三ツ椡');
ok($zip->set_number('9592327')->is_valid_number, '新潟県新発田市福島');
ok($zip->set_number('9592328')->is_valid_number, '新潟県新発田市乗廻');
ok($zip->set_number('9592329')->is_valid_number, '新潟県新発田市中ノ目新田');
ok($zip->set_number('9592331')->is_valid_number, '新潟県新発田市下飯塚');
ok($zip->set_number('9592332')->is_valid_number, '新潟県新発田市万代');
ok($zip->set_number('9592333')->is_valid_number, '新潟県新発田市岡屋敷');
ok($zip->set_number('9592334')->is_valid_number, '新潟県新発田市月岡');
ok($zip->set_number('9592335')->is_valid_number, '新潟県新発田市本田');
ok($zip->set_number('9592336')->is_valid_number, '新潟県新発田市加治万代');
ok($zip->set_number('9592337')->is_valid_number, '新潟県新発田市竹俣万代');
ok($zip->set_number('9592338')->is_valid_number, '新潟県新発田市月岡温泉');
ok($zip->set_number('9592381')->is_valid_number, '新潟県新発田市滝沢');
ok($zip->set_number('9592401')->is_valid_number, '新潟県新発田市湖南');
ok($zip->set_number('9592402')->is_valid_number, '新潟県新発田市小島');
ok($zip->set_number('9592403')->is_valid_number, '新潟県新発田市塚田');
ok($zip->set_number('9592404')->is_valid_number, '新潟県新発田市下城');
ok($zip->set_number('9592405')->is_valid_number, '新潟県新発田市野中');
ok($zip->set_number('9592406')->is_valid_number, '新潟県新発田市稲荷');
ok($zip->set_number('9592407')->is_valid_number, '新潟県新発田市川口');
ok($zip->set_number('9592408')->is_valid_number, '新潟県新発田市吉田');
ok($zip->set_number('9592409')->is_valid_number, '新潟県新発田市古楯');
ok($zip->set_number('9592411')->is_valid_number, '新潟県新発田市横岡');
ok($zip->set_number('9592412')->is_valid_number, '新潟県新発田市平山');
ok($zip->set_number('9592413')->is_valid_number, '新潟県新発田市箱岩');
ok($zip->set_number('9592414')->is_valid_number, '新潟県新発田市下山田');
ok($zip->set_number('9592415')->is_valid_number, '新潟県新発田市住田');
ok($zip->set_number('9592416')->is_valid_number, '新潟県新発田市西浦');
ok($zip->set_number('9592417')->is_valid_number, '新潟県新発田市下西山');
ok($zip->set_number('9592421')->is_valid_number, '新潟県新発田市上今泉');
ok($zip->set_number('9592422')->is_valid_number, '新潟県新発田市関妻');
ok($zip->set_number('9592425')->is_valid_number, '新潟県新発田市高田');
ok($zip->set_number('9592426')->is_valid_number, '新潟県新発田市向中条');
ok($zip->set_number('9592431')->is_valid_number, '新潟県新発田市釜杭');
ok($zip->set_number('9592432')->is_valid_number, '新潟県新発田市二本木');
ok($zip->set_number('9592433')->is_valid_number, '新潟県新発田市古川');
ok($zip->set_number('9592434')->is_valid_number, '新潟県新発田市押廻');
ok($zip->set_number('9592435')->is_valid_number, '新潟県新発田市川尻');
ok($zip->set_number('9592436')->is_valid_number, '新潟県新発田市草荷');
ok($zip->set_number('9592437')->is_valid_number, '新潟県新発田市高山寺');
ok($zip->set_number('9592441')->is_valid_number, '新潟県新発田市金津');
ok($zip->set_number('9592442')->is_valid_number, '新潟県新発田市茗荷谷');
ok($zip->set_number('9592443')->is_valid_number, '新潟県新発田市新屋敷');
ok($zip->set_number('9592444')->is_valid_number, '新潟県新発田市新保小路');
ok($zip->set_number('9592445')->is_valid_number, '新潟県新発田市館野小路');
ok($zip->set_number('9592451')->is_valid_number, '新潟県新発田市下中');
ok($zip->set_number('9592452')->is_valid_number, '新潟県新発田市上館');
ok($zip->set_number('9592453')->is_valid_number, '新潟県新発田市三日市');
ok($zip->set_number('9592454')->is_valid_number, '新潟県新発田市早道場');
ok($zip->set_number('9592455')->is_valid_number, '新潟県新発田市上小松');
ok($zip->set_number('9592456')->is_valid_number, '新潟県新発田市下小松');
ok($zip->set_number('9592457')->is_valid_number, '新潟県新発田市下今泉');
ok($zip->set_number('9592461')->is_valid_number, '新潟県新発田市大野');
ok($zip->set_number('9592462')->is_valid_number, '新潟県新発田市戸野港');
ok($zip->set_number('9592463')->is_valid_number, '新潟県新発田市岡島');
ok($zip->set_number('9592464')->is_valid_number, '新潟県新発田市金塚');
ok($zip->set_number('9592465')->is_valid_number, '新潟県新発田市相馬');
ok($zip->set_number('9592468')->is_valid_number, '新潟県新発田市中俵');
ok($zip->set_number('9592471')->is_valid_number, '新潟県新発田市小国谷');
ok($zip->set_number('9592472')->is_valid_number, '新潟県新発田市貝屋');
ok($zip->set_number('9592473')->is_valid_number, '新潟県新発田市金山');
ok($zip->set_number('9592474')->is_valid_number, '新潟県新発田市境');
ok($zip->set_number('9592475')->is_valid_number, '新潟県新発田市寺尾');
ok($zip->set_number('9592476')->is_valid_number, '新潟県新発田市貝塚');
ok($zip->set_number('9592477')->is_valid_number, '新潟県新発田市下小中山');
ok($zip->set_number('9592478')->is_valid_number, '新潟県新発田市下坂町');
ok($zip->set_number('9592479')->is_valid_number, '新潟県新発田市金沢');
ok($zip->set_number('9592501')->is_valid_number, '新潟県新発田市上荒沢');
ok($zip->set_number('9592502')->is_valid_number, '新潟県新発田市熊出');
ok($zip->set_number('9592503')->is_valid_number, '新潟県新発田市下中山');
ok($zip->set_number('9592504')->is_valid_number, '新潟県新発田市上寺内');
ok($zip->set_number('9592505')->is_valid_number, '新潟県新発田市下寺内');
ok($zip->set_number('9592506')->is_valid_number, '新潟県新発田市横山');
ok($zip->set_number('9592507')->is_valid_number, '新潟県新発田市溝足');
ok($zip->set_number('9592511')->is_valid_number, '新潟県新発田市菅谷');
ok($zip->set_number('9592512')->is_valid_number, '新潟県新発田市小出');
ok($zip->set_number('9592513')->is_valid_number, '新潟県新発田市繁山');
ok($zip->set_number('9592514')->is_valid_number, '新潟県新発田市上石川');
ok($zip->set_number('9592515')->is_valid_number, '新潟県新発田市中川');
ok($zip->set_number('9592516')->is_valid_number, '新潟県新発田市下石川');
ok($zip->set_number('9592517')->is_valid_number, '新潟県新発田市麓');
ok($zip->set_number('9592518')->is_valid_number, '新潟県新発田市滝');
ok($zip->set_number('9592521')->is_valid_number, '新潟県新発田市蔵光');
ok($zip->set_number('9592522')->is_valid_number, '新潟県新発田市北中江');
ok($zip->set_number('9592523')->is_valid_number, '新潟県新発田市上中江');
ok($zip->set_number('9592524')->is_valid_number, '新潟県新発田市下中江');
ok($zip->set_number('9592525')->is_valid_number, '新潟県新発田市中倉');
ok($zip->set_number('9592526')->is_valid_number, '新潟県新発田市中妻');
ok($zip->set_number('9592527')->is_valid_number, '新潟県新発田市黒岩');
ok($zip->set_number('9592528')->is_valid_number, '新潟県新発田市東宮内');
ok($zip->set_number('9592600')->is_valid_number, '新潟県胎内市以下に掲載がない場合');
ok($zip->set_number('9592601')->is_valid_number, '新潟県胎内市桃崎浜');
ok($zip->set_number('9592602')->is_valid_number, '新潟県胎内市乙');
ok($zip->set_number('9592603')->is_valid_number, '新潟県胎内市菅田');
ok($zip->set_number('9592604')->is_valid_number, '新潟県胎内市大出');
ok($zip->set_number('9592605')->is_valid_number, '新潟県胎内市江尻');
ok($zip->set_number('9592606')->is_valid_number, '新潟県胎内市八幡');
ok($zip->set_number('9592607')->is_valid_number, '新潟県胎内市地本');
ok($zip->set_number('9592608')->is_valid_number, '新潟県胎内市富岡');
ok($zip->set_number('9592609')->is_valid_number, '新潟県胎内市荒井浜');
ok($zip->set_number('9592611')->is_valid_number, '新潟県胎内市山屋');
ok($zip->set_number('9592612')->is_valid_number, '新潟県胎内市小地谷');
ok($zip->set_number('9592613')->is_valid_number, '新潟県胎内市平木田駅前');
ok($zip->set_number('9592614')->is_valid_number, '新潟県胎内市平木田');
ok($zip->set_number('9592615')->is_valid_number, '新潟県胎内市横道');
ok($zip->set_number('9592616')->is_valid_number, '新潟県胎内市土作');
ok($zip->set_number('9592617')->is_valid_number, '新潟県胎内市高野村新田');
ok($zip->set_number('9592618')->is_valid_number, '新潟県胎内市高野');
ok($zip->set_number('9592619')->is_valid_number, '新潟県胎内市十二天');
ok($zip->set_number('9592621')->is_valid_number, '新潟県胎内市並槻');
ok($zip->set_number('9592622')->is_valid_number, '新潟県胎内市追分');
ok($zip->set_number('9592623')->is_valid_number, '新潟県胎内市仁谷野');
ok($zip->set_number('9592624')->is_valid_number, '新潟県胎内市羽黒');
ok($zip->set_number('9592625')->is_valid_number, '新潟県胎内市半山');
ok($zip->set_number('9592626')->is_valid_number, '新潟県胎内市飯角');
ok($zip->set_number('9592627')->is_valid_number, '新潟県胎内市野中');
ok($zip->set_number('9592628')->is_valid_number, '新潟県胎内市二葉町');
ok($zip->set_number('9592629')->is_valid_number, '新潟県胎内市中条');
ok($zip->set_number('9592631')->is_valid_number, '新潟県胎内市表町');
ok($zip->set_number('9592632')->is_valid_number, '新潟県胎内市新栄町');
ok($zip->set_number('9592633')->is_valid_number, '新潟県胎内市関沢');
ok($zip->set_number('9592634')->is_valid_number, '新潟県胎内市小牧台');
ok($zip->set_number('9592635')->is_valid_number, '新潟県胎内市つつじが丘');
ok($zip->set_number('9592636')->is_valid_number, '新潟県胎内市星の宮町');
ok($zip->set_number('9592637')->is_valid_number, '新潟県胎内市長橋');
ok($zip->set_number('9592638')->is_valid_number, '新潟県胎内市水沢町');
ok($zip->set_number('9592641')->is_valid_number, '新潟県胎内市若松町');
ok($zip->set_number('9592642')->is_valid_number, '新潟県胎内市新和町');
ok($zip->set_number('9592643')->is_valid_number, '新潟県胎内市東本町');
ok($zip->set_number('9592644')->is_valid_number, '新潟県胎内市大川町');
ok($zip->set_number('9592645')->is_valid_number, '新潟県胎内市本町');
ok($zip->set_number('9592646')->is_valid_number, '新潟県胎内市西栄町');
ok($zip->set_number('9592647')->is_valid_number, '新潟県胎内市北本町');
ok($zip->set_number('9592648')->is_valid_number, '新潟県胎内市住吉町');
ok($zip->set_number('9592651')->is_valid_number, '新潟県胎内市西条町');
ok($zip->set_number('9592652')->is_valid_number, '新潟県胎内市協和町');
ok($zip->set_number('9592653')->is_valid_number, '新潟県胎内市倉敷町');
ok($zip->set_number('9592654')->is_valid_number, '新潟県胎内市本郷町');
ok($zip->set_number('9592655')->is_valid_number, '新潟県胎内市本郷');
ok($zip->set_number('9592656')->is_valid_number, '新潟県胎内市西本町');
ok($zip->set_number('9592657')->is_valid_number, '新潟県胎内市江上');
ok($zip->set_number('9592658')->is_valid_number, '新潟県胎内市西条');
ok($zip->set_number('9592659')->is_valid_number, '新潟県胎内市あかね町');
ok($zip->set_number('9592661')->is_valid_number, '新潟県胎内市赤川');
ok($zip->set_number('9592662')->is_valid_number, '新潟県胎内市鷹ノ巣');
ok($zip->set_number('9592663')->is_valid_number, '新潟県胎内市草野');
ok($zip->set_number('9592664')->is_valid_number, '新潟県胎内市柴橋');
ok($zip->set_number('9592665')->is_valid_number, '新潟県胎内市大塚');
ok($zip->set_number('9592666')->is_valid_number, '新潟県胎内市新舘');
ok($zip->set_number('9592667')->is_valid_number, '新潟県胎内市西川内');
ok($zip->set_number('9592668')->is_valid_number, '新潟県胎内市弥彦岡');
ok($zip->set_number('9592669')->is_valid_number, '新潟県胎内市塩津');
ok($zip->set_number('9592671')->is_valid_number, '新潟県胎内市東川内');
ok($zip->set_number('9592672')->is_valid_number, '新潟県胎内市八田');
ok($zip->set_number('9592673')->is_valid_number, '新潟県胎内市寅田');
ok($zip->set_number('9592674')->is_valid_number, '新潟県胎内市小舟戸');
ok($zip->set_number('9592675')->is_valid_number, '新潟県胎内市船戸');
ok($zip->set_number('9592676')->is_valid_number, '新潟県胎内市上城塚');
ok($zip->set_number('9592677')->is_valid_number, '新潟県胎内市下城塚');
ok($zip->set_number('9592701')->is_valid_number, '新潟県胎内市笹口浜');
ok($zip->set_number('9592702')->is_valid_number, '新潟県胎内市平根台');
ok($zip->set_number('9592703')->is_valid_number, '新潟県胎内市高畑');
ok($zip->set_number('9592704')->is_valid_number, '新潟県胎内市宮瀬');
ok($zip->set_number('9592705')->is_valid_number, '新潟県胎内市鴻ノ巣');
ok($zip->set_number('9592706')->is_valid_number, '新潟県胎内市山王');
ok($zip->set_number('9592707')->is_valid_number, '新潟県胎内市下高田');
ok($zip->set_number('9592708')->is_valid_number, '新潟県胎内市中村浜');
ok($zip->set_number('9592709')->is_valid_number, '新潟県胎内市村松浜');
ok($zip->set_number('9592712')->is_valid_number, '新潟県胎内市築地');
ok($zip->set_number('9592713')->is_valid_number, '新潟県胎内市築地新');
ok($zip->set_number('9592714')->is_valid_number, '新潟県胎内市堀口');
ok($zip->set_number('9592715')->is_valid_number, '新潟県胎内市高橋');
ok($zip->set_number('9592716')->is_valid_number, '新潟県胎内市中倉');
ok($zip->set_number('9592721')->is_valid_number, '新潟県胎内市苔実');
ok($zip->set_number('9592722')->is_valid_number, '新潟県胎内市竹島');
ok($zip->set_number('9592723')->is_valid_number, '新潟県胎内市宮川');
ok($zip->set_number('9592724')->is_valid_number, '新潟県胎内市北成田');
ok($zip->set_number('9592801')->is_valid_number, '新潟県胎内市近江新');
ok($zip->set_number('9592802')->is_valid_number, '新潟県胎内市切田');
ok($zip->set_number('9592803')->is_valid_number, '新潟県胎内市蔵王');
ok($zip->set_number('9592804')->is_valid_number, '新潟県胎内市塩沢');
ok($zip->set_number('9592805')->is_valid_number, '新潟県胎内市下館');
ok($zip->set_number('9592806')->is_valid_number, '新潟県胎内市下赤谷');
ok($zip->set_number('9592807')->is_valid_number, '新潟県胎内市黒川');
ok($zip->set_number('9592808')->is_valid_number, '新潟県胎内市東牧');
ok($zip->set_number('9592809')->is_valid_number, '新潟県胎内市下江端');
ok($zip->set_number('9592811')->is_valid_number, '新潟県胎内市鍬江');
ok($zip->set_number('9592812')->is_valid_number, '新潟県胎内市小長谷');
ok($zip->set_number('9592813')->is_valid_number, '新潟県胎内市大長谷');
ok($zip->set_number('9592814')->is_valid_number, '新潟県胎内市黒俣');
ok($zip->set_number('9592815')->is_valid_number, '新潟県胎内市持倉');
ok($zip->set_number('9592816')->is_valid_number, '新潟県胎内市下荒沢');
ok($zip->set_number('9592817')->is_valid_number, '新潟県胎内市須巻');
ok($zip->set_number('9592821')->is_valid_number, '新潟県胎内市坪穴');
ok($zip->set_number('9592822')->is_valid_number, '新潟県胎内市夏井');
ok($zip->set_number('9592823')->is_valid_number, '新潟県胎内市熱田坂');
ok($zip->set_number('9592824')->is_valid_number, '新潟県胎内市宮久');
ok($zip->set_number('9592825')->is_valid_number, '新潟県胎内市坂井');
ok($zip->set_number('9592826')->is_valid_number, '新潟県胎内市鼓岡');
ok($zip->set_number('9592827')->is_valid_number, '新潟県胎内市栗木野新田');
ok($zip->set_number('9593101')->is_valid_number, '新潟県村上市花立');
ok($zip->set_number('9593102')->is_valid_number, '新潟県村上市貝附');
ok($zip->set_number('9593103')->is_valid_number, '新潟県村上市荒島');
ok($zip->set_number('9593104')->is_valid_number, '新潟県村上市春木山');
ok($zip->set_number('9593105')->is_valid_number, '新潟県村上市梨木');
ok($zip->set_number('9593106')->is_valid_number, '新潟県村上市切田');
ok($zip->set_number('9593107')->is_valid_number, '新潟県村上市下鍜冶屋');
ok($zip->set_number('9593108')->is_valid_number, '新潟県村上市上鍜冶屋');
ok($zip->set_number('9593111')->is_valid_number, '新潟県村上市長政');
ok($zip->set_number('9593112')->is_valid_number, '新潟県村上市中野');
ok($zip->set_number('9593113')->is_valid_number, '新潟県村上市名割');
ok($zip->set_number('9593114')->is_valid_number, '新潟県村上市南新保');
ok($zip->set_number('9593115')->is_valid_number, '新潟県村上市新光寺');
ok($zip->set_number('9593116')->is_valid_number, '新潟県村上市荒屋');
ok($zip->set_number('9593117')->is_valid_number, '新潟県村上市海老江');
ok($zip->set_number('9593121')->is_valid_number, '新潟県村上市佐々木');
ok($zip->set_number('9593122')->is_valid_number, '新潟県村上市大津');
ok($zip->set_number('9593123')->is_valid_number, '新潟県村上市中倉');
ok($zip->set_number('9593124')->is_valid_number, '新潟県村上市金屋');
ok($zip->set_number('9593125')->is_valid_number, '新潟県村上市荒川縁新田');
ok($zip->set_number('9593126')->is_valid_number, '新潟県村上市鳥屋');
ok($zip->set_number('9593131')->is_valid_number, '新潟県村上市藤沢');
ok($zip->set_number('9593132')->is_valid_number, '新潟県村上市坂町');
ok($zip->set_number('9593133')->is_valid_number, '新潟県村上市山口');
ok($zip->set_number('9593134')->is_valid_number, '新潟県村上市羽ヶ榎');
ok($zip->set_number('9593200')->is_valid_number, '新潟県岩船郡関川村以下に掲載がない場合');
ok($zip->set_number('9593201')->is_valid_number, '新潟県岩船郡関川村朴坂');
ok($zip->set_number('9593202')->is_valid_number, '新潟県岩船郡関川村宮前');
ok($zip->set_number('9593203')->is_valid_number, '新潟県岩船郡関川村南中');
ok($zip->set_number('9593204')->is_valid_number, '新潟県岩船郡関川村蛇喰');
ok($zip->set_number('9593205')->is_valid_number, '新潟県岩船郡関川村上新保');
ok($zip->set_number('9593206')->is_valid_number, '新潟県岩船郡関川村中束');
ok($zip->set_number('9593207')->is_valid_number, '新潟県岩船郡関川村蕨野');
ok($zip->set_number('9593208')->is_valid_number, '新潟県岩船郡関川村田麦千刈');
ok($zip->set_number('9593211')->is_valid_number, '新潟県岩船郡関川村小和田');
ok($zip->set_number('9593212')->is_valid_number, '新潟県岩船郡関川村若山');
ok($zip->set_number('9593213')->is_valid_number, '新潟県岩船郡関川村上野');
ok($zip->set_number('9593214')->is_valid_number, '新潟県岩船郡関川村上野新');
ok($zip->set_number('9593215')->is_valid_number, '新潟県岩船郡関川村深沢');
ok($zip->set_number('9593216')->is_valid_number, '新潟県岩船郡関川村上野原');
ok($zip->set_number('9593221')->is_valid_number, '新潟県岩船郡関川村下川口');
ok($zip->set_number('9593222')->is_valid_number, '新潟県岩船郡関川村荒川台');
ok($zip->set_number('9593223')->is_valid_number, '新潟県岩船郡関川村大内淵');
ok($zip->set_number('9593224')->is_valid_number, '新潟県岩船郡関川村聞出');
ok($zip->set_number('9593225')->is_valid_number, '新潟県岩船郡関川村沼');
ok($zip->set_number('9593226')->is_valid_number, '新潟県岩船郡関川村片貝');
ok($zip->set_number('9593227')->is_valid_number, '新潟県岩船郡関川村八ツ口');
ok($zip->set_number('9593228')->is_valid_number, '新潟県岩船郡関川村金丸');
ok($zip->set_number('9593231')->is_valid_number, '新潟県岩船郡関川村上川口');
ok($zip->set_number('9593232')->is_valid_number, '新潟県岩船郡関川村蔵田島');
ok($zip->set_number('9593233')->is_valid_number, '新潟県岩船郡関川村久保');
ok($zip->set_number('9593234')->is_valid_number, '新潟県岩船郡関川村鮖谷');
ok($zip->set_number('9593235')->is_valid_number, '新潟県岩船郡関川村安角');
ok($zip->set_number('9593236')->is_valid_number, '新潟県岩船郡関川村大石');
ok($zip->set_number('9593237')->is_valid_number, '新潟県岩船郡関川村金俣');
ok($zip->set_number('9593241')->is_valid_number, '新潟県岩船郡関川村大島');
ok($zip->set_number('9593242')->is_valid_number, '新潟県岩船郡関川村下土沢');
ok($zip->set_number('9593243')->is_valid_number, '新潟県岩船郡関川村鍬江沢');
ok($zip->set_number('9593244')->is_valid_number, '新潟県岩船郡関川村山本');
ok($zip->set_number('9593245')->is_valid_number, '新潟県岩船郡関川村幾地');
ok($zip->set_number('9593246')->is_valid_number, '新潟県岩船郡関川村上土沢');
ok($zip->set_number('9593251')->is_valid_number, '新潟県岩船郡関川村桂');
ok($zip->set_number('9593252')->is_valid_number, '新潟県岩船郡関川村高田');
ok($zip->set_number('9593253')->is_valid_number, '新潟県岩船郡関川村平内新');
ok($zip->set_number('9593254')->is_valid_number, '新潟県岩船郡関川村小見前新田');
ok($zip->set_number('9593255')->is_valid_number, '新潟県岩船郡関川村松ケ丘');
ok($zip->set_number('9593256')->is_valid_number, '新潟県岩船郡関川村小見');
ok($zip->set_number('9593257')->is_valid_number, '新潟県岩船郡関川村上野山');
ok($zip->set_number('9593258')->is_valid_number, '新潟県岩船郡関川村滝原');
ok($zip->set_number('9593259')->is_valid_number, '新潟県岩船郡関川村松平');
ok($zip->set_number('9593261')->is_valid_number, '新潟県岩船郡関川村湯沢');
ok($zip->set_number('9593262')->is_valid_number, '新潟県岩船郡関川村沢');
ok($zip->set_number('9593263')->is_valid_number, '新潟県岩船郡関川村高瀬');
ok($zip->set_number('9593264')->is_valid_number, '新潟県岩船郡関川村上関');
ok($zip->set_number('9593265')->is_valid_number, '新潟県岩船郡関川村下関');
ok($zip->set_number('9593271')->is_valid_number, '新潟県岩船郡関川村辰田新');
ok($zip->set_number('9593272')->is_valid_number, '新潟県岩船郡関川村打上');
ok($zip->set_number('9593273')->is_valid_number, '新潟県岩船郡関川村勝蔵');
ok($zip->set_number('9593274')->is_valid_number, '新潟県岩船郡関川村南赤谷');
ok($zip->set_number('9593275')->is_valid_number, '新潟県岩船郡関川村内須川');
ok($zip->set_number('9593401')->is_valid_number, '新潟県村上市七湊');
ok($zip->set_number('9593402')->is_valid_number, '新潟県村上市志田平');
ok($zip->set_number('9593403')->is_valid_number, '新潟県村上市上助渕');
ok($zip->set_number('9593404')->is_valid_number, '新潟県村上市山屋');
ok($zip->set_number('9593405')->is_valid_number, '新潟県村上市里本庄');
ok($zip->set_number('9593406')->is_valid_number, '新潟県村上市下助渕');
ok($zip->set_number('9593407')->is_valid_number, '新潟県村上市殿岡');
ok($zip->set_number('9593411')->is_valid_number, '新潟県村上市南大平');
ok($zip->set_number('9593412')->is_valid_number, '新潟県村上市指合');
ok($zip->set_number('9593413')->is_valid_number, '新潟県村上市小出');
ok($zip->set_number('9593414')->is_valid_number, '新潟県村上市有明');
ok($zip->set_number('9593415')->is_valid_number, '新潟県村上市大塚');
ok($zip->set_number('9593416')->is_valid_number, '新潟県村上市今宿');
ok($zip->set_number('9593417')->is_valid_number, '新潟県村上市河内');
ok($zip->set_number('9593421')->is_valid_number, '新潟県村上市桃川');
ok($zip->set_number('9593422')->is_valid_number, '新潟県村上市飯岡');
ok($zip->set_number('9593423')->is_valid_number, '新潟県村上市九日市');
ok($zip->set_number('9593424')->is_valid_number, '新潟県村上市牧目');
ok($zip->set_number('9593425')->is_valid_number, '新潟県村上市山田');
ok($zip->set_number('9593426')->is_valid_number, '新潟県村上市岩野沢');
ok($zip->set_number('9593427')->is_valid_number, '新潟県村上市松沢');
ok($zip->set_number('9593428')->is_valid_number, '新潟県村上市松喜和');
ok($zip->set_number('9593431')->is_valid_number, '新潟県村上市平林');
ok($zip->set_number('9593432')->is_valid_number, '新潟県村上市葛籠山');
ok($zip->set_number('9593433')->is_valid_number, '新潟県村上市川部');
ok($zip->set_number('9593434')->is_valid_number, '新潟県村上市小岩内');
ok($zip->set_number('9593435')->is_valid_number, '新潟県村上市宿田');
ok($zip->set_number('9593436')->is_valid_number, '新潟県村上市牛屋');
ok($zip->set_number('9593437')->is_valid_number, '新潟県村上市福田');
ok($zip->set_number('9593441')->is_valid_number, '新潟県村上市塩谷');
ok($zip->set_number('9593442')->is_valid_number, '新潟県村上市長松');
ok($zip->set_number('9593443')->is_valid_number, '新潟県村上市北新保');
ok($zip->set_number('9593444')->is_valid_number, '新潟県村上市南田中');
ok($zip->set_number('9593445')->is_valid_number, '新潟県村上市新飯田');
ok($zip->set_number('9593446')->is_valid_number, '新潟県村上市小口川');
ok($zip->set_number('9593447')->is_valid_number, '新潟県村上市高御堂');
ok($zip->set_number('9593448')->is_valid_number, '新潟県村上市潟端');
ok($zip->set_number('9593449')->is_valid_number, '新潟県村上市岩船駅前');
ok($zip->set_number('9593651')->is_valid_number, '新潟県村上市芦谷');
ok($zip->set_number('9593652')->is_valid_number, '新潟県村上市越沢');
ok($zip->set_number('9593653')->is_valid_number, '新潟県村上市寒川');
ok($zip->set_number('9593661')->is_valid_number, '新潟県村上市脇川');
ok($zip->set_number('9593662')->is_valid_number, '新潟県村上市今川');
ok($zip->set_number('9593663')->is_valid_number, '新潟県村上市板貝');
ok($zip->set_number('9593664')->is_valid_number, '新潟県村上市笹川');
ok($zip->set_number('9593665')->is_valid_number, '新潟県村上市桑川');
ok($zip->set_number('9593666')->is_valid_number, '新潟県村上市浜新保');
ok($zip->set_number('9593901')->is_valid_number, '新潟県村上市伊呉野');
ok($zip->set_number('9593902')->is_valid_number, '新潟県村上市中浜');
ok($zip->set_number('9593903')->is_valid_number, '新潟県村上市岩崎');
ok($zip->set_number('9593904')->is_valid_number, '新潟県村上市温出');
ok($zip->set_number('9593905')->is_valid_number, '新潟県村上市堀ノ内');
ok($zip->set_number('9593906')->is_valid_number, '新潟県村上市大谷沢');
ok($zip->set_number('9593907')->is_valid_number, '新潟県村上市府屋');
ok($zip->set_number('9593911')->is_valid_number, '新潟県村上市杉平');
ok($zip->set_number('9593912')->is_valid_number, '新潟県村上市遅郷');
ok($zip->set_number('9593913')->is_valid_number, '新潟県村上市岩石');
ok($zip->set_number('9593914')->is_valid_number, '新潟県村上市小俣');
ok($zip->set_number('9593915')->is_valid_number, '新潟県村上市大代');
ok($zip->set_number('9593916')->is_valid_number, '新潟県村上市雷');
ok($zip->set_number('9593917')->is_valid_number, '新潟県村上市山熊田');
ok($zip->set_number('9593918')->is_valid_number, '新潟県村上市中継');
ok($zip->set_number('9593919')->is_valid_number, '新潟県村上市塔下');
ok($zip->set_number('9593921')->is_valid_number, '新潟県村上市荒川口');
ok($zip->set_number('9593922')->is_valid_number, '新潟県村上市朴平');
ok($zip->set_number('9593923')->is_valid_number, '新潟県村上市荒川');
ok($zip->set_number('9593924')->is_valid_number, '新潟県村上市北黒川');
ok($zip->set_number('9593925')->is_valid_number, '新潟県村上市大沢');
ok($zip->set_number('9593926')->is_valid_number, '新潟県村上市大毎');
ok($zip->set_number('9593927')->is_valid_number, '新潟県村上市北中');
ok($zip->set_number('9593928')->is_valid_number, '新潟県村上市中津原');
ok($zip->set_number('9593931')->is_valid_number, '新潟県村上市長坂');
ok($zip->set_number('9593932')->is_valid_number, '新潟県村上市垣之内');
ok($zip->set_number('9593933')->is_valid_number, '新潟県村上市下大鳥');
ok($zip->set_number('9593934')->is_valid_number, '新潟県村上市上大鳥');
ok($zip->set_number('9593935')->is_valid_number, '新潟県村上市北田中');
ok($zip->set_number('9593936')->is_valid_number, '新潟県村上市北赤谷');
ok($zip->set_number('9593937')->is_valid_number, '新潟県村上市板屋沢');
ok($zip->set_number('9593938')->is_valid_number, '新潟県村上市遠矢崎');
ok($zip->set_number('9593941')->is_valid_number, '新潟県村上市碁石');
ok($zip->set_number('9593942')->is_valid_number, '新潟県村上市勝木');
ok($zip->set_number('9593943')->is_valid_number, '新潟県村上市下大蔵');
ok($zip->set_number('9593944')->is_valid_number, '新潟県村上市立島');
ok($zip->set_number('9593945')->is_valid_number, '新潟県村上市間瀬');
ok($zip->set_number('9593946')->is_valid_number, '新潟県村上市寝屋');
ok($zip->set_number('9593947')->is_valid_number, '新潟県村上市鵜泊');
ok($zip->set_number('9593948')->is_valid_number, '新潟県村上市上大蔵');
ok($zip->set_number('9594301')->is_valid_number, '新潟県東蒲原郡阿賀町向鹿瀬');
ok($zip->set_number('9594302')->is_valid_number, '新潟県東蒲原郡阿賀町鹿瀬');
ok($zip->set_number('9594303')->is_valid_number, '新潟県東蒲原郡阿賀町日出谷');
ok($zip->set_number('9594304')->is_valid_number, '新潟県東蒲原郡阿賀町豊実');
ok($zip->set_number('9594400')->is_valid_number, '新潟県東蒲原郡阿賀町以下に掲載がない場合');
ok($zip->set_number('9594401')->is_valid_number, '新潟県東蒲原郡阿賀町角島');
ok($zip->set_number('9594402')->is_valid_number, '新潟県東蒲原郡阿賀町津川');
ok($zip->set_number('9594403')->is_valid_number, '新潟県東蒲原郡阿賀町平堀');
ok($zip->set_number('9594404')->is_valid_number, '新潟県東蒲原郡阿賀町広沢');
ok($zip->set_number('9594405')->is_valid_number, '新潟県東蒲原郡阿賀町上ノ山');
ok($zip->set_number('9594406')->is_valid_number, '新潟県東蒲原郡阿賀町雲和田');
ok($zip->set_number('9594407')->is_valid_number, '新潟県東蒲原郡阿賀町西');
ok($zip->set_number('9594408')->is_valid_number, '新潟県東蒲原郡阿賀町赤岩');
ok($zip->set_number('9594409')->is_valid_number, '新潟県東蒲原郡阿賀町京ノ瀬');
ok($zip->set_number('9594410')->is_valid_number, '新潟県東蒲原郡阿賀町大牧');
ok($zip->set_number('9594411')->is_valid_number, '新潟県東蒲原郡阿賀町天満');
ok($zip->set_number('9594412')->is_valid_number, '新潟県東蒲原郡阿賀町花立');
ok($zip->set_number('9594413')->is_valid_number, '新潟県東蒲原郡阿賀町倉ノ平');
ok($zip->set_number('9594414')->is_valid_number, '新潟県東蒲原郡阿賀町福取');
ok($zip->set_number('9594415')->is_valid_number, '新潟県東蒲原郡阿賀町八ツ田');
ok($zip->set_number('9594416')->is_valid_number, '新潟県東蒲原郡阿賀町田沢');
ok($zip->set_number('9594417')->is_valid_number, '新潟県東蒲原郡阿賀町八木山');
ok($zip->set_number('9594418')->is_valid_number, '新潟県東蒲原郡阿賀町野村');
ok($zip->set_number('9594441')->is_valid_number, '新潟県東蒲原郡阿賀町払川');
ok($zip->set_number('9594501')->is_valid_number, '新潟県東蒲原郡阿賀町九島');
ok($zip->set_number('9594502')->is_valid_number, '新潟県東蒲原郡阿賀町小出');
ok($zip->set_number('9594503')->is_valid_number, '新潟県東蒲原郡阿賀町豊川乙');
ok($zip->set_number('9594504')->is_valid_number, '新潟県東蒲原郡阿賀町豊川丙');
ok($zip->set_number('9594505')->is_valid_number, '新潟県東蒲原郡阿賀町豊川甲');
ok($zip->set_number('9594506')->is_valid_number, '新潟県東蒲原郡阿賀町両郷乙');
ok($zip->set_number('9594507')->is_valid_number, '新潟県東蒲原郡阿賀町両郷甲');
ok($zip->set_number('9594511')->is_valid_number, '新潟県東蒲原郡阿賀町東山');
ok($zip->set_number('9594512')->is_valid_number, '新潟県東蒲原郡阿賀町大倉乙');
ok($zip->set_number('9594513')->is_valid_number, '新潟県東蒲原郡阿賀町大倉甲');
ok($zip->set_number('9594514')->is_valid_number, '新潟県東蒲原郡阿賀町七名乙');
ok($zip->set_number('9594515')->is_valid_number, '新潟県東蒲原郡阿賀町七名甲');
ok($zip->set_number('9594521')->is_valid_number, '新潟県東蒲原郡阿賀町三宝分甲');
ok($zip->set_number('9594522')->is_valid_number, '新潟県東蒲原郡阿賀町三宝分乙');
ok($zip->set_number('9594523')->is_valid_number, '新潟県東蒲原郡阿賀町三宝分丙');
ok($zip->set_number('9594524')->is_valid_number, '新潟県東蒲原郡阿賀町三方乙');
ok($zip->set_number('9594525')->is_valid_number, '新潟県東蒲原郡阿賀町小手茂');
ok($zip->set_number('9594526')->is_valid_number, '新潟県東蒲原郡阿賀町三方甲');
ok($zip->set_number('9594531')->is_valid_number, '新潟県東蒲原郡阿賀町日野川甲');
ok($zip->set_number('9594532')->is_valid_number, '新潟県東蒲原郡阿賀町広谷丙');
ok($zip->set_number('9594533')->is_valid_number, '新潟県東蒲原郡阿賀町神谷丙');
ok($zip->set_number('9594534')->is_valid_number, '新潟県東蒲原郡阿賀町神谷乙');
ok($zip->set_number('9594535')->is_valid_number, '新潟県東蒲原郡阿賀町神谷甲');
ok($zip->set_number('9594536')->is_valid_number, '新潟県東蒲原郡阿賀町広谷甲');
ok($zip->set_number('9594537')->is_valid_number, '新潟県東蒲原郡阿賀町広谷乙');
ok($zip->set_number('9594538')->is_valid_number, '新潟県東蒲原郡阿賀町日野川丙');
ok($zip->set_number('9594539')->is_valid_number, '新潟県東蒲原郡阿賀町日野川乙');
ok($zip->set_number('9594601')->is_valid_number, '新潟県東蒲原郡阿賀町綱木');
ok($zip->set_number('9594602')->is_valid_number, '新潟県東蒲原郡阿賀町古岐');
ok($zip->set_number('9594603')->is_valid_number, '新潟県東蒲原郡阿賀町新谷');
ok($zip->set_number('9594604')->is_valid_number, '新潟県東蒲原郡阿賀町行地');
ok($zip->set_number('9594605')->is_valid_number, '新潟県東蒲原郡阿賀町細越');
ok($zip->set_number('9594606')->is_valid_number, '新潟県東蒲原郡阿賀町五十沢');
ok($zip->set_number('9594608')->is_valid_number, '新潟県東蒲原郡阿賀町小花地');
ok($zip->set_number('9594611')->is_valid_number, '新潟県東蒲原郡阿賀町中ノ沢');
ok($zip->set_number('9594612')->is_valid_number, '新潟県東蒲原郡阿賀町岡沢');
ok($zip->set_number('9594614')->is_valid_number, '新潟県東蒲原郡阿賀町五十島');
ok($zip->set_number('9594617')->is_valid_number, '新潟県東蒲原郡阿賀町上島');
ok($zip->set_number('9594618')->is_valid_number, '新潟県東蒲原郡阿賀町川口');
ok($zip->set_number('9594621')->is_valid_number, '新潟県東蒲原郡阿賀町あが野北');
ok($zip->set_number('9594622')->is_valid_number, '新潟県東蒲原郡阿賀町白崎');
ok($zip->set_number('9594623')->is_valid_number, '新潟県東蒲原郡阿賀町黒岩');
ok($zip->set_number('9594624')->is_valid_number, '新潟県東蒲原郡阿賀町谷沢');
ok($zip->set_number('9594625')->is_valid_number, '新潟県東蒲原郡阿賀町吉津');
ok($zip->set_number('9594626')->is_valid_number, '新潟県東蒲原郡阿賀町あが野南');
ok($zip->set_number('9594627')->is_valid_number, '新潟県東蒲原郡阿賀町岩谷');
ok($zip->set_number('9594631')->is_valid_number, '新潟県東蒲原郡阿賀町取上');
ok($zip->set_number('9594632')->is_valid_number, '新潟県東蒲原郡阿賀町石戸');
ok($zip->set_number('9594633')->is_valid_number, '新潟県東蒲原郡阿賀町長谷');
ok($zip->set_number('9594634')->is_valid_number, '新潟県東蒲原郡阿賀町熊渡');
ok($zip->set_number('9594635')->is_valid_number, '新潟県東蒲原郡阿賀町釣浜');
ok($zip->set_number('9594636')->is_valid_number, '新潟県東蒲原郡阿賀町石間');
ok($zip->set_number('9600000')->is_valid_number, '福島県福島市以下に掲載がない場合');
ok($zip->set_number('9600101')->is_valid_number, '福島県福島市瀬上町');
ok($zip->set_number('9600102')->is_valid_number, '福島県福島市鎌田');
ok($zip->set_number('9600103')->is_valid_number, '福島県福島市本内(その他)');
ok($zip->set_number('9600111')->is_valid_number, '福島県福島市丸子');
ok($zip->set_number('9600112')->is_valid_number, '福島県福島市南矢野目');
ok($zip->set_number('9600113')->is_valid_number, '福島県福島市北矢野目');
ok($zip->set_number('9600114')->is_valid_number, '福島県福島市沖高');
ok($zip->set_number('9600115')->is_valid_number, '福島県福島市下飯坂');
ok($zip->set_number('9600116')->is_valid_number, '福島県福島市宮代');
ok($zip->set_number('9600201')->is_valid_number, '福島県福島市飯坂町');
ok($zip->set_number('9600211')->is_valid_number, '福島県福島市飯坂町湯野');
ok($zip->set_number('9600221')->is_valid_number, '福島県福島市飯坂町東湯野');
ok($zip->set_number('9600231')->is_valid_number, '福島県福島市飯坂町平野');
ok($zip->set_number('9600241')->is_valid_number, '福島県福島市笹谷');
ok($zip->set_number('9600251')->is_valid_number, '福島県福島市大笹生');
ok($zip->set_number('9600252')->is_valid_number, '福島県福島市李平');
ok($zip->set_number('9600261')->is_valid_number, '福島県福島市飯坂町中野');
ok($zip->set_number('9600271')->is_valid_number, '福島県福島市飯坂町茂庭');
ok($zip->set_number('9600401')->is_valid_number, '福島県伊達市下川原');
ok($zip->set_number('9600402')->is_valid_number, '福島県伊達市水抜');
ok($zip->set_number('9600403')->is_valid_number, '福島県伊達市前川原');
ok($zip->set_number('9600404')->is_valid_number, '福島県伊達市原島');
ok($zip->set_number('9600405')->is_valid_number, '福島県伊達市一本木');
ok($zip->set_number('9600406')->is_valid_number, '福島県伊達市堂ノ内');
ok($zip->set_number('9600407')->is_valid_number, '福島県伊達市日照');
ok($zip->set_number('9600408')->is_valid_number, '福島県伊達市岡沼');
ok($zip->set_number('9600411')->is_valid_number, '福島県伊達市梨子木町');
ok($zip->set_number('9600412')->is_valid_number, '福島県伊達市雪車町');
ok($zip->set_number('9600413')->is_valid_number, '福島県伊達市宮前');
ok($zip->set_number('9600414')->is_valid_number, '福島県伊達市長岡');
ok($zip->set_number('9600415')->is_valid_number, '福島県伊達市右城');
ok($zip->set_number('9600416')->is_valid_number, '福島県伊達市中畑');
ok($zip->set_number('9600417')->is_valid_number, '福島県伊達市北畑');
ok($zip->set_number('9600418')->is_valid_number, '福島県伊達市岡前');
ok($zip->set_number('9600419')->is_valid_number, '福島県伊達市広前');
ok($zip->set_number('9600421')->is_valid_number, '福島県伊達市一本杉');
ok($zip->set_number('9600422')->is_valid_number, '福島県伊達市川原田');
ok($zip->set_number('9600423')->is_valid_number, '福島県伊達市荒町');
ok($zip->set_number('9600424')->is_valid_number, '福島県伊達市姥ケ懐');
ok($zip->set_number('9600425')->is_valid_number, '福島県伊達市姥川');
ok($zip->set_number('9600426')->is_valid_number, '福島県伊達市坂ノ下');
ok($zip->set_number('9600427')->is_valid_number, '福島県伊達市鍛治屋川');
ok($zip->set_number('9600428')->is_valid_number, '福島県伊達市坂ノ上');
ok($zip->set_number('9600429')->is_valid_number, '福島県伊達市塚畑');
ok($zip->set_number('9600431')->is_valid_number, '福島県伊達市川原町');
ok($zip->set_number('9600432')->is_valid_number, '福島県伊達市長川原');
ok($zip->set_number('9600433')->is_valid_number, '福島県伊達市上川原');
ok($zip->set_number('9600434')->is_valid_number, '福島県伊達市堰下');
ok($zip->set_number('9600435')->is_valid_number, '福島県伊達市堰上');
ok($zip->set_number('9600436')->is_valid_number, '福島県伊達市前田');
ok($zip->set_number('9600437')->is_valid_number, '福島県伊達市一本松');
ok($zip->set_number('9600438')->is_valid_number, '福島県伊達市雷田');
ok($zip->set_number('9600441')->is_valid_number, '福島県伊達市新町');
ok($zip->set_number('9600442')->is_valid_number, '福島県伊達市菅田');
ok($zip->set_number('9600443')->is_valid_number, '福島県伊達市諏訪西');
ok($zip->set_number('9600444')->is_valid_number, '福島県伊達市諏訪前');
ok($zip->set_number('9600445')->is_valid_number, '福島県伊達市神明前');
ok($zip->set_number('9600446')->is_valid_number, '福島県伊達市諏訪野');
ok($zip->set_number('9600447')->is_valid_number, '福島県伊達市寺前');
ok($zip->set_number('9600448')->is_valid_number, '福島県伊達市屋敷間');
ok($zip->set_number('9600451')->is_valid_number, '福島県伊達市下志和田');
ok($zip->set_number('9600452')->is_valid_number, '福島県伊達市中志和田');
ok($zip->set_number('9600453')->is_valid_number, '福島県伊達市上志和田');
ok($zip->set_number('9600454')->is_valid_number, '福島県伊達市志和田前');
ok($zip->set_number('9600455')->is_valid_number, '福島県伊達市姥石');
ok($zip->set_number('9600456')->is_valid_number, '福島県伊達市中道');
ok($zip->set_number('9600457')->is_valid_number, '福島県伊達市江向');
ok($zip->set_number('9600458')->is_valid_number, '福島県伊達市扇田');
ok($zip->set_number('9600461')->is_valid_number, '福島県伊達市片町');
ok($zip->set_number('9600462')->is_valid_number, '福島県伊達市本町');
ok($zip->set_number('9600463')->is_valid_number, '福島県伊達市田町');
ok($zip->set_number('9600464')->is_valid_number, '福島県伊達市南堀');
ok($zip->set_number('9600465')->is_valid_number, '福島県伊達市久根妻');
ok($zip->set_number('9600466')->is_valid_number, '福島県伊達市根岸');
ok($zip->set_number('9600467')->is_valid_number, '福島県伊達市舘ノ内');
ok($zip->set_number('9600468')->is_valid_number, '福島県伊達市北後');
ok($zip->set_number('9600471')->is_valid_number, '福島県伊達市長町');
ok($zip->set_number('9600472')->is_valid_number, '福島県伊達市根田');
ok($zip->set_number('9600473')->is_valid_number, '福島県伊達市沢田');
ok($zip->set_number('9600474')->is_valid_number, '福島県伊達市沓形');
ok($zip->set_number('9600475')->is_valid_number, '福島県伊達市干供田');
ok($zip->set_number('9600476')->is_valid_number, '福島県伊達市鶴巻');
ok($zip->set_number('9600477')->is_valid_number, '福島県伊達市柏木町');
ok($zip->set_number('9600478')->is_valid_number, '福島県伊達市細谷');
ok($zip->set_number('9600479')->is_valid_number, '福島県伊達市野崎');
ok($zip->set_number('9600481')->is_valid_number, '福島県伊達市堀切端');
ok($zip->set_number('9600482')->is_valid_number, '福島県伊達市鶴田');
ok($zip->set_number('9600483')->is_valid_number, '福島県伊達市柳内');
ok($zip->set_number('9600484')->is_valid_number, '福島県伊達市馬場口');
ok($zip->set_number('9600485')->is_valid_number, '福島県伊達市篭田');
ok($zip->set_number('9600486')->is_valid_number, '福島県伊達市六角');
ok($zip->set_number('9600487')->is_valid_number, '福島県伊達市高田');
ok($zip->set_number('9600488')->is_valid_number, '福島県伊達市上台');
ok($zip->set_number('9600489')->is_valid_number, '福島県伊達市瀬戸場');
ok($zip->set_number('9600501')->is_valid_number, '福島県伊達市伏黒');
ok($zip->set_number('9600502')->is_valid_number, '福島県伊達市箱崎');
ok($zip->set_number('9600600')->is_valid_number, '福島県伊達市以下に掲載がない場合');
ok($zip->set_number('9600601')->is_valid_number, '福島県伊達市保原町栄町');
ok($zip->set_number('9600602')->is_valid_number, '福島県伊達市保原町久保');
ok($zip->set_number('9600603')->is_valid_number, '福島県伊達市保原町古町');
ok($zip->set_number('9600604')->is_valid_number, '福島県伊達市保原町元木');
ok($zip->set_number('9600605')->is_valid_number, '福島県伊達市保原町元町');
ok($zip->set_number('9600606')->is_valid_number, '福島県伊達市保原町鉄炮町');
ok($zip->set_number('9600607')->is_valid_number, '福島県伊達市保原町10丁目');
ok($zip->set_number('9600608')->is_valid_number, '福島県伊達市保原町11丁目');
ok($zip->set_number('9600609')->is_valid_number, '福島県伊達市保原町12丁目');
ok($zip->set_number('9600611')->is_valid_number, '福島県伊達市保原町城ノ内');
ok($zip->set_number('9600612')->is_valid_number, '福島県伊達市保原町宮下');
ok($zip->set_number('9600613')->is_valid_number, '福島県伊達市保原町内町');
ok($zip->set_number('9600614')->is_valid_number, '福島県伊達市保原町磐前通');
ok($zip->set_number('9600615')->is_valid_number, '福島県伊達市保原町5丁目');
ok($zip->set_number('9600616')->is_valid_number, '福島県伊達市保原町6丁目');
ok($zip->set_number('9600617')->is_valid_number, '福島県伊達市保原町7丁目');
ok($zip->set_number('9600618')->is_valid_number, '福島県伊達市保原町8丁目');
ok($zip->set_number('9600619')->is_valid_number, '福島県伊達市保原町9丁目');
ok($zip->set_number('9600621')->is_valid_number, '福島県伊達市保原町中村町');
ok($zip->set_number('9600622')->is_valid_number, '福島県伊達市保原町市柳町');
ok($zip->set_number('9600623')->is_valid_number, '福島県伊達市保原町前田町');
ok($zip->set_number('9600624')->is_valid_number, '福島県伊達市保原町1丁目');
ok($zip->set_number('9600625')->is_valid_number, '福島県伊達市保原町2丁目');
ok($zip->set_number('9600626')->is_valid_number, '福島県伊達市保原町3丁目');
ok($zip->set_number('9600627')->is_valid_number, '福島県伊達市保原町4丁目');
ok($zip->set_number('9600628')->is_valid_number, '福島県伊達市保原町実町');
ok($zip->set_number('9600629')->is_valid_number, '福島県伊達市保原町弥生町');
ok($zip->set_number('9600631')->is_valid_number, '福島県伊達市保原町中瀬');
ok($zip->set_number('9600632')->is_valid_number, '福島県伊達市保原町大立目');
ok($zip->set_number('9600633')->is_valid_number, '福島県伊達市保原町二井田');
ok($zip->set_number('9600634')->is_valid_number, '福島県伊達市保原町大泉');
ok($zip->set_number('9600635')->is_valid_number, '福島県伊達市保原町半道');
ok($zip->set_number('9600636')->is_valid_number, '福島県伊達市保原町大和');
ok($zip->set_number('9600637')->is_valid_number, '福島県伊達市保原町将監');
ok($zip->set_number('9600638')->is_valid_number, '福島県伊達市保原町北河原');
ok($zip->set_number('9600639')->is_valid_number, '福島県伊達市保原町六万坊');
ok($zip->set_number('9600641')->is_valid_number, '福島県伊達市保原町西猫川');
ok($zip->set_number('9600642')->is_valid_number, '福島県伊達市保原町東猫川');
ok($zip->set_number('9600643')->is_valid_number, '福島県伊達市保原町下河原');
ok($zip->set_number('9600644')->is_valid_number, '福島県伊達市保原町豊田');
ok($zip->set_number('9600644')->is_valid_number, '福島県伊達市保原町豊町');
ok($zip->set_number('9600645')->is_valid_number, '福島県伊達市保原町台後');
ok($zip->set_number('9600646')->is_valid_number, '福島県伊達市保原町東台後');
ok($zip->set_number('9600647')->is_valid_number, '福島県伊達市保原町小蓋');
ok($zip->set_number('9600648')->is_valid_number, '福島県伊達市保原町東小蓋');
ok($zip->set_number('9600649')->is_valid_number, '福島県伊達市保原町清水町');
ok($zip->set_number('9600650')->is_valid_number, '福島県伊達市保原町西新田');
ok($zip->set_number('9600651')->is_valid_number, '福島県伊達市保原町柏町');
ok($zip->set_number('9600652')->is_valid_number, '福島県伊達市保原町西町');
ok($zip->set_number('9600653')->is_valid_number, '福島県伊達市保原町泉町');
ok($zip->set_number('9600654')->is_valid_number, '福島県伊達市保原町小幡町');
ok($zip->set_number('9600655')->is_valid_number, '福島県伊達市保原町宮内町');
ok($zip->set_number('9600656')->is_valid_number, '福島県伊達市保原町八幡町');
ok($zip->set_number('9600657')->is_valid_number, '福島県伊達市保原町中瀬町');
ok($zip->set_number('9600658')->is_valid_number, '福島県伊達市保原町古川端');
ok($zip->set_number('9600659')->is_valid_number, '福島県伊達市保原町西ノ内');
ok($zip->set_number('9600661')->is_valid_number, '福島県伊達市保原町金原田');
ok($zip->set_number('9600662')->is_valid_number, '福島県伊達市保原町柱田');
ok($zip->set_number('9600663')->is_valid_number, '福島県伊達市保原町舟橋');
ok($zip->set_number('9600664')->is_valid_number, '福島県伊達市保原町太田中');
ok($zip->set_number('9600665')->is_valid_number, '福島県伊達市保原町岡代');
ok($zip->set_number('9600666')->is_valid_number, '福島県伊達市保原町村岡');
ok($zip->set_number('9600667')->is_valid_number, '福島県伊達市保原町八幡台');
ok($zip->set_number('9600668')->is_valid_number, '福島県伊達市保原町烏内');
ok($zip->set_number('9600669')->is_valid_number, '福島県伊達市保原町赤橋');
ok($zip->set_number('9600670')->is_valid_number, '福島県伊達市保原町桑田');
ok($zip->set_number('9600671')->is_valid_number, '福島県伊達市保原町東野崎');
ok($zip->set_number('9600672')->is_valid_number, '福島県伊達市保原町下野崎');
ok($zip->set_number('9600673')->is_valid_number, '福島県伊達市保原町野崎');
ok($zip->set_number('9600674')->is_valid_number, '福島県伊達市保原町上野崎');
ok($zip->set_number('9600675')->is_valid_number, '福島県伊達市保原町大柳');
ok($zip->set_number('9600676')->is_valid_number, '福島県伊達市保原町千刈');
ok($zip->set_number('9600677')->is_valid_number, '福島県伊達市保原町早稲田');
ok($zip->set_number('9600678')->is_valid_number, '福島県伊達市保原町京門');
ok($zip->set_number('9600679')->is_valid_number, '福島県伊達市保原町油谷地');
ok($zip->set_number('9600681')->is_valid_number, '福島県伊達市保原町所沢');
ok($zip->set_number('9600682')->is_valid_number, '福島県伊達市保原町富沢');
ok($zip->set_number('9600683')->is_valid_number, '福島県伊達市保原町高成田');
ok($zip->set_number('9600684')->is_valid_number, '福島県伊達市保原町上保原');
ok($zip->set_number('9600685')->is_valid_number, '福島県伊達市保原町黄金町');
ok($zip->set_number('9600686')->is_valid_number, '福島県伊達市保原町竹内町');
ok($zip->set_number('9600687')->is_valid_number, '福島県伊達市保原町旭町');
ok($zip->set_number('9600688')->is_valid_number, '福島県伊達市保原町みずほ');
ok($zip->set_number('9600689')->is_valid_number, '福島県伊達市保原町高子岡');
ok($zip->set_number('9600701')->is_valid_number, '福島県伊達市梁川町五十沢');
ok($zip->set_number('9600702')->is_valid_number, '福島県伊達市梁川町東大枝');
ok($zip->set_number('9600703')->is_valid_number, '福島県伊達市梁川町山舟生');
ok($zip->set_number('9600704')->is_valid_number, '福島県伊達市梁川町舟生');
ok($zip->set_number('9600705')->is_valid_number, '福島県伊達市梁川町元舟場');
ok($zip->set_number('9600706')->is_valid_number, '福島県伊達市梁川町北町谷川');
ok($zip->set_number('9600707')->is_valid_number, '福島県伊達市梁川町南町谷川');
ok($zip->set_number('9600708')->is_valid_number, '福島県伊達市梁川町東塩野川');
ok($zip->set_number('9600709')->is_valid_number, '福島県伊達市梁川町西塩野川');
ok($zip->set_number('9600711')->is_valid_number, '福島県伊達市梁川町粟野');
ok($zip->set_number('9600711')->is_valid_number, '福島県伊達市梁川町下川原');
ok($zip->set_number('9600712')->is_valid_number, '福島県伊達市梁川町御八郎');
ok($zip->set_number('9600713')->is_valid_number, '福島県伊達市梁川町八筋');
ok($zip->set_number('9600715')->is_valid_number, '福島県伊達市梁川町大舘');
ok($zip->set_number('9600716')->is_valid_number, '福島県伊達市梁川町白川田');
ok($zip->set_number('9600717')->is_valid_number, '福島県伊達市梁川町向川原');
ok($zip->set_number('9600718')->is_valid_number, '福島県伊達市梁川町二野袋');
ok($zip->set_number('9600719')->is_valid_number, '福島県伊達市梁川町やながわ工業団地');
ok($zip->set_number('9600721')->is_valid_number, '福島県伊達市梁川町白根');
ok($zip->set_number('9600722')->is_valid_number, '福島県伊達市梁川町八幡');
ok($zip->set_number('9600723')->is_valid_number, '福島県伊達市梁川町足駄木');
ok($zip->set_number('9600723')->is_valid_number, '福島県伊達市梁川町内山');
ok($zip->set_number('9600723')->is_valid_number, '福島県伊達市梁川町上足駄木');
ok($zip->set_number('9600723')->is_valid_number, '福島県伊達市梁川町里見山');
ok($zip->set_number('9600724')->is_valid_number, '福島県伊達市梁川町北新井');
ok($zip->set_number('9600725')->is_valid_number, '福島県伊達市梁川町赤五輪');
ok($zip->set_number('9600726')->is_valid_number, '福島県伊達市梁川町北町頭');
ok($zip->set_number('9600727')->is_valid_number, '福島県伊達市梁川町上町');
ok($zip->set_number('9600728')->is_valid_number, '福島県伊達市梁川町天神前');
ok($zip->set_number('9600729')->is_valid_number, '福島県伊達市梁川町希望ケ丘');
ok($zip->set_number('9600731')->is_valid_number, '福島県伊達市梁川町天神町');
ok($zip->set_number('9600732')->is_valid_number, '福島県伊達市梁川町南町頭');
ok($zip->set_number('9600733')->is_valid_number, '福島県伊達市梁川町菖蒲沢');
ok($zip->set_number('9600734')->is_valid_number, '福島県伊達市梁川町茶臼山');
ok($zip->set_number('9600735')->is_valid_number, '福島県伊達市梁川町鶴ケ岡');
ok($zip->set_number('9600736')->is_valid_number, '福島県伊達市梁川町桜岳');
ok($zip->set_number('9600741')->is_valid_number, '福島県伊達市梁川町大町');
ok($zip->set_number('9600742')->is_valid_number, '福島県伊達市梁川町清水町');
ok($zip->set_number('9600743')->is_valid_number, '福島県伊達市梁川町元陣内');
ok($zip->set_number('9600744')->is_valid_number, '福島県伊達市梁川町内町');
ok($zip->set_number('9600745')->is_valid_number, '福島県伊達市梁川町右城町');
ok($zip->set_number('9600746')->is_valid_number, '福島県伊達市梁川町大清水');
ok($zip->set_number('9600747')->is_valid_number, '福島県伊達市梁川町町裏');
ok($zip->set_number('9600751')->is_valid_number, '福島県伊達市梁川町古町');
ok($zip->set_number('9600752')->is_valid_number, '福島県伊達市梁川町四日市');
ok($zip->set_number('9600753')->is_valid_number, '福島県伊達市梁川町上川原');
ok($zip->set_number('9600754')->is_valid_number, '福島県伊達市梁川町栄町');
ok($zip->set_number('9600755')->is_valid_number, '福島県伊達市梁川町中久保');
ok($zip->set_number('9600756')->is_valid_number, '福島県伊達市梁川町青葉町');
ok($zip->set_number('9600757')->is_valid_number, '福島県伊達市梁川町幸町');
ok($zip->set_number('9600758')->is_valid_number, '福島県伊達市梁川町桜町');
ok($zip->set_number('9600759')->is_valid_number, '福島県伊達市梁川町広瀬町');
ok($zip->set_number('9600760')->is_valid_number, '福島県伊達市梁川町陽光台');
ok($zip->set_number('9600762')->is_valid_number, '福島県伊達市梁川町丹波塚');
ok($zip->set_number('9600763')->is_valid_number, '福島県伊達市梁川町大門道');
ok($zip->set_number('9600764')->is_valid_number, '福島県伊達市梁川町壱丁田');
ok($zip->set_number('9600765')->is_valid_number, '福島県伊達市梁川町大関');
ok($zip->set_number('9600766')->is_valid_number, '福島県伊達市梁川町細谷');
ok($zip->set_number('9600767')->is_valid_number, '福島県伊達市梁川町新田');
ok($zip->set_number('9600768')->is_valid_number, '福島県伊達市梁川町柳田');
ok($zip->set_number('9600769')->is_valid_number, '福島県伊達市梁川町舟橋');
ok($zip->set_number('9600772')->is_valid_number, '福島県伊達市梁川町上割田');
ok($zip->set_number('9600773')->is_valid_number, '福島県伊達市梁川町五反田');
ok($zip->set_number('9600774')->is_valid_number, '福島県伊達市梁川町石井戸');
ok($zip->set_number('9600775')->is_valid_number, '福島県伊達市梁川町四石蒔');
ok($zip->set_number('9600776')->is_valid_number, '福島県伊達市梁川町東土橋');
ok($zip->set_number('9600777')->is_valid_number, '福島県伊達市梁川町西土橋');
ok($zip->set_number('9600778')->is_valid_number, '福島県伊達市梁川町伝樋');
ok($zip->set_number('9600781')->is_valid_number, '福島県伊達市梁川町北本町');
ok($zip->set_number('9600782')->is_valid_number, '福島県伊達市梁川町中町');
ok($zip->set_number('9600783')->is_valid_number, '福島県伊達市梁川町本町');
ok($zip->set_number('9600784')->is_valid_number, '福島県伊達市梁川町田町');
ok($zip->set_number('9600785')->is_valid_number, '福島県伊達市梁川町小梁川');
ok($zip->set_number('9600786')->is_valid_number, '福島県伊達市梁川町南本町');
ok($zip->set_number('9600787')->is_valid_number, '福島県伊達市梁川町山城舘');
ok($zip->set_number('9600801')->is_valid_number, '福島県伊達市霊山町掛田');
ok($zip->set_number('9600802')->is_valid_number, '福島県伊達市霊山町山野川');
ok($zip->set_number('9600803')->is_valid_number, '福島県伊達市霊山町泉原');
ok($zip->set_number('9600804')->is_valid_number, '福島県伊達市霊山町大石');
ok($zip->set_number('9600805')->is_valid_number, '福島県伊達市霊山町中川');
ok($zip->set_number('9600806')->is_valid_number, '福島県伊達市霊山町山戸田');
ok($zip->set_number('9600807')->is_valid_number, '福島県伊達市霊山町石田');
ok($zip->set_number('9600808')->is_valid_number, '福島県伊達市霊山町下小国');
ok($zip->set_number('9600809')->is_valid_number, '福島県伊達市霊山町上小国');
ok($zip->set_number('9600811')->is_valid_number, '福島県福島市大波');
ok($zip->set_number('9600901')->is_valid_number, '福島県伊達市月舘町布川');
ok($zip->set_number('9600902')->is_valid_number, '福島県伊達市月舘町月舘');
ok($zip->set_number('9600903')->is_valid_number, '福島県伊達市月舘町下手渡');
ok($zip->set_number('9600904')->is_valid_number, '福島県伊達市月舘町上手渡');
ok($zip->set_number('9600905')->is_valid_number, '福島県伊達市月舘町糠田');
ok($zip->set_number('9600906')->is_valid_number, '福島県伊達市月舘町御代田');
ok($zip->set_number('9601101')->is_valid_number, '福島県福島市大森');
ok($zip->set_number('9601102')->is_valid_number, '福島県福島市永井川');
ok($zip->set_number('9601103')->is_valid_number, '福島県福島市平石');
ok($zip->set_number('9601104')->is_valid_number, '福島県福島市小田');
ok($zip->set_number('9601105')->is_valid_number, '福島県福島市山田');
ok($zip->set_number('9601106')->is_valid_number, '福島県福島市下鳥渡');
ok($zip->set_number('9601107')->is_valid_number, '福島県福島市上鳥渡');
ok($zip->set_number('9601108')->is_valid_number, '福島県福島市成川');
ok($zip->set_number('9601231')->is_valid_number, '福島県福島市松川町沼袋');
ok($zip->set_number('9601232')->is_valid_number, '福島県福島市松川町下川崎');
ok($zip->set_number('9601241')->is_valid_number, '福島県福島市松川町');
ok($zip->set_number('9601242')->is_valid_number, '福島県福島市松川町美郷');
ok($zip->set_number('9601243')->is_valid_number, '福島県福島市松川町水原');
ok($zip->set_number('9601244')->is_valid_number, '福島県福島市松川町関谷');
ok($zip->set_number('9601245')->is_valid_number, '福島県福島市松川町浅川');
ok($zip->set_number('9601246')->is_valid_number, '福島県福島市松川町金沢');
ok($zip->set_number('9601247')->is_valid_number, '福島県福島市光が丘');
ok($zip->set_number('9601248')->is_valid_number, '福島県福島市金谷川');
ok($zip->set_number('9601301')->is_valid_number, '福島県福島市飯野町');
ok($zip->set_number('9601302')->is_valid_number, '福島県福島市飯野町明治');
ok($zip->set_number('9601303')->is_valid_number, '福島県福島市飯野町青木');
ok($zip->set_number('9601304')->is_valid_number, '福島県福島市飯野町大久保');
ok($zip->set_number('9601321')->is_valid_number, '福島県福島市立子山');
ok($zip->set_number('9601400')->is_valid_number, '福島県伊達郡川俣町以下に掲載がない場合');
ok($zip->set_number('9601401')->is_valid_number, '福島県伊達郡川俣町飯坂');
ok($zip->set_number('9601402')->is_valid_number, '福島県伊達郡川俣町小綱木');
ok($zip->set_number('9601403')->is_valid_number, '福島県伊達郡川俣町大綱木');
ok($zip->set_number('9601404')->is_valid_number, '福島県伊達郡川俣町西福沢');
ok($zip->set_number('9601405')->is_valid_number, '福島県伊達郡川俣町東福沢');
ok($zip->set_number('9601406')->is_valid_number, '福島県伊達郡川俣町鶴沢');
ok($zip->set_number('9601407')->is_valid_number, '福島県伊達郡川俣町小神');
ok($zip->set_number('9601408')->is_valid_number, '福島県伊達郡川俣町羽田');
ok($zip->set_number('9601409')->is_valid_number, '福島県伊達郡川俣町秋山');
ok($zip->set_number('9601411')->is_valid_number, '福島県伊達郡川俣町細田');
ok($zip->set_number('9601412')->is_valid_number, '福島県伊達郡川俣町仲ノ内');
ok($zip->set_number('9601413')->is_valid_number, '福島県伊達郡川俣町広畑');
ok($zip->set_number('9601414')->is_valid_number, '福島県伊達郡川俣町上桜');
ok($zip->set_number('9601415')->is_valid_number, '福島県伊達郡川俣町仁井町');
ok($zip->set_number('9601416')->is_valid_number, '福島県伊達郡川俣町舘ノ腰');
ok($zip->set_number('9601417')->is_valid_number, '福島県伊達郡川俣町橋本');
ok($zip->set_number('9601421')->is_valid_number, '福島県伊達郡川俣町鉄炮町');
ok($zip->set_number('9601422')->is_valid_number, '福島県伊達郡川俣町新中町');
ok($zip->set_number('9601423')->is_valid_number, '福島県伊達郡川俣町池ノ入');
ok($zip->set_number('9601424')->is_valid_number, '福島県伊達郡川俣町寺久保');
ok($zip->set_number('9601425')->is_valid_number, '福島県伊達郡川俣町新宮');
ok($zip->set_number('9601426')->is_valid_number, '福島県伊達郡川俣町日和田');
ok($zip->set_number('9601427')->is_valid_number, '福島県伊達郡川俣町段ノ腰');
ok($zip->set_number('9601428')->is_valid_number, '福島県伊達郡川俣町五百田');
ok($zip->set_number('9601429')->is_valid_number, '福島県伊達郡川俣町柏崎');
ok($zip->set_number('9601431')->is_valid_number, '福島県伊達郡川俣町大清水');
ok($zip->set_number('9601432')->is_valid_number, '福島県伊達郡川俣町東大清水');
ok($zip->set_number('9601433')->is_valid_number, '福島県伊達郡川俣町賤ノ田');
ok($zip->set_number('9601434')->is_valid_number, '福島県伊達郡川俣町小作');
ok($zip->set_number('9601435')->is_valid_number, '福島県伊達郡川俣町大作');
ok($zip->set_number('9601436')->is_valid_number, '福島県伊達郡川俣町川原田');
ok($zip->set_number('9601441')->is_valid_number, '福島県伊達郡川俣町道内');
ok($zip->set_number('9601442')->is_valid_number, '福島県伊達郡川俣町後庵');
ok($zip->set_number('9601443')->is_valid_number, '福島県伊達郡川俣町大内');
ok($zip->set_number('9601444')->is_valid_number, '福島県伊達郡川俣町根本');
ok($zip->set_number('9601445')->is_valid_number, '福島県伊達郡川俣町中島');
ok($zip->set_number('9601446')->is_valid_number, '福島県伊達郡川俣町舘');
ok($zip->set_number('9601451')->is_valid_number, '福島県伊達郡川俣町本町');
ok($zip->set_number('9601452')->is_valid_number, '福島県伊達郡川俣町後田');
ok($zip->set_number('9601453')->is_valid_number, '福島県伊達郡川俣町瓦町');
ok($zip->set_number('9601454')->is_valid_number, '福島県伊達郡川俣町八反田');
ok($zip->set_number('9601455')->is_valid_number, '福島県伊達郡川俣町竹ノ内');
ok($zip->set_number('9601456')->is_valid_number, '福島県伊達郡川俣町中丁');
ok($zip->set_number('9601461')->is_valid_number, '福島県伊達郡川俣町宮町');
ok($zip->set_number('9601462')->is_valid_number, '福島県伊達郡川俣町寺前');
ok($zip->set_number('9601463')->is_valid_number, '福島県伊達郡川俣町樋ノ口');
ok($zip->set_number('9601464')->is_valid_number, '福島県伊達郡川俣町宮ノ脇');
ok($zip->set_number('9601465')->is_valid_number, '福島県伊達郡川俣町赤坂');
ok($zip->set_number('9601466')->is_valid_number, '福島県伊達郡川俣町宮前');
ok($zip->set_number('9601467')->is_valid_number, '福島県伊達郡川俣町宮ノ入');
ok($zip->set_number('9601468')->is_valid_number, '福島県伊達郡川俣町天神入');
ok($zip->set_number('9601469')->is_valid_number, '福島県伊達郡川俣町道場');
ok($zip->set_number('9601471')->is_valid_number, '福島県伊達郡川俣町西戸ノ内');
ok($zip->set_number('9601472')->is_valid_number, '福島県伊達郡川俣町草ケ入');
ok($zip->set_number('9601473')->is_valid_number, '福島県伊達郡川俣町桜ケ作');
ok($zip->set_number('9601474')->is_valid_number, '福島県伊達郡川俣町七曲');
ok($zip->set_number('9601475')->is_valid_number, '福島県伊達郡川俣町早坂');
ok($zip->set_number('9601476')->is_valid_number, '福島県伊達郡川俣町石川');
ok($zip->set_number('9601477')->is_valid_number, '福島県伊達郡川俣町倉ケ作');
ok($zip->set_number('9601478')->is_valid_number, '福島県伊達郡川俣町壁沢');
ok($zip->set_number('9601481')->is_valid_number, '福島県伊達郡川俣町七窪');
ok($zip->set_number('9601482')->is_valid_number, '福島県伊達郡川俣町元屋敷');
ok($zip->set_number('9601483')->is_valid_number, '福島県伊達郡川俣町壺ケ作');
ok($zip->set_number('9601484')->is_valid_number, '福島県伊達郡川俣町延命神');
ok($zip->set_number('9601485')->is_valid_number, '福島県伊達郡川俣町海老ケ作');
ok($zip->set_number('9601486')->is_valid_number, '福島県伊達郡川俣町下拍子');
ok($zip->set_number('9601487')->is_valid_number, '福島県伊達郡川俣町三百田');
ok($zip->set_number('9601488')->is_valid_number, '福島県伊達郡川俣町新田');
ok($zip->set_number('9601489')->is_valid_number, '福島県伊達郡川俣町小島');
ok($zip->set_number('9601501')->is_valid_number, '福島県伊達郡川俣町山木屋');
ok($zip->set_number('9601600')->is_valid_number, '福島県相馬郡飯舘村以下に掲載がない場合');
ok($zip->set_number('9601631')->is_valid_number, '福島県相馬郡飯舘村松塚');
ok($zip->set_number('9601632')->is_valid_number, '福島県相馬郡飯舘村関根');
ok($zip->set_number('9601633')->is_valid_number, '福島県相馬郡飯舘村臼石');
ok($zip->set_number('9601634')->is_valid_number, '福島県相馬郡飯舘村二枚橋');
ok($zip->set_number('9601635')->is_valid_number, '福島県相馬郡飯舘村須萱');
ok($zip->set_number('9601636')->is_valid_number, '福島県相馬郡飯舘村前田');
ok($zip->set_number('9601721')->is_valid_number, '福島県相馬郡飯舘村飯樋');
ok($zip->set_number('9601722')->is_valid_number, '福島県相馬郡飯舘村比曽');
ok($zip->set_number('9601723')->is_valid_number, '福島県相馬郡飯舘村長泥');
ok($zip->set_number('9601724')->is_valid_number, '福島県相馬郡飯舘村蕨平');
ok($zip->set_number('9601801')->is_valid_number, '福島県相馬郡飯舘村草野');
ok($zip->set_number('9601802')->is_valid_number, '福島県相馬郡飯舘村深谷');
ok($zip->set_number('9601803')->is_valid_number, '福島県相馬郡飯舘村伊丹沢');
ok($zip->set_number('9601804')->is_valid_number, '福島県相馬郡飯舘村関沢');
ok($zip->set_number('9601811')->is_valid_number, '福島県相馬郡飯舘村小宮');
ok($zip->set_number('9601812')->is_valid_number, '福島県相馬郡飯舘村芦原');
ok($zip->set_number('9601813')->is_valid_number, '福島県相馬郡飯舘村八木沢');
ok($zip->set_number('9601814')->is_valid_number, '福島県相馬郡飯舘村大倉');
ok($zip->set_number('9601815')->is_valid_number, '福島県相馬郡飯舘村佐須');
ok($zip->set_number('9602101')->is_valid_number, '福島県福島市さくら');
ok($zip->set_number('9602102')->is_valid_number, '福島県福島市荒井北');
ok($zip->set_number('9602151')->is_valid_number, '福島県福島市桜本(その他)');
ok($zip->set_number('9602152')->is_valid_number, '福島県福島市土船');
ok($zip->set_number('9602153')->is_valid_number, '福島県福島市庄野');
ok($zip->set_number('9602154')->is_valid_number, '福島県福島市佐倉下');
ok($zip->set_number('9602155')->is_valid_number, '福島県福島市上名倉');
ok($zip->set_number('9602156')->is_valid_number, '福島県福島市荒井');
ok($zip->set_number('9602157')->is_valid_number, '福島県福島市土湯温泉町');
ok($zip->set_number('9602158')->is_valid_number, '福島県福島市佐原');
ok($zip->set_number('9602251')->is_valid_number, '福島県福島市桜本(木通沢)');
ok($zip->set_number('9602261')->is_valid_number, '福島県福島市町庭坂');
ok($zip->set_number('9602262')->is_valid_number, '福島県福島市在庭坂');
ok($zip->set_number('9602263')->is_valid_number, '福島県福島市二子塚');
ok($zip->set_number('9608001')->is_valid_number, '福島県福島市天神町');
ok($zip->set_number('9608002')->is_valid_number, '福島県福島市森合町');
ok($zip->set_number('9608003')->is_valid_number, '福島県福島市森合');
ok($zip->set_number('9608011')->is_valid_number, '福島県福島市宮下町');
ok($zip->set_number('9608012')->is_valid_number, '福島県福島市御山町');
ok($zip->set_number('9608013')->is_valid_number, '福島県福島市南平');
ok($zip->set_number('9608014')->is_valid_number, '福島県福島市大平山');
ok($zip->set_number('9608014')->is_valid_number, '福島県福島市児石');
ok($zip->set_number('9608015')->is_valid_number, '福島県福島市狐山');
ok($zip->set_number('9608016')->is_valid_number, '福島県福島市狐塚畑');
ok($zip->set_number('9608017')->is_valid_number, '福島県福島市狐塚');
ok($zip->set_number('9608018')->is_valid_number, '福島県福島市松木町');
ok($zip->set_number('9608021')->is_valid_number, '福島県福島市霞町');
ok($zip->set_number('9608022')->is_valid_number, '福島県福島市新浜町');
ok($zip->set_number('9608023')->is_valid_number, '福島県福島市大明神');
ok($zip->set_number('9608024')->is_valid_number, '福島県福島市堂殿');
ok($zip->set_number('9608025')->is_valid_number, '福島県福島市駒山');
ok($zip->set_number('9608026')->is_valid_number, '福島県福島市狩野');
ok($zip->set_number('9608031')->is_valid_number, '福島県福島市栄町');
ok($zip->set_number('9608032')->is_valid_number, '福島県福島市陣場町');
ok($zip->set_number('9608033')->is_valid_number, '福島県福島市万世町');
ok($zip->set_number('9608034')->is_valid_number, '福島県福島市置賜町');
ok($zip->set_number('9608035')->is_valid_number, '福島県福島市本町');
ok($zip->set_number('9608036')->is_valid_number, '福島県福島市新町');
ok($zip->set_number('9608041')->is_valid_number, '福島県福島市大町');
ok($zip->set_number('9608042')->is_valid_number, '福島県福島市荒町');
ok($zip->set_number('9608043')->is_valid_number, '福島県福島市中町');
ok($zip->set_number('9608044')->is_valid_number, '福島県福島市早稲町');
ok($zip->set_number('9608051')->is_valid_number, '福島県福島市曽根田町');
ok($zip->set_number('9608052')->is_valid_number, '福島県福島市公事田');
ok($zip->set_number('9608053')->is_valid_number, '福島県福島市三河南町');
ok($zip->set_number('9608054')->is_valid_number, '福島県福島市三河北町');
ok($zip->set_number('9608055')->is_valid_number, '福島県福島市野田町');
ok($zip->set_number('9608056')->is_valid_number, '福島県福島市八島田');
ok($zip->set_number('9608057')->is_valid_number, '福島県福島市笹木野');
ok($zip->set_number('9608058')->is_valid_number, '福島県福島市下谷地');
ok($zip->set_number('9608061')->is_valid_number, '福島県福島市五月町');
ok($zip->set_number('9608062')->is_valid_number, '福島県福島市清明町');
ok($zip->set_number('9608063')->is_valid_number, '福島県福島市柳町');
ok($zip->set_number('9608064')->is_valid_number, '福島県福島市御倉町');
ok($zip->set_number('9608065')->is_valid_number, '福島県福島市杉妻町');
ok($zip->set_number('9608066')->is_valid_number, '福島県福島市矢剣町');
ok($zip->set_number('9608067')->is_valid_number, '福島県福島市須川町');
ok($zip->set_number('9608068')->is_valid_number, '福島県福島市太田町');
ok($zip->set_number('9608071')->is_valid_number, '福島県福島市東中央');
ok($zip->set_number('9608072')->is_valid_number, '福島県福島市北中央');
ok($zip->set_number('9608073')->is_valid_number, '福島県福島市南中央');
ok($zip->set_number('9608074')->is_valid_number, '福島県福島市西中央');
ok($zip->set_number('9608075')->is_valid_number, '福島県福島市下野寺');
ok($zip->set_number('9608076')->is_valid_number, '福島県福島市上野寺');
ok($zip->set_number('9608101')->is_valid_number, '福島県福島市上町');
ok($zip->set_number('9608102')->is_valid_number, '福島県福島市北町');
ok($zip->set_number('9608103')->is_valid_number, '福島県福島市舟場町');
ok($zip->set_number('9608104')->is_valid_number, '福島県福島市豊田町');
ok($zip->set_number('9608105')->is_valid_number, '福島県福島市仲間町');
ok($zip->set_number('9608106')->is_valid_number, '福島県福島市宮町');
ok($zip->set_number('9608107')->is_valid_number, '福島県福島市浜田町');
ok($zip->set_number('9608111')->is_valid_number, '福島県福島市五老内町');
ok($zip->set_number('9608112')->is_valid_number, '福島県福島市花園町');
ok($zip->set_number('9608113')->is_valid_number, '福島県福島市旭町');
ok($zip->set_number('9608114')->is_valid_number, '福島県福島市松浪町');
ok($zip->set_number('9608115')->is_valid_number, '福島県福島市山下町');
ok($zip->set_number('9608116')->is_valid_number, '福島県福島市春日町');
ok($zip->set_number('9608117')->is_valid_number, '福島県福島市入江町');
ok($zip->set_number('9608121')->is_valid_number, '福島県福島市小金山');
ok($zip->set_number('9608122')->is_valid_number, '福島県福島市清水山');
ok($zip->set_number('9608123')->is_valid_number, '福島県福島市所窪');
ok($zip->set_number('9608124')->is_valid_number, '福島県福島市山居上');
ok($zip->set_number('9608125')->is_valid_number, '福島県福島市鴇頭森');
ok($zip->set_number('9608131')->is_valid_number, '福島県福島市北五老内町');
ok($zip->set_number('9608132')->is_valid_number, '福島県福島市東浜町');
ok($zip->set_number('9608133')->is_valid_number, '福島県福島市桜木町');
ok($zip->set_number('9608134')->is_valid_number, '福島県福島市上浜町');
ok($zip->set_number('9608135')->is_valid_number, '福島県福島市腰浜町');
ok($zip->set_number('9608136')->is_valid_number, '福島県福島市八島町');
ok($zip->set_number('9608137')->is_valid_number, '福島県福島市堀河町');
ok($zip->set_number('9608141')->is_valid_number, '福島県福島市渡利');
ok($zip->set_number('9608142')->is_valid_number, '福島県福島市小倉寺');
ok($zip->set_number('9608143')->is_valid_number, '福島県福島市南向台');
ok($zip->set_number('9608151')->is_valid_number, '福島県福島市太平寺');
ok($zip->set_number('9608152')->is_valid_number, '福島県福島市鳥谷野');
ok($zip->set_number('9608153')->is_valid_number, '福島県福島市黒岩');
ok($zip->set_number('9608154')->is_valid_number, '福島県福島市伏拝');
ok($zip->set_number('9608155')->is_valid_number, '福島県福島市清水町');
ok($zip->set_number('9608156')->is_valid_number, '福島県福島市田沢');
ok($zip->set_number('9608157')->is_valid_number, '福島県福島市蓬莱町');
ok($zip->set_number('9608161')->is_valid_number, '福島県福島市郷野目');
ok($zip->set_number('9608162')->is_valid_number, '福島県福島市南町');
ok($zip->set_number('9608163')->is_valid_number, '福島県福島市方木田');
ok($zip->set_number('9608164')->is_valid_number, '福島県福島市八木田');
ok($zip->set_number('9608165')->is_valid_number, '福島県福島市吉倉');
ok($zip->set_number('9608166')->is_valid_number, '福島県福島市仁井田');
ok($zip->set_number('9608201')->is_valid_number, '福島県福島市岡島');
ok($zip->set_number('9608202')->is_valid_number, '福島県福島市山口');
ok($zip->set_number('9608203')->is_valid_number, '福島県福島市本内(南下釜)');
ok($zip->set_number('9608204')->is_valid_number, '福島県福島市岡部');
ok($zip->set_number('9608211')->is_valid_number, '福島県福島市茶屋下');
ok($zip->set_number('9608212')->is_valid_number, '福島県福島市道前');
ok($zip->set_number('9608213')->is_valid_number, '福島県福島市遠瀬戸');
ok($zip->set_number('9608214')->is_valid_number, '福島県福島市古川');
ok($zip->set_number('9608215')->is_valid_number, '福島県福島市下荒子');
ok($zip->set_number('9608216')->is_valid_number, '福島県福島市中荒子');
ok($zip->set_number('9608217')->is_valid_number, '福島県福島市上荒子');
ok($zip->set_number('9608218')->is_valid_number, '福島県福島市高野河原下');
ok($zip->set_number('9608221')->is_valid_number, '福島県福島市北中川原');
ok($zip->set_number('9608222')->is_valid_number, '福島県福島市蝦貫');
ok($zip->set_number('9608223')->is_valid_number, '福島県福島市矢倉下');
ok($zip->set_number('9608224')->is_valid_number, '福島県福島市舘ノ前');
ok($zip->set_number('9608225')->is_valid_number, '福島県福島市舘ノ内');
ok($zip->set_number('9608226')->is_valid_number, '福島県福島市北ノ前');
ok($zip->set_number('9608227')->is_valid_number, '福島県福島市田中島');
ok($zip->set_number('9608228')->is_valid_number, '福島県福島市松山町');
ok($zip->set_number('9608231')->is_valid_number, '福島県福島市北原');
ok($zip->set_number('9608232')->is_valid_number, '福島県福島市立石');
ok($zip->set_number('9608233')->is_valid_number, '福島県福島市猫渕');
ok($zip->set_number('9608234')->is_valid_number, '福島県福島市山居');
ok($zip->set_number('9608235')->is_valid_number, '福島県福島市滝元');
ok($zip->set_number('9608236')->is_valid_number, '福島県福島市山際');
ok($zip->set_number('9608237')->is_valid_number, '福島県福島市大森(2-2)');
ok($zip->set_number('9608241')->is_valid_number, '福島県福島市岩ノ前');
ok($zip->set_number('9608242')->is_valid_number, '福島県福島市坂登');
ok($zip->set_number('9608243')->is_valid_number, '福島県福島市岩谷');
ok($zip->set_number('9608244')->is_valid_number, '福島県福島市石田');
ok($zip->set_number('9608251')->is_valid_number, '福島県福島市北沢又');
ok($zip->set_number('9608252')->is_valid_number, '福島県福島市御山');
ok($zip->set_number('9608253')->is_valid_number, '福島県福島市泉');
ok($zip->set_number('9608254')->is_valid_number, '福島県福島市南沢又');
ok($zip->set_number('9610000')->is_valid_number, '福島県白河市以下に掲載がない場合');
ok($zip->set_number('9610000')->is_valid_number, '福島県西白河郡西郷村以下に掲載がない場合');
ok($zip->set_number('9610001')->is_valid_number, '福島県白河市小田川');
ok($zip->set_number('9610002')->is_valid_number, '福島県白河市大和田');
ok($zip->set_number('9610003')->is_valid_number, '福島県白河市泉田');
ok($zip->set_number('9610004')->is_valid_number, '福島県白河市萱根');
ok($zip->set_number('9610005')->is_valid_number, '福島県白河市豊地');
ok($zip->set_number('9610011')->is_valid_number, '福島県白河市久田野');
ok($zip->set_number('9610012')->is_valid_number, '福島県白河市本沼');
ok($zip->set_number('9610013')->is_valid_number, '福島県白河市舟田');
ok($zip->set_number('9610014')->is_valid_number, '福島県白河市借宿');
ok($zip->set_number('9610015')->is_valid_number, '福島県白河市田島');
ok($zip->set_number('9610016')->is_valid_number, '福島県白河市板橋');
ok($zip->set_number('9610017')->is_valid_number, '福島県白河市双石');
ok($zip->set_number('9610021')->is_valid_number, '福島県白河市関辺');
ok($zip->set_number('9610022')->is_valid_number, '福島県白河市南池下');
ok($zip->set_number('9610023')->is_valid_number, '福島県白河市亀石');
ok($zip->set_number('9610024')->is_valid_number, '福島県白河市新夏梨');
ok($zip->set_number('9610025')->is_valid_number, '福島県白河市夏梨');
ok($zip->set_number('9610026')->is_valid_number, '福島県白河市上ノ原');
ok($zip->set_number('9610027')->is_valid_number, '福島県白河市十文字');
ok($zip->set_number('9610031')->is_valid_number, '福島県白河市道東');
ok($zip->set_number('9610032')->is_valid_number, '福島県白河市家ノ前');
ok($zip->set_number('9610033')->is_valid_number, '福島県白河市八幡山');
ok($zip->set_number('9610034')->is_valid_number, '福島県白河市屋敷添');
ok($zip->set_number('9610035')->is_valid_number, '福島県白河市南家ノ前');
ok($zip->set_number('9610036')->is_valid_number, '福島県白河市裏山');
ok($zip->set_number('9610037')->is_valid_number, '福島県白河市新道');
ok($zip->set_number('9610038')->is_valid_number, '福島県白河市旗宿');
ok($zip->set_number('9610039')->is_valid_number, '福島県白河市上野原');
ok($zip->set_number('9610041')->is_valid_number, '福島県白河市結城');
ok($zip->set_number('9610042')->is_valid_number, '福島県白河市金鈴');
ok($zip->set_number('9610043')->is_valid_number, '福島県白河市藤沢');
ok($zip->set_number('9610044')->is_valid_number, '福島県白河市藤沢山');
ok($zip->set_number('9610045')->is_valid_number, '福島県白河市合戦坂');
ok($zip->set_number('9610046')->is_valid_number, '福島県白河市土武塚');
ok($zip->set_number('9610047')->is_valid_number, '福島県白河市八竜神');
ok($zip->set_number('9610051')->is_valid_number, '福島県白河市大');
ok($zip->set_number('9610052')->is_valid_number, '福島県白河市南中川原');
ok($zip->set_number('9610053')->is_valid_number, '福島県白河市中田');
ok($zip->set_number('9610054')->is_valid_number, '福島県白河市北中川原');
ok($zip->set_number('9610061')->is_valid_number, '福島県白河市田中山');
ok($zip->set_number('9610062')->is_valid_number, '福島県白河市外薄葉');
ok($zip->set_number('9610063')->is_valid_number, '福島県白河市薄葉');
ok($zip->set_number('9610064')->is_valid_number, '福島県白河市女石');
ok($zip->set_number('9610065')->is_valid_number, '福島県白河市向寺');
ok($zip->set_number('9610066')->is_valid_number, '福島県白河市羅漢前');
ok($zip->set_number('9610071')->is_valid_number, '福島県白河市士多町東');
ok($zip->set_number('9610072')->is_valid_number, '福島県白河市士多町');
ok($zip->set_number('9610073')->is_valid_number, '福島県白河市田町');
ok($zip->set_number('9610074')->is_valid_number, '福島県白河市郭内');
ok($zip->set_number('9610075')->is_valid_number, '福島県白河市会津町');
ok($zip->set_number('9610076')->is_valid_number, '福島県白河市五番町川原');
ok($zip->set_number('9610077')->is_valid_number, '福島県白河市仁井町');
ok($zip->set_number('9610078')->is_valid_number, '福島県白河市米村道北');
ok($zip->set_number('9610081')->is_valid_number, '福島県白河市飯沢山');
ok($zip->set_number('9610082')->is_valid_number, '福島県白河市飯沢');
ok($zip->set_number('9610083')->is_valid_number, '福島県白河市金勝寺');
ok($zip->set_number('9610084')->is_valid_number, '福島県白河市金勝寺東');
ok($zip->set_number('9610085')->is_valid_number, '福島県白河市町田');
ok($zip->set_number('9610086')->is_valid_number, '福島県白河市鶴巻山');
ok($zip->set_number('9610087')->is_valid_number, '福島県白河市鶴巻');
ok($zip->set_number('9610091')->is_valid_number, '福島県白河市弥次郎窪');
ok($zip->set_number('9610092')->is_valid_number, '福島県白河市六反山');
ok($zip->set_number('9610093')->is_valid_number, '福島県白河市葉ノ木平');
ok($zip->set_number('9610094')->is_valid_number, '福島県白河市追廻');
ok($zip->set_number('9610100')->is_valid_number, '福島県西白河郡中島村以下に掲載がない場合');
ok($zip->set_number('9610101')->is_valid_number, '福島県西白河郡中島村松崎');
ok($zip->set_number('9610102')->is_valid_number, '福島県西白河郡中島村滑津');
ok($zip->set_number('9610103')->is_valid_number, '福島県西白河郡中島村中島');
ok($zip->set_number('9610104')->is_valid_number, '福島県西白河郡中島村吉岡');
ok($zip->set_number('9610105')->is_valid_number, '福島県西白河郡中島村川原田');
ok($zip->set_number('9610106')->is_valid_number, '福島県西白河郡中島村二子塚');
ok($zip->set_number('9610301')->is_valid_number, '福島県白河市東下野出島');
ok($zip->set_number('9610302')->is_valid_number, '福島県白河市東上野出島');
ok($zip->set_number('9610303')->is_valid_number, '福島県白河市東釜子');
ok($zip->set_number('9610304')->is_valid_number, '福島県白河市東工業団地');
ok($zip->set_number('9610305')->is_valid_number, '福島県白河市東千田');
ok($zip->set_number('9610306')->is_valid_number, '福島県白河市東形見');
ok($zip->set_number('9610307')->is_valid_number, '福島県白河市東栃本');
ok($zip->set_number('9610308')->is_valid_number, '福島県白河市東蕪内');
ok($zip->set_number('9610309')->is_valid_number, '福島県白河市東深仁井田');
ok($zip->set_number('9610401')->is_valid_number, '福島県白河市表郷中野');
ok($zip->set_number('9610402')->is_valid_number, '福島県白河市表郷内松');
ok($zip->set_number('9610403')->is_valid_number, '福島県白河市表郷番沢');
ok($zip->set_number('9610404')->is_valid_number, '福島県白河市表郷社田');
ok($zip->set_number('9610405')->is_valid_number, '福島県白河市表郷小松');
ok($zip->set_number('9610406')->is_valid_number, '福島県白河市表郷八幡');
ok($zip->set_number('9610407')->is_valid_number, '福島県白河市表郷中寺');
ok($zip->set_number('9610408')->is_valid_number, '福島県白河市表郷堀之内');
ok($zip->set_number('9610409')->is_valid_number, '福島県白河市表郷河東田');
ok($zip->set_number('9610411')->is_valid_number, '福島県白河市表郷深渡戸');
ok($zip->set_number('9610412')->is_valid_number, '福島県白河市表郷下羽原');
ok($zip->set_number('9610413')->is_valid_number, '福島県白河市表郷三森');
ok($zip->set_number('9610414')->is_valid_number, '福島県白河市表郷高木');
ok($zip->set_number('9610415')->is_valid_number, '福島県白河市表郷梁森');
ok($zip->set_number('9610416')->is_valid_number, '福島県白河市表郷金山');
ok($zip->set_number('9610801')->is_valid_number, '福島県白河市豊年');
ok($zip->set_number('9610802')->is_valid_number, '福島県白河市関川窪');
ok($zip->set_number('9610803')->is_valid_number, '福島県白河市栄町');
ok($zip->set_number('9610804')->is_valid_number, '福島県白河市蛇石');
ok($zip->set_number('9610805')->is_valid_number, '福島県白河市文珠山');
ok($zip->set_number('9610811')->is_valid_number, '福島県白河市菅生舘');
ok($zip->set_number('9610812')->is_valid_number, '福島県白河市南湖');
ok($zip->set_number('9610813')->is_valid_number, '福島県白河市東大沼');
ok($zip->set_number('9610814')->is_valid_number, '福島県白河市三本松山');
ok($zip->set_number('9610815')->is_valid_number, '福島県白河市五郎窪');
ok($zip->set_number('9610816')->is_valid_number, '福島県白河市西大沼');
ok($zip->set_number('9610817')->is_valid_number, '福島県白河市東武塚');
ok($zip->set_number('9610821')->is_valid_number, '福島県白河市北裏');
ok($zip->set_number('9610822')->is_valid_number, '福島県白河市瀬戸原');
ok($zip->set_number('9610823')->is_valid_number, '福島県白河市中島');
ok($zip->set_number('9610824')->is_valid_number, '福島県白河市丸小山');
ok($zip->set_number('9610825')->is_valid_number, '福島県白河市池下向山');
ok($zip->set_number('9610826')->is_valid_number, '福島県白河市池下裏');
ok($zip->set_number('9610827')->is_valid_number, '福島県白河市池下');
ok($zip->set_number('9610828')->is_valid_number, '福島県白河市十三原道下');
ok($zip->set_number('9610829')->is_valid_number, '福島県白河市十三原道上');
ok($zip->set_number('9610831')->is_valid_number, '福島県白河市老久保');
ok($zip->set_number('9610832')->is_valid_number, '福島県白河市西小丸山');
ok($zip->set_number('9610833')->is_valid_number, '福島県白河市東三坂山');
ok($zip->set_number('9610834')->is_valid_number, '福島県白河市西三坂');
ok($zip->set_number('9610835')->is_valid_number, '福島県白河市白坂');
ok($zip->set_number('9610836')->is_valid_number, '福島県白河市みさか');
ok($zip->set_number('9610837')->is_valid_number, '福島県白河市西三坂山');
ok($zip->set_number('9610838')->is_valid_number, '福島県白河市老久保山');
ok($zip->set_number('9610841')->is_valid_number, '福島県白河市古高山');
ok($zip->set_number('9610842')->is_valid_number, '福島県白河市新池');
ok($zip->set_number('9610843')->is_valid_number, '福島県白河市古池');
ok($zip->set_number('9610844')->is_valid_number, '福島県白河市中野山');
ok($zip->set_number('9610845')->is_valid_number, '福島県白河市大坂山');
ok($zip->set_number('9610846')->is_valid_number, '福島県白河市大暮矢見山');
ok($zip->set_number('9610851')->is_valid_number, '福島県白河市南登リ町');
ok($zip->set_number('9610852')->is_valid_number, '福島県白河市転坂');
ok($zip->set_number('9610853')->is_valid_number, '福島県白河市新高山');
ok($zip->set_number('9610854')->is_valid_number, '福島県白河市高山');
ok($zip->set_number('9610855')->is_valid_number, '福島県白河市高山西');
ok($zip->set_number('9610856')->is_valid_number, '福島県白河市新白河');
ok($zip->set_number('9610857')->is_valid_number, '福島県白河市南堀切');
ok($zip->set_number('9610861')->is_valid_number, '福島県白河市風神下');
ok($zip->set_number('9610862')->is_valid_number, '福島県白河市三番町');
ok($zip->set_number('9610863')->is_valid_number, '福島県白河市七番町');
ok($zip->set_number('9610864')->is_valid_number, '福島県白河市風神山東');
ok($zip->set_number('9610865')->is_valid_number, '福島県白河市花見坂');
ok($zip->set_number('9610866')->is_valid_number, '福島県白河市鶴芝');
ok($zip->set_number('9610867')->is_valid_number, '福島県白河市石切場');
ok($zip->set_number('9610871')->is_valid_number, '福島県白河市米山越');
ok($zip->set_number('9610872')->is_valid_number, '福島県白河市三本松');
ok($zip->set_number('9610873')->is_valid_number, '福島県白河市松並');
ok($zip->set_number('9610874')->is_valid_number, '福島県白河市九番町西裏');
ok($zip->set_number('9610875')->is_valid_number, '福島県白河市九番町');
ok($zip->set_number('9610881')->is_valid_number, '福島県白河市与惣小屋');
ok($zip->set_number('9610882')->is_valid_number, '福島県白河市与惣小屋山');
ok($zip->set_number('9610883')->is_valid_number, '福島県白河市東小丸山');
ok($zip->set_number('9610884')->is_valid_number, '福島県白河市鬼越道下');
ok($zip->set_number('9610885')->is_valid_number, '福島県白河市鬼越');
ok($zip->set_number('9610886')->is_valid_number, '福島県白河市影鬼越');
ok($zip->set_number('9610887')->is_valid_number, '福島県白河市鬼越山');
ok($zip->set_number('9610888')->is_valid_number, '福島県白河市十三原');
ok($zip->set_number('9610901')->is_valid_number, '福島県白河市明戸');
ok($zip->set_number('9610902')->is_valid_number, '福島県白河市番士小路');
ok($zip->set_number('9610903')->is_valid_number, '福島県白河市年貢町');
ok($zip->set_number('9610904')->is_valid_number, '福島県白河市馬町裏');
ok($zip->set_number('9610905')->is_valid_number, '福島県白河市本町');
ok($zip->set_number('9610906')->is_valid_number, '福島県白河市本町北裏');
ok($zip->set_number('9610907')->is_valid_number, '福島県白河市横町');
ok($zip->set_number('9610908')->is_valid_number, '福島県白河市大手町');
ok($zip->set_number('9610911')->is_valid_number, '福島県白河市桜町');
ok($zip->set_number('9610912')->is_valid_number, '福島県白河市旭町');
ok($zip->set_number('9610913')->is_valid_number, '福島県白河市鍛冶町');
ok($zip->set_number('9610914')->is_valid_number, '福島県白河市寺小路');
ok($zip->set_number('9610915')->is_valid_number, '福島県白河市馬町下');
ok($zip->set_number('9610916')->is_valid_number, '福島県白河市束前町');
ok($zip->set_number('9610917')->is_valid_number, '福島県白河市八百屋町');
ok($zip->set_number('9610921')->is_valid_number, '福島県白河市円明寺');
ok($zip->set_number('9610922')->is_valid_number, '福島県白河市菖蒲沢');
ok($zip->set_number('9610923')->is_valid_number, '福島県白河市白井掛下');
ok($zip->set_number('9610924')->is_valid_number, '福島県白河市白井掛');
ok($zip->set_number('9610925')->is_valid_number, '福島県白河市向新蔵');
ok($zip->set_number('9610926')->is_valid_number, '福島県白河市友月山');
ok($zip->set_number('9610931')->is_valid_number, '福島県白河市馬町');
ok($zip->set_number('9610932')->is_valid_number, '福島県白河市南町');
ok($zip->set_number('9610933')->is_valid_number, '福島県白河市新蔵町');
ok($zip->set_number('9610934')->is_valid_number, '福島県白河市袋町');
ok($zip->set_number('9610935')->is_valid_number, '福島県白河市手代町');
ok($zip->set_number('9610936')->is_valid_number, '福島県白河市大工町');
ok($zip->set_number('9610937')->is_valid_number, '福島県白河市上ノ台');
ok($zip->set_number('9610941')->is_valid_number, '福島県白河市八幡小路');
ok($zip->set_number('9610942')->is_valid_number, '福島県白河市愛宕町');
ok($zip->set_number('9610943')->is_valid_number, '福島県白河市金屋町');
ok($zip->set_number('9610944')->is_valid_number, '福島県白河市宰領町');
ok($zip->set_number('9610945')->is_valid_number, '福島県白河市巡り矢');
ok($zip->set_number('9610946')->is_valid_number, '福島県白河市二番町');
ok($zip->set_number('9610947')->is_valid_number, '福島県白河市一番町');
ok($zip->set_number('9610951')->is_valid_number, '福島県白河市中町');
ok($zip->set_number('9610952')->is_valid_number, '福島県白河市中町北裏');
ok($zip->set_number('9610953')->is_valid_number, '福島県白河市鷹匠町');
ok($zip->set_number('9610954')->is_valid_number, '福島県白河市天神町');
ok($zip->set_number('9610955')->is_valid_number, '福島県白河市道場町');
ok($zip->set_number('9610956')->is_valid_number, '福島県白河市勘定町');
ok($zip->set_number('9610957')->is_valid_number, '福島県白河市道場小路');
ok($zip->set_number('9610961')->is_valid_number, '福島県白河市四ツ谷');
ok($zip->set_number('9610962')->is_valid_number, '福島県白河市登リ町');
ok($zip->set_number('9610963')->is_valid_number, '福島県白河市日影');
ok($zip->set_number('9610964')->is_valid_number, '福島県白河市日向');
ok($zip->set_number('9610965')->is_valid_number, '福島県白河市細工町');
ok($zip->set_number('9610971')->is_valid_number, '福島県白河市昭和町');
ok($zip->set_number('9610972')->is_valid_number, '福島県白河市立石');
ok($zip->set_number('9610973')->is_valid_number, '福島県白河市北登リ町');
ok($zip->set_number('9610974')->is_valid_number, '福島県白河市北堀切');
ok($zip->set_number('9610975')->is_valid_number, '福島県白河市立石山');
ok($zip->set_number('9610981')->is_valid_number, '福島県白河市北真舟');
ok($zip->set_number('9610982')->is_valid_number, '福島県白河市南真舟');
ok($zip->set_number('9610983')->is_valid_number, '福島県白河市真舟');
ok($zip->set_number('9610984')->is_valid_number, '福島県白河市和尚壇山');
ok($zip->set_number('9610985')->is_valid_number, '福島県白河市和尚壇');
ok($zip->set_number('9610986')->is_valid_number, '福島県白河市塩路山');
ok($zip->set_number('9610991')->is_valid_number, '福島県白河市中山東');
ok($zip->set_number('9610992')->is_valid_number, '福島県白河市南堀川端');
ok($zip->set_number('9610993')->is_valid_number, '福島県白河市中山南');
ok($zip->set_number('9610994')->is_valid_number, '福島県白河市中山下');
ok($zip->set_number('9610995')->is_valid_number, '福島県白河市中山');
ok($zip->set_number('9610996')->is_valid_number, '福島県白河市北堀川端');
ok($zip->set_number('9618001')->is_valid_number, '福島県西白河郡西郷村羽太');
ok($zip->set_number('9618002')->is_valid_number, '福島県白河市大信隈戸(北小萱)');
ok($zip->set_number('9618011')->is_valid_number, '福島県西白河郡西郷村柏野');
ok($zip->set_number('9618021')->is_valid_number, '福島県西白河郡西郷村長坂');
ok($zip->set_number('9618031')->is_valid_number, '福島県西白河郡西郷村米');
ok($zip->set_number('9618041')->is_valid_number, '福島県西白河郡西郷村豊作東');
ok($zip->set_number('9618042')->is_valid_number, '福島県西白河郡西郷村豊作西');
ok($zip->set_number('9618043')->is_valid_number, '福島県西白河郡西郷村石塚南');
ok($zip->set_number('9618044')->is_valid_number, '福島県西白河郡西郷村石塚北');
ok($zip->set_number('9618045')->is_valid_number, '福島県西白河郡西郷村屋敷裏西');
ok($zip->set_number('9618046')->is_valid_number, '福島県西白河郡西郷村屋敷裏東');
ok($zip->set_number('9618047')->is_valid_number, '福島県西白河郡西郷村裏山南');
ok($zip->set_number('9618051')->is_valid_number, '福島県西白河郡西郷村下前田東');
ok($zip->set_number('9618052')->is_valid_number, '福島県西白河郡西郷村道南東');
ok($zip->set_number('9618053')->is_valid_number, '福島県西白河郡西郷村前山東');
ok($zip->set_number('9618054')->is_valid_number, '福島県西白河郡西郷村前山西');
ok($zip->set_number('9618055')->is_valid_number, '福島県西白河郡西郷村道南西');
ok($zip->set_number('9618056')->is_valid_number, '福島県西白河郡西郷村下前田西');
ok($zip->set_number('9618061')->is_valid_number, '福島県西白河郡西郷村小田倉');
ok($zip->set_number('9618071')->is_valid_number, '福島県西白河郡西郷村真船');
ok($zip->set_number('9618081')->is_valid_number, '福島県西白河郡西郷村鶴生');
ok($zip->set_number('9618091')->is_valid_number, '福島県西白河郡西郷村熊倉');
ok($zip->set_number('9620000')->is_valid_number, '福島県須賀川市以下に掲載がない場合');
ok($zip->set_number('9620001')->is_valid_number, '福島県須賀川市森宿');
ok($zip->set_number('9620002')->is_valid_number, '福島県須賀川市上人坦');
ok($zip->set_number('9620003')->is_valid_number, '福島県須賀川市岩瀬森');
ok($zip->set_number('9620004')->is_valid_number, '福島県須賀川市中山');
ok($zip->set_number('9620005')->is_valid_number, '福島県須賀川市台');
ok($zip->set_number('9620006')->is_valid_number, '福島県須賀川市山寺道');
ok($zip->set_number('9620007')->is_valid_number, '福島県須賀川市下宿町');
ok($zip->set_number('9620011')->is_valid_number, '福島県須賀川市坂の上町');
ok($zip->set_number('9620012')->is_valid_number, '福島県須賀川市陣場町');
ok($zip->set_number('9620013')->is_valid_number, '福島県須賀川市岡東町');
ok($zip->set_number('9620014')->is_valid_number, '福島県須賀川市西川町');
ok($zip->set_number('9620015')->is_valid_number, '福島県須賀川市日向町');
ok($zip->set_number('9620016')->is_valid_number, '福島県須賀川市西田町');
ok($zip->set_number('9620017')->is_valid_number, '福島県須賀川市西の内町');
ok($zip->set_number('9620021')->is_valid_number, '福島県須賀川市館取町');
ok($zip->set_number('9620022')->is_valid_number, '福島県須賀川市丸田町');
ok($zip->set_number('9620023')->is_valid_number, '福島県須賀川市大黒町');
ok($zip->set_number('9620024')->is_valid_number, '福島県須賀川市稲荷町');
ok($zip->set_number('9620025')->is_valid_number, '福島県須賀川市八幡山');
ok($zip->set_number('9620026')->is_valid_number, '福島県須賀川市岩崎');
ok($zip->set_number('9620027')->is_valid_number, '福島県須賀川市堀底町');
ok($zip->set_number('9620028')->is_valid_number, '福島県須賀川市茶畑町');
ok($zip->set_number('9620031')->is_valid_number, '福島県須賀川市影沼町');
ok($zip->set_number('9620032')->is_valid_number, '福島県須賀川市大袋町');
ok($zip->set_number('9620033')->is_valid_number, '福島県須賀川市岩作');
ok($zip->set_number('9620034')->is_valid_number, '福島県須賀川市一里坦');
ok($zip->set_number('9620035')->is_valid_number, '福島県須賀川市五月雨');
ok($zip->set_number('9620036')->is_valid_number, '福島県須賀川市芹沢町');
ok($zip->set_number('9620041')->is_valid_number, '福島県須賀川市横山町');
ok($zip->set_number('9620042')->is_valid_number, '福島県須賀川市稲');
ok($zip->set_number('9620043')->is_valid_number, '福島県須賀川市岩渕');
ok($zip->set_number('9620044')->is_valid_number, '福島県須賀川市池下');
ok($zip->set_number('9620045')->is_valid_number, '福島県須賀川市保土原');
ok($zip->set_number('9620046')->is_valid_number, '福島県須賀川市泉田');
ok($zip->set_number('9620047')->is_valid_number, '福島県須賀川市松塚');
ok($zip->set_number('9620051')->is_valid_number, '福島県須賀川市越久');
ok($zip->set_number('9620052')->is_valid_number, '福島県須賀川市西川');
ok($zip->set_number('9620053')->is_valid_number, '福島県須賀川市卸町');
ok($zip->set_number('9620054')->is_valid_number, '福島県須賀川市牛袋町');
ok($zip->set_number('9620055')->is_valid_number, '福島県須賀川市新町');
ok($zip->set_number('9620056')->is_valid_number, '福島県須賀川市大桑原');
ok($zip->set_number('9620057')->is_valid_number, '福島県須賀川市袋田');
ok($zip->set_number('9620058')->is_valid_number, '福島県須賀川市池ノ下町');
ok($zip->set_number('9620059')->is_valid_number, '福島県須賀川市吉美根');
ok($zip->set_number('9620061')->is_valid_number, '福島県須賀川市北山寺町');
ok($zip->set_number('9620062')->is_valid_number, '福島県須賀川市山寺町');
ok($zip->set_number('9620063')->is_valid_number, '福島県須賀川市西山寺町');
ok($zip->set_number('9620121')->is_valid_number, '福島県須賀川市横田');
ok($zip->set_number('9620122')->is_valid_number, '福島県須賀川市木之崎');
ok($zip->set_number('9620123')->is_valid_number, '福島県須賀川市矢田野');
ok($zip->set_number('9620124')->is_valid_number, '福島県須賀川市桙衝');
ok($zip->set_number('9620125')->is_valid_number, '福島県須賀川市堀込');
ok($zip->set_number('9620126')->is_valid_number, '福島県須賀川市花の里');
ok($zip->set_number('9620201')->is_valid_number, '福島県須賀川市志茂');
ok($zip->set_number('9620202')->is_valid_number, '福島県須賀川市小中');
ok($zip->set_number('9620203')->is_valid_number, '福島県須賀川市長沼');
ok($zip->set_number('9620204')->is_valid_number, '福島県須賀川市江花');
ok($zip->set_number('9620205')->is_valid_number, '福島県須賀川市勢至堂');
ok($zip->set_number('9620211')->is_valid_number, '福島県須賀川市滝(赤土、雁田、北久保、白砂、白砂山、大新畑、大日前、滝西、チャクの下、');
ok($zip->set_number('9620211')->is_valid_number, '福島県須賀川市日向前、本郷、前田)');
ok($zip->set_number('9620301')->is_valid_number, '福島県須賀川市今泉');
ok($zip->set_number('9620302')->is_valid_number, '福島県須賀川市柱田');
ok($zip->set_number('9620303')->is_valid_number, '福島県須賀川市梅田');
ok($zip->set_number('9620304')->is_valid_number, '福島県須賀川市滝(その他)');
ok($zip->set_number('9620305')->is_valid_number, '福島県須賀川市守屋');
ok($zip->set_number('9620311')->is_valid_number, '福島県須賀川市矢沢');
ok($zip->set_number('9620312')->is_valid_number, '福島県須賀川市大久保');
ok($zip->set_number('9620313')->is_valid_number, '福島県須賀川市北横田');
ok($zip->set_number('9620314')->is_valid_number, '福島県須賀川市深渡戸');
ok($zip->set_number('9620315')->is_valid_number, '福島県須賀川市畑田');
ok($zip->set_number('9620401')->is_valid_number, '福島県須賀川市向陽町');
ok($zip->set_number('9620402')->is_valid_number, '福島県須賀川市仁井田');
ok($zip->set_number('9620403')->is_valid_number, '福島県須賀川市滑川');
ok($zip->set_number('9620404')->is_valid_number, '福島県須賀川市舘ケ岡');
ok($zip->set_number('9620405')->is_valid_number, '福島県須賀川市季の郷');
ok($zip->set_number('9620406')->is_valid_number, '福島県須賀川市宮の杜');
ok($zip->set_number('9620500')->is_valid_number, '福島県岩瀬郡天栄村以下に掲載がない場合');
ok($zip->set_number('9620501')->is_valid_number, '福島県岩瀬郡天栄村牧之内');
ok($zip->set_number('9620502')->is_valid_number, '福島県岩瀬郡天栄村上松本');
ok($zip->set_number('9620503')->is_valid_number, '福島県岩瀬郡天栄村下松本');
ok($zip->set_number('9620504')->is_valid_number, '福島県岩瀬郡天栄村大里');
ok($zip->set_number('9620511')->is_valid_number, '福島県岩瀬郡天栄村白子');
ok($zip->set_number('9620512')->is_valid_number, '福島県岩瀬郡天栄村飯豊');
ok($zip->set_number('9620513')->is_valid_number, '福島県岩瀬郡天栄村沖内');
ok($zip->set_number('9620514')->is_valid_number, '福島県岩瀬郡天栄村柿之内');
ok($zip->set_number('9620515')->is_valid_number, '福島県岩瀬郡天栄村高林');
ok($zip->set_number('9620516')->is_valid_number, '福島県岩瀬郡天栄村小川');
ok($zip->set_number('9620621')->is_valid_number, '福島県岩瀬郡天栄村湯本');
ok($zip->set_number('9620622')->is_valid_number, '福島県岩瀬郡天栄村田良尾');
ok($zip->set_number('9620623')->is_valid_number, '福島県岩瀬郡天栄村羽鳥');
ok($zip->set_number('9620711')->is_valid_number, '福島県須賀川市塩田');
ok($zip->set_number('9620712')->is_valid_number, '福島県須賀川市小倉');
ok($zip->set_number('9620713')->is_valid_number, '福島県須賀川市上小山田');
ok($zip->set_number('9620714')->is_valid_number, '福島県須賀川市下小山田');
ok($zip->set_number('9620721')->is_valid_number, '福島県須賀川市雨田');
ok($zip->set_number('9620722')->is_valid_number, '福島県須賀川市大栗');
ok($zip->set_number('9620723')->is_valid_number, '福島県須賀川市狸森');
ok($zip->set_number('9620724')->is_valid_number, '福島県須賀川市田中');
ok($zip->set_number('9620725')->is_valid_number, '福島県須賀川市日照田');
ok($zip->set_number('9620726')->is_valid_number, '福島県須賀川市市野関');
ok($zip->set_number('9620727')->is_valid_number, '福島県須賀川市小作田');
ok($zip->set_number('9620728')->is_valid_number, '福島県須賀川市虹の台');
ok($zip->set_number('9620801')->is_valid_number, '福島県須賀川市江持');
ok($zip->set_number('9620802')->is_valid_number, '福島県須賀川市堤');
ok($zip->set_number('9620803')->is_valid_number, '福島県須賀川市古河');
ok($zip->set_number('9620804')->is_valid_number, '福島県須賀川市中曽根');
ok($zip->set_number('9620805')->is_valid_number, '福島県須賀川市崩免');
ok($zip->set_number('9620806')->is_valid_number, '福島県須賀川市下宿前');
ok($zip->set_number('9620807')->is_valid_number, '福島県須賀川市境免');
ok($zip->set_number('9620811')->is_valid_number, '福島県須賀川市あおば町');
ok($zip->set_number('9620812')->is_valid_number, '福島県須賀川市浜尾');
ok($zip->set_number('9620813')->is_valid_number, '福島県須賀川市和田');
ok($zip->set_number('9620814')->is_valid_number, '福島県須賀川市前田川');
ok($zip->set_number('9620815')->is_valid_number, '福島県須賀川市牡丹園');
ok($zip->set_number('9620816')->is_valid_number, '福島県須賀川市朝日田');
ok($zip->set_number('9620817')->is_valid_number, '福島県須賀川市南上町');
ok($zip->set_number('9620818')->is_valid_number, '福島県須賀川市和田道');
ok($zip->set_number('9620821')->is_valid_number, '福島県須賀川市桜岡');
ok($zip->set_number('9620822')->is_valid_number, '福島県須賀川市東作');
ok($zip->set_number('9620823')->is_valid_number, '福島県須賀川市花岡');
ok($zip->set_number('9620824')->is_valid_number, '福島県須賀川市新田');
ok($zip->set_number('9620825')->is_valid_number, '福島県須賀川市六軒');
ok($zip->set_number('9620826')->is_valid_number, '福島県須賀川市広表');
ok($zip->set_number('9620827')->is_valid_number, '福島県須賀川市寺田');
ok($zip->set_number('9620831')->is_valid_number, '福島県須賀川市八幡町');
ok($zip->set_number('9620832')->is_valid_number, '福島県須賀川市本町');
ok($zip->set_number('9620833')->is_valid_number, '福島県須賀川市馬町');
ok($zip->set_number('9620834')->is_valid_number, '福島県須賀川市旭町');
ok($zip->set_number('9620835')->is_valid_number, '福島県須賀川市千日堂');
ok($zip->set_number('9620836')->is_valid_number, '福島県須賀川市並木町');
ok($zip->set_number('9620837')->is_valid_number, '福島県須賀川市高久田境');
ok($zip->set_number('9620838')->is_valid_number, '福島県須賀川市南町');
ok($zip->set_number('9620839')->is_valid_number, '福島県須賀川市大町');
ok($zip->set_number('9620841')->is_valid_number, '福島県須賀川市上北町');
ok($zip->set_number('9620842')->is_valid_number, '福島県須賀川市宮先町');
ok($zip->set_number('9620843')->is_valid_number, '福島県須賀川市池上町');
ok($zip->set_number('9620844')->is_valid_number, '福島県須賀川市東町');
ok($zip->set_number('9620845')->is_valid_number, '福島県須賀川市中町');
ok($zip->set_number('9620846')->is_valid_number, '福島県須賀川市加治町');
ok($zip->set_number('9620847')->is_valid_number, '福島県須賀川市諏訪町');
ok($zip->set_number('9620848')->is_valid_number, '福島県須賀川市弘法坦');
ok($zip->set_number('9620851')->is_valid_number, '福島県須賀川市中宿');
ok($zip->set_number('9620852')->is_valid_number, '福島県須賀川市仲の町');
ok($zip->set_number('9620853')->is_valid_number, '福島県須賀川市前川');
ok($zip->set_number('9620854')->is_valid_number, '福島県須賀川市古屋敷');
ok($zip->set_number('9620855')->is_valid_number, '福島県須賀川市守谷舘');
ok($zip->set_number('9620856')->is_valid_number, '福島県須賀川市北町');
ok($zip->set_number('9620857')->is_valid_number, '福島県須賀川市長禄町');
ok($zip->set_number('9620858')->is_valid_number, '福島県須賀川市栄町');
ok($zip->set_number('9620859')->is_valid_number, '福島県須賀川市塚田');
ok($zip->set_number('9620861')->is_valid_number, '福島県須賀川市古舘');
ok($zip->set_number('9620862')->is_valid_number, '福島県須賀川市六郎兵衛');
ok($zip->set_number('9620863')->is_valid_number, '福島県須賀川市緑町');
ok($zip->set_number('9620864')->is_valid_number, '福島県須賀川市北上町');
ok($zip->set_number('9620865')->is_valid_number, '福島県須賀川市妙見');
ok($zip->set_number('9620866')->is_valid_number, '福島県須賀川市栗谷沢');
ok($zip->set_number('9620867')->is_valid_number, '福島県須賀川市愛宕山');
ok($zip->set_number('9620868')->is_valid_number, '福島県須賀川市芦田塚');
ok($zip->set_number('9630000')->is_valid_number, '福島県郡山市以下に掲載がない場合');
ok($zip->set_number('9630101')->is_valid_number, '福島県郡山市安積町日出山');
ok($zip->set_number('9630102')->is_valid_number, '福島県郡山市安積町笹川');
ok($zip->set_number('9630103')->is_valid_number, '福島県郡山市安積町大森町');
ok($zip->set_number('9630104')->is_valid_number, '福島県郡山市安積町南長久保');
ok($zip->set_number('9630105')->is_valid_number, '福島県郡山市安積町長久保');
ok($zip->set_number('9630106')->is_valid_number, '福島県郡山市成山町');
ok($zip->set_number('9630107')->is_valid_number, '福島県郡山市安積');
ok($zip->set_number('9630108')->is_valid_number, '福島県郡山市笹川');
ok($zip->set_number('9630109')->is_valid_number, '福島県郡山市安積町吉田');
ok($zip->set_number('9630111')->is_valid_number, '福島県郡山市安積町荒井');
ok($zip->set_number('9630112')->is_valid_number, '福島県郡山市安積町成田');
ok($zip->set_number('9630113')->is_valid_number, '福島県郡山市安積町牛庭');
ok($zip->set_number('9630114')->is_valid_number, '福島県郡山市安積町(柴宮東)');
ok($zip->set_number('9630115')->is_valid_number, '福島県郡山市南');
ok($zip->set_number('9630116')->is_valid_number, '福島県郡山市安積荒井本町');
ok($zip->set_number('9630117')->is_valid_number, '福島県郡山市安積荒井');
ok($zip->set_number('9630118')->is_valid_number, '福島県郡山市安積北井');
ok($zip->set_number('9630119')->is_valid_number, '福島県郡山市巳六段');
ok($zip->set_number('9630121')->is_valid_number, '福島県郡山市三穂田町川田');
ok($zip->set_number('9630122')->is_valid_number, '福島県郡山市三穂田町野田');
ok($zip->set_number('9630123')->is_valid_number, '福島県郡山市三穂田町鍋山');
ok($zip->set_number('9630124')->is_valid_number, '福島県郡山市三穂田町下守屋');
ok($zip->set_number('9630125')->is_valid_number, '福島県郡山市三穂田町富岡');
ok($zip->set_number('9630126')->is_valid_number, '福島県郡山市三穂田町山口');
ok($zip->set_number('9630127')->is_valid_number, '福島県郡山市三穂田町大谷');
ok($zip->set_number('9630128')->is_valid_number, '福島県郡山市三穂田町駒屋');
ok($zip->set_number('9630129')->is_valid_number, '福島県郡山市三穂田町八幡');
ok($zip->set_number('9630201')->is_valid_number, '福島県郡山市大槻町');
ok($zip->set_number('9630202')->is_valid_number, '福島県郡山市柏山町');
ok($zip->set_number('9630203')->is_valid_number, '福島県郡山市静町');
ok($zip->set_number('9630204')->is_valid_number, '福島県郡山市土瓜');
ok($zip->set_number('9630205')->is_valid_number, '福島県郡山市堤');
ok($zip->set_number('9630206')->is_valid_number, '福島県郡山市中野');
ok($zip->set_number('9630207')->is_valid_number, '福島県郡山市鳴神');
ok($zip->set_number('9630208')->is_valid_number, '福島県郡山市谷地');
ok($zip->set_number('9630209')->is_valid_number, '福島県郡山市御前南');
ok($zip->set_number('9630211')->is_valid_number, '福島県郡山市片平町');
ok($zip->set_number('9630212')->is_valid_number, '福島県郡山市逢瀬町河内');
ok($zip->set_number('9630213')->is_valid_number, '福島県郡山市逢瀬町多田野');
ok($zip->set_number('9630214')->is_valid_number, '福島県郡山市逢瀬町夏出');
ok($zip->set_number('9630215')->is_valid_number, '福島県郡山市待池台');
ok($zip->set_number('9630216')->is_valid_number, '福島県郡山市中ノ目');
ok($zip->set_number('9630221')->is_valid_number, '福島県郡山市亀田西');
ok($zip->set_number('9630231')->is_valid_number, '福島県郡山市谷地本町');
ok($zip->set_number('9630232')->is_valid_number, '福島県郡山市静西');
ok($zip->set_number('9630531')->is_valid_number, '福島県郡山市日和田町高倉');
ok($zip->set_number('9630532')->is_valid_number, '福島県郡山市日和田町梅沢');
ok($zip->set_number('9630533')->is_valid_number, '福島県郡山市日和田町八丁目');
ok($zip->set_number('9630534')->is_valid_number, '福島県郡山市日和田町');
ok($zip->set_number('9630541')->is_valid_number, '福島県郡山市喜久田町堀之内');
ok($zip->set_number('9630542')->is_valid_number, '福島県郡山市喜久田町原');
ok($zip->set_number('9630543')->is_valid_number, '福島県郡山市喜久田町前田沢');
ok($zip->set_number('9630544')->is_valid_number, '福島県郡山市喜久田町坪沢');
ok($zip->set_number('9630545')->is_valid_number, '福島県郡山市喜久田町赤坂');
ok($zip->set_number('9630546')->is_valid_number, '福島県郡山市喜久田町早稲原');
ok($zip->set_number('9630547')->is_valid_number, '福島県郡山市喜久田町卸');
ok($zip->set_number('9630551')->is_valid_number, '福島県郡山市喜久田町');
ok($zip->set_number('9630552')->is_valid_number, '福島県郡山市東原');
ok($zip->set_number('9630661')->is_valid_number, '福島県郡山市舞木町');
ok($zip->set_number('9630662')->is_valid_number, '福島県郡山市白岩町');
ok($zip->set_number('9630663')->is_valid_number, '福島県郡山市下白岩町');
ok($zip->set_number('9630664')->is_valid_number, '福島県郡山市あぶくま台');
ok($zip->set_number('9630665')->is_valid_number, '福島県郡山市横川町');
ok($zip->set_number('9630666')->is_valid_number, '福島県郡山市安原町');
ok($zip->set_number('9630667')->is_valid_number, '福島県郡山市阿久津町');
ok($zip->set_number('9630671')->is_valid_number, '福島県郡山市富久山町南小泉');
ok($zip->set_number('9630672')->is_valid_number, '福島県郡山市富久山町北小泉');
ok($zip->set_number('9630673')->is_valid_number, '福島県郡山市富久山町堂坂');
ok($zip->set_number('9630701')->is_valid_number, '福島県郡山市緑ケ丘西');
ok($zip->set_number('9630702')->is_valid_number, '福島県郡山市緑ケ丘東');
ok($zip->set_number('9630703')->is_valid_number, '福島県郡山市蒲倉町');
ok($zip->set_number('9630704')->is_valid_number, '福島県郡山市荒井町');
ok($zip->set_number('9630711')->is_valid_number, '福島県郡山市中田町上石');
ok($zip->set_number('9630712')->is_valid_number, '福島県郡山市中田町海老根');
ok($zip->set_number('9630713')->is_valid_number, '福島県郡山市中田町高倉');
ok($zip->set_number('9630714')->is_valid_number, '福島県郡山市中田町赤沼');
ok($zip->set_number('9630721')->is_valid_number, '福島県郡山市田村町手代木');
ok($zip->set_number('9630722')->is_valid_number, '福島県郡山市田村町小川');
ok($zip->set_number('9630723')->is_valid_number, '福島県郡山市田村町桜ケ丘');
ok($zip->set_number('9630724')->is_valid_number, '福島県郡山市田村町上行合');
ok($zip->set_number('9630725')->is_valid_number, '福島県郡山市田村町金屋');
ok($zip->set_number('9630726')->is_valid_number, '福島県郡山市田村町下行合');
ok($zip->set_number('9630831')->is_valid_number, '福島県郡山市中田町柳橋');
ok($zip->set_number('9630832')->is_valid_number, '福島県郡山市中田町中津川');
ok($zip->set_number('9630833')->is_valid_number, '福島県郡山市中田町下枝');
ok($zip->set_number('9630834')->is_valid_number, '福島県郡山市中田町牛縊本郷');
ok($zip->set_number('9630835')->is_valid_number, '福島県郡山市中田町黒木');
ok($zip->set_number('9630836')->is_valid_number, '福島県郡山市中田町木目沢');
ok($zip->set_number('9630837')->is_valid_number, '福島県郡山市中田町駒板');
ok($zip->set_number('9630901')->is_valid_number, '福島県郡山市西田町丹伊田');
ok($zip->set_number('9630902')->is_valid_number, '福島県郡山市西田町高柴');
ok($zip->set_number('9630903')->is_valid_number, '福島県郡山市西田町板橋');
ok($zip->set_number('9630904')->is_valid_number, '福島県郡山市西田町土棚');
ok($zip->set_number('9630911')->is_valid_number, '福島県郡山市西田町大田');
ok($zip->set_number('9630912')->is_valid_number, '福島県郡山市西田町根木屋');
ok($zip->set_number('9630913')->is_valid_number, '福島県郡山市西田町芹沢');
ok($zip->set_number('9630914')->is_valid_number, '福島県郡山市西田町木村');
ok($zip->set_number('9630921')->is_valid_number, '福島県郡山市西田町鬼生田');
ok($zip->set_number('9630922')->is_valid_number, '福島県郡山市西田町三町目');
ok($zip->set_number('9630923')->is_valid_number, '福島県郡山市西田町黒田');
ok($zip->set_number('9630924')->is_valid_number, '福島県郡山市西田町大網');
ok($zip->set_number('9630925')->is_valid_number, '福島県郡山市西田町阿広木');
ok($zip->set_number('9631151')->is_valid_number, '福島県郡山市田村町金沢');
ok($zip->set_number('9631152')->is_valid_number, '福島県郡山市田村町細田');
ok($zip->set_number('9631153')->is_valid_number, '福島県郡山市田村町大供');
ok($zip->set_number('9631154')->is_valid_number, '福島県郡山市田村町岩作');
ok($zip->set_number('9631155')->is_valid_number, '福島県郡山市田村町守山');
ok($zip->set_number('9631156')->is_valid_number, '福島県郡山市田村町東山');
ok($zip->set_number('9631161')->is_valid_number, '福島県郡山市田村町大善寺');
ok($zip->set_number('9631162')->is_valid_number, '福島県郡山市田村町山中');
ok($zip->set_number('9631163')->is_valid_number, '福島県郡山市田村町正直');
ok($zip->set_number('9631164')->is_valid_number, '福島県郡山市田村町御代田');
ok($zip->set_number('9631165')->is_valid_number, '福島県郡山市田村町徳定');
ok($zip->set_number('9631241')->is_valid_number, '福島県郡山市田村町川曲');
ok($zip->set_number('9631242')->is_valid_number, '福島県郡山市田村町糠塚');
ok($zip->set_number('9631243')->is_valid_number, '福島県郡山市田村町田母神');
ok($zip->set_number('9631244')->is_valid_number, '福島県郡山市田村町栃本');
ok($zip->set_number('9631245')->is_valid_number, '福島県郡山市田村町栃山神');
ok($zip->set_number('9631246')->is_valid_number, '福島県郡山市田村町谷田川');
ok($zip->set_number('9631247')->is_valid_number, '福島県郡山市田村町下道渡');
ok($zip->set_number('9631248')->is_valid_number, '福島県郡山市田村町上道渡');
ok($zip->set_number('9631301')->is_valid_number, '福島県郡山市熱海町石筵');
ok($zip->set_number('9631302')->is_valid_number, '福島県郡山市熱海町高玉');
ok($zip->set_number('9631303')->is_valid_number, '福島県郡山市熱海町玉川');
ok($zip->set_number('9631304')->is_valid_number, '福島県郡山市熱海町安子島');
ok($zip->set_number('9631305')->is_valid_number, '福島県郡山市熱海町下伊豆島');
ok($zip->set_number('9631306')->is_valid_number, '福島県郡山市熱海町上伊豆島');
ok($zip->set_number('9631307')->is_valid_number, '福島県郡山市熱海町長橋');
ok($zip->set_number('9631308')->is_valid_number, '福島県郡山市熱海町中山');
ok($zip->set_number('9631309')->is_valid_number, '福島県郡山市熱海町熱海');
ok($zip->set_number('9631311')->is_valid_number, '福島県郡山市上伊豆島');
ok($zip->set_number('9631411')->is_valid_number, '福島県郡山市湖南町舟津');
ok($zip->set_number('9631412')->is_valid_number, '福島県郡山市湖南町舘');
ok($zip->set_number('9631413')->is_valid_number, '福島県郡山市湖南町横沢');
ok($zip->set_number('9631414')->is_valid_number, '福島県郡山市湖南町浜路');
ok($zip->set_number('9631521')->is_valid_number, '福島県郡山市湖南町中野');
ok($zip->set_number('9631522')->is_valid_number, '福島県郡山市湖南町三代');
ok($zip->set_number('9631631')->is_valid_number, '福島県郡山市湖南町赤津');
ok($zip->set_number('9631632')->is_valid_number, '福島県郡山市湖南町馬入新田');
ok($zip->set_number('9631633')->is_valid_number, '福島県郡山市湖南町福良');
ok($zip->set_number('9633311')->is_valid_number, '福島県田村郡小野町湯沢');
ok($zip->set_number('9633312')->is_valid_number, '福島県田村郡小野町夏井');
ok($zip->set_number('9633313')->is_valid_number, '福島県田村郡小野町南田原井');
ok($zip->set_number('9633314')->is_valid_number, '福島県田村郡小野町塩庭');
ok($zip->set_number('9633315')->is_valid_number, '福島県田村郡小野町和名田');
ok($zip->set_number('9633316')->is_valid_number, '福島県田村郡小野町上羽出庭');
ok($zip->set_number('9633400')->is_valid_number, '福島県田村郡小野町以下に掲載がない場合');
ok($zip->set_number('9633401')->is_valid_number, '福島県田村郡小野町小野新町');
ok($zip->set_number('9633402')->is_valid_number, '福島県田村郡小野町谷津作');
ok($zip->set_number('9633403')->is_valid_number, '福島県田村郡小野町小野赤沼');
ok($zip->set_number('9633404')->is_valid_number, '福島県田村郡小野町菖蒲谷');
ok($zip->set_number('9633405')->is_valid_number, '福島県田村郡小野町雁股田');
ok($zip->set_number('9633406')->is_valid_number, '福島県田村郡小野町皮籠石');
ok($zip->set_number('9633521')->is_valid_number, '福島県田村郡小野町飯豊');
ok($zip->set_number('9633522')->is_valid_number, '福島県田村郡小野町小戸神');
ok($zip->set_number('9633523')->is_valid_number, '福島県田村郡小野町小野山神');
ok($zip->set_number('9633524')->is_valid_number, '福島県田村郡小野町浮金');
ok($zip->set_number('9633525')->is_valid_number, '福島県田村郡小野町吉野辺');
ok($zip->set_number('9633601')->is_valid_number, '福島県田村市滝根町菅谷');
ok($zip->set_number('9633602')->is_valid_number, '福島県田村市滝根町神俣');
ok($zip->set_number('9633603')->is_valid_number, '福島県田村市滝根町広瀬');
ok($zip->set_number('9634111')->is_valid_number, '福島県田村市大越町上大越');
ok($zip->set_number('9634112')->is_valid_number, '福島県田村市大越町下大越');
ok($zip->set_number('9634113')->is_valid_number, '福島県田村市大越町早稲川');
ok($zip->set_number('9634114')->is_valid_number, '福島県田村市大越町牧野');
ok($zip->set_number('9634115')->is_valid_number, '福島県田村市大越町栗出');
ok($zip->set_number('9634201')->is_valid_number, '福島県田村市船引町永谷');
ok($zip->set_number('9634202')->is_valid_number, '福島県田村市船引町椚山');
ok($zip->set_number('9634203')->is_valid_number, '福島県田村市船引町門沢');
ok($zip->set_number('9634204')->is_valid_number, '福島県田村市船引町堀越');
ok($zip->set_number('9634205')->is_valid_number, '福島県田村市船引町遠山沢');
ok($zip->set_number('9634300')->is_valid_number, '福島県田村市以下に掲載がない場合');
ok($zip->set_number('9634311')->is_valid_number, '福島県田村市船引町今泉');
ok($zip->set_number('9634312')->is_valid_number, '福島県田村市船引町船引');
ok($zip->set_number('9634313')->is_valid_number, '福島県田村市船引町石森');
ok($zip->set_number('9634314')->is_valid_number, '福島県田村市船引町文珠');
ok($zip->set_number('9634315')->is_valid_number, '福島県田村市船引町春山');
ok($zip->set_number('9634316')->is_valid_number, '福島県田村市船引町芦沢');
ok($zip->set_number('9634317')->is_valid_number, '福島県田村市船引町東部台');
ok($zip->set_number('9634318')->is_valid_number, '福島県田村市船引町光陽台');
ok($zip->set_number('9634321')->is_valid_number, '福島県田村市船引町笹山');
ok($zip->set_number('9634322')->is_valid_number, '福島県田村市船引町荒和田');
ok($zip->set_number('9634323')->is_valid_number, '福島県田村市船引町要田');
ok($zip->set_number('9634324')->is_valid_number, '福島県田村市船引町成田');
ok($zip->set_number('9634431')->is_valid_number, '福島県田村市船引町石沢');
ok($zip->set_number('9634432')->is_valid_number, '福島県田村市船引町長外路');
ok($zip->set_number('9634433')->is_valid_number, '福島県田村市船引町北鹿又');
ok($zip->set_number('9634434')->is_valid_number, '福島県田村市船引町門鹿');
ok($zip->set_number('9634435')->is_valid_number, '福島県田村市船引町大倉');
ok($zip->set_number('9634436')->is_valid_number, '福島県田村市船引町新舘');
ok($zip->set_number('9634541')->is_valid_number, '福島県田村市船引町上移');
ok($zip->set_number('9634542')->is_valid_number, '福島県田村市船引町横道');
ok($zip->set_number('9634543')->is_valid_number, '福島県田村市船引町中山');
ok($zip->set_number('9634544')->is_valid_number, '福島県田村市船引町南移');
ok($zip->set_number('9634545')->is_valid_number, '福島県田村市船引町北移');
ok($zip->set_number('9634601')->is_valid_number, '福島県田村市常葉町山根');
ok($zip->set_number('9634602')->is_valid_number, '福島県田村市常葉町常葉');
ok($zip->set_number('9634603')->is_valid_number, '福島県田村市常葉町西向');
ok($zip->set_number('9634604')->is_valid_number, '福島県田村市常葉町鹿山');
ok($zip->set_number('9634605')->is_valid_number, '福島県田村市常葉町久保');
ok($zip->set_number('9634606')->is_valid_number, '福島県田村市常葉町新田作');
ok($zip->set_number('9634611')->is_valid_number, '福島県田村市常葉町堀田');
ok($zip->set_number('9634612')->is_valid_number, '福島県田村市常葉町早稲川');
ok($zip->set_number('9634613')->is_valid_number, '福島県田村市常葉町関本');
ok($zip->set_number('9634614')->is_valid_number, '福島県田村市常葉町小桧山');
ok($zip->set_number('9634701')->is_valid_number, '福島県田村市都路町古道');
ok($zip->set_number('9634702')->is_valid_number, '福島県田村市都路町岩井沢');
ok($zip->set_number('9635100')->is_valid_number, '福島県東白川郡矢祭町以下に掲載がない場合');
ok($zip->set_number('9635111')->is_valid_number, '福島県東白川郡矢祭町金沢');
ok($zip->set_number('9635112')->is_valid_number, '福島県東白川郡矢祭町宝坂');
ok($zip->set_number('9635113')->is_valid_number, '福島県東白川郡矢祭町下関河内');
ok($zip->set_number('9635114')->is_valid_number, '福島県東白川郡矢祭町大ぬかり');
ok($zip->set_number('9635115')->is_valid_number, '福島県東白川郡矢祭町上関河内');
ok($zip->set_number('9635116')->is_valid_number, '福島県東白川郡矢祭町高野');
ok($zip->set_number('9635117')->is_valid_number, '福島県東白川郡矢祭町山下');
ok($zip->set_number('9635118')->is_valid_number, '福島県東白川郡矢祭町東舘');
ok($zip->set_number('9635119')->is_valid_number, '福島県東白川郡矢祭町小田川');
ok($zip->set_number('9635201')->is_valid_number, '福島県東白川郡矢祭町中石井');
ok($zip->set_number('9635202')->is_valid_number, '福島県東白川郡矢祭町下石井');
ok($zip->set_number('9635203')->is_valid_number, '福島県東白川郡矢祭町戸塚');
ok($zip->set_number('9635321')->is_valid_number, '福島県東白川郡矢祭町関岡');
ok($zip->set_number('9635322')->is_valid_number, '福島県東白川郡矢祭町内川');
ok($zip->set_number('9635323')->is_valid_number, '福島県東白川郡矢祭町茗荷');
ok($zip->set_number('9635341')->is_valid_number, '福島県東白川郡塙町台宿');
ok($zip->set_number('9635342')->is_valid_number, '福島県東白川郡塙町伊香');
ok($zip->set_number('9635343')->is_valid_number, '福島県東白川郡塙町植田');
ok($zip->set_number('9635344')->is_valid_number, '福島県東白川郡塙町真名畑');
ok($zip->set_number('9635400')->is_valid_number, '福島県東白川郡塙町以下に掲載がない場合');
ok($zip->set_number('9635401')->is_valid_number, '福島県東白川郡塙町東河内');
ok($zip->set_number('9635402')->is_valid_number, '福島県東白川郡塙町常世北野');
ok($zip->set_number('9635403')->is_valid_number, '福島県東白川郡塙町常世中野');
ok($zip->set_number('9635404')->is_valid_number, '福島県東白川郡塙町竹之内');
ok($zip->set_number('9635405')->is_valid_number, '福島県東白川郡塙町塙');
ok($zip->set_number('9635406')->is_valid_number, '福島県東白川郡塙町上渋井');
ok($zip->set_number('9635407')->is_valid_number, '福島県東白川郡塙町西河内');
ok($zip->set_number('9635408')->is_valid_number, '福島県東白川郡塙町堀越');
ok($zip->set_number('9635411')->is_valid_number, '福島県東白川郡塙町上石井');
ok($zip->set_number('9635505')->is_valid_number, '福島県東白川郡鮫川村渡瀬(越虫68)');
ok($zip->set_number('9635521')->is_valid_number, '福島県東白川郡塙町那倉');
ok($zip->set_number('9635522')->is_valid_number, '福島県東白川郡塙町片貝');
ok($zip->set_number('9635531')->is_valid_number, '福島県東白川郡塙町田代');
ok($zip->set_number('9635532')->is_valid_number, '福島県東白川郡塙町大蕨');
ok($zip->set_number('9635533')->is_valid_number, '福島県東白川郡塙町湯岐');
ok($zip->set_number('9635534')->is_valid_number, '福島県東白川郡塙町木野反');
ok($zip->set_number('9635535')->is_valid_number, '福島県東白川郡塙町山形');
ok($zip->set_number('9635536')->is_valid_number, '福島県東白川郡塙町川上');
ok($zip->set_number('9635537')->is_valid_number, '福島県東白川郡塙町板庭');
ok($zip->set_number('9635538')->is_valid_number, '福島県東白川郡塙町中塚');
ok($zip->set_number('9635539')->is_valid_number, '福島県東白川郡塙町田野作');
ok($zip->set_number('9635661')->is_valid_number, '福島県東白川郡棚倉町山田');
ok($zip->set_number('9635662')->is_valid_number, '福島県東白川郡棚倉町岡田');
ok($zip->set_number('9635663')->is_valid_number, '福島県東白川郡棚倉町流');
ok($zip->set_number('9635664')->is_valid_number, '福島県東白川郡棚倉町塚原');
ok($zip->set_number('9635671')->is_valid_number, '福島県東白川郡棚倉町寺山');
ok($zip->set_number('9635672')->is_valid_number, '福島県東白川郡棚倉町八槻');
ok($zip->set_number('9635681')->is_valid_number, '福島県東白川郡棚倉町上手沢');
ok($zip->set_number('9635682')->is_valid_number, '福島県東白川郡棚倉町下手沢');
ok($zip->set_number('9635683')->is_valid_number, '福島県東白川郡棚倉町下山本');
ok($zip->set_number('9635684')->is_valid_number, '福島県東白川郡棚倉町中山本');
ok($zip->set_number('9635685')->is_valid_number, '福島県東白川郡棚倉町北山本');
ok($zip->set_number('9636100')->is_valid_number, '福島県東白川郡棚倉町以下に掲載がない場合');
ok($zip->set_number('9636101')->is_valid_number, '福島県東白川郡棚倉町堤');
ok($zip->set_number('9636102')->is_valid_number, '福島県東白川郡棚倉町天王内');
ok($zip->set_number('9636103')->is_valid_number, '福島県東白川郡棚倉町逆川');
ok($zip->set_number('9636104')->is_valid_number, '福島県東白川郡棚倉町檜木');
ok($zip->set_number('9636105')->is_valid_number, '福島県東白川郡棚倉町小菅生');
ok($zip->set_number('9636106')->is_valid_number, '福島県東白川郡棚倉町金沢内');
ok($zip->set_number('9636111')->is_valid_number, '福島県東白川郡棚倉町一色');
ok($zip->set_number('9636112')->is_valid_number, '福島県東白川郡棚倉町玉野');
ok($zip->set_number('9636113')->is_valid_number, '福島県東白川郡棚倉町板橋');
ok($zip->set_number('9636114')->is_valid_number, '福島県東白川郡棚倉町上台');
ok($zip->set_number('9636115')->is_valid_number, '福島県東白川郡棚倉町福井');
ok($zip->set_number('9636121')->is_valid_number, '福島県東白川郡棚倉町花園');
ok($zip->set_number('9636122')->is_valid_number, '福島県東白川郡棚倉町仁公儀');
ok($zip->set_number('9636123')->is_valid_number, '福島県東白川郡棚倉町関口');
ok($zip->set_number('9636131')->is_valid_number, '福島県東白川郡棚倉町棚倉');
ok($zip->set_number('9636141')->is_valid_number, '福島県東白川郡棚倉町富岡');
ok($zip->set_number('9636142')->is_valid_number, '福島県東白川郡棚倉町山際');
ok($zip->set_number('9636143')->is_valid_number, '福島県東白川郡棚倉町福岡');
ok($zip->set_number('9636144')->is_valid_number, '福島県東白川郡棚倉町強梨');
ok($zip->set_number('9636145')->is_valid_number, '福島県東白川郡棚倉町大梅');
ok($zip->set_number('9636146')->is_valid_number, '福島県東白川郡棚倉町戸中');
ok($zip->set_number('9636147')->is_valid_number, '福島県東白川郡棚倉町漆草');
ok($zip->set_number('9636151')->is_valid_number, '福島県東白川郡棚倉町祝部内');
ok($zip->set_number('9636152')->is_valid_number, '福島県東白川郡棚倉町小爪');
ok($zip->set_number('9636153')->is_valid_number, '福島県東白川郡棚倉町瀬ケ野');
ok($zip->set_number('9636200')->is_valid_number, '福島県石川郡浅川町以下に掲載がない場合');
ok($zip->set_number('9636201')->is_valid_number, '福島県石川郡浅川町福貴作');
ok($zip->set_number('9636202')->is_valid_number, '福島県石川郡浅川町里白石');
ok($zip->set_number('9636203')->is_valid_number, '福島県石川郡浅川町山白石');
ok($zip->set_number('9636204')->is_valid_number, '福島県石川郡浅川町浅川');
ok($zip->set_number('9636205')->is_valid_number, '福島県石川郡浅川町滝輪');
ok($zip->set_number('9636206')->is_valid_number, '福島県石川郡浅川町太田輪');
ok($zip->set_number('9636207')->is_valid_number, '福島県石川郡浅川町小貫');
ok($zip->set_number('9636208')->is_valid_number, '福島県石川郡浅川町染');
ok($zip->set_number('9636211')->is_valid_number, '福島県石川郡浅川町畑田');
ok($zip->set_number('9636212')->is_valid_number, '福島県石川郡浅川町松野入');
ok($zip->set_number('9636213')->is_valid_number, '福島県石川郡浅川町中里');
ok($zip->set_number('9636214')->is_valid_number, '福島県石川郡浅川町大草');
ok($zip->set_number('9636215')->is_valid_number, '福島県石川郡浅川町根岸');
ok($zip->set_number('9636216')->is_valid_number, '福島県石川郡浅川町袖山');
ok($zip->set_number('9636217')->is_valid_number, '福島県石川郡浅川町簑輪');
ok($zip->set_number('9636218')->is_valid_number, '福島県石川郡浅川町東大畑');
ok($zip->set_number('9636300')->is_valid_number, '福島県石川郡玉川村以下に掲載がない場合');
ok($zip->set_number('9636301')->is_valid_number, '福島県石川郡玉川村四辻新田');
ok($zip->set_number('9636302')->is_valid_number, '福島県石川郡玉川村南須釜');
ok($zip->set_number('9636303')->is_valid_number, '福島県石川郡玉川村吉');
ok($zip->set_number('9636304')->is_valid_number, '福島県石川郡玉川村北須釜');
ok($zip->set_number('9636305')->is_valid_number, '福島県石川郡玉川村山小屋');
ok($zip->set_number('9636306')->is_valid_number, '福島県石川郡玉川村山新田');
ok($zip->set_number('9636311')->is_valid_number, '福島県石川郡玉川村岩法寺');
ok($zip->set_number('9636312')->is_valid_number, '福島県石川郡玉川村小高');
ok($zip->set_number('9636313')->is_valid_number, '福島県石川郡玉川村川辺');
ok($zip->set_number('9636314')->is_valid_number, '福島県石川郡玉川村蒜生');
ok($zip->set_number('9636315')->is_valid_number, '福島県石川郡玉川村中');
ok($zip->set_number('9636316')->is_valid_number, '福島県石川郡玉川村竜崎');
ok($zip->set_number('9637700')->is_valid_number, '福島県田村郡三春町以下に掲載がない場合');
ok($zip->set_number('9637701')->is_valid_number, '福島県田村郡三春町実沢');
ok($zip->set_number('9637702')->is_valid_number, '福島県田村郡三春町青石');
ok($zip->set_number('9637703')->is_valid_number, '福島県田村郡三春町庄司');
ok($zip->set_number('9637704')->is_valid_number, '福島県田村郡三春町熊耳');
ok($zip->set_number('9637705')->is_valid_number, '福島県田村郡三春町天王下');
ok($zip->set_number('9637706')->is_valid_number, '福島県田村郡三春町大平');
ok($zip->set_number('9637707')->is_valid_number, '福島県田村郡三春町芹ケ沢');
ok($zip->set_number('9637708')->is_valid_number, '福島県田村郡三春町栗林');
ok($zip->set_number('9637709')->is_valid_number, '福島県田村郡三春町小滝');
ok($zip->set_number('9637711')->is_valid_number, '福島県田村郡三春町桜ケ丘');
ok($zip->set_number('9637712')->is_valid_number, '福島県田村郡三春町込木');
ok($zip->set_number('9637712')->is_valid_number, '福島県田村郡三春町八方谷');
ok($zip->set_number('9637712')->is_valid_number, '福島県田村郡三春町楽内');
ok($zip->set_number('9637713')->is_valid_number, '福島県田村郡三春町柴原');
ok($zip->set_number('9637714')->is_valid_number, '福島県田村郡三春町滝');
ok($zip->set_number('9637715')->is_valid_number, '福島県田村郡三春町樋渡');
ok($zip->set_number('9637716')->is_valid_number, '福島県田村郡三春町根本');
ok($zip->set_number('9637716')->is_valid_number, '福島県田村郡三春町蛇石');
ok($zip->set_number('9637717')->is_valid_number, '福島県田村郡三春町狐田');
ok($zip->set_number('9637718')->is_valid_number, '福島県田村郡三春町過足');
ok($zip->set_number('9637719')->is_valid_number, '福島県田村郡三春町貝山');
ok($zip->set_number('9637721')->is_valid_number, '福島県田村郡三春町春沢');
ok($zip->set_number('9637721')->is_valid_number, '福島県田村郡三春町春田');
ok($zip->set_number('9637721')->is_valid_number, '福島県田村郡三春町蛇沢');
ok($zip->set_number('9637722')->is_valid_number, '福島県田村郡三春町西方');
ok($zip->set_number('9637723')->is_valid_number, '福島県田村郡三春町斎藤');
ok($zip->set_number('9637724')->is_valid_number, '福島県田村郡三春町沼沢');
ok($zip->set_number('9637725')->is_valid_number, '福島県田村郡三春町鷹巣');
ok($zip->set_number('9637726')->is_valid_number, '福島県田村郡三春町沼之倉');
ok($zip->set_number('9637731')->is_valid_number, '福島県田村郡三春町下舞木');
ok($zip->set_number('9637732')->is_valid_number, '福島県田村郡三春町上舞木');
ok($zip->set_number('9637733')->is_valid_number, '福島県田村郡三春町山田');
ok($zip->set_number('9637741')->is_valid_number, '福島県田村郡三春町鎌田前');
ok($zip->set_number('9637741')->is_valid_number, '福島県田村郡三春町天王前');
ok($zip->set_number('9637741')->is_valid_number, '福島県田村郡三春町八島台');
ok($zip->set_number('9637742')->is_valid_number, '福島県田村郡三春町鶴蒔田');
ok($zip->set_number('9637743')->is_valid_number, '福島県田村郡三春町丈六');
ok($zip->set_number('9637744')->is_valid_number, '福島県田村郡三春町八幡町');
ok($zip->set_number('9637745')->is_valid_number, '福島県田村郡三春町尼ケ谷');
ok($zip->set_number('9637746')->is_valid_number, '福島県田村郡三春町馬場');
ok($zip->set_number('9637747')->is_valid_number, '福島県田村郡三春町雁木田');
ok($zip->set_number('9637748')->is_valid_number, '福島県田村郡三春町山崎');
ok($zip->set_number('9637749')->is_valid_number, '福島県田村郡三春町一本松');
ok($zip->set_number('9637749')->is_valid_number, '福島県田村郡三春町大久保');
ok($zip->set_number('9637751')->is_valid_number, '福島県田村郡三春町北町');
ok($zip->set_number('9637752')->is_valid_number, '福島県田村郡三春町烏帽子石');
ok($zip->set_number('9637752')->is_valid_number, '福島県田村郡三春町亀井');
ok($zip->set_number('9637752')->is_valid_number, '福島県田村郡三春町清水畑');
ok($zip->set_number('9637752')->is_valid_number, '福島県田村郡三春町仁井町');
ok($zip->set_number('9637752')->is_valid_number, '福島県田村郡三春町六升蒔');
ok($zip->set_number('9637753')->is_valid_number, '福島県田村郡三春町赤坂');
ok($zip->set_number('9637753')->is_valid_number, '福島県田村郡三春町師範場');
ok($zip->set_number('9637753')->is_valid_number, '福島県田村郡三春町清水');
ok($zip->set_number('9637753')->is_valid_number, '福島県田村郡三春町永作');
ok($zip->set_number('9637753')->is_valid_number, '福島県田村郡三春町八十内');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町恵下越');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町化粧坂');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町庚申坂');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町四軒丁');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町新町');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町番組');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町番組頭');
ok($zip->set_number('9637754')->is_valid_number, '福島県田村郡三春町弓町');
ok($zip->set_number('9637755')->is_valid_number, '福島県田村郡三春町山中');
ok($zip->set_number('9637756')->is_valid_number, '福島県田村郡三春町南町');
ok($zip->set_number('9637757')->is_valid_number, '福島県田村郡三春町会下谷');
ok($zip->set_number('9637758')->is_valid_number, '福島県田村郡三春町小金滝');
ok($zip->set_number('9637758')->is_valid_number, '福島県田村郡三春町桜谷');
ok($zip->set_number('9637759')->is_valid_number, '福島県田村郡三春町大町');
ok($zip->set_number('9637761')->is_valid_number, '福島県田村郡三春町四反田');
ok($zip->set_number('9637761')->is_valid_number, '福島県田村郡三春町樋ノ口');
ok($zip->set_number('9637762')->is_valid_number, '福島県田村郡三春町小浜海道');
ok($zip->set_number('9637763')->is_valid_number, '福島県田村郡三春町燕清水');
ok($zip->set_number('9637763')->is_valid_number, '福島県田村郡三春町日向町');
ok($zip->set_number('9637763')->is_valid_number, '福島県田村郡三春町持合畑');
ok($zip->set_number('9637764')->is_valid_number, '福島県田村郡三春町北向町');
ok($zip->set_number('9637765')->is_valid_number, '福島県田村郡三春町荒町');
ok($zip->set_number('9637766')->is_valid_number, '福島県田村郡三春町中町');
ok($zip->set_number('9637767')->is_valid_number, '福島県田村郡三春町御免町');
ok($zip->set_number('9637768')->is_valid_number, '福島県田村郡三春町渋池');
ok($zip->set_number('9637769')->is_valid_number, '福島県田村郡三春町担橋');
ok($zip->set_number('9637771')->is_valid_number, '福島県田村郡三春町平沢');
ok($zip->set_number('9637772')->is_valid_number, '福島県田村郡三春町御祭');
ok($zip->set_number('9637773')->is_valid_number, '福島県田村郡三春町深田和');
ok($zip->set_number('9637781')->is_valid_number, '福島県田村郡三春町北成田');
ok($zip->set_number('9637782')->is_valid_number, '福島県田村郡三春町富沢');
ok($zip->set_number('9637783')->is_valid_number, '福島県田村郡三春町南成田');
ok($zip->set_number('9637784')->is_valid_number, '福島県田村郡三春町六斗蒔');
ok($zip->set_number('9637785')->is_valid_number, '福島県田村郡三春町松橋');
ok($zip->set_number('9637786')->is_valid_number, '福島県田村郡三春町七草木');
ok($zip->set_number('9637800')->is_valid_number, '福島県石川郡石川町以下に掲載がない場合');
ok($zip->set_number('9637801')->is_valid_number, '福島県石川郡石川町湯郷渡');
ok($zip->set_number('9637802')->is_valid_number, '福島県石川郡石川町北山');
ok($zip->set_number('9637803')->is_valid_number, '福島県石川郡石川町中田');
ok($zip->set_number('9637804')->is_valid_number, '福島県石川郡石川町坂路');
ok($zip->set_number('9637805')->is_valid_number, '福島県石川郡石川町谷地');
ok($zip->set_number('9637806')->is_valid_number, '福島県石川郡石川町谷沢');
ok($zip->set_number('9637807')->is_valid_number, '福島県石川郡石川町形見');
ok($zip->set_number('9637808')->is_valid_number, '福島県石川郡石川町双里');
ok($zip->set_number('9637811')->is_valid_number, '福島県石川郡石川町北山形');
ok($zip->set_number('9637812')->is_valid_number, '福島県石川郡石川町南山形');
ok($zip->set_number('9637813')->is_valid_number, '福島県石川郡石川町板橋');
ok($zip->set_number('9637814')->is_valid_number, '福島県石川郡石川町山形');
ok($zip->set_number('9637815')->is_valid_number, '福島県石川郡石川町大沢');
ok($zip->set_number('9637816')->is_valid_number, '福島県石川郡石川町豆ケ平');
ok($zip->set_number('9637817')->is_valid_number, '福島県石川郡石川町立ケ岡');
ok($zip->set_number('9637818')->is_valid_number, '福島県石川郡石川町塩沼');
ok($zip->set_number('9637821')->is_valid_number, '福島県石川郡石川町宝殿前');
ok($zip->set_number('9637822')->is_valid_number, '福島県石川郡石川町梁瀬');
ok($zip->set_number('9637823')->is_valid_number, '福島県石川郡石川町王子平');
ok($zip->set_number('9637824')->is_valid_number, '福島県石川郡石川町原');
ok($zip->set_number('9637825')->is_valid_number, '福島県石川郡石川町沢井');
ok($zip->set_number('9637826')->is_valid_number, '福島県石川郡石川町赤羽');
ok($zip->set_number('9637827')->is_valid_number, '福島県石川郡石川町新屋敷(その他)');
ok($zip->set_number('9637828')->is_valid_number, '福島県石川郡石川町下ノ内');
ok($zip->set_number('9637831')->is_valid_number, '福島県石川郡石川町母畑');
ok($zip->set_number('9637832')->is_valid_number, '福島県石川郡石川町弥吾');
ok($zip->set_number('9637833')->is_valid_number, '福島県石川郡石川町石田');
ok($zip->set_number('9637834')->is_valid_number, '福島県石川郡石川町轡取');
ok($zip->set_number('9637835')->is_valid_number, '福島県石川郡石川町草倉田');
ok($zip->set_number('9637836')->is_valid_number, '福島県石川郡石川町塩沢');
ok($zip->set_number('9637837')->is_valid_number, '福島県石川郡石川町中野');
ok($zip->set_number('9637838')->is_valid_number, '福島県石川郡石川町曲木');
ok($zip->set_number('9637841')->is_valid_number, '福島県石川郡石川町江堀田');
ok($zip->set_number('9637842')->is_valid_number, '福島県石川郡石川町境ノ内');
ok($zip->set_number('9637843')->is_valid_number, '福島県石川郡石川町屋敷ノ入');
ok($zip->set_number('9637844')->is_valid_number, '福島県石川郡石川町北町');
ok($zip->set_number('9637845')->is_valid_number, '福島県石川郡石川町高田');
ok($zip->set_number('9637846')->is_valid_number, '福島県石川郡石川町長久保');
ok($zip->set_number('9637847')->is_valid_number, '福島県石川郡石川町古舘');
ok($zip->set_number('9637848')->is_valid_number, '福島県石川郡石川町長郷田');
ok($zip->set_number('9637849')->is_valid_number, '福島県石川郡石川町一ノ沢');
ok($zip->set_number('9637851')->is_valid_number, '福島県石川郡石川町新町');
ok($zip->set_number('9637852')->is_valid_number, '福島県石川郡石川町関根');
ok($zip->set_number('9637853')->is_valid_number, '福島県石川郡石川町大室');
ok($zip->set_number('9637854')->is_valid_number, '福島県石川郡石川町松木下');
ok($zip->set_number('9637855')->is_valid_number, '福島県石川郡石川町猫啼');
ok($zip->set_number('9637856')->is_valid_number, '福島県石川郡石川町白石');
ok($zip->set_number('9637857')->is_valid_number, '福島県石川郡石川町当町');
ok($zip->set_number('9637858')->is_valid_number, '福島県石川郡石川町下泉');
ok($zip->set_number('9637859')->is_valid_number, '福島県石川郡石川町南町');
ok($zip->set_number('9637861')->is_valid_number, '福島県石川郡石川町矢ノ目田');
ok($zip->set_number('9637862')->is_valid_number, '福島県石川郡石川町鹿ノ坂');
ok($zip->set_number('9637863')->is_valid_number, '福島県石川郡石川町渡里沢');
ok($zip->set_number('9637864')->is_valid_number, '福島県石川郡石川町秋台');
ok($zip->set_number('9637865')->is_valid_number, '福島県石川郡石川町曲ノ内');
ok($zip->set_number('9637866')->is_valid_number, '福島県石川郡石川町外国見');
ok($zip->set_number('9637867')->is_valid_number, '福島県石川郡石川町石塚');
ok($zip->set_number('9637871')->is_valid_number, '福島県石川郡石川町前ノ内');
ok($zip->set_number('9637872')->is_valid_number, '福島県石川郡石川町大内');
ok($zip->set_number('9637873')->is_valid_number, '福島県石川郡石川町飛ケ作');
ok($zip->set_number('9637874')->is_valid_number, '福島県石川郡石川町大五郎内');
ok($zip->set_number('9637875')->is_valid_number, '福島県石川郡石川町柳作');
ok($zip->set_number('9637876')->is_valid_number, '福島県石川郡石川町国見');
ok($zip->set_number('9637881')->is_valid_number, '福島県石川郡石川町大橋');
ok($zip->set_number('9637882')->is_valid_number, '福島県石川郡石川町塩ノ平');
ok($zip->set_number('9637883')->is_valid_number, '福島県石川郡石川町麦ノ内');
ok($zip->set_number('9637884')->is_valid_number, '福島県石川郡石川町新屋敷(番地)');
ok($zip->set_number('9637885')->is_valid_number, '福島県石川郡石川町成亀');
ok($zip->set_number('9637886')->is_valid_number, '福島県石川郡石川町和久');
ok($zip->set_number('9638001')->is_valid_number, '福島県郡山市大町');
ok($zip->set_number('9638002')->is_valid_number, '福島県郡山市駅前');
ok($zip->set_number('9638003')->is_valid_number, '福島県郡山市燧田');
ok($zip->set_number('9638004')->is_valid_number, '福島県郡山市中町');
ok($zip->set_number('9638005')->is_valid_number, '福島県郡山市清水台');
ok($zip->set_number('9638006')->is_valid_number, '福島県郡山市赤木町');
ok($zip->set_number('9638007')->is_valid_number, '福島県郡山市大名艮');
ok($zip->set_number('9638008')->is_valid_number, '福島県郡山市東宿');
ok($zip->set_number('9638011')->is_valid_number, '福島県郡山市若葉町');
ok($zip->set_number('9638012')->is_valid_number, '福島県郡山市咲田');
ok($zip->set_number('9638013')->is_valid_number, '福島県郡山市神明町');
ok($zip->set_number('9638014')->is_valid_number, '福島県郡山市虎丸町');
ok($zip->set_number('9638015')->is_valid_number, '福島県郡山市細沼町');
ok($zip->set_number('9638016')->is_valid_number, '福島県郡山市豊田町');
ok($zip->set_number('9638017')->is_valid_number, '福島県郡山市長者');
ok($zip->set_number('9638018')->is_valid_number, '福島県郡山市桃見台');
ok($zip->set_number('9638021')->is_valid_number, '福島県郡山市桜木');
ok($zip->set_number('9638022')->is_valid_number, '福島県郡山市西ノ内');
ok($zip->set_number('9638023')->is_valid_number, '福島県郡山市緑町');
ok($zip->set_number('9638024')->is_valid_number, '福島県郡山市朝日');
ok($zip->set_number('9638025')->is_valid_number, '福島県郡山市桑野');
ok($zip->set_number('9638026')->is_valid_number, '福島県郡山市並木');
ok($zip->set_number('9638031')->is_valid_number, '福島県郡山市上亀田');
ok($zip->set_number('9638032')->is_valid_number, '福島県郡山市下亀田');
ok($zip->set_number('9638033')->is_valid_number, '福島県郡山市亀田');
ok($zip->set_number('9638034')->is_valid_number, '福島県郡山市島');
ok($zip->set_number('9638035')->is_valid_number, '福島県郡山市希望ケ丘');
ok($zip->set_number('9638036')->is_valid_number, '福島県郡山市うねめ町');
ok($zip->set_number('9638037')->is_valid_number, '福島県郡山市原中');
ok($zip->set_number('9638038')->is_valid_number, '福島県郡山市桑野北町');
ok($zip->set_number('9638039')->is_valid_number, '福島県郡山市小関谷地');
ok($zip->set_number('9638041')->is_valid_number, '福島県郡山市富田町');
ok($zip->set_number('9638042')->is_valid_number, '福島県郡山市不動前');
ok($zip->set_number('9638043')->is_valid_number, '福島県郡山市名郷田');
ok($zip->set_number('9638044')->is_valid_number, '福島県郡山市備前舘');
ok($zip->set_number('9638045')->is_valid_number, '福島県郡山市新屋敷');
ok($zip->set_number('9638046')->is_valid_number, '福島県郡山市町東');
ok($zip->set_number('9638047')->is_valid_number, '福島県郡山市富田東');
ok($zip->set_number('9638051')->is_valid_number, '福島県郡山市富久山町八山田');
ok($zip->set_number('9638052')->is_valid_number, '福島県郡山市八山田');
ok($zip->set_number('9638053')->is_valid_number, '福島県郡山市八山田西');
ok($zip->set_number('9638061')->is_valid_number, '福島県郡山市富久山町福原');
ok($zip->set_number('9638071')->is_valid_number, '福島県郡山市富久山町久保田');
ok($zip->set_number('9638100')->is_valid_number, '福島県石川郡平田村以下に掲載がない場合');
ok($zip->set_number('9638111')->is_valid_number, '福島県石川郡平田村東山');
ok($zip->set_number('9638112')->is_valid_number, '福島県石川郡平田村北方');
ok($zip->set_number('9638113')->is_valid_number, '福島県石川郡平田村駒形');
ok($zip->set_number('9638114')->is_valid_number, '福島県石川郡平田村小平');
ok($zip->set_number('9638115')->is_valid_number, '福島県石川郡平田村中倉');
ok($zip->set_number('9638116')->is_valid_number, '福島県石川郡平田村西山');
ok($zip->set_number('9638201')->is_valid_number, '福島県石川郡平田村蓬田新田');
ok($zip->set_number('9638202')->is_valid_number, '福島県石川郡平田村上蓬田');
ok($zip->set_number('9638203')->is_valid_number, '福島県石川郡平田村九生滝');
ok($zip->set_number('9638204')->is_valid_number, '福島県石川郡平田村鴇子');
ok($zip->set_number('9638205')->is_valid_number, '福島県石川郡平田村永田');
ok($zip->set_number('9638206')->is_valid_number, '福島県石川郡平田村小松原');
ok($zip->set_number('9638207')->is_valid_number, '福島県石川郡平田村下蓬田');
ok($zip->set_number('9638300')->is_valid_number, '福島県石川郡古殿町以下に掲載がない場合');
ok($zip->set_number('9638301')->is_valid_number, '福島県石川郡古殿町論田');
ok($zip->set_number('9638302')->is_valid_number, '福島県石川郡古殿町山上');
ok($zip->set_number('9638303')->is_valid_number, '福島県石川郡古殿町大久田');
ok($zip->set_number('9638304')->is_valid_number, '福島県石川郡古殿町松川');
ok($zip->set_number('9638305')->is_valid_number, '福島県石川郡古殿町竹貫');
ok($zip->set_number('9638306')->is_valid_number, '福島県石川郡古殿町田口');
ok($zip->set_number('9638307')->is_valid_number, '福島県石川郡古殿町鎌田');
ok($zip->set_number('9638308')->is_valid_number, '福島県石川郡古殿町仙石');
ok($zip->set_number('9638400')->is_valid_number, '福島県東白川郡鮫川村以下に掲載がない場合');
ok($zip->set_number('9638401')->is_valid_number, '福島県東白川郡鮫川村赤坂中野');
ok($zip->set_number('9638402')->is_valid_number, '福島県東白川郡鮫川村石井草');
ok($zip->set_number('9638403')->is_valid_number, '福島県東白川郡鮫川村赤坂東野');
ok($zip->set_number('9638404')->is_valid_number, '福島県東白川郡鮫川村青生野');
ok($zip->set_number('9638405')->is_valid_number, '福島県東白川郡鮫川村渡瀬(その他)');
ok($zip->set_number('9638406')->is_valid_number, '福島県東白川郡鮫川村富田');
ok($zip->set_number('9638407')->is_valid_number, '福島県東白川郡鮫川村赤坂西野');
ok($zip->set_number('9638408')->is_valid_number, '福島県東白川郡鮫川村西山');
ok($zip->set_number('9638801')->is_valid_number, '福島県郡山市向河原町');
ok($zip->set_number('9638802')->is_valid_number, '福島県郡山市谷島町');
ok($zip->set_number('9638803')->is_valid_number, '福島県郡山市横塚');
ok($zip->set_number('9638804')->is_valid_number, '福島県郡山市北畑');
ok($zip->set_number('9638805')->is_valid_number, '福島県郡山市古屋敷');
ok($zip->set_number('9638806')->is_valid_number, '福島県郡山市下舘野');
ok($zip->set_number('9638807')->is_valid_number, '福島県郡山市佐野良');
ok($zip->set_number('9638811')->is_valid_number, '福島県郡山市方八町');
ok($zip->set_number('9638812')->is_valid_number, '福島県郡山市松木町');
ok($zip->set_number('9638813')->is_valid_number, '福島県郡山市芳賀');
ok($zip->set_number('9638814')->is_valid_number, '福島県郡山市石渕町');
ok($zip->set_number('9638815')->is_valid_number, '福島県郡山市水門町');
ok($zip->set_number('9638816')->is_valid_number, '福島県郡山市上野山');
ok($zip->set_number('9638817')->is_valid_number, '福島県郡山市大平町');
ok($zip->set_number('9638818')->is_valid_number, '福島県郡山市十貫河原');
ok($zip->set_number('9638821')->is_valid_number, '福島県郡山市菱田町');
ok($zip->set_number('9638822')->is_valid_number, '福島県郡山市昭和');
ok($zip->set_number('9638823')->is_valid_number, '福島県郡山市古川');
ok($zip->set_number('9638824')->is_valid_number, '福島県郡山市道場');
ok($zip->set_number('9638825')->is_valid_number, '福島県郡山市石塚');
ok($zip->set_number('9638826')->is_valid_number, '福島県郡山市船場向');
ok($zip->set_number('9638827')->is_valid_number, '福島県郡山市外河原');
ok($zip->set_number('9638828')->is_valid_number, '福島県郡山市大河原');
ok($zip->set_number('9638829')->is_valid_number, '福島県郡山市榧の木');
ok($zip->set_number('9638831')->is_valid_number, '福島県郡山市七ツ池町');
ok($zip->set_number('9638832')->is_valid_number, '福島県郡山市山根町');
ok($zip->set_number('9638833')->is_valid_number, '福島県郡山市香久池');
ok($zip->set_number('9638834')->is_valid_number, '福島県郡山市図景');
ok($zip->set_number('9638835')->is_valid_number, '福島県郡山市小原田');
ok($zip->set_number('9638836')->is_valid_number, '福島県郡山市八作内');
ok($zip->set_number('9638837')->is_valid_number, '福島県郡山市八木橋');
ok($zip->set_number('9638838')->is_valid_number, '福島県郡山市深田台');
ok($zip->set_number('9638841')->is_valid_number, '福島県郡山市山崎');
ok($zip->set_number('9638842')->is_valid_number, '福島県郡山市城清水');
ok($zip->set_number('9638843')->is_valid_number, '福島県郡山市川向');
ok($zip->set_number('9638844')->is_valid_number, '福島県郡山市賀庄');
ok($zip->set_number('9638845')->is_valid_number, '福島県郡山市名倉');
ok($zip->set_number('9638846')->is_valid_number, '福島県郡山市久留米');
ok($zip->set_number('9638851')->is_valid_number, '福島県郡山市開成');
ok($zip->set_number('9638852')->is_valid_number, '福島県郡山市台新');
ok($zip->set_number('9638861')->is_valid_number, '福島県郡山市鶴見坦');
ok($zip->set_number('9638862')->is_valid_number, '福島県郡山市菜根');
ok($zip->set_number('9638863')->is_valid_number, '福島県郡山市菜根屋敷');
ok($zip->set_number('9638864')->is_valid_number, '福島県郡山市台東');
ok($zip->set_number('9638865')->is_valid_number, '福島県郡山市五百渕西');
ok($zip->set_number('9638866')->is_valid_number, '福島県郡山市桑野清水台');
ok($zip->set_number('9638867')->is_valid_number, '福島県郡山市五百渕山');
ok($zip->set_number('9638871')->is_valid_number, '福島県郡山市晴門田');
ok($zip->set_number('9638871')->is_valid_number, '福島県郡山市本町');
ok($zip->set_number('9638872')->is_valid_number, '福島県郡山市栄町');
ok($zip->set_number('9638873')->is_valid_number, '福島県郡山市愛宕町');
ok($zip->set_number('9638874')->is_valid_number, '福島県郡山市深沢');
ok($zip->set_number('9638875')->is_valid_number, '福島県郡山市池ノ台');
ok($zip->set_number('9638876')->is_valid_number, '福島県郡山市麓山');
ok($zip->set_number('9638877')->is_valid_number, '福島県郡山市堂前町');
ok($zip->set_number('9638878')->is_valid_number, '福島県郡山市堤下町');
ok($zip->set_number('9640000')->is_valid_number, '福島県二本松市以下に掲載がない場合');
ok($zip->set_number('9640001')->is_valid_number, '福島県二本松市中ノ目');
ok($zip->set_number('9640002')->is_valid_number, '福島県二本松市湯川町');
ok($zip->set_number('9640003')->is_valid_number, '福島県二本松市二伊滝');
ok($zip->set_number('9640004')->is_valid_number, '福島県二本松市伊佐沼町');
ok($zip->set_number('9640005')->is_valid_number, '福島県二本松市笹屋');
ok($zip->set_number('9640006')->is_valid_number, '福島県二本松市二又');
ok($zip->set_number('9640007')->is_valid_number, '福島県二本松市古家');
ok($zip->set_number('9640008')->is_valid_number, '福島県二本松市鉄扇町');
ok($zip->set_number('9640011')->is_valid_number, '福島県二本松市永田才木');
ok($zip->set_number('9640012')->is_valid_number, '福島県二本松市永田積内');
ok($zip->set_number('9640013')->is_valid_number, '福島県二本松市新田');
ok($zip->set_number('9640014')->is_valid_number, '福島県二本松市上新田');
ok($zip->set_number('9640015')->is_valid_number, '福島県二本松市板目沢');
ok($zip->set_number('9640016')->is_valid_number, '福島県二本松市大森沢');
ok($zip->set_number('9640017')->is_valid_number, '福島県二本松市永田御堂内');
ok($zip->set_number('9640021')->is_valid_number, '福島県二本松市永田馬保内');
ok($zip->set_number('9640022')->is_valid_number, '福島県二本松市永田鍛治内');
ok($zip->set_number('9640023')->is_valid_number, '福島県二本松市硯石');
ok($zip->set_number('9640024')->is_valid_number, '福島県二本松市井戸神');
ok($zip->set_number('9640025')->is_valid_number, '福島県二本松市屋戸入');
ok($zip->set_number('9640026')->is_valid_number, '福島県二本松市中山田');
ok($zip->set_number('9640027')->is_valid_number, '福島県二本松市山田');
ok($zip->set_number('9640028')->is_valid_number, '福島県二本松市高平');
ok($zip->set_number('9640029')->is_valid_number, '福島県二本松市永田');
ok($zip->set_number('9640031')->is_valid_number, '福島県二本松市前原');
ok($zip->set_number('9640032')->is_valid_number, '福島県二本松市毘沙門堂山');
ok($zip->set_number('9640033')->is_valid_number, '福島県二本松市毘沙門堂');
ok($zip->set_number('9640034')->is_valid_number, '福島県二本松市原セ堰下');
ok($zip->set_number('9640035')->is_valid_number, '福島県二本松市原セ天ケ作');
ok($zip->set_number('9640036')->is_valid_number, '福島県二本松市原セ才木');
ok($zip->set_number('9640037')->is_valid_number, '福島県二本松市原セ川原');
ok($zip->set_number('9640038')->is_valid_number, '福島県二本松市立石');
ok($zip->set_number('9640039')->is_valid_number, '福島県二本松市萩坂');
ok($zip->set_number('9640041')->is_valid_number, '福島県二本松市原セ日照田');
ok($zip->set_number('9640042')->is_valid_number, '福島県二本松市原セ大畑');
ok($zip->set_number('9640043')->is_valid_number, '福島県二本松市原セ諏訪');
ok($zip->set_number('9640044')->is_valid_number, '福島県二本松市原セ上ノ内');
ok($zip->set_number('9640045')->is_valid_number, '福島県二本松市原セ笠張');
ok($zip->set_number('9640046')->is_valid_number, '福島県二本松市原セ山口');
ok($zip->set_number('9640047')->is_valid_number, '福島県二本松市原セ上平');
ok($zip->set_number('9640048')->is_valid_number, '福島県二本松市大坂');
ok($zip->set_number('9640049')->is_valid_number, '福島県二本松市原セ仲谷地');
ok($zip->set_number('9640051')->is_valid_number, '福島県二本松市舘野原');
ok($zip->set_number('9640052')->is_valid_number, '福島県二本松市箕輪');
ok($zip->set_number('9640053')->is_valid_number, '福島県二本松市乳母沢');
ok($zip->set_number('9640054')->is_valid_number, '福島県二本松市苗松');
ok($zip->set_number('9640055')->is_valid_number, '福島県二本松市馬場平');
ok($zip->set_number('9640056')->is_valid_number, '福島県二本松市雄平台');
ok($zip->set_number('9640057')->is_valid_number, '福島県二本松市大石ケ作');
ok($zip->set_number('9640058')->is_valid_number, '福島県二本松市三雄山');
ok($zip->set_number('9640061')->is_valid_number, '福島県二本松市岳温泉深堀');
ok($zip->set_number('9640062')->is_valid_number, '福島県二本松市岳温泉大和');
ok($zip->set_number('9640063')->is_valid_number, '福島県二本松市才木山');
ok($zip->set_number('9640064')->is_valid_number, '福島県二本松市岳温泉横森');
ok($zip->set_number('9640065')->is_valid_number, '福島県二本松市小関');
ok($zip->set_number('9640066')->is_valid_number, '福島県二本松市岳温泉西大和');
ok($zip->set_number('9640071')->is_valid_number, '福島県二本松市栄町');
ok($zip->set_number('9640072')->is_valid_number, '福島県二本松市岳東町');
ok($zip->set_number('9640073')->is_valid_number, '福島県二本松市上葉木坂');
ok($zip->set_number('9640074')->is_valid_number, '福島県二本松市岳温泉');
ok($zip->set_number('9640075')->is_valid_number, '福島県二本松市永田(長坂国有林)');
ok($zip->set_number('9640076')->is_valid_number, '福島県二本松市永田橋積');
ok($zip->set_number('9640077')->is_valid_number, '福島県二本松市大関');
ok($zip->set_number('9640081')->is_valid_number, '福島県二本松市宮沢');
ok($zip->set_number('9640082')->is_valid_number, '福島県二本松市休石');
ok($zip->set_number('9640083')->is_valid_number, '福島県二本松市休石原');
ok($zip->set_number('9640084')->is_valid_number, '福島県二本松市大根畑');
ok($zip->set_number('9640085')->is_valid_number, '福島県二本松市不動平');
ok($zip->set_number('9640086')->is_valid_number, '福島県二本松市塩沢');
ok($zip->set_number('9640087')->is_valid_number, '福島県二本松市木ノ根坂');
ok($zip->set_number('9640088')->is_valid_number, '福島県二本松市沢松倉');
ok($zip->set_number('9640091')->is_valid_number, '福島県安達郡大玉村玉井(馬場平)');
ok($zip->set_number('9640111')->is_valid_number, '福島県二本松市太田');
ok($zip->set_number('9640201')->is_valid_number, '福島県二本松市戸沢');
ok($zip->set_number('9640202')->is_valid_number, '福島県二本松市針道');
ok($zip->set_number('9640203')->is_valid_number, '福島県二本松市木幡');
ok($zip->set_number('9640301')->is_valid_number, '福島県二本松市東新殿');
ok($zip->set_number('9640302')->is_valid_number, '福島県二本松市杉沢');
ok($zip->set_number('9640303')->is_valid_number, '福島県二本松市初森');
ok($zip->set_number('9640304')->is_valid_number, '福島県二本松市西新殿');
ok($zip->set_number('9640311')->is_valid_number, '福島県二本松市長折');
ok($zip->set_number('9640312')->is_valid_number, '福島県二本松市上長折');
ok($zip->set_number('9640313')->is_valid_number, '福島県二本松市小浜');
ok($zip->set_number('9640314')->is_valid_number, '福島県二本松市西勝田');
ok($zip->set_number('9640315')->is_valid_number, '福島県二本松市成田');
ok($zip->set_number('9640316')->is_valid_number, '福島県二本松市下長折');
ok($zip->set_number('9640321')->is_valid_number, '福島県二本松市上太田');
ok($zip->set_number('9640431')->is_valid_number, '福島県二本松市田沢');
ok($zip->set_number('9640432')->is_valid_number, '福島県二本松市茂原');
ok($zip->set_number('9640433')->is_valid_number, '福島県二本松市百目木');
ok($zip->set_number('9640801')->is_valid_number, '福島県二本松市向作田');
ok($zip->set_number('9640802')->is_valid_number, '福島県二本松市鐙摺石');
ok($zip->set_number('9640803')->is_valid_number, '福島県二本松市八万舘');
ok($zip->set_number('9640804')->is_valid_number, '福島県二本松市下平');
ok($zip->set_number('9640805')->is_valid_number, '福島県二本松市下ノ内');
ok($zip->set_number('9640806')->is_valid_number, '福島県二本松市羽石');
ok($zip->set_number('9640807')->is_valid_number, '福島県二本松市金色久保');
ok($zip->set_number('9640808')->is_valid_number, '福島県二本松市木藤次郎内');
ok($zip->set_number('9640811')->is_valid_number, '福島県二本松市宮戸');
ok($zip->set_number('9640812')->is_valid_number, '福島県二本松市関');
ok($zip->set_number('9640813')->is_valid_number, '福島県二本松市舟形石山');
ok($zip->set_number('9640814')->is_valid_number, '福島県二本松市遠西');
ok($zip->set_number('9640815')->is_valid_number, '福島県二本松市唐谷山');
ok($zip->set_number('9640816')->is_valid_number, '福島県二本松市原田');
ok($zip->set_number('9640817')->is_valid_number, '福島県二本松市高西');
ok($zip->set_number('9640818')->is_valid_number, '福島県二本松市不動');
ok($zip->set_number('9640821')->is_valid_number, '福島県二本松市舟形石');
ok($zip->set_number('9640822')->is_valid_number, '福島県二本松市舟石');
ok($zip->set_number('9640823')->is_valid_number, '福島県二本松市岩崎');
ok($zip->set_number('9640824')->is_valid_number, '福島県二本松市諏訪原');
ok($zip->set_number('9640825')->is_valid_number, '福島県二本松市下町');
ok($zip->set_number('9640826')->is_valid_number, '福島県二本松市石ノ花');
ok($zip->set_number('9640827')->is_valid_number, '福島県二本松市反返');
ok($zip->set_number('9640828')->is_valid_number, '福島県二本松市新林');
ok($zip->set_number('9640829')->is_valid_number, '福島県二本松市袋内');
ok($zip->set_number('9640831')->is_valid_number, '福島県二本松市前田');
ok($zip->set_number('9640832')->is_valid_number, '福島県二本松市落合');
ok($zip->set_number('9640833')->is_valid_number, '福島県二本松市杉田仲之内');
ok($zip->set_number('9640834')->is_valid_number, '福島県二本松市十神');
ok($zip->set_number('9640835')->is_valid_number, '福島県二本松市水神');
ok($zip->set_number('9640836')->is_valid_number, '福島県二本松市菅田');
ok($zip->set_number('9640837')->is_valid_number, '福島県二本松市七ツ段');
ok($zip->set_number('9640838')->is_valid_number, '福島県二本松市借宿');
ok($zip->set_number('9640841')->is_valid_number, '福島県二本松市瀬ノ上');
ok($zip->set_number('9640842')->is_valid_number, '福島県二本松市隠里');
ok($zip->set_number('9640843')->is_valid_number, '福島県二本松市坊主滝');
ok($zip->set_number('9640844')->is_valid_number, '福島県二本松市在師');
ok($zip->set_number('9640845')->is_valid_number, '福島県二本松市竹柄');
ok($zip->set_number('9640846')->is_valid_number, '福島県二本松市峠');
ok($zip->set_number('9640847')->is_valid_number, '福島県二本松市薬師');
ok($zip->set_number('9640848')->is_valid_number, '福島県二本松市上平内');
ok($zip->set_number('9640849')->is_valid_number, '福島県二本松市大沢');
ok($zip->set_number('9640851')->is_valid_number, '福島県二本松市反田');
ok($zip->set_number('9640852')->is_valid_number, '福島県二本松市長者宮');
ok($zip->set_number('9640853')->is_valid_number, '福島県二本松市向陽台');
ok($zip->set_number('9640854')->is_valid_number, '福島県二本松市郡山台');
ok($zip->set_number('9640855')->is_valid_number, '福島県二本松市成上');
ok($zip->set_number('9640856')->is_valid_number, '福島県二本松市西町');
ok($zip->set_number('9640857')->is_valid_number, '福島県二本松市東町');
ok($zip->set_number('9640858')->is_valid_number, '福島県二本松市姫子松');
ok($zip->set_number('9640859')->is_valid_number, '福島県二本松市中江');
ok($zip->set_number('9640861')->is_valid_number, '福島県二本松市西池');
ok($zip->set_number('9640862')->is_valid_number, '福島県二本松市杉田駄子内');
ok($zip->set_number('9640863')->is_valid_number, '福島県二本松市片岸');
ok($zip->set_number('9640864')->is_valid_number, '福島県二本松市社前');
ok($zip->set_number('9640865')->is_valid_number, '福島県二本松市杉田町');
ok($zip->set_number('9640866')->is_valid_number, '福島県二本松市長命');
ok($zip->set_number('9640867')->is_valid_number, '福島県二本松市住吉');
ok($zip->set_number('9640868')->is_valid_number, '福島県二本松市舘野');
ok($zip->set_number('9640869')->is_valid_number, '福島県二本松市大平山');
ok($zip->set_number('9640871')->is_valid_number, '福島県二本松市成田町');
ok($zip->set_number('9640872')->is_valid_number, '福島県二本松市藤太郎内');
ok($zip->set_number('9640873')->is_valid_number, '福島県二本松市東裏');
ok($zip->set_number('9640874')->is_valid_number, '福島県二本松市中里');
ok($zip->set_number('9640875')->is_valid_number, '福島県二本松市槻木');
ok($zip->set_number('9640876')->is_valid_number, '福島県二本松市正法寺町');
ok($zip->set_number('9640881')->is_valid_number, '福島県二本松市藤之前');
ok($zip->set_number('9640882')->is_valid_number, '福島県二本松市新座');
ok($zip->set_number('9640883')->is_valid_number, '福島県二本松市下山田');
ok($zip->set_number('9640884')->is_valid_number, '福島県二本松市大作');
ok($zip->set_number('9640885')->is_valid_number, '福島県二本松市高越屋戸');
ok($zip->set_number('9640886')->is_valid_number, '福島県二本松市高越松ケ作');
ok($zip->set_number('9640887')->is_valid_number, '福島県二本松市三保内');
ok($zip->set_number('9640891')->is_valid_number, '福島県二本松市大壇');
ok($zip->set_number('9640892')->is_valid_number, '福島県二本松市成田日向');
ok($zip->set_number('9640893')->is_valid_number, '福島県二本松市幸町');
ok($zip->set_number('9640894')->is_valid_number, '福島県二本松市坦子内');
ok($zip->set_number('9640895')->is_valid_number, '福島県二本松市三原町');
ok($zip->set_number('9640896')->is_valid_number, '福島県二本松市末広町');
ok($zip->set_number('9640897')->is_valid_number, '福島県二本松市塩沢町');
ok($zip->set_number('9640898')->is_valid_number, '福島県二本松市上原');
ok($zip->set_number('9640901')->is_valid_number, '福島県二本松市表');
ok($zip->set_number('9640902')->is_valid_number, '福島県二本松市竹田');
ok($zip->set_number('9640903')->is_valid_number, '福島県二本松市根崎');
ok($zip->set_number('9640904')->is_valid_number, '福島県二本松市郭内');
ok($zip->set_number('9640905')->is_valid_number, '福島県二本松市松岡');
ok($zip->set_number('9640906')->is_valid_number, '福島県二本松市若宮');
ok($zip->set_number('9640907')->is_valid_number, '福島県二本松市細野');
ok($zip->set_number('9640911')->is_valid_number, '福島県二本松市亀谷');
ok($zip->set_number('9640912')->is_valid_number, '福島県二本松市上竹');
ok($zip->set_number('9640913')->is_valid_number, '福島県二本松市茶園');
ok($zip->set_number('9640914')->is_valid_number, '福島県二本松市市海道');
ok($zip->set_number('9640915')->is_valid_number, '福島県二本松市金色');
ok($zip->set_number('9640916')->is_valid_number, '福島県二本松市向原');
ok($zip->set_number('9640917')->is_valid_number, '福島県二本松市本町');
ok($zip->set_number('9640921')->is_valid_number, '福島県二本松市小セ川');
ok($zip->set_number('9640922')->is_valid_number, '福島県二本松市島寺');
ok($zip->set_number('9640923')->is_valid_number, '福島県二本松市長下');
ok($zip->set_number('9640924')->is_valid_number, '福島県二本松市中森');
ok($zip->set_number('9640925')->is_valid_number, '福島県二本松市谷和子');
ok($zip->set_number('9640926')->is_valid_number, '福島県二本松市上蓬田');
ok($zip->set_number('9640927')->is_valid_number, '福島県二本松市石畑');
ok($zip->set_number('9640928')->is_valid_number, '福島県二本松市蓬田');
ok($zip->set_number('9640929')->is_valid_number, '福島県二本松市浅川');
ok($zip->set_number('9640931')->is_valid_number, '福島県二本松市矢ノ戸');
ok($zip->set_number('9640932')->is_valid_number, '福島県二本松市丑子内');
ok($zip->set_number('9640933')->is_valid_number, '福島県二本松市西光内');
ok($zip->set_number('9640934')->is_valid_number, '福島県二本松市三合内');
ok($zip->set_number('9640935')->is_valid_number, '福島県二本松市島ノ内');
ok($zip->set_number('9640936')->is_valid_number, '福島県二本松市諸越谷');
ok($zip->set_number('9640937')->is_valid_number, '福島県二本松市榎戸');
ok($zip->set_number('9640938')->is_valid_number, '福島県二本松市安達ケ原');
ok($zip->set_number('9640941')->is_valid_number, '福島県二本松市水上');
ok($zip->set_number('9640942')->is_valid_number, '福島県二本松市式部内');
ok($zip->set_number('9640943')->is_valid_number, '福島県二本松市明主内');
ok($zip->set_number('9640944')->is_valid_number, '福島県二本松市作');
ok($zip->set_number('9640945')->is_valid_number, '福島県二本松市遠山');
ok($zip->set_number('9640946')->is_valid_number, '福島県二本松市堀越');
ok($zip->set_number('9640947')->is_valid_number, '福島県二本松市松林');
ok($zip->set_number('9640948')->is_valid_number, '福島県二本松市橋本');
ok($zip->set_number('9640949')->is_valid_number, '福島県二本松市大平中井');
ok($zip->set_number('9640951')->is_valid_number, '福島県二本松市宮本');
ok($zip->set_number('9640952')->is_valid_number, '福島県二本松市神明石');
ok($zip->set_number('9640953')->is_valid_number, '福島県二本松市沼ケ作');
ok($zip->set_number('9640954')->is_valid_number, '福島県二本松市大稲場');
ok($zip->set_number('9640955')->is_valid_number, '福島県二本松市沖');
ok($zip->set_number('9640956')->is_valid_number, '福島県二本松市木ノ崎');
ok($zip->set_number('9640957')->is_valid_number, '福島県二本松市太子堂');
ok($zip->set_number('9640958')->is_valid_number, '福島県二本松市竹ノ内');
ok($zip->set_number('9640961')->is_valid_number, '福島県二本松市八坂町');
ok($zip->set_number('9640962')->is_valid_number, '福島県二本松市鈴石東町');
ok($zip->set_number('9640963')->is_valid_number, '福島県二本松市大久保');
ok($zip->set_number('9640964')->is_valid_number, '福島県二本松市五月町');
ok($zip->set_number('9640965')->is_valid_number, '福島県二本松市芹沢');
ok($zip->set_number('9640966')->is_valid_number, '福島県二本松市昭和町');
ok($zip->set_number('9640971')->is_valid_number, '福島県二本松市米五町');
ok($zip->set_number('9640972')->is_valid_number, '福島県二本松市鈴石町');
ok($zip->set_number('9640973')->is_valid_number, '福島県二本松市平石町');
ok($zip->set_number('9640974')->is_valid_number, '福島県二本松市小高内');
ok($zip->set_number('9640975')->is_valid_number, '福島県二本松市岡ノ内');
ok($zip->set_number('9640976')->is_valid_number, '福島県二本松市新生町');
ok($zip->set_number('9640981')->is_valid_number, '福島県二本松市平石高田');
ok($zip->set_number('9640982')->is_valid_number, '福島県二本松市赤井沢');
ok($zip->set_number('9640983')->is_valid_number, '福島県二本松市南トロミ');
ok($zip->set_number('9640984')->is_valid_number, '福島県二本松市北トロミ');
ok($zip->set_number('9640985')->is_valid_number, '福島県二本松市高田');
ok($zip->set_number('9640986')->is_valid_number, '福島県二本松市作田');
ok($zip->set_number('9640987')->is_valid_number, '福島県二本松市冠木');
ok($zip->set_number('9640991')->is_valid_number, '福島県二本松市中町');
ok($zip->set_number('9640992')->is_valid_number, '福島県二本松市平石三丁目');
ok($zip->set_number('9640993')->is_valid_number, '福島県二本松市田町');
ok($zip->set_number('9640994')->is_valid_number, '福島県二本松市南町');
ok($zip->set_number('9640995')->is_valid_number, '福島県二本松市錦町');
ok($zip->set_number('9640996')->is_valid_number, '福島県二本松市大町');
ok($zip->set_number('9640997')->is_valid_number, '福島県二本松市江口');
ok($zip->set_number('9650000')->is_valid_number, '福島県会津若松市以下に掲載がない場合');
ok($zip->set_number('9650001')->is_valid_number, '福島県会津若松市一箕町松長');
ok($zip->set_number('9650002')->is_valid_number, '福島県会津若松市一箕町金堀');
ok($zip->set_number('9650003')->is_valid_number, '福島県会津若松市一箕町八幡');
ok($zip->set_number('9650004')->is_valid_number, '福島県会津若松市一箕町八角');
ok($zip->set_number('9650005')->is_valid_number, '福島県会津若松市一箕町亀賀');
ok($zip->set_number('9650006')->is_valid_number, '福島県会津若松市一箕町鶴賀');
ok($zip->set_number('9650007')->is_valid_number, '福島県会津若松市飯盛');
ok($zip->set_number('9650008')->is_valid_number, '福島県会津若松市桧町');
ok($zip->set_number('9650009')->is_valid_number, '福島県会津若松市八角町');
ok($zip->set_number('9650011')->is_valid_number, '福島県会津若松市鶴賀町');
ok($zip->set_number('9650012')->is_valid_number, '福島県会津若松市居合町');
ok($zip->set_number('9650013')->is_valid_number, '福島県会津若松市堤町');
ok($zip->set_number('9650014')->is_valid_number, '福島県会津若松市大塚');
ok($zip->set_number('9650015')->is_valid_number, '福島県会津若松市北滝沢');
ok($zip->set_number('9650016')->is_valid_number, '福島県会津若松市中島町');
ok($zip->set_number('9650021')->is_valid_number, '福島県会津若松市山見町');
ok($zip->set_number('9650022')->is_valid_number, '福島県会津若松市滝沢町');
ok($zip->set_number('9650023')->is_valid_number, '福島県会津若松市蚕養町');
ok($zip->set_number('9650024')->is_valid_number, '福島県会津若松市白虎町');
ok($zip->set_number('9650025')->is_valid_number, '福島県会津若松市扇町');
ok($zip->set_number('9650026')->is_valid_number, '福島県会津若松市平安町');
ok($zip->set_number('9650027')->is_valid_number, '福島県会津若松市花畑東');
ok($zip->set_number('9650031')->is_valid_number, '福島県会津若松市相生町');
ok($zip->set_number('9650032')->is_valid_number, '福島県会津若松市旭町');
ok($zip->set_number('9650033')->is_valid_number, '福島県会津若松市行仁町');
ok($zip->set_number('9650034')->is_valid_number, '福島県会津若松市上町');
ok($zip->set_number('9650035')->is_valid_number, '福島県会津若松市馬場町');
ok($zip->set_number('9650036')->is_valid_number, '福島県会津若松市馬場本町');
ok($zip->set_number('9650037')->is_valid_number, '福島県会津若松市中央');
ok($zip->set_number('9650038')->is_valid_number, '福島県会津若松市昭和町');
ok($zip->set_number('9650041')->is_valid_number, '福島県会津若松市駅前町');
ok($zip->set_number('9650042')->is_valid_number, '福島県会津若松市大町');
ok($zip->set_number('9650043')->is_valid_number, '福島県会津若松市城北町');
ok($zip->set_number('9650044')->is_valid_number, '福島県会津若松市七日町');
ok($zip->set_number('9650045')->is_valid_number, '福島県会津若松市西七日町');
ok($zip->set_number('9650046')->is_valid_number, '福島県会津若松市八日町');
ok($zip->set_number('9650047')->is_valid_number, '福島県会津若松市五月町');
ok($zip->set_number('9650048')->is_valid_number, '福島県会津若松市橋本');
ok($zip->set_number('9650051')->is_valid_number, '福島県会津若松市町北町谷地');
ok($zip->set_number('9650052')->is_valid_number, '福島県会津若松市町北町始');
ok($zip->set_number('9650053')->is_valid_number, '福島県会津若松市町北町上荒久田');
ok($zip->set_number('9650054')->is_valid_number, '福島県会津若松市町北町石堂');
ok($zip->set_number('9650055')->is_valid_number, '福島県会津若松市石堂町');
ok($zip->set_number('9650056')->is_valid_number, '福島県会津若松市金川町');
ok($zip->set_number('9650057')->is_valid_number, '福島県会津若松市町北町藤室');
ok($zip->set_number('9650058')->is_valid_number, '福島県会津若松市町北町中沢');
ok($zip->set_number('9650059')->is_valid_number, '福島県会津若松市インター西');
ok($zip->set_number('9650060')->is_valid_number, '福島県会津若松市高久工業団地');
ok($zip->set_number('9650061')->is_valid_number, '福島県会津若松市神指町高久');
ok($zip->set_number('9650062')->is_valid_number, '福島県会津若松市神指町北四合');
ok($zip->set_number('9650063')->is_valid_number, '福島県会津若松市神指町高瀬');
ok($zip->set_number('9650064')->is_valid_number, '福島県会津若松市神指町黒川');
ok($zip->set_number('9650065')->is_valid_number, '福島県会津若松市神指町中四合');
ok($zip->set_number('9650066')->is_valid_number, '福島県会津若松市神指町横沼');
ok($zip->set_number('9650067')->is_valid_number, '福島県会津若松市神指町下神指');
ok($zip->set_number('9650068')->is_valid_number, '福島県会津若松市神指町小見');
ok($zip->set_number('9650069')->is_valid_number, '福島県会津若松市神指町天満');
ok($zip->set_number('9650071')->is_valid_number, '福島県会津若松市高野町木流');
ok($zip->set_number('9650072')->is_valid_number, '福島県会津若松市高野町橋本木流');
ok($zip->set_number('9650073')->is_valid_number, '福島県会津若松市高野町上沼');
ok($zip->set_number('9650074')->is_valid_number, '福島県会津若松市高野町平塚');
ok($zip->set_number('9650075')->is_valid_number, '福島県会津若松市高野町中前田');
ok($zip->set_number('9650076')->is_valid_number, '福島県会津若松市高野町中沼');
ok($zip->set_number('9650077')->is_valid_number, '福島県会津若松市高野町上高野');
ok($zip->set_number('9650078')->is_valid_number, '福島県会津若松市高野町柳川');
ok($zip->set_number('9650079')->is_valid_number, '福島県会津若松市高野町界沢');
ok($zip->set_number('9650080')->is_valid_number, '福島県会津若松市神指町橋本');
ok($zip->set_number('9650081')->is_valid_number, '福島県会津若松市神指町西城戸');
ok($zip->set_number('9650082')->is_valid_number, '福島県会津若松市神指町榎木檀');
ok($zip->set_number('9650083')->is_valid_number, '福島県会津若松市神指町上神指');
ok($zip->set_number('9650084')->is_valid_number, '福島県会津若松市神指町東神指');
ok($zip->set_number('9650085')->is_valid_number, '福島県会津若松市神指町如来堂');
ok($zip->set_number('9650086')->is_valid_number, '福島県会津若松市神指町本丸');
ok($zip->set_number('9650087')->is_valid_number, '福島県会津若松市神指町高瀬新田');
ok($zip->set_number('9650088')->is_valid_number, '福島県会津若松市町北町中沢西');
ok($zip->set_number('9650089')->is_valid_number, '福島県会津若松市神指町東城戸');
ok($zip->set_number('9650101')->is_valid_number, '福島県会津若松市北会津町真宮');
ok($zip->set_number('9650102')->is_valid_number, '福島県会津若松市真宮新町北');
ok($zip->set_number('9650103')->is_valid_number, '福島県会津若松市真宮新町南');
ok($zip->set_number('9650107')->is_valid_number, '福島県会津若松市北会津町和泉');
ok($zip->set_number('9650110')->is_valid_number, '福島県会津若松市北会津町中里');
ok($zip->set_number('9650111')->is_valid_number, '福島県会津若松市北会津町下荒井');
ok($zip->set_number('9650112')->is_valid_number, '福島県会津若松市北会津町白山');
ok($zip->set_number('9650113')->is_valid_number, '福島県会津若松市北会津町安良田');
ok($zip->set_number('9650114')->is_valid_number, '福島県会津若松市北会津町宮ノ下');
ok($zip->set_number('9650115')->is_valid_number, '福島県会津若松市北会津町舘');
ok($zip->set_number('9650116')->is_valid_number, '福島県会津若松市北会津町出尻');
ok($zip->set_number('9650117')->is_valid_number, '福島県会津若松市北会津町田村山');
ok($zip->set_number('9650118')->is_valid_number, '福島県会津若松市北会津町石原');
ok($zip->set_number('9650121')->is_valid_number, '福島県会津若松市北会津町蟹川');
ok($zip->set_number('9650124')->is_valid_number, '福島県会津若松市北会津町宮袋');
ok($zip->set_number('9650126')->is_valid_number, '福島県会津若松市北会津町鷺林');
ok($zip->set_number('9650127')->is_valid_number, '福島県会津若松市北会津町宮袋新田');
ok($zip->set_number('9650128')->is_valid_number, '福島県会津若松市北会津町十二所');
ok($zip->set_number('9650129')->is_valid_number, '福島県会津若松市北会津町本田');
ok($zip->set_number('9650131')->is_valid_number, '福島県会津若松市北会津町中荒井');
ok($zip->set_number('9650132')->is_valid_number, '福島県会津若松市北会津町ほたるの森');
ok($zip->set_number('9650133')->is_valid_number, '福島県会津若松市北会津町二日町');
ok($zip->set_number('9650134')->is_valid_number, '福島県会津若松市北会津町東麻生');
ok($zip->set_number('9650135')->is_valid_number, '福島県会津若松市北会津町寺堀');
ok($zip->set_number('9650136')->is_valid_number, '福島県会津若松市北会津町今和泉');
ok($zip->set_number('9650201')->is_valid_number, '福島県会津若松市湊町赤井');
ok($zip->set_number('9650202')->is_valid_number, '福島県会津若松市湊町共和');
ok($zip->set_number('9650203')->is_valid_number, '福島県会津若松市湊町静潟');
ok($zip->set_number('9650204')->is_valid_number, '福島県会津若松市湊町原');
ok($zip->set_number('9650205')->is_valid_number, '福島県会津若松市湊町平潟');
ok($zip->set_number('9650801')->is_valid_number, '福島県会津若松市宮町');
ok($zip->set_number('9650802')->is_valid_number, '福島県会津若松市徒之町');
ok($zip->set_number('9650803')->is_valid_number, '福島県会津若松市城前');
ok($zip->set_number('9650804')->is_valid_number, '福島県会津若松市花春町');
ok($zip->set_number('9650805')->is_valid_number, '福島県会津若松市天寧寺町');
ok($zip->set_number('9650806')->is_valid_number, '福島県会津若松市宝町');
ok($zip->set_number('9650807')->is_valid_number, '福島県会津若松市城東町');
ok($zip->set_number('9650808')->is_valid_number, '福島県会津若松市南町');
ok($zip->set_number('9650809')->is_valid_number, '福島県会津若松市城南町');
ok($zip->set_number('9650811')->is_valid_number, '福島県会津若松市和田');
ok($zip->set_number('9650812')->is_valid_number, '福島県会津若松市慶山');
ok($zip->set_number('9650813')->is_valid_number, '福島県会津若松市東山町石山');
ok($zip->set_number('9650814')->is_valid_number, '福島県会津若松市東山町湯本');
ok($zip->set_number('9650815')->is_valid_number, '福島県会津若松市東山町湯川');
ok($zip->set_number('9650816')->is_valid_number, '福島県会津若松市南千石町');
ok($zip->set_number('9650817')->is_valid_number, '福島県会津若松市千石町');
ok($zip->set_number('9650818')->is_valid_number, '福島県会津若松市東千石');
ok($zip->set_number('9650821')->is_valid_number, '福島県会津若松市湯川南');
ok($zip->set_number('9650822')->is_valid_number, '福島県会津若松市花見ケ丘');
ok($zip->set_number('9650823')->is_valid_number, '福島県会津若松市建福寺前');
ok($zip->set_number('9650824')->is_valid_number, '福島県会津若松市北青木');
ok($zip->set_number('9650825')->is_valid_number, '福島県会津若松市門田町黒岩');
ok($zip->set_number('9650826')->is_valid_number, '福島県会津若松市門田町御山');
ok($zip->set_number('9650827')->is_valid_number, '福島県会津若松市門田町堤沢');
ok($zip->set_number('9650828')->is_valid_number, '福島県会津若松市門田町面川');
ok($zip->set_number('9650829')->is_valid_number, '福島県会津若松市門田町根岸東');
ok($zip->set_number('9650830')->is_valid_number, '福島県会津若松市西年貢');
ok($zip->set_number('9650831')->is_valid_number, '福島県会津若松市表町');
ok($zip->set_number('9650832')->is_valid_number, '福島県会津若松市天神町');
ok($zip->set_number('9650833')->is_valid_number, '福島県会津若松市明和町');
ok($zip->set_number('9650834')->is_valid_number, '福島県会津若松市門田町年貢町');
ok($zip->set_number('9650835')->is_valid_number, '福島県会津若松市館馬町');
ok($zip->set_number('9650836')->is_valid_number, '福島県会津若松市館脇町');
ok($zip->set_number('9650837')->is_valid_number, '福島県会津若松市錦町');
ok($zip->set_number('9650838')->is_valid_number, '福島県会津若松市古川町');
ok($zip->set_number('9650839')->is_valid_number, '福島県会津若松市東年貢');
ok($zip->set_number('9650841')->is_valid_number, '福島県会津若松市門田町日吉');
ok($zip->set_number('9650842')->is_valid_number, '福島県会津若松市門田町中野');
ok($zip->set_number('9650843')->is_valid_number, '福島県会津若松市門田町徳久');
ok($zip->set_number('9650844')->is_valid_number, '福島県会津若松市門田町一ノ堰');
ok($zip->set_number('9650845')->is_valid_number, '福島県会津若松市門田町工業団地');
ok($zip->set_number('9650846')->is_valid_number, '福島県会津若松市門田町飯寺');
ok($zip->set_number('9650847')->is_valid_number, '福島県会津若松市対馬館町');
ok($zip->set_number('9650848')->is_valid_number, '福島県会津若松市飯寺北');
ok($zip->set_number('9650849')->is_valid_number, '福島県会津若松市幕内南町');
ok($zip->set_number('9650851')->is_valid_number, '福島県会津若松市御旗町');
ok($zip->set_number('9650852')->is_valid_number, '福島県会津若松市日吉町');
ok($zip->set_number('9650853')->is_valid_number, '福島県会津若松市材木町');
ok($zip->set_number('9650854')->is_valid_number, '福島県会津若松市桜町');
ok($zip->set_number('9650855')->is_valid_number, '福島県会津若松市住吉町');
ok($zip->set_number('9650856')->is_valid_number, '福島県会津若松市幕内東町');
ok($zip->set_number('9650857')->is_valid_number, '福島県会津若松市柳原町');
ok($zip->set_number('9650858')->is_valid_number, '福島県会津若松市神指町南四合');
ok($zip->set_number('9650859')->is_valid_number, '福島県会津若松市神指町幕内');
ok($zip->set_number('9650861')->is_valid_number, '福島県会津若松市日新町');
ok($zip->set_number('9650862')->is_valid_number, '福島県会津若松市本町');
ok($zip->set_number('9650863')->is_valid_number, '福島県会津若松市湯川町');
ok($zip->set_number('9650864')->is_valid_number, '福島県会津若松市城西町');
ok($zip->set_number('9650865')->is_valid_number, '福島県会津若松市川原町');
ok($zip->set_number('9650866')->is_valid_number, '福島県会津若松市新横町');
ok($zip->set_number('9650867')->is_valid_number, '福島県会津若松市緑町');
ok($zip->set_number('9650871')->is_valid_number, '福島県会津若松市栄町');
ok($zip->set_number('9650872')->is_valid_number, '福島県会津若松市東栄町');
ok($zip->set_number('9650873')->is_valid_number, '福島県会津若松市追手町');
ok($zip->set_number('9650874')->is_valid_number, '福島県会津若松市南花畑');
ok($zip->set_number('9650875')->is_valid_number, '福島県会津若松市米代');
ok($zip->set_number('9650876')->is_valid_number, '福島県会津若松市山鹿町');
ok($zip->set_number('9650877')->is_valid_number, '福島県会津若松市西栄町');
ok($zip->set_number('9650878')->is_valid_number, '福島県会津若松市中町');
ok($zip->set_number('9660000')->is_valid_number, '福島県喜多方市以下に掲載がない場合');
ok($zip->set_number('9660001')->is_valid_number, '福島県喜多方市岩月町入田付');
ok($zip->set_number('9660002')->is_valid_number, '福島県喜多方市岩月町宮津');
ok($zip->set_number('9660003')->is_valid_number, '福島県喜多方市岩月町橿野');
ok($zip->set_number('9660004')->is_valid_number, '福島県喜多方市岩月町喜多方');
ok($zip->set_number('9660005')->is_valid_number, '福島県喜多方市岩月町大都');
ok($zip->set_number('9660006')->is_valid_number, '福島県喜多方市北町上');
ok($zip->set_number('9660007')->is_valid_number, '福島県喜多方市東桜ガ丘');
ok($zip->set_number('9660011')->is_valid_number, '福島県喜多方市関柴町関柴');
ok($zip->set_number('9660012')->is_valid_number, '福島県喜多方市関柴町下柴');
ok($zip->set_number('9660013')->is_valid_number, '福島県喜多方市関柴町豊芦');
ok($zip->set_number('9660014')->is_valid_number, '福島県喜多方市関柴町西勝');
ok($zip->set_number('9660015')->is_valid_number, '福島県喜多方市関柴町上高額');
ok($zip->set_number('9660016')->is_valid_number, '福島県喜多方市関柴町平林');
ok($zip->set_number('9660017')->is_valid_number, '福島県喜多方市関柴町三津井');
ok($zip->set_number('9660021')->is_valid_number, '福島県喜多方市熊倉町都');
ok($zip->set_number('9660022')->is_valid_number, '福島県喜多方市熊倉町雄国');
ok($zip->set_number('9660023')->is_valid_number, '福島県喜多方市熊倉町新合');
ok($zip->set_number('9660024')->is_valid_number, '福島県喜多方市熊倉町熊倉');
ok($zip->set_number('9660031')->is_valid_number, '福島県喜多方市舞台田');
ok($zip->set_number('9660032')->is_valid_number, '福島県喜多方市梨子ノ木');
ok($zip->set_number('9660033')->is_valid_number, '福島県喜多方市瀬戸');
ok($zip->set_number('9660034')->is_valid_number, '福島県喜多方市二本木');
ok($zip->set_number('9660035')->is_valid_number, '福島県喜多方市中台');
ok($zip->set_number('9660035')->is_valid_number, '福島県喜多方市畑台');
ok($zip->set_number('9660036')->is_valid_number, '福島県喜多方市柳清水');
ok($zip->set_number('9660037')->is_valid_number, '福島県喜多方市大豆田');
ok($zip->set_number('9660038')->is_valid_number, '福島県喜多方市桜町');
ok($zip->set_number('9660039')->is_valid_number, '福島県喜多方市加登');
ok($zip->set_number('9660041')->is_valid_number, '福島県喜多方市蒔田');
ok($zip->set_number('9660042')->is_valid_number, '福島県喜多方市下江');
ok($zip->set_number('9660043')->is_valid_number, '福島県喜多方市上江');
ok($zip->set_number('9660044')->is_valid_number, '福島県喜多方市沢ノ目');
ok($zip->set_number('9660045')->is_valid_number, '福島県喜多方市南原');
ok($zip->set_number('9660046')->is_valid_number, '福島県喜多方市原田');
ok($zip->set_number('9660047')->is_valid_number, '福島県喜多方市銭田');
ok($zip->set_number('9660048')->is_valid_number, '福島県喜多方市越巻');
ok($zip->set_number('9660049')->is_valid_number, '福島県喜多方市長面');
ok($zip->set_number('9660051')->is_valid_number, '福島県喜多方市東町');
ok($zip->set_number('9660052')->is_valid_number, '福島県喜多方市四百苅');
ok($zip->set_number('9660053')->is_valid_number, '福島県喜多方市石田');
ok($zip->set_number('9660054')->is_valid_number, '福島県喜多方市大谷地田');
ok($zip->set_number('9660055')->is_valid_number, '福島県喜多方市台');
ok($zip->set_number('9660056')->is_valid_number, '福島県喜多方市屋敷免');
ok($zip->set_number('9660057')->is_valid_number, '福島県喜多方市井戸尻');
ok($zip->set_number('9660058')->is_valid_number, '福島県喜多方市広面');
ok($zip->set_number('9660061')->is_valid_number, '福島県喜多方市馬場');
ok($zip->set_number('9660062')->is_valid_number, '福島県喜多方市寺南');
ok($zip->set_number('9660063')->is_valid_number, '福島県喜多方市五ノ神');
ok($zip->set_number('9660064')->is_valid_number, '福島県喜多方市惣座宮');
ok($zip->set_number('9660065')->is_valid_number, '福島県喜多方市中川原');
ok($zip->set_number('9660066')->is_valid_number, '福島県喜多方市宮西');
ok($zip->set_number('9660067')->is_valid_number, '福島県喜多方市村西');
ok($zip->set_number('9660068')->is_valid_number, '福島県喜多方市寺西');
ok($zip->set_number('9660069')->is_valid_number, '福島県喜多方市稲清水');
ok($zip->set_number('9660071')->is_valid_number, '福島県喜多方市山ノ神');
ok($zip->set_number('9660072')->is_valid_number, '福島県喜多方市北町');
ok($zip->set_number('9660073')->is_valid_number, '福島県喜多方市中町');
ok($zip->set_number('9660074')->is_valid_number, '福島県喜多方市南町');
ok($zip->set_number('9660081')->is_valid_number, '福島県喜多方市西町');
ok($zip->set_number('9660082')->is_valid_number, '福島県喜多方市南條');
ok($zip->set_number('9660083')->is_valid_number, '福島県喜多方市六枚長');
ok($zip->set_number('9660084')->is_valid_number, '福島県喜多方市西井戸尻');
ok($zip->set_number('9660085')->is_valid_number, '福島県喜多方市江中子');
ok($zip->set_number('9660086')->is_valid_number, '福島県喜多方市西四ツ谷');
ok($zip->set_number('9660087')->is_valid_number, '福島県喜多方市稲荷宮');
ok($zip->set_number('9660091')->is_valid_number, '福島県喜多方市青葉台');
ok($zip->set_number('9660092')->is_valid_number, '福島県喜多方市清水台');
ok($zip->set_number('9660093')->is_valid_number, '福島県喜多方市清水が丘');
ok($zip->set_number('9660094')->is_valid_number, '福島県喜多方市押切');
ok($zip->set_number('9660095')->is_valid_number, '福島県喜多方市押切東');
ok($zip->set_number('9660096')->is_valid_number, '福島県喜多方市押切南');
ok($zip->set_number('9660097')->is_valid_number, '福島県喜多方市通船場');
ok($zip->set_number('9660101')->is_valid_number, '福島県喜多方市熱塩加納町熱塩');
ok($zip->set_number('9660102')->is_valid_number, '福島県喜多方市熱塩加納町山田');
ok($zip->set_number('9660103')->is_valid_number, '福島県喜多方市熱塩加納町加納');
ok($zip->set_number('9660104')->is_valid_number, '福島県喜多方市熱塩加納町米岡');
ok($zip->set_number('9660105')->is_valid_number, '福島県喜多方市熱塩加納町宮川');
ok($zip->set_number('9660106')->is_valid_number, '福島県喜多方市熱塩加納町林際');
ok($zip->set_number('9660107')->is_valid_number, '福島県喜多方市熱塩加納町居廻');
ok($zip->set_number('9660108')->is_valid_number, '福島県喜多方市熱塩加納町相田');
ok($zip->set_number('9660400')->is_valid_number, '福島県耶麻郡北塩原村以下に掲載がない場合');
ok($zip->set_number('9660401')->is_valid_number, '福島県耶麻郡北塩原村桧原(雄子沢、雄子沢原、細野、南黄連沢、南黄連沢山、黄連沢山、黄連原山)');
ok($zip->set_number('9660402')->is_valid_number, '福島県耶麻郡北塩原村大塩');
ok($zip->set_number('9660403')->is_valid_number, '福島県耶麻郡北塩原村関屋');
ok($zip->set_number('9660404')->is_valid_number, '福島県耶麻郡北塩原村北山');
ok($zip->set_number('9660405')->is_valid_number, '福島県耶麻郡北塩原村下吉');
ok($zip->set_number('9660501')->is_valid_number, '福島県耶麻郡北塩原村桧原(苧畑沢、金山、五十両原、巣ノ山、滝ノ原、道前原、墓下、桧原、無縁');
ok($zip->set_number('9660501')->is_valid_number, '福島県耶麻郡北塩原村原、早稲沢、小屋沢、水梨原、中原、楢木平原、焼桂山、館山)');
ok($zip->set_number('9660801')->is_valid_number, '福島県喜多方市常盤台');
ok($zip->set_number('9660802')->is_valid_number, '福島県喜多方市桜ガ丘');
ok($zip->set_number('9660803')->is_valid_number, '福島県喜多方市落合');
ok($zip->set_number('9660804')->is_valid_number, '福島県喜多方市沼田');
ok($zip->set_number('9660805')->is_valid_number, '福島県喜多方市小田付道上');
ok($zip->set_number('9660806')->is_valid_number, '福島県喜多方市水上');
ok($zip->set_number('9660811')->is_valid_number, '福島県喜多方市上川向');
ok($zip->set_number('9660812')->is_valid_number, '福島県喜多方市緑町');
ok($zip->set_number('9660813')->is_valid_number, '福島県喜多方市小田付道下');
ok($zip->set_number('9660814')->is_valid_number, '福島県喜多方市御清水');
ok($zip->set_number('9660814')->is_valid_number, '福島県喜多方市御清水東');
ok($zip->set_number('9660815')->is_valid_number, '福島県喜多方市谷地田');
ok($zip->set_number('9660816')->is_valid_number, '福島県喜多方市細田');
ok($zip->set_number('9660817')->is_valid_number, '福島県喜多方市3丁目');
ok($zip->set_number('9660818')->is_valid_number, '福島県喜多方市2丁目');
ok($zip->set_number('9660819')->is_valid_number, '福島県喜多方市1丁目');
ok($zip->set_number('9660821')->is_valid_number, '福島県喜多方市梅竹');
ok($zip->set_number('9660822')->is_valid_number, '福島県喜多方市柳原');
ok($zip->set_number('9660823')->is_valid_number, '福島県喜多方市東川原田');
ok($zip->set_number('9660824')->is_valid_number, '福島県喜多方市六百刈');
ok($zip->set_number('9660825')->is_valid_number, '福島県喜多方市御清水南');
ok($zip->set_number('9660826')->is_valid_number, '福島県喜多方市町尻東');
ok($zip->set_number('9660827')->is_valid_number, '福島県喜多方市沢ノ免');
ok($zip->set_number('9660831')->is_valid_number, '福島県喜多方市小田');
ok($zip->set_number('9660832')->is_valid_number, '福島県喜多方市百苅田');
ok($zip->set_number('9660833')->is_valid_number, '福島県喜多方市中島');
ok($zip->set_number('9660834')->is_valid_number, '福島県喜多方市谷地田上');
ok($zip->set_number('9660835')->is_valid_number, '福島県喜多方市行作');
ok($zip->set_number('9660836')->is_valid_number, '福島県喜多方市大坪');
ok($zip->set_number('9660837')->is_valid_number, '福島県喜多方市前田上');
ok($zip->set_number('9660838')->is_valid_number, '福島県喜多方市永久');
ok($zip->set_number('9660839')->is_valid_number, '福島県喜多方市大道田');
ok($zip->set_number('9660841')->is_valid_number, '福島県喜多方市さつきが丘');
ok($zip->set_number('9660842')->is_valid_number, '福島県喜多方市川下');
ok($zip->set_number('9660843')->is_valid_number, '福島県喜多方市東籠田');
ok($zip->set_number('9660844')->is_valid_number, '福島県喜多方市西籠田');
ok($zip->set_number('9660845')->is_valid_number, '福島県喜多方市長内');
ok($zip->set_number('9660846')->is_valid_number, '福島県喜多方市町田下');
ok($zip->set_number('9660847')->is_valid_number, '福島県喜多方市町田');
ok($zip->set_number('9660848')->is_valid_number, '福島県喜多方市一本木下');
ok($zip->set_number('9660849')->is_valid_number, '福島県喜多方市一本木上');
ok($zip->set_number('9660850')->is_valid_number, '福島県喜多方市下川原');
ok($zip->set_number('9660851')->is_valid_number, '福島県喜多方市北原');
ok($zip->set_number('9660852')->is_valid_number, '福島県喜多方市天満前');
ok($zip->set_number('9660853')->is_valid_number, '福島県喜多方市千苅');
ok($zip->set_number('9660854')->is_valid_number, '福島県喜多方市千苅道上');
ok($zip->set_number('9660855')->is_valid_number, '福島県喜多方市太子堂');
ok($zip->set_number('9660856')->is_valid_number, '福島県喜多方市長源段');
ok($zip->set_number('9660857')->is_valid_number, '福島県喜多方市町西');
ok($zip->set_number('9660858')->is_valid_number, '福島県喜多方市町北');
ok($zip->set_number('9660859')->is_valid_number, '福島県喜多方市番帳免');
ok($zip->set_number('9660861')->is_valid_number, '福島県喜多方市寺町');
ok($zip->set_number('9660862')->is_valid_number, '福島県喜多方市常盤町');
ok($zip->set_number('9660862')->is_valid_number, '福島県喜多方市前田');
ok($zip->set_number('9660863')->is_valid_number, '福島県喜多方市町尻西');
ok($zip->set_number('9660864')->is_valid_number, '福島県喜多方市七百苅');
ok($zip->set_number('9660865')->is_valid_number, '福島県喜多方市寺田');
ok($zip->set_number('9660866')->is_valid_number, '福島県喜多方市古寺');
ok($zip->set_number('9660867')->is_valid_number, '福島県喜多方市扇田');
ok($zip->set_number('9660868')->is_valid_number, '福島県喜多方市市道');
ok($zip->set_number('9660869')->is_valid_number, '福島県喜多方市慶徳道下');
ok($zip->set_number('9660871')->is_valid_number, '福島県喜多方市寺町南');
ok($zip->set_number('9660872')->is_valid_number, '福島県喜多方市慶徳道上');
ok($zip->set_number('9660873')->is_valid_number, '福島県喜多方市舘野');
ok($zip->set_number('9660874')->is_valid_number, '福島県喜多方市窪屋敷');
ok($zip->set_number('9660875')->is_valid_number, '福島県喜多方市鶴巻');
ok($zip->set_number('9660877')->is_valid_number, '福島県喜多方市坂井道上');
ok($zip->set_number('9660881')->is_valid_number, '福島県喜多方市中清水');
ok($zip->set_number('9660882')->is_valid_number, '福島県喜多方市中寺');
ok($zip->set_number('9660884')->is_valid_number, '福島県喜多方市壇ノ前');
ok($zip->set_number('9660887')->is_valid_number, '福島県喜多方市飯田道上');
ok($zip->set_number('9660891')->is_valid_number, '福島県喜多方市蝦蟆渕');
ok($zip->set_number('9660892')->is_valid_number, '福島県喜多方市経壇');
ok($zip->set_number('9660893')->is_valid_number, '福島県喜多方市花園');
ok($zip->set_number('9660894')->is_valid_number, '福島県喜多方市御茶屋');
ok($zip->set_number('9660895')->is_valid_number, '福島県喜多方市東小原');
ok($zip->set_number('9660896')->is_valid_number, '福島県喜多方市諏訪');
ok($zip->set_number('9660898')->is_valid_number, '福島県喜多方市見頃道上');
ok($zip->set_number('9660899')->is_valid_number, '福島県喜多方市樋越');
ok($zip->set_number('9660901')->is_valid_number, '福島県喜多方市松山町鳥見山');
ok($zip->set_number('9660902')->is_valid_number, '福島県喜多方市松山町村松');
ok($zip->set_number('9660903')->is_valid_number, '福島県喜多方市松山町大飯坂');
ok($zip->set_number('9660904')->is_valid_number, '福島県喜多方市大荒井');
ok($zip->set_number('9660911')->is_valid_number, '福島県喜多方市豊川町高堂太');
ok($zip->set_number('9660912')->is_valid_number, '福島県喜多方市豊川町一井');
ok($zip->set_number('9660913')->is_valid_number, '福島県喜多方市豊川町沢部');
ok($zip->set_number('9660914')->is_valid_number, '福島県喜多方市豊川町米室');
ok($zip->set_number('9660915')->is_valid_number, '福島県喜多方市大谷地');
ok($zip->set_number('9660921')->is_valid_number, '福島県喜多方市慶徳町松舞家');
ok($zip->set_number('9660922')->is_valid_number, '福島県喜多方市慶徳町豊岡');
ok($zip->set_number('9660923')->is_valid_number, '福島県喜多方市慶徳町新宮');
ok($zip->set_number('9660924')->is_valid_number, '福島県喜多方市慶徳町山科');
ok($zip->set_number('9660931')->is_valid_number, '福島県喜多方市上三宮町上三宮');
ok($zip->set_number('9660932')->is_valid_number, '福島県喜多方市上三宮町吉川');
ok($zip->set_number('9660933')->is_valid_number, '福島県喜多方市上三宮町三谷');
ok($zip->set_number('9670000')->is_valid_number, '福島県南会津郡南会津町以下に掲載がない場合');
ok($zip->set_number('9670001')->is_valid_number, '福島県南会津郡南会津町長野');
ok($zip->set_number('9670002')->is_valid_number, '福島県南会津郡南会津町田部');
ok($zip->set_number('9670003')->is_valid_number, '福島県南会津郡南会津町水無');
ok($zip->set_number('9670004')->is_valid_number, '福島県南会津郡南会津町田島');
ok($zip->set_number('9670005')->is_valid_number, '福島県南会津郡南会津町中荒井');
ok($zip->set_number('9670006')->is_valid_number, '福島県南会津郡南会津町永田');
ok($zip->set_number('9670007')->is_valid_number, '福島県南会津郡南会津町丹藤');
ok($zip->set_number('9670011')->is_valid_number, '福島県南会津郡南会津町栗生沢');
ok($zip->set_number('9670012')->is_valid_number, '福島県南会津郡南会津町川島');
ok($zip->set_number('9670013')->is_valid_number, '福島県南会津郡南会津町関本');
ok($zip->set_number('9670014')->is_valid_number, '福島県南会津郡南会津町糸沢');
ok($zip->set_number('9670015')->is_valid_number, '福島県南会津郡南会津町滝原');
ok($zip->set_number('9670016')->is_valid_number, '福島県南会津郡南会津町藤生');
ok($zip->set_number('9670021')->is_valid_number, '福島県南会津郡南会津町高野');
ok($zip->set_number('9670022')->is_valid_number, '福島県南会津郡南会津町塩江');
ok($zip->set_number('9670023')->is_valid_number, '福島県南会津郡南会津町福米沢');
ok($zip->set_number('9670024')->is_valid_number, '福島県南会津郡南会津町金井沢');
ok($zip->set_number('9670025')->is_valid_number, '福島県南会津郡南会津町静川');
ok($zip->set_number('9670026')->is_valid_number, '福島県南会津郡南会津町針生');
ok($zip->set_number('9670301')->is_valid_number, '福島県南会津郡南会津町たのせ');
ok($zip->set_number('9670302')->is_valid_number, '福島県南会津郡南会津町塩ノ原');
ok($zip->set_number('9670303')->is_valid_number, '福島県南会津郡南会津町福渡');
ok($zip->set_number('9670304')->is_valid_number, '福島県南会津郡南会津町松戸原');
ok($zip->set_number('9670305')->is_valid_number, '福島県南会津郡南会津町戸中');
ok($zip->set_number('9670306')->is_valid_number, '福島県南会津郡南会津町前沢');
ok($zip->set_number('9670307')->is_valid_number, '福島県南会津郡南会津町水石');
ok($zip->set_number('9670311')->is_valid_number, '福島県南会津郡南会津町新田原');
ok($zip->set_number('9670312')->is_valid_number, '福島県南会津郡南会津町熨斗戸');
ok($zip->set_number('9670313')->is_valid_number, '福島県南会津郡南会津町森戸');
ok($zip->set_number('9670314')->is_valid_number, '福島県南会津郡南会津町八総');
ok($zip->set_number('9670315')->is_valid_number, '福島県南会津郡南会津町高杖原');
ok($zip->set_number('9670317')->is_valid_number, '福島県南会津郡南会津町伊与戸');
ok($zip->set_number('9670318')->is_valid_number, '福島県南会津郡南会津町八木ノ沢');
ok($zip->set_number('9670319')->is_valid_number, '福島県南会津郡南会津町大久保');
ok($zip->set_number('9670321')->is_valid_number, '福島県南会津郡南会津町井桁');
ok($zip->set_number('9670322')->is_valid_number, '福島県南会津郡南会津町精舎');
ok($zip->set_number('9670323')->is_valid_number, '福島県南会津郡南会津町岩下');
ok($zip->set_number('9670324')->is_valid_number, '福島県南会津郡南会津町番屋');
ok($zip->set_number('9670331')->is_valid_number, '福島県南会津郡南会津町押戸');
ok($zip->set_number('9670332')->is_valid_number, '福島県南会津郡南会津町角生');
ok($zip->set_number('9670333')->is_valid_number, '福島県南会津郡南会津町湯ノ花');
ok($zip->set_number('9670334')->is_valid_number, '福島県南会津郡南会津町水引');
ok($zip->set_number('9670335')->is_valid_number, '福島県南会津郡南会津町貝原');
ok($zip->set_number('9670336')->is_valid_number, '福島県南会津郡南会津町吉高');
ok($zip->set_number('9670341')->is_valid_number, '福島県南会津郡南会津町穴原');
ok($zip->set_number('9670342')->is_valid_number, '福島県南会津郡南会津町助木生');
ok($zip->set_number('9670343')->is_valid_number, '福島県南会津郡南会津町小高林');
ok($zip->set_number('9670344')->is_valid_number, '福島県南会津郡南会津町上ノ原');
ok($zip->set_number('9670345')->is_valid_number, '福島県南会津郡南会津町木賊');
ok($zip->set_number('9670346')->is_valid_number, '福島県南会津郡南会津町川衣');
ok($zip->set_number('9670347')->is_valid_number, '福島県南会津郡南会津町宮里');
ok($zip->set_number('9670500')->is_valid_number, '福島県南会津郡檜枝岐村以下に掲載がない場合');
ok($zip->set_number('9670501')->is_valid_number, '福島県南会津郡南会津町古町');
ok($zip->set_number('9670502')->is_valid_number, '福島県南会津郡南会津町多々石');
ok($zip->set_number('9670503')->is_valid_number, '福島県南会津郡南会津町白沢');
ok($zip->set_number('9670504')->is_valid_number, '福島県南会津郡南会津町浜野');
ok($zip->set_number('9670505')->is_valid_number, '福島県南会津郡南会津町宮沢');
ok($zip->set_number('9670506')->is_valid_number, '福島県南会津郡南会津町小塩');
ok($zip->set_number('9670507')->is_valid_number, '福島県南会津郡南会津町青柳');
ok($zip->set_number('9670511')->is_valid_number, '福島県南会津郡南会津町内川');
ok($zip->set_number('9670512')->is_valid_number, '福島県南会津郡南会津町耻風');
ok($zip->set_number('9670513')->is_valid_number, '福島県南会津郡南会津町大原');
ok($zip->set_number('9670514')->is_valid_number, '福島県南会津郡南会津町小立岩');
ok($zip->set_number('9670515')->is_valid_number, '福島県南会津郡南会津町大桃');
ok($zip->set_number('9670521')->is_valid_number, '福島県南会津郡檜枝岐村居平');
ok($zip->set_number('9670522')->is_valid_number, '福島県南会津郡檜枝岐村上ノ原');
ok($zip->set_number('9670523')->is_valid_number, '福島県南会津郡檜枝岐村下ノ台');
ok($zip->set_number('9670524')->is_valid_number, '福島県南会津郡檜枝岐村上ノ台');
ok($zip->set_number('9670525')->is_valid_number, '福島県南会津郡檜枝岐村下ノ原');
ok($zip->set_number('9670526')->is_valid_number, '福島県南会津郡檜枝岐村滝沢');
ok($zip->set_number('9670527')->is_valid_number, '福島県南会津郡檜枝岐村見通');
ok($zip->set_number('9670528')->is_valid_number, '福島県南会津郡檜枝岐村葭ケ平');
ok($zip->set_number('9670531')->is_valid_number, '福島県南会津郡檜枝岐村燧ケ岳');
ok($zip->set_number('9670532')->is_valid_number, '福島県南会津郡檜枝岐村尾瀬沼');
ok($zip->set_number('9670601')->is_valid_number, '福島県南会津郡南会津町木伏');
ok($zip->set_number('9670602')->is_valid_number, '福島県南会津郡南会津町水根沢');
ok($zip->set_number('9670603')->is_valid_number, '福島県南会津郡南会津町大新田');
ok($zip->set_number('9670604')->is_valid_number, '福島県南会津郡南会津町大橋');
ok($zip->set_number('9670605')->is_valid_number, '福島県南会津郡南会津町東');
ok($zip->set_number('9670611')->is_valid_number, '福島県南会津郡南会津町山口');
ok($zip->set_number('9670621')->is_valid_number, '福島県南会津郡南会津町鴇巣');
ok($zip->set_number('9670622')->is_valid_number, '福島県南会津郡南会津町宮床');
ok($zip->set_number('9670631')->is_valid_number, '福島県南会津郡南会津町界');
ok($zip->set_number('9670632')->is_valid_number, '福島県南会津郡南会津町片貝');
ok($zip->set_number('9670633')->is_valid_number, '福島県南会津郡南会津町富山');
ok($zip->set_number('9670634')->is_valid_number, '福島県南会津郡南会津町下山');
ok($zip->set_number('9670641')->is_valid_number, '福島県南会津郡南会津町和泉田');
ok($zip->set_number('9670642')->is_valid_number, '福島県南会津郡南会津町小野島');
ok($zip->set_number('9680000')->is_valid_number, '福島県大沼郡金山町以下に掲載がない場合');
ok($zip->set_number('9680001')->is_valid_number, '福島県大沼郡金山町水沼');
ok($zip->set_number('9680002')->is_valid_number, '福島県大沼郡金山町大栗山');
ok($zip->set_number('9680003')->is_valid_number, '福島県大沼郡金山町沼沢');
ok($zip->set_number('9680004')->is_valid_number, '福島県大沼郡金山町太郎布');
ok($zip->set_number('9680005')->is_valid_number, '福島県大沼郡金山町大志');
ok($zip->set_number('9680006')->is_valid_number, '福島県大沼郡金山町中川');
ok($zip->set_number('9680011')->is_valid_number, '福島県大沼郡金山町川口');
ok($zip->set_number('9680012')->is_valid_number, '福島県大沼郡金山町小栗山');
ok($zip->set_number('9680013')->is_valid_number, '福島県大沼郡金山町八町');
ok($zip->set_number('9680014')->is_valid_number, '福島県大沼郡金山町玉梨');
ok($zip->set_number('9680015')->is_valid_number, '福島県大沼郡金山町西谷');
ok($zip->set_number('9680016')->is_valid_number, '福島県大沼郡金山町本名');
ok($zip->set_number('9680100')->is_valid_number, '福島県大沼郡昭和村以下に掲載がない場合');
ok($zip->set_number('9680101')->is_valid_number, '福島県大沼郡昭和村松山');
ok($zip->set_number('9680102')->is_valid_number, '福島県大沼郡昭和村野尻');
ok($zip->set_number('9680103')->is_valid_number, '福島県大沼郡昭和村下中津川');
ok($zip->set_number('9680104')->is_valid_number, '福島県大沼郡昭和村小中津川');
ok($zip->set_number('9680211')->is_valid_number, '福島県大沼郡昭和村小野川');
ok($zip->set_number('9680212')->is_valid_number, '福島県大沼郡昭和村喰丸');
ok($zip->set_number('9680213')->is_valid_number, '福島県大沼郡昭和村両原');
ok($zip->set_number('9680214')->is_valid_number, '福島県大沼郡昭和村大芦');
ok($zip->set_number('9680215')->is_valid_number, '福島県大沼郡昭和村佐倉');
ok($zip->set_number('9680321')->is_valid_number, '福島県大沼郡金山町越川');
ok($zip->set_number('9680322')->is_valid_number, '福島県大沼郡金山町横田');
ok($zip->set_number('9680323')->is_valid_number, '福島県大沼郡金山町山入');
ok($zip->set_number('9680324')->is_valid_number, '福島県大沼郡金山町田沢');
ok($zip->set_number('9680325')->is_valid_number, '福島県大沼郡金山町滝沢');
ok($zip->set_number('9680326')->is_valid_number, '福島県大沼郡金山町大塩');
ok($zip->set_number('9680400')->is_valid_number, '福島県南会津郡只見町以下に掲載がない場合');
ok($zip->set_number('9680411')->is_valid_number, '福島県南会津郡只見町塩沢');
ok($zip->set_number('9680412')->is_valid_number, '福島県南会津郡只見町十島');
ok($zip->set_number('9680413')->is_valid_number, '福島県南会津郡只見町寄岩');
ok($zip->set_number('9680414')->is_valid_number, '福島県南会津郡只見町蒲生');
ok($zip->set_number('9680415')->is_valid_number, '福島県南会津郡只見町叶津');
ok($zip->set_number('9680421')->is_valid_number, '福島県南会津郡只見町只見');
ok($zip->set_number('9680422')->is_valid_number, '福島県南会津郡只見町石伏');
ok($zip->set_number('9680423')->is_valid_number, '福島県南会津郡只見町田子倉');
ok($zip->set_number('9680431')->is_valid_number, '福島県南会津郡只見町楢戸');
ok($zip->set_number('9680432')->is_valid_number, '福島県南会津郡只見町黒沢');
ok($zip->set_number('9680433')->is_valid_number, '福島県南会津郡只見町福井');
ok($zip->set_number('9680434')->is_valid_number, '福島県南会津郡只見町小川');
ok($zip->set_number('9680441')->is_valid_number, '福島県南会津郡只見町黒谷');
ok($zip->set_number('9680442')->is_valid_number, '福島県南会津郡只見町長浜');
ok($zip->set_number('9680443')->is_valid_number, '福島県南会津郡只見町荒島');
ok($zip->set_number('9680444')->is_valid_number, '福島県南会津郡只見町熊倉');
ok($zip->set_number('9680445')->is_valid_number, '福島県南会津郡只見町亀岡');
ok($zip->set_number('9680601')->is_valid_number, '福島県南会津郡只見町小林');
ok($zip->set_number('9680602')->is_valid_number, '福島県南会津郡只見町大倉');
ok($zip->set_number('9680603')->is_valid_number, '福島県南会津郡只見町梁取');
ok($zip->set_number('9680604')->is_valid_number, '福島県南会津郡只見町塩ノ岐');
ok($zip->set_number('9680605')->is_valid_number, '福島県南会津郡只見町二軒在家');
ok($zip->set_number('9680606')->is_valid_number, '福島県南会津郡只見町坂田');
ok($zip->set_number('9680607')->is_valid_number, '福島県南会津郡只見町布沢');
ok($zip->set_number('9690100')->is_valid_number, '福島県西白河郡泉崎村以下に掲載がない場合');
ok($zip->set_number('9690101')->is_valid_number, '福島県西白河郡泉崎村泉崎');
ok($zip->set_number('9690102')->is_valid_number, '福島県西白河郡泉崎村関和久(その他)');
ok($zip->set_number('9690103')->is_valid_number, '福島県西白河郡泉崎村北平山');
ok($zip->set_number('9690104')->is_valid_number, '福島県西白河郡泉崎村太田川');
ok($zip->set_number('9690105')->is_valid_number, '福島県西白河郡泉崎村踏瀬');
ok($zip->set_number('9690106')->is_valid_number, '福島県西白河郡泉崎村関和久(八雲神社)');
ok($zip->set_number('9690200')->is_valid_number, '福島県西白河郡矢吹町以下に掲載がない場合');
ok($zip->set_number('9690201')->is_valid_number, '福島県西白河郡矢吹町大町');
ok($zip->set_number('9690202')->is_valid_number, '福島県西白河郡矢吹町新町');
ok($zip->set_number('9690203')->is_valid_number, '福島県西白河郡矢吹町北浦');
ok($zip->set_number('9690204')->is_valid_number, '福島県西白河郡矢吹町関山');
ok($zip->set_number('9690205')->is_valid_number, '福島県西白河郡矢吹町五本松');
ok($zip->set_number('9690206')->is_valid_number, '福島県西白河郡矢吹町赤沢');
ok($zip->set_number('9690211')->is_valid_number, '福島県西白河郡矢吹町北町');
ok($zip->set_number('9690212')->is_valid_number, '福島県西白河郡矢吹町善郷内');
ok($zip->set_number('9690213')->is_valid_number, '福島県西白河郡矢吹町本町');
ok($zip->set_number('9690221')->is_valid_number, '福島県西白河郡矢吹町中町');
ok($zip->set_number('9690222')->is_valid_number, '福島県西白河郡矢吹町八幡町');
ok($zip->set_number('9690223')->is_valid_number, '福島県西白河郡矢吹町文京町');
ok($zip->set_number('9690224')->is_valid_number, '福島県西白河郡矢吹町大久保');
ok($zip->set_number('9690225')->is_valid_number, '福島県西白河郡矢吹町東長峰');
ok($zip->set_number('9690226')->is_valid_number, '福島県西白河郡矢吹町西長峰');
ok($zip->set_number('9690227')->is_valid_number, '福島県西白河郡矢吹町田町');
ok($zip->set_number('9690231')->is_valid_number, '福島県西白河郡矢吹町中丸');
ok($zip->set_number('9690232')->is_valid_number, '福島県西白河郡矢吹町本城舘');
ok($zip->set_number('9690233')->is_valid_number, '福島県西白河郡矢吹町花の里');
ok($zip->set_number('9690234')->is_valid_number, '福島県西白河郡矢吹町前田');
ok($zip->set_number('9690235')->is_valid_number, '福島県西白河郡矢吹町丸の内');
ok($zip->set_number('9690236')->is_valid_number, '福島県西白河郡矢吹町一本木');
ok($zip->set_number('9690236')->is_valid_number, '福島県西白河郡矢吹町中畑新田');
ok($zip->set_number('9690236')->is_valid_number, '福島県西白河郡矢吹町矢吹');
ok($zip->set_number('9690237')->is_valid_number, '福島県西白河郡矢吹町牡丹平');
ok($zip->set_number('9690238')->is_valid_number, '福島県西白河郡矢吹町大池');
ok($zip->set_number('9690241')->is_valid_number, '福島県西白河郡矢吹町陣ケ岡');
ok($zip->set_number('9690241')->is_valid_number, '福島県西白河郡矢吹町天開');
ok($zip->set_number('9690242')->is_valid_number, '福島県西白河郡矢吹町三城目');
ok($zip->set_number('9690243')->is_valid_number, '福島県西白河郡矢吹町中沖');
ok($zip->set_number('9690243')->is_valid_number, '福島県西白河郡矢吹町東川原');
ok($zip->set_number('9690244')->is_valid_number, '福島県西白河郡矢吹町奉行塚');
ok($zip->set_number('9690244')->is_valid_number, '福島県西白河郡矢吹町谷中');
ok($zip->set_number('9690245')->is_valid_number, '福島県西白河郡矢吹町白山');
ok($zip->set_number('9690246')->is_valid_number, '福島県西白河郡矢吹町上宮崎');
ok($zip->set_number('9690246')->is_valid_number, '福島県西白河郡矢吹町下宮崎');
ok($zip->set_number('9690247')->is_valid_number, '福島県西白河郡矢吹町諏訪の前');
ok($zip->set_number('9690247')->is_valid_number, '福島県西白河郡矢吹町寺の前');
ok($zip->set_number('9690248')->is_valid_number, '福島県西白河郡矢吹町東郷');
ok($zip->set_number('9690251')->is_valid_number, '福島県西白河郡矢吹町神田東');
ok($zip->set_number('9690251')->is_valid_number, '福島県西白河郡矢吹町神田西');
ok($zip->set_number('9690251')->is_valid_number, '福島県西白河郡矢吹町神田南');
ok($zip->set_number('9690252')->is_valid_number, '福島県西白河郡矢吹町神の内');
ok($zip->set_number('9690252')->is_valid_number, '福島県西白河郡矢吹町堤');
ok($zip->set_number('9690252')->is_valid_number, '福島県西白河郡矢吹町中野目東');
ok($zip->set_number('9690252')->is_valid_number, '福島県西白河郡矢吹町中野目西');
ok($zip->set_number('9690252')->is_valid_number, '福島県西白河郡矢吹町東堤');
ok($zip->set_number('9690253')->is_valid_number, '福島県西白河郡矢吹町明新上');
ok($zip->set_number('9690253')->is_valid_number, '福島県西白河郡矢吹町明新中');
ok($zip->set_number('9690253')->is_valid_number, '福島県西白河郡矢吹町明新下');
ok($zip->set_number('9690253')->is_valid_number, '福島県西白河郡矢吹町明新原');
ok($zip->set_number('9690253')->is_valid_number, '福島県西白河郡矢吹町明新東');
ok($zip->set_number('9690253')->is_valid_number, '福島県西白河郡矢吹町明新西');
ok($zip->set_number('9690254')->is_valid_number, '福島県西白河郡矢吹町平鉢');
ok($zip->set_number('9690255')->is_valid_number, '福島県西白河郡矢吹町寺内');
ok($zip->set_number('9690255')->is_valid_number, '福島県西白河郡矢吹町寺内東');
ok($zip->set_number('9690255')->is_valid_number, '福島県西白河郡矢吹町寺内西');
ok($zip->set_number('9690255')->is_valid_number, '福島県西白河郡矢吹町寺内南');
ok($zip->set_number('9690256')->is_valid_number, '福島県西白河郡矢吹町鍋内');
ok($zip->set_number('9690257')->is_valid_number, '福島県西白河郡矢吹町上の前');
ok($zip->set_number('9690257')->is_valid_number, '福島県西白河郡矢吹町住吉');
ok($zip->set_number('9690257')->is_valid_number, '福島県西白河郡矢吹町前久保');
ok($zip->set_number('9690258')->is_valid_number, '福島県西白河郡矢吹町沢尻');
ok($zip->set_number('9690261')->is_valid_number, '福島県西白河郡矢吹町弥栄');
ok($zip->set_number('9690262')->is_valid_number, '福島県西白河郡矢吹町松房');
ok($zip->set_number('9690263')->is_valid_number, '福島県西白河郡矢吹町根宿');
ok($zip->set_number('9690264')->is_valid_number, '福島県西白河郡矢吹町中畑');
ok($zip->set_number('9690265')->is_valid_number, '福島県西白河郡矢吹町中畑南');
ok($zip->set_number('9690266')->is_valid_number, '福島県西白河郡矢吹町上敷面');
ok($zip->set_number('9690267')->is_valid_number, '福島県西白河郡矢吹町諏訪清水');
ok($zip->set_number('9690268')->is_valid_number, '福島県西白河郡矢吹町松倉');
ok($zip->set_number('9690271')->is_valid_number, '福島県西白河郡矢吹町小松');
ok($zip->set_number('9690272')->is_valid_number, '福島県西白河郡矢吹町曙町');
ok($zip->set_number('9690281')->is_valid_number, '福島県西白河郡矢吹町境町');
ok($zip->set_number('9690281')->is_valid_number, '福島県西白河郡矢吹町馬場');
ok($zip->set_number('9690282')->is_valid_number, '福島県西白河郡矢吹町本郷町');
ok($zip->set_number('9690283')->is_valid_number, '福島県西白河郡矢吹町南町');
ok($zip->set_number('9690284')->is_valid_number, '福島県西白河郡矢吹町滝八幡');
ok($zip->set_number('9690284')->is_valid_number, '福島県西白河郡矢吹町舘沢');
ok($zip->set_number('9690285')->is_valid_number, '福島県西白河郡矢吹町花咲');
ok($zip->set_number('9690286')->is_valid_number, '福島県西白河郡矢吹町大和内');
ok($zip->set_number('9690287')->is_valid_number, '福島県西白河郡矢吹町井戸尻');
ok($zip->set_number('9690287')->is_valid_number, '福島県西白河郡矢吹町川原');
ok($zip->set_number('9690287')->is_valid_number, '福島県西白河郡矢吹町堰の上');
ok($zip->set_number('9690288')->is_valid_number, '福島県西白河郡矢吹町子ハ清水');
ok($zip->set_number('9690288')->is_valid_number, '福島県西白河郡矢吹町田内');
ok($zip->set_number('9690288')->is_valid_number, '福島県西白河郡矢吹町東の内');
ok($zip->set_number('9690301')->is_valid_number, '福島県白河市大信上新城');
ok($zip->set_number('9690302')->is_valid_number, '福島県白河市大信隈戸(その他)');
ok($zip->set_number('9690303')->is_valid_number, '福島県白河市大信下小屋');
ok($zip->set_number('9690304')->is_valid_number, '福島県白河市大信下新城');
ok($zip->set_number('9690305')->is_valid_number, '福島県白河市大信田園町府');
ok($zip->set_number('9690306')->is_valid_number, '福島県白河市大信豊地');
ok($zip->set_number('9690307')->is_valid_number, '福島県白河市大信中新城');
ok($zip->set_number('9690308')->is_valid_number, '福島県白河市大信増見');
ok($zip->set_number('9690309')->is_valid_number, '福島県白河市大信町屋');
ok($zip->set_number('9690400')->is_valid_number, '福島県岩瀬郡鏡石町以下に掲載がない場合');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町池ノ原');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町大池');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町岡ノ内');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町鏡田かげ沼町');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町鏡沼');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町鹿島');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町蒲之沢町');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町川崎町');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町五斗蒔町');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町境');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町桜町');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町高久田');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町豊田');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町仁井田');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町東鹿島');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町深内町');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町不時沼');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町前山');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町南高久田');
ok($zip->set_number('9690401')->is_valid_number, '福島県岩瀬郡鏡石町本町');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町池の台');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町大宮');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町河原');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町北町');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町新町');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町諏訪町');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町成田');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町成田原町');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町成田東');
ok($zip->set_number('9690402')->is_valid_number, '福島県岩瀬郡鏡石町東河原');
ok($zip->set_number('9690403')->is_valid_number, '福島県岩瀬郡鏡石町借宿');
ok($zip->set_number('9690403')->is_valid_number, '福島県岩瀬郡鏡石町久来石');
ok($zip->set_number('9690403')->is_valid_number, '福島県岩瀬郡鏡石町久来石南');
ok($zip->set_number('9690403')->is_valid_number, '福島県岩瀬郡鏡石町小栗山');
ok($zip->set_number('9690403')->is_valid_number, '福島県岩瀬郡鏡石町桜岡');
ok($zip->set_number('9690403')->is_valid_number, '福島県岩瀬郡鏡石町城ノ内');
ok($zip->set_number('9690403')->is_valid_number, '福島県岩瀬郡鏡石町堂前');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町旭町');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町大山');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町岡の台');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町笠石');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町笠石原町');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町中央');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町豊郷');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町豊郷中');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町中町');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町羽鳥');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町東町');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町堀米');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町緑町');
ok($zip->set_number('9690404')->is_valid_number, '福島県岩瀬郡鏡石町南町');
ok($zip->set_number('9691100')->is_valid_number, '福島県本宮市以下に掲載がない場合');
ok($zip->set_number('9691101')->is_valid_number, '福島県本宮市高木');
ok($zip->set_number('9691103')->is_valid_number, '福島県本宮市仁井田');
ok($zip->set_number('9691104')->is_valid_number, '福島県本宮市荒井');
ok($zip->set_number('9691105')->is_valid_number, '福島県本宮市関下');
ok($zip->set_number('9691106')->is_valid_number, '福島県本宮市岩根');
ok($zip->set_number('9691107')->is_valid_number, '福島県本宮市青田');
ok($zip->set_number('9691108')->is_valid_number, '福島県本宮市本宮堀切');
ok($zip->set_number('9691109')->is_valid_number, '福島県本宮市本宮富ヶ峰');
ok($zip->set_number('9691111')->is_valid_number, '福島県本宮市本宮作田');
ok($zip->set_number('9691111')->is_valid_number, '福島県本宮市本宮作田台');
ok($zip->set_number('9691112')->is_valid_number, '福島県本宮市本宮大榎');
ok($zip->set_number('9691113')->is_valid_number, '福島県本宮市本宮坊屋敷');
ok($zip->set_number('9691114')->is_valid_number, '福島県本宮市本宮関根');
ok($zip->set_number('9691115')->is_valid_number, '福島県本宮市本宮立石');
ok($zip->set_number('9691116')->is_valid_number, '福島県本宮市本宮弁天');
ok($zip->set_number('9691117')->is_valid_number, '福島県本宮市本宮鹿ノ子田');
ok($zip->set_number('9691118')->is_valid_number, '福島県本宮市本宮下台');
ok($zip->set_number('9691119')->is_valid_number, '福島県本宮市本宮柳ノ内');
ok($zip->set_number('9691121')->is_valid_number, '福島県本宮市本宮舘ノ越');
ok($zip->set_number('9691122')->is_valid_number, '福島県本宮市本宮大町');
ok($zip->set_number('9691123')->is_valid_number, '福島県本宮市本宮東町');
ok($zip->set_number('9691123')->is_valid_number, '福島県本宮市本宮東町裏');
ok($zip->set_number('9691124')->is_valid_number, '福島県本宮市本宮仲町');
ok($zip->set_number('9691125')->is_valid_number, '福島県本宮市本宮荒町');
ok($zip->set_number('9691126')->is_valid_number, '福島県本宮市本宮馬場');
ok($zip->set_number('9691127')->is_valid_number, '福島県本宮市本宮鉄砲町');
ok($zip->set_number('9691128')->is_valid_number, '福島県本宮市本宮舘町');
ok($zip->set_number('9691129')->is_valid_number, '福島県本宮市本宮鍛冶免');
ok($zip->set_number('9691129')->is_valid_number, '福島県本宮市本宮矢来');
ok($zip->set_number('9691131')->is_valid_number, '福島県本宮市本宮南町裡');
ok($zip->set_number('9691132')->is_valid_number, '福島県本宮市本宮下町');
ok($zip->set_number('9691133')->is_valid_number, '福島県本宮市本宮中條');
ok($zip->set_number('9691134')->is_valid_number, '福島県本宮市本宮上町');
ok($zip->set_number('9691135')->is_valid_number, '福島県本宮市本宮土樋');
ok($zip->set_number('9691135')->is_valid_number, '福島県本宮市本宮蛭田');
ok($zip->set_number('9691136')->is_valid_number, '福島県本宮市本宮九縄');
ok($zip->set_number('9691137')->is_valid_number, '福島県本宮市本宮太郎丸');
ok($zip->set_number('9691138')->is_valid_number, '福島県本宮市本宮鳴瀬');
ok($zip->set_number('9691139')->is_valid_number, '福島県本宮市本宮石塚');
ok($zip->set_number('9691141')->is_valid_number, '福島県本宮市本宮兼谷');
ok($zip->set_number('9691142')->is_valid_number, '福島県本宮市本宮兼谷平');
ok($zip->set_number('9691143')->is_valid_number, '福島県本宮市本宮山田');
ok($zip->set_number('9691144')->is_valid_number, '福島県本宮市本宮大森');
ok($zip->set_number('9691145')->is_valid_number, '福島県本宮市本宮葭ヶ入');
ok($zip->set_number('9691146')->is_valid_number, '福島県本宮市本宮南山神');
ok($zip->set_number('9691147')->is_valid_number, '福島県本宮市本宮花町');
ok($zip->set_number('9691148')->is_valid_number, '福島県本宮市本宮栄田');
ok($zip->set_number('9691149')->is_valid_number, '福島県本宮市本宮万世');
ok($zip->set_number('9691151')->is_valid_number, '福島県本宮市本宮千代田');
ok($zip->set_number('9691152')->is_valid_number, '福島県本宮市本宮上千束');
ok($zip->set_number('9691152')->is_valid_number, '福島県本宮市本宮千束');
ok($zip->set_number('9691153')->is_valid_number, '福島県本宮市本宮塩田入');
ok($zip->set_number('9691154')->is_valid_number, '福島県本宮市本宮塩田');
ok($zip->set_number('9691155')->is_valid_number, '福島県本宮市本宮懸鉄');
ok($zip->set_number('9691155')->is_valid_number, '福島県本宮市本宮反町');
ok($zip->set_number('9691155')->is_valid_number, '福島県本宮市本宮雲雀田');
ok($zip->set_number('9691155')->is_valid_number, '福島県本宮市本宮舞台');
ok($zip->set_number('9691156')->is_valid_number, '福島県本宮市本宮諏訪');
ok($zip->set_number('9691156')->is_valid_number, '福島県本宮市本宮鍋田');
ok($zip->set_number('9691157')->is_valid_number, '福島県本宮市本宮瀬樋内');
ok($zip->set_number('9691157')->is_valid_number, '福島県本宮市本宮田中');
ok($zip->set_number('9691158')->is_valid_number, '福島県本宮市本宮天ヶ');
ok($zip->set_number('9691158')->is_valid_number, '福島県本宮市本宮蛇ノ鼻');
ok($zip->set_number('9691158')->is_valid_number, '福島県本宮市本宮平井');
ok($zip->set_number('9691159')->is_valid_number, '福島県本宮市本宮小幡');
ok($zip->set_number('9691159')->is_valid_number, '福島県本宮市本宮小籏北');
ok($zip->set_number('9691159')->is_valid_number, '福島県本宮市本宮広町');
ok($zip->set_number('9691161')->is_valid_number, '福島県本宮市本宮欠下');
ok($zip->set_number('9691162')->is_valid_number, '福島県本宮市本宮北川原田');
ok($zip->set_number('9691162')->is_valid_number, '福島県本宮市本宮南河原田');
ok($zip->set_number('9691163')->is_valid_number, '福島県本宮市本宮白川');
ok($zip->set_number('9691164')->is_valid_number, '福島県本宮市本宮戸崎');
ok($zip->set_number('9691165')->is_valid_number, '福島県本宮市本宮中台');
ok($zip->set_number('9691166')->is_valid_number, '福島県本宮市本宮近江内');
ok($zip->set_number('9691167')->is_valid_number, '福島県本宮市本宮北山神');
ok($zip->set_number('9691167')->is_valid_number, '福島県本宮市本宮道屋敷');
ok($zip->set_number('9691168')->is_valid_number, '福島県本宮市本宮一ッ屋');
ok($zip->set_number('9691169')->is_valid_number, '福島県本宮市本宮小原田');
ok($zip->set_number('9691171')->is_valid_number, '福島県本宮市本宮樋ノ口');
ok($zip->set_number('9691172')->is_valid_number, '福島県本宮市本宮北ノ内');
ok($zip->set_number('9691173')->is_valid_number, '福島県本宮市本宮中野');
ok($zip->set_number('9691173')->is_valid_number, '福島県本宮市本宮中野後');
ok($zip->set_number('9691174')->is_valid_number, '福島県本宮市本宮南ノ内');
ok($zip->set_number('9691175')->is_valid_number, '福島県本宮市本宮竹花');
ok($zip->set_number('9691175')->is_valid_number, '福島県本宮市本宮名郷');
ok($zip->set_number('9691175')->is_valid_number, '福島県本宮市本宮名郷脇');
ok($zip->set_number('9691176')->is_valid_number, '福島県本宮市本宮赤坂');
ok($zip->set_number('9691176')->is_valid_number, '福島県本宮市本宮地蔵堂');
ok($zip->set_number('9691201')->is_valid_number, '福島県本宮市稲沢');
ok($zip->set_number('9691202')->is_valid_number, '福島県本宮市松沢');
ok($zip->set_number('9691203')->is_valid_number, '福島県本宮市白岩');
ok($zip->set_number('9691204')->is_valid_number, '福島県本宮市糠沢');
ok($zip->set_number('9691205')->is_valid_number, '福島県本宮市和田');
ok($zip->set_number('9691206')->is_valid_number, '福島県本宮市長屋');
ok($zip->set_number('9691300')->is_valid_number, '福島県安達郡大玉村以下に掲載がない場合');
ok($zip->set_number('9691301')->is_valid_number, '福島県安達郡大玉村大山');
ok($zip->set_number('9691302')->is_valid_number, '福島県安達郡大玉村玉井(その他)');
ok($zip->set_number('9691401')->is_valid_number, '福島県二本松市吉倉');
ok($zip->set_number('9691402')->is_valid_number, '福島県二本松市米沢');
ok($zip->set_number('9691403')->is_valid_number, '福島県二本松市渋川');
ok($zip->set_number('9691404')->is_valid_number, '福島県二本松市油井');
ok($zip->set_number('9691405')->is_valid_number, '福島県二本松市智恵子の森');
ok($zip->set_number('9691511')->is_valid_number, '福島県二本松市下川崎');
ok($zip->set_number('9691512')->is_valid_number, '福島県二本松市上川崎');
ok($zip->set_number('9691513')->is_valid_number, '福島県二本松市小沢');
ok($zip->set_number('9691600')->is_valid_number, '福島県伊達郡桑折町以下に掲載がない場合');
ok($zip->set_number('9691601')->is_valid_number, '福島県伊達郡桑折町北町');
ok($zip->set_number('9691602')->is_valid_number, '福島県伊達郡桑折町町裏');
ok($zip->set_number('9691603')->is_valid_number, '福島県伊達郡桑折町上町');
ok($zip->set_number('9691604')->is_valid_number, '福島県伊達郡桑折町堰下');
ok($zip->set_number('9691605')->is_valid_number, '福島県伊達郡桑折町堰合');
ok($zip->set_number('9691606')->is_valid_number, '福島県伊達郡桑折町東段');
ok($zip->set_number('9691607')->is_valid_number, '福島県伊達郡桑折町西段');
ok($zip->set_number('9691608')->is_valid_number, '福島県伊達郡桑折町芝堤');
ok($zip->set_number('9691611')->is_valid_number, '福島県伊達郡桑折町東大隅');
ok($zip->set_number('9691612')->is_valid_number, '福島県伊達郡桑折町西大隅');
ok($zip->set_number('9691613')->is_valid_number, '福島県伊達郡桑折町桑島');
ok($zip->set_number('9691614')->is_valid_number, '福島県伊達郡桑折町本町');
ok($zip->set_number('9691615')->is_valid_number, '福島県伊達郡桑折町沢');
ok($zip->set_number('9691616')->is_valid_number, '福島県伊達郡桑折町舘');
ok($zip->set_number('9691617')->is_valid_number, '福島県伊達郡桑折町陣屋');
ok($zip->set_number('9691618')->is_valid_number, '福島県伊達郡桑折町庫場');
ok($zip->set_number('9691619')->is_valid_number, '福島県伊達郡桑折町仮屋');
ok($zip->set_number('9691621')->is_valid_number, '福島県伊達郡桑折町道場前');
ok($zip->set_number('9691622')->is_valid_number, '福島県伊達郡桑折町南町');
ok($zip->set_number('9691623')->is_valid_number, '福島県伊達郡桑折町和尚堂');
ok($zip->set_number('9691624')->is_valid_number, '福島県伊達郡桑折町新和町');
ok($zip->set_number('9691625')->is_valid_number, '福島県伊達郡桑折町新吉町');
ok($zip->set_number('9691626')->is_valid_number, '福島県伊達郡桑折町寺坂');
ok($zip->set_number('9691627')->is_valid_number, '福島県伊達郡桑折町諏訪');
ok($zip->set_number('9691628')->is_valid_number, '福島県伊達郡桑折町新町');
ok($zip->set_number('9691629')->is_valid_number, '福島県伊達郡桑折町西町');
ok($zip->set_number('9691631')->is_valid_number, '福島県伊達郡桑折町白銀');
ok($zip->set_number('9691631')->is_valid_number, '福島県伊達郡桑折町薮内');
ok($zip->set_number('9691632')->is_valid_number, '福島県伊達郡桑折町田植');
ok($zip->set_number('9691633')->is_valid_number, '福島県伊達郡桑折町赤坂');
ok($zip->set_number('9691633')->is_valid_number, '福島県伊達郡桑折町一里壇');
ok($zip->set_number('9691633')->is_valid_number, '福島県伊達郡桑折町界');
ok($zip->set_number('9691634')->is_valid_number, '福島県伊達郡桑折町落合');
ok($zip->set_number('9691634')->is_valid_number, '福島県伊達郡桑折町杉ノ前');
ok($zip->set_number('9691634')->is_valid_number, '福島県伊達郡桑折町砂子沢');
ok($zip->set_number('9691635')->is_valid_number, '福島県伊達郡桑折町狐崎');
ok($zip->set_number('9691635')->is_valid_number, '福島県伊達郡桑折町東八串');
ok($zip->set_number('9691641')->is_valid_number, '福島県伊達郡桑折町南半田');
ok($zip->set_number('9691642')->is_valid_number, '福島県伊達郡桑折町北半田');
ok($zip->set_number('9691643')->is_valid_number, '福島県伊達郡桑折町谷地');
ok($zip->set_number('9691651')->is_valid_number, '福島県伊達郡桑折町万正寺');
ok($zip->set_number('9691652')->is_valid_number, '福島県伊達郡桑折町成田');
ok($zip->set_number('9691653')->is_valid_number, '福島県伊達郡桑折町松原');
ok($zip->set_number('9691654')->is_valid_number, '福島県伊達郡桑折町平沢');
ok($zip->set_number('9691661')->is_valid_number, '福島県伊達郡桑折町上郡');
ok($zip->set_number('9691662')->is_valid_number, '福島県伊達郡桑折町下郡');
ok($zip->set_number('9691663')->is_valid_number, '福島県伊達郡桑折町伊達崎');
ok($zip->set_number('9691700')->is_valid_number, '福島県伊達郡国見町以下に掲載がない場合');
ok($zip->set_number('9691701')->is_valid_number, '福島県伊達郡国見町石母田');
ok($zip->set_number('9691711')->is_valid_number, '福島県伊達郡国見町貝田');
ok($zip->set_number('9691712')->is_valid_number, '福島県伊達郡国見町光明寺');
ok($zip->set_number('9691713')->is_valid_number, '福島県伊達郡国見町大木戸');
ok($zip->set_number('9691714')->is_valid_number, '福島県伊達郡国見町高城');
ok($zip->set_number('9691721')->is_valid_number, '福島県伊達郡国見町川内');
ok($zip->set_number('9691722')->is_valid_number, '福島県伊達郡国見町西大枝');
ok($zip->set_number('9691731')->is_valid_number, '福島県伊達郡国見町森山');
ok($zip->set_number('9691741')->is_valid_number, '福島県伊達郡国見町徳江');
ok($zip->set_number('9691751')->is_valid_number, '福島県伊達郡国見町塚野目');
ok($zip->set_number('9691761')->is_valid_number, '福島県伊達郡国見町藤田');
ok($zip->set_number('9691771')->is_valid_number, '福島県伊達郡国見町山崎');
ok($zip->set_number('9691780')->is_valid_number, '福島県伊達郡国見町新内谷');
ok($zip->set_number('9691781')->is_valid_number, '福島県伊達郡国見町内谷');
ok($zip->set_number('9691782')->is_valid_number, '福島県伊達郡国見町泉田');
ok($zip->set_number('9691783')->is_valid_number, '福島県伊達郡国見町鳥取');
ok($zip->set_number('9691784')->is_valid_number, '福島県伊達郡国見町小坂');
ok($zip->set_number('9691785')->is_valid_number, '福島県伊達郡国見町板橋南');
ok($zip->set_number('9691786')->is_valid_number, '福島県伊達郡国見町新泉田');
ok($zip->set_number('9691787')->is_valid_number, '福島県伊達郡国見町新小坂');
ok($zip->set_number('9691788')->is_valid_number, '福島県伊達郡国見町小坂南');
ok($zip->set_number('9691789')->is_valid_number, '福島県伊達郡国見町新鳥取');
ok($zip->set_number('9692271')->is_valid_number, '福島県耶麻郡猪苗代町中小松');
ok($zip->set_number('9692272')->is_valid_number, '福島県耶麻郡猪苗代町金田');
ok($zip->set_number('9692273')->is_valid_number, '福島県耶麻郡猪苗代町関都');
ok($zip->set_number('9692274')->is_valid_number, '福島県耶麻郡猪苗代町壺楊');
ok($zip->set_number('9692275')->is_valid_number, '福島県耶麻郡猪苗代町山潟');
ok($zip->set_number('9692661')->is_valid_number, '福島県耶麻郡猪苗代町三郷');
ok($zip->set_number('9692662')->is_valid_number, '福島県耶麻郡猪苗代町八幡');
ok($zip->set_number('9692663')->is_valid_number, '福島県耶麻郡猪苗代町川桁');
ok($zip->set_number('9692701')->is_valid_number, '福島県耶麻郡北塩原村桧原(秋元、荒砂沢山、裏磐梯、大府平、大府平原、小野川、小野川原、剣ケ峯、');
ok($zip->set_number('9692701')->is_valid_number, '福島県耶麻郡北塩原村狐鷹森、五色沼、甚九郎沢山、甚九郎山、曽原山、寺沢山、蛇平原山、湯平山、');
ok($zip->set_number('9692701')->is_valid_number, '福島県耶麻郡北塩原村簗部沢山)');
ok($zip->set_number('9692751')->is_valid_number, '福島県耶麻郡猪苗代町若宮');
ok($zip->set_number('9692752')->is_valid_number, '福島県耶麻郡猪苗代町蚕養');
ok($zip->set_number('9693100')->is_valid_number, '福島県耶麻郡猪苗代町以下に掲載がない場合');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町家ノ前');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町上ノ山');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町大谷地');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町欠上り');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町北ノ林');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町行人壇');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町グミ沢原');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町渋谷');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町清水');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町清水端');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町下辺沢');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町菖蒲田');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町新堀田東');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町新堀西');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町堰間上');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町芹沢');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町土湯沢山');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町土手間');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町中道西');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町長坂');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町沼ノ倉');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町琵琶沢原');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町辺沢');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町程塚');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町三ツ屋');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町村中');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町村北');
ok($zip->set_number('9693101')->is_valid_number, '福島県耶麻郡猪苗代町山神原');
ok($zip->set_number('9693102')->is_valid_number, '福島県耶麻郡猪苗代町右近山');
ok($zip->set_number('9693102')->is_valid_number, '福島県耶麻郡猪苗代町西峰');
ok($zip->set_number('9693102')->is_valid_number, '福島県耶麻郡猪苗代町猫石山');
ok($zip->set_number('9693102')->is_valid_number, '福島県耶麻郡猪苗代町葉山');
ok($zip->set_number('9693102')->is_valid_number, '福島県耶麻郡猪苗代町雛草');
ok($zip->set_number('9693102')->is_valid_number, '福島県耶麻郡猪苗代町見禰');
ok($zip->set_number('9693102')->is_valid_number, '福島県耶麻郡猪苗代町見禰山');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町鹿野境');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町上村前');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町上村東');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町桐木沢');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町五輪原');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町諏訪前');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町諏訪東');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町諏訪西');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町禰次');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町ハノ木沢');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町林崎');
ok($zip->set_number('9693103')->is_valid_number, '福島県耶麻郡猪苗代町町島田');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町雷');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町出雲壇');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町板橋北');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町太田');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町太田西');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町小黒川');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町窪田');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町窪ノ内');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町窪南');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町御三壇');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町五百苅');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町猿壇');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町二丁田');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町沼田');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町東町裏');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町明円');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町村東下');
ok($zip->set_number('9693111')->is_valid_number, '福島県耶麻郡猪苗代町村東');
ok($zip->set_number('9693112')->is_valid_number, '福島県耶麻郡猪苗代町堤');
ok($zip->set_number('9693112')->is_valid_number, '福島県耶麻郡猪苗代町寺後');
ok($zip->set_number('9693112')->is_valid_number, '福島県耶麻郡猪苗代町中町');
ok($zip->set_number('9693112')->is_valid_number, '福島県耶麻郡猪苗代町馬場');
ok($zip->set_number('9693112')->is_valid_number, '福島県耶麻郡猪苗代町弁才天西');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町大道西');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町北半坂');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町新地');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町茶園');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町堤下');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町堤北');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町鶴峰西');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町樋場');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町樋場道下');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町並杉西');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町土町');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町土町西裡');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町土町南');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町半坂');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町町西');
ok($zip->set_number('9693113')->is_valid_number, '福島県耶麻郡猪苗代町南半坂');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町芦原');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町裏町');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町オヒテ川');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町上ザル田');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町津金沢');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町寺東');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町梨木西');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町町東');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町横まくり');
ok($zip->set_number('9693121')->is_valid_number, '福島県耶麻郡猪苗代町横マクリ');
ok($zip->set_number('9693122')->is_valid_number, '福島県耶麻郡猪苗代町新町');
ok($zip->set_number('9693122')->is_valid_number, '福島県耶麻郡猪苗代町カキ田');
ok($zip->set_number('9693122')->is_valid_number, '福島県耶麻郡猪苗代町ガギ田');
ok($zip->set_number('9693122')->is_valid_number, '福島県耶麻郡猪苗代町坂下');
ok($zip->set_number('9693122')->is_valid_number, '福島県耶麻郡猪苗代町塚田');
ok($zip->set_number('9693122')->is_valid_number, '福島県耶麻郡猪苗代町町尻');
ok($zip->set_number('9693122')->is_valid_number, '福島県耶麻郡猪苗代町本町');
ok($zip->set_number('9693123')->is_valid_number, '福島県耶麻郡猪苗代町古城跡');
ok($zip->set_number('9693123')->is_valid_number, '福島県耶麻郡猪苗代町古城町');
ok($zip->set_number('9693123')->is_valid_number, '福島県耶麻郡猪苗代町城南');
ok($zip->set_number('9693123')->is_valid_number, '福島県耶麻郡猪苗代町鶴田');
ok($zip->set_number('9693131')->is_valid_number, '福島県耶麻郡猪苗代町今泉');
ok($zip->set_number('9693131')->is_valid_number, '福島県耶麻郡猪苗代町上屋敷');
ok($zip->set_number('9693131')->is_valid_number, '福島県耶麻郡猪苗代町下園');
ok($zip->set_number('9693131')->is_valid_number, '福島県耶麻郡猪苗代町新堀向');
ok($zip->set_number('9693131')->is_valid_number, '福島県耶麻郡猪苗代町西舘');
ok($zip->set_number('9693131')->is_valid_number, '福島県耶麻郡猪苗代町東谷地');
ok($zip->set_number('9693131')->is_valid_number, '福島県耶麻郡猪苗代町村南');
ok($zip->set_number('9693132')->is_valid_number, '福島県耶麻郡猪苗代町堅田');
ok($zip->set_number('9693133')->is_valid_number, '福島県耶麻郡猪苗代町千代田');
ok($zip->set_number('9693141')->is_valid_number, '福島県耶麻郡猪苗代町磐里');
ok($zip->set_number('9693141')->is_valid_number, '福島県耶麻郡猪苗代町六角');
ok($zip->set_number('9693281')->is_valid_number, '福島県耶麻郡猪苗代町西葉山');
ok($zip->set_number('9693282')->is_valid_number, '福島県耶麻郡猪苗代町酸奨沢');
ok($zip->set_number('9693283')->is_valid_number, '福島県耶麻郡猪苗代町長田');
ok($zip->set_number('9693284')->is_valid_number, '福島県耶麻郡猪苗代町三ツ和');
ok($zip->set_number('9693285')->is_valid_number, '福島県耶麻郡猪苗代町翁沢');
ok($zip->set_number('9693286')->is_valid_number, '福島県耶麻郡猪苗代町磐根');
ok($zip->set_number('9693287')->is_valid_number, '福島県耶麻郡猪苗代町不動');
ok($zip->set_number('9693288')->is_valid_number, '福島県耶麻郡猪苗代町綿場');
ok($zip->set_number('9693300')->is_valid_number, '福島県耶麻郡磐梯町以下に掲載がない場合');
ok($zip->set_number('9693301')->is_valid_number, '福島県耶麻郡磐梯町磐梯');
ok($zip->set_number('9693302')->is_valid_number, '福島県耶麻郡磐梯町更科');
ok($zip->set_number('9693303')->is_valid_number, '福島県耶麻郡磐梯町赤枝');
ok($zip->set_number('9693304')->is_valid_number, '福島県耶麻郡磐梯町大谷');
ok($zip->set_number('9693401')->is_valid_number, '福島県会津若松市河東町岡田');
ok($zip->set_number('9693402')->is_valid_number, '福島県会津若松市河東町福島');
ok($zip->set_number('9693411')->is_valid_number, '福島県会津若松市河東町大田原');
ok($zip->set_number('9693412')->is_valid_number, '福島県会津若松市河東町代田');
ok($zip->set_number('9693421')->is_valid_number, '福島県会津若松市河東町熊野堂');
ok($zip->set_number('9693422')->is_valid_number, '福島県会津若松市河東町広野');
ok($zip->set_number('9693431')->is_valid_number, '福島県会津若松市河東町東長原');
ok($zip->set_number('9693441')->is_valid_number, '福島県会津若松市河東町南高野');
ok($zip->set_number('9693451')->is_valid_number, '福島県会津若松市河東町八田');
ok($zip->set_number('9693461')->is_valid_number, '福島県会津若松市河東町浅山');
ok($zip->set_number('9693462')->is_valid_number, '福島県会津若松市河東町金田');
ok($zip->set_number('9693463')->is_valid_number, '福島県会津若松市河東町倉橋');
ok($zip->set_number('9693464')->is_valid_number, '福島県会津若松市河東町工業団地');
ok($zip->set_number('9693471')->is_valid_number, '福島県会津若松市河東町広田');
ok($zip->set_number('9693481')->is_valid_number, '福島県会津若松市河東町郡山');
ok($zip->set_number('9693482')->is_valid_number, '福島県会津若松市河東町谷沢');
ok($zip->set_number('9693500')->is_valid_number, '福島県河沼郡湯川村以下に掲載がない場合');
ok($zip->set_number('9693501')->is_valid_number, '福島県喜多方市塩川町三吉');
ok($zip->set_number('9693502')->is_valid_number, '福島県喜多方市塩川町常世');
ok($zip->set_number('9693503')->is_valid_number, '福島県喜多方市塩川町五合');
ok($zip->set_number('9693504')->is_valid_number, '福島県喜多方市塩川町中屋沢');
ok($zip->set_number('9693505')->is_valid_number, '福島県喜多方市塩川町金橋');
ok($zip->set_number('9693506')->is_valid_number, '福島県喜多方市塩川町窪');
ok($zip->set_number('9693511')->is_valid_number, '福島県喜多方市塩川町町北');
ok($zip->set_number('9693512')->is_valid_number, '福島県喜多方市塩川町東栄町');
ok($zip->set_number('9693513')->is_valid_number, '福島県喜多方市塩川町中町');
ok($zip->set_number('9693514')->is_valid_number, '福島県喜多方市塩川町新町');
ok($zip->set_number('9693515')->is_valid_number, '福島県喜多方市塩川町米沢町');
ok($zip->set_number('9693520')->is_valid_number, '福島県喜多方市塩川町古戸城');
ok($zip->set_number('9693521')->is_valid_number, '福島県喜多方市塩川町岡ノ前');
ok($zip->set_number('9693521')->is_valid_number, '福島県喜多方市塩川町東岡');
ok($zip->set_number('9693521')->is_valid_number, '福島県喜多方市塩川町身神');
ok($zip->set_number('9693522')->is_valid_number, '福島県喜多方市塩川町新丁');
ok($zip->set_number('9693523')->is_valid_number, '福島県喜多方市塩川町石橋');
ok($zip->set_number('9693523')->is_valid_number, '福島県喜多方市塩川町反町');
ok($zip->set_number('9693524')->is_valid_number, '福島県喜多方市塩川町清水岸');
ok($zip->set_number('9693524')->is_valid_number, '福島県喜多方市塩川町竹ノ花');
ok($zip->set_number('9693524')->is_valid_number, '福島県喜多方市塩川町舘ノ内');
ok($zip->set_number('9693525')->is_valid_number, '福島県喜多方市塩川町黄金田');
ok($zip->set_number('9693525')->is_valid_number, '福島県喜多方市塩川町諏訪前');
ok($zip->set_number('9693526')->is_valid_number, '福島県喜多方市塩川町諏訪町');
ok($zip->set_number('9693527')->is_valid_number, '福島県喜多方市塩川町御殿場');
ok($zip->set_number('9693528')->is_valid_number, '福島県喜多方市塩川町諏訪北');
ok($zip->set_number('9693529')->is_valid_number, '福島県喜多方市塩川町下前田');
ok($zip->set_number('9693531')->is_valid_number, '福島県喜多方市塩川町新井田谷地');
ok($zip->set_number('9693532')->is_valid_number, '福島県喜多方市塩川町大在家');
ok($zip->set_number('9693532')->is_valid_number, '福島県喜多方市塩川町経塚');
ok($zip->set_number('9693532')->is_valid_number, '福島県喜多方市塩川町小府根');
ok($zip->set_number('9693532')->is_valid_number, '福島県喜多方市塩川町高道');
ok($zip->set_number('9693532')->is_valid_number, '福島県喜多方市塩川町藤ノ木');
ok($zip->set_number('9693533')->is_valid_number, '福島県喜多方市塩川町新江木');
ok($zip->set_number('9693534')->is_valid_number, '福島県喜多方市塩川町遠田');
ok($zip->set_number('9693534')->is_valid_number, '福島県喜多方市塩川町西ノ新田');
ok($zip->set_number('9693535')->is_valid_number, '福島県喜多方市塩川町会知');
ok($zip->set_number('9693536')->is_valid_number, '福島県喜多方市塩川町大田木');
ok($zip->set_number('9693537')->is_valid_number, '福島県喜多方市塩川町四奈川');
ok($zip->set_number('9693538')->is_valid_number, '福島県喜多方市塩川町天沼');
ok($zip->set_number('9693539')->is_valid_number, '福島県喜多方市塩川町源太屋敷');
ok($zip->set_number('9693539')->is_valid_number, '福島県喜多方市塩川町吉沖');
ok($zip->set_number('9693541')->is_valid_number, '福島県河沼郡湯川村浜崎');
ok($zip->set_number('9693542')->is_valid_number, '福島県河沼郡湯川村湊');
ok($zip->set_number('9693543')->is_valid_number, '福島県河沼郡湯川村笈川');
ok($zip->set_number('9693544')->is_valid_number, '福島県河沼郡湯川村清水田');
ok($zip->set_number('9693545')->is_valid_number, '福島県河沼郡湯川村桜町');
ok($zip->set_number('9693546')->is_valid_number, '福島県河沼郡湯川村美田園');
ok($zip->set_number('9693551')->is_valid_number, '福島県河沼郡湯川村堂畑');
ok($zip->set_number('9693552')->is_valid_number, '福島県河沼郡湯川村三川');
ok($zip->set_number('9693553')->is_valid_number, '福島県河沼郡湯川村田川');
ok($zip->set_number('9693554')->is_valid_number, '福島県河沼郡湯川村熊ノ目');
ok($zip->set_number('9693555')->is_valid_number, '福島県河沼郡湯川村佐野目');
ok($zip->set_number('9693556')->is_valid_number, '福島県河沼郡湯川村勝常');
ok($zip->set_number('9694101')->is_valid_number, '福島県喜多方市山都町小舟寺');
ok($zip->set_number('9694102')->is_valid_number, '福島県喜多方市山都町一川');
ok($zip->set_number('9694103')->is_valid_number, '福島県喜多方市山都町木幡');
ok($zip->set_number('9694104')->is_valid_number, '福島県喜多方市山都町蓬莱');
ok($zip->set_number('9694105')->is_valid_number, '福島県喜多方市山都町三津合');
ok($zip->set_number('9694106')->is_valid_number, '福島県喜多方市山都町朝倉');
ok($zip->set_number('9694107')->is_valid_number, '福島県喜多方市山都町相川');
ok($zip->set_number('9694108')->is_valid_number, '福島県喜多方市山都町一ノ木');
ok($zip->set_number('9694109')->is_valid_number, '福島県喜多方市山都町早稲谷');
ok($zip->set_number('9694111')->is_valid_number, '福島県喜多方市山都町蔵ノ後');
ok($zip->set_number('9694112')->is_valid_number, '福島県喜多方市山都町上ノ原道東');
ok($zip->set_number('9694113')->is_valid_number, '福島県喜多方市山都町上ノ原道西');
ok($zip->set_number('9694114')->is_valid_number, '福島県喜多方市山都町小山');
ok($zip->set_number('9694115')->is_valid_number, '福島県喜多方市山都町五十苅');
ok($zip->set_number('9694116')->is_valid_number, '福島県喜多方市山都町清水上');
ok($zip->set_number('9694117')->is_valid_number, '福島県喜多方市山都町清水尻');
ok($zip->set_number('9694118')->is_valid_number, '福島県喜多方市山都町古屋敷');
ok($zip->set_number('9694119')->is_valid_number, '福島県喜多方市山都町江戸塚');
ok($zip->set_number('9694121')->is_valid_number, '福島県喜多方市山都町太田');
ok($zip->set_number('9694122')->is_valid_number, '福島県喜多方市山都町木曽');
ok($zip->set_number('9694123')->is_valid_number, '福島県喜多方市山都町中新田');
ok($zip->set_number('9694124')->is_valid_number, '福島県喜多方市山都町墓ノ後');
ok($zip->set_number('9694125')->is_valid_number, '福島県喜多方市山都町弥左エ門田');
ok($zip->set_number('9694126')->is_valid_number, '福島県喜多方市山都町馬放場');
ok($zip->set_number('9694127')->is_valid_number, '福島県喜多方市山都町久祢花');
ok($zip->set_number('9694130')->is_valid_number, '福島県喜多方市山都町松ノ前');
ok($zip->set_number('9694131')->is_valid_number, '福島県喜多方市山都町広野');
ok($zip->set_number('9694132')->is_valid_number, '福島県喜多方市山都町三ノ宮');
ok($zip->set_number('9694133')->is_valid_number, '福島県喜多方市山都町広葎田');
ok($zip->set_number('9694134')->is_valid_number, '福島県喜多方市山都町葎田');
ok($zip->set_number('9694135')->is_valid_number, '福島県喜多方市山都町広中新田');
ok($zip->set_number('9694136')->is_valid_number, '福島県喜多方市山都町町尻');
ok($zip->set_number('9694137')->is_valid_number, '福島県喜多方市山都町中野');
ok($zip->set_number('9694138')->is_valid_number, '福島県喜多方市山都町蛇崩');
ok($zip->set_number('9694139')->is_valid_number, '福島県喜多方市山都町北松ノ前');
ok($zip->set_number('9694140')->is_valid_number, '福島県喜多方市山都町石打場下');
ok($zip->set_number('9694141')->is_valid_number, '福島県喜多方市山都町田向');
ok($zip->set_number('9694142')->is_valid_number, '福島県喜多方市山都町七十苅');
ok($zip->set_number('9694143')->is_valid_number, '福島県喜多方市山都町沢田');
ok($zip->set_number('9694144')->is_valid_number, '福島県喜多方市山都町殿戸');
ok($zip->set_number('9694145')->is_valid_number, '福島県喜多方市山都町西原');
ok($zip->set_number('9694146')->is_valid_number, '福島県喜多方市山都町広古屋敷');
ok($zip->set_number('9694147')->is_valid_number, '福島県喜多方市山都町石堀古');
ok($zip->set_number('9694148')->is_valid_number, '福島県喜多方市山都町岩渕');
ok($zip->set_number('9694149')->is_valid_number, '福島県喜多方市山都町谷地');
ok($zip->set_number('9694151')->is_valid_number, '福島県喜多方市山都町大山中');
ok($zip->set_number('9694152')->is_valid_number, '福島県喜多方市山都町上ノ山平');
ok($zip->set_number('9694153')->is_valid_number, '福島県喜多方市山都町下殿戸');
ok($zip->set_number('9694154')->is_valid_number, '福島県喜多方市山都町舘原');
ok($zip->set_number('9694155')->is_valid_number, '福島県喜多方市山都町入海');
ok($zip->set_number('9694156')->is_valid_number, '福島県喜多方市山都町西川');
ok($zip->set_number('9694157')->is_valid_number, '福島県喜多方市山都町小松');
ok($zip->set_number('9694161')->is_valid_number, '福島県喜多方市山都町中石打場');
ok($zip->set_number('9694162')->is_valid_number, '福島県喜多方市山都町上新田');
ok($zip->set_number('9694163')->is_valid_number, '福島県喜多方市山都町下石打場');
ok($zip->set_number('9694164')->is_valid_number, '福島県喜多方市山都町上石打場');
ok($zip->set_number('9694165')->is_valid_number, '福島県喜多方市山都町三ツ山');
ok($zip->set_number('9694166')->is_valid_number, '福島県喜多方市山都町沢尻');
ok($zip->set_number('9694167')->is_valid_number, '福島県喜多方市山都町大林');
ok($zip->set_number('9694168')->is_valid_number, '福島県喜多方市山都町金子沢');
ok($zip->set_number('9694169')->is_valid_number, '福島県喜多方市山都町山中');
ok($zip->set_number('9694301')->is_valid_number, '福島県喜多方市高郷町上郷');
ok($zip->set_number('9694302')->is_valid_number, '福島県喜多方市高郷町峯');
ok($zip->set_number('9694303')->is_valid_number, '福島県喜多方市高郷町揚津');
ok($zip->set_number('9694304')->is_valid_number, '福島県喜多方市高郷町磐見');
ok($zip->set_number('9694311')->is_valid_number, '福島県喜多方市高郷町西羽賀');
ok($zip->set_number('9694312')->is_valid_number, '福島県喜多方市高郷町池ノ原');
ok($zip->set_number('9694313')->is_valid_number, '福島県喜多方市高郷町塩坪');
ok($zip->set_number('9694314')->is_valid_number, '福島県喜多方市高郷町川井');
ok($zip->set_number('9694315')->is_valid_number, '福島県喜多方市高郷町夏井');
ok($zip->set_number('9694316')->is_valid_number, '福島県喜多方市高郷町大田賀');
ok($zip->set_number('9694400')->is_valid_number, '福島県耶麻郡西会津町以下に掲載がない場合');
ok($zip->set_number('9694401')->is_valid_number, '福島県耶麻郡西会津町登世島');
ok($zip->set_number('9694402')->is_valid_number, '福島県耶麻郡西会津町尾野本');
ok($zip->set_number('9694403')->is_valid_number, '福島県耶麻郡西会津町束松');
ok($zip->set_number('9694404')->is_valid_number, '福島県耶麻郡西会津町睦合');
ok($zip->set_number('9694405')->is_valid_number, '福島県耶麻郡西会津町下谷');
ok($zip->set_number('9694406')->is_valid_number, '福島県耶麻郡西会津町野沢');
ok($zip->set_number('9694511')->is_valid_number, '福島県耶麻郡西会津町群岡');
ok($zip->set_number('9694512')->is_valid_number, '福島県耶麻郡西会津町上野尻');
ok($zip->set_number('9694513')->is_valid_number, '福島県耶麻郡西会津町宝坂屋敷');
ok($zip->set_number('9694514')->is_valid_number, '福島県耶麻郡西会津町宝坂宝坂');
ok($zip->set_number('9694515')->is_valid_number, '福島県耶麻郡西会津町下野尻');
ok($zip->set_number('9694621')->is_valid_number, '福島県耶麻郡西会津町新郷冨士');
ok($zip->set_number('9694622')->is_valid_number, '福島県耶麻郡西会津町新郷笹川');
ok($zip->set_number('9694623')->is_valid_number, '福島県耶麻郡西会津町新郷豊洲');
ok($zip->set_number('9694624')->is_valid_number, '福島県耶麻郡西会津町新郷三河');
ok($zip->set_number('9694731')->is_valid_number, '福島県耶麻郡西会津町奥川飯根');
ok($zip->set_number('9694732')->is_valid_number, '福島県耶麻郡西会津町奥川飯沢');
ok($zip->set_number('9694733')->is_valid_number, '福島県耶麻郡西会津町奥川大綱木');
ok($zip->set_number('9694734')->is_valid_number, '福島県耶麻郡西会津町奥川飯里');
ok($zip->set_number('9694735')->is_valid_number, '福島県耶麻郡西会津町奥川豊島');
ok($zip->set_number('9694736')->is_valid_number, '福島県耶麻郡西会津町奥川元島');
ok($zip->set_number('9694737')->is_valid_number, '福島県耶麻郡西会津町奥川高陽根');
ok($zip->set_number('9695111')->is_valid_number, '福島県会津若松市大戸町石村');
ok($zip->set_number('9695112')->is_valid_number, '福島県会津若松市大戸町下雨屋');
ok($zip->set_number('9695113')->is_valid_number, '福島県会津若松市大戸町宮内');
ok($zip->set_number('9695114')->is_valid_number, '福島県会津若松市大戸町上雨屋');
ok($zip->set_number('9695121')->is_valid_number, '福島県会津若松市大戸町上三寄南原');
ok($zip->set_number('9695122')->is_valid_number, '福島県会津若松市大戸町上三寄乙');
ok($zip->set_number('9695122')->is_valid_number, '福島県会津若松市大戸町上三寄香塩');
ok($zip->set_number('9695123')->is_valid_number, '福島県会津若松市大戸町上三寄大豆田');
ok($zip->set_number('9695123')->is_valid_number, '福島県会津若松市大戸町上三寄丙');
ok($zip->set_number('9695131')->is_valid_number, '福島県会津若松市大戸町高川');
ok($zip->set_number('9695132')->is_valid_number, '福島県会津若松市大戸町上小塩');
ok($zip->set_number('9695133')->is_valid_number, '福島県会津若松市大戸町大川');
ok($zip->set_number('9695141')->is_valid_number, '福島県会津若松市大戸町小谷川端');
ok($zip->set_number('9695142')->is_valid_number, '福島県会津若松市大戸町小谷坂下');
ok($zip->set_number('9695143')->is_valid_number, '福島県会津若松市大戸町小谷原');
ok($zip->set_number('9695144')->is_valid_number, '福島県会津若松市大戸町小谷西村');
ok($zip->set_number('9695145')->is_valid_number, '福島県会津若松市大戸町小谷平沢');
ok($zip->set_number('9695146')->is_valid_number, '福島県会津若松市大戸町小谷湯ノ平');
ok($zip->set_number('9695147')->is_valid_number, '福島県会津若松市大戸町芦牧');
ok($zip->set_number('9695201')->is_valid_number, '福島県南会津郡下郷町高陦');
ok($zip->set_number('9695202')->is_valid_number, '福島県南会津郡下郷町枝松');
ok($zip->set_number('9695203')->is_valid_number, '福島県南会津郡下郷町白岩');
ok($zip->set_number('9695204')->is_valid_number, '福島県南会津郡下郷町弥五島');
ok($zip->set_number('9695205')->is_valid_number, '福島県南会津郡下郷町大沢');
ok($zip->set_number('9695206')->is_valid_number, '福島県南会津郡下郷町湯野上');
ok($zip->set_number('9695207')->is_valid_number, '福島県南会津郡下郷町大内');
ok($zip->set_number('9695208')->is_valid_number, '福島県南会津郡下郷町小沼崎');
ok($zip->set_number('9695300')->is_valid_number, '福島県南会津郡下郷町以下に掲載がない場合');
ok($zip->set_number('9695311')->is_valid_number, '福島県南会津郡下郷町豊成');
ok($zip->set_number('9695312')->is_valid_number, '福島県南会津郡下郷町戸赤');
ok($zip->set_number('9695313')->is_valid_number, '福島県南会津郡下郷町原');
ok($zip->set_number('9695314')->is_valid_number, '福島県南会津郡下郷町日影');
ok($zip->set_number('9695315')->is_valid_number, '福島県南会津郡下郷町荒石');
ok($zip->set_number('9695316')->is_valid_number, '福島県南会津郡下郷町石井');
ok($zip->set_number('9695317')->is_valid_number, '福島県南会津郡下郷町志源行');
ok($zip->set_number('9695318')->is_valid_number, '福島県南会津郡下郷町磯上');
ok($zip->set_number('9695321')->is_valid_number, '福島県南会津郡下郷町沢口');
ok($zip->set_number('9695322')->is_valid_number, '福島県南会津郡下郷町領毛');
ok($zip->set_number('9695323')->is_valid_number, '福島県南会津郡下郷町桑取火');
ok($zip->set_number('9695324')->is_valid_number, '福島県南会津郡下郷町安張');
ok($zip->set_number('9695325')->is_valid_number, '福島県南会津郡下郷町中山');
ok($zip->set_number('9695326')->is_valid_number, '福島県南会津郡下郷町栄富');
ok($zip->set_number('9695331')->is_valid_number, '福島県南会津郡下郷町澳田');
ok($zip->set_number('9695332')->is_valid_number, '福島県南会津郡下郷町中妻');
ok($zip->set_number('9695333')->is_valid_number, '福島県南会津郡下郷町合川');
ok($zip->set_number('9695334')->is_valid_number, '福島県南会津郡下郷町大松川');
ok($zip->set_number('9695335')->is_valid_number, '福島県南会津郡下郷町南倉沢');
ok($zip->set_number('9695341')->is_valid_number, '福島県南会津郡下郷町野際新田');
ok($zip->set_number('9695342')->is_valid_number, '福島県南会津郡下郷町音金');
ok($zip->set_number('9695343')->is_valid_number, '福島県南会津郡下郷町落合');
ok($zip->set_number('9695344')->is_valid_number, '福島県南会津郡下郷町沢田');
ok($zip->set_number('9695345')->is_valid_number, '福島県南会津郡下郷町塩生');
ok($zip->set_number('9696001')->is_valid_number, '福島県会津若松市北会津町天満');
ok($zip->set_number('9696002')->is_valid_number, '福島県会津若松市北会津町麻生新田');
ok($zip->set_number('9696003')->is_valid_number, '福島県会津若松市北会津町西麻生');
ok($zip->set_number('9696004')->is_valid_number, '福島県会津若松市北会津町古麻生');
ok($zip->set_number('9696005')->is_valid_number, '福島県会津若松市北会津町松野');
ok($zip->set_number('9696006')->is_valid_number, '福島県会津若松市北会津町新在家');
ok($zip->set_number('9696007')->is_valid_number, '福島県会津若松市北会津町北後庵');
ok($zip->set_number('9696008')->is_valid_number, '福島県会津若松市北会津町大島');
ok($zip->set_number('9696011')->is_valid_number, '福島県会津若松市北会津町西後庵');
ok($zip->set_number('9696012')->is_valid_number, '福島県会津若松市北会津町金屋');
ok($zip->set_number('9696013')->is_valid_number, '福島県会津若松市北会津町下野');
ok($zip->set_number('9696015')->is_valid_number, '福島県会津若松市北会津町水季の里');
ok($zip->set_number('9696021')->is_valid_number, '福島県大沼郡会津美里町舘ノ廻甲');
ok($zip->set_number('9696022')->is_valid_number, '福島県大沼郡会津美里町大道上甲');
ok($zip->set_number('9696023')->is_valid_number, '福島県大沼郡会津美里町近右エ門田');
ok($zip->set_number('9696024')->is_valid_number, '福島県大沼郡会津美里町川原町北甲');
ok($zip->set_number('9696025')->is_valid_number, '福島県大沼郡会津美里町権現堂甲');
ok($zip->set_number('9696026')->is_valid_number, '福島県大沼郡会津美里町本郷前川原甲');
ok($zip->set_number('9696027')->is_valid_number, '福島県大沼郡会津美里町荒井甲');
ok($zip->set_number('9696028')->is_valid_number, '福島県大沼郡会津美里町旱泥甲');
ok($zip->set_number('9696029')->is_valid_number, '福島県大沼郡会津美里町三本松甲');
ok($zip->set_number('9696031')->is_valid_number, '福島県大沼郡会津美里町広面');
ok($zip->set_number('9696032')->is_valid_number, '福島県大沼郡会津美里町竹原');
ok($zip->set_number('9696033')->is_valid_number, '福島県大沼郡会津美里町堰向');
ok($zip->set_number('9696034')->is_valid_number, '福島県大沼郡会津美里町堰向甲');
ok($zip->set_number('9696035')->is_valid_number, '福島県大沼郡会津美里町中樋');
ok($zip->set_number('9696036')->is_valid_number, '福島県大沼郡会津美里町上野川原');
ok($zip->set_number('9696037')->is_valid_number, '福島県大沼郡会津美里町家西甲');
ok($zip->set_number('9696038')->is_valid_number, '福島県大沼郡会津美里町御用地甲');
ok($zip->set_number('9696041')->is_valid_number, '福島県大沼郡会津美里町川原町');
ok($zip->set_number('9696042')->is_valid_number, '福島県大沼郡会津美里町瀬戸町甲');
ok($zip->set_number('9696043')->is_valid_number, '福島県大沼郡会津美里町松原際甲');
ok($zip->set_number('9696044')->is_valid_number, '福島県大沼郡会津美里町瀬戸屋前');
ok($zip->set_number('9696045')->is_valid_number, '福島県大沼郡会津美里町北浦甲');
ok($zip->set_number('9696046')->is_valid_number, '福島県大沼郡会津美里町石切畑甲');
ok($zip->set_number('9696047')->is_valid_number, '福島県大沼郡会津美里町北川原甲');
ok($zip->set_number('9696051')->is_valid_number, '福島県大沼郡会津美里町思堀');
ok($zip->set_number('9696052')->is_valid_number, '福島県大沼郡会津美里町黒川');
ok($zip->set_number('9696053')->is_valid_number, '福島県大沼郡会津美里町仲塚甲');
ok($zip->set_number('9696054')->is_valid_number, '福島県大沼郡会津美里町惣印南');
ok($zip->set_number('9696055')->is_valid_number, '福島県大沼郡会津美里町惣印甲');
ok($zip->set_number('9696056')->is_valid_number, '福島県大沼郡会津美里町惣印東');
ok($zip->set_number('9696057')->is_valid_number, '福島県大沼郡会津美里町大川端甲');
ok($zip->set_number('9696058')->is_valid_number, '福島県大沼郡会津美里町的場甲');
ok($zip->set_number('9696059')->is_valid_number, '福島県大沼郡会津美里町六日町甲');
ok($zip->set_number('9696061')->is_valid_number, '福島県大沼郡会津美里町上町甲');
ok($zip->set_number('9696062')->is_valid_number, '福島県大沼郡会津美里町御用地');
ok($zip->set_number('9696063')->is_valid_number, '福島県大沼郡会津美里町御用地跡甲');
ok($zip->set_number('9696064')->is_valid_number, '福島県大沼郡会津美里町向川原');
ok($zip->set_number('9696065')->is_valid_number, '福島県大沼郡会津美里町本郷入口道上甲');
ok($zip->set_number('9696066')->is_valid_number, '福島県大沼郡会津美里町本郷入口中道上甲');
ok($zip->set_number('9696067')->is_valid_number, '福島県大沼郡会津美里町梁場上甲');
ok($zip->set_number('9696068')->is_valid_number, '福島県大沼郡会津美里町車川原甲');
ok($zip->set_number('9696069')->is_valid_number, '福島県大沼郡会津美里町船場甲');
ok($zip->set_number('9696071')->is_valid_number, '福島県大沼郡会津美里町本郷上');
ok($zip->set_number('9696072')->is_valid_number, '福島県大沼郡会津美里町真々川甲');
ok($zip->set_number('9696073')->is_valid_number, '福島県大沼郡会津美里町寺ノ前甲');
ok($zip->set_number('9696074')->is_valid_number, '福島県大沼郡会津美里町中道下甲');
ok($zip->set_number('9696075')->is_valid_number, '福島県大沼郡会津美里町本郷道東');
ok($zip->set_number('9696076')->is_valid_number, '福島県大沼郡会津美里町本郷道東甲');
ok($zip->set_number('9696077')->is_valid_number, '福島県大沼郡会津美里町東谷地甲');
ok($zip->set_number('9696078')->is_valid_number, '福島県大沼郡会津美里町蛭ケ窪');
ok($zip->set_number('9696079')->is_valid_number, '福島県大沼郡会津美里町三日町甲');
ok($zip->set_number('9696081')->is_valid_number, '福島県大沼郡会津美里町三日町上');
ok($zip->set_number('9696082')->is_valid_number, '福島県大沼郡会津美里町三日町上甲');
ok($zip->set_number('9696083')->is_valid_number, '福島県大沼郡会津美里町三日町道上甲');
ok($zip->set_number('9696084')->is_valid_number, '福島県大沼郡会津美里町本郷高田町甲');
ok($zip->set_number('9696085')->is_valid_number, '福島県大沼郡会津美里町西谷地');
ok($zip->set_number('9696086')->is_valid_number, '福島県大沼郡会津美里町西谷地甲');
ok($zip->set_number('9696087')->is_valid_number, '福島県大沼郡会津美里町本郷道西');
ok($zip->set_number('9696101')->is_valid_number, '福島県大沼郡会津美里町駅前');
ok($zip->set_number('9696102')->is_valid_number, '福島県大沼郡会津美里町思堀向');
ok($zip->set_number('9696103')->is_valid_number, '福島県大沼郡会津美里町上村北');
ok($zip->set_number('9696104')->is_valid_number, '福島県大沼郡会津美里町上村西道上');
ok($zip->set_number('9696104')->is_valid_number, '福島県大沼郡会津美里町上村西道下');
ok($zip->set_number('9696105')->is_valid_number, '福島県大沼郡会津美里町上村東');
ok($zip->set_number('9696105')->is_valid_number, '福島県大沼郡会津美里町上村南');
ok($zip->set_number('9696106')->is_valid_number, '福島県大沼郡会津美里町黒川内');
ok($zip->set_number('9696107')->is_valid_number, '福島県大沼郡会津美里町新用地');
ok($zip->set_number('9696108')->is_valid_number, '福島県大沼郡会津美里町堰下');
ok($zip->set_number('9696109')->is_valid_number, '福島県大沼郡会津美里町宗頤町');
ok($zip->set_number('9696111')->is_valid_number, '福島県大沼郡会津美里町家西');
ok($zip->set_number('9696112')->is_valid_number, '福島県大沼郡会津美里町家東甲');
ok($zip->set_number('9696113')->is_valid_number, '福島県大沼郡会津美里町車川原');
ok($zip->set_number('9696114')->is_valid_number, '福島県大沼郡会津美里町御用地跡');
ok($zip->set_number('9696115')->is_valid_number, '福島県大沼郡会津美里町新町');
ok($zip->set_number('9696116')->is_valid_number, '福島県大沼郡会津美里町瀬戸町');
ok($zip->set_number('9696117')->is_valid_number, '福島県大沼郡会津美里町本郷入口道上');
ok($zip->set_number('9696118')->is_valid_number, '福島県大沼郡会津美里町仲塚');
ok($zip->set_number('9696118')->is_valid_number, '福島県大沼郡会津美里町向川原甲');
ok($zip->set_number('9696119')->is_valid_number, '福島県大沼郡会津美里町梁場上');
ok($zip->set_number('9696121')->is_valid_number, '福島県大沼郡会津美里町延命寺前');
ok($zip->set_number('9696122')->is_valid_number, '福島県大沼郡会津美里町寺ノ前');
ok($zip->set_number('9696123')->is_valid_number, '福島県大沼郡会津美里町中道下');
ok($zip->set_number('9696124')->is_valid_number, '福島県大沼郡会津美里町東谷地');
ok($zip->set_number('9696125')->is_valid_number, '福島県大沼郡会津美里町本郷');
ok($zip->set_number('9696126')->is_valid_number, '福島県大沼郡会津美里町本郷甲');
ok($zip->set_number('9696127')->is_valid_number, '福島県大沼郡会津美里町本郷上甲');
ok($zip->set_number('9696128')->is_valid_number, '福島県大沼郡会津美里町真々川');
ok($zip->set_number('9696129')->is_valid_number, '福島県大沼郡会津美里町本郷道西甲');
ok($zip->set_number('9696131')->is_valid_number, '福島県大沼郡会津美里町大石');
ok($zip->set_number('9696132')->is_valid_number, '福島県大沼郡会津美里町本郷高田町');
ok($zip->set_number('9696133')->is_valid_number, '福島県大沼郡会津美里町船場');
ok($zip->set_number('9696134')->is_valid_number, '福島県大沼郡会津美里町三日町');
ok($zip->set_number('9696135')->is_valid_number, '福島県大沼郡会津美里町穂馬');
ok($zip->set_number('9696141')->is_valid_number, '福島県大沼郡会津美里町大八郷');
ok($zip->set_number('9696142')->is_valid_number, '福島県大沼郡会津美里町村上');
ok($zip->set_number('9696143')->is_valid_number, '福島県大沼郡会津美里町氷玉');
ok($zip->set_number('9696144')->is_valid_number, '福島県大沼郡会津美里町福重岡');
ok($zip->set_number('9696145')->is_valid_number, '福島県大沼郡会津美里町山南');
ok($zip->set_number('9696146')->is_valid_number, '福島県大沼郡会津美里町横堀下');
ok($zip->set_number('9696151')->is_valid_number, '福島県大沼郡会津美里町石切畑');
ok($zip->set_number('9696152')->is_valid_number, '福島県大沼郡会津美里町川原町甲');
ok($zip->set_number('9696154')->is_valid_number, '福島県大沼郡会津美里町北浦');
ok($zip->set_number('9696155')->is_valid_number, '福島県大沼郡会津美里町北川原');
ok($zip->set_number('9696156')->is_valid_number, '福島県大沼郡会津美里町瀬戸屋前甲');
ok($zip->set_number('9696157')->is_valid_number, '福島県大沼郡会津美里町本屋敷');
ok($zip->set_number('9696158')->is_valid_number, '福島県大沼郡会津美里町松原際');
ok($zip->set_number('9696159')->is_valid_number, '福島県大沼郡会津美里町川原町北');
ok($zip->set_number('9696161')->is_valid_number, '福島県大沼郡会津美里町荒井前');
ok($zip->set_number('9696162')->is_valid_number, '福島県大沼郡会津美里町杉');
ok($zip->set_number('9696163')->is_valid_number, '福島県大沼郡会津美里町黒沢');
ok($zip->set_number('9696164')->is_valid_number, '福島県大沼郡会津美里町本郷道上');
ok($zip->set_number('9696165')->is_valid_number, '福島県大沼郡会津美里町山道下');
ok($zip->set_number('9696166')->is_valid_number, '福島県大沼郡会津美里町下川原');
ok($zip->set_number('9696171')->is_valid_number, '福島県大沼郡会津美里町荒井');
ok($zip->set_number('9696172')->is_valid_number, '福島県大沼郡会津美里町本郷村西');
ok($zip->set_number('9696173')->is_valid_number, '福島県大沼郡会津美里町大道上');
ok($zip->set_number('9696174')->is_valid_number, '福島県大沼郡会津美里町権現堂');
ok($zip->set_number('9696175')->is_valid_number, '福島県大沼郡会津美里町舘ノ廻');
ok($zip->set_number('9696176')->is_valid_number, '福島県大沼郡会津美里町旱泥');
ok($zip->set_number('9696177')->is_valid_number, '福島県大沼郡会津美里町本郷前川原');
ok($zip->set_number('9696180')->is_valid_number, '福島県会津若松市北会津町両堂');
ok($zip->set_number('9696182')->is_valid_number, '福島県会津若松市北会津町柏原');
ok($zip->set_number('9696183')->is_valid_number, '福島県会津若松市北会津町上米塚');
ok($zip->set_number('9696184')->is_valid_number, '福島県会津若松市北会津町三本松');
ok($zip->set_number('9696185')->is_valid_number, '福島県会津若松市北会津町下米塚');
ok($zip->set_number('9696186')->is_valid_number, '福島県会津若松市北会津町古館');
ok($zip->set_number('9696188')->is_valid_number, '福島県会津若松市北会津町東小松');
ok($zip->set_number('9696189')->is_valid_number, '福島県会津若松市北会津町小松');
ok($zip->set_number('9696200')->is_valid_number, '福島県大沼郡会津美里町以下に掲載がない場合');
ok($zip->set_number('9696201')->is_valid_number, '福島県大沼郡会津美里町安田');
ok($zip->set_number('9696201')->is_valid_number, '福島県大沼郡会津美里町安田乙');
ok($zip->set_number('9696202')->is_valid_number, '福島県大沼郡会津美里町高田村東');
ok($zip->set_number('9696202')->is_valid_number, '福島県大沼郡会津美里町村前');
ok($zip->set_number('9696203')->is_valid_number, '福島県大沼郡会津美里町高田前川原');
ok($zip->set_number('9696203')->is_valid_number, '福島県大沼郡会津美里町水戸');
ok($zip->set_number('9696204')->is_valid_number, '福島県大沼郡会津美里町台ノ下');
ok($zip->set_number('9696204')->is_valid_number, '福島県大沼郡会津美里町宮ノ腰');
ok($zip->set_number('9696205')->is_valid_number, '福島県大沼郡会津美里町御田');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町家ノ下');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町坂ノ下道上');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町坂ノ下道下');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町坂ノ下道下甲');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町佐布川');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町高田中川原道下');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町松木田');
ok($zip->set_number('9696206')->is_valid_number, '福島県大沼郡会津美里町葭添');
ok($zip->set_number('9696207')->is_valid_number, '福島県大沼郡会津美里町宮里');
ok($zip->set_number('9696211')->is_valid_number, '福島県大沼郡会津美里町橋丸');
ok($zip->set_number('9696212')->is_valid_number, '福島県大沼郡会津美里町藤家館');
ok($zip->set_number('9696213')->is_valid_number, '福島県大沼郡会津美里町勝原');
ok($zip->set_number('9696214')->is_valid_number, '福島県大沼郡会津美里町冨川');
ok($zip->set_number('9696215')->is_valid_number, '福島県大沼郡会津美里町下堀');
ok($zip->set_number('9696221')->is_valid_number, '福島県大沼郡会津美里町旭館端');
ok($zip->set_number('9696222')->is_valid_number, '福島県大沼郡会津美里町旭市川');
ok($zip->set_number('9696223')->is_valid_number, '福島県大沼郡会津美里町旭寺入');
ok($zip->set_number('9696224')->is_valid_number, '福島県大沼郡会津美里町旭無量');
ok($zip->set_number('9696225')->is_valid_number, '福島県大沼郡会津美里町旭三寄');
ok($zip->set_number('9696226')->is_valid_number, '福島県大沼郡会津美里町旭杉原');
ok($zip->set_number('9696231')->is_valid_number, '福島県大沼郡会津美里町尾岐窪');
ok($zip->set_number('9696232')->is_valid_number, '福島県大沼郡会津美里町東尾岐');
ok($zip->set_number('9696241')->is_valid_number, '福島県大沼郡会津美里町吉田');
ok($zip->set_number('9696242')->is_valid_number, '福島県大沼郡会津美里町大室');
ok($zip->set_number('9696243')->is_valid_number, '福島県大沼郡会津美里町宮川');
ok($zip->set_number('9696244')->is_valid_number, '福島県大沼郡会津美里町西尾');
ok($zip->set_number('9696245')->is_valid_number, '福島県大沼郡会津美里町西本');
ok($zip->set_number('9696251')->is_valid_number, '福島県大沼郡会津美里町永井野');
ok($zip->set_number('9696252')->is_valid_number, '福島県大沼郡会津美里町松岸');
ok($zip->set_number('9696253')->is_valid_number, '福島県大沼郡会津美里町杉屋');
ok($zip->set_number('9696254')->is_valid_number, '福島県大沼郡会津美里町荻窪');
ok($zip->set_number('9696255')->is_valid_number, '福島県大沼郡会津美里町松沢');
ok($zip->set_number('9696256')->is_valid_number, '福島県大沼郡会津美里町上戸原');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町内川原');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町梅ノ木');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町権現宮');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町権現宮甲');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町権現宮南');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町権現宮南甲');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町高田道上');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町地尻');
ok($zip->set_number('9696261')->is_valid_number, '福島県大沼郡会津美里町東川原');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町鹿島');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町観音北');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町外川原');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町外川原甲');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町法憧寺北');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町法憧寺北甲');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町法憧寺東');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町法憧寺南');
ok($zip->set_number('9696262')->is_valid_number, '福島県大沼郡会津美里町法憧寺南甲');
ok($zip->set_number('9696263')->is_valid_number, '福島県大沼郡会津美里町清竜寺北');
ok($zip->set_number('9696263')->is_valid_number, '福島県大沼郡会津美里町宮北');
ok($zip->set_number('9696263')->is_valid_number, '福島県大沼郡会津美里町宮林');
ok($zip->set_number('9696263')->is_valid_number, '福島県大沼郡会津美里町宮林甲');
ok($zip->set_number('9696263')->is_valid_number, '福島県大沼郡会津美里町文珠西');
ok($zip->set_number('9696263')->is_valid_number, '福島県大沼郡会津美里町文珠東');
ok($zip->set_number('9696264')->is_valid_number, '福島県大沼郡会津美里町高田');
ok($zip->set_number('9696264')->is_valid_number, '福島県大沼郡会津美里町高田乙');
ok($zip->set_number('9696264')->is_valid_number, '福島県大沼郡会津美里町高田甲');
ok($zip->set_number('9696265')->is_valid_number, '福島県大沼郡会津美里町漆原北');
ok($zip->set_number('9696265')->is_valid_number, '福島県大沼郡会津美里町御蔵南');
ok($zip->set_number('9696265')->is_valid_number, '福島県大沼郡会津美里町川添');
ok($zip->set_number('9696265')->is_valid_number, '福島県大沼郡会津美里町館南');
ok($zip->set_number('9696265')->is_valid_number, '福島県大沼郡会津美里町長光寺南');
ok($zip->set_number('9696265')->is_valid_number, '福島県大沼郡会津美里町六地蔵');
ok($zip->set_number('9696266')->is_valid_number, '福島県大沼郡会津美里町油田');
ok($zip->set_number('9696266')->is_valid_number, '福島県大沼郡会津美里町新丁屋敷');
ok($zip->set_number('9696266')->is_valid_number, '福島県大沼郡会津美里町館ノ越');
ok($zip->set_number('9696266')->is_valid_number, '福島県大沼郡会津美里町西裏屋敷添');
ok($zip->set_number('9696266')->is_valid_number, '福島県大沼郡会津美里町布才地');
ok($zip->set_number('9696266')->is_valid_number, '福島県大沼郡会津美里町竜興寺北');
ok($zip->set_number('9696267')->is_valid_number, '福島県大沼郡会津美里町新丁西');
ok($zip->set_number('9696267')->is_valid_number, '福島県大沼郡会津美里町西裏');
ok($zip->set_number('9696268')->is_valid_number, '福島県大沼郡会津美里町谷地');
ok($zip->set_number('9696268')->is_valid_number, '福島県大沼郡会津美里町谷地前');
ok($zip->set_number('9696268')->is_valid_number, '福島県大沼郡会津美里町柳台');
ok($zip->set_number('9696268')->is_valid_number, '福島県大沼郡会津美里町柳台甲');
ok($zip->set_number('9696271')->is_valid_number, '福島県大沼郡会津美里町寺崎');
ok($zip->set_number('9696271')->is_valid_number, '福島県大沼郡会津美里町沼ノ上');
ok($zip->set_number('9696272')->is_valid_number, '福島県大沼郡会津美里町赤留');
ok($zip->set_number('9696273')->is_valid_number, '福島県大沼郡会津美里町八木沢');
ok($zip->set_number('9696274')->is_valid_number, '福島県大沼郡会津美里町雀林');
ok($zip->set_number('9696301')->is_valid_number, '福島県大沼郡会津美里町杉甲');
ok($zip->set_number('9696302')->is_valid_number, '福島県大沼郡会津美里町山道下甲');
ok($zip->set_number('9696303')->is_valid_number, '福島県大沼郡会津美里町山道上');
ok($zip->set_number('9696304')->is_valid_number, '福島県大沼郡会津美里町黒沢甲');
ok($zip->set_number('9696305')->is_valid_number, '福島県大沼郡会津美里町延命寺前甲');
ok($zip->set_number('9696306')->is_valid_number, '福島県大沼郡会津美里町延命寺前乙');
ok($zip->set_number('9696307')->is_valid_number, '福島県大沼郡会津美里町石田甲');
ok($zip->set_number('9696311')->is_valid_number, '福島県大沼郡会津美里町清水台');
ok($zip->set_number('9696312')->is_valid_number, '福島県大沼郡会津美里町清水台甲');
ok($zip->set_number('9696313')->is_valid_number, '福島県大沼郡会津美里町下川原甲');
ok($zip->set_number('9696314')->is_valid_number, '福島県大沼郡会津美里町清水川甲');
ok($zip->set_number('9696315')->is_valid_number, '福島県大沼郡会津美里町蛇ノ宮甲');
ok($zip->set_number('9696316')->is_valid_number, '福島県大沼郡会津美里町北原');
ok($zip->set_number('9696317')->is_valid_number, '福島県大沼郡会津美里町北原甲');
ok($zip->set_number('9696318')->is_valid_number, '福島県大沼郡会津美里町北原乙');
ok($zip->set_number('9696321')->is_valid_number, '福島県大沼郡会津美里町丸山北');
ok($zip->set_number('9696322')->is_valid_number, '福島県大沼郡会津美里町丸山北甲');
ok($zip->set_number('9696323')->is_valid_number, '福島県大沼郡会津美里町丸山');
ok($zip->set_number('9696324')->is_valid_number, '福島県大沼郡会津美里町丸山乙');
ok($zip->set_number('9696325')->is_valid_number, '福島県大沼郡会津美里町宮後');
ok($zip->set_number('9696326')->is_valid_number, '福島県大沼郡会津美里町宮後甲');
ok($zip->set_number('9696327')->is_valid_number, '福島県大沼郡会津美里町宮後乙');
ok($zip->set_number('9696328')->is_valid_number, '福島県大沼郡会津美里町山南乙');
ok($zip->set_number('9696331')->is_valid_number, '福島県大沼郡会津美里町本郷村西甲');
ok($zip->set_number('9696332')->is_valid_number, '福島県大沼郡会津美里町本郷村西乙');
ok($zip->set_number('9696333')->is_valid_number, '福島県大沼郡会津美里町大八郷乙');
ok($zip->set_number('9696334')->is_valid_number, '福島県大沼郡会津美里町本郷村東乙');
ok($zip->set_number('9696335')->is_valid_number, '福島県大沼郡会津美里町村上乙');
ok($zip->set_number('9696336')->is_valid_number, '福島県大沼郡会津美里町本郷千苅');
ok($zip->set_number('9696337')->is_valid_number, '福島県大沼郡会津美里町本郷千苅乙');
ok($zip->set_number('9696338')->is_valid_number, '福島県大沼郡会津美里町橋本乙');
ok($zip->set_number('9696341')->is_valid_number, '福島県大沼郡会津美里町横堀下乙');
ok($zip->set_number('9696342')->is_valid_number, '福島県大沼郡会津美里町倉田');
ok($zip->set_number('9696343')->is_valid_number, '福島県大沼郡会津美里町沖田');
ok($zip->set_number('9696351')->is_valid_number, '福島県大沼郡会津美里町穴田');
ok($zip->set_number('9696352')->is_valid_number, '福島県大沼郡会津美里町穴田乙');
ok($zip->set_number('9696353')->is_valid_number, '福島県大沼郡会津美里町堂ノ前');
ok($zip->set_number('9696354')->is_valid_number, '福島県大沼郡会津美里町堂ノ前甲');
ok($zip->set_number('9696355')->is_valid_number, '福島県大沼郡会津美里町西沖');
ok($zip->set_number('9696356')->is_valid_number, '福島県大沼郡会津美里町稗田乙');
ok($zip->set_number('9696401')->is_valid_number, '福島県大沼郡会津美里町和田目');
ok($zip->set_number('9696402')->is_valid_number, '福島県大沼郡会津美里町新屋敷');
ok($zip->set_number('9696403')->is_valid_number, '福島県大沼郡会津美里町鶴野辺');
ok($zip->set_number('9696404')->is_valid_number, '福島県大沼郡会津美里町境野');
ok($zip->set_number('9696405')->is_valid_number, '福島県大沼郡会津美里町米田');
ok($zip->set_number('9696406')->is_valid_number, '福島県大沼郡会津美里町佐賀瀬川');
ok($zip->set_number('9696407')->is_valid_number, '福島県大沼郡会津美里町上平');
ok($zip->set_number('9696408')->is_valid_number, '福島県大沼郡会津美里町沼田');
ok($zip->set_number('9696409')->is_valid_number, '福島県大沼郡会津美里町小沢');
ok($zip->set_number('9696411')->is_valid_number, '福島県大沼郡会津美里町立石田');
ok($zip->set_number('9696500')->is_valid_number, '福島県河沼郡会津坂下町以下に掲載がない場合');
ok($zip->set_number('9696501')->is_valid_number, '福島県河沼郡会津坂下町長井');
ok($zip->set_number('9696502')->is_valid_number, '福島県河沼郡会津坂下町津尻');
ok($zip->set_number('9696503')->is_valid_number, '福島県河沼郡会津坂下町宇内');
ok($zip->set_number('9696504')->is_valid_number, '福島県河沼郡会津坂下町八日沢');
ok($zip->set_number('9696505')->is_valid_number, '福島県河沼郡会津坂下町新舘');
ok($zip->set_number('9696506')->is_valid_number, '福島県河沼郡会津坂下町見明');
ok($zip->set_number('9696507')->is_valid_number, '福島県河沼郡会津坂下町大上');
ok($zip->set_number('9696511')->is_valid_number, '福島県河沼郡会津坂下町青木');
ok($zip->set_number('9696512')->is_valid_number, '福島県河沼郡会津坂下町沼越');
ok($zip->set_number('9696513')->is_valid_number, '福島県河沼郡会津坂下町立川');
ok($zip->set_number('9696514')->is_valid_number, '福島県河沼郡会津坂下町五香');
ok($zip->set_number('9696515')->is_valid_number, '福島県河沼郡会津坂下町福原前');
ok($zip->set_number('9696516')->is_valid_number, '福島県河沼郡会津坂下町中泉');
ok($zip->set_number('9696517')->is_valid_number, '福島県河沼郡会津坂下町合川');
ok($zip->set_number('9696518')->is_valid_number, '福島県河沼郡会津坂下町青津');
ok($zip->set_number('9696519')->is_valid_number, '福島県河沼郡会津坂下町御池田');
ok($zip->set_number('9696519')->is_valid_number, '福島県河沼郡会津坂下町三谷');
ok($zip->set_number('9696521')->is_valid_number, '福島県河沼郡会津坂下町金上');
ok($zip->set_number('9696522')->is_valid_number, '福島県河沼郡会津坂下町宮古');
ok($zip->set_number('9696523')->is_valid_number, '福島県河沼郡会津坂下町海老細');
ok($zip->set_number('9696524')->is_valid_number, '福島県河沼郡会津坂下町束原');
ok($zip->set_number('9696525')->is_valid_number, '福島県河沼郡会津坂下町開津');
ok($zip->set_number('9696526')->is_valid_number, '福島県河沼郡会津坂下町五ノ併');
ok($zip->set_number('9696527')->is_valid_number, '福島県河沼郡会津坂下町福原');
ok($zip->set_number('9696528')->is_valid_number, '福島県河沼郡会津坂下町新開津');
ok($zip->set_number('9696531')->is_valid_number, '福島県河沼郡会津坂下町上口');
ok($zip->set_number('9696531')->is_valid_number, '福島県河沼郡会津坂下町東上口甲');
ok($zip->set_number('9696532')->is_valid_number, '福島県河沼郡会津坂下町東川前丙');
ok($zip->set_number('9696532')->is_valid_number, '福島県河沼郡会津坂下町道下丙');
ok($zip->set_number('9696533')->is_valid_number, '福島県河沼郡会津坂下町上ノ台乙');
ok($zip->set_number('9696533')->is_valid_number, '福島県河沼郡会津坂下町台ノ下');
ok($zip->set_number('9696534')->is_valid_number, '福島県河沼郡会津坂下町小川原');
ok($zip->set_number('9696534')->is_valid_number, '福島県河沼郡会津坂下町北小川原乙');
ok($zip->set_number('9696534')->is_valid_number, '福島県河沼郡会津坂下町原道東甲');
ok($zip->set_number('9696535')->is_valid_number, '福島県河沼郡会津坂下町家ノ前乙');
ok($zip->set_number('9696535')->is_valid_number, '福島県河沼郡会津坂下町東屋敷添乙');
ok($zip->set_number('9696536')->is_valid_number, '福島県河沼郡会津坂下町市中一番甲');
ok($zip->set_number('9696537')->is_valid_number, '福島県河沼郡会津坂下町戌亥乙');
ok($zip->set_number('9696537')->is_valid_number, '福島県河沼郡会津坂下町西ノ宮乙');
ok($zip->set_number('9696538')->is_valid_number, '福島県河沼郡会津坂下町姥ケ下乙');
ok($zip->set_number('9696538')->is_valid_number, '福島県河沼郡会津坂下町上窪道北乙');
ok($zip->set_number('9696538')->is_valid_number, '福島県河沼郡会津坂下町上沼ノ上丙');
ok($zip->set_number('9696539')->is_valid_number, '福島県河沼郡会津坂下町古市乙');
ok($zip->set_number('9696541')->is_valid_number, '福島県河沼郡会津坂下町上四十石甲');
ok($zip->set_number('9696541')->is_valid_number, '福島県河沼郡会津坂下町四十石');
ok($zip->set_number('9696542')->is_valid_number, '福島県河沼郡会津坂下町光明寺東甲');
ok($zip->set_number('9696542')->is_valid_number, '福島県河沼郡会津坂下町古屋敷甲');
ok($zip->set_number('9696543')->is_valid_number, '福島県河沼郡会津坂下町市中二番甲');
ok($zip->set_number('9696544')->is_valid_number, '福島県河沼郡会津坂下町大堀川西甲');
ok($zip->set_number('9696544')->is_valid_number, '福島県河沼郡会津坂下町東南町裏甲');
ok($zip->set_number('9696545')->is_valid_number, '福島県河沼郡会津坂下町五反田');
ok($zip->set_number('9696546')->is_valid_number, '福島県河沼郡会津坂下町曲田');
ok($zip->set_number('9696547')->is_valid_number, '福島県河沼郡会津坂下町市中三番甲');
ok($zip->set_number('9696548')->is_valid_number, '福島県河沼郡会津坂下町茶屋町甲');
ok($zip->set_number('9696549')->is_valid_number, '福島県河沼郡会津坂下町古町川尻');
ok($zip->set_number('9696551')->is_valid_number, '福島県河沼郡会津坂下町舘ノ下');
ok($zip->set_number('9696552')->is_valid_number, '福島県河沼郡会津坂下町舘ノ内甲');
ok($zip->set_number('9696553')->is_valid_number, '福島県河沼郡会津坂下町石田');
ok($zip->set_number('9696553')->is_valid_number, '福島県河沼郡会津坂下町西南町裏甲');
ok($zip->set_number('9696554')->is_valid_number, '福島県河沼郡会津坂下町松ノ目');
ok($zip->set_number('9696555')->is_valid_number, '福島県河沼郡会津坂下町沢ノ目');
ok($zip->set_number('9696556')->is_valid_number, '福島県河沼郡会津坂下町北逆水甲');
ok($zip->set_number('9696556')->is_valid_number, '福島県河沼郡会津坂下町逆水');
ok($zip->set_number('9696557')->is_valid_number, '福島県河沼郡会津坂下町市中四番甲');
ok($zip->set_number('9696561')->is_valid_number, '福島県河沼郡会津坂下町大道');
ok($zip->set_number('9696562')->is_valid_number, '福島県河沼郡会津坂下町一丁田甲');
ok($zip->set_number('9696562')->is_valid_number, '福島県河沼郡会津坂下町中岡甲');
ok($zip->set_number('9696563')->is_valid_number, '福島県河沼郡会津坂下町市中新町甲');
ok($zip->set_number('9696564')->is_valid_number, '福島県河沼郡会津坂下町中岩田');
ok($zip->set_number('9696565')->is_valid_number, '福島県河沼郡会津坂下町惣六');
ok($zip->set_number('9696566')->is_valid_number, '福島県河沼郡会津坂下町稲荷塚');
ok($zip->set_number('9696567')->is_valid_number, '福島県河沼郡会津坂下町沼田甲');
ok($zip->set_number('9696571')->is_valid_number, '福島県河沼郡会津坂下町白狐');
ok($zip->set_number('9696572')->is_valid_number, '福島県河沼郡会津坂下町羽林');
ok($zip->set_number('9696573')->is_valid_number, '福島県河沼郡会津坂下町大沖');
ok($zip->set_number('9696574')->is_valid_number, '福島県河沼郡会津坂下町樋島');
ok($zip->set_number('9696575')->is_valid_number, '福島県河沼郡会津坂下町勝大');
ok($zip->set_number('9696576')->is_valid_number, '福島県河沼郡会津坂下町牛川');
ok($zip->set_number('9696581')->is_valid_number, '福島県河沼郡会津坂下町片門');
ok($zip->set_number('9696582')->is_valid_number, '福島県河沼郡会津坂下町高寺');
ok($zip->set_number('9696583')->is_valid_number, '福島県河沼郡会津坂下町気多宮');
ok($zip->set_number('9696584')->is_valid_number, '福島県河沼郡会津坂下町塔寺');
ok($zip->set_number('9696585')->is_valid_number, '福島県河沼郡会津坂下町船杉');
ok($zip->set_number('9696586')->is_valid_number, '福島県河沼郡会津坂下町坂本');
ok($zip->set_number('9696587')->is_valid_number, '福島県河沼郡会津坂下町束松');
ok($zip->set_number('9697200')->is_valid_number, '福島県河沼郡柳津町以下に掲載がない場合');
ok($zip->set_number('9697201')->is_valid_number, '福島県河沼郡柳津町柳津');
ok($zip->set_number('9697202')->is_valid_number, '福島県河沼郡柳津町大柳');
ok($zip->set_number('9697203')->is_valid_number, '福島県河沼郡柳津町軽井沢');
ok($zip->set_number('9697204')->is_valid_number, '福島県河沼郡柳津町猪倉野');
ok($zip->set_number('9697205')->is_valid_number, '福島県河沼郡柳津町郷戸');
ok($zip->set_number('9697206')->is_valid_number, '福島県河沼郡柳津町飯谷');
ok($zip->set_number('9697207')->is_valid_number, '福島県河沼郡柳津町小椿');
ok($zip->set_number('9697208')->is_valid_number, '福島県河沼郡柳津町藤');
ok($zip->set_number('9697209')->is_valid_number, '福島県河沼郡柳津町細八');
ok($zip->set_number('9697311')->is_valid_number, '福島県河沼郡柳津町湯八木沢');
ok($zip->set_number('9697312')->is_valid_number, '福島県河沼郡柳津町久保田');
ok($zip->set_number('9697313')->is_valid_number, '福島県河沼郡柳津町五畳敷');
ok($zip->set_number('9697314')->is_valid_number, '福島県河沼郡柳津町牧沢');
ok($zip->set_number('9697315')->is_valid_number, '福島県河沼郡柳津町四つ谷');
ok($zip->set_number('9697321')->is_valid_number, '福島県河沼郡柳津町砂子原');
ok($zip->set_number('9697322')->is_valid_number, '福島県河沼郡柳津町黒沢');
ok($zip->set_number('9697323')->is_valid_number, '福島県河沼郡柳津町芋小屋');
ok($zip->set_number('9697324')->is_valid_number, '福島県河沼郡柳津町胄中');
ok($zip->set_number('9697325')->is_valid_number, '福島県河沼郡柳津町大成沢');
ok($zip->set_number('9697326')->is_valid_number, '福島県河沼郡柳津町琵琶首');
ok($zip->set_number('9697401')->is_valid_number, '福島県大沼郡三島町西方');
ok($zip->set_number('9697402')->is_valid_number, '福島県大沼郡三島町名入');
ok($zip->set_number('9697403')->is_valid_number, '福島県大沼郡三島町小山');
ok($zip->set_number('9697404')->is_valid_number, '福島県大沼郡三島町高清水');
ok($zip->set_number('9697405')->is_valid_number, '福島県大沼郡三島町滝原');
ok($zip->set_number('9697406')->is_valid_number, '福島県大沼郡三島町早戸');
ok($zip->set_number('9697407')->is_valid_number, '福島県大沼郡三島町大石田');
ok($zip->set_number('9697413')->is_valid_number, '福島県大沼郡三島町桧原(小和瀬)');
ok($zip->set_number('9697500')->is_valid_number, '福島県大沼郡三島町以下に掲載がない場合');
ok($zip->set_number('9697511')->is_valid_number, '福島県大沼郡三島町宮下');
ok($zip->set_number('9697512')->is_valid_number, '福島県大沼郡三島町桑原');
ok($zip->set_number('9697513')->is_valid_number, '福島県大沼郡三島町桧原(その他)');
ok($zip->set_number('9697514')->is_valid_number, '福島県大沼郡三島町滝谷');
ok($zip->set_number('9697515')->is_valid_number, '福島県大沼郡三島町川井');
ok($zip->set_number('9697516')->is_valid_number, '福島県大沼郡三島町大登');
ok($zip->set_number('9697517')->is_valid_number, '福島県大沼郡三島町大谷');
ok($zip->set_number('9697518')->is_valid_number, '福島県大沼郡三島町浅岐');
ok($zip->set_number('9697519')->is_valid_number, '福島県大沼郡三島町間方');
ok($zip->set_number('9700000')->is_valid_number, '福島県いわき市以下に掲載がない場合');
ok($zip->set_number('9700101')->is_valid_number, '福島県いわき市平下神谷');
ok($zip->set_number('9700102')->is_valid_number, '福島県いわき市平下大越');
ok($zip->set_number('9700103')->is_valid_number, '福島県いわき市平藤間');
ok($zip->set_number('9700104')->is_valid_number, '福島県いわき市平上大越');
ok($zip->set_number('9700105')->is_valid_number, '福島県いわき市平菅波');
ok($zip->set_number('9700106')->is_valid_number, '福島県いわき市平山崎');
ok($zip->set_number('9700107')->is_valid_number, '福島県いわき市平荒田目');
ok($zip->set_number('9700111')->is_valid_number, '福島県いわき市平原高野');
ok($zip->set_number('9700112')->is_valid_number, '福島県いわき市平泉崎');
ok($zip->set_number('9700113')->is_valid_number, '福島県いわき市平絹谷');
ok($zip->set_number('9700114')->is_valid_number, '福島県いわき市平水品');
ok($zip->set_number('9700115')->is_valid_number, '福島県いわき市平北神谷');
ok($zip->set_number('9700116')->is_valid_number, '福島県いわき市平馬目');
ok($zip->set_number('9700221')->is_valid_number, '福島県いわき市平下高久');
ok($zip->set_number('9700222')->is_valid_number, '福島県いわき市平沼ノ内');
ok($zip->set_number('9700222')->is_valid_number, '福島県いわき市平沼ノ内諏訪原');
ok($zip->set_number('9700223')->is_valid_number, '福島県いわき市平薄磯');
ok($zip->set_number('9700224')->is_valid_number, '福島県いわき市平豊間');
ok($zip->set_number('9700225')->is_valid_number, '福島県いわき市平上山口');
ok($zip->set_number('9700226')->is_valid_number, '福島県いわき市平下山口');
ok($zip->set_number('9700227')->is_valid_number, '福島県いわき市平鶴ケ井');
ok($zip->set_number('9700228')->is_valid_number, '福島県いわき市平神谷作');
ok($zip->set_number('9700229')->is_valid_number, '福島県いわき市薄磯');
ok($zip->set_number('9700311')->is_valid_number, '福島県いわき市江名');
ok($zip->set_number('9700312')->is_valid_number, '福島県いわき市折戸');
ok($zip->set_number('9700313')->is_valid_number, '福島県いわき市中之作');
ok($zip->set_number('9700314')->is_valid_number, '福島県いわき市洋向台');
ok($zip->set_number('9700315')->is_valid_number, '福島県いわき市永崎');
ok($zip->set_number('9700316')->is_valid_number, '福島県いわき市小名浜下神白');
ok($zip->set_number('9700317')->is_valid_number, '福島県いわき市小名浜上神白');
ok($zip->set_number('9701141')->is_valid_number, '福島県いわき市好間町愛谷');
ok($zip->set_number('9701142')->is_valid_number, '福島県いわき市好間町今新田');
ok($zip->set_number('9701143')->is_valid_number, '福島県いわき市好間町小谷作');
ok($zip->set_number('9701144')->is_valid_number, '福島県いわき市好間工業団地');
ok($zip->set_number('9701145')->is_valid_number, '福島県いわき市好間町北好間');
ok($zip->set_number('9701146')->is_valid_number, '福島県いわき市好間町榊小屋');
ok($zip->set_number('9701147')->is_valid_number, '福島県いわき市好間町大利');
ok($zip->set_number('9701151')->is_valid_number, '福島県いわき市好間町下好間');
ok($zip->set_number('9701152')->is_valid_number, '福島県いわき市好間町中好間');
ok($zip->set_number('9701153')->is_valid_number, '福島県いわき市好間町上好間');
ok($zip->set_number('9701261')->is_valid_number, '福島県いわき市三和町渡戸(その他)');
ok($zip->set_number('9701262')->is_valid_number, '福島県いわき市三和町上永井');
ok($zip->set_number('9701263')->is_valid_number, '福島県いわき市三和町下永井');
ok($zip->set_number('9701264')->is_valid_number, '福島県いわき市三和町合戸');
ok($zip->set_number('9701361')->is_valid_number, '福島県いわき市三和町渡戸(川前)');
ok($zip->set_number('9701371')->is_valid_number, '福島県いわき市三和町中寺');
ok($zip->set_number('9701372')->is_valid_number, '福島県いわき市三和町下市萱');
ok($zip->set_number('9701373')->is_valid_number, '福島県いわき市三和町上市萱');
ok($zip->set_number('9701374')->is_valid_number, '福島県いわき市三和町上三坂');
ok($zip->set_number('9701375')->is_valid_number, '福島県いわき市三和町中三坂');
ok($zip->set_number('9701376')->is_valid_number, '福島県いわき市三和町下三坂');
ok($zip->set_number('9701377')->is_valid_number, '福島県いわき市三和町差塩');
ok($zip->set_number('9708001')->is_valid_number, '福島県いわき市平上平窪');
ok($zip->set_number('9708002')->is_valid_number, '福島県いわき市平中平窪');
ok($zip->set_number('9708003')->is_valid_number, '福島県いわき市平下平窪');
ok($zip->set_number('9708004')->is_valid_number, '福島県いわき市平下平窪中島町');
ok($zip->set_number('9708005')->is_valid_number, '福島県いわき市平下平窪古川町');
ok($zip->set_number('9708006')->is_valid_number, '福島県いわき市平下平窪山土内町');
ok($zip->set_number('9708007')->is_valid_number, '福島県いわき市平中平窪新町');
ok($zip->set_number('9708008')->is_valid_number, '福島県いわき市平中平窪細田町');
ok($zip->set_number('9708011')->is_valid_number, '福島県いわき市平上片寄');
ok($zip->set_number('9708012')->is_valid_number, '福島県いわき市平下片寄');
ok($zip->set_number('9708013')->is_valid_number, '福島県いわき市平大室');
ok($zip->set_number('9708014')->is_valid_number, '福島県いわき市平幕ノ内');
ok($zip->set_number('9708015')->is_valid_number, '福島県いわき市好間町川中子');
ok($zip->set_number('9708016')->is_valid_number, '福島県いわき市平中塩');
ok($zip->set_number('9708017')->is_valid_number, '福島県いわき市石森');
ok($zip->set_number('9708018')->is_valid_number, '福島県いわき市平四ツ波');
ok($zip->set_number('9708021')->is_valid_number, '福島県いわき市平中神谷');
ok($zip->set_number('9708022')->is_valid_number, '福島県いわき市平塩');
ok($zip->set_number('9708023')->is_valid_number, '福島県いわき市平鎌田');
ok($zip->set_number('9708024')->is_valid_number, '福島県いわき市平北白土');
ok($zip->set_number('9708025')->is_valid_number, '福島県いわき市平南白土');
ok($zip->set_number('9708026')->is_valid_number, '福島県いわき市平');
ok($zip->set_number('9708027')->is_valid_number, '福島県いわき市平鯨岡');
ok($zip->set_number('9708028')->is_valid_number, '福島県いわき市平上神谷');
ok($zip->set_number('9708031')->is_valid_number, '福島県いわき市平中山');
ok($zip->set_number('9708032')->is_valid_number, '福島県いわき市平下荒川');
ok($zip->set_number('9708033')->is_valid_number, '福島県いわき市自由ケ丘');
ok($zip->set_number('9708034')->is_valid_number, '福島県いわき市平上荒川');
ok($zip->set_number('9708035')->is_valid_number, '福島県いわき市明治団地');
ok($zip->set_number('9708036')->is_valid_number, '福島県いわき市平谷川瀬');
ok($zip->set_number('9708041')->is_valid_number, '福島県いわき市平小泉');
ok($zip->set_number('9708042')->is_valid_number, '福島県いわき市平上高久');
ok($zip->set_number('9708043')->is_valid_number, '福島県いわき市中央台鹿島');
ok($zip->set_number('9708044')->is_valid_number, '福島県いわき市中央台飯野');
ok($zip->set_number('9708045')->is_valid_number, '福島県いわき市郷ケ丘');
ok($zip->set_number('9708046')->is_valid_number, '福島県いわき市平吉野谷');
ok($zip->set_number('9708047')->is_valid_number, '福島県いわき市中央台高久');
ok($zip->set_number('9708051')->is_valid_number, '福島県いわき市平六町目');
ok($zip->set_number('9708052')->is_valid_number, '福島県いわき市平祢宜町');
ok($zip->set_number('9708053')->is_valid_number, '福島県いわき市平正月町');
ok($zip->set_number('9708054')->is_valid_number, '福島県いわき市平鎌田町');
ok($zip->set_number('9718101')->is_valid_number, '福島県いわき市小名浜');
ok($zip->set_number('9718102')->is_valid_number, '福島県いわき市小名浜港ケ丘');
ok($zip->set_number('9718111')->is_valid_number, '福島県いわき市小名浜大原');
ok($zip->set_number('9718112')->is_valid_number, '福島県いわき市小名浜南富岡');
ok($zip->set_number('9718121')->is_valid_number, '福島県いわき市小名浜岩出');
ok($zip->set_number('9718122')->is_valid_number, '福島県いわき市小名浜林城');
ok($zip->set_number('9718123')->is_valid_number, '福島県いわき市小名浜相子島');
ok($zip->set_number('9718124')->is_valid_number, '福島県いわき市小名浜住吉');
ok($zip->set_number('9718125')->is_valid_number, '福島県いわき市小名浜島');
ok($zip->set_number('9718126')->is_valid_number, '福島県いわき市小名浜野田');
ok($zip->set_number('9718127')->is_valid_number, '福島県いわき市小名浜玉川町');
ok($zip->set_number('9718131')->is_valid_number, '福島県いわき市常磐上矢田町');
ok($zip->set_number('9718132')->is_valid_number, '福島県いわき市鹿島町下矢田');
ok($zip->set_number('9718133')->is_valid_number, '福島県いわき市鹿島町米田');
ok($zip->set_number('9718134')->is_valid_number, '福島県いわき市鹿島町飯田');
ok($zip->set_number('9718135')->is_valid_number, '福島県いわき市小名浜金成');
ok($zip->set_number('9718136')->is_valid_number, '福島県いわき市常磐三沢町');
ok($zip->set_number('9718137')->is_valid_number, '福島県いわき市常磐松久須根町');
ok($zip->set_number('9718138')->is_valid_number, '福島県いわき市若葉台');
ok($zip->set_number('9718139')->is_valid_number, '福島県いわき市鹿島町鹿島');
ok($zip->set_number('9718141')->is_valid_number, '福島県いわき市鹿島町走熊');
ok($zip->set_number('9718142')->is_valid_number, '福島県いわき市鹿島町上蔵持');
ok($zip->set_number('9718143')->is_valid_number, '福島県いわき市鹿島町下蔵持');
ok($zip->set_number('9718144')->is_valid_number, '福島県いわき市鹿島町久保');
ok($zip->set_number('9718145')->is_valid_number, '福島県いわき市鹿島町船戸');
ok($zip->set_number('9718146')->is_valid_number, '福島県いわき市鹿島町御代');
ok($zip->set_number('9718151')->is_valid_number, '福島県いわき市小名浜岡小名');
ok($zip->set_number('9718152')->is_valid_number, '福島県いわき市湘南台');
ok($zip->set_number('9718161')->is_valid_number, '福島県いわき市小名浜諏訪町');
ok($zip->set_number('9718162')->is_valid_number, '福島県いわき市小名浜花畑町');
ok($zip->set_number('9718163')->is_valid_number, '福島県いわき市小名浜中町境');
ok($zip->set_number('9718164')->is_valid_number, '福島県いわき市小名浜寺廻町');
ok($zip->set_number('9718164')->is_valid_number, '福島県いわき市小名浜西町');
ok($zip->set_number('9718165')->is_valid_number, '福島県いわき市小名浜愛宕町');
ok($zip->set_number('9718166')->is_valid_number, '福島県いわき市小名浜愛宕上');
ok($zip->set_number('9718167')->is_valid_number, '福島県いわき市小名浜西君ケ塚町');
ok($zip->set_number('9718168')->is_valid_number, '福島県いわき市小名浜君ケ塚町');
ok($zip->set_number('9718169')->is_valid_number, '福島県いわき市小名浜南君ケ塚町');
ok($zip->set_number('9718171')->is_valid_number, '福島県いわき市泉ケ丘');
ok($zip->set_number('9718172')->is_valid_number, '福島県いわき市泉玉露');
ok($zip->set_number('9718181')->is_valid_number, '福島県いわき市泉町本谷');
ok($zip->set_number('9718182')->is_valid_number, '福島県いわき市泉町滝尻');
ok($zip->set_number('9718183')->is_valid_number, '福島県いわき市泉町下川');
ok($zip->set_number('9718184')->is_valid_number, '福島県いわき市泉町黒須野');
ok($zip->set_number('9718185')->is_valid_number, '福島県いわき市泉町');
ok($zip->set_number('9718186')->is_valid_number, '福島県いわき市泉町玉露');
ok($zip->set_number('9718187')->is_valid_number, '福島県いわき市葉山');
ok($zip->set_number('9718188')->is_valid_number, '福島県いわき市泉もえぎ台');
ok($zip->set_number('9718189')->is_valid_number, '福島県いわき市泉滝尻');
ok($zip->set_number('9720161')->is_valid_number, '福島県いわき市遠野町上遠野');
ok($zip->set_number('9720162')->is_valid_number, '福島県いわき市遠野町滝');
ok($zip->set_number('9720163')->is_valid_number, '福島県いわき市遠野町根岸');
ok($zip->set_number('9720164')->is_valid_number, '福島県いわき市遠野町深山田');
ok($zip->set_number('9720251')->is_valid_number, '福島県いわき市遠野町入遠野');
ok($zip->set_number('9720252')->is_valid_number, '福島県いわき市遠野町上根本');
ok($zip->set_number('9720253')->is_valid_number, '福島県いわき市遠野町大平');
ok($zip->set_number('9728301')->is_valid_number, '福島県いわき市草木台');
ok($zip->set_number('9728311')->is_valid_number, '福島県いわき市常磐水野谷町');
ok($zip->set_number('9728312')->is_valid_number, '福島県いわき市常磐下船尾町');
ok($zip->set_number('9728313')->is_valid_number, '福島県いわき市常磐岩ケ岡町');
ok($zip->set_number('9728314')->is_valid_number, '福島県いわき市常磐馬玉町');
ok($zip->set_number('9728315')->is_valid_number, '福島県いわき市常磐長孫町');
ok($zip->set_number('9728316')->is_valid_number, '福島県いわき市常磐西郷町');
ok($zip->set_number('9728317')->is_valid_number, '福島県いわき市常磐下湯長谷町');
ok($zip->set_number('9728318')->is_valid_number, '福島県いわき市常磐関船町');
ok($zip->set_number('9728321')->is_valid_number, '福島県いわき市常磐湯本町');
ok($zip->set_number('9728322')->is_valid_number, '福島県いわき市常磐上湯長谷町');
ok($zip->set_number('9728323')->is_valid_number, '福島県いわき市常磐松が台');
ok($zip->set_number('9728324')->is_valid_number, '福島県いわき市桜ケ丘');
ok($zip->set_number('9728325')->is_valid_number, '福島県いわき市常磐白鳥町');
ok($zip->set_number('9728326')->is_valid_number, '福島県いわき市常磐藤原町');
ok($zip->set_number('9728331')->is_valid_number, '福島県いわき市渡辺町泉田');
ok($zip->set_number('9728332')->is_valid_number, '福島県いわき市渡辺町昼野');
ok($zip->set_number('9728333')->is_valid_number, '福島県いわき市渡辺町洞');
ok($zip->set_number('9728334')->is_valid_number, '福島県いわき市渡辺町田部');
ok($zip->set_number('9728335')->is_valid_number, '福島県いわき市渡辺町松小屋');
ok($zip->set_number('9728336')->is_valid_number, '福島県いわき市渡辺町上釜戸');
ok($zip->set_number('9728337')->is_valid_number, '福島県いわき市渡辺町中釜戸');
ok($zip->set_number('9728338')->is_valid_number, '福島県いわき市中部工業団地');
ok($zip->set_number('9738401')->is_valid_number, '福島県いわき市内郷小島町');
ok($zip->set_number('9738402')->is_valid_number, '福島県いわき市内郷御厩町');
ok($zip->set_number('9738403')->is_valid_number, '福島県いわき市内郷綴町');
ok($zip->set_number('9738404')->is_valid_number, '福島県いわき市内郷内町');
ok($zip->set_number('9738405')->is_valid_number, '福島県いわき市内郷白水町');
ok($zip->set_number('9738406')->is_valid_number, '福島県いわき市内郷高野町');
ok($zip->set_number('9738407')->is_valid_number, '福島県いわき市内郷宮町');
ok($zip->set_number('9738408')->is_valid_number, '福島県いわき市内郷高坂町');
ok($zip->set_number('9738409')->is_valid_number, '福島県いわき市内郷御台境町');
ok($zip->set_number('9738411')->is_valid_number, '福島県いわき市小島町');
ok($zip->set_number('9738412')->is_valid_number, '福島県いわき市平成');
ok($zip->set_number('9740151')->is_valid_number, '福島県いわき市田人町黒田');
ok($zip->set_number('9740152')->is_valid_number, '福島県いわき市田人町旅人(その他)');
ok($zip->set_number('9740153')->is_valid_number, '福島県いわき市田人町南大平');
ok($zip->set_number('9740241')->is_valid_number, '福島県いわき市田人町荷路夫');
ok($zip->set_number('9740242')->is_valid_number, '福島県いわき市田人町貝泊');
ok($zip->set_number('9740243')->is_valid_number, '福島県いわき市田人町石住');
ok($zip->set_number('9740252')->is_valid_number, '福島県いわき市田人町旅人(水呑場)');
ok($zip->set_number('9748201')->is_valid_number, '福島県いわき市江畑町');
ok($zip->set_number('9748202')->is_valid_number, '福島県いわき市添野町');
ok($zip->set_number('9748203')->is_valid_number, '福島県いわき市後田町');
ok($zip->set_number('9748204')->is_valid_number, '福島県いわき市高倉町');
ok($zip->set_number('9748211')->is_valid_number, '福島県いわき市金山町');
ok($zip->set_number('9748212')->is_valid_number, '福島県いわき市東田町');
ok($zip->set_number('9748213')->is_valid_number, '福島県いわき市石塚町');
ok($zip->set_number('9748221')->is_valid_number, '福島県いわき市小浜町');
ok($zip->set_number('9748222')->is_valid_number, '福島県いわき市岩間町');
ok($zip->set_number('9748223')->is_valid_number, '福島県いわき市佐糠町');
ok($zip->set_number('9748231')->is_valid_number, '福島県いわき市富津町');
ok($zip->set_number('9748232')->is_valid_number, '福島県いわき市錦町');
ok($zip->set_number('9748233')->is_valid_number, '福島県いわき市錦町中央');
ok($zip->set_number('9748241')->is_valid_number, '福島県いわき市山田町');
ok($zip->set_number('9748242')->is_valid_number, '福島県いわき市南台');
ok($zip->set_number('9748251')->is_valid_number, '福島県いわき市中岡町');
ok($zip->set_number('9748252')->is_valid_number, '福島県いわき市仁井田町');
ok($zip->set_number('9748261')->is_valid_number, '福島県いわき市植田町');
ok($zip->set_number('9750000')->is_valid_number, '福島県南相馬市以下に掲載がない場合');
ok($zip->set_number('9750001')->is_valid_number, '福島県南相馬市原町区大町');
ok($zip->set_number('9750002')->is_valid_number, '福島県南相馬市原町区東町');
ok($zip->set_number('9750003')->is_valid_number, '福島県南相馬市原町区栄町');
ok($zip->set_number('9750004')->is_valid_number, '福島県南相馬市原町区旭町');
ok($zip->set_number('9750005')->is_valid_number, '福島県南相馬市原町区二見町');
ok($zip->set_number('9750006')->is_valid_number, '福島県南相馬市原町区橋本町');
ok($zip->set_number('9750007')->is_valid_number, '福島県南相馬市原町区南町');
ok($zip->set_number('9750008')->is_valid_number, '福島県南相馬市原町区本町');
ok($zip->set_number('9750011')->is_valid_number, '福島県南相馬市原町区小川町');
ok($zip->set_number('9750012')->is_valid_number, '福島県南相馬市原町区三島町');
ok($zip->set_number('9750013')->is_valid_number, '福島県南相馬市原町区上町');
ok($zip->set_number('9750014')->is_valid_number, '福島県南相馬市原町区西町');
ok($zip->set_number('9750015')->is_valid_number, '福島県南相馬市原町区国見町');
ok($zip->set_number('9750016')->is_valid_number, '福島県南相馬市原町区仲町');
ok($zip->set_number('9750017')->is_valid_number, '福島県南相馬市原町区牛越');
ok($zip->set_number('9750018')->is_valid_number, '福島県南相馬市原町区北町');
ok($zip->set_number('9750021')->is_valid_number, '福島県南相馬市原町区金沢');
ok($zip->set_number('9750022')->is_valid_number, '福島県南相馬市原町区北泉');
ok($zip->set_number('9750023')->is_valid_number, '福島県南相馬市原町区泉');
ok($zip->set_number('9750024')->is_valid_number, '福島県南相馬市原町区下北高平');
ok($zip->set_number('9750025')->is_valid_number, '福島県南相馬市原町区下高平');
ok($zip->set_number('9750026')->is_valid_number, '福島県南相馬市原町区上高平');
ok($zip->set_number('9750027')->is_valid_number, '福島県南相馬市原町区上北高平');
ok($zip->set_number('9750031')->is_valid_number, '福島県南相馬市原町区錦町');
ok($zip->set_number('9750032')->is_valid_number, '福島県南相馬市原町区桜井町');
ok($zip->set_number('9750033')->is_valid_number, '福島県南相馬市原町区高見町');
ok($zip->set_number('9750034')->is_valid_number, '福島県南相馬市原町区上渋佐');
ok($zip->set_number('9750035')->is_valid_number, '福島県南相馬市原町区下渋佐');
ok($zip->set_number('9750036')->is_valid_number, '福島県南相馬市原町区萱浜');
ok($zip->set_number('9750037')->is_valid_number, '福島県南相馬市原町区北原');
ok($zip->set_number('9750038')->is_valid_number, '福島県南相馬市原町区日の出町');
ok($zip->set_number('9750039')->is_valid_number, '福島県南相馬市原町区青葉町');
ok($zip->set_number('9750041')->is_valid_number, '福島県南相馬市原町区下太田');
ok($zip->set_number('9750042')->is_valid_number, '福島県南相馬市原町区雫');
ok($zip->set_number('9750043')->is_valid_number, '福島県南相馬市原町区小浜');
ok($zip->set_number('9750044')->is_valid_number, '福島県南相馬市原町区下江井');
ok($zip->set_number('9750045')->is_valid_number, '福島県南相馬市原町区小沢');
ok($zip->set_number('9750046')->is_valid_number, '福島県南相馬市原町区堤谷');
ok($zip->set_number('9750047')->is_valid_number, '福島県南相馬市原町区江井');
ok($zip->set_number('9750048')->is_valid_number, '福島県南相馬市原町区米々沢');
ok($zip->set_number('9750049')->is_valid_number, '福島県南相馬市原町区大甕');
ok($zip->set_number('9750051')->is_valid_number, '福島県南相馬市原町区牛来');
ok($zip->set_number('9750052')->is_valid_number, '福島県南相馬市原町区中太田');
ok($zip->set_number('9750053')->is_valid_number, '福島県南相馬市原町区益田');
ok($zip->set_number('9750054')->is_valid_number, '福島県南相馬市原町区高');
ok($zip->set_number('9750055')->is_valid_number, '福島県南相馬市原町区小木さく');
ok($zip->set_number('9750056')->is_valid_number, '福島県南相馬市原町区鶴谷');
ok($zip->set_number('9750057')->is_valid_number, '福島県南相馬市原町区矢川原');
ok($zip->set_number('9750058')->is_valid_number, '福島県南相馬市原町区片倉');
ok($zip->set_number('9750059')->is_valid_number, '福島県南相馬市原町区上太田');
ok($zip->set_number('9750061')->is_valid_number, '福島県南相馬市原町区大木戸');
ok($zip->set_number('9750062')->is_valid_number, '福島県南相馬市原町区本陣前');
ok($zip->set_number('9750063')->is_valid_number, '福島県南相馬市原町区馬場');
ok($zip->set_number('9750064')->is_valid_number, '福島県南相馬市原町区押釜');
ok($zip->set_number('9750065')->is_valid_number, '福島県南相馬市原町区陣ケ崎');
ok($zip->set_number('9750071')->is_valid_number, '福島県南相馬市原町区深野');
ok($zip->set_number('9750072')->is_valid_number, '福島県南相馬市原町区北長野');
ok($zip->set_number('9750073')->is_valid_number, '福島県南相馬市原町区北新田');
ok($zip->set_number('9750074')->is_valid_number, '福島県南相馬市原町区長野');
ok($zip->set_number('9750075')->is_valid_number, '福島県南相馬市原町区石神');
ok($zip->set_number('9750076')->is_valid_number, '福島県南相馬市原町区信田沢');
ok($zip->set_number('9750077')->is_valid_number, '福島県南相馬市原町区高倉');
ok($zip->set_number('9750078')->is_valid_number, '福島県南相馬市原町区大谷');
ok($zip->set_number('9750079')->is_valid_number, '福島県南相馬市原町区大原');
ok($zip->set_number('9760000')->is_valid_number, '福島県相馬市以下に掲載がない場合');
ok($zip->set_number('9760001')->is_valid_number, '福島県相馬市大野台');
ok($zip->set_number('9760002')->is_valid_number, '福島県相馬市椎木');
ok($zip->set_number('9760003')->is_valid_number, '福島県相馬市塚部');
ok($zip->set_number('9760004')->is_valid_number, '福島県相馬市長老内');
ok($zip->set_number('9760005')->is_valid_number, '福島県相馬市光陽');
ok($zip->set_number('9760006')->is_valid_number, '福島県相馬市石上');
ok($zip->set_number('9760007')->is_valid_number, '福島県相馬市大坪');
ok($zip->set_number('9760011')->is_valid_number, '福島県相馬市新沼');
ok($zip->set_number('9760012')->is_valid_number, '福島県相馬市北小泉');
ok($zip->set_number('9760013')->is_valid_number, '福島県相馬市小泉');
ok($zip->set_number('9760014')->is_valid_number, '福島県相馬市北飯渕');
ok($zip->set_number('9760015')->is_valid_number, '福島県相馬市塚ノ町');
ok($zip->set_number('9760016')->is_valid_number, '福島県相馬市沖ノ内');
ok($zip->set_number('9760021')->is_valid_number, '福島県相馬市原釜');
ok($zip->set_number('9760022')->is_valid_number, '福島県相馬市尾浜');
ok($zip->set_number('9760023')->is_valid_number, '福島県相馬市和田');
ok($zip->set_number('9760024')->is_valid_number, '福島県相馬市本笑');
ok($zip->set_number('9760025')->is_valid_number, '福島県相馬市岩子');
ok($zip->set_number('9760026')->is_valid_number, '福島県相馬市南飯渕');
ok($zip->set_number('9760031')->is_valid_number, '福島県相馬市百槻');
ok($zip->set_number('9760032')->is_valid_number, '福島県相馬市大曲');
ok($zip->set_number('9760033')->is_valid_number, '福島県相馬市新田');
ok($zip->set_number('9760034')->is_valid_number, '福島県相馬市柏崎');
ok($zip->set_number('9760035')->is_valid_number, '福島県相馬市程田');
ok($zip->set_number('9760036')->is_valid_number, '福島県相馬市馬場野');
ok($zip->set_number('9760037')->is_valid_number, '福島県相馬市中野');
ok($zip->set_number('9760041')->is_valid_number, '福島県相馬市西山');
ok($zip->set_number('9760042')->is_valid_number, '福島県相馬市中村');
ok($zip->set_number('9760051')->is_valid_number, '福島県相馬市初野');
ok($zip->set_number('9760052')->is_valid_number, '福島県相馬市黒木');
ok($zip->set_number('9760053')->is_valid_number, '福島県相馬市小野');
ok($zip->set_number('9760151')->is_valid_number, '福島県相馬市山上');
ok($zip->set_number('9760152')->is_valid_number, '福島県相馬市粟津');
ok($zip->set_number('9760153')->is_valid_number, '福島県相馬市東玉野');
ok($zip->set_number('9760154')->is_valid_number, '福島県相馬市玉野');
ok($zip->set_number('9790141')->is_valid_number, '福島県いわき市勿来町(窪田)');
ok($zip->set_number('9790142')->is_valid_number, '福島県いわき市勿来町(酒井)');
ok($zip->set_number('9790143')->is_valid_number, '福島県いわき市勿来町(白米)');
ok($zip->set_number('9790144')->is_valid_number, '福島県いわき市勿来町(大高)');
ok($zip->set_number('9790145')->is_valid_number, '福島県いわき市勿来町(四沢)');
ok($zip->set_number('9790146')->is_valid_number, '福島県いわき市勿来町(関田)');
ok($zip->set_number('9790147')->is_valid_number, '福島県いわき市勿来町(九面)');
ok($zip->set_number('9790151')->is_valid_number, '福島県いわき市瀬戸町');
ok($zip->set_number('9790152')->is_valid_number, '福島県いわき市山玉町');
ok($zip->set_number('9790153')->is_valid_number, '福島県いわき市川部町');
ok($zip->set_number('9790154')->is_valid_number, '福島県いわき市沼部町');
ok($zip->set_number('9790155')->is_valid_number, '福島県いわき市三沢町');
ok($zip->set_number('9790201')->is_valid_number, '福島県いわき市四倉町');
ok($zip->set_number('9790202')->is_valid_number, '福島県いわき市四倉町上仁井田');
ok($zip->set_number('9790203')->is_valid_number, '福島県いわき市四倉町下仁井田');
ok($zip->set_number('9790204')->is_valid_number, '福島県いわき市四倉町細谷');
ok($zip->set_number('9790205')->is_valid_number, '福島県いわき市四倉町大森');
ok($zip->set_number('9790206')->is_valid_number, '福島県いわき市四倉町狐塚');
ok($zip->set_number('9790207')->is_valid_number, '福島県いわき市四倉町塩木');
ok($zip->set_number('9790211')->is_valid_number, '福島県いわき市四倉町白岩');
ok($zip->set_number('9790212')->is_valid_number, '福島県いわき市四倉町戸田');
ok($zip->set_number('9790213')->is_valid_number, '福島県いわき市四倉町名木');
ok($zip->set_number('9790214')->is_valid_number, '福島県いわき市四倉町長友');
ok($zip->set_number('9790215')->is_valid_number, '福島県いわき市四倉町中島');
ok($zip->set_number('9790216')->is_valid_number, '福島県いわき市四倉町玉山');
ok($zip->set_number('9790221')->is_valid_number, '福島県いわき市四倉町上岡');
ok($zip->set_number('9790222')->is_valid_number, '福島県いわき市四倉町八茎');
ok($zip->set_number('9790223')->is_valid_number, '福島県いわき市四倉町山田小湊');
ok($zip->set_number('9790224')->is_valid_number, '福島県いわき市四倉町薬王寺');
ok($zip->set_number('9790225')->is_valid_number, '福島県いわき市四倉町下柳生');
ok($zip->set_number('9790226')->is_valid_number, '福島県いわき市四倉町上柳生');
ok($zip->set_number('9790227')->is_valid_number, '福島県いわき市四倉町駒込');
ok($zip->set_number('9790331')->is_valid_number, '福島県いわき市久之浜町末続');
ok($zip->set_number('9790332')->is_valid_number, '福島県いわき市久之浜町金ケ沢');
ok($zip->set_number('9790333')->is_valid_number, '福島県いわき市久之浜町久之浜');
ok($zip->set_number('9790334')->is_valid_number, '福島県いわき市久之浜町西');
ok($zip->set_number('9790335')->is_valid_number, '福島県いわき市久之浜町田之網');
ok($zip->set_number('9790336')->is_valid_number, '福島県いわき市大久町小山田');
ok($zip->set_number('9790337')->is_valid_number, '福島県いわき市大久町小久');
ok($zip->set_number('9790338')->is_valid_number, '福島県いわき市大久町大久');
ok($zip->set_number('9790400')->is_valid_number, '福島県双葉郡広野町以下に掲載がない場合');
ok($zip->set_number('9790401')->is_valid_number, '福島県双葉郡広野町上北迫');
ok($zip->set_number('9790402')->is_valid_number, '福島県双葉郡広野町下北迫');
ok($zip->set_number('9790403')->is_valid_number, '福島県双葉郡広野町下浅見川');
ok($zip->set_number('9790404')->is_valid_number, '福島県双葉郡広野町折木');
ok($zip->set_number('9790405')->is_valid_number, '福島県双葉郡広野町夕筋');
ok($zip->set_number('9790406')->is_valid_number, '福島県双葉郡広野町上浅見川');
ok($zip->set_number('9790407')->is_valid_number, '福島県双葉郡広野町広洋台');
ok($zip->set_number('9790408')->is_valid_number, '福島県双葉郡広野町中央台');
ok($zip->set_number('9790511')->is_valid_number, '福島県双葉郡楢葉町前原');
ok($zip->set_number('9790512')->is_valid_number, '福島県双葉郡楢葉町山田浜');
ok($zip->set_number('9790513')->is_valid_number, '福島県双葉郡楢葉町山田岡');
ok($zip->set_number('9790514')->is_valid_number, '福島県双葉郡楢葉町下小塙');
ok($zip->set_number('9790515')->is_valid_number, '福島県双葉郡楢葉町上小塙');
ok($zip->set_number('9790600')->is_valid_number, '福島県双葉郡楢葉町以下に掲載がない場合');
ok($zip->set_number('9790601')->is_valid_number, '福島県双葉郡楢葉町波倉');
ok($zip->set_number('9790602')->is_valid_number, '福島県双葉郡楢葉町下繁岡');
ok($zip->set_number('9790603')->is_valid_number, '福島県双葉郡楢葉町井出');
ok($zip->set_number('9790604')->is_valid_number, '福島県双葉郡楢葉町北田');
ok($zip->set_number('9790605')->is_valid_number, '福島県双葉郡楢葉町大谷');
ok($zip->set_number('9790606')->is_valid_number, '福島県双葉郡楢葉町上繁岡');
ok($zip->set_number('9790622')->is_valid_number, '福島県双葉郡富岡町毛萱(前川原232~244、311、312、337~862番地');
ok($zip->set_number('9790622')->is_valid_number, '福島県双葉郡富岡町〔東京電力福島第二原子力発電所構内〕)');
ok($zip->set_number('9791100')->is_valid_number, '福島県双葉郡富岡町以下に掲載がない場合');
ok($zip->set_number('9791101')->is_valid_number, '福島県双葉郡富岡町小良ケ浜');
ok($zip->set_number('9791111')->is_valid_number, '福島県双葉郡富岡町小浜');
ok($zip->set_number('9791112')->is_valid_number, '福島県双葉郡富岡町中央');
ok($zip->set_number('9791113')->is_valid_number, '福島県双葉郡富岡町曲田');
ok($zip->set_number('9791121')->is_valid_number, '福島県双葉郡富岡町仏浜');
ok($zip->set_number('9791122')->is_valid_number, '福島県双葉郡富岡町毛萱(その他)');
ok($zip->set_number('9791123')->is_valid_number, '福島県双葉郡富岡町駅前');
ok($zip->set_number('9791131')->is_valid_number, '福島県双葉郡富岡町上郡山');
ok($zip->set_number('9791132')->is_valid_number, '福島県双葉郡富岡町下郡山');
ok($zip->set_number('9791141')->is_valid_number, '福島県双葉郡富岡町上手岡');
ok($zip->set_number('9791151')->is_valid_number, '福島県双葉郡富岡町本岡');
ok($zip->set_number('9791152')->is_valid_number, '福島県双葉郡富岡町本町');
ok($zip->set_number('9791161')->is_valid_number, '福島県双葉郡富岡町夜の森');
ok($zip->set_number('9791162')->is_valid_number, '福島県双葉郡富岡町桜');
ok($zip->set_number('9791171')->is_valid_number, '福島県双葉郡富岡町大菅');
ok($zip->set_number('9791200')->is_valid_number, '福島県双葉郡川内村以下に掲載がない場合');
ok($zip->set_number('9791201')->is_valid_number, '福島県双葉郡川内村上川内');
ok($zip->set_number('9791202')->is_valid_number, '福島県双葉郡川内村下川内');
ok($zip->set_number('9791300')->is_valid_number, '福島県双葉郡大熊町以下に掲載がない場合');
ok($zip->set_number('9791301')->is_valid_number, '福島県双葉郡大熊町夫沢');
ok($zip->set_number('9791302')->is_valid_number, '福島県双葉郡大熊町小入野');
ok($zip->set_number('9791303')->is_valid_number, '福島県双葉郡大熊町熊川');
ok($zip->set_number('9791304')->is_valid_number, '福島県双葉郡大熊町小良浜');
ok($zip->set_number('9791305')->is_valid_number, '福島県双葉郡大熊町熊');
ok($zip->set_number('9791306')->is_valid_number, '福島県双葉郡大熊町大川原');
ok($zip->set_number('9791307')->is_valid_number, '福島県双葉郡大熊町野上');
ok($zip->set_number('9791308')->is_valid_number, '福島県双葉郡大熊町下野上');
ok($zip->set_number('9791400')->is_valid_number, '福島県双葉郡双葉町以下に掲載がない場合');
ok($zip->set_number('9791401')->is_valid_number, '福島県双葉郡双葉町中野');
ok($zip->set_number('9791402')->is_valid_number, '福島県双葉郡双葉町中浜');
ok($zip->set_number('9791411')->is_valid_number, '福島県双葉郡双葉町郡山');
ok($zip->set_number('9791412')->is_valid_number, '福島県双葉郡双葉町細谷');
ok($zip->set_number('9791421')->is_valid_number, '福島県双葉郡双葉町前田');
ok($zip->set_number('9791422')->is_valid_number, '福島県双葉郡双葉町水沢');
ok($zip->set_number('9791423')->is_valid_number, '福島県双葉郡双葉町目迫');
ok($zip->set_number('9791431')->is_valid_number, '福島県双葉郡双葉町山田');
ok($zip->set_number('9791432')->is_valid_number, '福島県双葉郡双葉町松迫');
ok($zip->set_number('9791433')->is_valid_number, '福島県双葉郡双葉町石熊');
ok($zip->set_number('9791441')->is_valid_number, '福島県双葉郡双葉町下羽鳥');
ok($zip->set_number('9791442')->is_valid_number, '福島県双葉郡双葉町上羽鳥');
ok($zip->set_number('9791451')->is_valid_number, '福島県双葉郡双葉町渋川');
ok($zip->set_number('9791452')->is_valid_number, '福島県双葉郡双葉町松倉');
ok($zip->set_number('9791453')->is_valid_number, '福島県双葉郡双葉町寺沢');
ok($zip->set_number('9791461')->is_valid_number, '福島県双葉郡双葉町両竹');
ok($zip->set_number('9791462')->is_valid_number, '福島県双葉郡双葉町中田');
ok($zip->set_number('9791463')->is_valid_number, '福島県双葉郡双葉町鴻草');
ok($zip->set_number('9791471')->is_valid_number, '福島県双葉郡双葉町長塚');
ok($zip->set_number('9791472')->is_valid_number, '福島県双葉郡双葉町新山');
ok($zip->set_number('9791500')->is_valid_number, '福島県双葉郡浪江町以下に掲載がない場合');
ok($zip->set_number('9791501')->is_valid_number, '福島県双葉郡浪江町立野');
ok($zip->set_number('9791502')->is_valid_number, '福島県双葉郡浪江町藤橋');
ok($zip->set_number('9791503')->is_valid_number, '福島県双葉郡浪江町西台');
ok($zip->set_number('9791504')->is_valid_number, '福島県双葉郡浪江町酒田');
ok($zip->set_number('9791505')->is_valid_number, '福島県双葉郡浪江町苅宿');
ok($zip->set_number('9791506')->is_valid_number, '福島県双葉郡浪江町室原(その他)');
ok($zip->set_number('9791511')->is_valid_number, '福島県双葉郡浪江町棚塩');
ok($zip->set_number('9791512')->is_valid_number, '福島県双葉郡浪江町北幾世橋');
ok($zip->set_number('9791513')->is_valid_number, '福島県双葉郡浪江町幾世橋');
ok($zip->set_number('9791521')->is_valid_number, '福島県双葉郡浪江町権現堂');
ok($zip->set_number('9791522')->is_valid_number, '福島県双葉郡浪江町請戸');
ok($zip->set_number('9791523')->is_valid_number, '福島県双葉郡浪江町中浜');
ok($zip->set_number('9791524')->is_valid_number, '福島県双葉郡浪江町両竹');
ok($zip->set_number('9791525')->is_valid_number, '福島県双葉郡浪江町高瀬');
ok($zip->set_number('9791526')->is_valid_number, '福島県双葉郡浪江町牛渡');
ok($zip->set_number('9791531')->is_valid_number, '福島県双葉郡浪江町川添');
ok($zip->set_number('9791532')->is_valid_number, '福島県双葉郡浪江町樋渡');
ok($zip->set_number('9791533')->is_valid_number, '福島県双葉郡浪江町酒井');
ok($zip->set_number('9791534')->is_valid_number, '福島県双葉郡浪江町谷津田');
ok($zip->set_number('9791535')->is_valid_number, '福島県双葉郡浪江町井手');
ok($zip->set_number('9791536')->is_valid_number, '福島県双葉郡浪江町加倉');
ok($zip->set_number('9791541')->is_valid_number, '福島県双葉郡浪江町田尻');
ok($zip->set_number('9791542')->is_valid_number, '福島県双葉郡浪江町末森');
ok($zip->set_number('9791543')->is_valid_number, '福島県双葉郡浪江町小野田');
ok($zip->set_number('9791544')->is_valid_number, '福島県双葉郡浪江町大堀');
ok($zip->set_number('9791545')->is_valid_number, '福島県双葉郡浪江町小丸');
ok($zip->set_number('9791600')->is_valid_number, '福島県双葉郡葛尾村以下に掲載がない場合');
ok($zip->set_number('9791601')->is_valid_number, '福島県双葉郡葛尾村葛尾');
ok($zip->set_number('9791602')->is_valid_number, '福島県双葉郡葛尾村落合');
ok($zip->set_number('9791603')->is_valid_number, '福島県双葉郡葛尾村野川');
ok($zip->set_number('9791604')->is_valid_number, '福島県双葉郡葛尾村上野川');
ok($zip->set_number('9791706')->is_valid_number, '福島県双葉郡浪江町室原(小伝谷67)');
ok($zip->set_number('9791751')->is_valid_number, '福島県双葉郡浪江町赤宇木');
ok($zip->set_number('9791752')->is_valid_number, '福島県双葉郡浪江町昼曽根');
ok($zip->set_number('9791753')->is_valid_number, '福島県双葉郡浪江町川房');
ok($zip->set_number('9791754')->is_valid_number, '福島県双葉郡浪江町南津島');
ok($zip->set_number('9791755')->is_valid_number, '福島県双葉郡浪江町羽附');
ok($zip->set_number('9791756')->is_valid_number, '福島県双葉郡浪江町下津島');
ok($zip->set_number('9791757')->is_valid_number, '福島県双葉郡浪江町津島');
ok($zip->set_number('9792101')->is_valid_number, '福島県南相馬市小高区片草');
ok($zip->set_number('9792102')->is_valid_number, '福島県南相馬市小高区小高');
ok($zip->set_number('9792103')->is_valid_number, '福島県南相馬市小高区大井');
ok($zip->set_number('9792104')->is_valid_number, '福島県南相馬市小高区塚原');
ok($zip->set_number('9792111')->is_valid_number, '福島県南相馬市小高区仲町');
ok($zip->set_number('9792112')->is_valid_number, '福島県南相馬市小高区田町');
ok($zip->set_number('9792113')->is_valid_number, '福島県南相馬市小高区関場');
ok($zip->set_number('9792114')->is_valid_number, '福島県南相馬市小高区西町');
ok($zip->set_number('9792115')->is_valid_number, '福島県南相馬市小高区上町');
ok($zip->set_number('9792121')->is_valid_number, '福島県南相馬市小高区東町');
ok($zip->set_number('9792122')->is_valid_number, '福島県南相馬市小高区南町');
ok($zip->set_number('9792123')->is_valid_number, '福島県南相馬市小高区大町');
ok($zip->set_number('9792124')->is_valid_number, '福島県南相馬市小高区本町');
ok($zip->set_number('9792131')->is_valid_number, '福島県南相馬市小高区福岡');
ok($zip->set_number('9792132')->is_valid_number, '福島県南相馬市小高区水谷');
ok($zip->set_number('9792133')->is_valid_number, '福島県南相馬市小高区泉沢');
ok($zip->set_number('9792134')->is_valid_number, '福島県南相馬市小高区岡田');
ok($zip->set_number('9792141')->is_valid_number, '福島県南相馬市小高区村上');
ok($zip->set_number('9792142')->is_valid_number, '福島県南相馬市小高区角部内');
ok($zip->set_number('9792143')->is_valid_number, '福島県南相馬市小高区蛯沢');
ok($zip->set_number('9792144')->is_valid_number, '福島県南相馬市小高区井田川');
ok($zip->set_number('9792145')->is_valid_number, '福島県南相馬市小高区浦尻');
ok($zip->set_number('9792146')->is_valid_number, '福島県南相馬市小高区下浦');
ok($zip->set_number('9792147')->is_valid_number, '福島県南相馬市小高区女場');
ok($zip->set_number('9792151')->is_valid_number, '福島県南相馬市小高区耳谷');
ok($zip->set_number('9792152')->is_valid_number, '福島県南相馬市小高区行津');
ok($zip->set_number('9792153')->is_valid_number, '福島県南相馬市小高区上浦');
ok($zip->set_number('9792154')->is_valid_number, '福島県南相馬市小高区神山');
ok($zip->set_number('9792155')->is_valid_number, '福島県南相馬市小高区上根沢');
ok($zip->set_number('9792156')->is_valid_number, '福島県南相馬市小高区小屋木');
ok($zip->set_number('9792157')->is_valid_number, '福島県南相馬市小高区吉名');
ok($zip->set_number('9792161')->is_valid_number, '福島県南相馬市小高区藤木');
ok($zip->set_number('9792162')->is_valid_number, '福島県南相馬市小高区飯崎');
ok($zip->set_number('9792163')->is_valid_number, '福島県南相馬市小高区大田和');
ok($zip->set_number('9792164')->is_valid_number, '福島県南相馬市小高区川房');
ok($zip->set_number('9792165')->is_valid_number, '福島県南相馬市小高区金谷');
ok($zip->set_number('9792171')->is_valid_number, '福島県南相馬市小高区北鳩原');
ok($zip->set_number('9792172')->is_valid_number, '福島県南相馬市小高区南鳩原');
ok($zip->set_number('9792173')->is_valid_number, '福島県南相馬市小高区小谷');
ok($zip->set_number('9792174')->is_valid_number, '福島県南相馬市小高区大富');
ok($zip->set_number('9792175')->is_valid_number, '福島県南相馬市小高区羽倉');
ok($zip->set_number('9792301')->is_valid_number, '福島県南相馬市鹿島区永渡');
ok($zip->set_number('9792302')->is_valid_number, '福島県南相馬市鹿島区南柚木');
ok($zip->set_number('9792303')->is_valid_number, '福島県南相馬市鹿島区北屋形');
ok($zip->set_number('9792304')->is_valid_number, '福島県南相馬市鹿島区南屋形');
ok($zip->set_number('9792305')->is_valid_number, '福島県南相馬市鹿島区永田');
ok($zip->set_number('9792311')->is_valid_number, '福島県南相馬市鹿島区北海老');
ok($zip->set_number('9792312')->is_valid_number, '福島県南相馬市鹿島区南海老');
ok($zip->set_number('9792313')->is_valid_number, '福島県南相馬市鹿島区北右田');
ok($zip->set_number('9792314')->is_valid_number, '福島県南相馬市鹿島区南右田');
ok($zip->set_number('9792321')->is_valid_number, '福島県南相馬市鹿島区小島田');
ok($zip->set_number('9792322')->is_valid_number, '福島県南相馬市鹿島区大内');
ok($zip->set_number('9792323')->is_valid_number, '福島県南相馬市鹿島区烏崎');
ok($zip->set_number('9792324')->is_valid_number, '福島県南相馬市鹿島区川子');
ok($zip->set_number('9792331')->is_valid_number, '福島県南相馬市鹿島区江垂');
ok($zip->set_number('9792332')->is_valid_number, '福島県南相馬市鹿島区塩崎');
ok($zip->set_number('9792333')->is_valid_number, '福島県南相馬市鹿島区寺内');
ok($zip->set_number('9792334')->is_valid_number, '福島県南相馬市鹿島区西町');
ok($zip->set_number('9792335')->is_valid_number, '福島県南相馬市鹿島区鹿島');
ok($zip->set_number('9792336')->is_valid_number, '福島県南相馬市鹿島区あさひ');
ok($zip->set_number('9792441')->is_valid_number, '福島県南相馬市鹿島区角川原');
ok($zip->set_number('9792442')->is_valid_number, '福島県南相馬市鹿島区横手');
ok($zip->set_number('9792443')->is_valid_number, '福島県南相馬市鹿島区牛河内');
ok($zip->set_number('9792444')->is_valid_number, '福島県南相馬市鹿島区岡和田');
ok($zip->set_number('9792451')->is_valid_number, '福島県南相馬市鹿島区浮田');
ok($zip->set_number('9792452')->is_valid_number, '福島県南相馬市鹿島区小山田');
ok($zip->set_number('9792453')->is_valid_number, '福島県南相馬市鹿島区小池');
ok($zip->set_number('9792454')->is_valid_number, '福島県南相馬市鹿島区橲原');
ok($zip->set_number('9792461')->is_valid_number, '福島県南相馬市鹿島区山下');
ok($zip->set_number('9792462')->is_valid_number, '福島県南相馬市鹿島区上栃窪');
ok($zip->set_number('9792463')->is_valid_number, '福島県南相馬市鹿島区栃窪');
ok($zip->set_number('9792464')->is_valid_number, '福島県南相馬市鹿島区御山');
ok($zip->set_number('9792501')->is_valid_number, '福島県相馬市磯部');
ok($zip->set_number('9792511')->is_valid_number, '福島県相馬市蒲庭');
ok($zip->set_number('9792512')->is_valid_number, '福島県相馬市柚木');
ok($zip->set_number('9792521')->is_valid_number, '福島県相馬市赤木');
ok($zip->set_number('9792522')->is_valid_number, '福島県相馬市日下石');
ok($zip->set_number('9792531')->is_valid_number, '福島県相馬市立谷');
ok($zip->set_number('9792532')->is_valid_number, '福島県相馬市富沢');
ok($zip->set_number('9792533')->is_valid_number, '福島県相馬市坪田');
ok($zip->set_number('9792541')->is_valid_number, '福島県相馬市今田');
ok($zip->set_number('9792542')->is_valid_number, '福島県相馬市成田');
ok($zip->set_number('9792611')->is_valid_number, '福島県相馬郡新地町駒ケ嶺');
ok($zip->set_number('9792700')->is_valid_number, '福島県相馬郡新地町以下に掲載がない場合');
ok($zip->set_number('9792701')->is_valid_number, '福島県相馬郡新地町埓木崎');
ok($zip->set_number('9792702')->is_valid_number, '福島県相馬郡新地町谷地小屋');
ok($zip->set_number('9792703')->is_valid_number, '福島県相馬郡新地町小川');
ok($zip->set_number('9792704')->is_valid_number, '福島県相馬郡新地町大戸浜');
ok($zip->set_number('9792705')->is_valid_number, '福島県相馬郡新地町今泉');
ok($zip->set_number('9792706')->is_valid_number, '福島県相馬郡新地町杉目');
ok($zip->set_number('9792707')->is_valid_number, '福島県相馬郡新地町真弓');
ok($zip->set_number('9792708')->is_valid_number, '福島県相馬郡新地町福田');
ok($zip->set_number('9792709')->is_valid_number, '福島県相馬郡新地町駅前');
ok($zip->set_number('9792711')->is_valid_number, '福島県相馬郡新地町中島');
ok($zip->set_number('9793111')->is_valid_number, '福島県いわき市小川町柴原');
ok($zip->set_number('9793112')->is_valid_number, '福島県いわき市小川町上平');
ok($zip->set_number('9793113')->is_valid_number, '福島県いわき市小川町三島');
ok($zip->set_number('9793114')->is_valid_number, '福島県いわき市小川町関場');
ok($zip->set_number('9793115')->is_valid_number, '福島県いわき市小川町下小川');
ok($zip->set_number('9793121')->is_valid_number, '福島県いわき市小川町西小川');
ok($zip->set_number('9793122')->is_valid_number, '福島県いわき市小川町高萩');
ok($zip->set_number('9793123')->is_valid_number, '福島県いわき市小川町塩田');
ok($zip->set_number('9793124')->is_valid_number, '福島県いわき市小川町上小川');
ok($zip->set_number('9793125')->is_valid_number, '福島県いわき市小川町福岡');
ok($zip->set_number('9793131')->is_valid_number, '福島県いわき市平赤井');
ok($zip->set_number('9793132')->is_valid_number, '福島県いわき市平赤井比良');
ok($zip->set_number('9793201')->is_valid_number, '福島県いわき市川前町川前');
ok($zip->set_number('9793202')->is_valid_number, '福島県いわき市川前町下桶売');
ok($zip->set_number('9793203')->is_valid_number, '福島県いわき市川前町上桶売');
ok($zip->set_number('9793204')->is_valid_number, '福島県いわき市川前町小白井');
ok($zip->set_number('9800000')->is_valid_number, '宮城県仙台市青葉区以下に掲載がない場合');
ok($zip->set_number('9800001')->is_valid_number, '宮城県仙台市青葉区中江');
ok($zip->set_number('9800002')->is_valid_number, '宮城県仙台市青葉区福沢町');
ok($zip->set_number('9800003')->is_valid_number, '宮城県仙台市青葉区小田原(4~8丁目)');
ok($zip->set_number('9800004')->is_valid_number, '宮城県仙台市青葉区宮町');
ok($zip->set_number('9800005')->is_valid_number, '宮城県仙台市青葉区梅田町');
ok($zip->set_number('9800011')->is_valid_number, '宮城県仙台市青葉区上杉');
ok($zip->set_number('9800012')->is_valid_number, '宮城県仙台市青葉区錦町');
ok($zip->set_number('9800013')->is_valid_number, '宮城県仙台市青葉区花京院');
ok($zip->set_number('9800014')->is_valid_number, '宮城県仙台市青葉区本町');
ok($zip->set_number('9800021')->is_valid_number, '宮城県仙台市青葉区中央(次のビルを除く)');
ok($zip->set_number('9800022')->is_valid_number, '宮城県仙台市青葉区五橋(1、2丁目)');
ok($zip->set_number('9800023')->is_valid_number, '宮城県仙台市青葉区北目町');
ok($zip->set_number('9800065')->is_valid_number, '宮城県仙台市青葉区土樋(1丁目「11を除く」)');
ok($zip->set_number('9800801')->is_valid_number, '宮城県仙台市青葉区木町通');
ok($zip->set_number('9800802')->is_valid_number, '宮城県仙台市青葉区二日町');
ok($zip->set_number('9800803')->is_valid_number, '宮城県仙台市青葉区国分町');
ok($zip->set_number('9800804')->is_valid_number, '宮城県仙台市青葉区大町');
ok($zip->set_number('9800805')->is_valid_number, '宮城県仙台市青葉区大手町');
ok($zip->set_number('9800811')->is_valid_number, '宮城県仙台市青葉区一番町');
ok($zip->set_number('9800812')->is_valid_number, '宮城県仙台市青葉区片平');
ok($zip->set_number('9800813')->is_valid_number, '宮城県仙台市青葉区米ケ袋');
ok($zip->set_number('9800814')->is_valid_number, '宮城県仙台市青葉区霊屋下');
ok($zip->set_number('9800815')->is_valid_number, '宮城県仙台市青葉区花壇');
ok($zip->set_number('9800821')->is_valid_number, '宮城県仙台市青葉区春日町');
ok($zip->set_number('9800822')->is_valid_number, '宮城県仙台市青葉区立町');
ok($zip->set_number('9800823')->is_valid_number, '宮城県仙台市青葉区桜ケ岡公園');
ok($zip->set_number('9800824')->is_valid_number, '宮城県仙台市青葉区支倉町');
ok($zip->set_number('9800845')->is_valid_number, '宮城県仙台市青葉区荒巻(その他)');
ok($zip->set_number('9800851')->is_valid_number, '宮城県仙台市青葉区川内明神横丁');
ok($zip->set_number('9800852')->is_valid_number, '宮城県仙台市青葉区川内川前丁');
ok($zip->set_number('9800853')->is_valid_number, '宮城県仙台市青葉区川内大工町');
ok($zip->set_number('9800854')->is_valid_number, '宮城県仙台市青葉区川内中ノ瀬町');
ok($zip->set_number('9800855')->is_valid_number, '宮城県仙台市青葉区川内澱橋通');
ok($zip->set_number('9800856')->is_valid_number, '宮城県仙台市青葉区青葉山');
ok($zip->set_number('9800861')->is_valid_number, '宮城県仙台市青葉区川内元支倉');
ok($zip->set_number('9800862')->is_valid_number, '宮城県仙台市青葉区川内');
ok($zip->set_number('9800863')->is_valid_number, '宮城県仙台市青葉区川内追廻');
ok($zip->set_number('9800864')->is_valid_number, '宮城県仙台市青葉区川内山屋敷');
ok($zip->set_number('9800865')->is_valid_number, '宮城県仙台市青葉区川内亀岡町');
ok($zip->set_number('9800866')->is_valid_number, '宮城県仙台市青葉区川内三十人町');
ok($zip->set_number('9800867')->is_valid_number, '宮城県仙台市青葉区川内亀岡北裏丁');
ok($zip->set_number('9800871')->is_valid_number, '宮城県仙台市青葉区八幡');
ok($zip->set_number('9800872')->is_valid_number, '宮城県仙台市青葉区星陵町');
ok($zip->set_number('9800873')->is_valid_number, '宮城県仙台市青葉区広瀬町');
ok($zip->set_number('9800874')->is_valid_number, '宮城県仙台市青葉区角五郎');
ok($zip->set_number('9806001')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(1階)');
ok($zip->set_number('9806002')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(2階)');
ok($zip->set_number('9806003')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(3階)');
ok($zip->set_number('9806004')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(4階)');
ok($zip->set_number('9806005')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(5階)');
ok($zip->set_number('9806006')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(6階)');
ok($zip->set_number('9806007')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(7階)');
ok($zip->set_number('9806008')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(8階)');
ok($zip->set_number('9806009')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(9階)');
ok($zip->set_number('9806010')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(10階)');
ok($zip->set_number('9806011')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(11階)');
ok($zip->set_number('9806012')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(12階)');
ok($zip->set_number('9806013')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(13階)');
ok($zip->set_number('9806014')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(14階)');
ok($zip->set_number('9806015')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(15階)');
ok($zip->set_number('9806016')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(16階)');
ok($zip->set_number('9806017')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(17階)');
ok($zip->set_number('9806018')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(18階)');
ok($zip->set_number('9806019')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(19階)');
ok($zip->set_number('9806020')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(20階)');
ok($zip->set_number('9806021')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(21階)');
ok($zip->set_number('9806022')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(22階)');
ok($zip->set_number('9806023')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(23階)');
ok($zip->set_number('9806024')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(24階)');
ok($zip->set_number('9806025')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(25階)');
ok($zip->set_number('9806026')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(26階)');
ok($zip->set_number('9806027')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(27階)');
ok($zip->set_number('9806028')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(28階)');
ok($zip->set_number('9806029')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(29階)');
ok($zip->set_number('9806030')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(30階)');
ok($zip->set_number('9806090')->is_valid_number, '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル(地階・階層不明)');
ok($zip->set_number('9806101')->is_valid_number, '宮城県仙台市青葉区中央アエル(1階)');
ok($zip->set_number('9806102')->is_valid_number, '宮城県仙台市青葉区中央アエル(2階)');
ok($zip->set_number('9806103')->is_valid_number, '宮城県仙台市青葉区中央アエル(3階)');
ok($zip->set_number('9806104')->is_valid_number, '宮城県仙台市青葉区中央アエル(4階)');
ok($zip->set_number('9806105')->is_valid_number, '宮城県仙台市青葉区中央アエル(5階)');
ok($zip->set_number('9806106')->is_valid_number, '宮城県仙台市青葉区中央アエル(6階)');
ok($zip->set_number('9806107')->is_valid_number, '宮城県仙台市青葉区中央アエル(7階)');
ok($zip->set_number('9806108')->is_valid_number, '宮城県仙台市青葉区中央アエル(8階)');
ok($zip->set_number('9806109')->is_valid_number, '宮城県仙台市青葉区中央アエル(9階)');
ok($zip->set_number('9806110')->is_valid_number, '宮城県仙台市青葉区中央アエル(10階)');
ok($zip->set_number('9806111')->is_valid_number, '宮城県仙台市青葉区中央アエル(11階)');
ok($zip->set_number('9806112')->is_valid_number, '宮城県仙台市青葉区中央アエル(12階)');
ok($zip->set_number('9806113')->is_valid_number, '宮城県仙台市青葉区中央アエル(13階)');
ok($zip->set_number('9806114')->is_valid_number, '宮城県仙台市青葉区中央アエル(14階)');
ok($zip->set_number('9806115')->is_valid_number, '宮城県仙台市青葉区中央アエル(15階)');
ok($zip->set_number('9806116')->is_valid_number, '宮城県仙台市青葉区中央アエル(16階)');
ok($zip->set_number('9806117')->is_valid_number, '宮城県仙台市青葉区中央アエル(17階)');
ok($zip->set_number('9806118')->is_valid_number, '宮城県仙台市青葉区中央アエル(18階)');
ok($zip->set_number('9806119')->is_valid_number, '宮城県仙台市青葉区中央アエル(19階)');
ok($zip->set_number('9806120')->is_valid_number, '宮城県仙台市青葉区中央アエル(20階)');
ok($zip->set_number('9806121')->is_valid_number, '宮城県仙台市青葉区中央アエル(21階)');
ok($zip->set_number('9806122')->is_valid_number, '宮城県仙台市青葉区中央アエル(22階)');
ok($zip->set_number('9806123')->is_valid_number, '宮城県仙台市青葉区中央アエル(23階)');
ok($zip->set_number('9806124')->is_valid_number, '宮城県仙台市青葉区中央アエル(24階)');
ok($zip->set_number('9806125')->is_valid_number, '宮城県仙台市青葉区中央アエル(25階)');
ok($zip->set_number('9806126')->is_valid_number, '宮城県仙台市青葉区中央アエル(26階)');
ok($zip->set_number('9806127')->is_valid_number, '宮城県仙台市青葉区中央アエル(27階)');
ok($zip->set_number('9806128')->is_valid_number, '宮城県仙台市青葉区中央アエル(28階)');
ok($zip->set_number('9806129')->is_valid_number, '宮城県仙台市青葉区中央アエル(29階)');
ok($zip->set_number('9806130')->is_valid_number, '宮城県仙台市青葉区中央アエル(30階)');
ok($zip->set_number('9806131')->is_valid_number, '宮城県仙台市青葉区中央アエル(31階)');
ok($zip->set_number('9806190')->is_valid_number, '宮城県仙台市青葉区中央アエル(地階・階層不明)');
ok($zip->set_number('9810100')->is_valid_number, '宮城県宮城郡利府町以下に掲載がない場合');
ok($zip->set_number('9810101')->is_valid_number, '宮城県宮城郡利府町赤沼');
ok($zip->set_number('9810102')->is_valid_number, '宮城県宮城郡利府町春日');
ok($zip->set_number('9810103')->is_valid_number, '宮城県宮城郡利府町森郷');
ok($zip->set_number('9810104')->is_valid_number, '宮城県宮城郡利府町中央');
ok($zip->set_number('9810105')->is_valid_number, '宮城県宮城郡利府町葉山');
ok($zip->set_number('9810111')->is_valid_number, '宮城県宮城郡利府町加瀬');
ok($zip->set_number('9810112')->is_valid_number, '宮城県宮城郡利府町利府');
ok($zip->set_number('9810113')->is_valid_number, '宮城県宮城郡利府町飯土井');
ok($zip->set_number('9810114')->is_valid_number, '宮城県宮城郡利府町新中道');
ok($zip->set_number('9810121')->is_valid_number, '宮城県宮城郡利府町神谷沢');
ok($zip->set_number('9810122')->is_valid_number, '宮城県宮城郡利府町菅谷');
ok($zip->set_number('9810123')->is_valid_number, '宮城県宮城郡利府町沢乙');
ok($zip->set_number('9810124')->is_valid_number, '宮城県宮城郡利府町沢乙東');
ok($zip->set_number('9810131')->is_valid_number, '宮城県宮城郡利府町青山');
ok($zip->set_number('9810132')->is_valid_number, '宮城県宮城郡利府町花園');
ok($zip->set_number('9810133')->is_valid_number, '宮城県宮城郡利府町青葉台');
ok($zip->set_number('9810134')->is_valid_number, '宮城県宮城郡利府町しらかし台');
ok($zip->set_number('9810135')->is_valid_number, '宮城県宮城郡利府町菅谷台');
ok($zip->set_number('9810136')->is_valid_number, '宮城県宮城郡利府町皆の丘');
ok($zip->set_number('9810200')->is_valid_number, '宮城県宮城郡松島町以下に掲載がない場合');
ok($zip->set_number('9810201')->is_valid_number, '宮城県宮城郡松島町竹谷');
ok($zip->set_number('9810202')->is_valid_number, '宮城県宮城郡松島町北小泉');
ok($zip->set_number('9810203')->is_valid_number, '宮城県宮城郡松島町根廻');
ok($zip->set_number('9810204')->is_valid_number, '宮城県宮城郡松島町初原');
ok($zip->set_number('9810205')->is_valid_number, '宮城県宮城郡松島町幡谷');
ok($zip->set_number('9810211')->is_valid_number, '宮城県宮城郡松島町手樽');
ok($zip->set_number('9810212')->is_valid_number, '宮城県宮城郡松島町磯崎');
ok($zip->set_number('9810213')->is_valid_number, '宮城県宮城郡松島町松島');
ok($zip->set_number('9810214')->is_valid_number, '宮城県宮城郡松島町桜渡戸');
ok($zip->set_number('9810215')->is_valid_number, '宮城県宮城郡松島町高城');
ok($zip->set_number('9810301')->is_valid_number, '宮城県東松島市牛網');
ok($zip->set_number('9810302')->is_valid_number, '宮城県東松島市浜市');
ok($zip->set_number('9810303')->is_valid_number, '宮城県東松島市小野');
ok($zip->set_number('9810304')->is_valid_number, '宮城県東松島市川下');
ok($zip->set_number('9810305')->is_valid_number, '宮城県東松島市上下堤');
ok($zip->set_number('9810306')->is_valid_number, '宮城県東松島市西福田');
ok($zip->set_number('9810307')->is_valid_number, '宮城県東松島市新田');
ok($zip->set_number('9810308')->is_valid_number, '宮城県東松島市高松');
ok($zip->set_number('9810309')->is_valid_number, '宮城県東松島市根古');
ok($zip->set_number('9810411')->is_valid_number, '宮城県東松島市野蒜');
ok($zip->set_number('9810412')->is_valid_number, '宮城県東松島市宮戸');
ok($zip->set_number('9810413')->is_valid_number, '宮城県東松島市新東名');
ok($zip->set_number('9810414')->is_valid_number, '宮城県東松島市大塚');
ok($zip->set_number('9810415')->is_valid_number, '宮城県東松島市浅井');
ok($zip->set_number('9810416')->is_valid_number, '宮城県東松島市野蒜ケ丘');
ok($zip->set_number('9810500')->is_valid_number, '宮城県東松島市以下に掲載がない場合');
ok($zip->set_number('9810501')->is_valid_number, '宮城県東松島市赤井');
ok($zip->set_number('9810502')->is_valid_number, '宮城県東松島市大曲');
ok($zip->set_number('9810503')->is_valid_number, '宮城県東松島市矢本');
ok($zip->set_number('9810504')->is_valid_number, '宮城県東松島市小松');
ok($zip->set_number('9810505')->is_valid_number, '宮城県東松島市大塩');
ok($zip->set_number('9810506')->is_valid_number, '宮城県東松島市あおい');
ok($zip->set_number('9810507')->is_valid_number, '宮城県東松島市みそら');
ok($zip->set_number('9810901')->is_valid_number, '宮城県仙台市青葉区北根黒松');
ok($zip->set_number('9810902')->is_valid_number, '宮城県仙台市青葉区北根');
ok($zip->set_number('9810903')->is_valid_number, '宮城県仙台市青葉区台原森林公園');
ok($zip->set_number('9810904')->is_valid_number, '宮城県仙台市青葉区旭ケ丘');
ok($zip->set_number('9810905')->is_valid_number, '宮城県仙台市青葉区小松島');
ok($zip->set_number('9810906')->is_valid_number, '宮城県仙台市青葉区小松島新堤');
ok($zip->set_number('9810907')->is_valid_number, '宮城県仙台市青葉区高松');
ok($zip->set_number('9810908')->is_valid_number, '宮城県仙台市青葉区東照宮');
ok($zip->set_number('9810911')->is_valid_number, '宮城県仙台市青葉区台原');
ok($zip->set_number('9810912')->is_valid_number, '宮城県仙台市青葉区堤町');
ok($zip->set_number('9810913')->is_valid_number, '宮城県仙台市青葉区昭和町');
ok($zip->set_number('9810914')->is_valid_number, '宮城県仙台市青葉区堤通雨宮町');
ok($zip->set_number('9810915')->is_valid_number, '宮城県仙台市青葉区通町');
ok($zip->set_number('9810916')->is_valid_number, '宮城県仙台市青葉区青葉町');
ok($zip->set_number('9810917')->is_valid_number, '宮城県仙台市青葉区葉山町');
ok($zip->set_number('9810921')->is_valid_number, '宮城県仙台市青葉区藤松');
ok($zip->set_number('9810922')->is_valid_number, '宮城県仙台市青葉区鷺ケ森');
ok($zip->set_number('9810923')->is_valid_number, '宮城県仙台市青葉区東勝山');
ok($zip->set_number('9810924')->is_valid_number, '宮城県仙台市青葉区双葉ケ丘');
ok($zip->set_number('9810931')->is_valid_number, '宮城県仙台市青葉区北山');
ok($zip->set_number('9810932')->is_valid_number, '宮城県仙台市青葉区木町');
ok($zip->set_number('9810933')->is_valid_number, '宮城県仙台市青葉区柏木');
ok($zip->set_number('9810934')->is_valid_number, '宮城県仙台市青葉区新坂町');
ok($zip->set_number('9810935')->is_valid_number, '宮城県仙台市青葉区三条町');
ok($zip->set_number('9810936')->is_valid_number, '宮城県仙台市青葉区千代田町');
ok($zip->set_number('9810941')->is_valid_number, '宮城県仙台市青葉区菊田町');
ok($zip->set_number('9810942')->is_valid_number, '宮城県仙台市青葉区貝ケ森');
ok($zip->set_number('9810943')->is_valid_number, '宮城県仙台市青葉区国見');
ok($zip->set_number('9810944')->is_valid_number, '宮城県仙台市青葉区子平町');
ok($zip->set_number('9810945')->is_valid_number, '宮城県仙台市青葉区荒巻(西雷神、仁田谷地、坊主門)');
ok($zip->set_number('9810951')->is_valid_number, '宮城県仙台市青葉区滝道');
ok($zip->set_number('9810952')->is_valid_number, '宮城県仙台市青葉区中山');
ok($zip->set_number('9810953')->is_valid_number, '宮城県仙台市青葉区西勝山');
ok($zip->set_number('9810954')->is_valid_number, '宮城県仙台市青葉区川平');
ok($zip->set_number('9810961')->is_valid_number, '宮城県仙台市青葉区桜ケ丘');
ok($zip->set_number('9810962')->is_valid_number, '宮城県仙台市青葉区水の森');
ok($zip->set_number('9810963')->is_valid_number, '宮城県仙台市青葉区あけぼの町');
ok($zip->set_number('9810964')->is_valid_number, '宮城県仙台市青葉区荒巻中央');
ok($zip->set_number('9810965')->is_valid_number, '宮城県仙台市青葉区荒巻神明町');
ok($zip->set_number('9810966')->is_valid_number, '宮城県仙台市青葉区荒巻本沢');
ok($zip->set_number('9810967')->is_valid_number, '宮城県仙台市青葉区山手町');
ok($zip->set_number('9811101')->is_valid_number, '宮城県仙台市太白区四郎丸');
ok($zip->set_number('9811102')->is_valid_number, '宮城県仙台市太白区袋原');
ok($zip->set_number('9811103')->is_valid_number, '宮城県仙台市太白区中田町');
ok($zip->set_number('9811104')->is_valid_number, '宮城県仙台市太白区中田');
ok($zip->set_number('9811105')->is_valid_number, '宮城県仙台市太白区西中田');
ok($zip->set_number('9811106')->is_valid_number, '宮城県仙台市太白区柳生');
ok($zip->set_number('9811107')->is_valid_number, '宮城県仙台市太白区東中田');
ok($zip->set_number('9811200')->is_valid_number, '宮城県名取市以下に掲載がない場合');
ok($zip->set_number('9811201')->is_valid_number, '宮城県名取市下増田(その他)');
ok($zip->set_number('9811202')->is_valid_number, '宮城県名取市閖上西');
ok($zip->set_number('9811203')->is_valid_number, '宮城県名取市閖上中央');
ok($zip->set_number('9811204')->is_valid_number, '宮城県名取市閖上東');
ok($zip->set_number('9811211')->is_valid_number, '宮城県名取市高柳');
ok($zip->set_number('9811212')->is_valid_number, '宮城県名取市小塚原');
ok($zip->set_number('9811213')->is_valid_number, '宮城県名取市閖上');
ok($zip->set_number('9811214')->is_valid_number, '宮城県名取市杉ケ袋');
ok($zip->set_number('9811215')->is_valid_number, '宮城県名取市牛野');
ok($zip->set_number('9811216')->is_valid_number, '宮城県名取市大曲');
ok($zip->set_number('9811217')->is_valid_number, '宮城県名取市美田園');
ok($zip->set_number('9811218')->is_valid_number, '宮城県名取市美田園北');
ok($zip->set_number('9811221')->is_valid_number, '宮城県名取市田高');
ok($zip->set_number('9811222')->is_valid_number, '宮城県名取市上余田');
ok($zip->set_number('9811223')->is_valid_number, '宮城県名取市下余田');
ok($zip->set_number('9811224')->is_valid_number, '宮城県名取市増田');
ok($zip->set_number('9811225')->is_valid_number, '宮城県名取市飯野坂');
ok($zip->set_number('9811226')->is_valid_number, '宮城県名取市植松');
ok($zip->set_number('9811227')->is_valid_number, '宮城県名取市杜せきのした');
ok($zip->set_number('9811230')->is_valid_number, '宮城県名取市愛の杜');
ok($zip->set_number('9811231')->is_valid_number, '宮城県名取市手倉田');
ok($zip->set_number('9811232')->is_valid_number, '宮城県名取市大手町');
ok($zip->set_number('9811233')->is_valid_number, '宮城県名取市小山');
ok($zip->set_number('9811234')->is_valid_number, '宮城県名取市箱塚');
ok($zip->set_number('9811235')->is_valid_number, '宮城県名取市名取が丘');
ok($zip->set_number('9811236')->is_valid_number, '宮城県名取市愛島小豆島');
ok($zip->set_number('9811237')->is_valid_number, '宮城県名取市愛島北目');
ok($zip->set_number('9811238')->is_valid_number, '宮城県名取市愛島笠島');
ok($zip->set_number('9811239')->is_valid_number, '宮城県名取市愛島塩手');
ok($zip->set_number('9811240')->is_valid_number, '宮城県名取市愛島郷');
ok($zip->set_number('9811241')->is_valid_number, '宮城県名取市高舘熊野堂');
ok($zip->set_number('9811242')->is_valid_number, '宮城県名取市高舘吉田');
ok($zip->set_number('9811243')->is_valid_number, '宮城県名取市高舘川上');
ok($zip->set_number('9811244')->is_valid_number, '宮城県名取市那智が丘');
ok($zip->set_number('9811245')->is_valid_number, '宮城県名取市ゆりが丘');
ok($zip->set_number('9811246')->is_valid_number, '宮城県名取市相互台');
ok($zip->set_number('9811247')->is_valid_number, '宮城県名取市みどり台');
ok($zip->set_number('9811248')->is_valid_number, '宮城県名取市相互台東');
ok($zip->set_number('9811251')->is_valid_number, '宮城県名取市愛島台');
ok($zip->set_number('9811500')->is_valid_number, '宮城県角田市以下に掲載がない場合');
ok($zip->set_number('9811501')->is_valid_number, '宮城県角田市藤田');
ok($zip->set_number('9811502')->is_valid_number, '宮城県角田市尾山');
ok($zip->set_number('9811503')->is_valid_number, '宮城県角田市島田');
ok($zip->set_number('9811504')->is_valid_number, '宮城県角田市枝野');
ok($zip->set_number('9811505')->is_valid_number, '宮城県角田市角田');
ok($zip->set_number('9811511')->is_valid_number, '宮城県角田市花島');
ok($zip->set_number('9811512')->is_valid_number, '宮城県角田市横倉');
ok($zip->set_number('9811513')->is_valid_number, '宮城県角田市豊室');
ok($zip->set_number('9811514')->is_valid_number, '宮城県角田市小田');
ok($zip->set_number('9811515')->is_valid_number, '宮城県角田市笠島');
ok($zip->set_number('9811516')->is_valid_number, '宮城県角田市高倉');
ok($zip->set_number('9811517')->is_valid_number, '宮城県角田市毛萱');
ok($zip->set_number('9811518')->is_valid_number, '宮城県角田市稲置');
ok($zip->set_number('9811521')->is_valid_number, '宮城県角田市江尻');
ok($zip->set_number('9811522')->is_valid_number, '宮城県角田市佐倉');
ok($zip->set_number('9811523')->is_valid_number, '宮城県角田市梶賀');
ok($zip->set_number('9811524')->is_valid_number, '宮城県角田市岡');
ok($zip->set_number('9811525')->is_valid_number, '宮城県角田市君萱');
ok($zip->set_number('9811526')->is_valid_number, '宮城県角田市神次郎');
ok($zip->set_number('9811531')->is_valid_number, '宮城県角田市鳩原');
ok($zip->set_number('9811532')->is_valid_number, '宮城県角田市小坂');
ok($zip->set_number('9811533')->is_valid_number, '宮城県角田市平貫');
ok($zip->set_number('9811534')->is_valid_number, '宮城県角田市坂津田');
ok($zip->set_number('9812100')->is_valid_number, '宮城県伊具郡丸森町以下に掲載がない場合');
ok($zip->set_number('9812101')->is_valid_number, '宮城県伊具郡丸森町舘矢間木沼');
ok($zip->set_number('9812102')->is_valid_number, '宮城県伊具郡丸森町舘矢間舘山');
ok($zip->set_number('9812103')->is_valid_number, '宮城県伊具郡丸森町舘矢間山田');
ok($zip->set_number('9812104')->is_valid_number, '宮城県伊具郡丸森町大舘');
ok($zip->set_number('9812105')->is_valid_number, '宮城県伊具郡丸森町舘矢間松掛');
ok($zip->set_number('9812106')->is_valid_number, '宮城県伊具郡丸森町木沼');
ok($zip->set_number('9812111')->is_valid_number, '宮城県伊具郡丸森町神明');
ok($zip->set_number('9812111')->is_valid_number, '宮城県伊具郡丸森町神明東');
ok($zip->set_number('9812111')->is_valid_number, '宮城県伊具郡丸森町神明南');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町石渕');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町作田');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町城東');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町新町');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町平');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町寺内');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町寺内前');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町羽山');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町蛭田');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町渕ノ上');
ok($zip->set_number('9812112')->is_valid_number, '宮城県伊具郡丸森町矢洗');
ok($zip->set_number('9812113')->is_valid_number, '宮城県伊具郡丸森町越田');
ok($zip->set_number('9812113')->is_valid_number, '宮城県伊具郡丸森町羽入');
ok($zip->set_number('9812113')->is_valid_number, '宮城県伊具郡丸森町羽入前');
ok($zip->set_number('9812113')->is_valid_number, '宮城県伊具郡丸森町宮脇');
ok($zip->set_number('9812114')->is_valid_number, '宮城県伊具郡丸森町赤堀');
ok($zip->set_number('9812114')->is_valid_number, '宮城県伊具郡丸森町泉');
ok($zip->set_number('9812114')->is_valid_number, '宮城県伊具郡丸森町泉下');
ok($zip->set_number('9812114')->is_valid_number, '宮城県伊具郡丸森町大目');
ok($zip->set_number('9812114')->is_valid_number, '宮城県伊具郡丸森町北前');
ok($zip->set_number('9812114')->is_valid_number, '宮城県伊具郡丸森町天王');
ok($zip->set_number('9812115')->is_valid_number, '宮城県伊具郡丸森町稲場');
ok($zip->set_number('9812115')->is_valid_number, '宮城県伊具郡丸森町稲場東');
ok($zip->set_number('9812115')->is_valid_number, '宮城県伊具郡丸森町三瓶内');
ok($zip->set_number('9812115')->is_valid_number, '宮城県伊具郡丸森町沼');
ok($zip->set_number('9812115')->is_valid_number, '宮城県伊具郡丸森町前河原');
ok($zip->set_number('9812115')->is_valid_number, '宮城県伊具郡丸森町山古谷');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町石倉');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町石倉前');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町石羽');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町上滝東');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町上滝西');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町桜渕');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町新田向');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町新田東');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町新田西');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町高松');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町滝原');
ok($zip->set_number('9812116')->is_valid_number, '宮城県伊具郡丸森町不動');
ok($zip->set_number('9812117')->is_valid_number, '宮城県伊具郡丸森町上林東');
ok($zip->set_number('9812117')->is_valid_number, '宮城県伊具郡丸森町上林西');
ok($zip->set_number('9812117')->is_valid_number, '宮城県伊具郡丸森町上林南');
ok($zip->set_number('9812117')->is_valid_number, '宮城県伊具郡丸森町中島');
ok($zip->set_number('9812117')->is_valid_number, '宮城県伊具郡丸森町畑中');
ok($zip->set_number('9812117')->is_valid_number, '宮城県伊具郡丸森町和田東');
ok($zip->set_number('9812117')->is_valid_number, '宮城県伊具郡丸森町和田西');
ok($zip->set_number('9812121')->is_valid_number, '宮城県伊具郡丸森町吉田');
ok($zip->set_number('9812122')->is_valid_number, '宮城県伊具郡丸森町荒田');
ok($zip->set_number('9812122')->is_valid_number, '宮城県伊具郡丸森町福沢');
ok($zip->set_number('9812122')->is_valid_number, '宮城県伊具郡丸森町福沢前');
ok($zip->set_number('9812123')->is_valid_number, '宮城県伊具郡丸森町原場');
ok($zip->set_number('9812123')->is_valid_number, '宮城県伊具郡丸森町柳田');
ok($zip->set_number('9812124')->is_valid_number, '宮城県伊具郡丸森町切立');
ok($zip->set_number('9812124')->is_valid_number, '宮城県伊具郡丸森町椚塚');
ok($zip->set_number('9812125')->is_valid_number, '宮城県伊具郡丸森町深田上');
ok($zip->set_number('9812125')->is_valid_number, '宮城県伊具郡丸森町深田下');
ok($zip->set_number('9812126')->is_valid_number, '宮城県伊具郡丸森町梅木坂');
ok($zip->set_number('9812126')->is_valid_number, '宮城県伊具郡丸森町金ケ作');
ok($zip->set_number('9812126')->is_valid_number, '宮城県伊具郡丸森町金ケ作前');
ok($zip->set_number('9812127')->is_valid_number, '宮城県伊具郡丸森町中ノ内');
ok($zip->set_number('9812131')->is_valid_number, '宮城県伊具郡丸森町銀杏');
ok($zip->set_number('9812131')->is_valid_number, '宮城県伊具郡丸森町後屋敷');
ok($zip->set_number('9812131')->is_valid_number, '宮城県伊具郡丸森町五福谷');
ok($zip->set_number('9812131')->is_valid_number, '宮城県伊具郡丸森町四反田');
ok($zip->set_number('9812131')->is_valid_number, '宮城県伊具郡丸森町上地');
ok($zip->set_number('9812131')->is_valid_number, '宮城県伊具郡丸森町塚田');
ok($zip->set_number('9812131')->is_valid_number, '宮城県伊具郡丸森町坂上');
ok($zip->set_number('9812132')->is_valid_number, '宮城県伊具郡丸森町牛子');
ok($zip->set_number('9812132')->is_valid_number, '宮城県伊具郡丸森町薄平');
ok($zip->set_number('9812132')->is_valid_number, '宮城県伊具郡丸森町馬渕');
ok($zip->set_number('9812132')->is_valid_number, '宮城県伊具郡丸森町向原');
ok($zip->set_number('9812132')->is_valid_number, '宮城県伊具郡丸森町蕨平');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町秋柴');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町四重麦一');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町四重麦二');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町四重麦三');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町四重麦四');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町四重麦五');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町四重麦六');
ok($zip->set_number('9812133')->is_valid_number, '宮城県伊具郡丸森町四重麦七');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠上');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠革踏石');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠小屋下');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠境');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠坂下');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠下');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠滝沢');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠野上');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠橋元');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠前');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠廻戸');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠向');
ok($zip->set_number('9812134')->is_valid_number, '宮城県伊具郡丸森町峠横向');
ok($zip->set_number('9812141')->is_valid_number, '宮城県伊具郡丸森町板山');
ok($zip->set_number('9812141')->is_valid_number, '宮城県伊具郡丸森町梅木平');
ok($zip->set_number('9812141')->is_valid_number, '宮城県伊具郡丸森町北沢');
ok($zip->set_number('9812141')->is_valid_number, '宮城県伊具郡丸森町小保田');
ok($zip->set_number('9812142')->is_valid_number, '宮城県伊具郡丸森町飯泉');
ok($zip->set_number('9812142')->is_valid_number, '宮城県伊具郡丸森町飯塚');
ok($zip->set_number('9812142')->is_valid_number, '宮城県伊具郡丸森町飯塚下');
ok($zip->set_number('9812142')->is_valid_number, '宮城県伊具郡丸森町竹谷');
ok($zip->set_number('9812142')->is_valid_number, '宮城県伊具郡丸森町垂松');
ok($zip->set_number('9812142')->is_valid_number, '宮城県伊具郡丸森町日向');
ok($zip->set_number('9812142')->is_valid_number, '宮城県伊具郡丸森町日向上');
ok($zip->set_number('9812143')->is_valid_number, '宮城県伊具郡丸森町虚空蔵上');
ok($zip->set_number('9812143')->is_valid_number, '宮城県伊具郡丸森町虚空蔵中');
ok($zip->set_number('9812143')->is_valid_number, '宮城県伊具郡丸森町虚空蔵下');
ok($zip->set_number('9812144')->is_valid_number, '宮城県伊具郡丸森町大畑');
ok($zip->set_number('9812144')->is_valid_number, '宮城県伊具郡丸森町大畑前');
ok($zip->set_number('9812144')->is_valid_number, '宮城県伊具郡丸森町土ケ森');
ok($zip->set_number('9812144')->is_valid_number, '宮城県伊具郡丸森町武士沢');
ok($zip->set_number('9812144')->is_valid_number, '宮城県伊具郡丸森町由縄坂');
ok($zip->set_number('9812145')->is_valid_number, '宮城県伊具郡丸森町川田島');
ok($zip->set_number('9812145')->is_valid_number, '宮城県伊具郡丸森町川田島菅');
ok($zip->set_number('9812145')->is_valid_number, '宮城県伊具郡丸森町川端');
ok($zip->set_number('9812145')->is_valid_number, '宮城県伊具郡丸森町五本松');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町欠入上');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町欠入下');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町欠入菅');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町欠入前山');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町関場');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町手掛橋中');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町手掛橋東');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町手掛橋西');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町中道');
ok($zip->set_number('9812146')->is_valid_number, '宮城県伊具郡丸森町広町');
ok($zip->set_number('9812151')->is_valid_number, '宮城県伊具郡丸森町千刈場');
ok($zip->set_number('9812152')->is_valid_number, '宮城県伊具郡丸森町鳥屋');
ok($zip->set_number('9812152')->is_valid_number, '宮城県伊具郡丸森町花田');
ok($zip->set_number('9812153')->is_valid_number, '宮城県伊具郡丸森町雁歌');
ok($zip->set_number('9812154')->is_valid_number, '宮城県伊具郡丸森町大川口');
ok($zip->set_number('9812154')->is_valid_number, '宮城県伊具郡丸森町大川口前');
ok($zip->set_number('9812155')->is_valid_number, '宮城県伊具郡丸森町片岸');
ok($zip->set_number('9812155')->is_valid_number, '宮城県伊具郡丸森町山崎');
ok($zip->set_number('9812155')->is_valid_number, '宮城県伊具郡丸森町山崎前');
ok($zip->set_number('9812156')->is_valid_number, '宮城県伊具郡丸森町うるし原');
ok($zip->set_number('9812156')->is_valid_number, '宮城県伊具郡丸森町小塚');
ok($zip->set_number('9812156')->is_valid_number, '宮城県伊具郡丸森町玉貫');
ok($zip->set_number('9812156')->is_valid_number, '宮城県伊具郡丸森町菱川内');
ok($zip->set_number('9812161')->is_valid_number, '宮城県伊具郡丸森町除南');
ok($zip->set_number('9812162')->is_valid_number, '宮城県伊具郡丸森町除北');
ok($zip->set_number('9812163')->is_valid_number, '宮城県伊具郡丸森町除');
ok($zip->set_number('9812164')->is_valid_number, '宮城県伊具郡丸森町町東');
ok($zip->set_number('9812165')->is_valid_number, '宮城県伊具郡丸森町町西');
ok($zip->set_number('9812166')->is_valid_number, '宮城県伊具郡丸森町高畑');
ok($zip->set_number('9812167')->is_valid_number, '宮城県伊具郡丸森町田町南');
ok($zip->set_number('9812168')->is_valid_number, '宮城県伊具郡丸森町田町北');
ok($zip->set_number('9812171')->is_valid_number, '宮城県伊具郡丸森町下滝');
ok($zip->set_number('9812171')->is_valid_number, '宮城県伊具郡丸森町下滝南');
ok($zip->set_number('9812171')->is_valid_number, '宮城県伊具郡丸森町船場');
ok($zip->set_number('9812172')->is_valid_number, '宮城県伊具郡丸森町敷文東');
ok($zip->set_number('9812172')->is_valid_number, '宮城県伊具郡丸森町敷文西');
ok($zip->set_number('9812172')->is_valid_number, '宮城県伊具郡丸森町百合沢');
ok($zip->set_number('9812173')->is_valid_number, '宮城県伊具郡丸森町天炉');
ok($zip->set_number('9812173')->is_valid_number, '宮城県伊具郡丸森町船越');
ok($zip->set_number('9812173')->is_valid_number, '宮城県伊具郡丸森町山田上');
ok($zip->set_number('9812173')->is_valid_number, '宮城県伊具郡丸森町山田下');
ok($zip->set_number('9812174')->is_valid_number, '宮城県伊具郡丸森町岡巻');
ok($zip->set_number('9812174')->is_valid_number, '宮城県伊具郡丸森町木落');
ok($zip->set_number('9812174')->is_valid_number, '宮城県伊具郡丸森町小倉');
ok($zip->set_number('9812174')->is_valid_number, '宮城県伊具郡丸森町砂ノ入');
ok($zip->set_number('9812181')->is_valid_number, '宮城県伊具郡丸森町子安');
ok($zip->set_number('9812181')->is_valid_number, '宮城県伊具郡丸森町高見南');
ok($zip->set_number('9812181')->is_valid_number, '宮城県伊具郡丸森町高見北');
ok($zip->set_number('9812181')->is_valid_number, '宮城県伊具郡丸森町曲木');
ok($zip->set_number('9812181')->is_valid_number, '宮城県伊具郡丸森町廻倉');
ok($zip->set_number('9812182')->is_valid_number, '宮城県伊具郡丸森町覆盆子原');
ok($zip->set_number('9812182')->is_valid_number, '宮城県伊具郡丸森町大鹿野');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町石釜');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町大高森');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町萱森');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町塩ノ貝');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町塩ノ貝後');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町空焼');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町角切');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町鳥木');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町屋敷');
ok($zip->set_number('9812183')->is_valid_number, '宮城県伊具郡丸森町屋敷前');
ok($zip->set_number('9812184')->is_valid_number, '宮城県伊具郡丸森町笠松');
ok($zip->set_number('9812184')->is_valid_number, '宮城県伊具郡丸森町柏木');
ok($zip->set_number('9812184')->is_valid_number, '宮城県伊具郡丸森町坂下');
ok($zip->set_number('9812184')->is_valid_number, '宮城県伊具郡丸森町田ノ入');
ok($zip->set_number('9812184')->is_valid_number, '宮城県伊具郡丸森町深田');
ok($zip->set_number('9812184')->is_valid_number, '宮城県伊具郡丸森町森');
ok($zip->set_number('9812185')->is_valid_number, '宮城県伊具郡丸森町椚林');
ok($zip->set_number('9812185')->is_valid_number, '宮城県伊具郡丸森町滝の上');
ok($zip->set_number('9812185')->is_valid_number, '宮城県伊具郡丸森町羽出庭');
ok($zip->set_number('9812185')->is_valid_number, '宮城県伊具郡丸森町火打石');
ok($zip->set_number('9812186')->is_valid_number, '宮城県伊具郡丸森町小坊木南');
ok($zip->set_number('9812186')->is_valid_number, '宮城県伊具郡丸森町小坊木北');
ok($zip->set_number('9812186')->is_valid_number, '宮城県伊具郡丸森町立沢南');
ok($zip->set_number('9812186')->is_valid_number, '宮城県伊具郡丸森町立沢北');
ok($zip->set_number('9812186')->is_valid_number, '宮城県伊具郡丸森町早坂');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町荒屋敷');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町大巻南');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町大巻北');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町川原田');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町川前');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町北原東');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町北原南');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町袖五郎');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町日照田');
ok($zip->set_number('9812187')->is_valid_number, '宮城県伊具郡丸森町水沢');
ok($zip->set_number('9812201')->is_valid_number, '宮城県伊具郡丸森町筆甫');
ok($zip->set_number('9812301')->is_valid_number, '宮城県伊具郡丸森町大張大蔵');
ok($zip->set_number('9812302')->is_valid_number, '宮城県伊具郡丸森町大張川張');
ok($zip->set_number('9812303')->is_valid_number, '宮城県伊具郡丸森町耕野');
ok($zip->set_number('9812401')->is_valid_number, '宮城県伊具郡丸森町小斎');
ok($zip->set_number('9812402')->is_valid_number, '宮城県伊具郡丸森町金山');
ok($zip->set_number('9812501')->is_valid_number, '宮城県伊具郡丸森町大内');
ok($zip->set_number('9813100')->is_valid_number, '宮城県仙台市泉区以下に掲載がない場合');
ok($zip->set_number('9813101')->is_valid_number, '宮城県仙台市泉区明石南');
ok($zip->set_number('9813102')->is_valid_number, '宮城県仙台市泉区向陽台');
ok($zip->set_number('9813103')->is_valid_number, '宮城県仙台市泉区山の寺');
ok($zip->set_number('9813104')->is_valid_number, '宮城県仙台市泉区永和台');
ok($zip->set_number('9813105')->is_valid_number, '宮城県仙台市泉区天神沢');
ok($zip->set_number('9813106')->is_valid_number, '宮城県仙台市泉区歩坂町');
ok($zip->set_number('9813107')->is_valid_number, '宮城県仙台市泉区本田町');
ok($zip->set_number('9813108')->is_valid_number, '宮城県仙台市泉区松陵');
ok($zip->set_number('9813109')->is_valid_number, '宮城県仙台市泉区鶴が丘');
ok($zip->set_number('9813111')->is_valid_number, '宮城県仙台市泉区松森');
ok($zip->set_number('9813112')->is_valid_number, '宮城県仙台市泉区八乙女');
ok($zip->set_number('9813113')->is_valid_number, '宮城県仙台市泉区真美沢');
ok($zip->set_number('9813114')->is_valid_number, '宮城県仙台市泉区友愛町');
ok($zip->set_number('9813115')->is_valid_number, '宮城県仙台市泉区愛隣町');
ok($zip->set_number('9813116')->is_valid_number, '宮城県仙台市泉区高玉町');
ok($zip->set_number('9813117')->is_valid_number, '宮城県仙台市泉区市名坂');
ok($zip->set_number('9813121')->is_valid_number, '宮城県仙台市泉区上谷刈');
ok($zip->set_number('9813122')->is_valid_number, '宮城県仙台市泉区加茂');
ok($zip->set_number('9813123')->is_valid_number, '宮城県仙台市泉区古内');
ok($zip->set_number('9813124')->is_valid_number, '宮城県仙台市泉区野村');
ok($zip->set_number('9813125')->is_valid_number, '宮城県仙台市泉区みずほ台');
ok($zip->set_number('9813126')->is_valid_number, '宮城県仙台市泉区泉中央南');
ok($zip->set_number('9813131')->is_valid_number, '宮城県仙台市泉区七北田');
ok($zip->set_number('9813132')->is_valid_number, '宮城県仙台市泉区将監');
ok($zip->set_number('9813133')->is_valid_number, '宮城県仙台市泉区泉中央');
ok($zip->set_number('9813134')->is_valid_number, '宮城県仙台市泉区桂');
ok($zip->set_number('9813135')->is_valid_number, '宮城県仙台市泉区八乙女中央');
ok($zip->set_number('9813136')->is_valid_number, '宮城県仙台市泉区将監殿');
ok($zip->set_number('9813137')->is_valid_number, '宮城県仙台市泉区大沢');
ok($zip->set_number('9813201')->is_valid_number, '宮城県仙台市泉区泉ケ丘');
ok($zip->set_number('9813202')->is_valid_number, '宮城県仙台市泉区北高森');
ok($zip->set_number('9813203')->is_valid_number, '宮城県仙台市泉区高森');
ok($zip->set_number('9813204')->is_valid_number, '宮城県仙台市泉区寺岡');
ok($zip->set_number('9813205')->is_valid_number, '宮城県仙台市泉区紫山');
ok($zip->set_number('9813206')->is_valid_number, '宮城県仙台市泉区明通');
ok($zip->set_number('9813211')->is_valid_number, '宮城県仙台市泉区長命ケ丘東');
ok($zip->set_number('9813212')->is_valid_number, '宮城県仙台市泉区長命ケ丘');
ok($zip->set_number('9813213')->is_valid_number, '宮城県仙台市泉区南中山');
ok($zip->set_number('9813214')->is_valid_number, '宮城県仙台市泉区館');
ok($zip->set_number('9813215')->is_valid_number, '宮城県仙台市泉区北中山');
ok($zip->set_number('9813216')->is_valid_number, '宮城県仙台市泉区小角');
ok($zip->set_number('9813217')->is_valid_number, '宮城県仙台市泉区実沢');
ok($zip->set_number('9813218')->is_valid_number, '宮城県仙台市泉区西中山');
ok($zip->set_number('9813221')->is_valid_number, '宮城県仙台市泉区根白石');
ok($zip->set_number('9813222')->is_valid_number, '宮城県仙台市泉区住吉台東');
ok($zip->set_number('9813223')->is_valid_number, '宮城県仙台市泉区住吉台西');
ok($zip->set_number('9813224')->is_valid_number, '宮城県仙台市泉区西田中');
ok($zip->set_number('9813225')->is_valid_number, '宮城県仙台市泉区福岡');
ok($zip->set_number('9813226')->is_valid_number, '宮城県仙台市泉区朴沢');
ok($zip->set_number('9813227')->is_valid_number, '宮城県仙台市泉区朝日');
ok($zip->set_number('9813271')->is_valid_number, '宮城県黒川郡大和町学苑');
ok($zip->set_number('9813300')->is_valid_number, '宮城県富谷市以下に掲載がない場合');
ok($zip->set_number('9813301')->is_valid_number, '宮城県富谷市志戸田');
ok($zip->set_number('9813302')->is_valid_number, '宮城県富谷市三ノ関');
ok($zip->set_number('9813303')->is_valid_number, '宮城県富谷市太子堂');
ok($zip->set_number('9813304')->is_valid_number, '宮城県富谷市ひより台');
ok($zip->set_number('9813305')->is_valid_number, '宮城県富谷市一ノ関');
ok($zip->set_number('9813306')->is_valid_number, '宮城県富谷市二ノ関');
ok($zip->set_number('9813311')->is_valid_number, '宮城県富谷市富谷');
ok($zip->set_number('9813312')->is_valid_number, '宮城県富谷市とちの木');
ok($zip->set_number('9813313')->is_valid_number, '宮城県富谷市高屋敷');
ok($zip->set_number('9813321')->is_valid_number, '宮城県富谷市大童');
ok($zip->set_number('9813322')->is_valid_number, '宮城県富谷市今泉');
ok($zip->set_number('9813323')->is_valid_number, '宮城県富谷市大亀');
ok($zip->set_number('9813324')->is_valid_number, '宮城県富谷市西成田');
ok($zip->set_number('9813325')->is_valid_number, '宮城県富谷市石積');
ok($zip->set_number('9813326')->is_valid_number, '宮城県富谷市明石');
ok($zip->set_number('9813327')->is_valid_number, '宮城県富谷市穀田');
ok($zip->set_number('9813328')->is_valid_number, '宮城県富谷市上桜木');
ok($zip->set_number('9813329')->is_valid_number, '宮城県富谷市大清水');
ok($zip->set_number('9813331')->is_valid_number, '宮城県富谷市東向陽台');
ok($zip->set_number('9813332')->is_valid_number, '宮城県富谷市明石台');
ok($zip->set_number('9813341')->is_valid_number, '宮城県富谷市成田');
ok($zip->set_number('9813351')->is_valid_number, '宮城県富谷市鷹乃杜');
ok($zip->set_number('9813352')->is_valid_number, '宮城県富谷市富ケ丘');
ok($zip->set_number('9813361')->is_valid_number, '宮城県富谷市あけの平');
ok($zip->set_number('9813362')->is_valid_number, '宮城県富谷市日吉台');
ok($zip->set_number('9813363')->is_valid_number, '宮城県富谷市杜乃橋');
ok($zip->set_number('9813401')->is_valid_number, '宮城県黒川郡大和町落合三ケ内');
ok($zip->set_number('9813402')->is_valid_number, '宮城県黒川郡大和町落合報恩寺');
ok($zip->set_number('9813403')->is_valid_number, '宮城県黒川郡大和町落合桧和田');
ok($zip->set_number('9813404')->is_valid_number, '宮城県黒川郡大和町落合相川');
ok($zip->set_number('9813405')->is_valid_number, '宮城県黒川郡大和町落合舞野');
ok($zip->set_number('9813406')->is_valid_number, '宮城県黒川郡大和町落合蒜袋');
ok($zip->set_number('9813407')->is_valid_number, '宮城県黒川郡大和町落合松坂');
ok($zip->set_number('9813408')->is_valid_number, '宮城県黒川郡大和町松坂平');
ok($zip->set_number('9813409')->is_valid_number, '宮城県黒川郡大和町流通平');
ok($zip->set_number('9813411')->is_valid_number, '宮城県黒川郡大和町鶴巣大平');
ok($zip->set_number('9813412')->is_valid_number, '宮城県黒川郡大和町鶴巣鳥屋');
ok($zip->set_number('9813413')->is_valid_number, '宮城県黒川郡大和町鶴巣幕柳');
ok($zip->set_number('9813414')->is_valid_number, '宮城県黒川郡大和町鶴巣太田');
ok($zip->set_number('9813415')->is_valid_number, '宮城県黒川郡大和町鶴巣小鶴沢');
ok($zip->set_number('9813416')->is_valid_number, '宮城県黒川郡大和町鶴巣山田');
ok($zip->set_number('9813417')->is_valid_number, '宮城県黒川郡大和町鶴巣北目大崎');
ok($zip->set_number('9813418')->is_valid_number, '宮城県黒川郡大和町鶴巣下草');
ok($zip->set_number('9813419')->is_valid_number, '宮城県黒川郡大和町まいの');
ok($zip->set_number('9813500')->is_valid_number, '宮城県黒川郡大郷町以下に掲載がない場合');
ok($zip->set_number('9813501')->is_valid_number, '宮城県黒川郡大郷町大松沢');
ok($zip->set_number('9813502')->is_valid_number, '宮城県黒川郡大郷町粕川');
ok($zip->set_number('9813503')->is_valid_number, '宮城県黒川郡大郷町石原');
ok($zip->set_number('9813511')->is_valid_number, '宮城県黒川郡大郷町山崎');
ok($zip->set_number('9813512')->is_valid_number, '宮城県黒川郡大郷町不来内');
ok($zip->set_number('9813513')->is_valid_number, '宮城県黒川郡大郷町味明');
ok($zip->set_number('9813514')->is_valid_number, '宮城県黒川郡大郷町川内');
ok($zip->set_number('9813515')->is_valid_number, '宮城県黒川郡大郷町羽生');
ok($zip->set_number('9813521')->is_valid_number, '宮城県黒川郡大郷町中村');
ok($zip->set_number('9813522')->is_valid_number, '宮城県黒川郡大郷町東成田');
ok($zip->set_number('9813523')->is_valid_number, '宮城県黒川郡大郷町土橋');
ok($zip->set_number('9813524')->is_valid_number, '宮城県黒川郡大郷町鶉崎');
ok($zip->set_number('9813600')->is_valid_number, '宮城県黒川郡大和町以下に掲載がない場合');
ok($zip->set_number('9813600')->is_valid_number, '宮城県黒川郡大衡村以下に掲載がない場合');
ok($zip->set_number('9813601')->is_valid_number, '宮城県黒川郡大衡村大瓜');
ok($zip->set_number('9813602')->is_valid_number, '宮城県黒川郡大衡村大衡');
ok($zip->set_number('9813603')->is_valid_number, '宮城県黒川郡大衡村沖の平');
ok($zip->set_number('9813604')->is_valid_number, '宮城県黒川郡大衡村駒場');
ok($zip->set_number('9813605')->is_valid_number, '宮城県黒川郡大衡村大森');
ok($zip->set_number('9813606')->is_valid_number, '宮城県黒川郡大衡村桔梗平');
ok($zip->set_number('9813607')->is_valid_number, '宮城県黒川郡大衡村奥田');
ok($zip->set_number('9813608')->is_valid_number, '宮城県黒川郡大衡村松の平');
ok($zip->set_number('9813609')->is_valid_number, '宮城県黒川郡大衡村中央平');
ok($zip->set_number('9813611')->is_valid_number, '宮城県黒川郡大衡村ときわ台');
ok($zip->set_number('9813612')->is_valid_number, '宮城県黒川郡大衡村ときわ台南');
ok($zip->set_number('9813621')->is_valid_number, '宮城県黒川郡大和町吉岡');
ok($zip->set_number('9813622')->is_valid_number, '宮城県黒川郡大和町もみじケ丘');
ok($zip->set_number('9813623')->is_valid_number, '宮城県黒川郡大和町小野');
ok($zip->set_number('9813624')->is_valid_number, '宮城県黒川郡大和町宮床');
ok($zip->set_number('9813625')->is_valid_number, '宮城県黒川郡大和町吉田');
ok($zip->set_number('9813626')->is_valid_number, '宮城県黒川郡大和町吉岡南');
ok($zip->set_number('9813627')->is_valid_number, '宮城県黒川郡大和町吉岡東');
ok($zip->set_number('9813628')->is_valid_number, '宮城県黒川郡大和町杜の丘');
ok($zip->set_number('9813629')->is_valid_number, '宮城県黒川郡大和町テクノヒルズ');
ok($zip->set_number('9813631')->is_valid_number, '宮城県黒川郡大和町吉岡天皇寺東');
ok($zip->set_number('9813632')->is_valid_number, '宮城県黒川郡大和町吉岡まほろば');
ok($zip->set_number('9814100')->is_valid_number, '宮城県加美郡色麻町以下に掲載がない場合');
ok($zip->set_number('9814101')->is_valid_number, '宮城県加美郡色麻町清水');
ok($zip->set_number('9814102')->is_valid_number, '宮城県加美郡色麻町高城');
ok($zip->set_number('9814103')->is_valid_number, '宮城県加美郡色麻町高根');
ok($zip->set_number('9814104')->is_valid_number, '宮城県加美郡色麻町平沢');
ok($zip->set_number('9814105')->is_valid_number, '宮城県加美郡色麻町吉田');
ok($zip->set_number('9814111')->is_valid_number, '宮城県加美郡色麻町黒沢');
ok($zip->set_number('9814112')->is_valid_number, '宮城県加美郡色麻町志津');
ok($zip->set_number('9814121')->is_valid_number, '宮城県加美郡色麻町一の関');
ok($zip->set_number('9814122')->is_valid_number, '宮城県加美郡色麻町四竃');
ok($zip->set_number('9814131')->is_valid_number, '宮城県加美郡色麻町大');
ok($zip->set_number('9814141')->is_valid_number, '宮城県加美郡色麻町王城寺');
ok($zip->set_number('9814151')->is_valid_number, '宮城県加美郡色麻町小栗山');
ok($zip->set_number('9814200')->is_valid_number, '宮城県加美郡加美町以下に掲載がない場合');
ok($zip->set_number('9814201')->is_valid_number, '宮城県加美郡加美町上多田川');
ok($zip->set_number('9814202')->is_valid_number, '宮城県加美郡加美町下多田川');
ok($zip->set_number('9814203')->is_valid_number, '宮城県加美郡加美町菜切谷');
ok($zip->set_number('9814211')->is_valid_number, '宮城県加美郡加美町上狼塚');
ok($zip->set_number('9814212')->is_valid_number, '宮城県加美郡加美町下狼塚');
ok($zip->set_number('9814213')->is_valid_number, '宮城県加美郡加美町平柳');
ok($zip->set_number('9814221')->is_valid_number, '宮城県加美郡加美町四日市場');
ok($zip->set_number('9814222')->is_valid_number, '宮城県加美郡加美町下新田');
ok($zip->set_number('9814223')->is_valid_number, '宮城県加美郡加美町雑式ノ目');
ok($zip->set_number('9814224')->is_valid_number, '宮城県加美郡加美町木伏');
ok($zip->set_number('9814225')->is_valid_number, '宮城県加美郡加美町新木伏');
ok($zip->set_number('9814226')->is_valid_number, '宮城県加美郡加美町押登目');
ok($zip->set_number('9814227')->is_valid_number, '宮城県加美郡加美町新川原');
ok($zip->set_number('9814228')->is_valid_number, '宮城県加美郡加美町鹿島越');
ok($zip->set_number('9814229')->is_valid_number, '宮城県加美郡加美町薬師堂');
ok($zip->set_number('9814231')->is_valid_number, '宮城県加美郡加美町百目木1番');
ok($zip->set_number('9814232')->is_valid_number, '宮城県加美郡加美町百目木2番');
ok($zip->set_number('9814233')->is_valid_number, '宮城県加美郡加美町百目木3番');
ok($zip->set_number('9814234')->is_valid_number, '宮城県加美郡加美町旧舘1番');
ok($zip->set_number('9814235')->is_valid_number, '宮城県加美郡加美町旧舘2番');
ok($zip->set_number('9814241')->is_valid_number, '宮城県加美郡加美町南町');
ok($zip->set_number('9814242')->is_valid_number, '宮城県加美郡加美町町西');
ok($zip->set_number('9814251')->is_valid_number, '宮城県加美郡加美町西町');
ok($zip->set_number('9814252')->is_valid_number, '宮城県加美郡加美町西田');
ok($zip->set_number('9814253')->is_valid_number, '宮城県加美郡加美町大門');
ok($zip->set_number('9814254')->is_valid_number, '宮城県加美郡加美町北町');
ok($zip->set_number('9814255')->is_valid_number, '宮城県加美郡加美町岡町');
ok($zip->set_number('9814256')->is_valid_number, '宮城県加美郡加美町下川原');
ok($zip->set_number('9814261')->is_valid_number, '宮城県加美郡加美町町裏');
ok($zip->set_number('9814262')->is_valid_number, '宮城県加美郡加美町一本杉');
ok($zip->set_number('9814263')->is_valid_number, '宮城県加美郡加美町雁原');
ok($zip->set_number('9814264')->is_valid_number, '宮城県加美郡加美町赤塚');
ok($zip->set_number('9814265')->is_valid_number, '宮城県加美郡加美町矢越');
ok($zip->set_number('9814271')->is_valid_number, '宮城県加美郡加美町羽場');
ok($zip->set_number('9814272')->is_valid_number, '宮城県加美郡加美町城生');
ok($zip->set_number('9814273')->is_valid_number, '宮城県加美郡加美町上川原');
ok($zip->set_number('9814274')->is_valid_number, '宮城県加美郡加美町一本柳');
ok($zip->set_number('9814275')->is_valid_number, '宮城県加美郡加美町穴畑');
ok($zip->set_number('9814276')->is_valid_number, '宮城県加美郡加美町焼橋');
ok($zip->set_number('9814277')->is_valid_number, '宮城県加美郡加美町一本柳南');
ok($zip->set_number('9814301')->is_valid_number, '宮城県加美郡加美町樋田');
ok($zip->set_number('9814302')->is_valid_number, '宮城県加美郡加美町下野目');
ok($zip->set_number('9814303')->is_valid_number, '宮城県加美郡加美町前田下');
ok($zip->set_number('9814304')->is_valid_number, '宮城県加美郡加美町久保');
ok($zip->set_number('9814305')->is_valid_number, '宮城県加美郡加美町宮田');
ok($zip->set_number('9814306')->is_valid_number, '宮城県加美郡加美町天王');
ok($zip->set_number('9814308')->is_valid_number, '宮城県加美郡加美町長町');
ok($zip->set_number('9814309')->is_valid_number, '宮城県加美郡加美町蓬田');
ok($zip->set_number('9814311')->is_valid_number, '宮城県加美郡加美町板橋');
ok($zip->set_number('9814312')->is_valid_number, '宮城県加美郡加美町月崎(皆屋敷)');
ok($zip->set_number('9814313')->is_valid_number, '宮城県加美郡加美町二ノ坪');
ok($zip->set_number('9814314')->is_valid_number, '宮城県加美郡加美町田中');
ok($zip->set_number('9814315')->is_valid_number, '宮城県加美郡加美町中嶋');
ok($zip->set_number('9814316')->is_valid_number, '宮城県加美郡加美町月崎(その他)');
ok($zip->set_number('9814317')->is_valid_number, '宮城県加美郡加美町神山西');
ok($zip->set_number('9814318')->is_valid_number, '宮城県加美郡加美町清水田');
ok($zip->set_number('9814319')->is_valid_number, '宮城県加美郡加美町久保田');
ok($zip->set_number('9814321')->is_valid_number, '宮城県加美郡加美町下原');
ok($zip->set_number('9814322')->is_valid_number, '宮城県加美郡加美町北下原');
ok($zip->set_number('9814323')->is_valid_number, '宮城県加美郡加美町石原');
ok($zip->set_number('9814324')->is_valid_number, '宮城県加美郡加美町北原');
ok($zip->set_number('9814325')->is_valid_number, '宮城県加美郡加美町五百刈');
ok($zip->set_number('9814326')->is_valid_number, '宮城県加美郡加美町北ノ口');
ok($zip->set_number('9814327')->is_valid_number, '宮城県加美郡加美町上野原');
ok($zip->set_number('9814328')->is_valid_number, '宮城県加美郡加美町一里塚');
ok($zip->set_number('9814329')->is_valid_number, '宮城県加美郡加美町鶴羽美');
ok($zip->set_number('9814331')->is_valid_number, '宮城県加美郡加美町北寺宿');
ok($zip->set_number('9814332')->is_valid_number, '宮城県加美郡加美町南寺宿');
ok($zip->set_number('9814333')->is_valid_number, '宮城県加美郡加美町中畑');
ok($zip->set_number('9814334')->is_valid_number, '宮城県加美郡加美町町屋敷');
ok($zip->set_number('9814335')->is_valid_number, '宮城県加美郡加美町新小路');
ok($zip->set_number('9814336')->is_valid_number, '宮城県加美郡加美町下タ川原');
ok($zip->set_number('9814337')->is_valid_number, '宮城県加美郡加美町長檀');
ok($zip->set_number('9814341')->is_valid_number, '宮城県加美郡加美町中原');
ok($zip->set_number('9814342')->is_valid_number, '宮城県加美郡加美町原中原浦');
ok($zip->set_number('9814343')->is_valid_number, '宮城県加美郡加美町内谷地');
ok($zip->set_number('9814344')->is_valid_number, '宮城県加美郡加美町原道端屋敷');
ok($zip->set_number('9814345')->is_valid_number, '宮城県加美郡加美町下北浦');
ok($zip->set_number('9814346')->is_valid_number, '宮城県加美郡加美町原南江端');
ok($zip->set_number('9814347')->is_valid_number, '宮城県加美郡加美町原高谷地屋敷');
ok($zip->set_number('9814351')->is_valid_number, '宮城県加美郡加美町南小路');
ok($zip->set_number('9814352')->is_valid_number, '宮城県加美郡加美町八石下');
ok($zip->set_number('9814353')->is_valid_number, '宮城県加美郡加美町照井');
ok($zip->set_number('9814354')->is_valid_number, '宮城県加美郡加美町麓山');
ok($zip->set_number('9814355')->is_valid_number, '宮城県加美郡加美町鹿原');
ok($zip->set_number('9814356')->is_valid_number, '宮城県加美郡加美町芋沢');
ok($zip->set_number('9814357')->is_valid_number, '宮城県加美郡加美町城内');
ok($zip->set_number('9814358')->is_valid_number, '宮城県加美郡加美町西八石');
ok($zip->set_number('9814361')->is_valid_number, '宮城県加美郡加美町藤兵衛前');
ok($zip->set_number('9814362')->is_valid_number, '宮城県加美郡加美町小瀬');
ok($zip->set_number('9814363')->is_valid_number, '宮城県加美郡加美町滝下');
ok($zip->set_number('9814364')->is_valid_number, '宮城県加美郡加美町松田');
ok($zip->set_number('9814365')->is_valid_number, '宮城県加美郡加美町伯治');
ok($zip->set_number('9814366')->is_valid_number, '宮城県加美郡加美町水芋');
ok($zip->set_number('9814367')->is_valid_number, '宮城県加美郡加美町門沢');
ok($zip->set_number('9814368')->is_valid_number, '宮城県加美郡加美町漆沢');
ok($zip->set_number('9814369')->is_valid_number, '宮城県加美郡加美町新松田');
ok($zip->set_number('9814371')->is_valid_number, '宮城県加美郡加美町原');
ok($zip->set_number('9814372')->is_valid_number, '宮城県加美郡加美町長清水');
ok($zip->set_number('9814373')->is_valid_number, '宮城県加美郡加美町原町');
ok($zip->set_number('9814374')->is_valid_number, '宮城県加美郡加美町上野目');
ok($zip->set_number('9814375')->is_valid_number, '宮城県加美郡加美町味ケ袋');
ok($zip->set_number('9814376')->is_valid_number, '宮城県加美郡加美町新北雷屋敷');
ok($zip->set_number('9814377')->is_valid_number, '宮城県加美郡加美町新南雷屋敷');
ok($zip->set_number('9814381')->is_valid_number, '宮城県加美郡加美町大谷地');
ok($zip->set_number('9814382')->is_valid_number, '宮城県加美郡加美町新伯治');
ok($zip->set_number('9814383')->is_valid_number, '宮城県加美郡加美町新滝下');
ok($zip->set_number('9814384')->is_valid_number, '宮城県加美郡加美町新藤兵衛前');
ok($zip->set_number('9814385')->is_valid_number, '宮城県加美郡加美町下原前');
ok($zip->set_number('9814386')->is_valid_number, '宮城県加美郡加美町城野');
ok($zip->set_number('9814401')->is_valid_number, '宮城県加美郡加美町宮崎');
ok($zip->set_number('9814402')->is_valid_number, '宮城県加美郡加美町北川内');
ok($zip->set_number('9814403')->is_valid_number, '宮城県加美郡加美町柳沢');
ok($zip->set_number('9814411')->is_valid_number, '宮城県加美郡加美町谷地森');
ok($zip->set_number('9814412')->is_valid_number, '宮城県加美郡加美町鳥嶋');
ok($zip->set_number('9814413')->is_valid_number, '宮城県加美郡加美町鳥屋ケ崎');
ok($zip->set_number('9814414')->is_valid_number, '宮城県加美郡加美町孫沢');
ok($zip->set_number('9814415')->is_valid_number, '宮城県加美郡加美町米泉');
ok($zip->set_number('9814416')->is_valid_number, '宮城県加美郡加美町沼ケ袋');
ok($zip->set_number('9814417')->is_valid_number, '宮城県加美郡加美町君ケ袋');
ok($zip->set_number('9814418')->is_valid_number, '宮城県加美郡加美町小泉');
ok($zip->set_number('9814419')->is_valid_number, '宮城県加美郡加美町木舟');
ok($zip->set_number('9818001')->is_valid_number, '宮城県仙台市泉区南光台東');
ok($zip->set_number('9818002')->is_valid_number, '宮城県仙台市泉区南光台南');
ok($zip->set_number('9818003')->is_valid_number, '宮城県仙台市泉区南光台');
ok($zip->set_number('9818004')->is_valid_number, '宮城県仙台市泉区旭丘堤');
ok($zip->set_number('9818005')->is_valid_number, '宮城県仙台市泉区東黒松');
ok($zip->set_number('9818006')->is_valid_number, '宮城県仙台市泉区黒松');
ok($zip->set_number('9818007')->is_valid_number, '宮城県仙台市泉区虹の丘');
ok($zip->set_number('9820000')->is_valid_number, '宮城県仙台市太白区以下に掲載がない場合');
ok($zip->set_number('9820001')->is_valid_number, '宮城県仙台市太白区八本松');
ok($zip->set_number('9820002')->is_valid_number, '宮城県仙台市太白区飯田');
ok($zip->set_number('9820003')->is_valid_number, '宮城県仙台市太白区郡山');
ok($zip->set_number('9820004')->is_valid_number, '宮城県仙台市太白区東大野田');
ok($zip->set_number('9820005')->is_valid_number, '宮城県仙台市太白区諏訪町');
ok($zip->set_number('9820006')->is_valid_number, '宮城県仙台市太白区東郡山');
ok($zip->set_number('9820007')->is_valid_number, '宮城県仙台市太白区あすと長町');
ok($zip->set_number('9820011')->is_valid_number, '宮城県仙台市太白区長町');
ok($zip->set_number('9820012')->is_valid_number, '宮城県仙台市太白区長町南');
ok($zip->set_number('9820013')->is_valid_number, '宮城県仙台市太白区太子堂');
ok($zip->set_number('9820014')->is_valid_number, '宮城県仙台市太白区大野田');
ok($zip->set_number('9820015')->is_valid_number, '宮城県仙台市太白区南大野田');
ok($zip->set_number('9820021')->is_valid_number, '宮城県仙台市太白区緑ケ丘');
ok($zip->set_number('9820022')->is_valid_number, '宮城県仙台市太白区鹿野本町');
ok($zip->set_number('9820023')->is_valid_number, '宮城県仙台市太白区鹿野');
ok($zip->set_number('9820024')->is_valid_number, '宮城県仙台市太白区砂押南町');
ok($zip->set_number('9820025')->is_valid_number, '宮城県仙台市太白区砂押町');
ok($zip->set_number('9820026')->is_valid_number, '宮城県仙台市太白区土手内');
ok($zip->set_number('9820027')->is_valid_number, '宮城県仙台市太白区大塒町');
ok($zip->set_number('9820031')->is_valid_number, '宮城県仙台市太白区泉崎');
ok($zip->set_number('9820032')->is_valid_number, '宮城県仙台市太白区富沢');
ok($zip->set_number('9820033')->is_valid_number, '宮城県仙台市太白区富田');
ok($zip->set_number('9820034')->is_valid_number, '宮城県仙台市太白区西多賀');
ok($zip->set_number('9820035')->is_valid_number, '宮城県仙台市太白区大谷地');
ok($zip->set_number('9820036')->is_valid_number, '宮城県仙台市太白区富沢南');
ok($zip->set_number('9820037')->is_valid_number, '宮城県仙台市太白区富沢西');
ok($zip->set_number('9820211')->is_valid_number, '宮城県仙台市太白区佐保山');
ok($zip->set_number('9820212')->is_valid_number, '宮城県仙台市太白区太白');
ok($zip->set_number('9820213')->is_valid_number, '宮城県仙台市太白区山田自由ケ丘');
ok($zip->set_number('9820214')->is_valid_number, '宮城県仙台市太白区山田(山田山24-2)');
ok($zip->set_number('9820215')->is_valid_number, '宮城県仙台市太白区旗立');
ok($zip->set_number('9820221')->is_valid_number, '宮城県仙台市太白区日本平');
ok($zip->set_number('9820222')->is_valid_number, '宮城県仙台市太白区人来田');
ok($zip->set_number('9820231')->is_valid_number, '宮城県仙台市太白区坪沼');
ok($zip->set_number('9820241')->is_valid_number, '宮城県仙台市太白区秋保町湯元');
ok($zip->set_number('9820242')->is_valid_number, '宮城県仙台市太白区秋保町境野');
ok($zip->set_number('9820243')->is_valid_number, '宮城県仙台市太白区秋保町長袋');
ok($zip->set_number('9820244')->is_valid_number, '宮城県仙台市太白区秋保町馬場');
ok($zip->set_number('9820245')->is_valid_number, '宮城県仙台市太白区秋保町湯向');
ok($zip->set_number('9820251')->is_valid_number, '宮城県仙台市太白区茂庭');
ok($zip->set_number('9820252')->is_valid_number, '宮城県仙台市太白区茂庭台');
ok($zip->set_number('9820261')->is_valid_number, '宮城県仙台市青葉区折立');
ok($zip->set_number('9820262')->is_valid_number, '宮城県仙台市青葉区西花苑');
ok($zip->set_number('9820263')->is_valid_number, '宮城県仙台市青葉区茂庭');
ok($zip->set_number('9820801')->is_valid_number, '宮城県仙台市太白区八木山本町');
ok($zip->set_number('9820802')->is_valid_number, '宮城県仙台市太白区八木山東');
ok($zip->set_number('9820803')->is_valid_number, '宮城県仙台市太白区金剛沢');
ok($zip->set_number('9820804')->is_valid_number, '宮城県仙台市太白区鈎取');
ok($zip->set_number('9820805')->is_valid_number, '宮城県仙台市太白区鈎取本町');
ok($zip->set_number('9820806')->is_valid_number, '宮城県仙台市太白区御堂平');
ok($zip->set_number('9820807')->is_valid_number, '宮城県仙台市太白区八木山南');
ok($zip->set_number('9820811')->is_valid_number, '宮城県仙台市太白区ひより台');
ok($zip->set_number('9820812')->is_valid_number, '宮城県仙台市太白区上野山');
ok($zip->set_number('9820813')->is_valid_number, '宮城県仙台市太白区山田北前町');
ok($zip->set_number('9820814')->is_valid_number, '宮城県仙台市太白区山田(その他)');
ok($zip->set_number('9820815')->is_valid_number, '宮城県仙台市太白区山田上ノ台町');
ok($zip->set_number('9820816')->is_valid_number, '宮城県仙台市太白区山田本町');
ok($zip->set_number('9820817')->is_valid_number, '宮城県仙台市太白区羽黒台');
ok($zip->set_number('9820818')->is_valid_number, '宮城県仙台市太白区山田新町');
ok($zip->set_number('9820821')->is_valid_number, '宮城県仙台市太白区松が丘');
ok($zip->set_number('9820822')->is_valid_number, '宮城県仙台市太白区若葉町');
ok($zip->set_number('9820823')->is_valid_number, '宮城県仙台市太白区恵和町');
ok($zip->set_number('9820824')->is_valid_number, '宮城県仙台市太白区芦の口');
ok($zip->set_number('9820825')->is_valid_number, '宮城県仙台市太白区西の平');
ok($zip->set_number('9820826')->is_valid_number, '宮城県仙台市太白区三神峯');
ok($zip->set_number('9820831')->is_valid_number, '宮城県仙台市太白区八木山香澄町');
ok($zip->set_number('9820832')->is_valid_number, '宮城県仙台市太白区八木山緑町');
ok($zip->set_number('9820833')->is_valid_number, '宮城県仙台市太白区八木山弥生町');
ok($zip->set_number('9820834')->is_valid_number, '宮城県仙台市太白区青山');
ok($zip->set_number('9820835')->is_valid_number, '宮城県仙台市太白区桜木町');
ok($zip->set_number('9820836')->is_valid_number, '宮城県仙台市太白区八木山松波町');
ok($zip->set_number('9820837')->is_valid_number, '宮城県仙台市太白区長町(越路)');
ok($zip->set_number('9820841')->is_valid_number, '宮城県仙台市太白区向山');
ok($zip->set_number('9820842')->is_valid_number, '宮城県仙台市太白区越路');
ok($zip->set_number('9820843')->is_valid_number, '宮城県仙台市太白区茂ケ崎');
ok($zip->set_number('9820844')->is_valid_number, '宮城県仙台市太白区根岸町');
ok($zip->set_number('9820845')->is_valid_number, '宮城県仙台市太白区門前町');
ok($zip->set_number('9820846')->is_valid_number, '宮城県仙台市太白区二ツ沢');
ok($zip->set_number('9820847')->is_valid_number, '宮城県仙台市太白区長嶺');
ok($zip->set_number('9820848')->is_valid_number, '宮城県仙台市太白区萩ケ丘');
ok($zip->set_number('9830000')->is_valid_number, '宮城県仙台市宮城野区以下に掲載がない場合');
ok($zip->set_number('9830001')->is_valid_number, '宮城県仙台市宮城野区港(1~4丁目)');
ok($zip->set_number('9830002')->is_valid_number, '宮城県仙台市宮城野区蒲生');
ok($zip->set_number('9830003')->is_valid_number, '宮城県仙台市宮城野区岡田');
ok($zip->set_number('9830004')->is_valid_number, '宮城県仙台市宮城野区岡田西町');
ok($zip->set_number('9830005')->is_valid_number, '宮城県仙台市宮城野区福室');
ok($zip->set_number('9830006')->is_valid_number, '宮城県仙台市宮城野区白鳥');
ok($zip->set_number('9830007')->is_valid_number, '宮城県仙台市宮城野区仙台港北');
ok($zip->set_number('9830011')->is_valid_number, '宮城県仙台市宮城野区栄');
ok($zip->set_number('9830012')->is_valid_number, '宮城県仙台市宮城野区出花');
ok($zip->set_number('9830013')->is_valid_number, '宮城県仙台市宮城野区中野');
ok($zip->set_number('9830014')->is_valid_number, '宮城県仙台市宮城野区高砂');
ok($zip->set_number('9830021')->is_valid_number, '宮城県仙台市宮城野区田子');
ok($zip->set_number('9830023')->is_valid_number, '宮城県仙台市宮城野区福田町');
ok($zip->set_number('9830024')->is_valid_number, '宮城県仙台市宮城野区鶴巻');
ok($zip->set_number('9830025')->is_valid_number, '宮城県仙台市宮城野区福田町南');
ok($zip->set_number('9830026')->is_valid_number, '宮城県仙台市宮城野区田子西');
ok($zip->set_number('9830031')->is_valid_number, '宮城県仙台市宮城野区小鶴');
ok($zip->set_number('9830032')->is_valid_number, '宮城県仙台市宮城野区仙石');
ok($zip->set_number('9830033')->is_valid_number, '宮城県仙台市宮城野区福住町');
ok($zip->set_number('9830034')->is_valid_number, '宮城県仙台市宮城野区扇町');
ok($zip->set_number('9830035')->is_valid_number, '宮城県仙台市宮城野区日の出町');
ok($zip->set_number('9830036')->is_valid_number, '宮城県仙台市宮城野区苦竹');
ok($zip->set_number('9830036')->is_valid_number, '宮城県仙台市宮城野区原町苦竹');
ok($zip->set_number('9830037')->is_valid_number, '宮城県仙台市宮城野区平成');
ok($zip->set_number('9830038')->is_valid_number, '宮城県仙台市宮城野区新田');
ok($zip->set_number('9830039')->is_valid_number, '宮城県仙台市宮城野区新田東');
ok($zip->set_number('9830041')->is_valid_number, '宮城県仙台市宮城野区南目館');
ok($zip->set_number('9830042')->is_valid_number, '宮城県仙台市宮城野区東宮城野');
ok($zip->set_number('9830043')->is_valid_number, '宮城県仙台市宮城野区萩野町');
ok($zip->set_number('9830044')->is_valid_number, '宮城県仙台市宮城野区宮千代');
ok($zip->set_number('9830045')->is_valid_number, '宮城県仙台市宮城野区宮城野');
ok($zip->set_number('9830046')->is_valid_number, '宮城県仙台市宮城野区西宮城野');
ok($zip->set_number('9830047')->is_valid_number, '宮城県仙台市宮城野区銀杏町');
ok($zip->set_number('9830803')->is_valid_number, '宮城県仙台市宮城野区小田原(1~3丁目)');
ok($zip->set_number('9830811')->is_valid_number, '宮城県仙台市宮城野区小田原清水沼通');
ok($zip->set_number('9830812')->is_valid_number, '宮城県仙台市宮城野区小田原弓ノ町');
ok($zip->set_number('9830813')->is_valid_number, '宮城県仙台市宮城野区小田原牛小屋丁');
ok($zip->set_number('9830814')->is_valid_number, '宮城県仙台市宮城野区小田原大行院丁');
ok($zip->set_number('9830815')->is_valid_number, '宮城県仙台市宮城野区小田原広丁');
ok($zip->set_number('9830816')->is_valid_number, '宮城県仙台市宮城野区小田原金剛院丁');
ok($zip->set_number('9830817')->is_valid_number, '宮城県仙台市宮城野区小田原山本丁');
ok($zip->set_number('9830821')->is_valid_number, '宮城県仙台市宮城野区岩切');
ok($zip->set_number('9830822')->is_valid_number, '宮城県仙台市宮城野区燕沢東');
ok($zip->set_number('9830823')->is_valid_number, '宮城県仙台市宮城野区燕沢');
ok($zip->set_number('9830824')->is_valid_number, '宮城県仙台市宮城野区鶴ケ谷');
ok($zip->set_number('9830825')->is_valid_number, '宮城県仙台市宮城野区鶴ケ谷北');
ok($zip->set_number('9830826')->is_valid_number, '宮城県仙台市宮城野区鶴ケ谷東');
ok($zip->set_number('9830828')->is_valid_number, '宮城県仙台市宮城野区岩切分台');
ok($zip->set_number('9830831')->is_valid_number, '宮城県仙台市宮城野区自由ケ丘');
ok($zip->set_number('9830832')->is_valid_number, '宮城県仙台市宮城野区安養寺');
ok($zip->set_number('9830833')->is_valid_number, '宮城県仙台市宮城野区東仙台');
ok($zip->set_number('9830834')->is_valid_number, '宮城県仙台市宮城野区松岡町');
ok($zip->set_number('9830835')->is_valid_number, '宮城県仙台市宮城野区大梶');
ok($zip->set_number('9830836')->is_valid_number, '宮城県仙台市宮城野区幸町');
ok($zip->set_number('9830837')->is_valid_number, '宮城県仙台市宮城野区枡江');
ok($zip->set_number('9830838')->is_valid_number, '宮城県仙台市宮城野区二の森');
ok($zip->set_number('9830839')->is_valid_number, '宮城県仙台市宮城野区蟹沢');
ok($zip->set_number('9830841')->is_valid_number, '宮城県仙台市宮城野区原町');
ok($zip->set_number('9830842')->is_valid_number, '宮城県仙台市宮城野区五輪');
ok($zip->set_number('9830843')->is_valid_number, '宮城県仙台市宮城野区二十人町通');
ok($zip->set_number('9830844')->is_valid_number, '宮城県仙台市宮城野区原町南目');
ok($zip->set_number('9830845')->is_valid_number, '宮城県仙台市宮城野区清水沼');
ok($zip->set_number('9830851')->is_valid_number, '宮城県仙台市宮城野区榴ケ岡');
ok($zip->set_number('9830852')->is_valid_number, '宮城県仙台市宮城野区榴岡');
ok($zip->set_number('9830853')->is_valid_number, '宮城県仙台市宮城野区東六番丁');
ok($zip->set_number('9830861')->is_valid_number, '宮城県仙台市宮城野区鉄砲町');
ok($zip->set_number('9830862')->is_valid_number, '宮城県仙台市宮城野区二十人町');
ok($zip->set_number('9830863')->is_valid_number, '宮城県仙台市宮城野区車町');
ok($zip->set_number('9830864')->is_valid_number, '宮城県仙台市宮城野区名掛丁');
ok($zip->set_number('9830865')->is_valid_number, '宮城県仙台市宮城野区元寺小路');
ok($zip->set_number('9830866')->is_valid_number, '宮城県仙台市宮城野区花京院通');
ok($zip->set_number('9830867')->is_valid_number, '宮城県仙台市宮城野区鉄砲町東');
ok($zip->set_number('9830868')->is_valid_number, '宮城県仙台市宮城野区鉄砲町中');
ok($zip->set_number('9830869')->is_valid_number, '宮城県仙台市宮城野区鉄砲町西');
ok($zip->set_number('9840000')->is_valid_number, '宮城県仙台市若林区以下に掲載がない場合');
ok($zip->set_number('9840001')->is_valid_number, '宮城県仙台市若林区鶴代町');
ok($zip->set_number('9840002')->is_valid_number, '宮城県仙台市若林区卸町東');
ok($zip->set_number('9840003')->is_valid_number, '宮城県仙台市若林区六丁の目北町');
ok($zip->set_number('9840004')->is_valid_number, '宮城県仙台市若林区六丁の目東町');
ok($zip->set_number('9840011')->is_valid_number, '宮城県仙台市若林区六丁の目西町');
ok($zip->set_number('9840012')->is_valid_number, '宮城県仙台市若林区六丁の目中町');
ok($zip->set_number('9840013')->is_valid_number, '宮城県仙台市若林区六丁の目南町');
ok($zip->set_number('9840014')->is_valid_number, '宮城県仙台市若林区六丁の目元町');
ok($zip->set_number('9840015')->is_valid_number, '宮城県仙台市若林区卸町');
ok($zip->set_number('9840016')->is_valid_number, '宮城県仙台市若林区蒲町東');
ok($zip->set_number('9840017')->is_valid_number, '宮城県仙台市若林区なないろの里');
ok($zip->set_number('9840022')->is_valid_number, '宮城県仙台市若林区五橋(3丁目)');
ok($zip->set_number('9840030')->is_valid_number, '宮城県仙台市若林区荒井東');
ok($zip->set_number('9840031')->is_valid_number, '宮城県仙台市若林区六丁目');
ok($zip->set_number('9840032')->is_valid_number, '宮城県仙台市若林区荒井');
ok($zip->set_number('9840033')->is_valid_number, '宮城県仙台市若林区荒浜');
ok($zip->set_number('9840034')->is_valid_number, '宮城県仙台市若林区荒浜新');
ok($zip->set_number('9840035')->is_valid_number, '宮城県仙台市若林区霞目');
ok($zip->set_number('9840036')->is_valid_number, '宮城県仙台市若林区長喜城');
ok($zip->set_number('9840037')->is_valid_number, '宮城県仙台市若林区蒲町');
ok($zip->set_number('9840038')->is_valid_number, '宮城県仙台市若林区伊在');
ok($zip->set_number('9840039')->is_valid_number, '宮城県仙台市若林区荒井南');
ok($zip->set_number('9840041')->is_valid_number, '宮城県仙台市若林区志波町');
ok($zip->set_number('9840042')->is_valid_number, '宮城県仙台市若林区大和町');
ok($zip->set_number('9840043')->is_valid_number, '宮城県仙台市若林区東新丁');
ok($zip->set_number('9840044')->is_valid_number, '宮城県仙台市若林区椌木通');
ok($zip->set_number('9840045')->is_valid_number, '宮城県仙台市若林区西新丁');
ok($zip->set_number('9840046')->is_valid_number, '宮城県仙台市若林区二軒茶屋');
ok($zip->set_number('9840047')->is_valid_number, '宮城県仙台市若林区木ノ下');
ok($zip->set_number('9840048')->is_valid_number, '宮城県仙台市若林区白萩町');
ok($zip->set_number('9840051')->is_valid_number, '宮城県仙台市若林区新寺');
ok($zip->set_number('9840052')->is_valid_number, '宮城県仙台市若林区連坊');
ok($zip->set_number('9840053')->is_valid_number, '宮城県仙台市若林区連坊小路');
ok($zip->set_number('9840054')->is_valid_number, '宮城県仙台市若林区裏柴田町');
ok($zip->set_number('9840055')->is_valid_number, '宮城県仙台市若林区表柴田町');
ok($zip->set_number('9840056')->is_valid_number, '宮城県仙台市若林区成田町');
ok($zip->set_number('9840057')->is_valid_number, '宮城県仙台市若林区三百人町');
ok($zip->set_number('9840058')->is_valid_number, '宮城県仙台市若林区元茶畑');
ok($zip->set_number('9840061')->is_valid_number, '宮城県仙台市若林区南鍛冶町');
ok($zip->set_number('9840062')->is_valid_number, '宮城県仙台市若林区弓ノ町');
ok($zip->set_number('9840063')->is_valid_number, '宮城県仙台市若林区石名坂');
ok($zip->set_number('9840064')->is_valid_number, '宮城県仙台市若林区石垣町');
ok($zip->set_number('9840065')->is_valid_number, '宮城県仙台市若林区土樋');
ok($zip->set_number('9840071')->is_valid_number, '宮城県仙台市若林区東九番丁');
ok($zip->set_number('9840072')->is_valid_number, '宮城県仙台市若林区東八番丁');
ok($zip->set_number('9840073')->is_valid_number, '宮城県仙台市若林区荒町');
ok($zip->set_number('9840074')->is_valid_number, '宮城県仙台市若林区東七番丁');
ok($zip->set_number('9840075')->is_valid_number, '宮城県仙台市若林区清水小路');
ok($zip->set_number('9840801')->is_valid_number, '宮城県仙台市若林区畳屋丁');
ok($zip->set_number('9840802')->is_valid_number, '宮城県仙台市若林区八軒小路');
ok($zip->set_number('9840803')->is_valid_number, '宮城県仙台市若林区新弓ノ町');
ok($zip->set_number('9840804')->is_valid_number, '宮城県仙台市若林区南石切町');
ok($zip->set_number('9840805')->is_valid_number, '宮城県仙台市若林区南材木町');
ok($zip->set_number('9840806')->is_valid_number, '宮城県仙台市若林区舟丁');
ok($zip->set_number('9840807')->is_valid_number, '宮城県仙台市若林区穀町');
ok($zip->set_number('9840811')->is_valid_number, '宮城県仙台市若林区保春院前丁');
ok($zip->set_number('9840812')->is_valid_number, '宮城県仙台市若林区五十人町');
ok($zip->set_number('9840813')->is_valid_number, '宮城県仙台市若林区六十人町');
ok($zip->set_number('9840814')->is_valid_number, '宮城県仙台市若林区南染師町');
ok($zip->set_number('9840815')->is_valid_number, '宮城県仙台市若林区文化町');
ok($zip->set_number('9840816')->is_valid_number, '宮城県仙台市若林区河原町');
ok($zip->set_number('9840817')->is_valid_number, '宮城県仙台市若林区堰場');
ok($zip->set_number('9840821')->is_valid_number, '宮城県仙台市若林区中倉');
ok($zip->set_number('9840822')->is_valid_number, '宮城県仙台市若林区かすみ町');
ok($zip->set_number('9840823')->is_valid_number, '宮城県仙台市若林区遠見塚');
ok($zip->set_number('9840824')->is_valid_number, '宮城県仙台市若林区遠見塚東');
ok($zip->set_number('9840825')->is_valid_number, '宮城県仙台市若林区古城');
ok($zip->set_number('9840826')->is_valid_number, '宮城県仙台市若林区若林');
ok($zip->set_number('9840827')->is_valid_number, '宮城県仙台市若林区南小泉');
ok($zip->set_number('9840828')->is_valid_number, '宮城県仙台市若林区一本杉町');
ok($zip->set_number('9840831')->is_valid_number, '宮城県仙台市若林区沖野');
ok($zip->set_number('9840832')->is_valid_number, '宮城県仙台市若林区下飯田');
ok($zip->set_number('9840833')->is_valid_number, '宮城県仙台市若林区飯田');
ok($zip->set_number('9840834')->is_valid_number, '宮城県仙台市若林区六郷');
ok($zip->set_number('9840835')->is_valid_number, '宮城県仙台市若林区今泉');
ok($zip->set_number('9840836')->is_valid_number, '宮城県仙台市若林区四郎丸');
ok($zip->set_number('9840837')->is_valid_number, '宮城県仙台市若林区日辺');
ok($zip->set_number('9840838')->is_valid_number, '宮城県仙台市若林区上飯田');
ok($zip->set_number('9840841')->is_valid_number, '宮城県仙台市若林区三本塚');
ok($zip->set_number('9840842')->is_valid_number, '宮城県仙台市若林区井土');
ok($zip->set_number('9840843')->is_valid_number, '宮城県仙台市若林区藤塚');
ok($zip->set_number('9840844')->is_valid_number, '宮城県仙台市若林区種次');
ok($zip->set_number('9840845')->is_valid_number, '宮城県仙台市若林区二木');
ok($zip->set_number('9850000')->is_valid_number, '宮城県塩竈市以下に掲載がない場合');
ok($zip->set_number('9850000')->is_valid_number, '宮城県多賀城市以下に掲載がない場合');
ok($zip->set_number('9850000')->is_valid_number, '宮城県宮城郡七ヶ浜町以下に掲載がない場合');
ok($zip->set_number('9850001')->is_valid_number, '宮城県塩竈市新浜町');
ok($zip->set_number('9850002')->is_valid_number, '宮城県塩竈市海岸通');
ok($zip->set_number('9850003')->is_valid_number, '宮城県塩竈市北浜');
ok($zip->set_number('9850004')->is_valid_number, '宮城県塩竈市藤倉');
ok($zip->set_number('9850005')->is_valid_number, '宮城県塩竈市杉の入');
ok($zip->set_number('9850006')->is_valid_number, '宮城県塩竈市杉の入裏');
ok($zip->set_number('9850011')->is_valid_number, '宮城県塩竈市貞山通');
ok($zip->set_number('9850012')->is_valid_number, '宮城県塩竈市芦畔町');
ok($zip->set_number('9850013')->is_valid_number, '宮城県塩竈市牛生町');
ok($zip->set_number('9850014')->is_valid_number, '宮城県塩竈市舟入');
ok($zip->set_number('9850015')->is_valid_number, '宮城県塩竈市中の島');
ok($zip->set_number('9850016')->is_valid_number, '宮城県塩竈市港町');
ok($zip->set_number('9850021')->is_valid_number, '宮城県塩竈市尾島町');
ok($zip->set_number('9850022')->is_valid_number, '宮城県塩竈市新富町');
ok($zip->set_number('9850023')->is_valid_number, '宮城県塩竈市花立町');
ok($zip->set_number('9850024')->is_valid_number, '宮城県塩竈市錦町');
ok($zip->set_number('9850025')->is_valid_number, '宮城県塩竈市佐浦町');
ok($zip->set_number('9850026')->is_valid_number, '宮城県塩竈市旭町');
ok($zip->set_number('9850031')->is_valid_number, '宮城県塩竈市石堂');
ok($zip->set_number('9850032')->is_valid_number, '宮城県塩竈市白萩町');
ok($zip->set_number('9850033')->is_valid_number, '宮城県塩竈市桜ケ丘');
ok($zip->set_number('9850034')->is_valid_number, '宮城県塩竈市南錦町');
ok($zip->set_number('9850035')->is_valid_number, '宮城県塩竈市野田');
ok($zip->set_number('9850036')->is_valid_number, '宮城県塩竈市東玉川町');
ok($zip->set_number('9850041')->is_valid_number, '宮城県塩竈市白菊町');
ok($zip->set_number('9850042')->is_valid_number, '宮城県塩竈市玉川');
ok($zip->set_number('9850043')->is_valid_number, '宮城県塩竈市袖野田町');
ok($zip->set_number('9850044')->is_valid_number, '宮城県塩竈市母子沢町');
ok($zip->set_number('9850045')->is_valid_number, '宮城県塩竈市西玉川町');
ok($zip->set_number('9850046')->is_valid_number, '宮城県塩竈市大日向町');
ok($zip->set_number('9850051')->is_valid_number, '宮城県塩竈市宮町');
ok($zip->set_number('9850052')->is_valid_number, '宮城県塩竈市本町');
ok($zip->set_number('9850053')->is_valid_number, '宮城県塩竈市南町');
ok($zip->set_number('9850054')->is_valid_number, '宮城県塩竈市香津町');
ok($zip->set_number('9850055')->is_valid_number, '宮城県塩竈市赤坂');
ok($zip->set_number('9850056')->is_valid_number, '宮城県塩竈市泉ケ岡');
ok($zip->set_number('9850057')->is_valid_number, '宮城県塩竈市西町');
ok($zip->set_number('9850061')->is_valid_number, '宮城県塩竈市清水沢');
ok($zip->set_number('9850062')->is_valid_number, '宮城県塩竈市泉沢町');
ok($zip->set_number('9850063')->is_valid_number, '宮城県塩竈市栄町');
ok($zip->set_number('9850064')->is_valid_number, '宮城県塩竈市権現堂');
ok($zip->set_number('9850065')->is_valid_number, '宮城県塩竈市向ケ丘');
ok($zip->set_number('9850066')->is_valid_number, '宮城県塩竈市月見ケ丘');
ok($zip->set_number('9850067')->is_valid_number, '宮城県塩竈市後楽町');
ok($zip->set_number('9850071')->is_valid_number, '宮城県塩竈市松陽台');
ok($zip->set_number('9850072')->is_valid_number, '宮城県塩竈市小松崎');
ok($zip->set_number('9850073')->is_valid_number, '宮城県塩竈市みのが丘');
ok($zip->set_number('9850074')->is_valid_number, '宮城県塩竈市一森山');
ok($zip->set_number('9850075')->is_valid_number, '宮城県塩竈市今宮町');
ok($zip->set_number('9850076')->is_valid_number, '宮城県塩竈市長沢町');
ok($zip->set_number('9850077')->is_valid_number, '宮城県塩竈市梅の宮');
ok($zip->set_number('9850081')->is_valid_number, '宮城県塩竈市石田');
ok($zip->set_number('9850082')->is_valid_number, '宮城県塩竈市青葉ケ丘');
ok($zip->set_number('9850083')->is_valid_number, '宮城県塩竈市越ノ浦');
ok($zip->set_number('9850084')->is_valid_number, '宮城県塩竈市楓町');
ok($zip->set_number('9850085')->is_valid_number, '宮城県塩竈市庚塚');
ok($zip->set_number('9850086')->is_valid_number, '宮城県塩竈市千賀の台');
ok($zip->set_number('9850087')->is_valid_number, '宮城県塩竈市伊保石');
ok($zip->set_number('9850088')->is_valid_number, '宮城県塩竈市長沢');
ok($zip->set_number('9850191')->is_valid_number, '宮城県塩竈市浦戸石浜');
ok($zip->set_number('9850192')->is_valid_number, '宮城県塩竈市浦戸桂島');
ok($zip->set_number('9850193')->is_valid_number, '宮城県塩竈市浦戸野々島');
ok($zip->set_number('9850194')->is_valid_number, '宮城県塩竈市浦戸寒風沢');
ok($zip->set_number('9850195')->is_valid_number, '宮城県塩竈市浦戸朴島');
ok($zip->set_number('9850801')->is_valid_number, '宮城県宮城郡七ヶ浜町代ヶ崎浜');
ok($zip->set_number('9850802')->is_valid_number, '宮城県宮城郡七ヶ浜町吉田浜');
ok($zip->set_number('9850803')->is_valid_number, '宮城県宮城郡七ヶ浜町花渕浜');
ok($zip->set_number('9850804')->is_valid_number, '宮城県宮城郡七ヶ浜町東宮浜');
ok($zip->set_number('9850805')->is_valid_number, '宮城県宮城郡七ヶ浜町笹山');
ok($zip->set_number('9850811')->is_valid_number, '宮城県宮城郡七ヶ浜町菖蒲田浜');
ok($zip->set_number('9850812')->is_valid_number, '宮城県宮城郡七ヶ浜町松ヶ浜');
ok($zip->set_number('9850813')->is_valid_number, '宮城県宮城郡七ヶ浜町湊浜');
ok($zip->set_number('9850821')->is_valid_number, '宮城県宮城郡七ヶ浜町汐見台');
ok($zip->set_number('9850822')->is_valid_number, '宮城県宮城郡七ヶ浜町汐見台南');
ok($zip->set_number('9850823')->is_valid_number, '宮城県宮城郡七ヶ浜町遠山');
ok($zip->set_number('9850824')->is_valid_number, '宮城県宮城郡七ヶ浜町境山');
ok($zip->set_number('9850831')->is_valid_number, '宮城県多賀城市笠神');
ok($zip->set_number('9850832')->is_valid_number, '宮城県多賀城市大代');
ok($zip->set_number('9850833')->is_valid_number, '宮城県多賀城市栄');
ok($zip->set_number('9850834')->is_valid_number, '宮城県多賀城市丸山');
ok($zip->set_number('9850835')->is_valid_number, '宮城県多賀城市下馬');
ok($zip->set_number('9850841')->is_valid_number, '宮城県多賀城市鶴ケ谷');
ok($zip->set_number('9850842')->is_valid_number, '宮城県多賀城市桜木');
ok($zip->set_number('9850843')->is_valid_number, '宮城県多賀城市明月');
ok($zip->set_number('9850844')->is_valid_number, '宮城県多賀城市宮内');
ok($zip->set_number('9850845')->is_valid_number, '宮城県多賀城市町前');
ok($zip->set_number('9850846')->is_valid_number, '宮城県多賀城市中野');
ok($zip->set_number('9850851')->is_valid_number, '宮城県多賀城市南宮');
ok($zip->set_number('9850852')->is_valid_number, '宮城県多賀城市山王');
ok($zip->set_number('9850853')->is_valid_number, '宮城県多賀城市高橋');
ok($zip->set_number('9850854')->is_valid_number, '宮城県多賀城市新田');
ok($zip->set_number('9850861')->is_valid_number, '宮城県多賀城市浮島');
ok($zip->set_number('9850862')->is_valid_number, '宮城県多賀城市高崎');
ok($zip->set_number('9850863')->is_valid_number, '宮城県多賀城市東田中');
ok($zip->set_number('9850864')->is_valid_number, '宮城県多賀城市市川');
ok($zip->set_number('9850865')->is_valid_number, '宮城県多賀城市城南');
ok($zip->set_number('9850871')->is_valid_number, '宮城県多賀城市留ケ谷');
ok($zip->set_number('9850872')->is_valid_number, '宮城県多賀城市伝上山');
ok($zip->set_number('9850873')->is_valid_number, '宮城県多賀城市中央');
ok($zip->set_number('9850874')->is_valid_number, '宮城県多賀城市八幡');
ok($zip->set_number('9850901')->is_valid_number, '宮城県仙台市宮城野区港(5丁目)');
ok($zip->set_number('9860000')->is_valid_number, '宮城県石巻市以下に掲載がない場合');
ok($zip->set_number('9860001')->is_valid_number, '宮城県石巻市水沼');
ok($zip->set_number('9860002')->is_valid_number, '宮城県石巻市真野');
ok($zip->set_number('9860003')->is_valid_number, '宮城県石巻市井内');
ok($zip->set_number('9860004')->is_valid_number, '宮城県石巻市新栄');
ok($zip->set_number('9860005')->is_valid_number, '宮城県石巻市大瓜');
ok($zip->set_number('9860006')->is_valid_number, '宮城県石巻市高木');
ok($zip->set_number('9860011')->is_valid_number, '宮城県石巻市湊');
ok($zip->set_number('9860013')->is_valid_number, '宮城県石巻市鹿妻本町');
ok($zip->set_number('9860015')->is_valid_number, '宮城県石巻市吉野町');
ok($zip->set_number('9860016')->is_valid_number, '宮城県石巻市八幡町');
ok($zip->set_number('9860017')->is_valid_number, '宮城県石巻市不動町');
ok($zip->set_number('9860020')->is_valid_number, '宮城県石巻市湊東');
ok($zip->set_number('9860021')->is_valid_number, '宮城県石巻市緑町');
ok($zip->set_number('9860022')->is_valid_number, '宮城県石巻市魚町');
ok($zip->set_number('9860023')->is_valid_number, '宮城県石巻市田代浜');
ok($zip->set_number('9860024')->is_valid_number, '宮城県石巻市川口町');
ok($zip->set_number('9860025')->is_valid_number, '宮城県石巻市湊町');
ok($zip->set_number('9860026')->is_valid_number, '宮城県石巻市大門町');
ok($zip->set_number('9860027')->is_valid_number, '宮城県石巻市明神町');
ok($zip->set_number('9860028')->is_valid_number, '宮城県石巻市松並');
ok($zip->set_number('9860029')->is_valid_number, '宮城県石巻市湊西');
ok($zip->set_number('9860031')->is_valid_number, '宮城県石巻市南境');
ok($zip->set_number('9860032')->is_valid_number, '宮城県石巻市開成');
ok($zip->set_number('9860033')->is_valid_number, '宮城県石巻市美園');
ok($zip->set_number('9860041')->is_valid_number, '宮城県石巻市伊原津');
ok($zip->set_number('9860042')->is_valid_number, '宮城県石巻市鹿妻南');
ok($zip->set_number('9860043')->is_valid_number, '宮城県石巻市鹿妻北');
ok($zip->set_number('9860101')->is_valid_number, '宮城県石巻市相野谷');
ok($zip->set_number('9860102')->is_valid_number, '宮城県石巻市成田');
ok($zip->set_number('9860103')->is_valid_number, '宮城県石巻市中島');
ok($zip->set_number('9860104')->is_valid_number, '宮城県石巻市皿貝');
ok($zip->set_number('9860105')->is_valid_number, '宮城県石巻市中野');
ok($zip->set_number('9860106')->is_valid_number, '宮城県石巻市馬鞍');
ok($zip->set_number('9860111')->is_valid_number, '宮城県石巻市釜谷');
ok($zip->set_number('9860112')->is_valid_number, '宮城県石巻市長面');
ok($zip->set_number('9860113')->is_valid_number, '宮城県石巻市尾ノ崎');
ok($zip->set_number('9860114')->is_valid_number, '宮城県石巻市針岡');
ok($zip->set_number('9860115')->is_valid_number, '宮城県石巻市福地');
ok($zip->set_number('9860121')->is_valid_number, '宮城県石巻市大森');
ok($zip->set_number('9860122')->is_valid_number, '宮城県石巻市東福田');
ok($zip->set_number('9860123')->is_valid_number, '宮城県石巻市北境');
ok($zip->set_number('9860124')->is_valid_number, '宮城県石巻市三輪田');
ok($zip->set_number('9860131')->is_valid_number, '宮城県石巻市飯野');
ok($zip->set_number('9860132')->is_valid_number, '宮城県石巻市小船越');
ok($zip->set_number('9860133')->is_valid_number, '宮城県石巻市二子');
ok($zip->set_number('9860201')->is_valid_number, '宮城県石巻市北上町十三浜');
ok($zip->set_number('9860202')->is_valid_number, '宮城県石巻市北上町橋浦');
ok($zip->set_number('9860203')->is_valid_number, '宮城県石巻市北上町長尾');
ok($zip->set_number('9860204')->is_valid_number, '宮城県石巻市北上町女川');
ok($zip->set_number('9860301')->is_valid_number, '宮城県石巻市桃生町脇谷');
ok($zip->set_number('9860302')->is_valid_number, '宮城県石巻市桃生町倉埣');
ok($zip->set_number('9860303')->is_valid_number, '宮城県石巻市桃生町永井');
ok($zip->set_number('9860304')->is_valid_number, '宮城県石巻市桃生町樫崎');
ok($zip->set_number('9860305')->is_valid_number, '宮城県石巻市桃生町牛田');
ok($zip->set_number('9860311')->is_valid_number, '宮城県石巻市桃生町太田');
ok($zip->set_number('9860312')->is_valid_number, '宮城県石巻市桃生町城内');
ok($zip->set_number('9860313')->is_valid_number, '宮城県石巻市桃生町中津山');
ok($zip->set_number('9860314')->is_valid_number, '宮城県石巻市桃生町寺崎');
ok($zip->set_number('9860321')->is_valid_number, '宮城県石巻市桃生町新田');
ok($zip->set_number('9860322')->is_valid_number, '宮城県石巻市桃生町給人町');
ok($zip->set_number('9860323')->is_valid_number, '宮城県石巻市桃生町神取');
ok($zip->set_number('9860324')->is_valid_number, '宮城県石巻市桃生町高須賀');
ok($zip->set_number('9860401')->is_valid_number, '宮城県登米市津山町柳津');
ok($zip->set_number('9860402')->is_valid_number, '宮城県登米市津山町横山');
ok($zip->set_number('9860700')->is_valid_number, '宮城県本吉郡南三陸町以下に掲載がない場合');
ok($zip->set_number('9860701')->is_valid_number, '宮城県本吉郡南三陸町志津川西田');
ok($zip->set_number('9860702')->is_valid_number, '宮城県本吉郡南三陸町志津川細浦');
ok($zip->set_number('9860703')->is_valid_number, '宮城県本吉郡南三陸町志津川蛇王');
ok($zip->set_number('9860704')->is_valid_number, '宮城県本吉郡南三陸町志津川森山');
ok($zip->set_number('9860705')->is_valid_number, '宮城県本吉郡南三陸町志津川阿曽');
ok($zip->set_number('9860706')->is_valid_number, '宮城県本吉郡南三陸町志津川清水浜');
ok($zip->set_number('9860707')->is_valid_number, '宮城県本吉郡南三陸町志津川荒坂');
ok($zip->set_number('9860708')->is_valid_number, '宮城県本吉郡南三陸町志津川松井田');
ok($zip->set_number('9860709')->is_valid_number, '宮城県本吉郡南三陸町志津川内井田');
ok($zip->set_number('9860711')->is_valid_number, '宮城県本吉郡南三陸町志津川権現');
ok($zip->set_number('9860712')->is_valid_number, '宮城県本吉郡南三陸町志津川北の又');
ok($zip->set_number('9860713')->is_valid_number, '宮城県本吉郡南三陸町志津川平貝');
ok($zip->set_number('9860714')->is_valid_number, '宮城県本吉郡南三陸町志津川蒲の沢');
ok($zip->set_number('9860715')->is_valid_number, '宮城県本吉郡南三陸町志津川深田');
ok($zip->set_number('9860716')->is_valid_number, '宮城県本吉郡南三陸町志津川平磯');
ok($zip->set_number('9860717')->is_valid_number, '宮城県本吉郡南三陸町志津川袖浜');
ok($zip->set_number('9860718')->is_valid_number, '宮城県本吉郡南三陸町志津川大畑');
ok($zip->set_number('9860721')->is_valid_number, '宮城県本吉郡南三陸町志津川米広');
ok($zip->set_number('9860722')->is_valid_number, '宮城県本吉郡南三陸町志津川大上坊');
ok($zip->set_number('9860723')->is_valid_number, '宮城県本吉郡南三陸町志津川立沢');
ok($zip->set_number('9860724')->is_valid_number, '宮城県本吉郡南三陸町志津川平井田');
ok($zip->set_number('9860725')->is_valid_number, '宮城県本吉郡南三陸町志津川沼田');
ok($zip->set_number('9860726')->is_valid_number, '宮城県本吉郡南三陸町志津川磯の沢');
ok($zip->set_number('9860727')->is_valid_number, '宮城県本吉郡南三陸町志津川新井田');
ok($zip->set_number('9860728')->is_valid_number, '宮城県本吉郡南三陸町志津川天王山');
ok($zip->set_number('9860729')->is_valid_number, '宮城県本吉郡南三陸町志津川天王前');
ok($zip->set_number('9860731')->is_valid_number, '宮城県本吉郡南三陸町志津川大森');
ok($zip->set_number('9860732')->is_valid_number, '宮城県本吉郡南三陸町志津川大森町');
ok($zip->set_number('9860733')->is_valid_number, '宮城県本吉郡南三陸町志津川旭ケ浦');
ok($zip->set_number('9860741')->is_valid_number, '宮城県本吉郡南三陸町志津川十日町');
ok($zip->set_number('9860742')->is_valid_number, '宮城県本吉郡南三陸町志津川本浜町');
ok($zip->set_number('9860743')->is_valid_number, '宮城県本吉郡南三陸町志津川南町');
ok($zip->set_number('9860751')->is_valid_number, '宮城県本吉郡南三陸町志津川上の山');
ok($zip->set_number('9860752')->is_valid_number, '宮城県本吉郡南三陸町志津川五日町');
ok($zip->set_number('9860753')->is_valid_number, '宮城県本吉郡南三陸町志津川城場');
ok($zip->set_number('9860754')->is_valid_number, '宮城県本吉郡南三陸町志津川助作');
ok($zip->set_number('9860761')->is_valid_number, '宮城県本吉郡南三陸町志津川廻館前');
ok($zip->set_number('9860762')->is_valid_number, '宮城県本吉郡南三陸町志津川塩入');
ok($zip->set_number('9860763')->is_valid_number, '宮城県本吉郡南三陸町志津川汐見町');
ok($zip->set_number('9860764')->is_valid_number, '宮城県本吉郡南三陸町志津川大久保');
ok($zip->set_number('9860765')->is_valid_number, '宮城県本吉郡南三陸町志津川林');
ok($zip->set_number('9860766')->is_valid_number, '宮城県本吉郡南三陸町志津川黒崎');
ok($zip->set_number('9860767')->is_valid_number, '宮城県本吉郡南三陸町志津川中瀬町');
ok($zip->set_number('9860768')->is_valid_number, '宮城県本吉郡南三陸町志津川御前下');
ok($zip->set_number('9860771')->is_valid_number, '宮城県本吉郡南三陸町志津川大沢');
ok($zip->set_number('9860772')->is_valid_number, '宮城県本吉郡南三陸町志津川秋目川');
ok($zip->set_number('9860773')->is_valid_number, '宮城県本吉郡南三陸町志津川熊田');
ok($zip->set_number('9860774')->is_valid_number, '宮城県本吉郡南三陸町志津川小森');
ok($zip->set_number('9860775')->is_valid_number, '宮城県本吉郡南三陸町志津川廻館');
ok($zip->set_number('9860776')->is_valid_number, '宮城県本吉郡南三陸町志津川竹川原');
ok($zip->set_number('9860777')->is_valid_number, '宮城県本吉郡南三陸町志津川上保呂毛');
ok($zip->set_number('9860778')->is_valid_number, '宮城県本吉郡南三陸町志津川下保呂毛');
ok($zip->set_number('9860779')->is_valid_number, '宮城県本吉郡南三陸町志津川田尻畑');
ok($zip->set_number('9860781')->is_valid_number, '宮城県本吉郡南三陸町戸倉');
ok($zip->set_number('9860782')->is_valid_number, '宮城県本吉郡南三陸町入谷');
ok($zip->set_number('9860801')->is_valid_number, '宮城県石巻市水明北');
ok($zip->set_number('9860802')->is_valid_number, '宮城県石巻市水明南');
ok($zip->set_number('9860803')->is_valid_number, '宮城県石巻市水押');
ok($zip->set_number('9860805')->is_valid_number, '宮城県石巻市大橋');
ok($zip->set_number('9860806')->is_valid_number, '宮城県石巻市開北');
ok($zip->set_number('9860811')->is_valid_number, '宮城県石巻市元倉');
ok($zip->set_number('9860812')->is_valid_number, '宮城県石巻市東中里');
ok($zip->set_number('9860813')->is_valid_number, '宮城県石巻市駅前北通り');
ok($zip->set_number('9860814')->is_valid_number, '宮城県石巻市南中里');
ok($zip->set_number('9860815')->is_valid_number, '宮城県石巻市中里');
ok($zip->set_number('9860821')->is_valid_number, '宮城県石巻市住吉町');
ok($zip->set_number('9860822')->is_valid_number, '宮城県石巻市中央');
ok($zip->set_number('9860823')->is_valid_number, '宮城県石巻市中瀬');
ok($zip->set_number('9860824')->is_valid_number, '宮城県石巻市立町');
ok($zip->set_number('9860825')->is_valid_number, '宮城県石巻市穀町');
ok($zip->set_number('9860826')->is_valid_number, '宮城県石巻市鋳銭場');
ok($zip->set_number('9860827')->is_valid_number, '宮城県石巻市千石町');
ok($zip->set_number('9860828')->is_valid_number, '宮城県石巻市旭町');
ok($zip->set_number('9860831')->is_valid_number, '宮城県石巻市羽黒町');
ok($zip->set_number('9860832')->is_valid_number, '宮城県石巻市泉町');
ok($zip->set_number('9860833')->is_valid_number, '宮城県石巻市日和が丘');
ok($zip->set_number('9860834')->is_valid_number, '宮城県石巻市門脇町');
ok($zip->set_number('9860835')->is_valid_number, '宮城県石巻市南浜町');
ok($zip->set_number('9860836')->is_valid_number, '宮城県石巻市南光町');
ok($zip->set_number('9860837')->is_valid_number, '宮城県石巻市宜山町');
ok($zip->set_number('9860838')->is_valid_number, '宮城県石巻市大手町');
ok($zip->set_number('9860841')->is_valid_number, '宮城県石巻市雲雀野町');
ok($zip->set_number('9860842')->is_valid_number, '宮城県石巻市潮見町');
ok($zip->set_number('9860843')->is_valid_number, '宮城県石巻市西浜町');
ok($zip->set_number('9860844')->is_valid_number, '宮城県石巻市重吉町');
ok($zip->set_number('9860845')->is_valid_number, '宮城県石巻市中島町');
ok($zip->set_number('9860846')->is_valid_number, '宮城県石巻市三河町');
ok($zip->set_number('9860847')->is_valid_number, '宮城県石巻市中浦');
ok($zip->set_number('9860848')->is_valid_number, '宮城県石巻市新館');
ok($zip->set_number('9860849')->is_valid_number, '宮城県石巻市中屋敷');
ok($zip->set_number('9860850')->is_valid_number, '宮城県石巻市あゆみ野');
ok($zip->set_number('9860851')->is_valid_number, '宮城県石巻市貞山');
ok($zip->set_number('9860852')->is_valid_number, '宮城県石巻市南谷地');
ok($zip->set_number('9860853')->is_valid_number, '宮城県石巻市門脇');
ok($zip->set_number('9860854')->is_valid_number, '宮城県石巻市大街道北');
ok($zip->set_number('9860855')->is_valid_number, '宮城県石巻市大街道東');
ok($zip->set_number('9860856')->is_valid_number, '宮城県石巻市大街道南');
ok($zip->set_number('9860857')->is_valid_number, '宮城県石巻市築山');
ok($zip->set_number('9860858')->is_valid_number, '宮城県石巻市三ツ股');
ok($zip->set_number('9860859')->is_valid_number, '宮城県石巻市大街道西');
ok($zip->set_number('9860860')->is_valid_number, '宮城県石巻市のぞみ野');
ok($zip->set_number('9860861')->is_valid_number, '宮城県石巻市蛇田');
ok($zip->set_number('9860862')->is_valid_number, '宮城県石巻市あけぼの');
ok($zip->set_number('9860863')->is_valid_number, '宮城県石巻市向陽町');
ok($zip->set_number('9860864')->is_valid_number, '宮城県石巻市新境町');
ok($zip->set_number('9860865')->is_valid_number, '宮城県石巻市丸井戸');
ok($zip->set_number('9860866')->is_valid_number, '宮城県石巻市茜平');
ok($zip->set_number('9860867')->is_valid_number, '宮城県石巻市わかば');
ok($zip->set_number('9860868')->is_valid_number, '宮城県石巻市恵み野');
ok($zip->set_number('9860869')->is_valid_number, '宮城県石巻市あけぼの北');
ok($zip->set_number('9860871')->is_valid_number, '宮城県石巻市清水町');
ok($zip->set_number('9860872')->is_valid_number, '宮城県石巻市田道町');
ok($zip->set_number('9860873')->is_valid_number, '宮城県石巻市山下町');
ok($zip->set_number('9860874')->is_valid_number, '宮城県石巻市双葉町');
ok($zip->set_number('9860875')->is_valid_number, '宮城県石巻市末広町');
ok($zip->set_number('9860876')->is_valid_number, '宮城県石巻市西山町');
ok($zip->set_number('9860877')->is_valid_number, '宮城県石巻市錦町');
ok($zip->set_number('9860878')->is_valid_number, '宮城県石巻市新橋');
ok($zip->set_number('9860881')->is_valid_number, '宮城県石巻市明神南');
ok($zip->set_number('9860882')->is_valid_number, '宮城県石巻市浦屋敷南');
ok($zip->set_number('9860883')->is_valid_number, '宮城県石巻市新館南');
ok($zip->set_number('9861111')->is_valid_number, '宮城県石巻市鹿又');
ok($zip->set_number('9861301')->is_valid_number, '宮城県石巻市雄勝町船越');
ok($zip->set_number('9861302')->is_valid_number, '宮城県石巻市雄勝町大浜');
ok($zip->set_number('9861303')->is_valid_number, '宮城県石巻市雄勝町立浜');
ok($zip->set_number('9861304')->is_valid_number, '宮城県石巻市雄勝町名振');
ok($zip->set_number('9861311')->is_valid_number, '宮城県石巻市雄勝町大須');
ok($zip->set_number('9861312')->is_valid_number, '宮城県石巻市雄勝町熊沢');
ok($zip->set_number('9861313')->is_valid_number, '宮城県石巻市雄勝町桑浜');
ok($zip->set_number('9861321')->is_valid_number, '宮城県石巻市雄勝町水浜');
ok($zip->set_number('9861322')->is_valid_number, '宮城県石巻市雄勝町分浜');
ok($zip->set_number('9861331')->is_valid_number, '宮城県石巻市雄勝町明神');
ok($zip->set_number('9861332')->is_valid_number, '宮城県石巻市雄勝町小島');
ok($zip->set_number('9861333')->is_valid_number, '宮城県石巻市雄勝町雄勝');
ok($zip->set_number('9861334')->is_valid_number, '宮城県石巻市雄勝町伊勢畑');
ok($zip->set_number('9861335')->is_valid_number, '宮城県石巻市雄勝町下雄勝');
ok($zip->set_number('9861336')->is_valid_number, '宮城県石巻市雄勝町上雄勝');
ok($zip->set_number('9862101')->is_valid_number, '宮城県石巻市沼津');
ok($zip->set_number('9862102')->is_valid_number, '宮城県石巻市沢田');
ok($zip->set_number('9862103')->is_valid_number, '宮城県石巻市流留');
ok($zip->set_number('9862104')->is_valid_number, '宮城県石巻市垂水町');
ok($zip->set_number('9862105')->is_valid_number, '宮城県石巻市新成');
ok($zip->set_number('9862111')->is_valid_number, '宮城県石巻市三和町');
ok($zip->set_number('9862112')->is_valid_number, '宮城県石巻市後生橋');
ok($zip->set_number('9862113')->is_valid_number, '宮城県石巻市宇田川町');
ok($zip->set_number('9862114')->is_valid_number, '宮城県石巻市塩富町');
ok($zip->set_number('9862115')->is_valid_number, '宮城県石巻市万石町');
ok($zip->set_number('9862116')->is_valid_number, '宮城県石巻市小竹浜');
ok($zip->set_number('9862121')->is_valid_number, '宮城県石巻市渡波町');
ok($zip->set_number('9862122')->is_valid_number, '宮城県石巻市幸町');
ok($zip->set_number('9862123')->is_valid_number, '宮城県石巻市伊勢町');
ok($zip->set_number('9862131')->is_valid_number, '宮城県石巻市浜松町');
ok($zip->set_number('9862132')->is_valid_number, '宮城県石巻市大宮町');
ok($zip->set_number('9862133')->is_valid_number, '宮城県石巻市長浜町');
ok($zip->set_number('9862134')->is_valid_number, '宮城県石巻市松原町');
ok($zip->set_number('9862135')->is_valid_number, '宮城県石巻市渡波');
ok($zip->set_number('9862136')->is_valid_number, '宮城県石巻市根岸');
ok($zip->set_number('9862137')->is_valid_number, '宮城県石巻市さくら町');
ok($zip->set_number('9862200')->is_valid_number, '宮城県牡鹿郡女川町以下に掲載がない場合');
ok($zip->set_number('9862201')->is_valid_number, '宮城県牡鹿郡女川町指ケ浜');
ok($zip->set_number('9862202')->is_valid_number, '宮城県牡鹿郡女川町尾浦');
ok($zip->set_number('9862203')->is_valid_number, '宮城県牡鹿郡女川町竹浦');
ok($zip->set_number('9862204')->is_valid_number, '宮城県牡鹿郡女川町桐ケ崎');
ok($zip->set_number('9862205')->is_valid_number, '宮城県牡鹿郡女川町御前浜');
ok($zip->set_number('9862211')->is_valid_number, '宮城県牡鹿郡女川町出島');
ok($zip->set_number('9862212')->is_valid_number, '宮城県牡鹿郡女川町江島');
ok($zip->set_number('9862221')->is_valid_number, '宮城県牡鹿郡女川町塚浜');
ok($zip->set_number('9862222')->is_valid_number, '宮城県牡鹿郡女川町飯子浜');
ok($zip->set_number('9862223')->is_valid_number, '宮城県牡鹿郡女川町野々浜');
ok($zip->set_number('9862224')->is_valid_number, '宮城県牡鹿郡女川町大石原浜');
ok($zip->set_number('9862225')->is_valid_number, '宮城県牡鹿郡女川町横浦');
ok($zip->set_number('9862226')->is_valid_number, '宮城県牡鹿郡女川町高白浜');
ok($zip->set_number('9862231')->is_valid_number, '宮城県牡鹿郡女川町浦宿浜');
ok($zip->set_number('9862232')->is_valid_number, '宮城県牡鹿郡女川町針浜');
ok($zip->set_number('9862240')->is_valid_number, '宮城県牡鹿郡女川町大道');
ok($zip->set_number('9862242')->is_valid_number, '宮城県牡鹿郡女川町小乗浜');
ok($zip->set_number('9862243')->is_valid_number, '宮城県牡鹿郡女川町鷲神浜');
ok($zip->set_number('9862244')->is_valid_number, '宮城県牡鹿郡女川町桜ケ丘');
ok($zip->set_number('9862246')->is_valid_number, '宮城県牡鹿郡女川町黄金');
ok($zip->set_number('9862247')->is_valid_number, '宮城県牡鹿郡女川町鷲神');
ok($zip->set_number('9862248')->is_valid_number, '宮城県牡鹿郡女川町小乗');
ok($zip->set_number('9862249')->is_valid_number, '宮城県牡鹿郡女川町内山');
ok($zip->set_number('9862251')->is_valid_number, '宮城県牡鹿郡女川町旭が丘');
ok($zip->set_number('9862261')->is_valid_number, '宮城県牡鹿郡女川町女川浜');
ok($zip->set_number('9862262')->is_valid_number, '宮城県牡鹿郡女川町清水');
ok($zip->set_number('9862263')->is_valid_number, '宮城県牡鹿郡女川町伊勢');
ok($zip->set_number('9862264')->is_valid_number, '宮城県牡鹿郡女川町海岸通り');
ok($zip->set_number('9862265')->is_valid_number, '宮城県牡鹿郡女川町女川');
ok($zip->set_number('9862266')->is_valid_number, '宮城県牡鹿郡女川町大原');
ok($zip->set_number('9862281')->is_valid_number, '宮城県牡鹿郡女川町石浜');
ok($zip->set_number('9862282')->is_valid_number, '宮城県牡鹿郡女川町宮ケ崎');
ok($zip->set_number('9862283')->is_valid_number, '宮城県牡鹿郡女川町市場通り');
ok($zip->set_number('9862341')->is_valid_number, '宮城県石巻市荻浜');
ok($zip->set_number('9862342')->is_valid_number, '宮城県石巻市小積浜');
ok($zip->set_number('9862343')->is_valid_number, '宮城県石巻市福貴浦');
ok($zip->set_number('9862344')->is_valid_number, '宮城県石巻市鹿立');
ok($zip->set_number('9862345')->is_valid_number, '宮城県石巻市狐崎浜');
ok($zip->set_number('9862346')->is_valid_number, '宮城県石巻市竹浜');
ok($zip->set_number('9862347')->is_valid_number, '宮城県石巻市牧浜');
ok($zip->set_number('9862351')->is_valid_number, '宮城県石巻市侍浜');
ok($zip->set_number('9862352')->is_valid_number, '宮城県石巻市月浦');
ok($zip->set_number('9862353')->is_valid_number, '宮城県石巻市桃浦');
ok($zip->set_number('9862354')->is_valid_number, '宮城県石巻市蛤浜');
ok($zip->set_number('9862355')->is_valid_number, '宮城県石巻市折浜');
ok($zip->set_number('9862401')->is_valid_number, '宮城県石巻市泊浜');
ok($zip->set_number('9862402')->is_valid_number, '宮城県石巻市谷川浜');
ok($zip->set_number('9862403')->is_valid_number, '宮城県石巻市鮫浦');
ok($zip->set_number('9862404')->is_valid_number, '宮城県石巻市寄磯浜');
ok($zip->set_number('9862405')->is_valid_number, '宮城県石巻市大谷川浜');
ok($zip->set_number('9862406')->is_valid_number, '宮城県石巻市前網浜');
ok($zip->set_number('9862411')->is_valid_number, '宮城県石巻市給分浜');
ok($zip->set_number('9862412')->is_valid_number, '宮城県石巻市大原浜');
ok($zip->set_number('9862413')->is_valid_number, '宮城県石巻市清水田浜');
ok($zip->set_number('9862414')->is_valid_number, '宮城県石巻市小網倉浜');
ok($zip->set_number('9862415')->is_valid_number, '宮城県石巻市小渕浜');
ok($zip->set_number('9862521')->is_valid_number, '宮城県石巻市新山浜');
ok($zip->set_number('9862522')->is_valid_number, '宮城県石巻市鮎川大町');
ok($zip->set_number('9862523')->is_valid_number, '宮城県石巻市鮎川浜');
ok($zip->set_number('9862524')->is_valid_number, '宮城県石巻市鮎川浜丁');
ok($zip->set_number('9862525')->is_valid_number, '宮城県石巻市長渡浜');
ok($zip->set_number('9862526')->is_valid_number, '宮城県石巻市網地浜');
ok($zip->set_number('9862527')->is_valid_number, '宮城県石巻市十八成浜');
ok($zip->set_number('9870000')->is_valid_number, '宮城県遠田郡美里町以下に掲載がない場合');
ok($zip->set_number('9870001')->is_valid_number, '宮城県遠田郡美里町藤ケ崎');
ok($zip->set_number('9870002')->is_valid_number, '宮城県遠田郡美里町藤ケ崎町');
ok($zip->set_number('9870003')->is_valid_number, '宮城県遠田郡美里町南小牛田');
ok($zip->set_number('9870004')->is_valid_number, '宮城県遠田郡美里町牛飼');
ok($zip->set_number('9870005')->is_valid_number, '宮城県遠田郡美里町北浦');
ok($zip->set_number('9870006')->is_valid_number, '宮城県遠田郡美里町関根');
ok($zip->set_number('9870011')->is_valid_number, '宮城県遠田郡美里町桜木町');
ok($zip->set_number('9870012')->is_valid_number, '宮城県遠田郡美里町素山町');
ok($zip->set_number('9870013')->is_valid_number, '宮城県遠田郡美里町素山');
ok($zip->set_number('9870014')->is_valid_number, '宮城県遠田郡美里町志賀町');
ok($zip->set_number('9870015')->is_valid_number, '宮城県遠田郡美里町青生');
ok($zip->set_number('9870021')->is_valid_number, '宮城県遠田郡美里町平針');
ok($zip->set_number('9870022')->is_valid_number, '宮城県遠田郡美里町荻埣');
ok($zip->set_number('9870024')->is_valid_number, '宮城県遠田郡美里町中埣');
ok($zip->set_number('9870024')->is_valid_number, '宮城県遠田郡美里町成田');
ok($zip->set_number('9870025')->is_valid_number, '宮城県遠田郡美里町中高城');
ok($zip->set_number('9870026')->is_valid_number, '宮城県遠田郡美里町南高城');
ok($zip->set_number('9870031')->is_valid_number, '宮城県遠田郡美里町高田');
ok($zip->set_number('9870032')->is_valid_number, '宮城県遠田郡美里町学田');
ok($zip->set_number('9870033')->is_valid_number, '宮城県遠田郡美里町小町井');
ok($zip->set_number('9870034')->is_valid_number, '宮城県遠田郡美里町化粧坂');
ok($zip->set_number('9870035')->is_valid_number, '宮城県遠田郡美里町志賀殿');
ok($zip->set_number('9870036')->is_valid_number, '宮城県遠田郡美里町妻の神');
ok($zip->set_number('9870037')->is_valid_number, '宮城県遠田郡美里町新藤ケ崎');
ok($zip->set_number('9870038')->is_valid_number, '宮城県遠田郡美里町駅東');
ok($zip->set_number('9870041')->is_valid_number, '宮城県遠田郡美里町峯山');
ok($zip->set_number('9870042')->is_valid_number, '宮城県遠田郡美里町峯山浦');
ok($zip->set_number('9870043')->is_valid_number, '宮城県遠田郡美里町新妻の神');
ok($zip->set_number('9870044')->is_valid_number, '宮城県遠田郡美里町西舘');
ok($zip->set_number('9870045')->is_valid_number, '宮城県遠田郡美里町内役田');
ok($zip->set_number('9870046')->is_valid_number, '宮城県遠田郡美里町役田');
ok($zip->set_number('9870051')->is_valid_number, '宮城県遠田郡美里町上意江');
ok($zip->set_number('9870052')->is_valid_number, '宮城県遠田郡美里町砂子田');
ok($zip->set_number('9870053')->is_valid_number, '宮城県遠田郡美里町叔廼前');
ok($zip->set_number('9870054')->is_valid_number, '宮城県遠田郡美里町塔の越');
ok($zip->set_number('9870055')->is_valid_number, '宮城県遠田郡美里町新一本柳');
ok($zip->set_number('9870056')->is_valid_number, '宮城県遠田郡美里町一本柳');
ok($zip->set_number('9870057')->is_valid_number, '宮城県遠田郡美里町狐山');
ok($zip->set_number('9870058')->is_valid_number, '宮城県遠田郡美里町塩釜');
ok($zip->set_number('9870059')->is_valid_number, '宮城県遠田郡美里町塩釜添');
ok($zip->set_number('9870061')->is_valid_number, '宮城県遠田郡美里町下境');
ok($zip->set_number('9870062')->is_valid_number, '宮城県遠田郡美里町待井');
ok($zip->set_number('9870063')->is_valid_number, '宮城県遠田郡美里町小沼');
ok($zip->set_number('9870064')->is_valid_number, '宮城県遠田郡美里町小沼添');
ok($zip->set_number('9870065')->is_valid_number, '宮城県遠田郡美里町勘堂');
ok($zip->set_number('9870066')->is_valid_number, '宮城県遠田郡美里町二ツ檀');
ok($zip->set_number('9870067')->is_valid_number, '宮城県遠田郡美里町大所');
ok($zip->set_number('9870068')->is_valid_number, '宮城県遠田郡美里町新大所');
ok($zip->set_number('9870069')->is_valid_number, '宮城県遠田郡美里町北原');
ok($zip->set_number('9870100')->is_valid_number, '宮城県遠田郡涌谷町以下に掲載がない場合');
ok($zip->set_number('9870101')->is_valid_number, '宮城県遠田郡涌谷町桜町裏');
ok($zip->set_number('9870102')->is_valid_number, '宮城県遠田郡涌谷町表桜町');
ok($zip->set_number('9870103')->is_valid_number, '宮城県遠田郡涌谷町裏桜町');
ok($zip->set_number('9870104')->is_valid_number, '宮城県遠田郡涌谷町田沼町');
ok($zip->set_number('9870105')->is_valid_number, '宮城県遠田郡涌谷町練丑町');
ok($zip->set_number('9870106')->is_valid_number, '宮城県遠田郡涌谷町六軒町');
ok($zip->set_number('9870107')->is_valid_number, '宮城県遠田郡涌谷町六軒町裏');
ok($zip->set_number('9870111')->is_valid_number, '宮城県遠田郡涌谷町柳町');
ok($zip->set_number('9870112')->is_valid_number, '宮城県遠田郡涌谷町桑木荒');
ok($zip->set_number('9870113')->is_valid_number, '宮城県遠田郡涌谷町渋江');
ok($zip->set_number('9870113')->is_valid_number, '宮城県遠田郡涌谷町古道下二本杉');
ok($zip->set_number('9870114')->is_valid_number, '宮城県遠田郡涌谷町新町裏');
ok($zip->set_number('9870115')->is_valid_number, '宮城県遠田郡涌谷町新町');
ok($zip->set_number('9870121')->is_valid_number, '宮城県遠田郡涌谷町涌谷');
ok($zip->set_number('9870130')->is_valid_number, '宮城県遠田郡涌谷町新九軒前');
ok($zip->set_number('9870131')->is_valid_number, '宮城県遠田郡涌谷町北田');
ok($zip->set_number('9870132')->is_valid_number, '宮城県遠田郡涌谷町蔵人沖名');
ok($zip->set_number('9870132')->is_valid_number, '宮城県遠田郡涌谷町小谷地');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町赤間屋敷');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町掃部沖名');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町後藤江');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町今左衛門沖名');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町新田');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町関谷沖名');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町台所橋道下');
ok($zip->set_number('9870133')->is_valid_number, '宮城県遠田郡涌谷町鷹野橋下中瀬');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町北五反田');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町九軒');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町五反田');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町佐山木');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町地不足道');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町西谷地');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町二歩');
ok($zip->set_number('9870134')->is_valid_number, '宮城県遠田郡涌谷町蘭場谷地');
ok($zip->set_number('9870135')->is_valid_number, '宮城県遠田郡涌谷町小蓋谷地');
ok($zip->set_number('9870135')->is_valid_number, '宮城県遠田郡涌谷町三十軒');
ok($zip->set_number('9870136')->is_valid_number, '宮城県遠田郡涌谷町一本柳');
ok($zip->set_number('9870137')->is_valid_number, '宮城県遠田郡涌谷町新中島乙');
ok($zip->set_number('9870137')->is_valid_number, '宮城県遠田郡涌谷町中島');
ok($zip->set_number('9870137')->is_valid_number, '宮城県遠田郡涌谷町中島乙');
ok($zip->set_number('9870137')->is_valid_number, '宮城県遠田郡涌谷町中島川前');
ok($zip->set_number('9870137')->is_valid_number, '宮城県遠田郡涌谷町中島甲');
ok($zip->set_number('9870138')->is_valid_number, '宮城県遠田郡涌谷町新境堀下');
ok($zip->set_number('9870139')->is_valid_number, '宮城県遠田郡涌谷町新台所橋');
ok($zip->set_number('9870140')->is_valid_number, '宮城県遠田郡涌谷町新沖新田');
ok($zip->set_number('9870141')->is_valid_number, '宮城県遠田郡涌谷町田町裏');
ok($zip->set_number('9870142')->is_valid_number, '宮城県遠田郡涌谷町浦町');
ok($zip->set_number('9870143')->is_valid_number, '宮城県遠田郡涌谷町長柄町');
ok($zip->set_number('9870144')->is_valid_number, '宮城県遠田郡涌谷町沖新田');
ok($zip->set_number('9870144')->is_valid_number, '宮城県遠田郡涌谷町小山下');
ok($zip->set_number('9870144')->is_valid_number, '宮城県遠田郡涌谷町下新田');
ok($zip->set_number('9870144')->is_valid_number, '宮城県遠田郡涌谷町砂田');
ok($zip->set_number('9870144')->is_valid_number, '宮城県遠田郡涌谷町八百刈');
ok($zip->set_number('9870144')->is_valid_number, '宮城県遠田郡涌谷町薔薇島');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町市道');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町烏鴉');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町尾切');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町鞍掛');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町花勝山');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町新尾切');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町新名鰭');
ok($zip->set_number('9870145')->is_valid_number, '宮城県遠田郡涌谷町名鰭');
ok($zip->set_number('9870146')->is_valid_number, '宮城県遠田郡涌谷町中下道');
ok($zip->set_number('9870147')->is_valid_number, '宮城県遠田郡涌谷町下道');
ok($zip->set_number('9870148')->is_valid_number, '宮城県遠田郡涌谷町三軒屋敷');
ok($zip->set_number('9870149')->is_valid_number, '宮城県遠田郡涌谷町新後藤江');
ok($zip->set_number('9870151')->is_valid_number, '宮城県遠田郡涌谷町小塚');
ok($zip->set_number('9870161')->is_valid_number, '宮城県遠田郡涌谷町川原町');
ok($zip->set_number('9870162')->is_valid_number, '宮城県遠田郡涌谷町本町');
ok($zip->set_number('9870163')->is_valid_number, '宮城県遠田郡涌谷町立町');
ok($zip->set_number('9870164')->is_valid_number, '宮城県遠田郡涌谷町刈萱町');
ok($zip->set_number('9870165')->is_valid_number, '宮城県遠田郡涌谷町追廻町');
ok($zip->set_number('9870171')->is_valid_number, '宮城県遠田郡涌谷町上郡');
ok($zip->set_number('9870172')->is_valid_number, '宮城県遠田郡涌谷町下郡');
ok($zip->set_number('9870281')->is_valid_number, '宮城県遠田郡涌谷町小里');
ok($zip->set_number('9870282')->is_valid_number, '宮城県遠田郡涌谷町太田');
ok($zip->set_number('9870283')->is_valid_number, '宮城県遠田郡涌谷町吉住');
ok($zip->set_number('9870284')->is_valid_number, '宮城県遠田郡涌谷町猪岡短台');
ok($zip->set_number('9870285')->is_valid_number, '宮城県遠田郡涌谷町箟岳');
ok($zip->set_number('9870286')->is_valid_number, '宮城県遠田郡涌谷町成沢');
ok($zip->set_number('9870301')->is_valid_number, '宮城県登米市米山町善王寺');
ok($zip->set_number('9870302')->is_valid_number, '宮城県登米市米山町沼田');
ok($zip->set_number('9870302')->is_valid_number, '宮城県登米市米山町櫓場');
ok($zip->set_number('9870302')->is_valid_number, '宮城県登米市米山町櫓場下');
ok($zip->set_number('9870303')->is_valid_number, '宮城県登米市米山町田畑西');
ok($zip->set_number('9870303')->is_valid_number, '宮城県登米市米山町田畑前');
ok($zip->set_number('9870304')->is_valid_number, '宮城県登米市米山町内');
ok($zip->set_number('9870304')->is_valid_number, '宮城県登米市米山町中道東');
ok($zip->set_number('9870304')->is_valid_number, '宮城県登米市米山町中道前');
ok($zip->set_number('9870305')->is_valid_number, '宮城県登米市米山町川前');
ok($zip->set_number('9870305')->is_valid_number, '宮城県登米市米山町水門');
ok($zip->set_number('9870305')->is_valid_number, '宮城県登米市米山町八反');
ok($zip->set_number('9870306')->is_valid_number, '宮城県登米市米山町地蔵川');
ok($zip->set_number('9870306')->is_valid_number, '宮城県登米市米山町土佐ケ渕');
ok($zip->set_number('9870307')->is_valid_number, '宮城県登米市米山町愛宕下');
ok($zip->set_number('9870307')->is_valid_number, '宮城県登米市米山町愛宕前');
ok($zip->set_number('9870307')->is_valid_number, '宮城県登米市米山町犬子松');
ok($zip->set_number('9870307')->is_valid_number, '宮城県登米市米山町猿ケ崎');
ok($zip->set_number('9870308')->is_valid_number, '宮城県登米市米山町小待井');
ok($zip->set_number('9870308')->is_valid_number, '宮城県登米市米山町小待井下');
ok($zip->set_number('9870308')->is_valid_number, '宮城県登米市米山町待井下');
ok($zip->set_number('9870309')->is_valid_number, '宮城県登米市米山町舘下');
ok($zip->set_number('9870309')->is_valid_number, '宮城県登米市米山町舘前');
ok($zip->set_number('9870311')->is_valid_number, '宮城県登米市米山町桜岡');
ok($zip->set_number('9870321')->is_valid_number, '宮城県登米市米山町西野');
ok($zip->set_number('9870331')->is_valid_number, '宮城県登米市米山町中津山');
ok($zip->set_number('9870341')->is_valid_number, '宮城県登米市豊里町大沢');
ok($zip->set_number('9870341')->is_valid_number, '宮城県登米市豊里町大沢沼田');
ok($zip->set_number('9870341')->is_valid_number, '宮城県登米市豊里町大沢谷岐');
ok($zip->set_number('9870341')->is_valid_number, '宮城県登米市豊里町十二沢');
ok($zip->set_number('9870341')->is_valid_number, '宮城県登米市豊里町竹ノ沢');
ok($zip->set_number('9870342')->is_valid_number, '宮城県登米市豊里町山根');
ok($zip->set_number('9870342')->is_valid_number, '宮城県登米市豊里町山根前');
ok($zip->set_number('9870343')->is_valid_number, '宮城県登米市豊里町小谷地');
ok($zip->set_number('9870343')->is_valid_number, '宮城県登米市豊里町沢尻');
ok($zip->set_number('9870344')->is_valid_number, '宮城県登米市豊里町境沢');
ok($zip->set_number('9870344')->is_valid_number, '宮城県登米市豊里町佐野');
ok($zip->set_number('9870344')->is_valid_number, '宮城県登米市豊里町迫');
ok($zip->set_number('9870345')->is_valid_number, '宮城県登米市豊里町中谷岐');
ok($zip->set_number('9870345')->is_valid_number, '宮城県登米市豊里町福沢');
ok($zip->set_number('9870346')->is_valid_number, '宮城県登米市豊里町白鳥山');
ok($zip->set_number('9870346')->is_valid_number, '宮城県登米市豊里町白鳥');
ok($zip->set_number('9870346')->is_valid_number, '宮城県登米市豊里町白鳥前');
ok($zip->set_number('9870351')->is_valid_number, '宮城県登米市豊里町久寿田');
ok($zip->set_number('9870351')->is_valid_number, '宮城県登米市豊里町久寿田前');
ok($zip->set_number('9870352')->is_valid_number, '宮城県登米市豊里町寿崎');
ok($zip->set_number('9870353')->is_valid_number, '宮城県登米市豊里町笑沢');
ok($zip->set_number('9870353')->is_valid_number, '宮城県登米市豊里町大椚');
ok($zip->set_number('9870353')->is_valid_number, '宮城県登米市豊里町平林');
ok($zip->set_number('9870354')->is_valid_number, '宮城県登米市豊里町上沼田');
ok($zip->set_number('9870354')->is_valid_number, '宮城県登米市豊里町下沼田');
ok($zip->set_number('9870354')->is_valid_number, '宮城県登米市豊里町昭和');
ok($zip->set_number('9870354')->is_valid_number, '宮城県登米市豊里町中沼田');
ok($zip->set_number('9870354')->is_valid_number, '宮城県登米市豊里町沼田');
ok($zip->set_number('9870355')->is_valid_number, '宮城県登米市豊里町後沢田');
ok($zip->set_number('9870355')->is_valid_number, '宮城県登米市豊里町保手');
ok($zip->set_number('9870356')->is_valid_number, '宮城県登米市豊里町芝下');
ok($zip->set_number('9870356')->is_valid_number, '宮城県登米市豊里町杢沢');
ok($zip->set_number('9870357')->is_valid_number, '宮城県登米市豊里町蕪木');
ok($zip->set_number('9870357')->is_valid_number, '宮城県登米市豊里町鳥越');
ok($zip->set_number('9870358')->is_valid_number, '宮城県登米市豊里町加々巻');
ok($zip->set_number('9870358')->is_valid_number, '宮城県登米市豊里町小巻');
ok($zip->set_number('9870358')->is_valid_number, '宮城県登米市豊里町新加々巻');
ok($zip->set_number('9870358')->is_valid_number, '宮城県登米市豊里町長根浦');
ok($zip->set_number('9870359')->is_valid_number, '宮城県登米市豊里町八反');
ok($zip->set_number('9870359')->is_valid_number, '宮城県登米市豊里町本地八反');
ok($zip->set_number('9870361')->is_valid_number, '宮城県登米市豊里町新田町');
ok($zip->set_number('9870362')->is_valid_number, '宮城県登米市豊里町上町裏');
ok($zip->set_number('9870362')->is_valid_number, '宮城県登米市豊里町小口前');
ok($zip->set_number('9870362')->is_valid_number, '宮城県登米市豊里町東待井下');
ok($zip->set_number('9870363')->is_valid_number, '宮城県登米市豊里町五反田');
ok($zip->set_number('9870363')->is_valid_number, '宮城県登米市豊里町横町');
ok($zip->set_number('9870364')->is_valid_number, '宮城県登米市豊里町下古屋');
ok($zip->set_number('9870364')->is_valid_number, '宮城県登米市豊里町土手下');
ok($zip->set_number('9870364')->is_valid_number, '宮城県登米市豊里町本地土手下');
ok($zip->set_number('9870365')->is_valid_number, '宮城県登米市豊里町新町');
ok($zip->set_number('9870366')->is_valid_number, '宮城県登米市豊里町浦軒');
ok($zip->set_number('9870366')->is_valid_number, '宮城県登米市豊里町上屋浦');
ok($zip->set_number('9870366')->is_valid_number, '宮城県登米市豊里町下屋浦');
ok($zip->set_number('9870367')->is_valid_number, '宮城県登米市豊里町川前');
ok($zip->set_number('9870368')->is_valid_number, '宮城県登米市豊里町七ツ塚');
ok($zip->set_number('9870368')->is_valid_number, '宮城県登米市豊里町町浦');
ok($zip->set_number('9870368')->is_valid_number, '宮城県登米市豊里町南町浦');
ok($zip->set_number('9870371')->is_valid_number, '宮城県登米市豊里町大曲');
ok($zip->set_number('9870371')->is_valid_number, '宮城県登米市豊里町唐崎');
ok($zip->set_number('9870371')->is_valid_number, '宮城県登米市豊里町十丁田');
ok($zip->set_number('9870372')->is_valid_number, '宮城県登米市豊里町西前田');
ok($zip->set_number('9870372')->is_valid_number, '宮城県登米市豊里町前田');
ok($zip->set_number('9870373')->is_valid_number, '宮城県登米市豊里町内町浦');
ok($zip->set_number('9870373')->is_valid_number, '宮城県登米市豊里町切津');
ok($zip->set_number('9870373')->is_valid_number, '宮城県登米市豊里町南切津');
ok($zip->set_number('9870374')->is_valid_number, '宮城県登米市豊里町東二ツ屋');
ok($zip->set_number('9870375')->is_valid_number, '宮城県登米市豊里町二ツ屋');
ok($zip->set_number('9870376')->is_valid_number, '宮城県登米市豊里町新細沼');
ok($zip->set_number('9870376')->is_valid_number, '宮城県登米市豊里町細沼');
ok($zip->set_number('9870376')->is_valid_number, '宮城県登米市豊里町細沼田');
ok($zip->set_number('9870377')->is_valid_number, '宮城県登米市豊里町内一番江');
ok($zip->set_number('9870377')->is_valid_number, '宮城県登米市豊里町外一番江');
ok($zip->set_number('9870378')->is_valid_number, '宮城県登米市豊里町鏡形');
ok($zip->set_number('9870378')->is_valid_number, '宮城県登米市豊里町新田鏡形');
ok($zip->set_number('9870379')->is_valid_number, '宮城県登米市豊里町剣先');
ok($zip->set_number('9870381')->is_valid_number, '宮城県登米市豊里町新長前');
ok($zip->set_number('9870381')->is_valid_number, '宮城県登米市豊里町長前');
ok($zip->set_number('9870382')->is_valid_number, '宮城県登米市豊里町上谷地');
ok($zip->set_number('9870383')->is_valid_number, '宮城県登米市豊里町外五番江');
ok($zip->set_number('9870383')->is_valid_number, '宮城県登米市豊里町外三番江');
ok($zip->set_number('9870383')->is_valid_number, '宮城県登米市豊里町外七番江');
ok($zip->set_number('9870383')->is_valid_number, '宮城県登米市豊里町外二番江');
ok($zip->set_number('9870383')->is_valid_number, '宮城県登米市豊里町外八番江');
ok($zip->set_number('9870383')->is_valid_number, '宮城県登米市豊里町外四番江');
ok($zip->set_number('9870383')->is_valid_number, '宮城県登米市豊里町外六番江');
ok($zip->set_number('9870384')->is_valid_number, '宮城県登米市豊里町十五貫');
ok($zip->set_number('9870384')->is_valid_number, '宮城県登米市豊里町十五貫谷地');
ok($zip->set_number('9870385')->is_valid_number, '宮城県登米市豊里町内田');
ok($zip->set_number('9870385')->is_valid_number, '宮城県登米市豊里町内畑');
ok($zip->set_number('9870385')->is_valid_number, '宮城県登米市豊里町下九');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町新高石前');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町高石');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町高石浦');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町西山成');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町西山成前');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町八の森');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町山成');
ok($zip->set_number('9870401')->is_valid_number, '宮城県登米市南方町山成前');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町板倉');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町板倉後');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町後屋敷待井');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町沢田');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町沢田前');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町沢田待井');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町沢田屋敷');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町新沢田');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町鶴代');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町戸根屋敷');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町中山');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町待井');
ok($zip->set_number('9870402')->is_valid_number, '宮城県登米市南方町松島屋敷');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町内ノ目');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町王塚');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町河面');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町鴻ノ木');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町小山');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町鶴江');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町二ツ橋');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町峯');
ok($zip->set_number('9870403')->is_valid_number, '宮城県登米市南方町薬師島屋敷');
ok($zip->set_number('9870404')->is_valid_number, '宮城県登米市南方町新島前');
ok($zip->set_number('9870404')->is_valid_number, '宮城県登米市南方町新丸ノ内');
ok($zip->set_number('9870405')->is_valid_number, '宮城県登米市南方町新中山');
ok($zip->set_number('9870411')->is_valid_number, '宮城県登米市南方町天沼');
ok($zip->set_number('9870411')->is_valid_number, '宮城県登米市南方町瀬ノ淵');
ok($zip->set_number('9870411')->is_valid_number, '宮城県登米市南方町寺袋');
ok($zip->set_number('9870412')->is_valid_number, '宮城県登米市南方町上ケ戸');
ok($zip->set_number('9870412')->is_valid_number, '宮城県登米市南方町雷');
ok($zip->set_number('9870412')->is_valid_number, '宮城県登米市南方町大涌戸');
ok($zip->set_number('9870412')->is_valid_number, '宮城県登米市南方町大門');
ok($zip->set_number('9870412')->is_valid_number, '宮城県登米市南方町照井');
ok($zip->set_number('9870412')->is_valid_number, '宮城県登米市南方町峯前');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町上原');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町下原前');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町宿畑');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町中原');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町原');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町原浦');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町原前');
ok($zip->set_number('9870413')->is_valid_number, '宮城県登米市南方町原屋敷');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町内鰐丸');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町大村');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町大村前');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町新山成浦');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町松葉');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町松葉表');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町松葉前');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町山成浦');
ok($zip->set_number('9870414')->is_valid_number, '宮城県登米市南方町鰐丸');
ok($zip->set_number('9870415')->is_valid_number, '宮城県登米市南方町真ケ沼');
ok($zip->set_number('9870421')->is_valid_number, '宮城県登米市南方町大畑');
ok($zip->set_number('9870421')->is_valid_number, '宮城県登米市南方町仕込');
ok($zip->set_number('9870421')->is_valid_number, '宮城県登米市南方町新井宿');
ok($zip->set_number('9870421')->is_valid_number, '宮城県登米市南方町南大畑前');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町大畠前');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町川前');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町新大畑前');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町新田');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町瀬川');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町東川前');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町蛇沼');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町室田');
ok($zip->set_number('9870422')->is_valid_number, '宮城県登米市南方町山崎');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町大嶽');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町大嶽前');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町大嶽山');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町烏田');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町ぜん荷前');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町ぜん荷山');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町館');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町堂地');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町堂地前');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町堀切');
ok($zip->set_number('9870423')->is_valid_number, '宮城県登米市南方町本郷大嶽');
ok($zip->set_number('9870424')->is_valid_number, '宮城県登米市南方町風張');
ok($zip->set_number('9870424')->is_valid_number, '宮城県登米市南方町館浦');
ok($zip->set_number('9870424')->is_valid_number, '宮城県登米市南方町細川');
ok($zip->set_number('9870424')->is_valid_number, '宮城県登米市南方町細川浦');
ok($zip->set_number('9870424')->is_valid_number, '宮城県登米市南方町細川前');
ok($zip->set_number('9870424')->is_valid_number, '宮城県登米市南方町南沢');
ok($zip->set_number('9870424')->is_valid_number, '宮城県登米市南方町南細川');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町梶沼');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町梶沼川前');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町梶沼前');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町上砥落');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町下砥落');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町十二山');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町新上砥落');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町新砥落');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町田中浦');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町砥落');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町沼向');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町米袋');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町米袋浦');
ok($zip->set_number('9870425')->is_valid_number, '宮城県登米市南方町米袋前');
ok($zip->set_number('9870426')->is_valid_number, '宮城県登米市南方町大袋');
ok($zip->set_number('9870426')->is_valid_number, '宮城県登米市南方町大袋浦');
ok($zip->set_number('9870426')->is_valid_number, '宮城県登米市南方町樟');
ok($zip->set_number('9870426')->is_valid_number, '宮城県登米市南方町樟土手外');
ok($zip->set_number('9870426')->is_valid_number, '宮城県登米市南方町成田');
ok($zip->set_number('9870426')->is_valid_number, '宮城県登米市南方町若狭前');
ok($zip->set_number('9870431')->is_valid_number, '宮城県登米市南方町一ノ曲');
ok($zip->set_number('9870431')->is_valid_number, '宮城県登米市南方町大埣');
ok($zip->set_number('9870431')->is_valid_number, '宮城県登米市南方町太田');
ok($zip->set_number('9870431')->is_valid_number, '宮城県登米市南方町新一ノ曲');
ok($zip->set_number('9870431')->is_valid_number, '宮城県登米市南方町横前');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町青笹');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町狼掛');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町上窪田');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町窪田');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町新畑岡下');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町堤田');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町畑岡');
ok($zip->set_number('9870432')->is_valid_number, '宮城県登米市南方町畑岡下');
ok($zip->set_number('9870433')->is_valid_number, '宮城県登米市南方町大平');
ok($zip->set_number('9870433')->is_valid_number, '宮城県登米市南方町大平前');
ok($zip->set_number('9870433')->is_valid_number, '宮城県登米市南方町長者原');
ok($zip->set_number('9870433')->is_valid_number, '宮城県登米市南方町中ノ口');
ok($zip->set_number('9870433')->is_valid_number, '宮城県登米市南方町沼崎');
ok($zip->set_number('9870433')->is_valid_number, '宮城県登米市南方町沼崎前');
ok($zip->set_number('9870441')->is_valid_number, '宮城県登米市南方町青島前');
ok($zip->set_number('9870441')->is_valid_number, '宮城県登米市南方町青島待井');
ok($zip->set_number('9870441')->is_valid_number, '宮城県登米市南方町青島屋敷');
ok($zip->set_number('9870441')->is_valid_number, '宮城県登米市南方町新青島前');
ok($zip->set_number('9870441')->is_valid_number, '宮城県登米市南方町新鳩峯');
ok($zip->set_number('9870442')->is_valid_number, '宮城県登米市南方町後高石');
ok($zip->set_number('9870442')->is_valid_number, '宮城県登米市南方町茶臼森');
ok($zip->set_number('9870442')->is_valid_number, '宮城県登米市南方町茶臼森前');
ok($zip->set_number('9870442')->is_valid_number, '宮城県登米市南方町中高石');
ok($zip->set_number('9870442')->is_valid_number, '宮城県登米市南方町中高石浦');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町板ケ沢');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町一網');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町大坂前');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町大西');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町表前');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町苔野谷地');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町新野谷地');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町外浦');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町長根');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町長根下');
ok($zip->set_number('9870443')->is_valid_number, '宮城県登米市南方町野谷地');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町尼池');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町大上');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町大森前');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町三代前');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町下新山');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町角欠前');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町間内');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町間内前');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町実沢');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町柳沢');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町柳沢前');
ok($zip->set_number('9870444')->is_valid_number, '宮城県登米市南方町横代');
ok($zip->set_number('9870445')->is_valid_number, '宮城県登米市南方町上平貝');
ok($zip->set_number('9870445')->is_valid_number, '宮城県登米市南方町下平貝');
ok($zip->set_number('9870445')->is_valid_number, '宮城県登米市南方町銭金壇');
ok($zip->set_number('9870445')->is_valid_number, '宮城県登米市南方町中須崎');
ok($zip->set_number('9870445')->is_valid_number, '宮城県登米市南方町平貝');
ok($zip->set_number('9870445')->is_valid_number, '宮城県登米市南方町翌沢');
ok($zip->set_number('9870446')->is_valid_number, '宮城県登米市南方町新高石浦');
ok($zip->set_number('9870447')->is_valid_number, '宮城県登米市南方町新長根下');
ok($zip->set_number('9870500')->is_valid_number, '宮城県登米市以下に掲載がない場合');
ok($zip->set_number('9870511')->is_valid_number, '宮城県登米市迫町佐沼');
ok($zip->set_number('9870512')->is_valid_number, '宮城県登米市迫町森');
ok($zip->set_number('9870513')->is_valid_number, '宮城県登米市迫町北方');
ok($zip->set_number('9870601')->is_valid_number, '宮城県登米市中田町石森');
ok($zip->set_number('9870602')->is_valid_number, '宮城県登米市中田町上沼');
ok($zip->set_number('9870611')->is_valid_number, '宮城県登米市中田町浅水');
ok($zip->set_number('9870621')->is_valid_number, '宮城県登米市中田町宝江黒沼');
ok($zip->set_number('9870622')->is_valid_number, '宮城県登米市中田町宝江新井田');
ok($zip->set_number('9870623')->is_valid_number, '宮城県登米市中田町宝江森');
ok($zip->set_number('9870701')->is_valid_number, '宮城県登米市登米町小島');
ok($zip->set_number('9870702')->is_valid_number, '宮城県登米市登米町寺池');
ok($zip->set_number('9870703')->is_valid_number, '宮城県登米市登米町日根牛');
ok($zip->set_number('9870704')->is_valid_number, '宮城県登米市登米町日野渡');
ok($zip->set_number('9870901')->is_valid_number, '宮城県登米市東和町米川');
ok($zip->set_number('9870902')->is_valid_number, '宮城県登米市東和町米谷');
ok($zip->set_number('9870903')->is_valid_number, '宮城県登米市東和町錦織');
ok($zip->set_number('9871101')->is_valid_number, '宮城県石巻市前谷地');
ok($zip->set_number('9871102')->is_valid_number, '宮城県石巻市和渕');
ok($zip->set_number('9871103')->is_valid_number, '宮城県石巻市北村');
ok($zip->set_number('9871221')->is_valid_number, '宮城県石巻市須江');
ok($zip->set_number('9871222')->is_valid_number, '宮城県石巻市広渕');
ok($zip->set_number('9871301')->is_valid_number, '宮城県大崎市松山須摩屋');
ok($zip->set_number('9871302')->is_valid_number, '宮城県大崎市松山長尾');
ok($zip->set_number('9871303')->is_valid_number, '宮城県大崎市松山金谷');
ok($zip->set_number('9871304')->is_valid_number, '宮城県大崎市松山千石');
ok($zip->set_number('9871305')->is_valid_number, '宮城県大崎市松山次橋');
ok($zip->set_number('9871306')->is_valid_number, '宮城県大崎市松山下伊場野');
ok($zip->set_number('9872001')->is_valid_number, '宮城県栗原市高清水蟹沢尻');
ok($zip->set_number('9872002')->is_valid_number, '宮城県栗原市高清水八重壁');
ok($zip->set_number('9872003')->is_valid_number, '宮城県栗原市高清水福塚');
ok($zip->set_number('9872004')->is_valid_number, '宮城県栗原市高清水浦南沢');
ok($zip->set_number('9872005')->is_valid_number, '宮城県栗原市高清水忽滑沢');
ok($zip->set_number('9872011')->is_valid_number, '宮城県栗原市高清水京の沢');
ok($zip->set_number('9872012')->is_valid_number, '宮城県栗原市高清水中の沢');
ok($zip->set_number('9872013')->is_valid_number, '宮城県栗原市高清水欠屋敷');
ok($zip->set_number('9872014')->is_valid_number, '宮城県栗原市高清水大沢');
ok($zip->set_number('9872015')->is_valid_number, '宮城県栗原市高清水西中里');
ok($zip->set_number('9872016')->is_valid_number, '宮城県栗原市高清水茂路具多');
ok($zip->set_number('9872017')->is_valid_number, '宮城県栗原市高清水石沢');
ok($zip->set_number('9872018')->is_valid_number, '宮城県栗原市高清水石沢浦');
ok($zip->set_number('9872021')->is_valid_number, '宮城県栗原市高清水神原');
ok($zip->set_number('9872022')->is_valid_number, '宮城県栗原市高清水原');
ok($zip->set_number('9872023')->is_valid_number, '宮城県栗原市高清水熊野堂');
ok($zip->set_number('9872024')->is_valid_number, '宮城県栗原市高清水小山田');
ok($zip->set_number('9872025')->is_valid_number, '宮城県栗原市高清水大西');
ok($zip->set_number('9872026')->is_valid_number, '宮城県栗原市高清水熊野');
ok($zip->set_number('9872027')->is_valid_number, '宮城県栗原市高清水若宮');
ok($zip->set_number('9872028')->is_valid_number, '宮城県栗原市高清水日向');
ok($zip->set_number('9872031')->is_valid_number, '宮城県栗原市高清水新田');
ok($zip->set_number('9872032')->is_valid_number, '宮城県栗原市高清水横手');
ok($zip->set_number('9872033')->is_valid_number, '宮城県栗原市高清水浅野');
ok($zip->set_number('9872034')->is_valid_number, '宮城県栗原市高清水明官');
ok($zip->set_number('9872035')->is_valid_number, '宮城県栗原市高清水浅野前');
ok($zip->set_number('9872036')->is_valid_number, '宮城県栗原市高清水南沢');
ok($zip->set_number('9872041')->is_valid_number, '宮城県栗原市高清水要の森');
ok($zip->set_number('9872042')->is_valid_number, '宮城県栗原市高清水宿の沢');
ok($zip->set_number('9872043')->is_valid_number, '宮城県栗原市高清水手取');
ok($zip->set_number('9872044')->is_valid_number, '宮城県栗原市高清水堤下');
ok($zip->set_number('9872045')->is_valid_number, '宮城県栗原市高清水西手取');
ok($zip->set_number('9872051')->is_valid_number, '宮城県栗原市高清水三森');
ok($zip->set_number('9872052')->is_valid_number, '宮城県栗原市高清水宮脇');
ok($zip->set_number('9872053')->is_valid_number, '宮城県栗原市高清水渕際');
ok($zip->set_number('9872054')->is_valid_number, '宮城県栗原市高清水沖');
ok($zip->set_number('9872055')->is_valid_number, '宮城県栗原市高清水五月田');
ok($zip->set_number('9872111')->is_valid_number, '宮城県栗原市高清水影の沢');
ok($zip->set_number('9872112')->is_valid_number, '宮城県栗原市高清水上折木');
ok($zip->set_number('9872113')->is_valid_number, '宮城県栗原市高清水折木');
ok($zip->set_number('9872114')->is_valid_number, '宮城県栗原市高清水下折木');
ok($zip->set_number('9872115')->is_valid_number, '宮城県栗原市高清水一本松');
ok($zip->set_number('9872116')->is_valid_number, '宮城県栗原市高清水来光沢');
ok($zip->set_number('9872121')->is_valid_number, '宮城県栗原市高清水上佐野');
ok($zip->set_number('9872122')->is_valid_number, '宮城県栗原市高清水中佐野');
ok($zip->set_number('9872123')->is_valid_number, '宮城県栗原市高清水新佐野');
ok($zip->set_number('9872124')->is_valid_number, '宮城県栗原市高清水下佐野');
ok($zip->set_number('9872125')->is_valid_number, '宮城県栗原市高清水十二の神');
ok($zip->set_number('9872126')->is_valid_number, '宮城県栗原市高清水大寺');
ok($zip->set_number('9872127')->is_valid_number, '宮城県栗原市高清水佐野沢田');
ok($zip->set_number('9872127')->is_valid_number, '宮城県栗原市高清水太子堂');
ok($zip->set_number('9872128')->is_valid_number, '宮城県栗原市高清水佐野丁');
ok($zip->set_number('9872131')->is_valid_number, '宮城県栗原市高清水水の手');
ok($zip->set_number('9872132')->is_valid_number, '宮城県栗原市高清水東館');
ok($zip->set_number('9872133')->is_valid_number, '宮城県栗原市高清水桜丁');
ok($zip->set_number('9872141')->is_valid_number, '宮城県栗原市高清水上外沢田');
ok($zip->set_number('9872141')->is_valid_number, '宮城県栗原市高清水北甚六原');
ok($zip->set_number('9872142')->is_valid_number, '宮城県栗原市高清水外沢田');
ok($zip->set_number('9872143')->is_valid_number, '宮城県栗原市高清水覚満寺');
ok($zip->set_number('9872144')->is_valid_number, '宮城県栗原市高清水台町');
ok($zip->set_number('9872145')->is_valid_number, '宮城県栗原市高清水向野');
ok($zip->set_number('9872146')->is_valid_number, '宮城県栗原市高清水乙牧堀');
ok($zip->set_number('9872146')->is_valid_number, '宮城県栗原市高清水甲牧堀');
ok($zip->set_number('9872146')->is_valid_number, '宮城県栗原市高清水丁牧堀');
ok($zip->set_number('9872146')->is_valid_number, '宮城県栗原市高清水丙牧堀');
ok($zip->set_number('9872147')->is_valid_number, '宮城県栗原市高清水観音沢');
ok($zip->set_number('9872147')->is_valid_number, '宮城県栗原市高清水観音堂');
ok($zip->set_number('9872151')->is_valid_number, '宮城県栗原市高清水東浦');
ok($zip->set_number('9872151')->is_valid_number, '宮城県栗原市高清水仰ケ返り');
ok($zip->set_number('9872152')->is_valid_number, '宮城県栗原市高清水天王沢');
ok($zip->set_number('9872153')->is_valid_number, '宮城県栗原市高清水北原');
ok($zip->set_number('9872154')->is_valid_number, '宮城県栗原市高清水南原');
ok($zip->set_number('9872155')->is_valid_number, '宮城県栗原市高清水萱刈');
ok($zip->set_number('9872156')->is_valid_number, '宮城県栗原市高清水千神');
ok($zip->set_number('9872157')->is_valid_number, '宮城県栗原市高清水中の茎');
ok($zip->set_number('9872158')->is_valid_number, '宮城県栗原市高清水上萩田');
ok($zip->set_number('9872158')->is_valid_number, '宮城県栗原市高清水新中の茎');
ok($zip->set_number('9872158')->is_valid_number, '宮城県栗原市高清水本道');
ok($zip->set_number('9872159')->is_valid_number, '宮城県栗原市高清水松の木沢田');
ok($zip->set_number('9872161')->is_valid_number, '宮城県栗原市高清水神明');
ok($zip->set_number('9872162')->is_valid_number, '宮城県栗原市高清水丁神明');
ok($zip->set_number('9872163')->is_valid_number, '宮城県栗原市高清水勝負ケ町');
ok($zip->set_number('9872164')->is_valid_number, '宮城県栗原市高清水新神明');
ok($zip->set_number('9872171')->is_valid_number, '宮城県栗原市高清水長福寺');
ok($zip->set_number('9872172')->is_valid_number, '宮城県栗原市高清水松原');
ok($zip->set_number('9872173')->is_valid_number, '宮城県栗原市高清水桂葉');
ok($zip->set_number('9872174')->is_valid_number, '宮城県栗原市高清水上桂葉');
ok($zip->set_number('9872175')->is_valid_number, '宮城県栗原市高清水五輪');
ok($zip->set_number('9872176')->is_valid_number, '宮城県栗原市高清水西善光寺');
ok($zip->set_number('9872177')->is_valid_number, '宮城県栗原市高清水新桂葉');
ok($zip->set_number('9872181')->is_valid_number, '宮城県栗原市高清水東善光寺');
ok($zip->set_number('9872182')->is_valid_number, '宮城県栗原市高清水中里');
ok($zip->set_number('9872183')->is_valid_number, '宮城県栗原市高清水袖山');
ok($zip->set_number('9872184')->is_valid_number, '宮城県栗原市高清水善光寺');
ok($zip->set_number('9872185')->is_valid_number, '宮城県栗原市高清水新町');
ok($zip->set_number('9872186')->is_valid_number, '宮城県栗原市高清水中町');
ok($zip->set_number('9872187')->is_valid_number, '宮城県栗原市高清水本町');
ok($zip->set_number('9872188')->is_valid_number, '宮城県栗原市高清水小山下');
ok($zip->set_number('9872189')->is_valid_number, '宮城県栗原市高清水下町');
ok($zip->set_number('9872200')->is_valid_number, '宮城県栗原市以下に掲載がない場合');
ok($zip->set_number('9872201')->is_valid_number, '宮城県栗原市築館富');
ok($zip->set_number('9872202')->is_valid_number, '宮城県栗原市築館城生野');
ok($zip->set_number('9872203')->is_valid_number, '宮城県栗原市築館下宮野');
ok($zip->set_number('9872204')->is_valid_number, '宮城県栗原市築館黒瀬');
ok($zip->set_number('9872205')->is_valid_number, '宮城県栗原市築館宮野中央');
ok($zip->set_number('9872211')->is_valid_number, '宮城県栗原市築館源光');
ok($zip->set_number('9872212')->is_valid_number, '宮城県栗原市築館木戸');
ok($zip->set_number('9872213')->is_valid_number, '宮城県栗原市築館内南沢');
ok($zip->set_number('9872214')->is_valid_number, '宮城県栗原市築館内沢');
ok($zip->set_number('9872215')->is_valid_number, '宮城県栗原市築館高田');
ok($zip->set_number('9872216')->is_valid_number, '宮城県栗原市築館伊豆');
ok($zip->set_number('9872221')->is_valid_number, '宮城県栗原市築館下待井');
ok($zip->set_number('9872222')->is_valid_number, '宮城県栗原市築館外南沢');
ok($zip->set_number('9872223')->is_valid_number, '宮城県栗原市築館萩沢');
ok($zip->set_number('9872224')->is_valid_number, '宮城県栗原市築館横須賀');
ok($zip->set_number('9872225')->is_valid_number, '宮城県栗原市築館太田');
ok($zip->set_number('9872226')->is_valid_number, '宮城県栗原市築館八沢');
ok($zip->set_number('9872227')->is_valid_number, '宮城県栗原市築館光屋敷');
ok($zip->set_number('9872228')->is_valid_number, '宮城県栗原市築館川添');
ok($zip->set_number('9872229')->is_valid_number, '宮城県栗原市築館三峰');
ok($zip->set_number('9872231')->is_valid_number, '宮城県栗原市築館赤坂');
ok($zip->set_number('9872232')->is_valid_number, '宮城県栗原市築館沢入');
ok($zip->set_number('9872233')->is_valid_number, '宮城県栗原市築館照越');
ok($zip->set_number('9872234')->is_valid_number, '宮城県栗原市築館新八ツ沢');
ok($zip->set_number('9872235')->is_valid_number, '宮城県栗原市築館築館');
ok($zip->set_number('9872236')->is_valid_number, '宮城県栗原市築館蟹沢');
ok($zip->set_number('9872241')->is_valid_number, '宮城県栗原市築館館下');
ok($zip->set_number('9872242')->is_valid_number, '宮城県栗原市築館館沢');
ok($zip->set_number('9872243')->is_valid_number, '宮城県栗原市築館萩沢東');
ok($zip->set_number('9872243')->is_valid_number, '宮城県栗原市築館萩沢南');
ok($zip->set_number('9872244')->is_valid_number, '宮城県栗原市築館西小山');
ok($zip->set_number('9872245')->is_valid_number, '宮城県栗原市築館荒田沢');
ok($zip->set_number('9872246')->is_valid_number, '宮城県栗原市築館上高森');
ok($zip->set_number('9872247')->is_valid_number, '宮城県栗原市築館下高森');
ok($zip->set_number('9872251')->is_valid_number, '宮城県栗原市築館藤木');
ok($zip->set_number('9872252')->is_valid_number, '宮城県栗原市築館薬師');
ok($zip->set_number('9872253')->is_valid_number, '宮城県栗原市築館青野');
ok($zip->set_number('9872261')->is_valid_number, '宮城県栗原市築館久伝');
ok($zip->set_number('9872262')->is_valid_number, '宮城県栗原市築館唐竹林');
ok($zip->set_number('9872263')->is_valid_number, '宮城県栗原市築館新田');
ok($zip->set_number('9872263')->is_valid_number, '宮城県栗原市築館薬師ケ丘');
ok($zip->set_number('9872264')->is_valid_number, '宮城県栗原市築館薬師台');
ok($zip->set_number('9872265')->is_valid_number, '宮城県栗原市築館小淵西');
ok($zip->set_number('9872265')->is_valid_number, '宮城県栗原市築館小淵東');
ok($zip->set_number('9872265')->is_valid_number, '宮城県栗原市築館境田');
ok($zip->set_number('9872265')->is_valid_number, '宮城県栗原市築館左野原');
ok($zip->set_number('9872271')->is_valid_number, '宮城県栗原市築館芋埣');
ok($zip->set_number('9872272')->is_valid_number, '宮城県栗原市築館留場');
ok($zip->set_number('9872273')->is_valid_number, '宮城県栗原市築館左足');
ok($zip->set_number('9872274')->is_valid_number, '宮城県栗原市築館新成田西');
ok($zip->set_number('9872274')->is_valid_number, '宮城県栗原市築館成田');
ok($zip->set_number('9872275')->is_valid_number, '宮城県栗原市築館上宮野');
ok($zip->set_number('9872301')->is_valid_number, '宮城県栗原市一迫大川口');
ok($zip->set_number('9872302')->is_valid_number, '宮城県栗原市一迫片子沢');
ok($zip->set_number('9872303')->is_valid_number, '宮城県栗原市一迫川口');
ok($zip->set_number('9872304')->is_valid_number, '宮城県栗原市一迫北沢');
ok($zip->set_number('9872305')->is_valid_number, '宮城県栗原市一迫狐崎');
ok($zip->set_number('9872306')->is_valid_number, '宮城県栗原市一迫嶋躰');
ok($zip->set_number('9872307')->is_valid_number, '宮城県栗原市一迫清水目');
ok($zip->set_number('9872308')->is_valid_number, '宮城県栗原市一迫真坂');
ok($zip->set_number('9872309')->is_valid_number, '宮城県栗原市一迫柳目');
ok($zip->set_number('9872311')->is_valid_number, '宮城県栗原市一迫御崎');
ok($zip->set_number('9872312')->is_valid_number, '宮城県栗原市一迫沖浦');
ok($zip->set_number('9872313')->is_valid_number, '宮城県栗原市一迫沖');
ok($zip->set_number('9872314')->is_valid_number, '宮城県栗原市一迫岡田');
ok($zip->set_number('9872315')->is_valid_number, '宮城県栗原市一迫間杭元');
ok($zip->set_number('9872316')->is_valid_number, '宮城県栗原市一迫小坂本');
ok($zip->set_number('9872317')->is_valid_number, '宮城県栗原市一迫久保田');
ok($zip->set_number('9872318')->is_valid_number, '宮城県栗原市一迫松の木');
ok($zip->set_number('9872319')->is_valid_number, '宮城県栗原市一迫宮前');
ok($zip->set_number('9872321')->is_valid_number, '宮城県栗原市一迫横町');
ok($zip->set_number('9872322')->is_valid_number, '宮城県栗原市一迫横町浦');
ok($zip->set_number('9872323')->is_valid_number, '宮城県栗原市一迫女子町');
ok($zip->set_number('9872324')->is_valid_number, '宮城県栗原市一迫三嶋');
ok($zip->set_number('9872325')->is_valid_number, '宮城県栗原市一迫坂下西');
ok($zip->set_number('9872326')->is_valid_number, '宮城県栗原市一迫山崎');
ok($zip->set_number('9872327')->is_valid_number, '宮城県栗原市一迫天神');
ok($zip->set_number('9872328')->is_valid_number, '宮城県栗原市一迫土川');
ok($zip->set_number('9872329')->is_valid_number, '宮城県栗原市一迫細越');
ok($zip->set_number('9872331')->is_valid_number, '宮城県栗原市一迫萩生');
ok($zip->set_number('9872332')->is_valid_number, '宮城県栗原市一迫高橋');
ok($zip->set_number('9872333')->is_valid_number, '宮城県栗原市一迫要害');
ok($zip->set_number('9872334')->is_valid_number, '宮城県栗原市一迫神山');
ok($zip->set_number('9872335')->is_valid_number, '宮城県栗原市一迫高田');
ok($zip->set_number('9872336')->is_valid_number, '宮城県栗原市一迫荒屋敷');
ok($zip->set_number('9872337')->is_valid_number, '宮城県栗原市一迫松原沢');
ok($zip->set_number('9872338')->is_valid_number, '宮城県栗原市一迫日向');
ok($zip->set_number('9872339')->is_valid_number, '宮城県栗原市一迫上中島');
ok($zip->set_number('9872341')->is_valid_number, '宮城県栗原市一迫中屋敷浦');
ok($zip->set_number('9872342')->is_valid_number, '宮城県栗原市一迫沢田');
ok($zip->set_number('9872343')->is_valid_number, '宮城県栗原市一迫一本杉');
ok($zip->set_number('9872344')->is_valid_number, '宮城県栗原市一迫宮下');
ok($zip->set_number('9872345')->is_valid_number, '宮城県栗原市一迫屋敷田');
ok($zip->set_number('9872346')->is_valid_number, '宮城県栗原市一迫大清水');
ok($zip->set_number('9872347')->is_valid_number, '宮城県栗原市一迫平館');
ok($zip->set_number('9872348')->is_valid_number, '宮城県栗原市一迫大平沢');
ok($zip->set_number('9872349')->is_valid_number, '宮城県栗原市一迫大際');
ok($zip->set_number('9872351')->is_valid_number, '宮城県栗原市一迫宇南田');
ok($zip->set_number('9872352')->is_valid_number, '宮城県栗原市一迫鹿込');
ok($zip->set_number('9872353')->is_valid_number, '宮城県栗原市一迫上久保');
ok($zip->set_number('9872354')->is_valid_number, '宮城県栗原市一迫西風');
ok($zip->set_number('9872355')->is_valid_number, '宮城県栗原市一迫鍛冶屋敷');
ok($zip->set_number('9872356')->is_valid_number, '宮城県栗原市一迫山沢');
ok($zip->set_number('9872357')->is_valid_number, '宮城県栗原市一迫沼田');
ok($zip->set_number('9872358')->is_valid_number, '宮城県栗原市一迫下小僧');
ok($zip->set_number('9872359')->is_valid_number, '宮城県栗原市一迫佐野原');
ok($zip->set_number('9872361')->is_valid_number, '宮城県栗原市一迫中小僧');
ok($zip->set_number('9872362')->is_valid_number, '宮城県栗原市一迫大栗');
ok($zip->set_number('9872363')->is_valid_number, '宮城県栗原市一迫佐野');
ok($zip->set_number('9872364')->is_valid_number, '宮城県栗原市一迫岩ケ沢');
ok($zip->set_number('9872365')->is_valid_number, '宮城県栗原市一迫新米');
ok($zip->set_number('9872366')->is_valid_number, '宮城県栗原市一迫論田');
ok($zip->set_number('9872367')->is_valid_number, '宮城県栗原市一迫上大土');
ok($zip->set_number('9872368')->is_valid_number, '宮城県栗原市一迫下大土');
ok($zip->set_number('9872369')->is_valid_number, '宮城県栗原市一迫荒町');
ok($zip->set_number('9872371')->is_valid_number, '宮城県栗原市一迫川台');
ok($zip->set_number('9872372')->is_valid_number, '宮城県栗原市一迫青木');
ok($zip->set_number('9872373')->is_valid_number, '宮城県栗原市一迫不動西');
ok($zip->set_number('9872374')->is_valid_number, '宮城県栗原市一迫清水原');
ok($zip->set_number('9872511')->is_valid_number, '宮城県栗原市花山本沢');
ok($zip->set_number('9872512')->is_valid_number, '宮城県栗原市花山草木沢');
ok($zip->set_number('9880000')->is_valid_number, '宮城県気仙沼市以下に掲載がない場合');
ok($zip->set_number('9880001')->is_valid_number, '宮城県気仙沼市東みなと町');
ok($zip->set_number('9880002')->is_valid_number, '宮城県気仙沼市錦町');
ok($zip->set_number('9880003')->is_valid_number, '宮城県気仙沼市本浜町');
ok($zip->set_number('9880004')->is_valid_number, '宮城県気仙沼市浜町');
ok($zip->set_number('9880005')->is_valid_number, '宮城県気仙沼市新浜町');
ok($zip->set_number('9880006')->is_valid_number, '宮城県気仙沼市西みなと町');
ok($zip->set_number('9880007')->is_valid_number, '宮城県気仙沼市中みなと町');
ok($zip->set_number('9880008')->is_valid_number, '宮城県気仙沼市魚浜町');
ok($zip->set_number('9880011')->is_valid_number, '宮城県気仙沼市陣山');
ok($zip->set_number('9880012')->is_valid_number, '宮城県気仙沼市栄町');
ok($zip->set_number('9880013')->is_valid_number, '宮城県気仙沼市魚町');
ok($zip->set_number('9880014')->is_valid_number, '宮城県気仙沼市柏崎');
ok($zip->set_number('9880015')->is_valid_number, '宮城県気仙沼市浜見山');
ok($zip->set_number('9880016')->is_valid_number, '宮城県気仙沼市沢田');
ok($zip->set_number('9880017')->is_valid_number, '宮城県気仙沼市南町');
ok($zip->set_number('9880018')->is_valid_number, '宮城県気仙沼市南町海岸');
ok($zip->set_number('9880021')->is_valid_number, '宮城県気仙沼市港町');
ok($zip->set_number('9880022')->is_valid_number, '宮城県気仙沼市河原田');
ok($zip->set_number('9880023')->is_valid_number, '宮城県気仙沼市南が丘');
ok($zip->set_number('9880024')->is_valid_number, '宮城県気仙沼市仲町');
ok($zip->set_number('9880025')->is_valid_number, '宮城県気仙沼市内ノ脇');
ok($zip->set_number('9880026')->is_valid_number, '宮城県気仙沼市幸町');
ok($zip->set_number('9880031')->is_valid_number, '宮城県気仙沼市潮見町');
ok($zip->set_number('9880032')->is_valid_number, '宮城県気仙沼市一景島');
ok($zip->set_number('9880033')->is_valid_number, '宮城県気仙沼市川口町');
ok($zip->set_number('9880034')->is_valid_number, '宮城県気仙沼市朝日町');
ok($zip->set_number('9880036')->is_valid_number, '宮城県気仙沼市弁天町');
ok($zip->set_number('9880037')->is_valid_number, '宮城県気仙沼市魚市場前');
ok($zip->set_number('9880041')->is_valid_number, '宮城県気仙沼市川畑');
ok($zip->set_number('9880042')->is_valid_number, '宮城県気仙沼市本郷');
ok($zip->set_number('9880043')->is_valid_number, '宮城県気仙沼市南郷');
ok($zip->set_number('9880044')->is_valid_number, '宮城県気仙沼市神山');
ok($zip->set_number('9880045')->is_valid_number, '宮城県気仙沼市田谷');
ok($zip->set_number('9880046')->is_valid_number, '宮城県気仙沼市田谷前');
ok($zip->set_number('9880051')->is_valid_number, '宮城県気仙沼市常楽');
ok($zip->set_number('9880052')->is_valid_number, '宮城県気仙沼市田中');
ok($zip->set_number('9880053')->is_valid_number, '宮城県気仙沼市田中前');
ok($zip->set_number('9880054')->is_valid_number, '宮城県気仙沼市駒場');
ok($zip->set_number('9880055')->is_valid_number, '宮城県気仙沼市反松');
ok($zip->set_number('9880056')->is_valid_number, '宮城県気仙沼市上田中');
ok($zip->set_number('9880057')->is_valid_number, '宮城県気仙沼市所沢');
ok($zip->set_number('9880058')->is_valid_number, '宮城県気仙沼市田中沖');
ok($zip->set_number('9880061')->is_valid_number, '宮城県気仙沼市岩ケ崎');
ok($zip->set_number('9880062')->is_valid_number, '宮城県気仙沼市明戸');
ok($zip->set_number('9880063')->is_valid_number, '宮城県気仙沼市四反田');
ok($zip->set_number('9880064')->is_valid_number, '宮城県気仙沼市九条');
ok($zip->set_number('9880065')->is_valid_number, '宮城県気仙沼市後九条');
ok($zip->set_number('9880066')->is_valid_number, '宮城県気仙沼市東新城');
ok($zip->set_number('9880071')->is_valid_number, '宮城県気仙沼市新町');
ok($zip->set_number('9880072')->is_valid_number, '宮城県気仙沼市化粧坂');
ok($zip->set_number('9880073')->is_valid_number, '宮城県気仙沼市笹が陣');
ok($zip->set_number('9880074')->is_valid_number, '宮城県気仙沼市本町');
ok($zip->set_number('9880075')->is_valid_number, '宮城県気仙沼市赤坂');
ok($zip->set_number('9880076')->is_valid_number, '宮城県気仙沼市舘山');
ok($zip->set_number('9880077')->is_valid_number, '宮城県気仙沼市古町');
ok($zip->set_number('9880081')->is_valid_number, '宮城県気仙沼市蔵底');
ok($zip->set_number('9880082')->is_valid_number, '宮城県気仙沼市太田');
ok($zip->set_number('9880083')->is_valid_number, '宮城県気仙沼市入沢');
ok($zip->set_number('9880084')->is_valid_number, '宮城県気仙沼市八日町');
ok($zip->set_number('9880085')->is_valid_number, '宮城県気仙沼市三日町');
ok($zip->set_number('9880086')->is_valid_number, '宮城県気仙沼市福美町');
ok($zip->set_number('9880087')->is_valid_number, '宮城県気仙沼市滝の入');
ok($zip->set_number('9880101')->is_valid_number, '宮城県気仙沼市赤岩舘下');
ok($zip->set_number('9880102')->is_valid_number, '宮城県気仙沼市赤岩舘森');
ok($zip->set_number('9880103')->is_valid_number, '宮城県気仙沼市赤岩港');
ok($zip->set_number('9880104')->is_valid_number, '宮城県気仙沼市赤岩五駄鱈');
ok($zip->set_number('9880105')->is_valid_number, '宮城県気仙沼市赤岩老松');
ok($zip->set_number('9880111')->is_valid_number, '宮城県気仙沼市松崎北沢');
ok($zip->set_number('9880112')->is_valid_number, '宮城県気仙沼市松崎前浜');
ok($zip->set_number('9880113')->is_valid_number, '宮城県気仙沼市松崎片浜');
ok($zip->set_number('9880114')->is_valid_number, '宮城県気仙沼市松崎浦田');
ok($zip->set_number('9880121')->is_valid_number, '宮城県気仙沼市松崎萱');
ok($zip->set_number('9880122')->is_valid_number, '宮城県気仙沼市松崎五駄鱈');
ok($zip->set_number('9880123')->is_valid_number, '宮城県気仙沼市松崎中瀬');
ok($zip->set_number('9880124')->is_valid_number, '宮城県気仙沼市松崎高谷');
ok($zip->set_number('9880131')->is_valid_number, '宮城県気仙沼市松崎尾崎');
ok($zip->set_number('9880132')->is_valid_number, '宮城県気仙沼市松崎馬場');
ok($zip->set_number('9880133')->is_valid_number, '宮城県気仙沼市松崎下赤田');
ok($zip->set_number('9880134')->is_valid_number, '宮城県気仙沼市松崎上赤田');
ok($zip->set_number('9880141')->is_valid_number, '宮城県気仙沼市松崎柳沢');
ok($zip->set_number('9880142')->is_valid_number, '宮城県気仙沼市松崎丸森');
ok($zip->set_number('9880143')->is_valid_number, '宮城県気仙沼市松崎地生');
ok($zip->set_number('9880144')->is_valid_number, '宮城県気仙沼市松崎鶴巻');
ok($zip->set_number('9880151')->is_valid_number, '宮城県気仙沼市松崎立石');
ok($zip->set_number('9880152')->is_valid_number, '宮城県気仙沼市松崎外ケ沢');
ok($zip->set_number('9880153')->is_valid_number, '宮城県気仙沼市松崎面瀬');
ok($zip->set_number('9880154')->is_valid_number, '宮城県気仙沼市松崎猫渕');
ok($zip->set_number('9880155')->is_valid_number, '宮城県気仙沼市松崎大萱');
ok($zip->set_number('9880156')->is_valid_number, '宮城県気仙沼市松崎下金取');
ok($zip->set_number('9880157')->is_valid_number, '宮城県気仙沼市松崎上金取');
ok($zip->set_number('9880161')->is_valid_number, '宮城県気仙沼市赤岩高前田');
ok($zip->set_number('9880162')->is_valid_number, '宮城県気仙沼市赤岩前田');
ok($zip->set_number('9880163')->is_valid_number, '宮城県気仙沼市赤岩迎前田');
ok($zip->set_number('9880164')->is_valid_number, '宮城県気仙沼市赤岩四十二');
ok($zip->set_number('9880165')->is_valid_number, '宮城県気仙沼市赤岩物見');
ok($zip->set_number('9880166')->is_valid_number, '宮城県気仙沼市赤岩上羽田');
ok($zip->set_number('9880167')->is_valid_number, '宮城県気仙沼市赤岩羽田');
ok($zip->set_number('9880168')->is_valid_number, '宮城県気仙沼市赤岩水梨子');
ok($zip->set_number('9880169')->is_valid_number, '宮城県気仙沼市物倉山');
ok($zip->set_number('9880171')->is_valid_number, '宮城県気仙沼市赤岩牧沢');
ok($zip->set_number('9880172')->is_valid_number, '宮城県気仙沼市赤岩大石倉');
ok($zip->set_number('9880173')->is_valid_number, '宮城県気仙沼市赤岩長柴');
ok($zip->set_number('9880174')->is_valid_number, '宮城県気仙沼市赤岩大滝');
ok($zip->set_number('9880181')->is_valid_number, '宮城県気仙沼市赤岩杉ノ沢');
ok($zip->set_number('9880182')->is_valid_number, '宮城県気仙沼市赤岩石兜');
ok($zip->set_number('9880183')->is_valid_number, '宮城県気仙沼市赤岩泥ノ木');
ok($zip->set_number('9880184')->is_valid_number, '宮城県気仙沼市赤岩平貝');
ok($zip->set_number('9880185')->is_valid_number, '宮城県気仙沼市赤岩小田');
ok($zip->set_number('9880201')->is_valid_number, '宮城県気仙沼市岩月千岩田');
ok($zip->set_number('9880202')->is_valid_number, '宮城県気仙沼市岩月台ノ沢');
ok($zip->set_number('9880203')->is_valid_number, '宮城県気仙沼市岩月星谷');
ok($zip->set_number('9880204')->is_valid_number, '宮城県気仙沼市岩月長平');
ok($zip->set_number('9880205')->is_valid_number, '宮城県気仙沼市岩月箒沢');
ok($zip->set_number('9880206')->is_valid_number, '宮城県気仙沼市岩月寺沢');
ok($zip->set_number('9880207')->is_valid_number, '宮城県気仙沼市岩月宝ケ沢');
ok($zip->set_number('9880211')->is_valid_number, '宮城県気仙沼市最知川原');
ok($zip->set_number('9880212')->is_valid_number, '宮城県気仙沼市最知森合');
ok($zip->set_number('9880213')->is_valid_number, '宮城県気仙沼市最知南最知');
ok($zip->set_number('9880214')->is_valid_number, '宮城県気仙沼市最知荒沢');
ok($zip->set_number('9880215')->is_valid_number, '宮城県気仙沼市最知北最知');
ok($zip->set_number('9880221')->is_valid_number, '宮城県気仙沼市長磯七半沢');
ok($zip->set_number('9880222')->is_valid_number, '宮城県気仙沼市長磯船原');
ok($zip->set_number('9880223')->is_valid_number, '宮城県気仙沼市長磯鳥子沢');
ok($zip->set_number('9880224')->is_valid_number, '宮城県気仙沼市長磯前林');
ok($zip->set_number('9880225')->is_valid_number, '宮城県気仙沼市長磯大窪');
ok($zip->set_number('9880226')->is_valid_number, '宮城県気仙沼市長磯後沢');
ok($zip->set_number('9880227')->is_valid_number, '宮城県気仙沼市長磯森');
ok($zip->set_number('9880231')->is_valid_number, '宮城県気仙沼市長磯浜');
ok($zip->set_number('9880232')->is_valid_number, '宮城県気仙沼市長磯下原');
ok($zip->set_number('9880233')->is_valid_number, '宮城県気仙沼市長磯原');
ok($zip->set_number('9880234')->is_valid_number, '宮城県気仙沼市長磯原ノ沢');
ok($zip->set_number('9880235')->is_valid_number, '宮城県気仙沼市長磯牧通');
ok($zip->set_number('9880236')->is_valid_number, '宮城県気仙沼市長磯二本松');
ok($zip->set_number('9880237')->is_valid_number, '宮城県気仙沼市長磯赤貝');
ok($zip->set_number('9880238')->is_valid_number, '宮城県気仙沼市長磯中原');
ok($zip->set_number('9880241')->is_valid_number, '宮城県気仙沼市波路上岩井崎');
ok($zip->set_number('9880242')->is_valid_number, '宮城県気仙沼市波路上崎野');
ok($zip->set_number('9880243')->is_valid_number, '宮城県気仙沼市波路上牧');
ok($zip->set_number('9880244')->is_valid_number, '宮城県気仙沼市波路上明戸');
ok($zip->set_number('9880245')->is_valid_number, '宮城県気仙沼市波路上杉ノ下');
ok($zip->set_number('9880246')->is_valid_number, '宮城県気仙沼市波路上瀬向');
ok($zip->set_number('9880247')->is_valid_number, '宮城県気仙沼市波路上内沼');
ok($zip->set_number('9880251')->is_valid_number, '宮城県気仙沼市波路上内田');
ok($zip->set_number('9880252')->is_valid_number, '宮城県気仙沼市波路上後原');
ok($zip->set_number('9880253')->is_valid_number, '宮城県気仙沼市波路上原');
ok($zip->set_number('9880254')->is_valid_number, '宮城県気仙沼市波路上野田');
ok($zip->set_number('9880255')->is_valid_number, '宮城県気仙沼市波路上向田');
ok($zip->set_number('9880256')->is_valid_number, '宮城県気仙沼市波路上向原');
ok($zip->set_number('9880261')->is_valid_number, '宮城県気仙沼市本吉町後田');
ok($zip->set_number('9880261')->is_valid_number, '宮城県気仙沼市本吉町直伝');
ok($zip->set_number('9880261')->is_valid_number, '宮城県気仙沼市本吉町土樋下');
ok($zip->set_number('9880262')->is_valid_number, '宮城県気仙沼市本吉町沖の田');
ok($zip->set_number('9880263')->is_valid_number, '宮城県気仙沼市本吉町洞沢');
ok($zip->set_number('9880264')->is_valid_number, '宮城県気仙沼市本吉町長根');
ok($zip->set_number('9880265')->is_valid_number, '宮城県気仙沼市本吉町窪');
ok($zip->set_number('9880266')->is_valid_number, '宮城県気仙沼市本吉町寺谷');
ok($zip->set_number('9880267')->is_valid_number, '宮城県気仙沼市本吉町寺沢');
ok($zip->set_number('9880267')->is_valid_number, '宮城県気仙沼市本吉町長畑');
ok($zip->set_number('9880268')->is_valid_number, '宮城県気仙沼市本吉町石川原');
ok($zip->set_number('9880269')->is_valid_number, '宮城県気仙沼市本吉町菖蒲沢');
ok($zip->set_number('9880269')->is_valid_number, '宮城県気仙沼市本吉町道貫');
ok($zip->set_number('9880271')->is_valid_number, '宮城県気仙沼市本吉町野々下');
ok($zip->set_number('9880272')->is_valid_number, '宮城県気仙沼市本吉町大谷');
ok($zip->set_number('9880273')->is_valid_number, '宮城県気仙沼市本吉町三島');
ok($zip->set_number('9880274')->is_valid_number, '宮城県気仙沼市本吉町滝根');
ok($zip->set_number('9880275')->is_valid_number, '宮城県気仙沼市本吉町九多丸');
ok($zip->set_number('9880276')->is_valid_number, '宮城県気仙沼市本吉町日門');
ok($zip->set_number('9880277')->is_valid_number, '宮城県気仙沼市本吉町天ヶ沢');
ok($zip->set_number('9880277')->is_valid_number, '宮城県気仙沼市本吉町田の沢');
ok($zip->set_number('9880278')->is_valid_number, '宮城県気仙沼市本吉町高瀬ヶ森');
ok($zip->set_number('9880278')->is_valid_number, '宮城県気仙沼市本吉町山谷');
ok($zip->set_number('9880279')->is_valid_number, '宮城県気仙沼市本吉町猿内');
ok($zip->set_number('9880281')->is_valid_number, '宮城県気仙沼市本吉町府中');
ok($zip->set_number('9880282')->is_valid_number, '宮城県気仙沼市本吉町前浜');
ok($zip->set_number('9880283')->is_valid_number, '宮城県気仙沼市本吉町大森');
ok($zip->set_number('9880283')->is_valid_number, '宮城県気仙沼市本吉町谷地');
ok($zip->set_number('9880284')->is_valid_number, '宮城県気仙沼市本吉町赤牛');
ok($zip->set_number('9880285')->is_valid_number, '宮城県気仙沼市本吉町小金沢');
ok($zip->set_number('9880286')->is_valid_number, '宮城県気仙沼市本吉町高');
ok($zip->set_number('9880287')->is_valid_number, '宮城県気仙沼市本吉町大朴木');
ok($zip->set_number('9880301')->is_valid_number, '宮城県気仙沼市本吉町狼の巣');
ok($zip->set_number('9880302')->is_valid_number, '宮城県気仙沼市本吉町林の沢');
ok($zip->set_number('9880303')->is_valid_number, '宮城県気仙沼市本吉町幸土');
ok($zip->set_number('9880304')->is_valid_number, '宮城県気仙沼市本吉町大沢');
ok($zip->set_number('9880305')->is_valid_number, '宮城県気仙沼市本吉町津谷長根');
ok($zip->set_number('9880306')->is_valid_number, '宮城県気仙沼市本吉町大椚');
ok($zip->set_number('9880307')->is_valid_number, '宮城県気仙沼市本吉町津谷舘岡');
ok($zip->set_number('9880308')->is_valid_number, '宮城県気仙沼市本吉町津谷松岡');
ok($zip->set_number('9880309')->is_valid_number, '宮城県気仙沼市本吉町津谷松尾');
ok($zip->set_number('9880311')->is_valid_number, '宮城県気仙沼市本吉町風越');
ok($zip->set_number('9880312')->is_valid_number, '宮城県気仙沼市本吉町道外');
ok($zip->set_number('9880313')->is_valid_number, '宮城県気仙沼市本吉町卯名沢');
ok($zip->set_number('9880314')->is_valid_number, '宮城県気仙沼市本吉町圃の沢');
ok($zip->set_number('9880315')->is_valid_number, '宮城県気仙沼市本吉町新圃の沢');
ok($zip->set_number('9880316')->is_valid_number, '宮城県気仙沼市本吉町新北明戸');
ok($zip->set_number('9880317')->is_valid_number, '宮城県気仙沼市本吉町北明戸');
ok($zip->set_number('9880318')->is_valid_number, '宮城県気仙沼市本吉町登米沢');
ok($zip->set_number('9880321')->is_valid_number, '宮城県気仙沼市本吉町小浜');
ok($zip->set_number('9880322')->is_valid_number, '宮城県気仙沼市本吉町二十一浜');
ok($zip->set_number('9880323')->is_valid_number, '宮城県気仙沼市本吉町今朝磯');
ok($zip->set_number('9880324')->is_valid_number, '宮城県気仙沼市本吉町歌生');
ok($zip->set_number('9880325')->is_valid_number, '宮城県気仙沼市本吉町蔵内');
ok($zip->set_number('9880326')->is_valid_number, '宮城県気仙沼市本吉町柳沢');
ok($zip->set_number('9880327')->is_valid_number, '宮城県気仙沼市本吉町長窪');
ok($zip->set_number('9880328')->is_valid_number, '宮城県気仙沼市本吉町菅の沢');
ok($zip->set_number('9880331')->is_valid_number, '宮城県気仙沼市本吉町中島');
ok($zip->set_number('9880332')->is_valid_number, '宮城県気仙沼市本吉町下宿');
ok($zip->set_number('9880333')->is_valid_number, '宮城県気仙沼市本吉町平貝');
ok($zip->set_number('9880334')->is_valid_number, '宮城県気仙沼市本吉町外尾');
ok($zip->set_number('9880335')->is_valid_number, '宮城県気仙沼市本吉町蕨野');
ok($zip->set_number('9880336')->is_valid_number, '宮城県気仙沼市本吉町泉沢');
ok($zip->set_number('9880337')->is_valid_number, '宮城県気仙沼市本吉町新南明戸');
ok($zip->set_number('9880338')->is_valid_number, '宮城県気仙沼市本吉町南明戸');
ok($zip->set_number('9880339')->is_valid_number, '宮城県気仙沼市本吉町泉');
ok($zip->set_number('9880341')->is_valid_number, '宮城県気仙沼市本吉町津谷桜子');
ok($zip->set_number('9880342')->is_valid_number, '宮城県気仙沼市本吉町幣掛');
ok($zip->set_number('9880343')->is_valid_number, '宮城県気仙沼市本吉町松ヶ沢');
ok($zip->set_number('9880344')->is_valid_number, '宮城県気仙沼市本吉町宮内');
ok($zip->set_number('9880345')->is_valid_number, '宮城県気仙沼市本吉町舘下');
ok($zip->set_number('9880346')->is_valid_number, '宮城県気仙沼市本吉町岳の下');
ok($zip->set_number('9880347')->is_valid_number, '宮城県気仙沼市本吉町猪の鼻');
ok($zip->set_number('9880348')->is_valid_number, '宮城県気仙沼市本吉町小峰崎');
ok($zip->set_number('9880351')->is_valid_number, '宮城県気仙沼市本吉町午王野沢');
ok($zip->set_number('9880352')->is_valid_number, '宮城県気仙沼市本吉町平椚');
ok($zip->set_number('9880353')->is_valid_number, '宮城県気仙沼市本吉町信夫');
ok($zip->set_number('9880354')->is_valid_number, '宮城県気仙沼市本吉町鹿の子');
ok($zip->set_number('9880355')->is_valid_number, '宮城県気仙沼市本吉町滝沢');
ok($zip->set_number('9880356')->is_valid_number, '宮城県気仙沼市本吉町大柴');
ok($zip->set_number('9880357')->is_valid_number, '宮城県気仙沼市本吉町中平');
ok($zip->set_number('9880358')->is_valid_number, '宮城県気仙沼市本吉町大東');
ok($zip->set_number('9880359')->is_valid_number, '宮城県気仙沼市本吉町上野');
ok($zip->set_number('9880361')->is_valid_number, '宮城県気仙沼市本吉町下要害');
ok($zip->set_number('9880362')->is_valid_number, '宮城県気仙沼市本吉町寺要害');
ok($zip->set_number('9880363')->is_valid_number, '宮城県気仙沼市本吉町深萩');
ok($zip->set_number('9880364')->is_valid_number, '宮城県気仙沼市本吉町小金山');
ok($zip->set_number('9880365')->is_valid_number, '宮城県気仙沼市本吉町馬籠町');
ok($zip->set_number('9880366')->is_valid_number, '宮城県気仙沼市本吉町馬籠町頭');
ok($zip->set_number('9880367')->is_valid_number, '宮城県気仙沼市本吉町向畑');
ok($zip->set_number('9880371')->is_valid_number, '宮城県気仙沼市本吉町漆原');
ok($zip->set_number('9880372')->is_valid_number, '宮城県気仙沼市本吉町尾田');
ok($zip->set_number('9880373')->is_valid_number, '宮城県気仙沼市本吉町狩猟');
ok($zip->set_number('9880374')->is_valid_number, '宮城県気仙沼市本吉町角柄');
ok($zip->set_number('9880375')->is_valid_number, '宮城県気仙沼市本吉町中沢');
ok($zip->set_number('9880381')->is_valid_number, '宮城県気仙沼市本吉町津谷新明戸');
ok($zip->set_number('9880382')->is_valid_number, '宮城県気仙沼市本吉町津谷明戸');
ok($zip->set_number('9880383')->is_valid_number, '宮城県気仙沼市本吉町坊の倉');
ok($zip->set_number('9880384')->is_valid_number, '宮城県気仙沼市本吉町高岡');
ok($zip->set_number('9880385')->is_valid_number, '宮城県気仙沼市本吉町下川内');
ok($zip->set_number('9880386')->is_valid_number, '宮城県気仙沼市本吉町西川内');
ok($zip->set_number('9880387')->is_valid_number, '宮城県気仙沼市本吉町中川内');
ok($zip->set_number('9880388')->is_valid_number, '宮城県気仙沼市本吉町上川内');
ok($zip->set_number('9880389')->is_valid_number, '宮城県気仙沼市本吉町東川内');
ok($zip->set_number('9880401')->is_valid_number, '宮城県本吉郡南三陸町歌津浪板');
ok($zip->set_number('9880402')->is_valid_number, '宮城県本吉郡南三陸町歌津港');
ok($zip->set_number('9880403')->is_valid_number, '宮城県本吉郡南三陸町歌津長羽');
ok($zip->set_number('9880404')->is_valid_number, '宮城県本吉郡南三陸町歌津牧田');
ok($zip->set_number('9880405')->is_valid_number, '宮城県本吉郡南三陸町歌津草木沢');
ok($zip->set_number('9880406')->is_valid_number, '宮城県本吉郡南三陸町歌津中野');
ok($zip->set_number('9880411')->is_valid_number, '宮城県本吉郡南三陸町歌津田茂川');
ok($zip->set_number('9880412')->is_valid_number, '宮城県本吉郡南三陸町歌津南の沢');
ok($zip->set_number('9880413')->is_valid_number, '宮城県本吉郡南三陸町歌津上の山');
ok($zip->set_number('9880414')->is_valid_number, '宮城県本吉郡南三陸町歌津長沢');
ok($zip->set_number('9880415')->is_valid_number, '宮城県本吉郡南三陸町歌津田の浦');
ok($zip->set_number('9880421')->is_valid_number, '宮城県本吉郡南三陸町歌津平棚');
ok($zip->set_number('9880422')->is_valid_number, '宮城県本吉郡南三陸町歌津松の崎');
ok($zip->set_number('9880423')->is_valid_number, '宮城県本吉郡南三陸町歌津枡沢');
ok($zip->set_number('9880424')->is_valid_number, '宮城県本吉郡南三陸町歌津北の沢');
ok($zip->set_number('9880425')->is_valid_number, '宮城県本吉郡南三陸町歌津神山');
ok($zip->set_number('9880426')->is_valid_number, '宮城県本吉郡南三陸町歌津石浜');
ok($zip->set_number('9880431')->is_valid_number, '宮城県本吉郡南三陸町歌津名足');
ok($zip->set_number('9880432')->is_valid_number, '宮城県本吉郡南三陸町歌津中山');
ok($zip->set_number('9880433')->is_valid_number, '宮城県本吉郡南三陸町歌津馬場');
ok($zip->set_number('9880434')->is_valid_number, '宮城県本吉郡南三陸町歌津大磯');
ok($zip->set_number('9880435')->is_valid_number, '宮城県本吉郡南三陸町歌津小沼');
ok($zip->set_number('9880436')->is_valid_number, '宮城県本吉郡南三陸町歌津小長柴');
ok($zip->set_number('9880441')->is_valid_number, '宮城県本吉郡南三陸町歌津田の頭');
ok($zip->set_number('9880442')->is_valid_number, '宮城県本吉郡南三陸町歌津番所');
ok($zip->set_number('9880443')->is_valid_number, '宮城県本吉郡南三陸町歌津尾崎');
ok($zip->set_number('9880444')->is_valid_number, '宮城県本吉郡南三陸町歌津泊浜');
ok($zip->set_number('9880445')->is_valid_number, '宮城県本吉郡南三陸町歌津館浜');
ok($zip->set_number('9880446')->is_valid_number, '宮城県本吉郡南三陸町歌津板橋');
ok($zip->set_number('9880447')->is_valid_number, '宮城県本吉郡南三陸町歌津長柴');
ok($zip->set_number('9880448')->is_valid_number, '宮城県本吉郡南三陸町歌津大沼');
ok($zip->set_number('9880451')->is_valid_number, '宮城県本吉郡南三陸町歌津管の浜');
ok($zip->set_number('9880452')->is_valid_number, '宮城県本吉郡南三陸町歌津町向');
ok($zip->set_number('9880453')->is_valid_number, '宮城県本吉郡南三陸町歌津伊里前');
ok($zip->set_number('9880454')->is_valid_number, '宮城県本吉郡南三陸町歌津峰畑');
ok($zip->set_number('9880455')->is_valid_number, '宮城県本吉郡南三陸町歌津吉野沢');
ok($zip->set_number('9880456')->is_valid_number, '宮城県本吉郡南三陸町歌津川内');
ok($zip->set_number('9880461')->is_valid_number, '宮城県本吉郡南三陸町歌津寄木');
ok($zip->set_number('9880462')->is_valid_number, '宮城県本吉郡南三陸町歌津砂浜');
ok($zip->set_number('9880463')->is_valid_number, '宮城県本吉郡南三陸町歌津大森');
ok($zip->set_number('9880464')->is_valid_number, '宮城県本吉郡南三陸町歌津森畑');
ok($zip->set_number('9880465')->is_valid_number, '宮城県本吉郡南三陸町歌津韮の浜');
ok($zip->set_number('9880466')->is_valid_number, '宮城県本吉郡南三陸町歌津平松');
ok($zip->set_number('9880467')->is_valid_number, '宮城県本吉郡南三陸町歌津皿貝');
ok($zip->set_number('9880471')->is_valid_number, '宮城県本吉郡南三陸町歌津石泉');
ok($zip->set_number('9880472')->is_valid_number, '宮城県本吉郡南三陸町歌津宮方');
ok($zip->set_number('9880473')->is_valid_number, '宮城県本吉郡南三陸町歌津中在');
ok($zip->set_number('9880474')->is_valid_number, '宮城県本吉郡南三陸町歌津田表');
ok($zip->set_number('9880475')->is_valid_number, '宮城県本吉郡南三陸町歌津白山');
ok($zip->set_number('9880476')->is_valid_number, '宮城県本吉郡南三陸町歌津上沢');
ok($zip->set_number('9880477')->is_valid_number, '宮城県本吉郡南三陸町歌津払川');
ok($zip->set_number('9880478')->is_valid_number, '宮城県本吉郡南三陸町歌津樋の口');
ok($zip->set_number('9880501')->is_valid_number, '宮城県気仙沼市唐桑町釜石下');
ok($zip->set_number('9880502')->is_valid_number, '宮城県気仙沼市唐桑町台の下');
ok($zip->set_number('9880503')->is_valid_number, '宮城県気仙沼市唐桑町荒谷前');
ok($zip->set_number('9880504')->is_valid_number, '宮城県気仙沼市唐桑町竹の袖');
ok($zip->set_number('9880505')->is_valid_number, '宮城県気仙沼市唐桑町港');
ok($zip->set_number('9880506')->is_valid_number, '宮城県気仙沼市唐桑町出山');
ok($zip->set_number('9880511')->is_valid_number, '宮城県気仙沼市唐桑町舘');
ok($zip->set_number('9880512')->is_valid_number, '宮城県気仙沼市唐桑町岩井沢');
ok($zip->set_number('9880513')->is_valid_number, '宮城県気仙沼市唐桑町載鈎');
ok($zip->set_number('9880514')->is_valid_number, '宮城県気仙沼市唐桑町小田');
ok($zip->set_number('9880521')->is_valid_number, '宮城県気仙沼市唐桑町大畑');
ok($zip->set_number('9880522')->is_valid_number, '宮城県気仙沼市唐桑町上川原');
ok($zip->set_number('9880523')->is_valid_number, '宮城県気仙沼市唐桑町境');
ok($zip->set_number('9880524')->is_valid_number, '宮城県気仙沼市唐桑町只越');
ok($zip->set_number('9880525')->is_valid_number, '宮城県気仙沼市唐桑町堂角');
ok($zip->set_number('9880526')->is_valid_number, '宮城県気仙沼市唐桑町唯越');
ok($zip->set_number('9880527')->is_valid_number, '宮城県気仙沼市唐桑町西舞根(その他)');
ok($zip->set_number('9880531')->is_valid_number, '宮城県気仙沼市唐桑町高石浜');
ok($zip->set_number('9880532')->is_valid_number, '宮城県気仙沼市唐桑町石浜');
ok($zip->set_number('9880533')->is_valid_number, '宮城県気仙沼市唐桑町明戸');
ok($zip->set_number('9880534')->is_valid_number, '宮城県気仙沼市唐桑町宿浦');
ok($zip->set_number('9880535')->is_valid_number, '宮城県気仙沼市唐桑町馬場');
ok($zip->set_number('9880541')->is_valid_number, '宮城県気仙沼市唐桑町北中');
ok($zip->set_number('9880542')->is_valid_number, '宮城県気仙沼市唐桑町中');
ok($zip->set_number('9880543')->is_valid_number, '宮城県気仙沼市唐桑町小長根');
ok($zip->set_number('9880544')->is_valid_number, '宮城県気仙沼市唐桑町欠浜');
ok($zip->set_number('9880551')->is_valid_number, '宮城県気仙沼市唐桑町松圃');
ok($zip->set_number('9880552')->is_valid_number, '宮城県気仙沼市唐桑町津本');
ok($zip->set_number('9880553')->is_valid_number, '宮城県気仙沼市唐桑町神の倉');
ok($zip->set_number('9880554')->is_valid_number, '宮城県気仙沼市唐桑町崎浜');
ok($zip->set_number('9880561')->is_valid_number, '宮城県気仙沼市唐桑町小鯖');
ok($zip->set_number('9880562')->is_valid_number, '宮城県気仙沼市唐桑町上小鯖');
ok($zip->set_number('9880563')->is_valid_number, '宮城県気仙沼市唐桑町中井');
ok($zip->set_number('9880571')->is_valid_number, '宮城県気仙沼市唐桑町鮪立');
ok($zip->set_number('9880572')->is_valid_number, '宮城県気仙沼市唐桑町上鮪立');
ok($zip->set_number('9880581')->is_valid_number, '宮城県気仙沼市唐桑町浦');
ok($zip->set_number('9880582')->is_valid_number, '宮城県気仙沼市唐桑町東舞根');
ok($zip->set_number('9880601')->is_valid_number, '宮城県気仙沼市外浜');
ok($zip->set_number('9880602')->is_valid_number, '宮城県気仙沼市大初平');
ok($zip->set_number('9880603')->is_valid_number, '宮城県気仙沼市外畑');
ok($zip->set_number('9880604')->is_valid_number, '宮城県気仙沼市廻舘');
ok($zip->set_number('9880605')->is_valid_number, '宮城県気仙沼市浦の浜');
ok($zip->set_number('9880606')->is_valid_number, '宮城県気仙沼市磯草');
ok($zip->set_number('9880607')->is_valid_number, '宮城県気仙沼市亀山');
ok($zip->set_number('9880611')->is_valid_number, '宮城県気仙沼市田尻');
ok($zip->set_number('9880612')->is_valid_number, '宮城県気仙沼市大向');
ok($zip->set_number('9880613')->is_valid_number, '宮城県気仙沼市高井');
ok($zip->set_number('9880621')->is_valid_number, '宮城県気仙沼市長崎');
ok($zip->set_number('9880622')->is_valid_number, '宮城県気仙沼市中山');
ok($zip->set_number('9880623')->is_valid_number, '宮城県気仙沼市浅根');
ok($zip->set_number('9880631')->is_valid_number, '宮城県気仙沼市三作浜');
ok($zip->set_number('9880632')->is_valid_number, '宮城県気仙沼市横沼');
ok($zip->set_number('9880633')->is_valid_number, '宮城県気仙沼市駒形');
ok($zip->set_number('9880634')->is_valid_number, '宮城県気仙沼市要害');
ok($zip->set_number('9880801')->is_valid_number, '宮城県気仙沼市上東側根');
ok($zip->set_number('9880802')->is_valid_number, '宮城県気仙沼市高判形山');
ok($zip->set_number('9880802')->is_valid_number, '宮城県気仙沼市日ノ口');
ok($zip->set_number('9880803')->is_valid_number, '宮城県気仙沼市上東側');
ok($zip->set_number('9880804')->is_valid_number, '宮城県気仙沼市東中才');
ok($zip->set_number('9880805')->is_valid_number, '宮城県気仙沼市西中才');
ok($zip->set_number('9880806')->is_valid_number, '宮城県気仙沼市上西側');
ok($zip->set_number('9880807')->is_valid_number, '宮城県気仙沼市白石');
ok($zip->set_number('9880811')->is_valid_number, '宮城県気仙沼市東八幡前');
ok($zip->set_number('9880812')->is_valid_number, '宮城県気仙沼市大岩井山');
ok($zip->set_number('9880812')->is_valid_number, '宮城県気仙沼市大峠山');
ok($zip->set_number('9880813')->is_valid_number, '宮城県気仙沼市浪板');
ok($zip->set_number('9880814')->is_valid_number, '宮城県気仙沼市大浦');
ok($zip->set_number('9880815')->is_valid_number, '宮城県気仙沼市小々汐');
ok($zip->set_number('9880816')->is_valid_number, '宮城県気仙沼市二ノ浜');
ok($zip->set_number('9880817')->is_valid_number, '宮城県気仙沼市西八幡町');
ok($zip->set_number('9880817')->is_valid_number, '宮城県気仙沼市西八幡前');
ok($zip->set_number('9880818')->is_valid_number, '宮城県気仙沼市三ノ浜');
ok($zip->set_number('9880821')->is_valid_number, '宮城県気仙沼市大林');
ok($zip->set_number('9880822')->is_valid_number, '宮城県気仙沼市切通');
ok($zip->set_number('9880823')->is_valid_number, '宮城県気仙沼市茗荷沢');
ok($zip->set_number('9880824')->is_valid_number, '宮城県気仙沼市川原崎');
ok($zip->set_number('9880825')->is_valid_number, '宮城県気仙沼市田尻沢');
ok($zip->set_number('9880826')->is_valid_number, '宮城県気仙沼市百目木');
ok($zip->set_number('9880827')->is_valid_number, '宮城県気仙沼市和野');
ok($zip->set_number('9880828')->is_valid_number, '宮城県気仙沼市下新田');
ok($zip->set_number('9880829')->is_valid_number, '宮城県気仙沼市新田');
ok($zip->set_number('9880831')->is_valid_number, '宮城県気仙沼市金成沢');
ok($zip->set_number('9880832')->is_valid_number, '宮城県気仙沼市瘻槻');
ok($zip->set_number('9880833')->is_valid_number, '宮城県気仙沼市渡戸');
ok($zip->set_number('9880834')->is_valid_number, '宮城県気仙沼市川上');
ok($zip->set_number('9880835')->is_valid_number, '宮城県気仙沼市長岩間');
ok($zip->set_number('9880836')->is_valid_number, '宮城県気仙沼市小芦');
ok($zip->set_number('9880837')->is_valid_number, '宮城県気仙沼市鹿ノ倉');
ok($zip->set_number('9880841')->is_valid_number, '宮城県気仙沼市柳沢');
ok($zip->set_number('9880842')->is_valid_number, '宮城県気仙沼市久保');
ok($zip->set_number('9880843')->is_valid_number, '宮城県気仙沼市落合');
ok($zip->set_number('9880844')->is_valid_number, '宮城県気仙沼市象ケ鼻');
ok($zip->set_number('9880845')->is_valid_number, '宮城県気仙沼市前木');
ok($zip->set_number('9880846')->is_valid_number, '宮城県気仙沼市川崎尻');
ok($zip->set_number('9880847')->is_valid_number, '宮城県気仙沼市阿霄月');
ok($zip->set_number('9880851')->is_valid_number, '宮城県気仙沼市下八瀬');
ok($zip->set_number('9880852')->is_valid_number, '宮城県気仙沼市松川');
ok($zip->set_number('9880853')->is_valid_number, '宮城県気仙沼市松川前');
ok($zip->set_number('9880854')->is_valid_number, '宮城県気仙沼市磯沢');
ok($zip->set_number('9880855')->is_valid_number, '宮城県気仙沼市名木沢');
ok($zip->set_number('9880861')->is_valid_number, '宮城県気仙沼市細尾');
ok($zip->set_number('9880862')->is_valid_number, '宮城県気仙沼市角地');
ok($zip->set_number('9880863')->is_valid_number, '宮城県気仙沼市黒沢');
ok($zip->set_number('9880863')->is_valid_number, '宮城県気仙沼市芳ノ口');
ok($zip->set_number('9880864')->is_valid_number, '宮城県気仙沼市塚沢');
ok($zip->set_number('9880865')->is_valid_number, '宮城県気仙沼市新早稲谷');
ok($zip->set_number('9880865')->is_valid_number, '宮城県気仙沼市早稲谷');
ok($zip->set_number('9880866')->is_valid_number, '宮城県気仙沼市内松川');
ok($zip->set_number('9880867')->is_valid_number, '宮城県気仙沼市新台');
ok($zip->set_number('9880867')->is_valid_number, '宮城県気仙沼市台');
ok($zip->set_number('9880868')->is_valid_number, '宮城県気仙沼市黒石山');
ok($zip->set_number('9880868')->is_valid_number, '宮城県気仙沼市新関根');
ok($zip->set_number('9880868')->is_valid_number, '宮城県気仙沼市関根');
ok($zip->set_number('9880927')->is_valid_number, '宮城県気仙沼市唐桑町西舞根(200番以上)');
ok($zip->set_number('9890111')->is_valid_number, '宮城県白石市越河五賀');
ok($zip->set_number('9890112')->is_valid_number, '宮城県白石市越河平');
ok($zip->set_number('9890113')->is_valid_number, '宮城県白石市越河');
ok($zip->set_number('9890200')->is_valid_number, '宮城県白石市以下に掲載がない場合');
ok($zip->set_number('9890201')->is_valid_number, '宮城県白石市小下倉');
ok($zip->set_number('9890202')->is_valid_number, '宮城県白石市上堰');
ok($zip->set_number('9890203')->is_valid_number, '宮城県白石市郡山');
ok($zip->set_number('9890204')->is_valid_number, '宮城県白石市松ケ丘');
ok($zip->set_number('9890205')->is_valid_number, '宮城県白石市東大畑');
ok($zip->set_number('9890206')->is_valid_number, '宮城県白石市寺屋敷前');
ok($zip->set_number('9890207')->is_valid_number, '宮城県白石市堂場前');
ok($zip->set_number('9890208')->is_valid_number, '宮城県白石市大畑');
ok($zip->set_number('9890211')->is_valid_number, '宮城県白石市大鷹沢鷹巣');
ok($zip->set_number('9890212')->is_valid_number, '宮城県白石市大鷹沢大町');
ok($zip->set_number('9890213')->is_valid_number, '宮城県白石市大鷹沢三沢');
ok($zip->set_number('9890214')->is_valid_number, '宮城県白石市大平坂谷');
ok($zip->set_number('9890215')->is_valid_number, '宮城県白石市斎川');
ok($zip->set_number('9890216')->is_valid_number, '宮城県白石市大平中目');
ok($zip->set_number('9890217')->is_valid_number, '宮城県白石市大平森合');
ok($zip->set_number('9890218')->is_valid_number, '宮城県白石市鷹巣東');
ok($zip->set_number('9890220')->is_valid_number, '宮城県白石市鷹巣西');
ok($zip->set_number('9890221')->is_valid_number, '宮城県白石市緑が丘');
ok($zip->set_number('9890222')->is_valid_number, '宮城県白石市鷹巣');
ok($zip->set_number('9890223')->is_valid_number, '宮城県白石市旭町');
ok($zip->set_number('9890224')->is_valid_number, '宮城県白石市北無双作');
ok($zip->set_number('9890225')->is_valid_number, '宮城県白石市東町');
ok($zip->set_number('9890226')->is_valid_number, '宮城県白石市白石沖');
ok($zip->set_number('9890227')->is_valid_number, '宮城県白石市田町');
ok($zip->set_number('9890228')->is_valid_number, '宮城県白石市兎作');
ok($zip->set_number('9890229')->is_valid_number, '宮城県白石市銚子ケ森');
ok($zip->set_number('9890231')->is_valid_number, '宮城県白石市福岡蔵本');
ok($zip->set_number('9890232')->is_valid_number, '宮城県白石市福岡長袋(その他)');
ok($zip->set_number('9890233')->is_valid_number, '宮城県白石市小原');
ok($zip->set_number('9890241')->is_valid_number, '宮城県白石市寿山');
ok($zip->set_number('9890242')->is_valid_number, '宮城県白石市柳町');
ok($zip->set_number('9890243')->is_valid_number, '宮城県白石市沢目');
ok($zip->set_number('9890244')->is_valid_number, '宮城県白石市上久保');
ok($zip->set_number('9890245')->is_valid_number, '宮城県白石市城南');
ok($zip->set_number('9890246')->is_valid_number, '宮城県白石市新館町');
ok($zip->set_number('9890247')->is_valid_number, '宮城県白石市八幡町');
ok($zip->set_number('9890248')->is_valid_number, '宮城県白石市南町');
ok($zip->set_number('9890251')->is_valid_number, '宮城県白石市益岡町');
ok($zip->set_number('9890252')->is_valid_number, '宮城県白石市西益岡町');
ok($zip->set_number('9890253')->is_valid_number, '宮城県白石市東小路');
ok($zip->set_number('9890254')->is_valid_number, '宮城県白石市大川町');
ok($zip->set_number('9890255')->is_valid_number, '宮城県白石市城北町');
ok($zip->set_number('9890256')->is_valid_number, '宮城県白石市本鍛冶小路');
ok($zip->set_number('9890257')->is_valid_number, '宮城県白石市亘理町');
ok($zip->set_number('9890258')->is_valid_number, '宮城県白石市半沢屋敷西');
ok($zip->set_number('9890259')->is_valid_number, '宮城県白石市半沢屋敷前');
ok($zip->set_number('9890261')->is_valid_number, '宮城県白石市外川原');
ok($zip->set_number('9890262')->is_valid_number, '宮城県白石市北川原');
ok($zip->set_number('9890263')->is_valid_number, '宮城県白石市柳川原');
ok($zip->set_number('9890264')->is_valid_number, '宮城県白石市幸');
ok($zip->set_number('9890265')->is_valid_number, '宮城県白石市十王堂北');
ok($zip->set_number('9890266')->is_valid_number, '宮城県白石市十王堂前');
ok($zip->set_number('9890267')->is_valid_number, '宮城県白石市延命寺北');
ok($zip->set_number('9890268')->is_valid_number, '宮城県白石市祢宜内');
ok($zip->set_number('9890271')->is_valid_number, '宮城県白石市不澄ケ池');
ok($zip->set_number('9890272')->is_valid_number, '宮城県白石市清水小路');
ok($zip->set_number('9890273')->is_valid_number, '宮城県白石市中町');
ok($zip->set_number('9890274')->is_valid_number, '宮城県白石市長町');
ok($zip->set_number('9890275')->is_valid_number, '宮城県白石市本町');
ok($zip->set_number('9890276')->is_valid_number, '宮城県白石市大手町');
ok($zip->set_number('9890277')->is_valid_number, '宮城県白石市沢端町');
ok($zip->set_number('9890278')->is_valid_number, '宮城県白石市沢端');
ok($zip->set_number('9890500')->is_valid_number, '宮城県刈田郡七ヶ宿町以下に掲載がない場合');
ok($zip->set_number('9890501')->is_valid_number, '宮城県刈田郡七ヶ宿町柏木山');
ok($zip->set_number('9890502')->is_valid_number, '宮城県刈田郡七ヶ宿町西町裏');
ok($zip->set_number('9890502')->is_valid_number, '宮城県刈田郡七ヶ宿町横川原');
ok($zip->set_number('9890503')->is_valid_number, '宮城県刈田郡七ヶ宿町横川');
ok($zip->set_number('9890504')->is_valid_number, '宮城県刈田郡七ヶ宿町上ノ平');
ok($zip->set_number('9890505')->is_valid_number, '宮城県刈田郡七ヶ宿町上ノ平山');
ok($zip->set_number('9890506')->is_valid_number, '宮城県刈田郡七ヶ宿町油畑');
ok($zip->set_number('9890507')->is_valid_number, '宮城県刈田郡七ヶ宿町大萱');
ok($zip->set_number('9890507')->is_valid_number, '宮城県刈田郡七ヶ宿町町下');
ok($zip->set_number('9890508')->is_valid_number, '宮城県刈田郡七ヶ宿町長老');
ok($zip->set_number('9890511')->is_valid_number, '宮城県刈田郡七ヶ宿町松原');
ok($zip->set_number('9890512')->is_valid_number, '宮城県刈田郡七ヶ宿町関');
ok($zip->set_number('9890513')->is_valid_number, '宮城県刈田郡七ヶ宿町上町尻');
ok($zip->set_number('9890514')->is_valid_number, '宮城県刈田郡七ヶ宿町下町尻');
ok($zip->set_number('9890515')->is_valid_number, '宮城県刈田郡七ヶ宿町町尻');
ok($zip->set_number('9890515')->is_valid_number, '宮城県刈田郡七ヶ宿町宮前');
ok($zip->set_number('9890516')->is_valid_number, '宮城県刈田郡七ヶ宿町大貫平');
ok($zip->set_number('9890516')->is_valid_number, '宮城県刈田郡七ヶ宿町上島田原');
ok($zip->set_number('9890516')->is_valid_number, '宮城県刈田郡七ヶ宿町下島田原');
ok($zip->set_number('9890516')->is_valid_number, '宮城県刈田郡七ヶ宿町西島田原');
ok($zip->set_number('9890516')->is_valid_number, '宮城県刈田郡七ヶ宿町東島田原');
ok($zip->set_number('9890517')->is_valid_number, '宮城県刈田郡七ヶ宿町上八合');
ok($zip->set_number('9890518')->is_valid_number, '宮城県刈田郡七ヶ宿町下八合');
ok($zip->set_number('9890519')->is_valid_number, '宮城県刈田郡七ヶ宿町神林山');
ok($zip->set_number('9890519')->is_valid_number, '宮城県刈田郡七ヶ宿町諏訪原');
ok($zip->set_number('9890521')->is_valid_number, '宮城県刈田郡七ヶ宿町新雷神');
ok($zip->set_number('9890522')->is_valid_number, '宮城県刈田郡七ヶ宿町一枚田');
ok($zip->set_number('9890523')->is_valid_number, '宮城県刈田郡七ヶ宿町館下');
ok($zip->set_number('9890524')->is_valid_number, '宮城県刈田郡七ヶ宿町上烏川');
ok($zip->set_number('9890524')->is_valid_number, '宮城県刈田郡七ヶ宿町廻館');
ok($zip->set_number('9890525')->is_valid_number, '宮城県刈田郡七ヶ宿町利津保');
ok($zip->set_number('9890526')->is_valid_number, '宮城県刈田郡七ヶ宿町明神前');
ok($zip->set_number('9890527')->is_valid_number, '宮城県刈田郡七ヶ宿町烏川岳');
ok($zip->set_number('9890528')->is_valid_number, '宮城県刈田郡七ヶ宿町沢上山');
ok($zip->set_number('9890529')->is_valid_number, '宮城県刈田郡七ヶ宿町大杉');
ok($zip->set_number('9890529')->is_valid_number, '宮城県刈田郡七ヶ宿町瀬見原');
ok($zip->set_number('9890531')->is_valid_number, '宮城県刈田郡七ヶ宿町矢立');
ok($zip->set_number('9890532')->is_valid_number, '宮城県刈田郡七ヶ宿町根添');
ok($zip->set_number('9890533')->is_valid_number, '宮城県刈田郡七ヶ宿町矢立平');
ok($zip->set_number('9890534')->is_valid_number, '宮城県刈田郡七ヶ宿町若林山');
ok($zip->set_number('9890535')->is_valid_number, '宮城県刈田郡七ヶ宿町夏梨平');
ok($zip->set_number('9890535')->is_valid_number, '宮城県刈田郡七ヶ宿町野沢倉山');
ok($zip->set_number('9890536')->is_valid_number, '宮城県刈田郡七ヶ宿町切通');
ok($zip->set_number('9890537')->is_valid_number, '宮城県刈田郡七ヶ宿町上野');
ok($zip->set_number('9890537')->is_valid_number, '宮城県刈田郡七ヶ宿町萩崎');
ok($zip->set_number('9890541')->is_valid_number, '宮城県刈田郡七ヶ宿町仕切目');
ok($zip->set_number('9890542')->is_valid_number, '宮城県刈田郡七ヶ宿町島木野');
ok($zip->set_number('9890543')->is_valid_number, '宮城県刈田郡七ヶ宿町蒲木');
ok($zip->set_number('9890544')->is_valid_number, '宮城県刈田郡七ヶ宿町中ノ沢原道下');
ok($zip->set_number('9890544')->is_valid_number, '宮城県刈田郡七ヶ宿町原谷地際');
ok($zip->set_number('9890545')->is_valid_number, '宮城県刈田郡七ヶ宿町原道上');
ok($zip->set_number('9890546')->is_valid_number, '宮城県刈田郡七ヶ宿町原道下');
ok($zip->set_number('9890547')->is_valid_number, '宮城県刈田郡七ヶ宿町中之沢');
ok($zip->set_number('9890548')->is_valid_number, '宮城県刈田郡七ヶ宿町八ツ分');
ok($zip->set_number('9890549')->is_valid_number, '宮城県刈田郡七ヶ宿町滑津');
ok($zip->set_number('9890551')->is_valid_number, '宮城県刈田郡七ヶ宿町八ツ森');
ok($zip->set_number('9890552')->is_valid_number, '宮城県刈田郡七ヶ宿町苗代端');
ok($zip->set_number('9890553')->is_valid_number, '宮城県刈田郡七ヶ宿町大迎');
ok($zip->set_number('9890554')->is_valid_number, '宮城県刈田郡七ヶ宿町陳ノ窪');
ok($zip->set_number('9890555')->is_valid_number, '宮城県刈田郡七ヶ宿町滝ノ上');
ok($zip->set_number('9890555')->is_valid_number, '宮城県刈田郡七ヶ宿町水上口');
ok($zip->set_number('9890556')->is_valid_number, '宮城県刈田郡七ヶ宿町愛宕下');
ok($zip->set_number('9890557')->is_valid_number, '宮城県刈田郡七ヶ宿町西森下');
ok($zip->set_number('9890561')->is_valid_number, '宮城県刈田郡七ヶ宿町栗原');
ok($zip->set_number('9890601')->is_valid_number, '宮城県刈田郡七ヶ宿町茂ヶ沢');
ok($zip->set_number('9890602')->is_valid_number, '宮城県刈田郡七ヶ宿町寺跡');
ok($zip->set_number('9890611')->is_valid_number, '宮城県刈田郡七ヶ宿町山伏坂');
ok($zip->set_number('9890612')->is_valid_number, '宮城県刈田郡七ヶ宿町侭ノ上');
ok($zip->set_number('9890613')->is_valid_number, '宮城県刈田郡七ヶ宿町上川原');
ok($zip->set_number('9890614')->is_valid_number, '宮城県刈田郡七ヶ宿町中川原');
ok($zip->set_number('9890615')->is_valid_number, '宮城県刈田郡七ヶ宿町沼田');
ok($zip->set_number('9890616')->is_valid_number, '宮城県刈田郡七ヶ宿町薄沢口');
ok($zip->set_number('9890617')->is_valid_number, '宮城県刈田郡七ヶ宿町滝下');
ok($zip->set_number('9890621')->is_valid_number, '宮城県刈田郡七ヶ宿町峠田');
ok($zip->set_number('9890622')->is_valid_number, '宮城県刈田郡七ヶ宿町峠田町頭');
ok($zip->set_number('9890623')->is_valid_number, '宮城県刈田郡七ヶ宿町上ノ台');
ok($zip->set_number('9890624')->is_valid_number, '宮城県刈田郡七ヶ宿町明神下');
ok($zip->set_number('9890625')->is_valid_number, '宮城県刈田郡七ヶ宿町峠田愛宕下');
ok($zip->set_number('9890626')->is_valid_number, '宮城県刈田郡七ヶ宿町茂庭道');
ok($zip->set_number('9890627')->is_valid_number, '宮城県刈田郡七ヶ宿町坂ノ下');
ok($zip->set_number('9890628')->is_valid_number, '宮城県刈田郡七ヶ宿町境ノ沢');
ok($zip->set_number('9890631')->is_valid_number, '宮城県刈田郡七ヶ宿町大石川原');
ok($zip->set_number('9890632')->is_valid_number, '宮城県刈田郡七ヶ宿町田中道下');
ok($zip->set_number('9890633')->is_valid_number, '宮城県刈田郡七ヶ宿町田中道上');
ok($zip->set_number('9890634')->is_valid_number, '宮城県刈田郡七ヶ宿町小駕籠沢');
ok($zip->set_number('9890635')->is_valid_number, '宮城県刈田郡七ヶ宿町板木');
ok($zip->set_number('9890636')->is_valid_number, '宮城県刈田郡七ヶ宿町六本杉');
ok($zip->set_number('9890641')->is_valid_number, '宮城県刈田郡七ヶ宿町程ヶ沢');
ok($zip->set_number('9890642')->is_valid_number, '宮城県刈田郡七ヶ宿町割付');
ok($zip->set_number('9890643')->is_valid_number, '宮城県刈田郡七ヶ宿町稲子');
ok($zip->set_number('9890644')->is_valid_number, '宮城県刈田郡七ヶ宿町稲子山');
ok($zip->set_number('9890651')->is_valid_number, '宮城県刈田郡七ヶ宿町東口道上');
ok($zip->set_number('9890652')->is_valid_number, '宮城県刈田郡七ヶ宿町東口道下');
ok($zip->set_number('9890653')->is_valid_number, '宮城県刈田郡七ヶ宿町湯原');
ok($zip->set_number('9890654')->is_valid_number, '宮城県刈田郡七ヶ宿町寺前');
ok($zip->set_number('9890655')->is_valid_number, '宮城県刈田郡七ヶ宿町壇前');
ok($zip->set_number('9890656')->is_valid_number, '宮城県刈田郡七ヶ宿町柳沢山国有林');
ok($zip->set_number('9890657')->is_valid_number, '宮城県刈田郡七ヶ宿町町裏');
ok($zip->set_number('9890658')->is_valid_number, '宮城県刈田郡七ヶ宿町南浦畑');
ok($zip->set_number('9890661')->is_valid_number, '宮城県刈田郡七ヶ宿町坂ノ上');
ok($zip->set_number('9890662')->is_valid_number, '宮城県刈田郡七ヶ宿町赤地');
ok($zip->set_number('9890663')->is_valid_number, '宮城県刈田郡七ヶ宿町東沢');
ok($zip->set_number('9890664')->is_valid_number, '宮城県刈田郡七ヶ宿町行人原道上');
ok($zip->set_number('9890665')->is_valid_number, '宮城県刈田郡七ヶ宿町侭ノ上地蔵前');
ok($zip->set_number('9890666')->is_valid_number, '宮城県刈田郡七ヶ宿町干蒲');
ok($zip->set_number('9890667')->is_valid_number, '宮城県刈田郡七ヶ宿町水下道上');
ok($zip->set_number('9890701')->is_valid_number, '宮城県刈田郡蔵王町宮');
ok($zip->set_number('9890731')->is_valid_number, '宮城県白石市福岡深谷');
ok($zip->set_number('9890732')->is_valid_number, '宮城県白石市福岡長袋(川寺山、芹沢)');
ok($zip->set_number('9890733')->is_valid_number, '宮城県白石市福岡八宮');
ok($zip->set_number('9890734')->is_valid_number, '宮城県白石市白鳥');
ok($zip->set_number('9890800')->is_valid_number, '宮城県刈田郡蔵王町以下に掲載がない場合');
ok($zip->set_number('9890821')->is_valid_number, '宮城県刈田郡蔵王町円田(その他)');
ok($zip->set_number('9890831')->is_valid_number, '宮城県刈田郡蔵王町平沢');
ok($zip->set_number('9890841')->is_valid_number, '宮城県刈田郡蔵王町小村崎');
ok($zip->set_number('9890842')->is_valid_number, '宮城県刈田郡蔵王町塩沢');
ok($zip->set_number('9890843')->is_valid_number, '宮城県刈田郡蔵王町矢附');
ok($zip->set_number('9890851')->is_valid_number, '宮城県刈田郡蔵王町曲竹');
ok($zip->set_number('9890901')->is_valid_number, '宮城県柴田郡川崎町前川(青根、手代塚山、沼ノ平山、名号下山、権現塚、火の塚山、峩々)');
ok($zip->set_number('9890908')->is_valid_number, '宮城県柴田郡川崎町青根温泉');
ok($zip->set_number('9890911')->is_valid_number, '宮城県刈田郡蔵王町遠刈田温泉栄町');
ok($zip->set_number('9890912')->is_valid_number, '宮城県刈田郡蔵王町遠刈田温泉仲町');
ok($zip->set_number('9890913')->is_valid_number, '宮城県刈田郡蔵王町遠刈田温泉本町');
ok($zip->set_number('9890914')->is_valid_number, '宮城県刈田郡蔵王町遠刈田温泉旭町');
ok($zip->set_number('9890915')->is_valid_number, '宮城県刈田郡蔵王町遠刈田温泉寿町');
ok($zip->set_number('9890916')->is_valid_number, '宮城県刈田郡蔵王町遠刈田温泉');
ok($zip->set_number('9890921')->is_valid_number, '宮城県刈田郡蔵王町円田(釜沢、善舞森、土浮谷地、土浮山2~5番地)');
ok($zip->set_number('9891101')->is_valid_number, '宮城県白石市白川小奥');
ok($zip->set_number('9891102')->is_valid_number, '宮城県白石市白川津田');
ok($zip->set_number('9891103')->is_valid_number, '宮城県白石市白川犬卒都婆');
ok($zip->set_number('9891104')->is_valid_number, '宮城県白石市白川内親');
ok($zip->set_number('9891200')->is_valid_number, '宮城県柴田郡大河原町以下に掲載がない場合');
ok($zip->set_number('9891201')->is_valid_number, '宮城県柴田郡大河原町大谷');
ok($zip->set_number('9891202')->is_valid_number, '宮城県柴田郡大河原町高砂町');
ok($zip->set_number('9891203')->is_valid_number, '宮城県柴田郡大河原町旭町');
ok($zip->set_number('9891204')->is_valid_number, '宮城県柴田郡大河原町大竜');
ok($zip->set_number('9891205')->is_valid_number, '宮城県柴田郡大河原町大芝');
ok($zip->set_number('9891206')->is_valid_number, '宮城県柴田郡大河原町中の倉');
ok($zip->set_number('9891207')->is_valid_number, '宮城県柴田郡大河原町川瀬町');
ok($zip->set_number('9891211')->is_valid_number, '宮城県柴田郡大河原町広瀬町');
ok($zip->set_number('9891212')->is_valid_number, '宮城県柴田郡大河原町山崎町');
ok($zip->set_number('9891213')->is_valid_number, '宮城県柴田郡大河原町住吉町');
ok($zip->set_number('9891214')->is_valid_number, '宮城県柴田郡大河原町甲子町');
ok($zip->set_number('9891215')->is_valid_number, '宮城県柴田郡大河原町中島町');
ok($zip->set_number('9891216')->is_valid_number, '宮城県柴田郡大河原町幸町');
ok($zip->set_number('9891217')->is_valid_number, '宮城県柴田郡大河原町錦町');
ok($zip->set_number('9891221')->is_valid_number, '宮城県柴田郡大河原町緑町');
ok($zip->set_number('9891222')->is_valid_number, '宮城県柴田郡大河原町南平');
ok($zip->set_number('9891223')->is_valid_number, '宮城県柴田郡大河原町東新町');
ok($zip->set_number('9891224')->is_valid_number, '宮城県柴田郡大河原町金ケ瀬');
ok($zip->set_number('9891225')->is_valid_number, '宮城県柴田郡大河原町広表');
ok($zip->set_number('9891231')->is_valid_number, '宮城県柴田郡大河原町中川原');
ok($zip->set_number('9891232')->is_valid_number, '宮城県柴田郡大河原町南海道下');
ok($zip->set_number('9891233')->is_valid_number, '宮城県柴田郡大河原町上川原');
ok($zip->set_number('9891234')->is_valid_number, '宮城県柴田郡大河原町新古川');
ok($zip->set_number('9891235')->is_valid_number, '宮城県柴田郡大河原町南原町');
ok($zip->set_number('9891236')->is_valid_number, '宮城県柴田郡大河原町東原町');
ok($zip->set_number('9891237')->is_valid_number, '宮城県柴田郡大河原町荒町');
ok($zip->set_number('9891241')->is_valid_number, '宮城県柴田郡大河原町町');
ok($zip->set_number('9891242')->is_valid_number, '宮城県柴田郡大河原町西浦');
ok($zip->set_number('9891243')->is_valid_number, '宮城県柴田郡大河原町南');
ok($zip->set_number('9891244')->is_valid_number, '宮城県柴田郡大河原町西町');
ok($zip->set_number('9891245')->is_valid_number, '宮城県柴田郡大河原町新南');
ok($zip->set_number('9891246')->is_valid_number, '宮城県柴田郡大河原町新東');
ok($zip->set_number('9891247')->is_valid_number, '宮城県柴田郡大河原町東');
ok($zip->set_number('9891248')->is_valid_number, '宮城県柴田郡大河原町土手崎');
ok($zip->set_number('9891249')->is_valid_number, '宮城県柴田郡大河原町海道東');
ok($zip->set_number('9891251')->is_valid_number, '宮城県柴田郡大河原町橋本');
ok($zip->set_number('9891252')->is_valid_number, '宮城県柴田郡大河原町八乙女');
ok($zip->set_number('9891253')->is_valid_number, '宮城県柴田郡大河原町西');
ok($zip->set_number('9891254')->is_valid_number, '宮城県柴田郡大河原町沼');
ok($zip->set_number('9891255')->is_valid_number, '宮城県柴田郡大河原町袖谷地');
ok($zip->set_number('9891256')->is_valid_number, '宮城県柴田郡大河原町堤');
ok($zip->set_number('9891257')->is_valid_number, '宮城県柴田郡大河原町新寺');
ok($zip->set_number('9891258')->is_valid_number, '宮城県柴田郡大河原町小山田');
ok($zip->set_number('9891259')->is_valid_number, '宮城県柴田郡大河原町福田');
ok($zip->set_number('9891261')->is_valid_number, '宮城県柴田郡大河原町大巻');
ok($zip->set_number('9891263')->is_valid_number, '宮城県柴田郡大河原町大谷地');
ok($zip->set_number('9891264')->is_valid_number, '宮城県柴田郡大河原町新青川');
ok($zip->set_number('9891266')->is_valid_number, '宮城県柴田郡大河原町千塚前');
ok($zip->set_number('9891267')->is_valid_number, '宮城県柴田郡大河原町小島');
ok($zip->set_number('9891271')->is_valid_number, '宮城県柴田郡大河原町東桜町');
ok($zip->set_number('9891272')->is_valid_number, '宮城県柴田郡大河原町南桜町');
ok($zip->set_number('9891273')->is_valid_number, '宮城県柴田郡大河原町西桜町');
ok($zip->set_number('9891274')->is_valid_number, '宮城県柴田郡大河原町新桜町');
ok($zip->set_number('9891300')->is_valid_number, '宮城県柴田郡村田町以下に掲載がない場合');
ok($zip->set_number('9891301')->is_valid_number, '宮城県柴田郡村田町菅生');
ok($zip->set_number('9891302')->is_valid_number, '宮城県柴田郡村田町小泉');
ok($zip->set_number('9891303')->is_valid_number, '宮城県柴田郡村田町薄木');
ok($zip->set_number('9891304')->is_valid_number, '宮城県柴田郡村田町西ケ丘');
ok($zip->set_number('9891305')->is_valid_number, '宮城県柴田郡村田町村田');
ok($zip->set_number('9891311')->is_valid_number, '宮城県柴田郡村田町足立(その他)');
ok($zip->set_number('9891321')->is_valid_number, '宮城県柴田郡村田町沼辺');
ok($zip->set_number('9891322')->is_valid_number, '宮城県柴田郡村田町関場');
ok($zip->set_number('9891323')->is_valid_number, '宮城県柴田郡村田町沼田');
ok($zip->set_number('9891500')->is_valid_number, '宮城県柴田郡川崎町以下に掲載がない場合');
ok($zip->set_number('9891501')->is_valid_number, '宮城県柴田郡川崎町前川(その他)');
ok($zip->set_number('9891502')->is_valid_number, '宮城県柴田郡川崎町今宿');
ok($zip->set_number('9891503')->is_valid_number, '宮城県柴田郡川崎町川内');
ok($zip->set_number('9891504')->is_valid_number, '宮城県柴田郡川崎町本砂金');
ok($zip->set_number('9891505')->is_valid_number, '宮城県柴田郡川崎町小野');
ok($zip->set_number('9891506')->is_valid_number, '宮城県柴田郡川崎町支倉台');
ok($zip->set_number('9891507')->is_valid_number, '宮城県柴田郡川崎町支倉');
ok($zip->set_number('9891511')->is_valid_number, '宮城県柴田郡村田町足立(北向)');
ok($zip->set_number('9891600')->is_valid_number, '宮城県柴田郡柴田町以下に掲載がない場合');
ok($zip->set_number('9891601')->is_valid_number, '宮城県柴田郡柴田町船岡中央');
ok($zip->set_number('9891602')->is_valid_number, '宮城県柴田郡柴田町船岡土手内');
ok($zip->set_number('9891603')->is_valid_number, '宮城県柴田郡柴田町船岡西');
ok($zip->set_number('9891604')->is_valid_number, '宮城県柴田郡柴田町船岡東');
ok($zip->set_number('9891605')->is_valid_number, '宮城県柴田郡柴田町船岡南');
ok($zip->set_number('9891606')->is_valid_number, '宮城県柴田郡柴田町船岡');
ok($zip->set_number('9891607')->is_valid_number, '宮城県柴田郡柴田町船岡新栄');
ok($zip->set_number('9891608')->is_valid_number, '宮城県柴田郡柴田町剣崎');
ok($zip->set_number('9891611')->is_valid_number, '宮城県柴田郡柴田町上名生');
ok($zip->set_number('9891612')->is_valid_number, '宮城県柴田郡柴田町中名生');
ok($zip->set_number('9891613')->is_valid_number, '宮城県柴田郡柴田町下名生');
ok($zip->set_number('9891621')->is_valid_number, '宮城県柴田郡柴田町本船迫');
ok($zip->set_number('9891622')->is_valid_number, '宮城県柴田郡柴田町西船迫');
ok($zip->set_number('9891623')->is_valid_number, '宮城県柴田郡柴田町北船岡');
ok($zip->set_number('9891631')->is_valid_number, '宮城県柴田郡柴田町東船迫(2丁目)');
ok($zip->set_number('9891731')->is_valid_number, '宮城県柴田郡柴田町東船迫(1丁目)');
ok($zip->set_number('9891741')->is_valid_number, '宮城県柴田郡柴田町富沢');
ok($zip->set_number('9891742')->is_valid_number, '宮城県柴田郡柴田町上川名');
ok($zip->set_number('9891743')->is_valid_number, '宮城県柴田郡柴田町四日市場');
ok($zip->set_number('9891744')->is_valid_number, '宮城県柴田郡柴田町松ケ越');
ok($zip->set_number('9891745')->is_valid_number, '宮城県柴田郡柴田町入間田');
ok($zip->set_number('9891746')->is_valid_number, '宮城県柴田郡柴田町ゆずが丘');
ok($zip->set_number('9891751')->is_valid_number, '宮城県柴田郡柴田町槻木新町');
ok($zip->set_number('9891752')->is_valid_number, '宮城県柴田郡柴田町槻木下町');
ok($zip->set_number('9891753')->is_valid_number, '宮城県柴田郡柴田町槻木上町');
ok($zip->set_number('9891754')->is_valid_number, '宮城県柴田郡柴田町槻木白幡');
ok($zip->set_number('9891755')->is_valid_number, '宮城県柴田郡柴田町槻木西');
ok($zip->set_number('9891756')->is_valid_number, '宮城県柴田郡柴田町槻木');
ok($zip->set_number('9891757')->is_valid_number, '宮城県柴田郡柴田町槻木東');
ok($zip->set_number('9891758')->is_valid_number, '宮城県柴田郡柴田町槻木駅西');
ok($zip->set_number('9891761')->is_valid_number, '宮城県柴田郡柴田町葉坂');
ok($zip->set_number('9891762')->is_valid_number, '宮城県柴田郡柴田町海老穴');
ok($zip->set_number('9891763')->is_valid_number, '宮城県柴田郡柴田町船迫');
ok($zip->set_number('9891764')->is_valid_number, '宮城県柴田郡柴田町小成田');
ok($zip->set_number('9891765')->is_valid_number, '宮城県柴田郡柴田町成田');
ok($zip->set_number('9892111')->is_valid_number, '宮城県亘理郡山元町坂元');
ok($zip->set_number('9892112')->is_valid_number, '宮城県亘理郡山元町真庭');
ok($zip->set_number('9892200')->is_valid_number, '宮城県亘理郡山元町以下に掲載がない場合');
ok($zip->set_number('9892201')->is_valid_number, '宮城県亘理郡山元町山寺');
ok($zip->set_number('9892202')->is_valid_number, '宮城県亘理郡山元町高瀬');
ok($zip->set_number('9892203')->is_valid_number, '宮城県亘理郡山元町浅生原');
ok($zip->set_number('9892204')->is_valid_number, '宮城県亘理郡山元町鷲足');
ok($zip->set_number('9892205')->is_valid_number, '宮城県亘理郡山元町小平');
ok($zip->set_number('9892206')->is_valid_number, '宮城県亘理郡山元町大平');
ok($zip->set_number('9892207')->is_valid_number, '宮城県亘理郡山元町八手庭');
ok($zip->set_number('9892208')->is_valid_number, '宮城県亘理郡山元町つばめの杜');
ok($zip->set_number('9892300')->is_valid_number, '宮城県亘理郡亘理町以下に掲載がない場合');
ok($zip->set_number('9892301')->is_valid_number, '宮城県亘理郡亘理町逢隈中泉');
ok($zip->set_number('9892302')->is_valid_number, '宮城県亘理郡亘理町逢隈牛袋');
ok($zip->set_number('9892303')->is_valid_number, '宮城県亘理郡亘理町逢隈十文字');
ok($zip->set_number('9892311')->is_valid_number, '宮城県亘理郡亘理町荒浜');
ok($zip->set_number('9892321')->is_valid_number, '宮城県亘理郡亘理町逢隈榎袋');
ok($zip->set_number('9892322')->is_valid_number, '宮城県亘理郡亘理町逢隈蕨');
ok($zip->set_number('9892323')->is_valid_number, '宮城県亘理郡亘理町逢隈鷺屋');
ok($zip->set_number('9892324')->is_valid_number, '宮城県亘理郡亘理町逢隈高屋');
ok($zip->set_number('9892325')->is_valid_number, '宮城県亘理郡亘理町花苺');
ok($zip->set_number('9892331')->is_valid_number, '宮城県亘理郡亘理町吉田');
ok($zip->set_number('9892332')->is_valid_number, '宮城県亘理郡亘理町苺浜');
ok($zip->set_number('9892333')->is_valid_number, '宮城県亘理郡亘理町苺里');
ok($zip->set_number('9892341')->is_valid_number, '宮城県亘理郡亘理町長瀞');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町旭');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町旭山');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町油田');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町五日町');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町祝田');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町裏城戸');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町江下');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町上中野地');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町上浜街道');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町上茨田');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町亀井戸');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町上町');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町北新田');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町北新町');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町狐塚');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町旧舘');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町境堤');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町桜小路');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町芝西');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町下小路');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町下浜街道');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町下茨田');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町新町');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町台田');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町道田中');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町道田東');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町道田西');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町中町');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町中町東');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町新井町');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町西郷');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町茨田後');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町東郷');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町見田内');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町南町');
ok($zip->set_number('9892351')->is_valid_number, '宮城県亘理郡亘理町南町東');
ok($zip->set_number('9892352')->is_valid_number, '宮城県亘理郡亘理町悠里');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町愛宕前');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町泉ケ入');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町北猿田');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町倉庭');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町先達前');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町舘南');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町鳥居前');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町沼頭');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町卑下入');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町堀の内');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町雪穴');
ok($zip->set_number('9892361')->is_valid_number, '宮城県亘理郡亘理町龍円寺前');
ok($zip->set_number('9892371')->is_valid_number, '宮城県亘理郡亘理町逢隈鹿島');
ok($zip->set_number('9892372')->is_valid_number, '宮城県亘理郡亘理町逢隈神宮寺');
ok($zip->set_number('9892381')->is_valid_number, '宮城県亘理郡亘理町逢隈上郡');
ok($zip->set_number('9892382')->is_valid_number, '宮城県亘理郡亘理町逢隈下郡');
ok($zip->set_number('9892383')->is_valid_number, '宮城県亘理郡亘理町逢隈田沢');
ok($zip->set_number('9892384')->is_valid_number, '宮城県亘理郡亘理町逢隈小山');
ok($zip->set_number('9892385')->is_valid_number, '宮城県亘理郡亘理町逢隈(郡)');
ok($zip->set_number('9892400')->is_valid_number, '宮城県岩沼市以下に掲載がない場合');
ok($zip->set_number('9892401')->is_valid_number, '宮城県名取市下増田(南原無番地、仙台空港関係施設)');
ok($zip->set_number('9892411')->is_valid_number, '宮城県名取市本郷');
ok($zip->set_number('9892412')->is_valid_number, '宮城県名取市堀内');
ok($zip->set_number('9892420')->is_valid_number, '宮城県岩沼市空港西');
ok($zip->set_number('9892421')->is_valid_number, '宮城県岩沼市下野郷');
ok($zip->set_number('9892422')->is_valid_number, '宮城県岩沼市空港南');
ok($zip->set_number('9892423')->is_valid_number, '宮城県岩沼市押分');
ok($zip->set_number('9892424')->is_valid_number, '宮城県岩沼市早股');
ok($zip->set_number('9892425')->is_valid_number, '宮城県岩沼市寺島');
ok($zip->set_number('9892426')->is_valid_number, '宮城県岩沼市末広');
ok($zip->set_number('9892427')->is_valid_number, '宮城県岩沼市里の杜');
ok($zip->set_number('9892428')->is_valid_number, '宮城県岩沼市玉浦西');
ok($zip->set_number('9892429')->is_valid_number, '宮城県岩沼市恵み野');
ok($zip->set_number('9892431')->is_valid_number, '宮城県岩沼市相の原');
ok($zip->set_number('9892432')->is_valid_number, '宮城県岩沼市中央');
ok($zip->set_number('9892433')->is_valid_number, '宮城県岩沼市桜');
ok($zip->set_number('9892434')->is_valid_number, '宮城県岩沼市藤浪');
ok($zip->set_number('9892435')->is_valid_number, '宮城県岩沼市阿武隈');
ok($zip->set_number('9892436')->is_valid_number, '宮城県岩沼市吹上');
ok($zip->set_number('9892437')->is_valid_number, '宮城県岩沼市吹上西');
ok($zip->set_number('9892441')->is_valid_number, '宮城県岩沼市館下');
ok($zip->set_number('9892442')->is_valid_number, '宮城県岩沼市大手町');
ok($zip->set_number('9892443')->is_valid_number, '宮城県岩沼市稲荷町');
ok($zip->set_number('9892444')->is_valid_number, '宮城県岩沼市本町');
ok($zip->set_number('9892445')->is_valid_number, '宮城県岩沼市桑原');
ok($zip->set_number('9892446')->is_valid_number, '宮城県岩沼市西六角');
ok($zip->set_number('9892447')->is_valid_number, '宮城県岩沼市桑原西');
ok($zip->set_number('9892448')->is_valid_number, '宮城県岩沼市二木');
ok($zip->set_number('9892451')->is_valid_number, '宮城県岩沼市土ケ崎');
ok($zip->set_number('9892452')->is_valid_number, '宮城県岩沼市武隈');
ok($zip->set_number('9892453')->is_valid_number, '宮城県岩沼市大昭和');
ok($zip->set_number('9892454')->is_valid_number, '宮城県岩沼市南長谷');
ok($zip->set_number('9892455')->is_valid_number, '宮城県岩沼市北長谷');
ok($zip->set_number('9892456')->is_valid_number, '宮城県岩沼市松ケ丘');
ok($zip->set_number('9892457')->is_valid_number, '宮城県岩沼市平等');
ok($zip->set_number('9892458')->is_valid_number, '宮城県岩沼市竹の里');
ok($zip->set_number('9892459')->is_valid_number, '宮城県岩沼市たけくま');
ok($zip->set_number('9892461')->is_valid_number, '宮城県岩沼市長岡');
ok($zip->set_number('9892462')->is_valid_number, '宮城県岩沼市山桜');
ok($zip->set_number('9892463')->is_valid_number, '宮城県岩沼市荒井');
ok($zip->set_number('9892464')->is_valid_number, '宮城県岩沼市三色吉');
ok($zip->set_number('9892465')->is_valid_number, '宮城県岩沼市志賀');
ok($zip->set_number('9892471')->is_valid_number, '宮城県岩沼市小川');
ok($zip->set_number('9892472')->is_valid_number, '宮城県岩沼市梶橋');
ok($zip->set_number('9892473')->is_valid_number, '宮城県岩沼市栄町');
ok($zip->set_number('9892474')->is_valid_number, '宮城県岩沼市朝日');
ok($zip->set_number('9892475')->is_valid_number, '宮城県岩沼市大和');
ok($zip->set_number('9892476')->is_valid_number, '宮城県岩沼市敷島');
ok($zip->set_number('9892477')->is_valid_number, '宮城県岩沼市東谷地');
ok($zip->set_number('9892478')->is_valid_number, '宮城県岩沼市あさひ野');
ok($zip->set_number('9893121')->is_valid_number, '宮城県仙台市青葉区郷六');
ok($zip->set_number('9893122')->is_valid_number, '宮城県仙台市青葉区栗生');
ok($zip->set_number('9893123')->is_valid_number, '宮城県仙台市青葉区錦ケ丘');
ok($zip->set_number('9893124')->is_valid_number, '宮城県仙台市青葉区上愛子');
ok($zip->set_number('9893125')->is_valid_number, '宮城県仙台市青葉区下愛子');
ok($zip->set_number('9893126')->is_valid_number, '宮城県仙台市青葉区落合');
ok($zip->set_number('9893127')->is_valid_number, '宮城県仙台市青葉区愛子東');
ok($zip->set_number('9893128')->is_valid_number, '宮城県仙台市青葉区愛子中央');
ok($zip->set_number('9893201')->is_valid_number, '宮城県仙台市青葉区国見ケ丘');
ok($zip->set_number('9893202')->is_valid_number, '宮城県仙台市青葉区中山台');
ok($zip->set_number('9893203')->is_valid_number, '宮城県仙台市青葉区中山吉成');
ok($zip->set_number('9893204')->is_valid_number, '宮城県仙台市青葉区南吉成');
ok($zip->set_number('9893205')->is_valid_number, '宮城県仙台市青葉区吉成');
ok($zip->set_number('9893206')->is_valid_number, '宮城県仙台市青葉区吉成台');
ok($zip->set_number('9893207')->is_valid_number, '宮城県仙台市青葉区中山台西');
ok($zip->set_number('9893211')->is_valid_number, '宮城県仙台市青葉区赤坂');
ok($zip->set_number('9893212')->is_valid_number, '宮城県仙台市青葉区芋沢');
ok($zip->set_number('9893213')->is_valid_number, '宮城県仙台市青葉区大倉');
ok($zip->set_number('9893214')->is_valid_number, '宮城県仙台市青葉区みやぎ台');
ok($zip->set_number('9893215')->is_valid_number, '宮城県仙台市青葉区向田');
ok($zip->set_number('9893216')->is_valid_number, '宮城県仙台市青葉区高野原');
ok($zip->set_number('9893431')->is_valid_number, '宮城県仙台市青葉区作並');
ok($zip->set_number('9893432')->is_valid_number, '宮城県仙台市青葉区熊ケ根');
ok($zip->set_number('9893433')->is_valid_number, '宮城県仙台市青葉区ニツカ');
ok($zip->set_number('9893434')->is_valid_number, '宮城県仙台市青葉区新川');
ok($zip->set_number('9894101')->is_valid_number, '宮城県大崎市鹿島台船越');
ok($zip->set_number('9894102')->is_valid_number, '宮城県大崎市鹿島台木間塚');
ok($zip->set_number('9894103')->is_valid_number, '宮城県大崎市鹿島台平渡');
ok($zip->set_number('9894104')->is_valid_number, '宮城県大崎市鹿島台広長');
ok($zip->set_number('9894105')->is_valid_number, '宮城県大崎市鹿島台深谷');
ok($zip->set_number('9894106')->is_valid_number, '宮城県大崎市鹿島台大迫');
ok($zip->set_number('9894201')->is_valid_number, '宮城県遠田郡美里町和多田沼');
ok($zip->set_number('9894202')->is_valid_number, '宮城県遠田郡美里町福ケ袋');
ok($zip->set_number('9894203')->is_valid_number, '宮城県遠田郡美里町練牛');
ok($zip->set_number('9894204')->is_valid_number, '宮城県遠田郡美里町大柳');
ok($zip->set_number('9894205')->is_valid_number, '宮城県遠田郡美里町木間塚');
ok($zip->set_number('9894206')->is_valid_number, '宮城県遠田郡美里町二郷');
ok($zip->set_number('9894207')->is_valid_number, '宮城県遠田郡美里町鳥谷坂一');
ok($zip->set_number('9894208')->is_valid_number, '宮城県遠田郡美里町鳥谷坂二');
ok($zip->set_number('9894209')->is_valid_number, '宮城県遠田郡美里町新鳥谷坂');
ok($zip->set_number('9894301')->is_valid_number, '宮城県大崎市田尻蕪栗');
ok($zip->set_number('9894302')->is_valid_number, '宮城県大崎市田尻大貫');
ok($zip->set_number('9894303')->is_valid_number, '宮城県大崎市田尻大沢');
ok($zip->set_number('9894304')->is_valid_number, '宮城県大崎市田尻北小牛田');
ok($zip->set_number('9894305')->is_valid_number, '宮城県大崎市田尻小塩');
ok($zip->set_number('9894306')->is_valid_number, '宮城県大崎市田尻桜田高野');
ok($zip->set_number('9894307')->is_valid_number, '宮城県大崎市田尻北高城');
ok($zip->set_number('9894308')->is_valid_number, '宮城県大崎市田尻沼部');
ok($zip->set_number('9894411')->is_valid_number, '宮城県大崎市田尻八幡');
ok($zip->set_number('9894412')->is_valid_number, '宮城県大崎市田尻大嶺');
ok($zip->set_number('9894413')->is_valid_number, '宮城県大崎市田尻通木');
ok($zip->set_number('9894414')->is_valid_number, '宮城県大崎市田尻北牧目');
ok($zip->set_number('9894415')->is_valid_number, '宮城県大崎市田尻');
ok($zip->set_number('9894416')->is_valid_number, '宮城県大崎市田尻中目');
ok($zip->set_number('9894417')->is_valid_number, '宮城県大崎市田尻沼木');
ok($zip->set_number('9894418')->is_valid_number, '宮城県大崎市田尻諏訪峠');
ok($zip->set_number('9894419')->is_valid_number, '宮城県大崎市田尻小松');
ok($zip->set_number('9894503')->is_valid_number, '宮城県栗原市瀬峰力石');
ok($zip->set_number('9894504')->is_valid_number, '宮城県栗原市瀬峰小深沢');
ok($zip->set_number('9894505')->is_valid_number, '宮城県栗原市瀬峰刈安沢');
ok($zip->set_number('9894506')->is_valid_number, '宮城県栗原市瀬峰清水沢');
ok($zip->set_number('9894507')->is_valid_number, '宮城県栗原市瀬峰西原');
ok($zip->set_number('9894508')->is_valid_number, '宮城県栗原市瀬峰柴ノ脇');
ok($zip->set_number('9894509')->is_valid_number, '宮城県栗原市瀬峰大鰐谷');
ok($zip->set_number('9894510')->is_valid_number, '宮城県栗原市瀬峰新下藤沢');
ok($zip->set_number('9894511')->is_valid_number, '宮城県栗原市瀬峰新田沢');
ok($zip->set_number('9894512')->is_valid_number, '宮城県栗原市瀬峰下藤沢');
ok($zip->set_number('9894513')->is_valid_number, '宮城県栗原市瀬峰根岸');
ok($zip->set_number('9894514')->is_valid_number, '宮城県栗原市瀬峰桃生田前');
ok($zip->set_number('9894515')->is_valid_number, '宮城県栗原市瀬峰桃生田');
ok($zip->set_number('9894516')->is_valid_number, '宮城県栗原市瀬峰長者原');
ok($zip->set_number('9894517')->is_valid_number, '宮城県栗原市瀬峰藤沢瀬嶺');
ok($zip->set_number('9894518')->is_valid_number, '宮城県栗原市瀬峰荒神堂');
ok($zip->set_number('9894519')->is_valid_number, '宮城県栗原市瀬峰横森前');
ok($zip->set_number('9894521')->is_valid_number, '宮城県栗原市瀬峰下田');
ok($zip->set_number('9894522')->is_valid_number, '宮城県栗原市瀬峰下の前');
ok($zip->set_number('9894523')->is_valid_number, '宮城県栗原市瀬峰北谷地');
ok($zip->set_number('9894524')->is_valid_number, '宮城県栗原市瀬峰藤田');
ok($zip->set_number('9894525')->is_valid_number, '宮城県栗原市瀬峰下谷地');
ok($zip->set_number('9894526')->is_valid_number, '宮城県栗原市瀬峰宮小路原西');
ok($zip->set_number('9894527')->is_valid_number, '宮城県栗原市瀬峰宮小路原東');
ok($zip->set_number('9894528')->is_valid_number, '宮城県栗原市瀬峰山崎前');
ok($zip->set_number('9894529')->is_valid_number, '宮城県栗原市瀬峰新下田');
ok($zip->set_number('9894531')->is_valid_number, '宮城県栗原市瀬峰筒ケ崎');
ok($zip->set_number('9894532')->is_valid_number, '宮城県栗原市瀬峰樋口山');
ok($zip->set_number('9894533')->is_valid_number, '宮城県栗原市瀬峰愛宕');
ok($zip->set_number('9894534')->is_valid_number, '宮城県栗原市瀬峰泉谷');
ok($zip->set_number('9894535')->is_valid_number, '宮城県栗原市瀬峰泉谷南');
ok($zip->set_number('9894536')->is_valid_number, '宮城県栗原市瀬峰壇ノ越');
ok($zip->set_number('9894537')->is_valid_number, '宮城県栗原市瀬峰船橋');
ok($zip->set_number('9894538')->is_valid_number, '宮城県栗原市瀬峰諏訪原');
ok($zip->set_number('9894539')->is_valid_number, '宮城県栗原市瀬峰二ツ谷');
ok($zip->set_number('9894540')->is_valid_number, '宮城県栗原市瀬峰牛渕前');
ok($zip->set_number('9894541')->is_valid_number, '宮城県栗原市瀬峰牛渕');
ok($zip->set_number('9894542')->is_valid_number, '宮城県栗原市瀬峰新井堀');
ok($zip->set_number('9894543')->is_valid_number, '宮城県栗原市瀬峰新井屋敷');
ok($zip->set_number('9894544')->is_valid_number, '宮城県栗原市瀬峰除');
ok($zip->set_number('9894545')->is_valid_number, '宮城県栗原市瀬峰伊勢堂');
ok($zip->set_number('9894546')->is_valid_number, '宮城県栗原市瀬峰四ツ壇');
ok($zip->set_number('9894547')->is_valid_number, '宮城県栗原市瀬峰神田');
ok($zip->set_number('9894548')->is_valid_number, '宮城県栗原市瀬峰長根');
ok($zip->set_number('9894549')->is_valid_number, '宮城県栗原市瀬峰荒町');
ok($zip->set_number('9894551')->is_valid_number, '宮城県栗原市瀬峰三代');
ok($zip->set_number('9894552')->is_valid_number, '宮城県栗原市瀬峰宮田');
ok($zip->set_number('9894553')->is_valid_number, '宮城県栗原市瀬峰二又');
ok($zip->set_number('9894554')->is_valid_number, '宮城県栗原市瀬峰原田');
ok($zip->set_number('9894555')->is_valid_number, '宮城県栗原市瀬峰野沢');
ok($zip->set_number('9894556')->is_valid_number, '宮城県栗原市瀬峰袋沢');
ok($zip->set_number('9894557')->is_valid_number, '宮城県栗原市瀬峰上沢田');
ok($zip->set_number('9894560')->is_valid_number, '宮城県栗原市瀬峰新道東');
ok($zip->set_number('9894561')->is_valid_number, '宮城県栗原市瀬峰樋渡');
ok($zip->set_number('9894562')->is_valid_number, '宮城県栗原市瀬峰川ノ畑');
ok($zip->set_number('9894563')->is_valid_number, '宮城県栗原市瀬峰上富前');
ok($zip->set_number('9894564')->is_valid_number, '宮城県栗原市瀬峰谷地田');
ok($zip->set_number('9894565')->is_valid_number, '宮城県栗原市瀬峰天神下');
ok($zip->set_number('9894566')->is_valid_number, '宮城県栗原市瀬峰上屋敷');
ok($zip->set_number('9894567')->is_valid_number, '宮城県栗原市瀬峰西原前');
ok($zip->set_number('9894568')->is_valid_number, '宮城県栗原市瀬峰大屋敷');
ok($zip->set_number('9894569')->is_valid_number, '宮城県栗原市瀬峰筒場');
ok($zip->set_number('9894570')->is_valid_number, '宮城県栗原市瀬峰町田前');
ok($zip->set_number('9894571')->is_valid_number, '宮城県栗原市瀬峰寺沢');
ok($zip->set_number('9894572')->is_valid_number, '宮城県栗原市瀬峰寺浦');
ok($zip->set_number('9894573')->is_valid_number, '宮城県栗原市瀬峰十王堂前');
ok($zip->set_number('9894574')->is_valid_number, '宮城県栗原市瀬峰北ノ沢');
ok($zip->set_number('9894575')->is_valid_number, '宮城県栗原市瀬峰町田');
ok($zip->set_number('9894576')->is_valid_number, '宮城県栗原市瀬峰高土山');
ok($zip->set_number('9894577')->is_valid_number, '宮城県栗原市瀬峰薬沢西');
ok($zip->set_number('9894578')->is_valid_number, '宮城県栗原市瀬峰薬沢東');
ok($zip->set_number('9894579')->is_valid_number, '宮城県栗原市瀬峰橋本浦');
ok($zip->set_number('9894580')->is_valid_number, '宮城県栗原市瀬峰大境前');
ok($zip->set_number('9894581')->is_valid_number, '宮城県栗原市瀬峰藤沢要害');
ok($zip->set_number('9894582')->is_valid_number, '宮城県栗原市瀬峰坂ノ下浦');
ok($zip->set_number('9894583')->is_valid_number, '宮城県栗原市瀬峰大境山');
ok($zip->set_number('9894584')->is_valid_number, '宮城県栗原市瀬峰清水山');
ok($zip->set_number('9894585')->is_valid_number, '宮城県栗原市瀬峰坂ノ下前北');
ok($zip->set_number('9894586')->is_valid_number, '宮城県栗原市瀬峰蔵王');
ok($zip->set_number('9894587')->is_valid_number, '宮城県栗原市瀬峰薬師堂前');
ok($zip->set_number('9894588')->is_valid_number, '宮城県栗原市瀬峰蒲盛');
ok($zip->set_number('9894589')->is_valid_number, '宮城県栗原市瀬峰富要害');
ok($zip->set_number('9894601')->is_valid_number, '宮城県登米市迫町新田');
ok($zip->set_number('9894701')->is_valid_number, '宮城県登米市石越町北郷');
ok($zip->set_number('9894702')->is_valid_number, '宮城県登米市石越町東郷');
ok($zip->set_number('9894703')->is_valid_number, '宮城県登米市石越町南郷');
ok($zip->set_number('9894802')->is_valid_number, '宮城県栗原市金成末野');
ok($zip->set_number('9894803')->is_valid_number, '宮城県栗原市金成藤渡戸');
ok($zip->set_number('9894805')->is_valid_number, '宮城県栗原市金成片馬合');
ok($zip->set_number('9894806')->is_valid_number, '宮城県栗原市金成有壁');
ok($zip->set_number('9894807')->is_valid_number, '宮城県栗原市金成赤児');
ok($zip->set_number('9894808')->is_valid_number, '宮城県栗原市金成普賢堂');
ok($zip->set_number('9895111')->is_valid_number, '宮城県栗原市金成日向');
ok($zip->set_number('9895112')->is_valid_number, '宮城県栗原市金成宇南崎');
ok($zip->set_number('9895113')->is_valid_number, '宮城県栗原市金成宮前');
ok($zip->set_number('9895114')->is_valid_number, '宮城県栗原市金成下富田');
ok($zip->set_number('9895115')->is_valid_number, '宮城県栗原市金成上富田');
ok($zip->set_number('9895116')->is_valid_number, '宮城県栗原市金成大梨');
ok($zip->set_number('9895117')->is_valid_number, '宮城県栗原市金成柧木沢');
ok($zip->set_number('9895118')->is_valid_number, '宮城県栗原市金成入ノ沢');
ok($zip->set_number('9895119')->is_valid_number, '宮城県栗原市金成狼ノ沢');
ok($zip->set_number('9895121')->is_valid_number, '宮城県栗原市金成大平');
ok($zip->set_number('9895122')->is_valid_number, '宮城県栗原市金成三沢');
ok($zip->set_number('9895123')->is_valid_number, '宮城県栗原市金成平治屋敷');
ok($zip->set_number('9895124')->is_valid_number, '宮城県栗原市金成山中堤下');
ok($zip->set_number('9895125')->is_valid_number, '宮城県栗原市金成大林寺沢');
ok($zip->set_number('9895126')->is_valid_number, '宮城県栗原市金成鍔ノ瓦');
ok($zip->set_number('9895127')->is_valid_number, '宮城県栗原市金成稲荷前');
ok($zip->set_number('9895128')->is_valid_number, '宮城県栗原市金成金山沢');
ok($zip->set_number('9895130')->is_valid_number, '宮城県栗原市金成清水田');
ok($zip->set_number('9895131')->is_valid_number, '宮城県栗原市金成日向田');
ok($zip->set_number('9895132')->is_valid_number, '宮城県栗原市金成干谷沢');
ok($zip->set_number('9895133')->is_valid_number, '宮城県栗原市金成新町');
ok($zip->set_number('9895134')->is_valid_number, '宮城県栗原市金成新町裏');
ok($zip->set_number('9895135')->is_valid_number, '宮城県栗原市金成台畑');
ok($zip->set_number('9895136')->is_valid_number, '宮城県栗原市金成熊ノ下');
ok($zip->set_number('9895137')->is_valid_number, '宮城県栗原市金成髪長');
ok($zip->set_number('9895138')->is_valid_number, '宮城県栗原市金成翁沢');
ok($zip->set_number('9895139')->is_valid_number, '宮城県栗原市金成黄金田');
ok($zip->set_number('9895141')->is_valid_number, '宮城県栗原市金成翁留');
ok($zip->set_number('9895142')->is_valid_number, '宮城県栗原市金成入生田');
ok($zip->set_number('9895143')->is_valid_number, '宮城県栗原市金成奉公田');
ok($zip->set_number('9895144')->is_valid_number, '宮城県栗原市金成中町');
ok($zip->set_number('9895145')->is_valid_number, '宮城県栗原市金成中町西裏');
ok($zip->set_number('9895146')->is_valid_number, '宮城県栗原市金成祝');
ok($zip->set_number('9895151')->is_valid_number, '宮城県栗原市金成桜町');
ok($zip->set_number('9895152')->is_valid_number, '宮城県栗原市金成四ツ屋敷');
ok($zip->set_number('9895153')->is_valid_number, '宮城県栗原市金成上町東裏');
ok($zip->set_number('9895154')->is_valid_number, '宮城県栗原市金成上町');
ok($zip->set_number('9895155')->is_valid_number, '宮城県栗原市金成上町西裏');
ok($zip->set_number('9895161')->is_valid_number, '宮城県栗原市金成館下');
ok($zip->set_number('9895162')->is_valid_number, '宮城県栗原市金成長根沢');
ok($zip->set_number('9895163')->is_valid_number, '宮城県栗原市金成大久保沢');
ok($zip->set_number('9895164')->is_valid_number, '宮城県栗原市金成金生');
ok($zip->set_number('9895165')->is_valid_number, '宮城県栗原市金成長館');
ok($zip->set_number('9895166')->is_valid_number, '宮城県栗原市金成長根前');
ok($zip->set_number('9895171')->is_valid_number, '宮城県栗原市金成沢辺');
ok($zip->set_number('9895172')->is_valid_number, '宮城県栗原市金成姉歯');
ok($zip->set_number('9895173')->is_valid_number, '宮城県栗原市金成梨崎');
ok($zip->set_number('9895181')->is_valid_number, '宮城県栗原市金成津久毛');
ok($zip->set_number('9895183')->is_valid_number, '宮城県栗原市金成小堤');
ok($zip->set_number('9895184')->is_valid_number, '宮城県栗原市金成小迫');
ok($zip->set_number('9895185')->is_valid_number, '宮城県栗原市金成大原木');
ok($zip->set_number('9895301')->is_valid_number, '宮城県栗原市栗駒岩ケ崎');
ok($zip->set_number('9895311')->is_valid_number, '宮城県栗原市栗駒里谷');
ok($zip->set_number('9895312')->is_valid_number, '宮城県栗原市栗駒猿飛来');
ok($zip->set_number('9895321')->is_valid_number, '宮城県栗原市栗駒栗原');
ok($zip->set_number('9895322')->is_valid_number, '宮城県栗原市栗駒桜田');
ok($zip->set_number('9895323')->is_valid_number, '宮城県栗原市栗駒菱沼');
ok($zip->set_number('9895324')->is_valid_number, '宮城県栗原市栗駒八幡');
ok($zip->set_number('9895331')->is_valid_number, '宮城県栗原市栗駒泉沢');
ok($zip->set_number('9895332')->is_valid_number, '宮城県栗原市栗駒芋埣');
ok($zip->set_number('9895333')->is_valid_number, '宮城県栗原市栗駒片子沢');
ok($zip->set_number('9895334')->is_valid_number, '宮城県栗原市栗駒嶺崎');
ok($zip->set_number('9895335')->is_valid_number, '宮城県栗原市栗駒渡丸');
ok($zip->set_number('9895341')->is_valid_number, '宮城県栗原市栗駒稲屋敷');
ok($zip->set_number('9895351')->is_valid_number, '宮城県栗原市栗駒中野');
ok($zip->set_number('9895361')->is_valid_number, '宮城県栗原市栗駒文字');
ok($zip->set_number('9895371')->is_valid_number, '宮城県栗原市栗駒沼倉');
ok($zip->set_number('9895372')->is_valid_number, '宮城県栗原市栗駒松倉');
ok($zip->set_number('9895381')->is_valid_number, '宮城県栗原市栗駒鳥沢');
ok($zip->set_number('9895382')->is_valid_number, '宮城県栗原市栗駒深谷');
ok($zip->set_number('9895401')->is_valid_number, '宮城県栗原市鶯沢袋');
ok($zip->set_number('9895402')->is_valid_number, '宮城県栗原市鶯沢南郷');
ok($zip->set_number('9895403')->is_valid_number, '宮城県栗原市鶯沢北郷');
ok($zip->set_number('9895501')->is_valid_number, '宮城県栗原市若柳川北');
ok($zip->set_number('9895502')->is_valid_number, '宮城県栗原市若柳川南');
ok($zip->set_number('9895503')->is_valid_number, '宮城県栗原市若柳下畑岡');
ok($zip->set_number('9895504')->is_valid_number, '宮城県栗原市若柳上畑岡');
ok($zip->set_number('9895505')->is_valid_number, '宮城県栗原市若柳福岡');
ok($zip->set_number('9895506')->is_valid_number, '宮城県栗原市若柳大林');
ok($zip->set_number('9895507')->is_valid_number, '宮城県栗原市若柳有賀');
ok($zip->set_number('9895508')->is_valid_number, '宮城県栗原市若柳武鎗');
ok($zip->set_number('9895509')->is_valid_number, '宮城県栗原市若柳大林新寺浦');
ok($zip->set_number('9895601')->is_valid_number, '宮城県栗原市志波姫刈敷');
ok($zip->set_number('9895602')->is_valid_number, '宮城県栗原市志波姫城内南');
ok($zip->set_number('9895603')->is_valid_number, '宮城県栗原市志波姫伊豆野');
ok($zip->set_number('9895604')->is_valid_number, '宮城県栗原市志波姫大門南');
ok($zip->set_number('9895605')->is_valid_number, '宮城県栗原市志波姫北郷');
ok($zip->set_number('9895606')->is_valid_number, '宮城県栗原市志波姫荒町南');
ok($zip->set_number('9895607')->is_valid_number, '宮城県栗原市志波姫蔵場南');
ok($zip->set_number('9895608')->is_valid_number, '宮城県栗原市志波姫荒町北');
ok($zip->set_number('9895609')->is_valid_number, '宮城県栗原市志波姫花崎西');
ok($zip->set_number('9895610')->is_valid_number, '宮城県栗原市志波姫要害東');
ok($zip->set_number('9895611')->is_valid_number, '宮城県栗原市志波姫南郷');
ok($zip->set_number('9895612')->is_valid_number, '宮城県栗原市志波姫新熊谷');
ok($zip->set_number('9895613')->is_valid_number, '宮城県栗原市志波姫新沼崎');
ok($zip->set_number('9895614')->is_valid_number, '宮城県栗原市志波姫新原');
ok($zip->set_number('9895615')->is_valid_number, '宮城県栗原市志波姫沼崎');
ok($zip->set_number('9895616')->is_valid_number, '宮城県栗原市志波姫新上戸');
ok($zip->set_number('9895617')->is_valid_number, '宮城県栗原市志波姫新橋本');
ok($zip->set_number('9895618')->is_valid_number, '宮城県栗原市志波姫新八樟');
ok($zip->set_number('9895619')->is_valid_number, '宮城県栗原市志波姫横峰浦');
ok($zip->set_number('9895621')->is_valid_number, '宮城県栗原市志波姫下里');
ok($zip->set_number('9895622')->is_valid_number, '宮城県栗原市志波姫八樟');
ok($zip->set_number('9895623')->is_valid_number, '宮城県栗原市志波姫南八樟');
ok($zip->set_number('9895624')->is_valid_number, '宮城県栗原市志波姫南堀口');
ok($zip->set_number('9895625')->is_valid_number, '宮城県栗原市志波姫堀口');
ok($zip->set_number('9895626')->is_valid_number, '宮城県栗原市志波姫中沖');
ok($zip->set_number('9895627')->is_valid_number, '宮城県栗原市志波姫北堀口');
ok($zip->set_number('9896100')->is_valid_number, '宮城県大崎市以下に掲載がない場合');
ok($zip->set_number('9896101')->is_valid_number, '宮城県大崎市古川福浦');
ok($zip->set_number('9896102')->is_valid_number, '宮城県大崎市古川江合本町');
ok($zip->set_number('9896103')->is_valid_number, '宮城県大崎市古川江合寿町');
ok($zip->set_number('9896104')->is_valid_number, '宮城県大崎市古川江合錦町');
ok($zip->set_number('9896105')->is_valid_number, '宮城県大崎市古川福沼');
ok($zip->set_number('9896106')->is_valid_number, '宮城県大崎市古川幸町');
ok($zip->set_number('9896111')->is_valid_number, '宮城県大崎市古川鶴ケ埣');
ok($zip->set_number('9896112')->is_valid_number, '宮城県大崎市古川馬寄');
ok($zip->set_number('9896113')->is_valid_number, '宮城県大崎市古川蓑口沼');
ok($zip->set_number('9896114')->is_valid_number, '宮城県大崎市古川大幡');
ok($zip->set_number('9896115')->is_valid_number, '宮城県大崎市古川駅東');
ok($zip->set_number('9896116')->is_valid_number, '宮城県大崎市古川李埣');
ok($zip->set_number('9896117')->is_valid_number, '宮城県大崎市古川旭');
ok($zip->set_number('9896121')->is_valid_number, '宮城県大崎市古川深沼');
ok($zip->set_number('9896122')->is_valid_number, '宮城県大崎市古川桑針');
ok($zip->set_number('9896123')->is_valid_number, '宮城県大崎市古川下中目');
ok($zip->set_number('9896124')->is_valid_number, '宮城県大崎市古川石森');
ok($zip->set_number('9896125')->is_valid_number, '宮城県大崎市古川師山');
ok($zip->set_number('9896126')->is_valid_number, '宮城県大崎市古川楡木');
ok($zip->set_number('9896127')->is_valid_number, '宮城県大崎市古川宮内');
ok($zip->set_number('9896128')->is_valid_number, '宮城県大崎市古川境野宮');
ok($zip->set_number('9896131')->is_valid_number, '宮城県大崎市古川金五輪');
ok($zip->set_number('9896132')->is_valid_number, '宮城県大崎市古川米袋');
ok($zip->set_number('9896133')->is_valid_number, '宮城県大崎市古川西荒井');
ok($zip->set_number('9896134')->is_valid_number, '宮城県大崎市古川米倉');
ok($zip->set_number('9896135')->is_valid_number, '宮城県大崎市古川稲葉');
ok($zip->set_number('9896136')->is_valid_number, '宮城県大崎市古川穂波');
ok($zip->set_number('9896141')->is_valid_number, '宮城県大崎市古川南新町');
ok($zip->set_number('9896142')->is_valid_number, '宮城県大崎市古川中島町');
ok($zip->set_number('9896143')->is_valid_number, '宮城県大崎市古川中里');
ok($zip->set_number('9896144')->is_valid_number, '宮城県大崎市古川小稲葉町');
ok($zip->set_number('9896145')->is_valid_number, '宮城県大崎市古川北稲葉');
ok($zip->set_number('9896151')->is_valid_number, '宮城県大崎市古川城西');
ok($zip->set_number('9896152')->is_valid_number, '宮城県大崎市古川二ノ構');
ok($zip->set_number('9896153')->is_valid_number, '宮城県大崎市古川七日町');
ok($zip->set_number('9896154')->is_valid_number, '宮城県大崎市古川三日町');
ok($zip->set_number('9896155')->is_valid_number, '宮城県大崎市古川南町');
ok($zip->set_number('9896156')->is_valid_number, '宮城県大崎市古川西館');
ok($zip->set_number('9896157')->is_valid_number, '宮城県大崎市古川栄町');
ok($zip->set_number('9896161')->is_valid_number, '宮城県大崎市古川駅南');
ok($zip->set_number('9896162')->is_valid_number, '宮城県大崎市古川駅前大通');
ok($zip->set_number('9896163')->is_valid_number, '宮城県大崎市古川台町');
ok($zip->set_number('9896164')->is_valid_number, '宮城県大崎市古川荒川小金町');
ok($zip->set_number('9896165')->is_valid_number, '宮城県大崎市古川十日町');
ok($zip->set_number('9896166')->is_valid_number, '宮城県大崎市古川東町');
ok($zip->set_number('9896167')->is_valid_number, '宮城県大崎市古川川端');
ok($zip->set_number('9896171')->is_valid_number, '宮城県大崎市古川北町');
ok($zip->set_number('9896172')->is_valid_number, '宮城県大崎市古川前田町');
ok($zip->set_number('9896173')->is_valid_number, '宮城県大崎市古川浦町');
ok($zip->set_number('9896174')->is_valid_number, '宮城県大崎市古川千手寺町');
ok($zip->set_number('9896175')->is_valid_number, '宮城県大崎市古川諏訪');
ok($zip->set_number('9896201')->is_valid_number, '宮城県大崎市古川渋井');
ok($zip->set_number('9896202')->is_valid_number, '宮城県大崎市古川上中目');
ok($zip->set_number('9896203')->is_valid_number, '宮城県大崎市古川飯川');
ok($zip->set_number('9896204')->is_valid_number, '宮城県大崎市古川矢目');
ok($zip->set_number('9896205')->is_valid_number, '宮城県大崎市古川新沼');
ok($zip->set_number('9896206')->is_valid_number, '宮城県大崎市古川中沢');
ok($zip->set_number('9896207')->is_valid_number, '宮城県大崎市古川堤根');
ok($zip->set_number('9896208')->is_valid_number, '宮城県大崎市古川引田');
ok($zip->set_number('9896211')->is_valid_number, '宮城県大崎市古川斎下');
ok($zip->set_number('9896212')->is_valid_number, '宮城県大崎市古川荒田目');
ok($zip->set_number('9896213')->is_valid_number, '宮城県大崎市古川保柳');
ok($zip->set_number('9896214')->is_valid_number, '宮城県大崎市古川新堀');
ok($zip->set_number('9896215')->is_valid_number, '宮城県大崎市古川耳取');
ok($zip->set_number('9896216')->is_valid_number, '宮城県大崎市古川柏崎');
ok($zip->set_number('9896217')->is_valid_number, '宮城県大崎市古川南沢');
ok($zip->set_number('9896221')->is_valid_number, '宮城県大崎市古川大宮');
ok($zip->set_number('9896222')->is_valid_number, '宮城県大崎市古川若葉町');
ok($zip->set_number('9896223')->is_valid_number, '宮城県大崎市古川');
ok($zip->set_number('9896224')->is_valid_number, '宮城県大崎市古川小泉');
ok($zip->set_number('9896225')->is_valid_number, '宮城県大崎市古川塚目');
ok($zip->set_number('9896226')->is_valid_number, '宮城県大崎市古川新田');
ok($zip->set_number('9896227')->is_valid_number, '宮城県大崎市古川大崎');
ok($zip->set_number('9896228')->is_valid_number, '宮城県大崎市古川清水');
ok($zip->set_number('9896231')->is_valid_number, '宮城県大崎市古川長岡');
ok($zip->set_number('9896232')->is_valid_number, '宮城県大崎市古川沢田');
ok($zip->set_number('9896233')->is_valid_number, '宮城県大崎市古川桜ノ目');
ok($zip->set_number('9896234')->is_valid_number, '宮城県大崎市古川小林');
ok($zip->set_number('9896235')->is_valid_number, '宮城県大崎市古川宮沢');
ok($zip->set_number('9896236')->is_valid_number, '宮城県大崎市古川川熊');
ok($zip->set_number('9896241')->is_valid_number, '宮城県大崎市古川清水沢');
ok($zip->set_number('9896242')->is_valid_number, '宮城県大崎市古川北宮沢');
ok($zip->set_number('9896243')->is_valid_number, '宮城県大崎市古川雨生沢');
ok($zip->set_number('9896244')->is_valid_number, '宮城県大崎市古川清滝');
ok($zip->set_number('9896251')->is_valid_number, '宮城県大崎市古川小野');
ok($zip->set_number('9896252')->is_valid_number, '宮城県大崎市古川荒谷');
ok($zip->set_number('9896253')->is_valid_number, '宮城県大崎市古川馬放');
ok($zip->set_number('9896254')->is_valid_number, '宮城県大崎市古川狐塚');
ok($zip->set_number('9896255')->is_valid_number, '宮城県大崎市古川休塚');
ok($zip->set_number('9896261')->is_valid_number, '宮城県大崎市古川長岡針');
ok($zip->set_number('9896262')->is_valid_number, '宮城県大崎市古川馬櫛');
ok($zip->set_number('9896263')->is_valid_number, '宮城県大崎市古川下谷地');
ok($zip->set_number('9896264')->is_valid_number, '宮城県大崎市古川上埣');
ok($zip->set_number('9896265')->is_valid_number, '宮城県大崎市古川渕尻');
ok($zip->set_number('9896266')->is_valid_number, '宮城県大崎市古川富長');
ok($zip->set_number('9896301')->is_valid_number, '宮城県大崎市三本木桑折');
ok($zip->set_number('9896302')->is_valid_number, '宮城県大崎市三本木上伊場野');
ok($zip->set_number('9896303')->is_valid_number, '宮城県大崎市三本木伊場野');
ok($zip->set_number('9896304')->is_valid_number, '宮城県大崎市三本木秋田');
ok($zip->set_number('9896305')->is_valid_number, '宮城県大崎市三本木伊賀');
ok($zip->set_number('9896306')->is_valid_number, '宮城県大崎市三本木新町');
ok($zip->set_number('9896311')->is_valid_number, '宮城県大崎市三本木坂本');
ok($zip->set_number('9896312')->is_valid_number, '宮城県大崎市三本木蟻ケ袋');
ok($zip->set_number('9896313')->is_valid_number, '宮城県大崎市三本木音無');
ok($zip->set_number('9896314')->is_valid_number, '宮城県大崎市三本木斉田');
ok($zip->set_number('9896315')->is_valid_number, '宮城県大崎市三本木新沼');
ok($zip->set_number('9896316')->is_valid_number, '宮城県大崎市三本木高柳');
ok($zip->set_number('9896317')->is_valid_number, '宮城県大崎市三本木蒜袋');
ok($zip->set_number('9896321')->is_valid_number, '宮城県大崎市三本木');
ok($zip->set_number('9896322')->is_valid_number, '宮城県大崎市三本木南谷地');
ok($zip->set_number('9896401')->is_valid_number, '宮城県大崎市岩出山(上真山、葛岡)');
ok($zip->set_number('9896402')->is_valid_number, '宮城県大崎市岩出山(磯田、下真山)');
ok($zip->set_number('9896403')->is_valid_number, '宮城県大崎市岩出山上野目');
ok($zip->set_number('9896404')->is_valid_number, '宮城県大崎市岩出山下一栗');
ok($zip->set_number('9896405')->is_valid_number, '宮城県大崎市岩出山池月');
ok($zip->set_number('9896411')->is_valid_number, '宮城県大崎市岩出山船場');
ok($zip->set_number('9896412')->is_valid_number, '宮城県大崎市岩出山下野目');
ok($zip->set_number('9896413')->is_valid_number, '宮城県大崎市岩出山東川原町');
ok($zip->set_number('9896414')->is_valid_number, '宮城県大崎市岩出山下川原');
ok($zip->set_number('9896415')->is_valid_number, '宮城県大崎市岩出山東川原');
ok($zip->set_number('9896421')->is_valid_number, '宮城県大崎市岩出山上中江');
ok($zip->set_number('9896422')->is_valid_number, '宮城県大崎市岩出山重蔵');
ok($zip->set_number('9896423')->is_valid_number, '宮城県大崎市岩出山前毘沙門');
ok($zip->set_number('9896424')->is_valid_number, '宮城県大崎市岩出山丸山');
ok($zip->set_number('9896425')->is_valid_number, '宮城県大崎市岩出山西御名掛');
ok($zip->set_number('9896426')->is_valid_number, '宮城県大崎市岩出山東御名掛');
ok($zip->set_number('9896431')->is_valid_number, '宮城県大崎市岩出山上川原南');
ok($zip->set_number('9896432')->is_valid_number, '宮城県大崎市岩出山上川原北');
ok($zip->set_number('9896433')->is_valid_number, '宮城県大崎市岩出山上川原町');
ok($zip->set_number('9896434')->is_valid_number, '宮城県大崎市岩出山下川原町');
ok($zip->set_number('9896435')->is_valid_number, '宮城県大崎市岩出山浦小路');
ok($zip->set_number('9896436')->is_valid_number, '宮城県大崎市岩出山二ノ構');
ok($zip->set_number('9896437')->is_valid_number, '宮城県大崎市岩出山城山');
ok($zip->set_number('9896441')->is_valid_number, '宮城県大崎市岩出山通丁');
ok($zip->set_number('9896442')->is_valid_number, '宮城県大崎市岩出山下金沢');
ok($zip->set_number('9896443')->is_valid_number, '宮城県大崎市岩出山轟');
ok($zip->set_number('9896444')->is_valid_number, '宮城県大崎市岩出山細峯');
ok($zip->set_number('9896445')->is_valid_number, '宮城県大崎市岩出山南沢');
ok($zip->set_number('9896446')->is_valid_number, '宮城県大崎市岩出山大学町');
ok($zip->set_number('9896447')->is_valid_number, '宮城県大崎市岩出山上金沢');
ok($zip->set_number('9896461')->is_valid_number, '宮城県大崎市岩出山松沢');
ok($zip->set_number('9896462')->is_valid_number, '宮城県大崎市岩出山蛭沢');
ok($zip->set_number('9896463')->is_valid_number, '宮城県大崎市岩出山木通沢');
ok($zip->set_number('9896464')->is_valid_number, '宮城県大崎市岩出山下東昌寺沢');
ok($zip->set_number('9896465')->is_valid_number, '宮城県大崎市岩出山上東昌寺沢');
ok($zip->set_number('9896466')->is_valid_number, '宮城県大崎市岩出山保土沢');
ok($zip->set_number('9896471')->is_valid_number, '宮城県大崎市岩出山(その他)');
ok($zip->set_number('9896701')->is_valid_number, '宮城県栗原市花山草木沢上原');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉赤這');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉石ノ梅');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉入沢');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉上ノ原');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉上川原');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉通原');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉川渡');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉築沢');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉久田');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉沢');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉新田');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉新町下');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉玉ノ木');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉中野');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉沼井');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉馬場');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉原');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉町');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉町下');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉町西');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉要害');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉横山');
ok($zip->set_number('9896711')->is_valid_number, '宮城県大崎市鳴子温泉蓬田');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉小身川原');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉川袋');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉木戸脇');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉黒崎');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉小室');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉小室山');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉境松');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉坂ノ上');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉沢目木');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉新小身川原');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉関口');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉大尺');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉滝岸');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉竹原');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉田中');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉月山');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉堤下');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉鶴田');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉天神');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉中道');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉野際');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉畑山');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉原崎');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉日向山');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉不動山');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉前森');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉前山');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉水沼');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉南山');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉山際');
ok($zip->set_number('9896712')->is_valid_number, '宮城県大崎市鳴子温泉和田');
ok($zip->set_number('9896801')->is_valid_number, '宮城県大崎市鳴子温泉末沢');
ok($zip->set_number('9896802')->is_valid_number, '宮城県大崎市鳴子温泉末沢西');
ok($zip->set_number('9896803')->is_valid_number, '宮城県大崎市鳴子温泉大畑');
ok($zip->set_number('9896804')->is_valid_number, '宮城県大崎市鳴子温泉中屋敷');
ok($zip->set_number('9896805')->is_valid_number, '宮城県大崎市鳴子温泉岩渕前');
ok($zip->set_number('9896806')->is_valid_number, '宮城県大崎市鳴子温泉岩渕');
ok($zip->set_number('9896807')->is_valid_number, '宮城県大崎市鳴子温泉見手野原');
ok($zip->set_number('9896811')->is_valid_number, '宮城県大崎市鳴子温泉赤湯');
ok($zip->set_number('9896811')->is_valid_number, '宮城県大崎市鳴子温泉鷲ノ巣');
ok($zip->set_number('9896821')->is_valid_number, '宮城県大崎市鳴子温泉車湯');
ok($zip->set_number('9896822')->is_valid_number, '宮城県大崎市鳴子温泉新屋敷');
ok($zip->set_number('9896823')->is_valid_number, '宮城県大崎市鳴子温泉湯元');
ok($zip->set_number('9896824')->is_valid_number, '宮城県大崎市鳴子温泉河原湯');
ok($zip->set_number('9896825')->is_valid_number, '宮城県大崎市鳴子温泉上鳴子');
ok($zip->set_number('9896826')->is_valid_number, '宮城県大崎市鳴子温泉古戸前');
ok($zip->set_number('9896827')->is_valid_number, '宮城県大崎市鳴子温泉尿前');
ok($zip->set_number('9896831')->is_valid_number, '宮城県大崎市鳴子温泉柳木');
ok($zip->set_number('9896832')->is_valid_number, '宮城県大崎市鳴子温泉星沼');
ok($zip->set_number('9896833')->is_valid_number, '宮城県大崎市鳴子温泉川端');
ok($zip->set_number('9896834')->is_valid_number, '宮城県大崎市鳴子温泉西原');
ok($zip->set_number('9896835')->is_valid_number, '宮城県大崎市鳴子温泉南原');
ok($zip->set_number('9896836')->is_valid_number, '宮城県大崎市鳴子温泉焼石亦');
ok($zip->set_number('9896837')->is_valid_number, '宮城県大崎市鳴子温泉南星沼');
ok($zip->set_number('9896838')->is_valid_number, '宮城県大崎市鳴子温泉奥羽岳');
ok($zip->set_number('9896941')->is_valid_number, '宮城県大崎市鳴子温泉鬼首');
ok($zip->set_number('9900000')->is_valid_number, '山形県山形市以下に掲載がない場合');
ok($zip->set_number('9900001')->is_valid_number, '山形県山形市穂積');
ok($zip->set_number('9900002')->is_valid_number, '山形県山形市高原町');
ok($zip->set_number('9900003')->is_valid_number, '山形県山形市早乙女');
ok($zip->set_number('9900004')->is_valid_number, '山形県山形市上山家町');
ok($zip->set_number('9900005')->is_valid_number, '山形県山形市下山家町');
ok($zip->set_number('9900006')->is_valid_number, '山形県山形市山家本町');
ok($zip->set_number('9900007')->is_valid_number, '山形県山形市沼の辺町');
ok($zip->set_number('9900008')->is_valid_number, '山形県山形市双月新町');
ok($zip->set_number('9900011')->is_valid_number, '山形県山形市妙見寺');
ok($zip->set_number('9900012')->is_valid_number, '山形県山形市釈迦堂');
ok($zip->set_number('9900013')->is_valid_number, '山形県山形市防原町');
ok($zip->set_number('9900014')->is_valid_number, '山形県山形市滑川');
ok($zip->set_number('9900015')->is_valid_number, '山形県山形市新山');
ok($zip->set_number('9900016')->is_valid_number, '山形県山形市関沢');
ok($zip->set_number('9900017')->is_valid_number, '山形県山形市上宝沢');
ok($zip->set_number('9900018')->is_valid_number, '山形県山形市下宝沢');
ok($zip->set_number('9900021')->is_valid_number, '山形県山形市小白川町');
ok($zip->set_number('9900022')->is_valid_number, '山形県山形市東山形');
ok($zip->set_number('9900023')->is_valid_number, '山形県山形市松波');
ok($zip->set_number('9900024')->is_valid_number, '山形県山形市あさひ町');
ok($zip->set_number('9900025')->is_valid_number, '山形県山形市あこや町');
ok($zip->set_number('9900031')->is_valid_number, '山形県山形市十日町');
ok($zip->set_number('9900032')->is_valid_number, '山形県山形市小姓町');
ok($zip->set_number('9900033')->is_valid_number, '山形県山形市諏訪町');
ok($zip->set_number('9900034')->is_valid_number, '山形県山形市東原町');
ok($zip->set_number('9900035')->is_valid_number, '山形県山形市小荷駄町');
ok($zip->set_number('9900036')->is_valid_number, '山形県山形市三日町');
ok($zip->set_number('9900037')->is_valid_number, '山形県山形市八日町');
ok($zip->set_number('9900038')->is_valid_number, '山形県山形市幸町');
ok($zip->set_number('9900039')->is_valid_number, '山形県山形市香澄町');
ok($zip->set_number('9900041')->is_valid_number, '山形県山形市緑町');
ok($zip->set_number('9900042')->is_valid_number, '山形県山形市七日町');
ok($zip->set_number('9900043')->is_valid_number, '山形県山形市本町');
ok($zip->set_number('9900044')->is_valid_number, '山形県山形市木の実町');
ok($zip->set_number('9900045')->is_valid_number, '山形県山形市桜町');
ok($zip->set_number('9900046')->is_valid_number, '山形県山形市大手町');
ok($zip->set_number('9900047')->is_valid_number, '山形県山形市旅篭町');
ok($zip->set_number('9900051')->is_valid_number, '山形県山形市銅町');
ok($zip->set_number('9900052')->is_valid_number, '山形県山形市円応寺町');
ok($zip->set_number('9900053')->is_valid_number, '山形県山形市薬師町');
ok($zip->set_number('9900054')->is_valid_number, '山形県山形市六日町');
ok($zip->set_number('9900055')->is_valid_number, '山形県山形市相生町');
ok($zip->set_number('9900056')->is_valid_number, '山形県山形市錦町');
ok($zip->set_number('9900057')->is_valid_number, '山形県山形市宮町');
ok($zip->set_number('9900061')->is_valid_number, '山形県山形市五十鈴');
ok($zip->set_number('9900062')->is_valid_number, '山形県山形市鈴川町');
ok($zip->set_number('9900063')->is_valid_number, '山形県山形市山家町');
ok($zip->set_number('9900064')->is_valid_number, '山形県山形市和合町');
ok($zip->set_number('9900065')->is_valid_number, '山形県山形市双月町');
ok($zip->set_number('9900066')->is_valid_number, '山形県山形市印役町');
ok($zip->set_number('9900067')->is_valid_number, '山形県山形市花楯');
ok($zip->set_number('9900068')->is_valid_number, '山形県山形市泉町');
ok($zip->set_number('9900071')->is_valid_number, '山形県山形市流通センター');
ok($zip->set_number('9900072')->is_valid_number, '山形県山形市浜崎');
ok($zip->set_number('9900073')->is_valid_number, '山形県山形市大野目');
ok($zip->set_number('9900074')->is_valid_number, '山形県山形市芳野');
ok($zip->set_number('9900075')->is_valid_number, '山形県山形市落合町');
ok($zip->set_number('9900076')->is_valid_number, '山形県山形市平久保');
ok($zip->set_number('9900077')->is_valid_number, '山形県山形市栄原');
ok($zip->set_number('9900300')->is_valid_number, '山形県東村山郡山辺町以下に掲載がない場合');
ok($zip->set_number('9900301')->is_valid_number, '山形県東村山郡山辺町山辺');
ok($zip->set_number('9900302')->is_valid_number, '山形県東村山郡山辺町緑ケ丘');
ok($zip->set_number('9900303')->is_valid_number, '山形県東村山郡山辺町清水');
ok($zip->set_number('9900311')->is_valid_number, '山形県東村山郡山辺町近江');
ok($zip->set_number('9900312')->is_valid_number, '山形県東村山郡山辺町三河尻');
ok($zip->set_number('9900321')->is_valid_number, '山形県東村山郡山辺町根際');
ok($zip->set_number('9900322')->is_valid_number, '山形県東村山郡山辺町要害');
ok($zip->set_number('9900323')->is_valid_number, '山形県東村山郡山辺町大塚');
ok($zip->set_number('9900331')->is_valid_number, '山形県東村山郡山辺町大寺');
ok($zip->set_number('9900332')->is_valid_number, '山形県東村山郡山辺町北垣');
ok($zip->set_number('9900333')->is_valid_number, '山形県東村山郡山辺町杉下');
ok($zip->set_number('9900341')->is_valid_number, '山形県東村山郡山辺町大蕨');
ok($zip->set_number('9900342')->is_valid_number, '山形県東村山郡山辺町北山');
ok($zip->set_number('9900351')->is_valid_number, '山形県東村山郡山辺町簗沢');
ok($zip->set_number('9900352')->is_valid_number, '山形県東村山郡山辺町北作');
ok($zip->set_number('9900361')->is_valid_number, '山形県東村山郡山辺町畑谷');
ok($zip->set_number('9900400')->is_valid_number, '山形県東村山郡中山町以下に掲載がない場合');
ok($zip->set_number('9900401')->is_valid_number, '山形県東村山郡中山町長崎');
ok($zip->set_number('9900402')->is_valid_number, '山形県東村山郡中山町いずみ');
ok($zip->set_number('9900403')->is_valid_number, '山形県東村山郡中山町達磨寺');
ok($zip->set_number('9900404')->is_valid_number, '山形県東村山郡中山町向新田');
ok($zip->set_number('9900405')->is_valid_number, '山形県東村山郡中山町金沢');
ok($zip->set_number('9900406')->is_valid_number, '山形県東村山郡中山町柳沢');
ok($zip->set_number('9900407')->is_valid_number, '山形県東村山郡中山町土橋');
ok($zip->set_number('9900408')->is_valid_number, '山形県東村山郡中山町岡');
ok($zip->set_number('9900409')->is_valid_number, '山形県東村山郡中山町小塩');
ok($zip->set_number('9900411')->is_valid_number, '山形県東村山郡中山町あおば');
ok($zip->set_number('9900501')->is_valid_number, '山形県寒河江市宮内');
ok($zip->set_number('9900502')->is_valid_number, '山形県寒河江市幸生');
ok($zip->set_number('9900503')->is_valid_number, '山形県寒河江市田代');
ok($zip->set_number('9900504')->is_valid_number, '山形県寒河江市留場');
ok($zip->set_number('9900505')->is_valid_number, '山形県寒河江市白岩');
ok($zip->set_number('9900511')->is_valid_number, '山形県寒河江市慈恩寺');
ok($zip->set_number('9900512')->is_valid_number, '山形県寒河江市箕輪');
ok($zip->set_number('9900513')->is_valid_number, '山形県寒河江市日和田');
ok($zip->set_number('9900521')->is_valid_number, '山形県寒河江市谷沢');
ok($zip->set_number('9900522')->is_valid_number, '山形県寒河江市清助新田');
ok($zip->set_number('9900523')->is_valid_number, '山形県寒河江市八鍬');
ok($zip->set_number('9900524')->is_valid_number, '山形県寒河江市高松');
ok($zip->set_number('9900525')->is_valid_number, '山形県寒河江市米沢');
ok($zip->set_number('9900561')->is_valid_number, '山形県寒河江市中央工業団地(1番地)');
ok($zip->set_number('9900700')->is_valid_number, '山形県西村山郡西川町以下に掲載がない場合');
ok($zip->set_number('9900701')->is_valid_number, '山形県西村山郡西川町睦合');
ok($zip->set_number('9900702')->is_valid_number, '山形県西村山郡西川町海味');
ok($zip->set_number('9900703')->is_valid_number, '山形県西村山郡西川町間沢');
ok($zip->set_number('9900711')->is_valid_number, '山形県西村山郡西川町吉川');
ok($zip->set_number('9900712')->is_valid_number, '山形県西村山郡西川町原');
ok($zip->set_number('9900713')->is_valid_number, '山形県西村山郡西川町沼山');
ok($zip->set_number('9900714')->is_valid_number, '山形県西村山郡西川町入間');
ok($zip->set_number('9900721')->is_valid_number, '山形県西村山郡西川町大井沢');
ok($zip->set_number('9900731')->is_valid_number, '山形県西村山郡西川町月岡');
ok($zip->set_number('9900732')->is_valid_number, '山形県西村山郡西川町砂子関');
ok($zip->set_number('9900733')->is_valid_number, '山形県西村山郡西川町月山沢');
ok($zip->set_number('9900734')->is_valid_number, '山形県西村山郡西川町志津');
ok($zip->set_number('9900735')->is_valid_number, '山形県西村山郡西川町本道寺');
ok($zip->set_number('9900741')->is_valid_number, '山形県西村山郡西川町綱取');
ok($zip->set_number('9900742')->is_valid_number, '山形県西村山郡西川町水沢');
ok($zip->set_number('9900743')->is_valid_number, '山形県西村山郡西川町岩根沢');
ok($zip->set_number('9900801')->is_valid_number, '山形県山形市天神町');
ok($zip->set_number('9900802')->is_valid_number, '山形県山形市見崎川原');
ok($zip->set_number('9900803')->is_valid_number, '山形県山形市見崎');
ok($zip->set_number('9900804')->is_valid_number, '山形県山形市七十刈');
ok($zip->set_number('9900805')->is_valid_number, '山形県山形市檀野前');
ok($zip->set_number('9900806')->is_valid_number, '山形県山形市藤治屋敷');
ok($zip->set_number('9900807')->is_valid_number, '山形県山形市白川');
ok($zip->set_number('9900808')->is_valid_number, '山形県山形市高田');
ok($zip->set_number('9900809')->is_valid_number, '山形県山形市下田');
ok($zip->set_number('9900810')->is_valid_number, '山形県山形市馬見ケ崎');
ok($zip->set_number('9900811')->is_valid_number, '山形県山形市長町');
ok($zip->set_number('9900812')->is_valid_number, '山形県山形市千歳');
ok($zip->set_number('9900813')->is_valid_number, '山形県山形市桧町');
ok($zip->set_number('9900814')->is_valid_number, '山形県山形市土樋');
ok($zip->set_number('9900815')->is_valid_number, '山形県山形市樋越');
ok($zip->set_number('9900817')->is_valid_number, '山形県山形市今塚');
ok($zip->set_number('9900818')->is_valid_number, '山形県山形市沖町');
ok($zip->set_number('9900819')->is_valid_number, '山形県山形市境田町');
ok($zip->set_number('9900821')->is_valid_number, '山形県山形市北町');
ok($zip->set_number('9900822')->is_valid_number, '山形県山形市北山形');
ok($zip->set_number('9900823')->is_valid_number, '山形県山形市下条町');
ok($zip->set_number('9900824')->is_valid_number, '山形県山形市肴町');
ok($zip->set_number('9900825')->is_valid_number, '山形県山形市城北町');
ok($zip->set_number('9900826')->is_valid_number, '山形県山形市霞城町');
ok($zip->set_number('9900827')->is_valid_number, '山形県山形市城南町');
ok($zip->set_number('9900828')->is_valid_number, '山形県山形市双葉町');
ok($zip->set_number('9900829')->is_valid_number, '山形県山形市五日町');
ok($zip->set_number('9900831')->is_valid_number, '山形県山形市西田');
ok($zip->set_number('9900832')->is_valid_number, '山形県山形市城西町');
ok($zip->set_number('9900833')->is_valid_number, '山形県山形市春日町');
ok($zip->set_number('9900834')->is_valid_number, '山形県山形市清住町');
ok($zip->set_number('9900835')->is_valid_number, '山形県山形市やよい');
ok($zip->set_number('9900836')->is_valid_number, '山形県山形市南石関');
ok($zip->set_number('9900841')->is_valid_number, '山形県山形市飯塚口');
ok($zip->set_number('9900842')->is_valid_number, '山形県山形市石関');
ok($zip->set_number('9900843')->is_valid_number, '山形県山形市横道');
ok($zip->set_number('9900844')->is_valid_number, '山形県山形市西見田');
ok($zip->set_number('9900845')->is_valid_number, '山形県山形市飯塚町');
ok($zip->set_number('9900846')->is_valid_number, '山形県山形市志鎌');
ok($zip->set_number('9900847')->is_valid_number, '山形県山形市砂田');
ok($zip->set_number('9900848')->is_valid_number, '山形県山形市宮浦');
ok($zip->set_number('9900849')->is_valid_number, '山形県山形市中沼');
ok($zip->set_number('9900850')->is_valid_number, '山形県山形市くぬぎざわ西');
ok($zip->set_number('9900851')->is_valid_number, '山形県山形市上椹沢');
ok($zip->set_number('9900852')->is_valid_number, '山形県山形市黄金');
ok($zip->set_number('9900853')->is_valid_number, '山形県山形市西崎');
ok($zip->set_number('9900854')->is_valid_number, '山形県山形市砂塚');
ok($zip->set_number('9900855')->is_valid_number, '山形県山形市千代田');
ok($zip->set_number('9900856')->is_valid_number, '山形県山形市金石田');
ok($zip->set_number('9900857')->is_valid_number, '山形県山形市平田');
ok($zip->set_number('9900858')->is_valid_number, '山形県山形市下椹沢');
ok($zip->set_number('9900859')->is_valid_number, '山形県山形市西原');
ok($zip->set_number('9900860')->is_valid_number, '山形県山形市陣場南');
ok($zip->set_number('9900861')->is_valid_number, '山形県山形市江俣');
ok($zip->set_number('9900862')->is_valid_number, '山形県山形市西江俣');
ok($zip->set_number('9900863')->is_valid_number, '山形県山形市江南');
ok($zip->set_number('9900864')->is_valid_number, '山形県山形市陣場');
ok($zip->set_number('9900865')->is_valid_number, '山形県山形市馬上台');
ok($zip->set_number('9900866')->is_valid_number, '山形県山形市横井');
ok($zip->set_number('9900867')->is_valid_number, '山形県山形市天神台');
ok($zip->set_number('9900868')->is_valid_number, '山形県山形市志戸田');
ok($zip->set_number('9900869')->is_valid_number, '山形県山形市東志戸田');
ok($zip->set_number('9900870')->is_valid_number, '山形県山形市島');
ok($zip->set_number('9900871')->is_valid_number, '山形県山形市銅谷口');
ok($zip->set_number('9900872')->is_valid_number, '山形県山形市八幡前');
ok($zip->set_number('9900874')->is_valid_number, '山形県山形市梅野木前');
ok($zip->set_number('9900875')->is_valid_number, '山形県山形市北江俣');
ok($zip->set_number('9900876')->is_valid_number, '山形県山形市行才');
ok($zip->set_number('9900877')->is_valid_number, '山形県山形市内表');
ok($zip->set_number('9900878')->is_valid_number, '山形県山形市内表東');
ok($zip->set_number('9900879')->is_valid_number, '山形県山形市南志戸田');
ok($zip->set_number('9900881')->is_valid_number, '山形県山形市瀬波');
ok($zip->set_number('9900882')->is_valid_number, '山形県山形市陣場新田');
ok($zip->set_number('9900883')->is_valid_number, '山形県山形市吉野宿');
ok($zip->set_number('9900884')->is_valid_number, '山形県山形市鮨洗');
ok($zip->set_number('9900885')->is_valid_number, '山形県山形市嶋北');
ok($zip->set_number('9900886')->is_valid_number, '山形県山形市嶋南');
ok($zip->set_number('9900891')->is_valid_number, '山形県山形市成安');
ok($zip->set_number('9900892')->is_valid_number, '山形県山形市中野');
ok($zip->set_number('9900893')->is_valid_number, '山形県山形市西中野');
ok($zip->set_number('9900894')->is_valid_number, '山形県山形市船町');
ok($zip->set_number('9900895')->is_valid_number, '山形県山形市向新田');
ok($zip->set_number('9900896')->is_valid_number, '山形県山形市北田');
ok($zip->set_number('9900897')->is_valid_number, '山形県山形市東田');
ok($zip->set_number('9900898')->is_valid_number, '山形県山形市三社');
ok($zip->set_number('9900899')->is_valid_number, '山形県山形市東篭野町');
ok($zip->set_number('9901100')->is_valid_number, '山形県西村山郡大江町以下に掲載がない場合');
ok($zip->set_number('9901101')->is_valid_number, '山形県西村山郡大江町左沢(その他)');
ok($zip->set_number('9901111')->is_valid_number, '山形県西村山郡大江町三郷丙');
ok($zip->set_number('9901112')->is_valid_number, '山形県西村山郡大江町三郷乙');
ok($zip->set_number('9901113')->is_valid_number, '山形県西村山郡大江町三郷甲');
ok($zip->set_number('9901114')->is_valid_number, '山形県西村山郡大江町富沢');
ok($zip->set_number('9901121')->is_valid_number, '山形県西村山郡大江町藤田');
ok($zip->set_number('9901122')->is_valid_number, '山形県西村山郡大江町小見');
ok($zip->set_number('9901131')->is_valid_number, '山形県西村山郡大江町荻野');
ok($zip->set_number('9901132')->is_valid_number, '山形県西村山郡大江町堂屋敷');
ok($zip->set_number('9901133')->is_valid_number, '山形県西村山郡大江町塩ノ平');
ok($zip->set_number('9901134')->is_valid_number, '山形県西村山郡大江町所部');
ok($zip->set_number('9901141')->is_valid_number, '山形県西村山郡大江町小釿');
ok($zip->set_number('9901142')->is_valid_number, '山形県西村山郡大江町材木');
ok($zip->set_number('9901143')->is_valid_number, '山形県西村山郡大江町橋上');
ok($zip->set_number('9901144')->is_valid_number, '山形県西村山郡大江町十八才甲');
ok($zip->set_number('9901145')->is_valid_number, '山形県西村山郡大江町十八才乙');
ok($zip->set_number('9901146')->is_valid_number, '山形県西村山郡大江町楢山');
ok($zip->set_number('9901151')->is_valid_number, '山形県西村山郡大江町本郷乙');
ok($zip->set_number('9901152')->is_valid_number, '山形県西村山郡大江町顔好甲');
ok($zip->set_number('9901153')->is_valid_number, '山形県西村山郡大江町顔好乙');
ok($zip->set_number('9901154')->is_valid_number, '山形県西村山郡大江町本郷甲');
ok($zip->set_number('9901161')->is_valid_number, '山形県西村山郡大江町原田');
ok($zip->set_number('9901162')->is_valid_number, '山形県西村山郡大江町本郷己');
ok($zip->set_number('9901163')->is_valid_number, '山形県西村山郡大江町本郷丁');
ok($zip->set_number('9901164')->is_valid_number, '山形県西村山郡大江町本郷丙');
ok($zip->set_number('9901165')->is_valid_number, '山形県西村山郡大江町本郷戊');
ok($zip->set_number('9901271')->is_valid_number, '山形県西村山郡大江町月布');
ok($zip->set_number('9901272')->is_valid_number, '山形県西村山郡大江町貫見');
ok($zip->set_number('9901273')->is_valid_number, '山形県西村山郡大江町小清');
ok($zip->set_number('9901274')->is_valid_number, '山形県西村山郡大江町柳川');
ok($zip->set_number('9901275')->is_valid_number, '山形県西村山郡大江町沢口');
ok($zip->set_number('9901276')->is_valid_number, '山形県西村山郡大江町黒森');
ok($zip->set_number('9901301')->is_valid_number, '山形県西村山郡朝日町中沢');
ok($zip->set_number('9901302')->is_valid_number, '山形県西村山郡朝日町玉ノ井');
ok($zip->set_number('9901303')->is_valid_number, '山形県西村山郡朝日町馬神');
ok($zip->set_number('9901304')->is_valid_number, '山形県西村山郡朝日町大谷');
ok($zip->set_number('9901305')->is_valid_number, '山形県西村山郡朝日町大沼');
ok($zip->set_number('9901306')->is_valid_number, '山形県西村山郡朝日町大暮山');
ok($zip->set_number('9901400')->is_valid_number, '山形県西村山郡朝日町以下に掲載がない場合');
ok($zip->set_number('9901411')->is_valid_number, '山形県西村山郡朝日町和合');
ok($zip->set_number('9901412')->is_valid_number, '山形県西村山郡朝日町和合平');
ok($zip->set_number('9901421')->is_valid_number, '山形県西村山郡朝日町古槇');
ok($zip->set_number('9901422')->is_valid_number, '山形県西村山郡朝日町送橋');
ok($zip->set_number('9901423')->is_valid_number, '山形県西村山郡朝日町下芦沢');
ok($zip->set_number('9901424')->is_valid_number, '山形県西村山郡朝日町水本');
ok($zip->set_number('9901431')->is_valid_number, '山形県西村山郡朝日町大滝');
ok($zip->set_number('9901432')->is_valid_number, '山形県西村山郡朝日町上郷');
ok($zip->set_number('9901433')->is_valid_number, '山形県西村山郡朝日町杉山');
ok($zip->set_number('9901441')->is_valid_number, '山形県西村山郡朝日町新宿');
ok($zip->set_number('9901442')->is_valid_number, '山形県西村山郡朝日町宮宿');
ok($zip->set_number('9901443')->is_valid_number, '山形県西村山郡朝日町雪谷');
ok($zip->set_number('9901444')->is_valid_number, '山形県西村山郡朝日町四ノ沢');
ok($zip->set_number('9901551')->is_valid_number, '山形県西村山郡朝日町三中');
ok($zip->set_number('9901552')->is_valid_number, '山形県西村山郡朝日町常盤');
ok($zip->set_number('9901553')->is_valid_number, '山形県西村山郡朝日町長沼');
ok($zip->set_number('9901561')->is_valid_number, '山形県西村山郡朝日町松程');
ok($zip->set_number('9901562')->is_valid_number, '山形県西村山郡朝日町大船木');
ok($zip->set_number('9901563')->is_valid_number, '山形県西村山郡朝日町今平');
ok($zip->set_number('9901571')->is_valid_number, '山形県西村山郡朝日町石須部');
ok($zip->set_number('9901572')->is_valid_number, '山形県西村山郡朝日町太郎');
ok($zip->set_number('9901573')->is_valid_number, '山形県西村山郡朝日町立木');
ok($zip->set_number('9901574')->is_valid_number, '山形県西村山郡朝日町白倉');
ok($zip->set_number('9902161')->is_valid_number, '山形県山形市漆山');
ok($zip->set_number('9902162')->is_valid_number, '山形県山形市あけぼの');
ok($zip->set_number('9902163')->is_valid_number, '山形県山形市伊達城');
ok($zip->set_number('9902164')->is_valid_number, '山形県山形市新開');
ok($zip->set_number('9902171')->is_valid_number, '山形県山形市七浦');
ok($zip->set_number('9902172')->is_valid_number, '山形県山形市千手堂');
ok($zip->set_number('9902173')->is_valid_number, '山形県山形市渋江');
ok($zip->set_number('9902174')->is_valid_number, '山形県山形市灰塚');
ok($zip->set_number('9902175')->is_valid_number, '山形県山形市中野目');
ok($zip->set_number('9902211')->is_valid_number, '山形県山形市十文字');
ok($zip->set_number('9902212')->is_valid_number, '山形県山形市上柳');
ok($zip->set_number('9902213')->is_valid_number, '山形県山形市寺西');
ok($zip->set_number('9902214')->is_valid_number, '山形県山形市青柳');
ok($zip->set_number('9902215')->is_valid_number, '山形県山形市下柳');
ok($zip->set_number('9902216')->is_valid_number, '山形県山形市千刈');
ok($zip->set_number('9902221')->is_valid_number, '山形県山形市風間');
ok($zip->set_number('9902222')->is_valid_number, '山形県山形市青野');
ok($zip->set_number('9902223')->is_valid_number, '山形県山形市塔の前');
ok($zip->set_number('9902224')->is_valid_number, '山形県山形市近田');
ok($zip->set_number('9902225')->is_valid_number, '山形県山形市花岡');
ok($zip->set_number('9902226')->is_valid_number, '山形県山形市西越');
ok($zip->set_number('9902227')->is_valid_number, '山形県山形市千石');
ok($zip->set_number('9902231')->is_valid_number, '山形県山形市大森');
ok($zip->set_number('9902232')->is_valid_number, '山形県山形市下東山');
ok($zip->set_number('9902233')->is_valid_number, '山形県山形市切畑');
ok($zip->set_number('9902234')->is_valid_number, '山形県山形市こも石');
ok($zip->set_number('9902235')->is_valid_number, '山形県山形市中里');
ok($zip->set_number('9902241')->is_valid_number, '山形県山形市上東山');
ok($zip->set_number('9902242')->is_valid_number, '山形県山形市高沢');
ok($zip->set_number('9902251')->is_valid_number, '山形県山形市立谷川');
ok($zip->set_number('9902301')->is_valid_number, '山形県山形市蔵王温泉');
ok($zip->set_number('9902302')->is_valid_number, '山形県山形市蔵王堀田');
ok($zip->set_number('9902303')->is_valid_number, '山形県山形市蔵王上野');
ok($zip->set_number('9902304')->is_valid_number, '山形県山形市蔵王山田');
ok($zip->set_number('9902305')->is_valid_number, '山形県山形市蔵王半郷');
ok($zip->set_number('9902306')->is_valid_number, '山形県山形市南半郷');
ok($zip->set_number('9902307')->is_valid_number, '山形県山形市表蔵王');
ok($zip->set_number('9902308')->is_valid_number, '山形県山形市東半郷');
ok($zip->set_number('9902311')->is_valid_number, '山形県山形市黒沢');
ok($zip->set_number('9902312')->is_valid_number, '山形県山形市南松原');
ok($zip->set_number('9902313')->is_valid_number, '山形県山形市松原');
ok($zip->set_number('9902314')->is_valid_number, '山形県山形市谷柏');
ok($zip->set_number('9902315')->is_valid_number, '山形県山形市津金沢');
ok($zip->set_number('9902316')->is_valid_number, '山形県山形市片谷地');
ok($zip->set_number('9902317')->is_valid_number, '山形県山形市みはらしの丘');
ok($zip->set_number('9902321')->is_valid_number, '山形県山形市桜田西');
ok($zip->set_number('9902322')->is_valid_number, '山形県山形市桜田南');
ok($zip->set_number('9902323')->is_valid_number, '山形県山形市桜田東');
ok($zip->set_number('9902324')->is_valid_number, '山形県山形市青田南');
ok($zip->set_number('9902331')->is_valid_number, '山形県山形市飯田西');
ok($zip->set_number('9902332')->is_valid_number, '山形県山形市飯田');
ok($zip->set_number('9902333')->is_valid_number, '山形県山形市蔵王飯田');
ok($zip->set_number('9902334')->is_valid_number, '山形県山形市蔵王成沢');
ok($zip->set_number('9902335')->is_valid_number, '山形県山形市蔵王南成沢');
ok($zip->set_number('9902337')->is_valid_number, '山形県山形市蔵王西成沢');
ok($zip->set_number('9902338')->is_valid_number, '山形県山形市蔵王松ケ丘');
ok($zip->set_number('9902339')->is_valid_number, '山形県山形市成沢西');
ok($zip->set_number('9902341')->is_valid_number, '山形県山形市柏倉');
ok($zip->set_number('9902342')->is_valid_number, '山形県山形市富神前');
ok($zip->set_number('9902342')->is_valid_number, '山形県山形市門伝');
ok($zip->set_number('9902343')->is_valid_number, '山形県山形市城森');
ok($zip->set_number('9902344')->is_valid_number, '山形県山形市大道端');
ok($zip->set_number('9902345')->is_valid_number, '山形県山形市富神台');
ok($zip->set_number('9902346')->is_valid_number, '山形県山形市高木');
ok($zip->set_number('9902351')->is_valid_number, '山形県山形市鋳物町');
ok($zip->set_number('9902352')->is_valid_number, '山形県山形市前明石');
ok($zip->set_number('9902353')->is_valid_number, '山形県山形市明石堂');
ok($zip->set_number('9902354')->is_valid_number, '山形県山形市東二位田');
ok($zip->set_number('9902355')->is_valid_number, '山形県山形市二位田');
ok($zip->set_number('9902361')->is_valid_number, '山形県山形市百目鬼');
ok($zip->set_number('9902362')->is_valid_number, '山形県山形市菅沢');
ok($zip->set_number('9902363')->is_valid_number, '山形県山形市長谷堂');
ok($zip->set_number('9902364')->is_valid_number, '山形県山形市大師堂');
ok($zip->set_number('9902365')->is_valid_number, '山形県山形市御手作');
ok($zip->set_number('9902366')->is_valid_number, '山形県山形市谷地前');
ok($zip->set_number('9902367')->is_valid_number, '山形県山形市すげさわの丘');
ok($zip->set_number('9902371')->is_valid_number, '山形県山形市村木沢');
ok($zip->set_number('9902372')->is_valid_number, '山形県山形市みのりが丘');
ok($zip->set_number('9902373')->is_valid_number, '山形県山形市若木');
ok($zip->set_number('9902374')->is_valid_number, '山形県山形市古館');
ok($zip->set_number('9902375')->is_valid_number, '山形県山形市東古館');
ok($zip->set_number('9902376')->is_valid_number, '山形県山形市桜ケ丘');
ok($zip->set_number('9902377')->is_valid_number, '山形県山形市藤沢川');
ok($zip->set_number('9902378')->is_valid_number, '山形県山形市反町');
ok($zip->set_number('9902381')->is_valid_number, '山形県山形市常明寺');
ok($zip->set_number('9902382')->is_valid_number, '山形県山形市滝平');
ok($zip->set_number('9902383')->is_valid_number, '山形県山形市芳沢');
ok($zip->set_number('9902384')->is_valid_number, '山形県山形市上反田');
ok($zip->set_number('9902385')->is_valid_number, '山形県山形市下反田');
ok($zip->set_number('9902386')->is_valid_number, '山形県山形市並柳');
ok($zip->set_number('9902401')->is_valid_number, '山形県山形市平清水');
ok($zip->set_number('9902402')->is_valid_number, '山形県山形市小立');
ok($zip->set_number('9902403')->is_valid_number, '山形県山形市岩波');
ok($zip->set_number('9902404')->is_valid_number, '山形県山形市八森');
ok($zip->set_number('9902405')->is_valid_number, '山形県山形市土坂');
ok($zip->set_number('9902406')->is_valid_number, '山形県山形市神尾');
ok($zip->set_number('9902411')->is_valid_number, '山形県山形市前田町');
ok($zip->set_number('9902412')->is_valid_number, '山形県山形市松山');
ok($zip->set_number('9902413')->is_valid_number, '山形県山形市南原町');
ok($zip->set_number('9902414')->is_valid_number, '山形県山形市寿町');
ok($zip->set_number('9902421')->is_valid_number, '山形県山形市上桜田');
ok($zip->set_number('9902422')->is_valid_number, '山形県山形市中桜田');
ok($zip->set_number('9902423')->is_valid_number, '山形県山形市東青田');
ok($zip->set_number('9902431')->is_valid_number, '山形県山形市松見町');
ok($zip->set_number('9902432')->is_valid_number, '山形県山形市荒楯町');
ok($zip->set_number('9902433')->is_valid_number, '山形県山形市鳥居ケ丘');
ok($zip->set_number('9902434')->is_valid_number, '山形県山形市旭が丘');
ok($zip->set_number('9902435')->is_valid_number, '山形県山形市青田');
ok($zip->set_number('9902441')->is_valid_number, '山形県山形市南一番町');
ok($zip->set_number('9902442')->is_valid_number, '山形県山形市南二番町');
ok($zip->set_number('9902443')->is_valid_number, '山形県山形市南三番町');
ok($zip->set_number('9902444')->is_valid_number, '山形県山形市南四番町');
ok($zip->set_number('9902445')->is_valid_number, '山形県山形市南栄町');
ok($zip->set_number('9902446')->is_valid_number, '山形県山形市白山');
ok($zip->set_number('9902447')->is_valid_number, '山形県山形市元木');
ok($zip->set_number('9902451')->is_valid_number, '山形県山形市吉原');
ok($zip->set_number('9902453')->is_valid_number, '山形県山形市若宮');
ok($zip->set_number('9902455')->is_valid_number, '山形県山形市吉原南');
ok($zip->set_number('9902461')->is_valid_number, '山形県山形市南館');
ok($zip->set_number('9902462')->is_valid_number, '山形県山形市深町');
ok($zip->set_number('9902463')->is_valid_number, '山形県山形市富の中');
ok($zip->set_number('9902464')->is_valid_number, '山形県山形市高堂');
ok($zip->set_number('9902465')->is_valid_number, '山形県山形市南館西');
ok($zip->set_number('9902471')->is_valid_number, '山形県山形市羽黒堂');
ok($zip->set_number('9902472')->is_valid_number, '山形県山形市明神前');
ok($zip->set_number('9902473')->is_valid_number, '山形県山形市松栄');
ok($zip->set_number('9902474')->is_valid_number, '山形県山形市沼木');
ok($zip->set_number('9902475')->is_valid_number, '山形県山形市木ノ目田');
ok($zip->set_number('9902476')->is_valid_number, '山形県山形市飯沢');
ok($zip->set_number('9902477')->is_valid_number, '山形県山形市長苗代');
ok($zip->set_number('9902481')->is_valid_number, '山形県山形市あかねケ丘');
ok($zip->set_number('9902482')->is_valid_number, '山形県山形市久保田');
ok($zip->set_number('9902483')->is_valid_number, '山形県山形市上町');
ok($zip->set_number('9902484')->is_valid_number, '山形県山形市篭田');
ok($zip->set_number('9902491')->is_valid_number, '山形県山形市あずま町');
ok($zip->set_number('9902492')->is_valid_number, '山形県山形市鉄砲町');
ok($zip->set_number('9902493')->is_valid_number, '山形県山形市美畑町');
ok($zip->set_number('9902494')->is_valid_number, '山形県山形市末広町');
ok($zip->set_number('9902495')->is_valid_number, '山形県山形市若葉町');
ok($zip->set_number('9910000')->is_valid_number, '山形県寒河江市以下に掲載がない場合');
ok($zip->set_number('9910001')->is_valid_number, '山形県寒河江市入倉');
ok($zip->set_number('9910002')->is_valid_number, '山形県寒河江市下河原');
ok($zip->set_number('9910003')->is_valid_number, '山形県寒河江市西根');
ok($zip->set_number('9910004')->is_valid_number, '山形県寒河江市西根北町');
ok($zip->set_number('9910005')->is_valid_number, '山形県寒河江市中河原');
ok($zip->set_number('9910006')->is_valid_number, '山形県寒河江市上河原');
ok($zip->set_number('9910006')->is_valid_number, '山形県寒河江市夕カヘ');
ok($zip->set_number('9910007')->is_valid_number, '山形県寒河江市道生');
ok($zip->set_number('9910008')->is_valid_number, '山形県寒河江市菊地堂');
ok($zip->set_number('9910008')->is_valid_number, '山形県寒河江市雲河原');
ok($zip->set_number('9910011')->is_valid_number, '山形県寒河江市日田');
ok($zip->set_number('9910012')->is_valid_number, '山形県寒河江市新山町');
ok($zip->set_number('9910013')->is_valid_number, '山形県寒河江市高田');
ok($zip->set_number('9910021')->is_valid_number, '山形県寒河江市中央');
ok($zip->set_number('9910022')->is_valid_number, '山形県寒河江市七日町');
ok($zip->set_number('9910023')->is_valid_number, '山形県寒河江市丸内');
ok($zip->set_number('9910024')->is_valid_number, '山形県寒河江市六供町');
ok($zip->set_number('9910025')->is_valid_number, '山形県寒河江市八幡町');
ok($zip->set_number('9910026')->is_valid_number, '山形県寒河江市山岸町');
ok($zip->set_number('9910027')->is_valid_number, '山形県寒河江市石持町');
ok($zip->set_number('9910028')->is_valid_number, '山形県寒河江市ほなみ');
ok($zip->set_number('9910031')->is_valid_number, '山形県寒河江市本町');
ok($zip->set_number('9910032')->is_valid_number, '山形県寒河江市南町');
ok($zip->set_number('9910033')->is_valid_number, '山形県寒河江市末広町');
ok($zip->set_number('9910034')->is_valid_number, '山形県寒河江市栄町');
ok($zip->set_number('9910035')->is_valid_number, '山形県寒河江市幸町');
ok($zip->set_number('9910041')->is_valid_number, '山形県寒河江市寒河江');
ok($zip->set_number('9910042')->is_valid_number, '山形県寒河江市高屋');
ok($zip->set_number('9910043')->is_valid_number, '山形県寒河江市島');
ok($zip->set_number('9910044')->is_valid_number, '山形県寒河江市越井坂町');
ok($zip->set_number('9910045')->is_valid_number, '山形県寒河江市小沼町');
ok($zip->set_number('9910046')->is_valid_number, '山形県寒河江市東新山町');
ok($zip->set_number('9910047')->is_valid_number, '山形県寒河江市新山');
ok($zip->set_number('9910048')->is_valid_number, '山形県寒河江市みずき');
ok($zip->set_number('9910049')->is_valid_number, '山形県寒河江市本楯');
ok($zip->set_number('9910051')->is_valid_number, '山形県寒河江市若葉町');
ok($zip->set_number('9910052')->is_valid_number, '山形県寒河江市幸田町');
ok($zip->set_number('9910053')->is_valid_number, '山形県寒河江市元町');
ok($zip->set_number('9910054')->is_valid_number, '山形県寒河江市仲谷地');
ok($zip->set_number('9910055')->is_valid_number, '山形県寒河江市船橋町');
ok($zip->set_number('9910056')->is_valid_number, '山形県寒河江市落衣前');
ok($zip->set_number('9910057')->is_valid_number, '山形県寒河江市内ノ袋');
ok($zip->set_number('9910061')->is_valid_number, '山形県寒河江市中央工業団地(その他)');
ok($zip->set_number('9910062')->is_valid_number, '山形県寒河江市緑町');
ok($zip->set_number('9910063')->is_valid_number, '山形県寒河江市柴橋');
ok($zip->set_number('9910064')->is_valid_number, '山形県寒河江市平塩');
ok($zip->set_number('9910065')->is_valid_number, '山形県寒河江市中郷');
ok($zip->set_number('9910066')->is_valid_number, '山形県寒河江市松川');
ok($zip->set_number('9910801')->is_valid_number, '山形県西村山郡大江町左沢(1518-3、1750-1~2228-18、2255-1~');
ok($zip->set_number('9910801')->is_valid_number, '山形県西村山郡大江町2257-28、2316~2318、2430-1~2431-75)');
ok($zip->set_number('9920000')->is_valid_number, '山形県米沢市以下に掲載がない場合');
ok($zip->set_number('9920001')->is_valid_number, '山形県米沢市窪田町東江股');
ok($zip->set_number('9920002')->is_valid_number, '山形県米沢市窪田町矢野目');
ok($zip->set_number('9920003')->is_valid_number, '山形県米沢市窪田町窪田');
ok($zip->set_number('9920004')->is_valid_number, '山形県米沢市窪田町小瀬');
ok($zip->set_number('9920005')->is_valid_number, '山形県米沢市窪田町藤泉');
ok($zip->set_number('9920011')->is_valid_number, '山形県米沢市中田町');
ok($zip->set_number('9920012')->is_valid_number, '山形県米沢市金池');
ok($zip->set_number('9920013')->is_valid_number, '山形県米沢市栄町');
ok($zip->set_number('9920014')->is_valid_number, '山形県米沢市鍛冶町');
ok($zip->set_number('9920015')->is_valid_number, '山形県米沢市立町');
ok($zip->set_number('9920016')->is_valid_number, '山形県米沢市川井小路');
ok($zip->set_number('9920017')->is_valid_number, '山形県米沢市桜木町');
ok($zip->set_number('9920021')->is_valid_number, '山形県米沢市花沢');
ok($zip->set_number('9920022')->is_valid_number, '山形県米沢市花沢町');
ok($zip->set_number('9920023')->is_valid_number, '山形県米沢市下花沢');
ok($zip->set_number('9920024')->is_valid_number, '山形県米沢市東大通');
ok($zip->set_number('9920025')->is_valid_number, '山形県米沢市通町');
ok($zip->set_number('9920026')->is_valid_number, '山形県米沢市東');
ok($zip->set_number('9920027')->is_valid_number, '山形県米沢市駅前');
ok($zip->set_number('9920031')->is_valid_number, '山形県米沢市大町');
ok($zip->set_number('9920032')->is_valid_number, '山形県米沢市相生町');
ok($zip->set_number('9920033')->is_valid_number, '山形県米沢市福田町');
ok($zip->set_number('9920034')->is_valid_number, '山形県米沢市吾妻町');
ok($zip->set_number('9920035')->is_valid_number, '山形県米沢市太田町');
ok($zip->set_number('9920036')->is_valid_number, '山形県米沢市福田');
ok($zip->set_number('9920037')->is_valid_number, '山形県米沢市本町');
ok($zip->set_number('9920038')->is_valid_number, '山形県米沢市城南');
ok($zip->set_number('9920039')->is_valid_number, '山形県米沢市門東町');
ok($zip->set_number('9920041')->is_valid_number, '山形県米沢市塩井町宮井');
ok($zip->set_number('9920042')->is_valid_number, '山形県米沢市塩井町塩野');
ok($zip->set_number('9920043')->is_valid_number, '山形県米沢市塩野');
ok($zip->set_number('9920044')->is_valid_number, '山形県米沢市春日');
ok($zip->set_number('9920045')->is_valid_number, '山形県米沢市中央');
ok($zip->set_number('9920046')->is_valid_number, '山形県米沢市信夫町');
ok($zip->set_number('9920047')->is_valid_number, '山形県米沢市徳町');
ok($zip->set_number('9920051')->is_valid_number, '山形県米沢市城北');
ok($zip->set_number('9920052')->is_valid_number, '山形県米沢市丸の内');
ok($zip->set_number('9920053')->is_valid_number, '山形県米沢市松が岬');
ok($zip->set_number('9920054')->is_valid_number, '山形県米沢市城西');
ok($zip->set_number('9920055')->is_valid_number, '山形県米沢市御廟');
ok($zip->set_number('9920056')->is_valid_number, '山形県米沢市直江町');
ok($zip->set_number('9920057')->is_valid_number, '山形県米沢市成島町');
ok($zip->set_number('9920058')->is_valid_number, '山形県米沢市木場町');
ok($zip->set_number('9920059')->is_valid_number, '山形県米沢市西大通');
ok($zip->set_number('9920061')->is_valid_number, '山形県米沢市堀川町');
ok($zip->set_number('9920062')->is_valid_number, '山形県米沢市林泉寺');
ok($zip->set_number('9920063')->is_valid_number, '山形県米沢市泉町');
ok($zip->set_number('9920064')->is_valid_number, '山形県米沢市杉の目町');
ok($zip->set_number('9920065')->is_valid_number, '山形県米沢市古志田町');
ok($zip->set_number('9920066')->is_valid_number, '山形県米沢市遠山町');
ok($zip->set_number('9920071')->is_valid_number, '山形県米沢市舘山矢子町');
ok($zip->set_number('9920072')->is_valid_number, '山形県米沢市舘山');
ok($zip->set_number('9920073')->is_valid_number, '山形県米沢市吹屋敷町');
ok($zip->set_number('9920074')->is_valid_number, '山形県米沢市矢来');
ok($zip->set_number('9920075')->is_valid_number, '山形県米沢市赤芝町');
ok($zip->set_number('9920076')->is_valid_number, '山形県米沢市小野川町');
ok($zip->set_number('9920077')->is_valid_number, '山形県米沢市簗沢');
ok($zip->set_number('9920081')->is_valid_number, '山形県米沢市下小菅');
ok($zip->set_number('9920082')->is_valid_number, '山形県米沢市広幡町小山田');
ok($zip->set_number('9920083')->is_valid_number, '山形県米沢市広幡町成島');
ok($zip->set_number('9920084')->is_valid_number, '山形県米沢市広幡町上小菅');
ok($zip->set_number('9920085')->is_valid_number, '山形県米沢市広幡町沖仲');
ok($zip->set_number('9920086')->is_valid_number, '山形県米沢市広幡町京塚');
ok($zip->set_number('9920087')->is_valid_number, '山形県米沢市広幡町大沢');
ok($zip->set_number('9920091')->is_valid_number, '山形県米沢市六郷町桐原');
ok($zip->set_number('9920092')->is_valid_number, '山形県米沢市六郷町西江股');
ok($zip->set_number('9920093')->is_valid_number, '山形県米沢市六郷町西藤泉');
ok($zip->set_number('9920094')->is_valid_number, '山形県米沢市六郷町轟');
ok($zip->set_number('9920095')->is_valid_number, '山形県米沢市六郷町一漆');
ok($zip->set_number('9920096')->is_valid_number, '山形県米沢市六郷町長橋');
ok($zip->set_number('9920111')->is_valid_number, '山形県米沢市下新田');
ok($zip->set_number('9920112')->is_valid_number, '山形県米沢市浅川');
ok($zip->set_number('9920113')->is_valid_number, '山形県米沢市長手');
ok($zip->set_number('9920114')->is_valid_number, '山形県米沢市木和田');
ok($zip->set_number('9920115')->is_valid_number, '山形県米沢市梓川');
ok($zip->set_number('9920116')->is_valid_number, '山形県米沢市竹井');
ok($zip->set_number('9920117')->is_valid_number, '山形県米沢市川井');
ok($zip->set_number('9920118')->is_valid_number, '山形県米沢市上新田');
ok($zip->set_number('9920119')->is_valid_number, '山形県米沢市アルカディア');
ok($zip->set_number('9920261')->is_valid_number, '山形県東置賜郡高畠町上和田');
ok($zip->set_number('9920262')->is_valid_number, '山形県東置賜郡高畠町元和田');
ok($zip->set_number('9920263')->is_valid_number, '山形県東置賜郡高畠町下和田');
ok($zip->set_number('9920264')->is_valid_number, '山形県東置賜郡高畠町馬頭');
ok($zip->set_number('9920265')->is_valid_number, '山形県東置賜郡高畠町佐沢');
ok($zip->set_number('9920300')->is_valid_number, '山形県東置賜郡高畠町以下に掲載がない場合');
ok($zip->set_number('9920301')->is_valid_number, '山形県東置賜郡高畠町二井宿');
ok($zip->set_number('9920302')->is_valid_number, '山形県東置賜郡高畠町安久津');
ok($zip->set_number('9920311')->is_valid_number, '山形県東置賜郡高畠町金原');
ok($zip->set_number('9920312')->is_valid_number, '山形県東置賜郡高畠町小郡山');
ok($zip->set_number('9920313')->is_valid_number, '山形県東置賜郡高畠町高安');
ok($zip->set_number('9920314')->is_valid_number, '山形県東置賜郡高畠町塩森');
ok($zip->set_number('9920315')->is_valid_number, '山形県東置賜郡高畠町泉岡');
ok($zip->set_number('9920321')->is_valid_number, '山形県東置賜郡高畠町亀岡');
ok($zip->set_number('9920322')->is_valid_number, '山形県東置賜郡高畠町中島');
ok($zip->set_number('9920323')->is_valid_number, '山形県東置賜郡高畠町露藤');
ok($zip->set_number('9920324')->is_valid_number, '山形県東置賜郡高畠町入生田');
ok($zip->set_number('9920325')->is_valid_number, '山形県東置賜郡高畠町船橋');
ok($zip->set_number('9920331')->is_valid_number, '山形県東置賜郡高畠町三条目');
ok($zip->set_number('9920332')->is_valid_number, '山形県東置賜郡高畠町相森');
ok($zip->set_number('9920333')->is_valid_number, '山形県東置賜郡高畠町柏木目');
ok($zip->set_number('9920334')->is_valid_number, '山形県東置賜郡高畠町一本柳');
ok($zip->set_number('9920335')->is_valid_number, '山形県東置賜郡高畠町川沼');
ok($zip->set_number('9920341')->is_valid_number, '山形県東置賜郡高畠町時沢');
ok($zip->set_number('9920342')->is_valid_number, '山形県東置賜郡高畠町竹森');
ok($zip->set_number('9920343')->is_valid_number, '山形県東置賜郡高畠町根岸');
ok($zip->set_number('9920344')->is_valid_number, '山形県東置賜郡高畠町深沼');
ok($zip->set_number('9920351')->is_valid_number, '山形県東置賜郡高畠町高畠');
ok($zip->set_number('9920352')->is_valid_number, '山形県東置賜郡高畠町中里');
ok($zip->set_number('9920471')->is_valid_number, '山形県南陽市金山');
ok($zip->set_number('9920472')->is_valid_number, '山形県南陽市宮内');
ok($zip->set_number('9920473')->is_valid_number, '山形県南陽市池黒');
ok($zip->set_number('9920474')->is_valid_number, '山形県南陽市漆山');
ok($zip->set_number('9920475')->is_valid_number, '山形県南陽市羽付');
ok($zip->set_number('9920476')->is_valid_number, '山形県南陽市砂塚');
ok($zip->set_number('9920477')->is_valid_number, '山形県南陽市梨郷');
ok($zip->set_number('9920478')->is_valid_number, '山形県南陽市竹原');
ok($zip->set_number('9920479')->is_valid_number, '山形県南陽市和田');
ok($zip->set_number('9920581')->is_valid_number, '山形県南陽市小滝');
ok($zip->set_number('9920582')->is_valid_number, '山形県南陽市荻');
ok($zip->set_number('9920583')->is_valid_number, '山形県南陽市下荻');
ok($zip->set_number('9920584')->is_valid_number, '山形県南陽市太郎');
ok($zip->set_number('9920601')->is_valid_number, '山形県東置賜郡川西町西大塚');
ok($zip->set_number('9920602')->is_valid_number, '山形県東置賜郡川西町大塚');
ok($zip->set_number('9920603')->is_valid_number, '山形県東置賜郡川西町東大塚');
ok($zip->set_number('9920771')->is_valid_number, '山形県西置賜郡白鷹町鮎貝');
ok($zip->set_number('9920772')->is_valid_number, '山形県西置賜郡白鷹町横田尻');
ok($zip->set_number('9920773')->is_valid_number, '山形県西置賜郡白鷹町高玉');
ok($zip->set_number('9920774')->is_valid_number, '山形県西置賜郡白鷹町山口');
ok($zip->set_number('9920775')->is_valid_number, '山形県西置賜郡白鷹町黒鴨');
ok($zip->set_number('9920776')->is_valid_number, '山形県西置賜郡白鷹町深山');
ok($zip->set_number('9920777')->is_valid_number, '山形県西置賜郡白鷹町栃窪');
ok($zip->set_number('9920778')->is_valid_number, '山形県西置賜郡白鷹町高岡');
ok($zip->set_number('9920779')->is_valid_number, '山形県西置賜郡白鷹町箕和田');
ok($zip->set_number('9920800')->is_valid_number, '山形県西置賜郡白鷹町以下に掲載がない場合');
ok($zip->set_number('9920801')->is_valid_number, '山形県西置賜郡白鷹町針生');
ok($zip->set_number('9920802')->is_valid_number, '山形県西置賜郡白鷹町中山');
ok($zip->set_number('9920811')->is_valid_number, '山形県西置賜郡白鷹町萩野');
ok($zip->set_number('9920812')->is_valid_number, '山形県西置賜郡白鷹町滝野');
ok($zip->set_number('9920821')->is_valid_number, '山形県西置賜郡白鷹町十王');
ok($zip->set_number('9920831')->is_valid_number, '山形県西置賜郡白鷹町荒砥甲');
ok($zip->set_number('9920832')->is_valid_number, '山形県西置賜郡白鷹町荒砥乙');
ok($zip->set_number('9920841')->is_valid_number, '山形県西置賜郡白鷹町畔藤');
ok($zip->set_number('9920851')->is_valid_number, '山形県西置賜郡白鷹町広野');
ok($zip->set_number('9920852')->is_valid_number, '山形県西置賜郡白鷹町浅立');
ok($zip->set_number('9920861')->is_valid_number, '山形県西置賜郡白鷹町大瀬');
ok($zip->set_number('9920862')->is_valid_number, '山形県西置賜郡白鷹町下山');
ok($zip->set_number('9920863')->is_valid_number, '山形県西置賜郡白鷹町菖蒲');
ok($zip->set_number('9920864')->is_valid_number, '山形県西置賜郡白鷹町佐野原');
ok($zip->set_number('9921121')->is_valid_number, '山形県米沢市万世町刈安');
ok($zip->set_number('9921122')->is_valid_number, '山形県米沢市万世町梓山');
ok($zip->set_number('9921123')->is_valid_number, '山形県米沢市万世町桑山');
ok($zip->set_number('9921124')->is_valid_number, '山形県米沢市万世町金谷');
ok($zip->set_number('9921125')->is_valid_number, '山形県米沢市万世町片子');
ok($zip->set_number('9921126')->is_valid_number, '山形県米沢市万世町堂森');
ok($zip->set_number('9921127')->is_valid_number, '山形県米沢市万世町牛森');
ok($zip->set_number('9921128')->is_valid_number, '山形県米沢市八幡原');
ok($zip->set_number('9921201')->is_valid_number, '山形県米沢市万世町立沢');
ok($zip->set_number('9921202')->is_valid_number, '山形県米沢市三沢');
ok($zip->set_number('9921203')->is_valid_number, '山形県米沢市大沢(大沢、笠松)');
ok($zip->set_number('9921204')->is_valid_number, '山形県米沢市大小屋');
ok($zip->set_number('9921205')->is_valid_number, '山形県米沢市関根');
ok($zip->set_number('9921206')->is_valid_number, '山形県米沢市赤崩(その他)');
ok($zip->set_number('9921303')->is_valid_number, '山形県米沢市大沢(その他)');
ok($zip->set_number('9921331')->is_valid_number, '山形県米沢市板谷');
ok($zip->set_number('9921406')->is_valid_number, '山形県米沢市赤崩(山王浦)');
ok($zip->set_number('9921441')->is_valid_number, '山形県米沢市笹野町');
ok($zip->set_number('9921442')->is_valid_number, '山形県米沢市芳泉町');
ok($zip->set_number('9921443')->is_valid_number, '山形県米沢市笹野');
ok($zip->set_number('9921444')->is_valid_number, '山形県米沢市諸仏町');
ok($zip->set_number('9921445')->is_valid_number, '山形県米沢市笹野本町');
ok($zip->set_number('9921446')->is_valid_number, '山形県米沢市直江石堤');
ok($zip->set_number('9921451')->is_valid_number, '山形県米沢市南原笹野町');
ok($zip->set_number('9921452')->is_valid_number, '山形県米沢市南原横堀町');
ok($zip->set_number('9921453')->is_valid_number, '山形県米沢市南原石垣町');
ok($zip->set_number('9921454')->is_valid_number, '山形県米沢市南原新町');
ok($zip->set_number('9921455')->is_valid_number, '山形県米沢市南原猪苗代町');
ok($zip->set_number('9921461')->is_valid_number, '山形県米沢市李山');
ok($zip->set_number('9921462')->is_valid_number, '山形県米沢市大平');
ok($zip->set_number('9921471')->is_valid_number, '山形県米沢市立石');
ok($zip->set_number('9921472')->is_valid_number, '山形県米沢市関');
ok($zip->set_number('9921473')->is_valid_number, '山形県米沢市関町');
ok($zip->set_number('9921474')->is_valid_number, '山形県米沢市綱木');
ok($zip->set_number('9921581')->is_valid_number, '山形県米沢市口田沢');
ok($zip->set_number('9921582')->is_valid_number, '山形県米沢市神原');
ok($zip->set_number('9921583')->is_valid_number, '山形県米沢市入田沢');
ok($zip->set_number('9930000')->is_valid_number, '山形県長井市以下に掲載がない場合');
ok($zip->set_number('9930001')->is_valid_number, '山形県長井市ままの上');
ok($zip->set_number('9930002')->is_valid_number, '山形県長井市屋城町');
ok($zip->set_number('9930003')->is_valid_number, '山形県長井市東町');
ok($zip->set_number('9930004')->is_valid_number, '山形県長井市神明町');
ok($zip->set_number('9930005')->is_valid_number, '山形県長井市片田町');
ok($zip->set_number('9930006')->is_valid_number, '山形県長井市あら町');
ok($zip->set_number('9930007')->is_valid_number, '山形県長井市本町');
ok($zip->set_number('9930011')->is_valid_number, '山形県長井市館町北');
ok($zip->set_number('9930012')->is_valid_number, '山形県長井市日の出町');
ok($zip->set_number('9930013')->is_valid_number, '山形県長井市館町南');
ok($zip->set_number('9930014')->is_valid_number, '山形県長井市小出');
ok($zip->set_number('9930015')->is_valid_number, '山形県長井市四ツ谷');
ok($zip->set_number('9930016')->is_valid_number, '山形県長井市台町');
ok($zip->set_number('9930017')->is_valid_number, '山形県長井市花作町');
ok($zip->set_number('9930021')->is_valid_number, '山形県長井市上伊佐沢');
ok($zip->set_number('9930022')->is_valid_number, '山形県長井市芦沢');
ok($zip->set_number('9930023')->is_valid_number, '山形県長井市下伊佐沢');
ok($zip->set_number('9930024')->is_valid_number, '山形県長井市中伊佐沢');
ok($zip->set_number('9930031')->is_valid_number, '山形県長井市泉');
ok($zip->set_number('9930032')->is_valid_number, '山形県長井市河井');
ok($zip->set_number('9930033')->is_valid_number, '山形県長井市今泉');
ok($zip->set_number('9930034')->is_valid_number, '山形県長井市歌丸');
ok($zip->set_number('9930035')->is_valid_number, '山形県長井市時庭');
ok($zip->set_number('9930041')->is_valid_number, '山形県長井市九野本');
ok($zip->set_number('9930042')->is_valid_number, '山形県長井市平山');
ok($zip->set_number('9930051')->is_valid_number, '山形県長井市幸町');
ok($zip->set_number('9930052')->is_valid_number, '山形県長井市新町');
ok($zip->set_number('9930053')->is_valid_number, '山形県長井市中道');
ok($zip->set_number('9930054')->is_valid_number, '山形県長井市清水町');
ok($zip->set_number('9930061')->is_valid_number, '山形県長井市寺泉');
ok($zip->set_number('9930062')->is_valid_number, '山形県長井市川原沢');
ok($zip->set_number('9930063')->is_valid_number, '山形県長井市草岡');
ok($zip->set_number('9930064')->is_valid_number, '山形県長井市勧進代');
ok($zip->set_number('9930071')->is_valid_number, '山形県長井市白兎');
ok($zip->set_number('9930072')->is_valid_number, '山形県長井市五十川');
ok($zip->set_number('9930073')->is_valid_number, '山形県長井市森');
ok($zip->set_number('9930074')->is_valid_number, '山形県長井市宮');
ok($zip->set_number('9930075')->is_valid_number, '山形県長井市成田');
ok($zip->set_number('9930081')->is_valid_number, '山形県長井市緑町');
ok($zip->set_number('9930082')->is_valid_number, '山形県長井市舟場');
ok($zip->set_number('9930083')->is_valid_number, '山形県長井市大町');
ok($zip->set_number('9930084')->is_valid_number, '山形県長井市栄町');
ok($zip->set_number('9930085')->is_valid_number, '山形県長井市高野町');
ok($zip->set_number('9930086')->is_valid_number, '山形県長井市十日町');
ok($zip->set_number('9930087')->is_valid_number, '山形県長井市横町');
ok($zip->set_number('9940000')->is_valid_number, '山形県天童市以下に掲載がない場合');
ok($zip->set_number('9940001')->is_valid_number, '山形県天童市万代');
ok($zip->set_number('9940002')->is_valid_number, '山形県天童市乱川');
ok($zip->set_number('9940003')->is_valid_number, '山形県天童市柏木町');
ok($zip->set_number('9940004')->is_valid_number, '山形県天童市小関');
ok($zip->set_number('9940005')->is_valid_number, '山形県天童市高木');
ok($zip->set_number('9940006')->is_valid_number, '山形県天童市成生');
ok($zip->set_number('9940007')->is_valid_number, '山形県天童市大清水');
ok($zip->set_number('9940011')->is_valid_number, '山形県天童市北久野本');
ok($zip->set_number('9940012')->is_valid_number, '山形県天童市久野本');
ok($zip->set_number('9940013')->is_valid_number, '山形県天童市老野森');
ok($zip->set_number('9940014')->is_valid_number, '山形県天童市糠塚');
ok($zip->set_number('9940015')->is_valid_number, '山形県天童市泉町');
ok($zip->set_number('9940016')->is_valid_number, '山形県天童市東久野本');
ok($zip->set_number('9940021')->is_valid_number, '山形県天童市山元');
ok($zip->set_number('9940022')->is_valid_number, '山形県天童市貫津');
ok($zip->set_number('9940023')->is_valid_number, '山形県天童市東善寺');
ok($zip->set_number('9940024')->is_valid_number, '山形県天童市鎌田');
ok($zip->set_number('9940025')->is_valid_number, '山形県天童市鎌田本町');
ok($zip->set_number('9940026')->is_valid_number, '山形県天童市東本町');
ok($zip->set_number('9940027')->is_valid_number, '山形県天童市桜町');
ok($zip->set_number('9940028')->is_valid_number, '山形県天童市鍬ノ町');
ok($zip->set_number('9940031')->is_valid_number, '山形県天童市天童中');
ok($zip->set_number('9940032')->is_valid_number, '山形県天童市小路');
ok($zip->set_number('9940033')->is_valid_number, '山形県天童市三日町');
ok($zip->set_number('9940034')->is_valid_number, '山形県天童市本町');
ok($zip->set_number('9940041')->is_valid_number, '山形県天童市五日町');
ok($zip->set_number('9940042')->is_valid_number, '山形県天童市北目');
ok($zip->set_number('9940043')->is_valid_number, '山形県天童市松城町');
ok($zip->set_number('9940044')->is_valid_number, '山形県天童市一日町');
ok($zip->set_number('9940045')->is_valid_number, '山形県天童市仲町');
ok($zip->set_number('9940046')->is_valid_number, '山形県天童市田鶴町');
ok($zip->set_number('9940047')->is_valid_number, '山形県天童市駅西');
ok($zip->set_number('9940048')->is_valid_number, '山形県天童市交り江');
ok($zip->set_number('9940049')->is_valid_number, '山形県天童市南町');
ok($zip->set_number('9940051')->is_valid_number, '山形県天童市奈良沢');
ok($zip->set_number('9940052')->is_valid_number, '山形県天童市下荻野戸');
ok($zip->set_number('9940053')->is_valid_number, '山形県天童市上荻野戸');
ok($zip->set_number('9940054')->is_valid_number, '山形県天童市荒谷');
ok($zip->set_number('9940055')->is_valid_number, '山形県天童市原町');
ok($zip->set_number('9940056')->is_valid_number, '山形県天童市干布');
ok($zip->set_number('9940057')->is_valid_number, '山形県天童市石鳥居');
ok($zip->set_number('9940061')->is_valid_number, '山形県天童市東芳賀');
ok($zip->set_number('9940062')->is_valid_number, '山形県天童市長岡北');
ok($zip->set_number('9940063')->is_valid_number, '山形県天童市東長岡');
ok($zip->set_number('9940064')->is_valid_number, '山形県天童市中里');
ok($zip->set_number('9940065')->is_valid_number, '山形県天童市清池');
ok($zip->set_number('9940066')->is_valid_number, '山形県天童市長岡');
ok($zip->set_number('9940067')->is_valid_number, '山形県天童市芳賀');
ok($zip->set_number('9940068')->is_valid_number, '山形県天童市高擶');
ok($zip->set_number('9940069')->is_valid_number, '山形県天童市清池東');
ok($zip->set_number('9940071')->is_valid_number, '山形県天童市矢野目');
ok($zip->set_number('9940072')->is_valid_number, '山形県天童市塚野目');
ok($zip->set_number('9940073')->is_valid_number, '山形県天童市寺津');
ok($zip->set_number('9940074')->is_valid_number, '山形県天童市藤内新田');
ok($zip->set_number('9940075')->is_valid_number, '山形県天童市蔵増');
ok($zip->set_number('9940076')->is_valid_number, '山形県天童市高野辺');
ok($zip->set_number('9940077')->is_valid_number, '山形県天童市窪野目');
ok($zip->set_number('9940078')->is_valid_number, '山形県天童市今町');
ok($zip->set_number('9940079')->is_valid_number, '山形県天童市大町');
ok($zip->set_number('9940081')->is_valid_number, '山形県天童市南小畑');
ok($zip->set_number('9940082')->is_valid_number, '山形県天童市芳賀タウン北');
ok($zip->set_number('9940083')->is_valid_number, '山形県天童市芳賀タウン南');
ok($zip->set_number('9940101')->is_valid_number, '山形県天童市山口');
ok($zip->set_number('9940102')->is_valid_number, '山形県天童市道満');
ok($zip->set_number('9940103')->is_valid_number, '山形県天童市川原子');
ok($zip->set_number('9940104')->is_valid_number, '山形県天童市田麦野');
ok($zip->set_number('9950000')->is_valid_number, '山形県村山市以下に掲載がない場合');
ok($zip->set_number('9950001')->is_valid_number, '山形県村山市土生田');
ok($zip->set_number('9950002')->is_valid_number, '山形県村山市五十沢');
ok($zip->set_number('9950003')->is_valid_number, '山形県村山市本飯田');
ok($zip->set_number('9950004')->is_valid_number, '山形県村山市金谷');
ok($zip->set_number('9950005')->is_valid_number, '山形県村山市たも山');
ok($zip->set_number('9950006')->is_valid_number, '山形県村山市林崎');
ok($zip->set_number('9950011')->is_valid_number, '山形県村山市楯岡北町');
ok($zip->set_number('9950012')->is_valid_number, '山形県村山市湯沢');
ok($zip->set_number('9950013')->is_valid_number, '山形県村山市楯岡湯沢');
ok($zip->set_number('9950014')->is_valid_number, '山形県村山市楯岡鶴ケ町');
ok($zip->set_number('9950015')->is_valid_number, '山形県村山市楯岡二日町');
ok($zip->set_number('9950016')->is_valid_number, '山形県村山市楯岡晦日町');
ok($zip->set_number('9950017')->is_valid_number, '山形県村山市楯岡十日町');
ok($zip->set_number('9950018')->is_valid_number, '山形県村山市楯岡新高田');
ok($zip->set_number('9950021')->is_valid_number, '山形県村山市楯岡楯');
ok($zip->set_number('9950022')->is_valid_number, '山形県村山市楯岡馬場');
ok($zip->set_number('9950023')->is_valid_number, '山形県村山市楯岡東沢');
ok($zip->set_number('9950024')->is_valid_number, '山形県村山市楯岡笛田');
ok($zip->set_number('9950025')->is_valid_number, '山形県村山市楯岡');
ok($zip->set_number('9950031')->is_valid_number, '山形県村山市楯岡大沢川');
ok($zip->set_number('9950032')->is_valid_number, '山形県村山市楯岡荒町');
ok($zip->set_number('9950033')->is_valid_number, '山形県村山市楯岡新町');
ok($zip->set_number('9950034')->is_valid_number, '山形県村山市楯岡五日町');
ok($zip->set_number('9950035')->is_valid_number, '山形県村山市中央');
ok($zip->set_number('9950036')->is_valid_number, '山形県村山市楯岡中町');
ok($zip->set_number('9950037')->is_valid_number, '山形県村山市楯岡俵町');
ok($zip->set_number('9950038')->is_valid_number, '山形県村山市駅西');
ok($zip->set_number('9950041')->is_valid_number, '山形県村山市河島');
ok($zip->set_number('9950042')->is_valid_number, '山形県村山市杉島');
ok($zip->set_number('9950051')->is_valid_number, '山形県村山市田沢');
ok($zip->set_number('9950052')->is_valid_number, '山形県村山市名取');
ok($zip->set_number('9950053')->is_valid_number, '山形県村山市西郷');
ok($zip->set_number('9950054')->is_valid_number, '山形県村山市大淀');
ok($zip->set_number('9950055')->is_valid_number, '山形県村山市長島');
ok($zip->set_number('9950056')->is_valid_number, '山形県村山市河島山');
ok($zip->set_number('9950111')->is_valid_number, '山形県村山市大久保');
ok($zip->set_number('9950112')->is_valid_number, '山形県村山市湯野沢');
ok($zip->set_number('9950113')->is_valid_number, '山形県村山市岩野');
ok($zip->set_number('9950201')->is_valid_number, '山形県村山市長善寺');
ok($zip->set_number('9950202')->is_valid_number, '山形県村山市白鳥');
ok($zip->set_number('9950203')->is_valid_number, '山形県村山市大槇');
ok($zip->set_number('9950204')->is_valid_number, '山形県村山市稲下');
ok($zip->set_number('9950205')->is_valid_number, '山形県村山市樽石');
ok($zip->set_number('9950206')->is_valid_number, '山形県村山市山の内');
ok($zip->set_number('9950207')->is_valid_number, '山形県村山市雪の観音郷');
ok($zip->set_number('9950208')->is_valid_number, '山形県村山市富並');
ok($zip->set_number('9950209')->is_valid_number, '山形県村山市碁点');
ok($zip->set_number('9960000')->is_valid_number, '山形県新庄市以下に掲載がない場合');
ok($zip->set_number('9960001')->is_valid_number, '山形県新庄市五日町');
ok($zip->set_number('9960002')->is_valid_number, '山形県新庄市金沢');
ok($zip->set_number('9960011')->is_valid_number, '山形県新庄市東谷地田町');
ok($zip->set_number('9960021')->is_valid_number, '山形県新庄市常葉町');
ok($zip->set_number('9960022')->is_valid_number, '山形県新庄市住吉町');
ok($zip->set_number('9960023')->is_valid_number, '山形県新庄市沖の町');
ok($zip->set_number('9960024')->is_valid_number, '山形県新庄市多門町');
ok($zip->set_number('9960025')->is_valid_number, '山形県新庄市若葉町');
ok($zip->set_number('9960026')->is_valid_number, '山形県新庄市大町');
ok($zip->set_number('9960027')->is_valid_number, '山形県新庄市本町');
ok($zip->set_number('9960028')->is_valid_number, '山形県新庄市万場町');
ok($zip->set_number('9960031')->is_valid_number, '山形県新庄市末広町');
ok($zip->set_number('9960032')->is_valid_number, '山形県新庄市上金沢町');
ok($zip->set_number('9960033')->is_valid_number, '山形県新庄市下金沢町');
ok($zip->set_number('9960034')->is_valid_number, '山形県新庄市下田町');
ok($zip->set_number('9960035')->is_valid_number, '山形県新庄市鉄砲町');
ok($zip->set_number('9960041')->is_valid_number, '山形県新庄市鳥越');
ok($zip->set_number('9960051')->is_valid_number, '山形県新庄市松本');
ok($zip->set_number('9960052')->is_valid_number, '山形県新庄市角沢');
ok($zip->set_number('9960053')->is_valid_number, '山形県新庄市福田');
ok($zip->set_number('9960054')->is_valid_number, '山形県新庄市仁間');
ok($zip->set_number('9960061')->is_valid_number, '山形県新庄市飛田');
ok($zip->set_number('9960071')->is_valid_number, '山形県新庄市小田島町');
ok($zip->set_number('9960072')->is_valid_number, '山形県新庄市宮内町');
ok($zip->set_number('9960073')->is_valid_number, '山形県新庄市栄町');
ok($zip->set_number('9960074')->is_valid_number, '山形県新庄市小田島');
ok($zip->set_number('9960075')->is_valid_number, '山形県新庄市横打町');
ok($zip->set_number('9960076')->is_valid_number, '山形県新庄市城西町');
ok($zip->set_number('9960077')->is_valid_number, '山形県新庄市城南町');
ok($zip->set_number('9960078')->is_valid_number, '山形県新庄市新町');
ok($zip->set_number('9960079')->is_valid_number, '山形県新庄市千門町');
ok($zip->set_number('9960081')->is_valid_number, '山形県新庄市中道町');
ok($zip->set_number('9960082')->is_valid_number, '山形県新庄市北町');
ok($zip->set_number('9960083')->is_valid_number, '山形県新庄市沼田町');
ok($zip->set_number('9960084')->is_valid_number, '山形県新庄市大手町');
ok($zip->set_number('9960085')->is_valid_number, '山形県新庄市堀端町');
ok($zip->set_number('9960086')->is_valid_number, '山形県新庄市石川町');
ok($zip->set_number('9960087')->is_valid_number, '山形県新庄市沼田');
ok($zip->set_number('9960088')->is_valid_number, '山形県新庄市桧町');
ok($zip->set_number('9960091')->is_valid_number, '山形県新庄市十日町(その他)');
ok($zip->set_number('9960111')->is_valid_number, '山形県新庄市升形');
ok($zip->set_number('9960112')->is_valid_number, '山形県新庄市本合海');
ok($zip->set_number('9960200')->is_valid_number, '山形県最上郡大蔵村以下に掲載がない場合');
ok($zip->set_number('9960201')->is_valid_number, '山形県最上郡大蔵村南山(その他)');
ok($zip->set_number('9960211')->is_valid_number, '山形県最上郡大蔵村合海');
ok($zip->set_number('9960212')->is_valid_number, '山形県最上郡大蔵村清水');
ok($zip->set_number('9960213')->is_valid_number, '山形県最上郡大蔵村赤松');
ok($zip->set_number('9960301')->is_valid_number, '山形県最上郡大蔵村南山(430番地以上「1770-1~2、1862-42、');
ok($zip->set_number('9960301')->is_valid_number, '山形県最上郡大蔵村1923-5を除く」、大谷地、折渡、鍵金野、金山、滝ノ沢、豊牧、沼の台、');
ok($zip->set_number('9960301')->is_valid_number, '山形県最上郡大蔵村肘折、平林)');
ok($zip->set_number('9970000')->is_valid_number, '山形県鶴岡市以下に掲載がない場合');
ok($zip->set_number('9970001')->is_valid_number, '山形県鶴岡市湯野沢');
ok($zip->set_number('9970002')->is_valid_number, '山形県鶴岡市播磨');
ok($zip->set_number('9970003')->is_valid_number, '山形県鶴岡市文下');
ok($zip->set_number('9970004')->is_valid_number, '山形県鶴岡市本田');
ok($zip->set_number('9970005')->is_valid_number, '山形県鶴岡市小京田');
ok($zip->set_number('9970006')->is_valid_number, '山形県鶴岡市福田');
ok($zip->set_number('9970007')->is_valid_number, '山形県鶴岡市豊田');
ok($zip->set_number('9970008')->is_valid_number, '山形県鶴岡市平田');
ok($zip->set_number('9970009')->is_valid_number, '山形県鶴岡市中京田');
ok($zip->set_number('9970010')->is_valid_number, '山形県鶴岡市余慶町');
ok($zip->set_number('9970011')->is_valid_number, '山形県鶴岡市宝田');
ok($zip->set_number('9970012')->is_valid_number, '山形県鶴岡市道形');
ok($zip->set_number('9970013')->is_valid_number, '山形県鶴岡市道形町');
ok($zip->set_number('9970014')->is_valid_number, '山形県鶴岡市大宝寺町');
ok($zip->set_number('9970015')->is_valid_number, '山形県鶴岡市末広町');
ok($zip->set_number('9970016')->is_valid_number, '山形県鶴岡市日和田町');
ok($zip->set_number('9970017')->is_valid_number, '山形県鶴岡市大宝寺(その他)');
ok($zip->set_number('9970018')->is_valid_number, '山形県鶴岡市茅原町');
ok($zip->set_number('9970019')->is_valid_number, '山形県鶴岡市茅原');
ok($zip->set_number('9970021')->is_valid_number, '山形県鶴岡市宝町');
ok($zip->set_number('9970022')->is_valid_number, '山形県鶴岡市切添町');
ok($zip->set_number('9970023')->is_valid_number, '山形県鶴岡市鳥居町');
ok($zip->set_number('9970024')->is_valid_number, '山形県鶴岡市朝暘町');
ok($zip->set_number('9970025')->is_valid_number, '山形県鶴岡市日出');
ok($zip->set_number('9970026')->is_valid_number, '山形県鶴岡市大東町');
ok($zip->set_number('9970027')->is_valid_number, '山形県鶴岡市昭和町');
ok($zip->set_number('9970028')->is_valid_number, '山形県鶴岡市山王町');
ok($zip->set_number('9970029')->is_valid_number, '山形県鶴岡市日吉町');
ok($zip->set_number('9970031')->is_valid_number, '山形県鶴岡市錦町');
ok($zip->set_number('9970032')->is_valid_number, '山形県鶴岡市上畑町');
ok($zip->set_number('9970033')->is_valid_number, '山形県鶴岡市泉町');
ok($zip->set_number('9970034')->is_valid_number, '山形県鶴岡市本町');
ok($zip->set_number('9970035')->is_valid_number, '山形県鶴岡市馬場町');
ok($zip->set_number('9970036')->is_valid_number, '山形県鶴岡市家中新町');
ok($zip->set_number('9970037')->is_valid_number, '山形県鶴岡市若葉町');
ok($zip->set_number('9970038')->is_valid_number, '山形県鶴岡市北茅原町');
ok($zip->set_number('9970039')->is_valid_number, '山形県鶴岡市西茅原町');
ok($zip->set_number('9970041')->is_valid_number, '山形県鶴岡市城北町');
ok($zip->set_number('9970042')->is_valid_number, '山形県鶴岡市新形町');
ok($zip->set_number('9970043')->is_valid_number, '山形県鶴岡市東新斎町');
ok($zip->set_number('9970044')->is_valid_number, '山形県鶴岡市新海町');
ok($zip->set_number('9970045')->is_valid_number, '山形県鶴岡市西新斎町');
ok($zip->set_number('9970046')->is_valid_number, '山形県鶴岡市みどり町');
ok($zip->set_number('9970047')->is_valid_number, '山形県鶴岡市大塚町');
ok($zip->set_number('9970048')->is_valid_number, '山形県鶴岡市平京田');
ok($zip->set_number('9970049')->is_valid_number, '山形県鶴岡市大部町');
ok($zip->set_number('9970051')->is_valid_number, '山形県鶴岡市荒井京田');
ok($zip->set_number('9970052')->is_valid_number, '山形県鶴岡市覚岸寺');
ok($zip->set_number('9970053')->is_valid_number, '山形県鶴岡市北京田');
ok($zip->set_number('9970054')->is_valid_number, '山形県鶴岡市高田');
ok($zip->set_number('9970055')->is_valid_number, '山形県鶴岡市西京田');
ok($zip->set_number('9970056')->is_valid_number, '山形県鶴岡市中野京田');
ok($zip->set_number('9970057')->is_valid_number, '山形県鶴岡市安丹');
ok($zip->set_number('9970058')->is_valid_number, '山形県鶴岡市林崎');
ok($zip->set_number('9970101')->is_valid_number, '山形県鶴岡市羽黒町町屋');
ok($zip->set_number('9970102')->is_valid_number, '山形県鶴岡市羽黒町中里');
ok($zip->set_number('9970103')->is_valid_number, '山形県鶴岡市羽黒町戸野');
ok($zip->set_number('9970104')->is_valid_number, '山形県鶴岡市羽黒町坂ノ下');
ok($zip->set_number('9970105')->is_valid_number, '山形県鶴岡市羽黒町川行');
ok($zip->set_number('9970106')->is_valid_number, '山形県鶴岡市羽黒町染興屋');
ok($zip->set_number('9970107')->is_valid_number, '山形県鶴岡市羽黒町小増川');
ok($zip->set_number('9970108')->is_valid_number, '山形県鶴岡市羽黒町金森目');
ok($zip->set_number('9970117')->is_valid_number, '山形県鶴岡市大宝寺(中野)');
ok($zip->set_number('9970121')->is_valid_number, '山形県鶴岡市羽黒町玉川');
ok($zip->set_number('9970122')->is_valid_number, '山形県鶴岡市羽黒町大口');
ok($zip->set_number('9970123')->is_valid_number, '山形県鶴岡市羽黒町市野山');
ok($zip->set_number('9970124')->is_valid_number, '山形県鶴岡市羽黒町増川新田');
ok($zip->set_number('9970125')->is_valid_number, '山形県鶴岡市羽黒町仙道');
ok($zip->set_number('9970126')->is_valid_number, '山形県鶴岡市羽黒町野荒町');
ok($zip->set_number('9970127')->is_valid_number, '山形県鶴岡市羽黒町十文字');
ok($zip->set_number('9970131')->is_valid_number, '山形県鶴岡市羽黒町川代');
ok($zip->set_number('9970141')->is_valid_number, '山形県鶴岡市羽黒町荒川');
ok($zip->set_number('9970142')->is_valid_number, '山形県鶴岡市羽黒町上野新田');
ok($zip->set_number('9970143')->is_valid_number, '山形県鶴岡市羽黒町野田');
ok($zip->set_number('9970151')->is_valid_number, '山形県鶴岡市羽黒町黒瀬');
ok($zip->set_number('9970152')->is_valid_number, '山形県鶴岡市羽黒町猪俣新田');
ok($zip->set_number('9970153')->is_valid_number, '山形県鶴岡市羽黒町高寺');
ok($zip->set_number('9970154')->is_valid_number, '山形県鶴岡市羽黒町馬渡ノ内下');
ok($zip->set_number('9970155')->is_valid_number, '山形県鶴岡市羽黒町石野新田');
ok($zip->set_number('9970156')->is_valid_number, '山形県鶴岡市羽黒町松尾');
ok($zip->set_number('9970157')->is_valid_number, '山形県鶴岡市羽黒町後田');
ok($zip->set_number('9970158')->is_valid_number, '山形県鶴岡市羽黒町松ケ岡');
ok($zip->set_number('9970161')->is_valid_number, '山形県鶴岡市羽黒町押口');
ok($zip->set_number('9970162')->is_valid_number, '山形県鶴岡市羽黒町細谷');
ok($zip->set_number('9970163')->is_valid_number, '山形県鶴岡市羽黒町狩谷野目');
ok($zip->set_number('9970164')->is_valid_number, '山形県鶴岡市羽黒町昼田');
ok($zip->set_number('9970165')->is_valid_number, '山形県鶴岡市羽黒町富沢');
ok($zip->set_number('9970166')->is_valid_number, '山形県鶴岡市羽黒町三ツ橋');
ok($zip->set_number('9970167')->is_valid_number, '山形県鶴岡市羽黒町赤川');
ok($zip->set_number('9970211')->is_valid_number, '山形県鶴岡市羽黒町手向');
ok($zip->set_number('9970301')->is_valid_number, '山形県鶴岡市馬渡');
ok($zip->set_number('9970302')->is_valid_number, '山形県鶴岡市田代');
ok($zip->set_number('9970303')->is_valid_number, '山形県鶴岡市たらのき代');
ok($zip->set_number('9970311')->is_valid_number, '山形県鶴岡市黒川');
ok($zip->set_number('9970321')->is_valid_number, '山形県鶴岡市宝谷');
ok($zip->set_number('9970322')->is_valid_number, '山形県鶴岡市松根');
ok($zip->set_number('9970323')->is_valid_number, '山形県鶴岡市西片屋');
ok($zip->set_number('9970331')->is_valid_number, '山形県鶴岡市板井川');
ok($zip->set_number('9970332')->is_valid_number, '山形県鶴岡市西荒屋');
ok($zip->set_number('9970333')->is_valid_number, '山形県鶴岡市常盤木');
ok($zip->set_number('9970334')->is_valid_number, '山形県鶴岡市丸岡');
ok($zip->set_number('9970341')->is_valid_number, '山形県鶴岡市下山添');
ok($zip->set_number('9970342')->is_valid_number, '山形県鶴岡市三千刈');
ok($zip->set_number('9970343')->is_valid_number, '山形県鶴岡市桂荒俣');
ok($zip->set_number('9970344')->is_valid_number, '山形県鶴岡市東荒屋');
ok($zip->set_number('9970345')->is_valid_number, '山形県鶴岡市中田');
ok($zip->set_number('9970346')->is_valid_number, '山形県鶴岡市上山添');
ok($zip->set_number('9970351')->is_valid_number, '山形県鶴岡市勝福寺');
ok($zip->set_number('9970361')->is_valid_number, '山形県鶴岡市民田');
ok($zip->set_number('9970362')->is_valid_number, '山形県鶴岡市中橋');
ok($zip->set_number('9970363')->is_valid_number, '山形県鶴岡市寿');
ok($zip->set_number('9970364')->is_valid_number, '山形県鶴岡市滝沢');
ok($zip->set_number('9970365')->is_valid_number, '山形県鶴岡市金谷');
ok($zip->set_number('9970366')->is_valid_number, '山形県鶴岡市谷定');
ok($zip->set_number('9970367')->is_valid_number, '山形県鶴岡市上山谷');
ok($zip->set_number('9970368')->is_valid_number, '山形県鶴岡市青龍寺');
ok($zip->set_number('9970369')->is_valid_number, '山形県鶴岡市高坂');
ok($zip->set_number('9970401')->is_valid_number, '山形県鶴岡市中野新田');
ok($zip->set_number('9970402')->is_valid_number, '山形県鶴岡市東岩本');
ok($zip->set_number('9970403')->is_valid_number, '山形県鶴岡市越中山');
ok($zip->set_number('9970404')->is_valid_number, '山形県鶴岡市下名川');
ok($zip->set_number('9970405')->is_valid_number, '山形県鶴岡市上名川');
ok($zip->set_number('9970411')->is_valid_number, '山形県鶴岡市熊出');
ok($zip->set_number('9970412')->is_valid_number, '山形県鶴岡市本郷');
ok($zip->set_number('9970413')->is_valid_number, '山形県鶴岡市行沢');
ok($zip->set_number('9970414')->is_valid_number, '山形県鶴岡市大針');
ok($zip->set_number('9970415')->is_valid_number, '山形県鶴岡市砂川');
ok($zip->set_number('9970531')->is_valid_number, '山形県鶴岡市大網');
ok($zip->set_number('9970532')->is_valid_number, '山形県鶴岡市田麦俣');
ok($zip->set_number('9970621')->is_valid_number, '山形県鶴岡市荒沢');
ok($zip->set_number('9970622')->is_valid_number, '山形県鶴岡市大鳥');
ok($zip->set_number('9970623')->is_valid_number, '山形県鶴岡市上田沢');
ok($zip->set_number('9970624')->is_valid_number, '山形県鶴岡市倉沢');
ok($zip->set_number('9970625')->is_valid_number, '山形県鶴岡市下田沢');
ok($zip->set_number('9970626')->is_valid_number, '山形県鶴岡市松沢');
ok($zip->set_number('9970751')->is_valid_number, '山形県鶴岡市藤沢');
ok($zip->set_number('9970752')->is_valid_number, '山形県鶴岡市湯田川');
ok($zip->set_number('9970753')->is_valid_number, '山形県鶴岡市田川');
ok($zip->set_number('9970754')->is_valid_number, '山形県鶴岡市少連寺');
ok($zip->set_number('9970755')->is_valid_number, '山形県鶴岡市砂谷');
ok($zip->set_number('9970756')->is_valid_number, '山形県鶴岡市東目');
ok($zip->set_number('9970757')->is_valid_number, '山形県鶴岡市坂野下');
ok($zip->set_number('9970758')->is_valid_number, '山形県鶴岡市関根');
ok($zip->set_number('9970801')->is_valid_number, '山形県鶴岡市東原町');
ok($zip->set_number('9970802')->is_valid_number, '山形県鶴岡市伊勢原町');
ok($zip->set_number('9970803')->is_valid_number, '山形県鶴岡市伊勢横内');
ok($zip->set_number('9970804')->is_valid_number, '山形県鶴岡市斎藤川原');
ok($zip->set_number('9970805')->is_valid_number, '山形県鶴岡市我老林');
ok($zip->set_number('9970806')->is_valid_number, '山形県鶴岡市遠賀原');
ok($zip->set_number('9970807')->is_valid_number, '山形県鶴岡市八ツ興屋');
ok($zip->set_number('9970808')->is_valid_number, '山形県鶴岡市苗津');
ok($zip->set_number('9970809')->is_valid_number, '山形県鶴岡市苗津町');
ok($zip->set_number('9970811')->is_valid_number, '山形県鶴岡市神明町');
ok($zip->set_number('9970812')->is_valid_number, '山形県鶴岡市長者町');
ok($zip->set_number('9970813')->is_valid_number, '山形県鶴岡市千石町');
ok($zip->set_number('9970814')->is_valid_number, '山形県鶴岡市城南町');
ok($zip->set_number('9970815')->is_valid_number, '山形県鶴岡市外内島');
ok($zip->set_number('9970816')->is_valid_number, '山形県鶴岡市文園町');
ok($zip->set_number('9970817')->is_valid_number, '山形県鶴岡市睦町');
ok($zip->set_number('9970818')->is_valid_number, '山形県鶴岡市三和町');
ok($zip->set_number('9970819')->is_valid_number, '山形県鶴岡市のぞみ町');
ok($zip->set_number('9970821')->is_valid_number, '山形県鶴岡市三光町');
ok($zip->set_number('9970822')->is_valid_number, '山形県鶴岡市双葉町');
ok($zip->set_number('9970823')->is_valid_number, '山形県鶴岡市海老島町');
ok($zip->set_number('9970824')->is_valid_number, '山形県鶴岡市日枝');
ok($zip->set_number('9970825')->is_valid_number, '山形県鶴岡市小真木原町');
ok($zip->set_number('9970826')->is_valid_number, '山形県鶴岡市美原町');
ok($zip->set_number('9970827')->is_valid_number, '山形県鶴岡市陽光町');
ok($zip->set_number('9970831')->is_valid_number, '山形県鶴岡市大西町');
ok($zip->set_number('9970832')->is_valid_number, '山形県鶴岡市青柳町');
ok($zip->set_number('9970833')->is_valid_number, '山形県鶴岡市柳田');
ok($zip->set_number('9970834')->is_valid_number, '山形県鶴岡市稲生');
ok($zip->set_number('9970835')->is_valid_number, '山形県鶴岡市番田');
ok($zip->set_number('9970836')->is_valid_number, '山形県鶴岡市寺田');
ok($zip->set_number('9970837')->is_valid_number, '山形県鶴岡市道田町');
ok($zip->set_number('9970838')->is_valid_number, '山形県鶴岡市淀川町');
ok($zip->set_number('9970839')->is_valid_number, '山形県鶴岡市砂田町');
ok($zip->set_number('9970841')->is_valid_number, '山形県鶴岡市白山');
ok($zip->set_number('9970842')->is_valid_number, '山形県鶴岡市井岡');
ok($zip->set_number('9970843')->is_valid_number, '山形県鶴岡市岡山');
ok($zip->set_number('9970844')->is_valid_number, '山形県鶴岡市森片');
ok($zip->set_number('9970845')->is_valid_number, '山形県鶴岡市下清水');
ok($zip->set_number('9970846')->is_valid_number, '山形県鶴岡市中清水');
ok($zip->set_number('9970847')->is_valid_number, '山形県鶴岡市上清水');
ok($zip->set_number('9970848')->is_valid_number, '山形県鶴岡市清水新田');
ok($zip->set_number('9970851')->is_valid_number, '山形県鶴岡市布目');
ok($zip->set_number('9970852')->is_valid_number, '山形県鶴岡市新斎部');
ok($zip->set_number('9970853')->is_valid_number, '山形県鶴岡市小淀川');
ok($zip->set_number('9970854')->is_valid_number, '山形県鶴岡市大淀川');
ok($zip->set_number('9970855')->is_valid_number, '山形県鶴岡市矢馳');
ok($zip->set_number('9970856')->is_valid_number, '山形県鶴岡市山田');
ok($zip->set_number('9970857')->is_valid_number, '山形県鶴岡市美咲町');
ok($zip->set_number('9970861')->is_valid_number, '山形県鶴岡市桜新町');
ok($zip->set_number('9970862')->is_valid_number, '山形県鶴岡市ほなみ町');
ok($zip->set_number('9971111')->is_valid_number, '山形県鶴岡市茨新田');
ok($zip->set_number('9971112')->is_valid_number, '山形県鶴岡市西沼');
ok($zip->set_number('9971113')->is_valid_number, '山形県鶴岡市長崎');
ok($zip->set_number('9971114')->is_valid_number, '山形県鶴岡市千安京田');
ok($zip->set_number('9971115')->is_valid_number, '山形県鶴岡市辻興屋');
ok($zip->set_number('9971116')->is_valid_number, '山形県鶴岡市面野山');
ok($zip->set_number('9971117')->is_valid_number, '山形県鶴岡市下川');
ok($zip->set_number('9971121')->is_valid_number, '山形県鶴岡市大山(その他)');
ok($zip->set_number('9971122')->is_valid_number, '山形県鶴岡市友江');
ok($zip->set_number('9971123')->is_valid_number, '山形県鶴岡市友江町');
ok($zip->set_number('9971124')->is_valid_number, '山形県鶴岡市大山(丁目)');
ok($zip->set_number('9971125')->is_valid_number, '山形県鶴岡市馬町');
ok($zip->set_number('9971131')->is_valid_number, '山形県鶴岡市菱津');
ok($zip->set_number('9971132')->is_valid_number, '山形県鶴岡市栃屋');
ok($zip->set_number('9971133')->is_valid_number, '山形県鶴岡市下興屋');
ok($zip->set_number('9971134')->is_valid_number, '山形県鶴岡市下小中');
ok($zip->set_number('9971135')->is_valid_number, '山形県鶴岡市中楯');
ok($zip->set_number('9971156')->is_valid_number, '山形県鶴岡市平成町');
ok($zip->set_number('9971201')->is_valid_number, '山形県鶴岡市湯野浜');
ok($zip->set_number('9971202')->is_valid_number, '山形県鶴岡市宮沢');
ok($zip->set_number('9971203')->is_valid_number, '山形県鶴岡市金沢');
ok($zip->set_number('9971204')->is_valid_number, '山形県鶴岡市加茂');
ok($zip->set_number('9971205')->is_valid_number, '山形県鶴岡市油戸');
ok($zip->set_number('9971206')->is_valid_number, '山形県鶴岡市今泉');
ok($zip->set_number('9971300')->is_valid_number, '山形県東田川郡三川町以下に掲載がない場合');
ok($zip->set_number('9971301')->is_valid_number, '山形県東田川郡三川町横山');
ok($zip->set_number('9971311')->is_valid_number, '山形県東田川郡三川町青山');
ok($zip->set_number('9971312')->is_valid_number, '山形県東田川郡三川町善阿弥');
ok($zip->set_number('9971313')->is_valid_number, '山形県東田川郡三川町角田二口');
ok($zip->set_number('9971314')->is_valid_number, '山形県東田川郡三川町東沼');
ok($zip->set_number('9971315')->is_valid_number, '山形県東田川郡三川町神花');
ok($zip->set_number('9971316')->is_valid_number, '山形県東田川郡三川町猪子');
ok($zip->set_number('9971317')->is_valid_number, '山形県東田川郡三川町成田新田');
ok($zip->set_number('9971321')->is_valid_number, '山形県東田川郡三川町押切新田');
ok($zip->set_number('9971322')->is_valid_number, '山形県東田川郡三川町土口');
ok($zip->set_number('9971331')->is_valid_number, '山形県東田川郡三川町助川');
ok($zip->set_number('9971332')->is_valid_number, '山形県東田川郡三川町堤野');
ok($zip->set_number('9971333')->is_valid_number, '山形県東田川郡三川町横内');
ok($zip->set_number('9971334')->is_valid_number, '山形県東田川郡三川町竹原田');
ok($zip->set_number('9971335')->is_valid_number, '山形県東田川郡三川町菱沼');
ok($zip->set_number('9971336')->is_valid_number, '山形県東田川郡三川町加藤');
ok($zip->set_number('9971337')->is_valid_number, '山形県東田川郡三川町小尺');
ok($zip->set_number('9971338')->is_valid_number, '山形県東田川郡三川町横川');
ok($zip->set_number('9971339')->is_valid_number, '山形県東田川郡三川町横川新田');
ok($zip->set_number('9980000')->is_valid_number, '山形県酒田市以下に掲載がない場合');
ok($zip->set_number('9980001')->is_valid_number, '山形県酒田市穂積(その他)');
ok($zip->set_number('9980002')->is_valid_number, '山形県酒田市藤塚');
ok($zip->set_number('9980003')->is_valid_number, '山形県酒田市酒井新田');
ok($zip->set_number('9980004')->is_valid_number, '山形県酒田市豊里');
ok($zip->set_number('9980005')->is_valid_number, '山形県酒田市宮海');
ok($zip->set_number('9980006')->is_valid_number, '山形県酒田市ゆたか');
ok($zip->set_number('9980011')->is_valid_number, '山形県酒田市上安町');
ok($zip->set_number('9980012')->is_valid_number, '山形県酒田市下安町');
ok($zip->set_number('9980013')->is_valid_number, '山形県酒田市東泉町');
ok($zip->set_number('9980014')->is_valid_number, '山形県酒田市千日町');
ok($zip->set_number('9980015')->is_valid_number, '山形県酒田市北千日堂前');
ok($zip->set_number('9980016')->is_valid_number, '山形県酒田市北千日町');
ok($zip->set_number('9980017')->is_valid_number, '山形県酒田市西野町');
ok($zip->set_number('9980018')->is_valid_number, '山形県酒田市泉町');
ok($zip->set_number('9980021')->is_valid_number, '山形県酒田市旭新町');
ok($zip->set_number('9980022')->is_valid_number, '山形県酒田市駅東');
ok($zip->set_number('9980023')->is_valid_number, '山形県酒田市幸町');
ok($zip->set_number('9980024')->is_valid_number, '山形県酒田市御成町');
ok($zip->set_number('9980025')->is_valid_number, '山形県酒田市南千日町');
ok($zip->set_number('9980026')->is_valid_number, '山形県酒田市栄町');
ok($zip->set_number('9980027')->is_valid_number, '山形県酒田市北今町');
ok($zip->set_number('9980028')->is_valid_number, '山形県酒田市北里町');
ok($zip->set_number('9980029')->is_valid_number, '山形県酒田市住吉町');
ok($zip->set_number('9980031')->is_valid_number, '山形県酒田市浜田');
ok($zip->set_number('9980032')->is_valid_number, '山形県酒田市相生町');
ok($zip->set_number('9980033')->is_valid_number, '山形県酒田市中央東町');
ok($zip->set_number('9980034')->is_valid_number, '山形県酒田市中央西町');
ok($zip->set_number('9980035')->is_valid_number, '山形県酒田市寿町');
ok($zip->set_number('9980036')->is_valid_number, '山形県酒田市船場町');
ok($zip->set_number('9980037')->is_valid_number, '山形県酒田市日吉町');
ok($zip->set_number('9980041')->is_valid_number, '山形県酒田市新井田町');
ok($zip->set_number('9980042')->is_valid_number, '山形県酒田市上本町');
ok($zip->set_number('9980043')->is_valid_number, '山形県酒田市本町(1~3丁目)');
ok($zip->set_number('9980044')->is_valid_number, '山形県酒田市中町');
ok($zip->set_number('9980045')->is_valid_number, '山形県酒田市二番町');
ok($zip->set_number('9980046')->is_valid_number, '山形県酒田市一番町');
ok($zip->set_number('9980051')->is_valid_number, '山形県酒田市高見台');
ok($zip->set_number('9980052')->is_valid_number, '山形県酒田市緑ケ丘');
ok($zip->set_number('9980053')->is_valid_number, '山形県酒田市若宮町');
ok($zip->set_number('9980054')->is_valid_number, '山形県酒田市宮野浦');
ok($zip->set_number('9980055')->is_valid_number, '山形県酒田市飯森山');
ok($zip->set_number('9980061')->is_valid_number, '山形県酒田市光ケ丘');
ok($zip->set_number('9980062')->is_valid_number, '山形県酒田市北新町');
ok($zip->set_number('9980063')->is_valid_number, '山形県酒田市南新町');
ok($zip->set_number('9980064')->is_valid_number, '山形県酒田市大浜');
ok($zip->set_number('9980071')->is_valid_number, '山形県酒田市古湊町');
ok($zip->set_number('9980072')->is_valid_number, '山形県酒田市北浜町');
ok($zip->set_number('9980073')->is_valid_number, '山形県酒田市松美町');
ok($zip->set_number('9980074')->is_valid_number, '山形県酒田市浜松町');
ok($zip->set_number('9980075')->is_valid_number, '山形県酒田市高砂');
ok($zip->set_number('9980101')->is_valid_number, '山形県酒田市坂野辺新田');
ok($zip->set_number('9980102')->is_valid_number, '山形県酒田市京田');
ok($zip->set_number('9980103')->is_valid_number, '山形県酒田市錦町');
ok($zip->set_number('9980104')->is_valid_number, '山形県酒田市広栄町');
ok($zip->set_number('9980105')->is_valid_number, '山形県酒田市広野新田');
ok($zip->set_number('9980111')->is_valid_number, '山形県酒田市黒森');
ok($zip->set_number('9980112')->is_valid_number, '山形県酒田市浜中');
ok($zip->set_number('9980113')->is_valid_number, '山形県酒田市広岡新田');
ok($zip->set_number('9980114')->is_valid_number, '山形県酒田市十里塚');
ok($zip->set_number('9980125')->is_valid_number, '山形県酒田市広野');
ok($zip->set_number('9980281')->is_valid_number, '山形県酒田市飛島');
ok($zip->set_number('9980801')->is_valid_number, '山形県酒田市北沢');
ok($zip->set_number('9980802')->is_valid_number, '山形県酒田市生石');
ok($zip->set_number('9980803')->is_valid_number, '山形県酒田市大槻新田');
ok($zip->set_number('9980804')->is_valid_number, '山形県酒田市横代');
ok($zip->set_number('9980805')->is_valid_number, '山形県酒田市関');
ok($zip->set_number('9980806')->is_valid_number, '山形県酒田市境興野');
ok($zip->set_number('9980811')->is_valid_number, '山形県酒田市手蔵田');
ok($zip->set_number('9980812')->is_valid_number, '山形県酒田市本川');
ok($zip->set_number('9980813')->is_valid_number, '山形県酒田市茨野新田');
ok($zip->set_number('9980814')->is_valid_number, '山形県酒田市小牧新田');
ok($zip->set_number('9980815')->is_valid_number, '山形県酒田市小牧');
ok($zip->set_number('9980816')->is_valid_number, '山形県酒田市大野新田');
ok($zip->set_number('9980817')->is_valid_number, '山形県酒田市熊手島');
ok($zip->set_number('9980818')->is_valid_number, '山形県酒田市勝保関');
ok($zip->set_number('9980819')->is_valid_number, '山形県酒田市熊野田');
ok($zip->set_number('9980821')->is_valid_number, '山形県酒田市遊摺部');
ok($zip->set_number('9980822')->is_valid_number, '山形県酒田市大宮');
ok($zip->set_number('9980823')->is_valid_number, '山形県酒田市卸町');
ok($zip->set_number('9980824')->is_valid_number, '山形県酒田市大宮町');
ok($zip->set_number('9980826')->is_valid_number, '山形県酒田市初瀬');
ok($zip->set_number('9980827')->is_valid_number, '山形県酒田市草刈谷地');
ok($zip->set_number('9980828')->is_valid_number, '山形県酒田市あきほ町');
ok($zip->set_number('9980829')->is_valid_number, '山形県酒田市仁助谷地');
ok($zip->set_number('9980831')->is_valid_number, '山形県酒田市東両羽町');
ok($zip->set_number('9980832')->is_valid_number, '山形県酒田市両羽町');
ok($zip->set_number('9980833')->is_valid_number, '山形県酒田市若原町');
ok($zip->set_number('9980834')->is_valid_number, '山形県酒田市若竹町');
ok($zip->set_number('9980835')->is_valid_number, '山形県酒田市堤町');
ok($zip->set_number('9980836')->is_valid_number, '山形県酒田市入船町');
ok($zip->set_number('9980837')->is_valid_number, '山形県酒田市下瀬');
ok($zip->set_number('9980838')->is_valid_number, '山形県酒田市山居町');
ok($zip->set_number('9980841')->is_valid_number, '山形県酒田市松原南');
ok($zip->set_number('9980842')->is_valid_number, '山形県酒田市亀ケ崎');
ok($zip->set_number('9980843')->is_valid_number, '山形県酒田市千石町');
ok($zip->set_number('9980851')->is_valid_number, '山形県酒田市東大町');
ok($zip->set_number('9980852')->is_valid_number, '山形県酒田市こがね町');
ok($zip->set_number('9980853')->is_valid_number, '山形県酒田市みずほ');
ok($zip->set_number('9980854')->is_valid_number, '山形県酒田市末広町');
ok($zip->set_number('9980855')->is_valid_number, '山形県酒田市東中の口町');
ok($zip->set_number('9980856')->is_valid_number, '山形県酒田市東栄町');
ok($zip->set_number('9980857')->is_valid_number, '山形県酒田市若浜町');
ok($zip->set_number('9980858')->is_valid_number, '山形県酒田市緑町');
ok($zip->set_number('9980859')->is_valid_number, '山形県酒田市大町');
ok($zip->set_number('9980861')->is_valid_number, '山形県酒田市富士見町');
ok($zip->set_number('9980862')->is_valid_number, '山形県酒田市曙町');
ok($zip->set_number('9980863')->is_valid_number, '山形県酒田市日の出町');
ok($zip->set_number('9980864')->is_valid_number, '山形県酒田市新橋');
ok($zip->set_number('9980865')->is_valid_number, '山形県酒田市北新橋');
ok($zip->set_number('9980871')->is_valid_number, '山形県酒田市荻島');
ok($zip->set_number('9980872')->is_valid_number, '山形県酒田市中野新田');
ok($zip->set_number('9980873')->is_valid_number, '山形県酒田市土崎');
ok($zip->set_number('9980874')->is_valid_number, '山形県酒田市四ツ興野');
ok($zip->set_number('9980875')->is_valid_number, '山形県酒田市東町');
ok($zip->set_number('9980876')->is_valid_number, '山形県酒田市古荒新田');
ok($zip->set_number('9980877')->is_valid_number, '山形県酒田市大多新田');
ok($zip->set_number('9980878')->is_valid_number, '山形県酒田市こあら');
ok($zip->set_number('9990100')->is_valid_number, '山形県東置賜郡川西町以下に掲載がない場合');
ok($zip->set_number('9990121')->is_valid_number, '山形県東置賜郡川西町上小松');
ok($zip->set_number('9990122')->is_valid_number, '山形県東置賜郡川西町中小松');
ok($zip->set_number('9990131')->is_valid_number, '山形県東置賜郡川西町黒川');
ok($zip->set_number('9990132')->is_valid_number, '山形県東置賜郡川西町高豆蒄');
ok($zip->set_number('9990133')->is_valid_number, '山形県東置賜郡川西町小松');
ok($zip->set_number('9990134')->is_valid_number, '山形県東置賜郡川西町下小松');
ok($zip->set_number('9990141')->is_valid_number, '山形県東置賜郡川西町高山');
ok($zip->set_number('9990142')->is_valid_number, '山形県東置賜郡川西町堀金');
ok($zip->set_number('9990143')->is_valid_number, '山形県東置賜郡川西町莅');
ok($zip->set_number('9990144')->is_valid_number, '山形県東置賜郡川西町時田');
ok($zip->set_number('9990145')->is_valid_number, '山形県東置賜郡川西町下奥田');
ok($zip->set_number('9990151')->is_valid_number, '山形県東置賜郡川西町大舟');
ok($zip->set_number('9990152')->is_valid_number, '山形県東置賜郡川西町上奥田');
ok($zip->set_number('9990153')->is_valid_number, '山形県東置賜郡川西町朴沢');
ok($zip->set_number('9990211')->is_valid_number, '山形県東置賜郡川西町洲島');
ok($zip->set_number('9990212')->is_valid_number, '山形県東置賜郡川西町下平柳');
ok($zip->set_number('9990213')->is_valid_number, '山形県東置賜郡川西町尾長島');
ok($zip->set_number('9990214')->is_valid_number, '山形県東置賜郡川西町吉田');
ok($zip->set_number('9990361')->is_valid_number, '山形県東置賜郡川西町玉庭');
ok($zip->set_number('9990421')->is_valid_number, '山形県西置賜郡飯豊町小屋');
ok($zip->set_number('9990422')->is_valid_number, '山形県西置賜郡飯豊町広河原');
ok($zip->set_number('9990423')->is_valid_number, '山形県西置賜郡飯豊町須郷');
ok($zip->set_number('9990424')->is_valid_number, '山形県西置賜郡飯豊町数馬');
ok($zip->set_number('9990425')->is_valid_number, '山形県西置賜郡飯豊町宇津沢');
ok($zip->set_number('9990426')->is_valid_number, '山形県西置賜郡飯豊町遅谷');
ok($zip->set_number('9990427')->is_valid_number, '山形県西置賜郡飯豊町上原');
ok($zip->set_number('9990431')->is_valid_number, '山形県西置賜郡飯豊町下屋地');
ok($zip->set_number('9990432')->is_valid_number, '山形県西置賜郡飯豊町白川');
ok($zip->set_number('9990433')->is_valid_number, '山形県西置賜郡飯豊町上屋地');
ok($zip->set_number('9990434')->is_valid_number, '山形県西置賜郡飯豊町川内戸');
ok($zip->set_number('9990435')->is_valid_number, '山形県西置賜郡飯豊町高造路');
ok($zip->set_number('9990436')->is_valid_number, '山形県西置賜郡飯豊町岩倉');
ok($zip->set_number('9990600')->is_valid_number, '山形県西置賜郡飯豊町以下に掲載がない場合');
ok($zip->set_number('9990601')->is_valid_number, '山形県西置賜郡飯豊町中');
ok($zip->set_number('9990602')->is_valid_number, '山形県西置賜郡飯豊町萩生');
ok($zip->set_number('9990603')->is_valid_number, '山形県西置賜郡飯豊町黒沢');
ok($zip->set_number('9990604')->is_valid_number, '山形県西置賜郡飯豊町椿');
ok($zip->set_number('9990605')->is_valid_number, '山形県西置賜郡飯豊町添川');
ok($zip->set_number('9990606')->is_valid_number, '山形県西置賜郡飯豊町松原');
ok($zip->set_number('9991111')->is_valid_number, '山形県西置賜郡飯豊町手ノ子');
ok($zip->set_number('9991112')->is_valid_number, '山形県西置賜郡飯豊町高峰');
ok($zip->set_number('9991113')->is_valid_number, '山形県西置賜郡飯豊町小白川');
ok($zip->set_number('9991201')->is_valid_number, '山形県西置賜郡小国町沼沢');
ok($zip->set_number('9991202')->is_valid_number, '山形県西置賜郡小国町白子沢');
ok($zip->set_number('9991203')->is_valid_number, '山形県西置賜郡小国町市野々');
ok($zip->set_number('9991211')->is_valid_number, '山形県西置賜郡小国町叶水');
ok($zip->set_number('9991212')->is_valid_number, '山形県西置賜郡小国町大石沢');
ok($zip->set_number('9991213')->is_valid_number, '山形県西置賜郡小国町新股');
ok($zip->set_number('9991214')->is_valid_number, '山形県西置賜郡小国町河原角');
ok($zip->set_number('9991215')->is_valid_number, '山形県西置賜郡小国町西滝');
ok($zip->set_number('9991216')->is_valid_number, '山形県西置賜郡小国町東滝');
ok($zip->set_number('9991300')->is_valid_number, '山形県西置賜郡小国町以下に掲載がない場合');
ok($zip->set_number('9991301')->is_valid_number, '山形県西置賜郡小国町金目');
ok($zip->set_number('9991302')->is_valid_number, '山形県西置賜郡小国町古田');
ok($zip->set_number('9991303')->is_valid_number, '山形県西置賜郡小国町若山');
ok($zip->set_number('9991311')->is_valid_number, '山形県西置賜郡小国町貝少');
ok($zip->set_number('9991312')->is_valid_number, '山形県西置賜郡小国町小渡');
ok($zip->set_number('9991313')->is_valid_number, '山形県西置賜郡小国町針生');
ok($zip->set_number('9991314')->is_valid_number, '山形県西置賜郡小国町新屋敷');
ok($zip->set_number('9991321')->is_valid_number, '山形県西置賜郡小国町綱木箱口');
ok($zip->set_number('9991322')->is_valid_number, '山形県西置賜郡小国町伊佐領');
ok($zip->set_number('9991323')->is_valid_number, '山形県西置賜郡小国町朝篠');
ok($zip->set_number('9991324')->is_valid_number, '山形県西置賜郡小国町松岡');
ok($zip->set_number('9991331')->is_valid_number, '山形県西置賜郡小国町東原');
ok($zip->set_number('9991332')->is_valid_number, '山形県西置賜郡小国町町原');
ok($zip->set_number('9991333')->is_valid_number, '山形県西置賜郡小国町芹出');
ok($zip->set_number('9991334')->is_valid_number, '山形県西置賜郡小国町黒沢');
ok($zip->set_number('9991335')->is_valid_number, '山形県西置賜郡小国町種沢');
ok($zip->set_number('9991336')->is_valid_number, '山形県西置賜郡小国町大滝');
ok($zip->set_number('9991337')->is_valid_number, '山形県西置賜郡小国町新原');
ok($zip->set_number('9991338')->is_valid_number, '山形県西置賜郡小国町杉沢');
ok($zip->set_number('9991339')->is_valid_number, '山形県西置賜郡小国町小倉');
ok($zip->set_number('9991341')->is_valid_number, '山形県西置賜郡小国町増岡');
ok($zip->set_number('9991342')->is_valid_number, '山形県西置賜郡小国町大宮');
ok($zip->set_number('9991343')->is_valid_number, '山形県西置賜郡小国町宮の台');
ok($zip->set_number('9991344')->is_valid_number, '山形県西置賜郡小国町田沢頭');
ok($zip->set_number('9991345')->is_valid_number, '山形県西置賜郡小国町北');
ok($zip->set_number('9991346')->is_valid_number, '山形県西置賜郡小国町湯ノ花');
ok($zip->set_number('9991351')->is_valid_number, '山形県西置賜郡小国町小国町');
ok($zip->set_number('9991352')->is_valid_number, '山形県西置賜郡小国町岩井沢');
ok($zip->set_number('9991353')->is_valid_number, '山形県西置賜郡小国町兵庫舘');
ok($zip->set_number('9991354')->is_valid_number, '山形県西置賜郡小国町幸町');
ok($zip->set_number('9991355')->is_valid_number, '山形県西置賜郡小国町西');
ok($zip->set_number('9991356')->is_valid_number, '山形県西置賜郡小国町あけぼの');
ok($zip->set_number('9991361')->is_valid_number, '山形県西置賜郡小国町栄町');
ok($zip->set_number('9991362')->is_valid_number, '山形県西置賜郡小国町緑町');
ok($zip->set_number('9991363')->is_valid_number, '山形県西置賜郡小国町小国小坂町');
ok($zip->set_number('9991401')->is_valid_number, '山形県西置賜郡小国町舟渡');
ok($zip->set_number('9991402')->is_valid_number, '山形県西置賜郡小国町網代瀬');
ok($zip->set_number('9991411')->is_valid_number, '山形県西置賜郡小国町松崎');
ok($zip->set_number('9991412')->is_valid_number, '山形県西置賜郡小国町尻無沢');
ok($zip->set_number('9991413')->is_valid_number, '山形県西置賜郡小国町今市');
ok($zip->set_number('9991414')->is_valid_number, '山形県西置賜郡小国町栃倉');
ok($zip->set_number('9991421')->is_valid_number, '山形県西置賜郡小国町越中里');
ok($zip->set_number('9991422')->is_valid_number, '山形県西置賜郡小国町長沢');
ok($zip->set_number('9991431')->is_valid_number, '山形県西置賜郡小国町焼山');
ok($zip->set_number('9991432')->is_valid_number, '山形県西置賜郡小国町中島');
ok($zip->set_number('9991433')->is_valid_number, '山形県西置賜郡小国町樋ノ沢');
ok($zip->set_number('9991434')->is_valid_number, '山形県西置賜郡小国町荒沢');
ok($zip->set_number('9991435')->is_valid_number, '山形県西置賜郡小国町入折戸');
ok($zip->set_number('9991436')->is_valid_number, '山形県西置賜郡小国町折戸');
ok($zip->set_number('9991441')->is_valid_number, '山形県西置賜郡小国町驚');
ok($zip->set_number('9991442')->is_valid_number, '山形県西置賜郡小国町太鼓沢');
ok($zip->set_number('9991443')->is_valid_number, '山形県西置賜郡小国町小股');
ok($zip->set_number('9991451')->is_valid_number, '山形県西置賜郡小国町石滝');
ok($zip->set_number('9991452')->is_valid_number, '山形県西置賜郡小国町五味沢');
ok($zip->set_number('9991501')->is_valid_number, '山形県西置賜郡小国町樽口');
ok($zip->set_number('9991502')->is_valid_number, '山形県西置賜郡小国町滝倉');
ok($zip->set_number('9991503')->is_valid_number, '山形県西置賜郡小国町菅沼');
ok($zip->set_number('9991504')->is_valid_number, '山形県西置賜郡小国町足水中里');
ok($zip->set_number('9991505')->is_valid_number, '山形県西置賜郡小国町百子沢');
ok($zip->set_number('9991506')->is_valid_number, '山形県西置賜郡小国町市野沢');
ok($zip->set_number('9991507')->is_valid_number, '山形県西置賜郡小国町足野水');
ok($zip->set_number('9991511')->is_valid_number, '山形県西置賜郡小国町玉川');
ok($zip->set_number('9991512')->is_valid_number, '山形県西置賜郡小国町片貝');
ok($zip->set_number('9991513')->is_valid_number, '山形県西置賜郡小国町中田山崎');
ok($zip->set_number('9991514')->is_valid_number, '山形県西置賜郡小国町玉川中里');
ok($zip->set_number('9991521')->is_valid_number, '山形県西置賜郡小国町泉岡');
ok($zip->set_number('9991522')->is_valid_number, '山形県西置賜郡小国町小玉川');
ok($zip->set_number('9992171')->is_valid_number, '山形県東置賜郡高畠町石岡');
ok($zip->set_number('9992172')->is_valid_number, '山形県東置賜郡高畠町夏茂');
ok($zip->set_number('9992173')->is_valid_number, '山形県東置賜郡高畠町山崎');
ok($zip->set_number('9992174')->is_valid_number, '山形県東置賜郡高畠町福沢');
ok($zip->set_number('9992175')->is_valid_number, '山形県東置賜郡高畠町福沢南');
ok($zip->set_number('9992176')->is_valid_number, '山形県東置賜郡高畠町糠野目');
ok($zip->set_number('9992177')->is_valid_number, '山形県東置賜郡高畠町小其塚');
ok($zip->set_number('9992178')->is_valid_number, '山形県東置賜郡高畠町上平柳');
ok($zip->set_number('9992179')->is_valid_number, '山形県東置賜郡高畠町蛇口');
ok($zip->set_number('9992200')->is_valid_number, '山形県南陽市以下に掲載がない場合');
ok($zip->set_number('9992201')->is_valid_number, '山形県南陽市釜渡戸');
ok($zip->set_number('9992202')->is_valid_number, '山形県南陽市元中山');
ok($zip->set_number('9992203')->is_valid_number, '山形県南陽市小岩沢');
ok($zip->set_number('9992204')->is_valid_number, '山形県南陽市川樋');
ok($zip->set_number('9992205')->is_valid_number, '山形県南陽市新田');
ok($zip->set_number('9992211')->is_valid_number, '山形県南陽市赤湯');
ok($zip->set_number('9992212')->is_valid_number, '山形県南陽市金沢');
ok($zip->set_number('9992213')->is_valid_number, '山形県南陽市松沢');
ok($zip->set_number('9992221')->is_valid_number, '山形県南陽市椚塚');
ok($zip->set_number('9992222')->is_valid_number, '山形県南陽市長岡');
ok($zip->set_number('9992223')->is_valid_number, '山形県南陽市俎柳');
ok($zip->set_number('9992224')->is_valid_number, '山形県南陽市大橋');
ok($zip->set_number('9992231')->is_valid_number, '山形県南陽市二色根');
ok($zip->set_number('9992232')->is_valid_number, '山形県南陽市三間通');
ok($zip->set_number('9992233')->is_valid_number, '山形県南陽市上野');
ok($zip->set_number('9992234')->is_valid_number, '山形県南陽市中央東');
ok($zip->set_number('9992241')->is_valid_number, '山形県南陽市郡山');
ok($zip->set_number('9992242')->is_valid_number, '山形県南陽市中ノ目');
ok($zip->set_number('9992243')->is_valid_number, '山形県南陽市鍋田');
ok($zip->set_number('9992244')->is_valid_number, '山形県南陽市島貫');
ok($zip->set_number('9992251')->is_valid_number, '山形県南陽市高梨');
ok($zip->set_number('9992252')->is_valid_number, '山形県南陽市沖田');
ok($zip->set_number('9992253')->is_valid_number, '山形県南陽市宮崎');
ok($zip->set_number('9992254')->is_valid_number, '山形県南陽市露橋');
ok($zip->set_number('9992255')->is_valid_number, '山形県南陽市関根');
ok($zip->set_number('9992256')->is_valid_number, '山形県南陽市坂井');
ok($zip->set_number('9992261')->is_valid_number, '山形県南陽市蒲生田');
ok($zip->set_number('9992262')->is_valid_number, '山形県南陽市若狭郷屋');
ok($zip->set_number('9992263')->is_valid_number, '山形県南陽市萩生田');
ok($zip->set_number('9992264')->is_valid_number, '山形県南陽市中落合');
ok($zip->set_number('9992265')->is_valid_number, '山形県南陽市西落合');
ok($zip->set_number('9992266')->is_valid_number, '山形県南陽市長瀞');
ok($zip->set_number('9992267')->is_valid_number, '山形県南陽市法師柳');
ok($zip->set_number('9993100')->is_valid_number, '山形県上山市以下に掲載がない場合');
ok($zip->set_number('9993101')->is_valid_number, '山形県上山市金瓶');
ok($zip->set_number('9993102')->is_valid_number, '山形県上山市新金谷');
ok($zip->set_number('9993103')->is_valid_number, '山形県上山市金谷');
ok($zip->set_number('9993104')->is_valid_number, '山形県上山市蔵王の森');
ok($zip->set_number('9993105')->is_valid_number, '山形県上山市泉川');
ok($zip->set_number('9993106')->is_valid_number, '山形県上山市旭町');
ok($zip->set_number('9993107')->is_valid_number, '山形県上山市みはらしの丘');
ok($zip->set_number('9993111')->is_valid_number, '山形県上山市権現堂');
ok($zip->set_number('9993112')->is_valid_number, '山形県上山市小倉');
ok($zip->set_number('9993113')->is_valid_number, '山形県上山市蔵王');
ok($zip->set_number('9993114')->is_valid_number, '山形県上山市永野');
ok($zip->set_number('9993115')->is_valid_number, '山形県上山市高野');
ok($zip->set_number('9993121')->is_valid_number, '山形県上山市東町');
ok($zip->set_number('9993122')->is_valid_number, '山形県上山市仙石');
ok($zip->set_number('9993123')->is_valid_number, '山形県上山市美咲町');
ok($zip->set_number('9993124')->is_valid_number, '山形県上山市金生');
ok($zip->set_number('9993125')->is_valid_number, '山形県上山市金生東');
ok($zip->set_number('9993126')->is_valid_number, '山形県上山市金生西');
ok($zip->set_number('9993131')->is_valid_number, '山形県上山市北町');
ok($zip->set_number('9993132')->is_valid_number, '山形県上山市栄町');
ok($zip->set_number('9993133')->is_valid_number, '山形県上山市八日町');
ok($zip->set_number('9993134')->is_valid_number, '山形県上山市矢来');
ok($zip->set_number('9993135')->is_valid_number, '山形県上山市南町');
ok($zip->set_number('9993141')->is_valid_number, '山形県上山市新湯');
ok($zip->set_number('9993142')->is_valid_number, '山形県上山市沢丁');
ok($zip->set_number('9993143')->is_valid_number, '山形県上山市二日町');
ok($zip->set_number('9993144')->is_valid_number, '山形県上山市石崎');
ok($zip->set_number('9993145')->is_valid_number, '山形県上山市河崎');
ok($zip->set_number('9993146')->is_valid_number, '山形県上山市松山');
ok($zip->set_number('9993151')->is_valid_number, '山形県上山市北町本丁');
ok($zip->set_number('9993152')->is_valid_number, '山形県上山市新丁');
ok($zip->set_number('9993153')->is_valid_number, '山形県上山市十日町');
ok($zip->set_number('9993154')->is_valid_number, '山形県上山市元城内');
ok($zip->set_number('9993155')->is_valid_number, '山形県上山市鶴脛町');
ok($zip->set_number('9993156')->is_valid_number, '山形県上山市湯町');
ok($zip->set_number('9993157')->is_valid_number, '山形県上山市御井戸丁');
ok($zip->set_number('9993158')->is_valid_number, '山形県上山市新町');
ok($zip->set_number('9993161')->is_valid_number, '山形県上山市弁天');
ok($zip->set_number('9993162')->is_valid_number, '山形県上山市四ツ谷');
ok($zip->set_number('9993163')->is_valid_number, '山形県上山市軽井沢');
ok($zip->set_number('9993164')->is_valid_number, '山形県上山市朝日台');
ok($zip->set_number('9993165')->is_valid_number, '山形県上山市裏町');
ok($zip->set_number('9993166')->is_valid_number, '山形県上山市久保手');
ok($zip->set_number('9993167')->is_valid_number, '山形県上山市大石');
ok($zip->set_number('9993171')->is_valid_number, '山形県上山市狸森');
ok($zip->set_number('9993172')->is_valid_number, '山形県上山市小白府');
ok($zip->set_number('9993201')->is_valid_number, '山形県上山市宮脇');
ok($zip->set_number('9993202')->is_valid_number, '山形県上山市下生居');
ok($zip->set_number('9993203')->is_valid_number, '山形県上山市中生居');
ok($zip->set_number('9993204')->is_valid_number, '山形県上山市上生居');
ok($zip->set_number('9993211')->is_valid_number, '山形県上山市牧野');
ok($zip->set_number('9993212')->is_valid_number, '山形県上山市原口');
ok($zip->set_number('9993213')->is_valid_number, '山形県上山市須田板');
ok($zip->set_number('9993214')->is_valid_number, '山形県上山市小笹');
ok($zip->set_number('9993215')->is_valid_number, '山形県上山市久保川');
ok($zip->set_number('9993216')->is_valid_number, '山形県上山市大門');
ok($zip->set_number('9993217')->is_valid_number, '山形県上山市菖蒲');
ok($zip->set_number('9993221')->is_valid_number, '山形県上山市関根');
ok($zip->set_number('9993222')->is_valid_number, '山形県上山市相生');
ok($zip->set_number('9993223')->is_valid_number, '山形県上山市三上');
ok($zip->set_number('9993224')->is_valid_number, '山形県上山市皆沢');
ok($zip->set_number('9993225')->is_valid_number, '山形県上山市楢下');
ok($zip->set_number('9993226')->is_valid_number, '山形県上山市金山');
ok($zip->set_number('9993231')->is_valid_number, '山形県上山市石堂');
ok($zip->set_number('9993232')->is_valid_number, '山形県上山市長清水');
ok($zip->set_number('9993233')->is_valid_number, '山形県上山市三本松');
ok($zip->set_number('9993234')->is_valid_number, '山形県上山市藤吾');
ok($zip->set_number('9993235')->is_valid_number, '山形県上山市阿弥陀地');
ok($zip->set_number('9993236')->is_valid_number, '山形県上山市細谷');
ok($zip->set_number('9993237')->is_valid_number, '山形県上山市小穴');
ok($zip->set_number('9993241')->is_valid_number, '山形県上山市けやきの森');
ok($zip->set_number('9993242')->is_valid_number, '山形県上山市葉山');
ok($zip->set_number('9993243')->is_valid_number, '山形県上山市高松');
ok($zip->set_number('9993244')->is_valid_number, '山形県上山市石曽根');
ok($zip->set_number('9993245')->is_valid_number, '山形県上山市川口');
ok($zip->set_number('9993246')->is_valid_number, '山形県上山市中山');
ok($zip->set_number('9993301')->is_valid_number, '山形県山形市山寺');
ok($zip->set_number('9993500')->is_valid_number, '山形県西村山郡河北町以下に掲載がない場合');
ok($zip->set_number('9993501')->is_valid_number, '山形県西村山郡河北町新吉田');
ok($zip->set_number('9993502')->is_valid_number, '山形県西村山郡河北町吉田');
ok($zip->set_number('9993503')->is_valid_number, '山形県西村山郡河北町岩木');
ok($zip->set_number('9993511')->is_valid_number, '山形県西村山郡河北町谷地');
ok($zip->set_number('9993512')->is_valid_number, '山形県西村山郡河北町谷地中央');
ok($zip->set_number('9993513')->is_valid_number, '山形県西村山郡河北町谷地所岡');
ok($zip->set_number('9993514')->is_valid_number, '山形県西村山郡河北町谷地ひな市');
ok($zip->set_number('9993515')->is_valid_number, '山形県西村山郡河北町谷地荒町東');
ok($zip->set_number('9993521')->is_valid_number, '山形県西村山郡河北町田井');
ok($zip->set_number('9993522')->is_valid_number, '山形県西村山郡河北町溝延');
ok($zip->set_number('9993531')->is_valid_number, '山形県西村山郡河北町畑中');
ok($zip->set_number('9993532')->is_valid_number, '山形県西村山郡河北町造山');
ok($zip->set_number('9993533')->is_valid_number, '山形県西村山郡河北町西里');
ok($zip->set_number('9993700')->is_valid_number, '山形県東根市以下に掲載がない場合');
ok($zip->set_number('9993701')->is_valid_number, '山形県東根市東根甲');
ok($zip->set_number('9993702')->is_valid_number, '山形県東根市温泉町');
ok($zip->set_number('9993703')->is_valid_number, '山形県東根市鷺ノ森');
ok($zip->set_number('9993704')->is_valid_number, '山形県東根市東根丙');
ok($zip->set_number('9993705')->is_valid_number, '山形県東根市宮崎');
ok($zip->set_number('9993706')->is_valid_number, '山形県東根市三日町');
ok($zip->set_number('9993707')->is_valid_number, '山形県東根市新田町');
ok($zip->set_number('9993708')->is_valid_number, '山形県東根市下川原');
ok($zip->set_number('9993709')->is_valid_number, '山形県東根市六田');
ok($zip->set_number('9993710')->is_valid_number, '山形県東根市小林');
ok($zip->set_number('9993711')->is_valid_number, '山形県東根市中央');
ok($zip->set_number('9993712')->is_valid_number, '山形県東根市大森');
ok($zip->set_number('9993713')->is_valid_number, '山形県東根市東根丁');
ok($zip->set_number('9993714')->is_valid_number, '山形県東根市大林');
ok($zip->set_number('9993715')->is_valid_number, '山形県東根市大林新田');
ok($zip->set_number('9993716')->is_valid_number, '山形県東根市蟹沢');
ok($zip->set_number('9993717')->is_valid_number, '山形県東根市一本木');
ok($zip->set_number('9993718')->is_valid_number, '山形県東根市四ツ家');
ok($zip->set_number('9993719')->is_valid_number, '山形県東根市中央西');
ok($zip->set_number('9993720')->is_valid_number, '山形県東根市さくらんぼ駅前');
ok($zip->set_number('9993721')->is_valid_number, '山形県東根市東根乙');
ok($zip->set_number('9993722')->is_valid_number, '山形県東根市泉郷');
ok($zip->set_number('9993723')->is_valid_number, '山形県東根市観音寺');
ok($zip->set_number('9993724')->is_valid_number, '山形県東根市関山');
ok($zip->set_number('9993725')->is_valid_number, '山形県東根市沼沢');
ok($zip->set_number('9993726')->is_valid_number, '山形県東根市猪野沢');
ok($zip->set_number('9993727')->is_valid_number, '山形県東根市野川');
ok($zip->set_number('9993728')->is_valid_number, '山形県東根市太田新田');
ok($zip->set_number('9993729')->is_valid_number, '山形県東根市中央東');
ok($zip->set_number('9993730')->is_valid_number, '山形県東根市中央南');
ok($zip->set_number('9993731')->is_valid_number, '山形県東根市神町営団大通り');
ok($zip->set_number('9993732')->is_valid_number, '山形県東根市神町営団中通り');
ok($zip->set_number('9993733')->is_valid_number, '山形県東根市神町営団三条通り');
ok($zip->set_number('9993734')->is_valid_number, '山形県東根市神町営団二条通り');
ok($zip->set_number('9993735')->is_valid_number, '山形県東根市神町営団一条通り');
ok($zip->set_number('9993736')->is_valid_number, '山形県東根市神町営団南通り');
ok($zip->set_number('9993737')->is_valid_number, '山形県東根市若木');
ok($zip->set_number('9993738')->is_valid_number, '山形県東根市若木大通り');
ok($zip->set_number('9993741')->is_valid_number, '山形県東根市中島東通り');
ok($zip->set_number('9993742')->is_valid_number, '山形県東根市中島通り');
ok($zip->set_number('9993743')->is_valid_number, '山形県東根市中島新田');
ok($zip->set_number('9993744')->is_valid_number, '山形県東根市板垣北通り');
ok($zip->set_number('9993745')->is_valid_number, '山形県東根市板垣中通り');
ok($zip->set_number('9993746')->is_valid_number, '山形県東根市板垣新田');
ok($zip->set_number('9993747')->is_valid_number, '山形県東根市板垣大通り');
ok($zip->set_number('9993748')->is_valid_number, '山形県東根市板垣西小路');
ok($zip->set_number('9993749')->is_valid_number, '山形県東根市板垣北小路');
ok($zip->set_number('9993751')->is_valid_number, '山形県東根市若木通り');
ok($zip->set_number('9993752')->is_valid_number, '山形県東根市若木五条通り');
ok($zip->set_number('9993753')->is_valid_number, '山形県東根市若木四条通り');
ok($zip->set_number('9993754')->is_valid_number, '山形県東根市若木三条通り');
ok($zip->set_number('9993755')->is_valid_number, '山形県東根市若木二条通り');
ok($zip->set_number('9993756')->is_valid_number, '山形県東根市若木一条通り');
ok($zip->set_number('9993757')->is_valid_number, '山形県東根市若木小路');
ok($zip->set_number('9993761')->is_valid_number, '山形県東根市神町');
ok($zip->set_number('9993762')->is_valid_number, '山形県東根市神町北');
ok($zip->set_number('9993763')->is_valid_number, '山形県東根市神町中央');
ok($zip->set_number('9993764')->is_valid_number, '山形県東根市神町東');
ok($zip->set_number('9993765')->is_valid_number, '山形県東根市神町南');
ok($zip->set_number('9993766')->is_valid_number, '山形県東根市神町西');
ok($zip->set_number('9993770')->is_valid_number, '山形県東根市柏原');
ok($zip->set_number('9993771')->is_valid_number, '山形県東根市長瀞');
ok($zip->set_number('9993772')->is_valid_number, '山形県東根市松沢');
ok($zip->set_number('9993773')->is_valid_number, '山形県東根市島大堀');
ok($zip->set_number('9993774')->is_valid_number, '山形県東根市郡山');
ok($zip->set_number('9993775')->is_valid_number, '山形県東根市野田');
ok($zip->set_number('9993776')->is_valid_number, '山形県東根市羽入');
ok($zip->set_number('9993777')->is_valid_number, '山形県東根市荷口');
ok($zip->set_number('9993778')->is_valid_number, '山形県東根市藤助新田');
ok($zip->set_number('9993779')->is_valid_number, '山形県東根市羽入東');
ok($zip->set_number('9993781')->is_valid_number, '山形県東根市本丸北');
ok($zip->set_number('9993782')->is_valid_number, '山形県東根市本丸東');
ok($zip->set_number('9993783')->is_valid_number, '山形県東根市本丸南');
ok($zip->set_number('9993784')->is_valid_number, '山形県東根市本町');
ok($zip->set_number('9993785')->is_valid_number, '山形県東根市本丸西');
ok($zip->set_number('9993786')->is_valid_number, '山形県東根市鷺の宿');
ok($zip->set_number('9993787')->is_valid_number, '山形県東根市白水');
ok($zip->set_number('9994100')->is_valid_number, '山形県北村山郡大石田町以下に掲載がない場合');
ok($zip->set_number('9994101')->is_valid_number, '山形県北村山郡大石田町鷹巣(その他)');
ok($zip->set_number('9994102')->is_valid_number, '山形県北村山郡大石田町海谷');
ok($zip->set_number('9994103')->is_valid_number, '山形県北村山郡大石田町岩ケ袋');
ok($zip->set_number('9994111')->is_valid_number, '山形県北村山郡大石田町大石田');
ok($zip->set_number('9994112')->is_valid_number, '山形県北村山郡大石田町緑町');
ok($zip->set_number('9994113')->is_valid_number, '山形県北村山郡大石田町今宿');
ok($zip->set_number('9994114')->is_valid_number, '山形県北村山郡大石田町四日町');
ok($zip->set_number('9994115')->is_valid_number, '山形県北村山郡大石田町桂木町');
ok($zip->set_number('9994116')->is_valid_number, '山形県北村山郡大石田町駅前通り');
ok($zip->set_number('9994121')->is_valid_number, '山形県北村山郡大石田町横山');
ok($zip->set_number('9994122')->is_valid_number, '山形県北村山郡大石田町田沢');
ok($zip->set_number('9994131')->is_valid_number, '山形県北村山郡大石田町大浦');
ok($zip->set_number('9994132')->is_valid_number, '山形県北村山郡大石田町駒籠');
ok($zip->set_number('9994133')->is_valid_number, '山形県北村山郡大石田町川前');
ok($zip->set_number('9994134')->is_valid_number, '山形県北村山郡大石田町豊田');
ok($zip->set_number('9994141')->is_valid_number, '山形県北村山郡大石田町次年子');
ok($zip->set_number('9994200')->is_valid_number, '山形県尾花沢市以下に掲載がない場合');
ok($zip->set_number('9994201')->is_valid_number, '山形県尾花沢市高橋');
ok($zip->set_number('9994202')->is_valid_number, '山形県尾花沢市行沢');
ok($zip->set_number('9994203')->is_valid_number, '山形県尾花沢市中島');
ok($zip->set_number('9994204')->is_valid_number, '山形県尾花沢市上ノ畑(175-8)');
ok($zip->set_number('9994205')->is_valid_number, '山形県尾花沢市押切');
ok($zip->set_number('9994206')->is_valid_number, '山形県尾花沢市富山');
ok($zip->set_number('9994207')->is_valid_number, '山形県尾花沢市岩谷沢');
ok($zip->set_number('9994208')->is_valid_number, '山形県尾花沢市市野々');
ok($zip->set_number('9994211')->is_valid_number, '山形県尾花沢市正厳');
ok($zip->set_number('9994212')->is_valid_number, '山形県尾花沢市二藤袋');
ok($zip->set_number('9994213')->is_valid_number, '山形県尾花沢市丹生');
ok($zip->set_number('9994214')->is_valid_number, '山形県尾花沢市牛房野');
ok($zip->set_number('9994221')->is_valid_number, '山形県尾花沢市尾花沢');
ok($zip->set_number('9994222')->is_valid_number, '山形県尾花沢市朧気');
ok($zip->set_number('9994223')->is_valid_number, '山形県尾花沢市五十沢');
ok($zip->set_number('9994224')->is_valid_number, '山形県尾花沢市新町');
ok($zip->set_number('9994225')->is_valid_number, '山形県尾花沢市若葉町');
ok($zip->set_number('9994226')->is_valid_number, '山形県尾花沢市新町中央');
ok($zip->set_number('9994227')->is_valid_number, '山形県尾花沢市中町');
ok($zip->set_number('9994228')->is_valid_number, '山形県尾花沢市上町');
ok($zip->set_number('9994229')->is_valid_number, '山形県尾花沢市横町');
ok($zip->set_number('9994231')->is_valid_number, '山形県尾花沢市北町');
ok($zip->set_number('9994232')->is_valid_number, '山形県尾花沢市梺町');
ok($zip->set_number('9994304')->is_valid_number, '山形県尾花沢市上ノ畑(その他)');
ok($zip->set_number('9994331')->is_valid_number, '山形県尾花沢市母袋');
ok($zip->set_number('9994332')->is_valid_number, '山形県尾花沢市上柳渡戸');
ok($zip->set_number('9994333')->is_valid_number, '山形県尾花沢市銀山新畑');
ok($zip->set_number('9994334')->is_valid_number, '山形県尾花沢市下柳渡戸');
ok($zip->set_number('9994335')->is_valid_number, '山形県尾花沢市原田');
ok($zip->set_number('9994336')->is_valid_number, '山形県尾花沢市北郷');
ok($zip->set_number('9994337')->is_valid_number, '山形県尾花沢市鶴巻田');
ok($zip->set_number('9994441')->is_valid_number, '山形県尾花沢市延沢');
ok($zip->set_number('9994442')->is_valid_number, '山形県尾花沢市六沢');
ok($zip->set_number('9994443')->is_valid_number, '山形県尾花沢市鶴子');
ok($zip->set_number('9994444')->is_valid_number, '山形県尾花沢市細野');
ok($zip->set_number('9994445')->is_valid_number, '山形県尾花沢市畑沢');
ok($zip->set_number('9994551')->is_valid_number, '山形県尾花沢市寺内');
ok($zip->set_number('9994552')->is_valid_number, '山形県尾花沢市荻袋');
ok($zip->set_number('9994553')->is_valid_number, '山形県尾花沢市野黒沢');
ok($zip->set_number('9994554')->is_valid_number, '山形県尾花沢市芦沢');
ok($zip->set_number('9994554')->is_valid_number, '山形県北村山郡大石田町鷹巣(岡草山)');
ok($zip->set_number('9994555')->is_valid_number, '山形県尾花沢市毒沢');
ok($zip->set_number('9994556')->is_valid_number, '山形県尾花沢市名木沢');
ok($zip->set_number('9994557')->is_valid_number, '山形県尾花沢市南沢');
ok($zip->set_number('9994600')->is_valid_number, '山形県最上郡舟形町以下に掲載がない場合');
ok($zip->set_number('9994601')->is_valid_number, '山形県最上郡舟形町舟形');
ok($zip->set_number('9994602')->is_valid_number, '山形県最上郡舟形町長者原');
ok($zip->set_number('9994603')->is_valid_number, '山形県最上郡舟形町富田');
ok($zip->set_number('9994604')->is_valid_number, '山形県最上郡舟形町堀内');
ok($zip->set_number('9994605')->is_valid_number, '山形県最上郡舟形町長沢');
ok($zip->set_number('9995101')->is_valid_number, '山形県新庄市昭和');
ok($zip->set_number('9995102')->is_valid_number, '山形県新庄市萩野');
ok($zip->set_number('9995103')->is_valid_number, '山形県新庄市泉田');
ok($zip->set_number('9995191')->is_valid_number, '山形県新庄市十日町(猫屋敷329~356)');
ok($zip->set_number('9995200')->is_valid_number, '山形県最上郡鮭川村以下に掲載がない場合');
ok($zip->set_number('9995201')->is_valid_number, '山形県最上郡鮭川村京塚');
ok($zip->set_number('9995202')->is_valid_number, '山形県最上郡鮭川村佐渡');
ok($zip->set_number('9995203')->is_valid_number, '山形県最上郡鮭川村川口');
ok($zip->set_number('9995204')->is_valid_number, '山形県最上郡鮭川村向居');
ok($zip->set_number('9995205')->is_valid_number, '山形県最上郡鮭川村中渡');
ok($zip->set_number('9995206')->is_valid_number, '山形県最上郡鮭川村曲川');
ok($zip->set_number('9995207')->is_valid_number, '山形県最上郡鮭川村庭月');
ok($zip->set_number('9995208')->is_valid_number, '山形県最上郡鮭川村石名坂');
ok($zip->set_number('9995300')->is_valid_number, '山形県最上郡真室川町以下に掲載がない場合');
ok($zip->set_number('9995301')->is_valid_number, '山形県最上郡真室川町川ノ内(その他)');
ok($zip->set_number('9995311')->is_valid_number, '山形県最上郡真室川町平岡');
ok($zip->set_number('9995312')->is_valid_number, '山形県最上郡真室川町新町');
ok($zip->set_number('9995313')->is_valid_number, '山形県最上郡真室川町内町');
ok($zip->set_number('9995314')->is_valid_number, '山形県最上郡真室川町木ノ下');
ok($zip->set_number('9995400')->is_valid_number, '山形県最上郡金山町以下に掲載がない場合');
ok($zip->set_number('9995401')->is_valid_number, '山形県最上郡金山町有屋');
ok($zip->set_number('9995402')->is_valid_number, '山形県最上郡金山町金山');
ok($zip->set_number('9995403')->is_valid_number, '山形県最上郡金山町安沢');
ok($zip->set_number('9995404')->is_valid_number, '山形県最上郡金山町下野明');
ok($zip->set_number('9995405')->is_valid_number, '山形県最上郡金山町上台');
ok($zip->set_number('9995406')->is_valid_number, '山形県最上郡金山町山崎');
ok($zip->set_number('9995411')->is_valid_number, '山形県最上郡金山町中田');
ok($zip->set_number('9995412')->is_valid_number, '山形県最上郡金山町飛森');
ok($zip->set_number('9995413')->is_valid_number, '山形県最上郡金山町谷口銀山');
ok($zip->set_number('9995414')->is_valid_number, '山形県最上郡金山町漆野');
ok($zip->set_number('9995415')->is_valid_number, '山形県最上郡金山町朴山');
ok($zip->set_number('9995521')->is_valid_number, '山形県最上郡真室川町大沢');
ok($zip->set_number('9995522')->is_valid_number, '山形県最上郡真室川町差首鍋');
ok($zip->set_number('9995601')->is_valid_number, '山形県最上郡真室川町川ノ内(2~128番地、419~614番地、1717番地、三滝、春木)');
ok($zip->set_number('9995602')->is_valid_number, '山形県最上郡真室川町及位');
ok($zip->set_number('9995603')->is_valid_number, '山形県最上郡真室川町大滝');
ok($zip->set_number('9995604')->is_valid_number, '山形県最上郡真室川町釜渕');
ok($zip->set_number('9996100')->is_valid_number, '山形県最上郡最上町以下に掲載がない場合');
ok($zip->set_number('9996101')->is_valid_number, '山形県最上郡最上町向町');
ok($zip->set_number('9996102')->is_valid_number, '山形県最上郡最上町東法田');
ok($zip->set_number('9996103')->is_valid_number, '山形県最上郡最上町黒澤');
ok($zip->set_number('9996104')->is_valid_number, '山形県最上郡最上町本城');
ok($zip->set_number('9996105')->is_valid_number, '山形県最上郡最上町富澤');
ok($zip->set_number('9996106')->is_valid_number, '山形県最上郡最上町堺田');
ok($zip->set_number('9996107')->is_valid_number, '山形県最上郡最上町満澤');
ok($zip->set_number('9996211')->is_valid_number, '山形県最上郡最上町大堀');
ok($zip->set_number('9996211')->is_valid_number, '山形県最上郡最上町瀬見');
ok($zip->set_number('9996212')->is_valid_number, '山形県最上郡最上町志茂');
ok($zip->set_number('9996213')->is_valid_number, '山形県最上郡最上町法田');
ok($zip->set_number('9996214')->is_valid_number, '山形県最上郡最上町若宮');
ok($zip->set_number('9996215')->is_valid_number, '山形県最上郡最上町月楯');
ok($zip->set_number('9996311')->is_valid_number, '山形県最上郡戸沢村津谷');
ok($zip->set_number('9996312')->is_valid_number, '山形県最上郡戸沢村岩清水');
ok($zip->set_number('9996313')->is_valid_number, '山形県最上郡戸沢村名高');
ok($zip->set_number('9996314')->is_valid_number, '山形県最上郡戸沢村松坂');
ok($zip->set_number('9996315')->is_valid_number, '山形県最上郡戸沢村神田');
ok($zip->set_number('9996400')->is_valid_number, '山形県最上郡戸沢村以下に掲載がない場合');
ok($zip->set_number('9996401')->is_valid_number, '山形県最上郡戸沢村古口(その他)');
ok($zip->set_number('9996402')->is_valid_number, '山形県最上郡戸沢村蔵岡');
ok($zip->set_number('9996403')->is_valid_number, '山形県最上郡戸沢村角川');
ok($zip->set_number('9996601')->is_valid_number, '山形県東田川郡庄内町狩川');
ok($zip->set_number('9996602')->is_valid_number, '山形県東田川郡庄内町三ケ沢');
ok($zip->set_number('9996603')->is_valid_number, '山形県東田川郡庄内町添津');
ok($zip->set_number('9996604')->is_valid_number, '山形県東田川郡庄内町千本杉');
ok($zip->set_number('9996605')->is_valid_number, '山形県東田川郡庄内町桑田');
ok($zip->set_number('9996606')->is_valid_number, '山形県東田川郡庄内町清川');
ok($zip->set_number('9996607')->is_valid_number, '山形県東田川郡庄内町肝煎');
ok($zip->set_number('9996608')->is_valid_number, '山形県東田川郡庄内町科沢');
ok($zip->set_number('9996609')->is_valid_number, '山形県東田川郡庄内町立谷沢');
ok($zip->set_number('9996652')->is_valid_number, '山形県鶴岡市添川(渡戸沢「筍沢温泉」)');
ok($zip->set_number('9996701')->is_valid_number, '山形県酒田市砂越');
ok($zip->set_number('9996702')->is_valid_number, '山形県酒田市砂越緑町');
ok($zip->set_number('9996703')->is_valid_number, '山形県酒田市天神堂');
ok($zip->set_number('9996704')->is_valid_number, '山形県酒田市石橋');
ok($zip->set_number('9996705')->is_valid_number, '山形県酒田市桜林');
ok($zip->set_number('9996706')->is_valid_number, '山形県酒田市桜林興野');
ok($zip->set_number('9996707')->is_valid_number, '山形県酒田市郡山');
ok($zip->set_number('9996708')->is_valid_number, '山形県酒田市泉興野');
ok($zip->set_number('9996711')->is_valid_number, '山形県酒田市飛鳥');
ok($zip->set_number('9996712')->is_valid_number, '山形県酒田市楢橋');
ok($zip->set_number('9996721')->is_valid_number, '山形県酒田市堀野内');
ok($zip->set_number('9996722')->is_valid_number, '山形県酒田市中野目');
ok($zip->set_number('9996723')->is_valid_number, '山形県酒田市三之宮');
ok($zip->set_number('9996724')->is_valid_number, '山形県酒田市山楯');
ok($zip->set_number('9996725')->is_valid_number, '山形県酒田市山谷新田');
ok($zip->set_number('9996726')->is_valid_number, '山形県酒田市山谷');
ok($zip->set_number('9996727')->is_valid_number, '山形県酒田市中野俣');
ok($zip->set_number('9996731')->is_valid_number, '山形県酒田市田沢');
ok($zip->set_number('9996732')->is_valid_number, '山形県酒田市楯山');
ok($zip->set_number('9996733')->is_valid_number, '山形県酒田市西坂本');
ok($zip->set_number('9996734')->is_valid_number, '山形県酒田市山元');
ok($zip->set_number('9996735')->is_valid_number, '山形県酒田市小林');
ok($zip->set_number('9996741')->is_valid_number, '山形県酒田市北俣');
ok($zip->set_number('9996801')->is_valid_number, '山形県最上郡戸沢村古口(柏沢)');
ok($zip->set_number('9996811')->is_valid_number, '山形県酒田市柏谷沢');
ok($zip->set_number('9996812')->is_valid_number, '山形県酒田市成興野');
ok($zip->set_number('9996813')->is_valid_number, '山形県酒田市大川渡');
ok($zip->set_number('9996814')->is_valid_number, '山形県酒田市地見興屋');
ok($zip->set_number('9996815')->is_valid_number, '山形県酒田市臼ケ沢');
ok($zip->set_number('9996816')->is_valid_number, '山形県酒田市大沼新田');
ok($zip->set_number('9996821')->is_valid_number, '山形県酒田市山寺');
ok($zip->set_number('9996822')->is_valid_number, '山形県酒田市南新屋敷');
ok($zip->set_number('9996823')->is_valid_number, '山形県酒田市真学寺沢');
ok($zip->set_number('9996824')->is_valid_number, '山形県酒田市元新屋敷');
ok($zip->set_number('9996825')->is_valid_number, '山形県酒田市南町');
ok($zip->set_number('9996826')->is_valid_number, '山形県酒田市稲荷沢');
ok($zip->set_number('9996827')->is_valid_number, '山形県酒田市仲町');
ok($zip->set_number('9996831')->is_valid_number, '山形県酒田市内町');
ok($zip->set_number('9996831')->is_valid_number, '山形県酒田市総光寺沢');
ok($zip->set_number('9996832')->is_valid_number, '山形県酒田市新屋敷');
ok($zip->set_number('9996833')->is_valid_number, '山形県酒田市北町');
ok($zip->set_number('9996834')->is_valid_number, '山形県酒田市荒町');
ok($zip->set_number('9996835')->is_valid_number, '山形県酒田市蔵小路');
ok($zip->set_number('9996835')->is_valid_number, '山形県酒田市本町');
ok($zip->set_number('9996836')->is_valid_number, '山形県酒田市肴町');
ok($zip->set_number('9996837')->is_valid_number, '山形県酒田市金谷');
ok($zip->set_number('9996837')->is_valid_number, '山形県酒田市新町');
ok($zip->set_number('9996838')->is_valid_number, '山形県酒田市片町');
ok($zip->set_number('9996839')->is_valid_number, '山形県酒田市土渕');
ok($zip->set_number('9996841')->is_valid_number, '山形県酒田市茗ケ沢');
ok($zip->set_number('9996842')->is_valid_number, '山形県酒田市上餅山');
ok($zip->set_number('9996843')->is_valid_number, '山形県酒田市上北目');
ok($zip->set_number('9996844')->is_valid_number, '山形県酒田市中北目');
ok($zip->set_number('9996845')->is_valid_number, '山形県酒田市小見');
ok($zip->set_number('9996846')->is_valid_number, '山形県酒田市下餅山');
ok($zip->set_number('9996847')->is_valid_number, '山形県酒田市引地');
ok($zip->set_number('9996848')->is_valid_number, '山形県酒田市竹田');
ok($zip->set_number('9996851')->is_valid_number, '山形県酒田市中牧田');
ok($zip->set_number('9996852')->is_valid_number, '山形県酒田市相沢');
ok($zip->set_number('9996853')->is_valid_number, '山形県酒田市石名坂');
ok($zip->set_number('9996861')->is_valid_number, '山形県酒田市山田');
ok($zip->set_number('9996862')->is_valid_number, '山形県酒田市西田');
ok($zip->set_number('9997121')->is_valid_number, '山形県鶴岡市早田');
ok($zip->set_number('9997122')->is_valid_number, '山形県鶴岡市小岩川');
ok($zip->set_number('9997123')->is_valid_number, '山形県鶴岡市大岩川');
ok($zip->set_number('9997124')->is_valid_number, '山形県鶴岡市槇代');
ok($zip->set_number('9997125')->is_valid_number, '山形県鶴岡市小名部');
ok($zip->set_number('9997126')->is_valid_number, '山形県鶴岡市鼠ケ関');
ok($zip->set_number('9997201')->is_valid_number, '山形県鶴岡市山五十川');
ok($zip->set_number('9997202')->is_valid_number, '山形県鶴岡市戸沢');
ok($zip->set_number('9997203')->is_valid_number, '山形県鶴岡市一霞');
ok($zip->set_number('9997204')->is_valid_number, '山形県鶴岡市湯温海');
ok($zip->set_number('9997205')->is_valid_number, '山形県鶴岡市温海');
ok($zip->set_number('9997206')->is_valid_number, '山形県鶴岡市小菅野代');
ok($zip->set_number('9997207')->is_valid_number, '山形県鶴岡市五十川');
ok($zip->set_number('9997311')->is_valid_number, '山形県鶴岡市菅野代');
ok($zip->set_number('9997312')->is_valid_number, '山形県鶴岡市温海川');
ok($zip->set_number('9997313')->is_valid_number, '山形県鶴岡市木野俣');
ok($zip->set_number('9997314')->is_valid_number, '山形県鶴岡市越沢');
ok($zip->set_number('9997315')->is_valid_number, '山形県鶴岡市関川');
ok($zip->set_number('9997316')->is_valid_number, '山形県鶴岡市小国');
ok($zip->set_number('9997461')->is_valid_number, '山形県鶴岡市堅苔沢');
ok($zip->set_number('9997462')->is_valid_number, '山形県鶴岡市小波渡');
ok($zip->set_number('9997463')->is_valid_number, '山形県鶴岡市三瀬');
ok($zip->set_number('9997464')->is_valid_number, '山形県鶴岡市由良');
ok($zip->set_number('9997541')->is_valid_number, '山形県鶴岡市西目');
ok($zip->set_number('9997542')->is_valid_number, '山形県鶴岡市水沢');
ok($zip->set_number('9997543')->is_valid_number, '山形県鶴岡市大広');
ok($zip->set_number('9997544')->is_valid_number, '山形県鶴岡市中山');
ok($zip->set_number('9997545')->is_valid_number, '山形県鶴岡市矢引');
ok($zip->set_number('9997546')->is_valid_number, '山形県鶴岡市中沢');
ok($zip->set_number('9997547')->is_valid_number, '山形県鶴岡市大荒');
ok($zip->set_number('9997548')->is_valid_number, '山形県鶴岡市みずほ');
ok($zip->set_number('9997601')->is_valid_number, '山形県鶴岡市藤島');
ok($zip->set_number('9997602')->is_valid_number, '山形県鶴岡市藤の花');
ok($zip->set_number('9997604')->is_valid_number, '山形県鶴岡市藤浪');
ok($zip->set_number('9997611')->is_valid_number, '山形県鶴岡市上藤島');
ok($zip->set_number('9997621')->is_valid_number, '山形県鶴岡市長沼');
ok($zip->set_number('9997622')->is_valid_number, '山形県鶴岡市豊栄');
ok($zip->set_number('9997631')->is_valid_number, '山形県鶴岡市八色木');
ok($zip->set_number('9997632')->is_valid_number, '山形県鶴岡市小中島');
ok($zip->set_number('9997633')->is_valid_number, '山形県鶴岡市須走');
ok($zip->set_number('9997634')->is_valid_number, '山形県鶴岡市三和');
ok($zip->set_number('9997635')->is_valid_number, '山形県鶴岡市越後京田');
ok($zip->set_number('9997636')->is_valid_number, '山形県鶴岡市野田目');
ok($zip->set_number('9997637')->is_valid_number, '山形県鶴岡市下中野目');
ok($zip->set_number('9997638')->is_valid_number, '山形県鶴岡市藤岡');
ok($zip->set_number('9997641')->is_valid_number, '山形県鶴岡市楪');
ok($zip->set_number('9997642')->is_valid_number, '山形県鶴岡市藤島関根');
ok($zip->set_number('9997643')->is_valid_number, '山形県鶴岡市無音');
ok($zip->set_number('9997644')->is_valid_number, '山形県鶴岡市川尻');
ok($zip->set_number('9997645')->is_valid_number, '山形県鶴岡市平足');
ok($zip->set_number('9997646')->is_valid_number, '山形県鶴岡市工藤');
ok($zip->set_number('9997651')->is_valid_number, '山形県鶴岡市鷺畑');
ok($zip->set_number('9997652')->is_valid_number, '山形県鶴岡市添川(その他)');
ok($zip->set_number('9997653')->is_valid_number, '山形県鶴岡市東堀越');
ok($zip->set_number('9997661')->is_valid_number, '山形県鶴岡市大川渡');
ok($zip->set_number('9997662')->is_valid_number, '山形県鶴岡市谷地興屋');
ok($zip->set_number('9997663')->is_valid_number, '山形県鶴岡市蛸井興屋');
ok($zip->set_number('9997664')->is_valid_number, '山形県鶴岡市上中野目');
ok($zip->set_number('9997671')->is_valid_number, '山形県鶴岡市古郡');
ok($zip->set_number('9997672')->is_valid_number, '山形県鶴岡市柳久瀬');
ok($zip->set_number('9997673')->is_valid_number, '山形県鶴岡市荒俣');
ok($zip->set_number('9997674')->is_valid_number, '山形県鶴岡市箕升新田');
ok($zip->set_number('9997675')->is_valid_number, '山形県鶴岡市宝徳');
ok($zip->set_number('9997676')->is_valid_number, '山形県鶴岡市幕野内');
ok($zip->set_number('9997677')->is_valid_number, '山形県鶴岡市大半田');
ok($zip->set_number('9997681')->is_valid_number, '山形県鶴岡市平形');
ok($zip->set_number('9997682')->is_valid_number, '山形県鶴岡市新屋敷');
ok($zip->set_number('9997683')->is_valid_number, '山形県鶴岡市渡前');
ok($zip->set_number('9997684')->is_valid_number, '山形県鶴岡市和名川');
ok($zip->set_number('9997685')->is_valid_number, '山形県鶴岡市砂塚');
ok($zip->set_number('9997700')->is_valid_number, '山形県東田川郡庄内町以下に掲載がない場合');
ok($zip->set_number('9997701')->is_valid_number, '山形県東田川郡庄内町跡');
ok($zip->set_number('9997702')->is_valid_number, '山形県東田川郡庄内町榎木');
ok($zip->set_number('9997703')->is_valid_number, '山形県東田川郡庄内町平岡');
ok($zip->set_number('9997704')->is_valid_number, '山形県東田川郡庄内町千河原');
ok($zip->set_number('9997705')->is_valid_number, '山形県東田川郡庄内町槇島');
ok($zip->set_number('9997706')->is_valid_number, '山形県東田川郡庄内町提興屋');
ok($zip->set_number('9997707')->is_valid_number, '山形県東田川郡庄内町廿六木');
ok($zip->set_number('9997711')->is_valid_number, '山形県東田川郡庄内町福原');
ok($zip->set_number('9997712')->is_valid_number, '山形県東田川郡庄内町堀野');
ok($zip->set_number('9997713')->is_valid_number, '山形県東田川郡庄内町常万');
ok($zip->set_number('9997714')->is_valid_number, '山形県東田川郡庄内町余目新田');
ok($zip->set_number('9997715')->is_valid_number, '山形県東田川郡庄内町廻館');
ok($zip->set_number('9997721')->is_valid_number, '山形県東田川郡庄内町堤新田');
ok($zip->set_number('9997722')->is_valid_number, '山形県東田川郡庄内町小出新田');
ok($zip->set_number('9997723')->is_valid_number, '山形県東田川郡庄内町連枝');
ok($zip->set_number('9997724')->is_valid_number, '山形県東田川郡庄内町赤渕新田');
ok($zip->set_number('9997725')->is_valid_number, '山形県東田川郡庄内町沢新田');
ok($zip->set_number('9997726')->is_valid_number, '山形県東田川郡庄内町古関');
ok($zip->set_number('9997727')->is_valid_number, '山形県東田川郡庄内町南野');
ok($zip->set_number('9997731')->is_valid_number, '山形県東田川郡庄内町主殿新田');
ok($zip->set_number('9997732')->is_valid_number, '山形県東田川郡庄内町南野新田');
ok($zip->set_number('9997733')->is_valid_number, '山形県東田川郡庄内町南興屋');
ok($zip->set_number('9997734')->is_valid_number, '山形県東田川郡庄内町中野');
ok($zip->set_number('9997735')->is_valid_number, '山形県東田川郡庄内町前田野目');
ok($zip->set_number('9997736')->is_valid_number, '山形県東田川郡庄内町福島');
ok($zip->set_number('9997737')->is_valid_number, '山形県東田川郡庄内町大真木');
ok($zip->set_number('9997741')->is_valid_number, '山形県東田川郡庄内町返吉');
ok($zip->set_number('9997742')->is_valid_number, '山形県東田川郡庄内町京島');
ok($zip->set_number('9997743')->is_valid_number, '山形県東田川郡庄内町新田目');
ok($zip->set_number('9997744')->is_valid_number, '山形県東田川郡庄内町本小野方');
ok($zip->set_number('9997745')->is_valid_number, '山形県東田川郡庄内町境興屋');
ok($zip->set_number('9997746')->is_valid_number, '山形県東田川郡庄内町西袋');
ok($zip->set_number('9997747')->is_valid_number, '山形県東田川郡庄内町大野');
ok($zip->set_number('9997748')->is_valid_number, '山形県東田川郡庄内町田谷');
ok($zip->set_number('9997749')->is_valid_number, '山形県東田川郡庄内町吉方');
ok($zip->set_number('9997751')->is_valid_number, '山形県東田川郡庄内町西小野方');
ok($zip->set_number('9997752')->is_valid_number, '山形県東田川郡庄内町近江新田');
ok($zip->set_number('9997753')->is_valid_number, '山形県東田川郡庄内町吉岡');
ok($zip->set_number('9997754')->is_valid_number, '山形県東田川郡庄内町島田');
ok($zip->set_number('9997755')->is_valid_number, '山形県東田川郡庄内町生三');
ok($zip->set_number('9997756')->is_valid_number, '山形県東田川郡庄内町茗荷瀬');
ok($zip->set_number('9997757')->is_valid_number, '山形県東田川郡庄内町払田');
ok($zip->set_number('9997761')->is_valid_number, '山形県東田川郡庄内町高田麦');
ok($zip->set_number('9997762')->is_valid_number, '山形県東田川郡庄内町家根合');
ok($zip->set_number('9997763')->is_valid_number, '山形県東田川郡庄内町落合');
ok($zip->set_number('9997764')->is_valid_number, '山形県東田川郡庄内町宮曽根');
ok($zip->set_number('9997765')->is_valid_number, '山形県東田川郡庄内町杉浦');
ok($zip->set_number('9997766')->is_valid_number, '山形県東田川郡庄内町久田');
ok($zip->set_number('9997767')->is_valid_number, '山形県東田川郡庄内町深川');
ok($zip->set_number('9997768')->is_valid_number, '山形県東田川郡庄内町西野');
ok($zip->set_number('9997771')->is_valid_number, '山形県酒田市局');
ok($zip->set_number('9997772')->is_valid_number, '山形県酒田市門田');
ok($zip->set_number('9997773')->is_valid_number, '山形県酒田市木川');
ok($zip->set_number('9997774')->is_valid_number, '山形県酒田市板戸');
ok($zip->set_number('9997775')->is_valid_number, '山形県酒田市落野目');
ok($zip->set_number('9997776')->is_valid_number, '山形県酒田市新堀');
ok($zip->set_number('9997777')->is_valid_number, '山形県酒田市丸沼');
ok($zip->set_number('9997781')->is_valid_number, '山形県東田川郡庄内町余目');
ok($zip->set_number('9997782')->is_valid_number, '山形県東田川郡庄内町松陽');
ok($zip->set_number('9998131')->is_valid_number, '山形県酒田市穂積(門田)');
ok($zip->set_number('9998132')->is_valid_number, '山形県酒田市刈屋');
ok($zip->set_number('9998133')->is_valid_number, '山形県酒田市大豊田');
ok($zip->set_number('9998134')->is_valid_number, '山形県酒田市本楯');
ok($zip->set_number('9998141')->is_valid_number, '山形県酒田市豊原');
ok($zip->set_number('9998142')->is_valid_number, '山形県酒田市城輪');
ok($zip->set_number('9998143')->is_valid_number, '山形県酒田市刈穂');
ok($zip->set_number('9998144')->is_valid_number, '山形県酒田市庭田');
ok($zip->set_number('9998145')->is_valid_number, '山形県酒田市保岡');
ok($zip->set_number('9998151')->is_valid_number, '山形県酒田市安田');
ok($zip->set_number('9998152')->is_valid_number, '山形県酒田市上安田');
ok($zip->set_number('9998153')->is_valid_number, '山形県酒田市円能寺');
ok($zip->set_number('9998154')->is_valid_number, '山形県酒田市古青渡');
ok($zip->set_number('9998155')->is_valid_number, '山形県酒田市曽根田');
ok($zip->set_number('9998156')->is_valid_number, '山形県酒田市久保田');
ok($zip->set_number('9998157')->is_valid_number, '山形県酒田市新青渡');
ok($zip->set_number('9998158')->is_valid_number, '山形県酒田市布目');
ok($zip->set_number('9998161')->is_valid_number, '山形県酒田市吉田');
ok($zip->set_number('9998162')->is_valid_number, '山形県酒田市上野曽根');
ok($zip->set_number('9998163')->is_valid_number, '山形県酒田市上興野');
ok($zip->set_number('9998164')->is_valid_number, '山形県酒田市漆曽根');
ok($zip->set_number('9998165')->is_valid_number, '山形県酒田市中野曽根');
ok($zip->set_number('9998166')->is_valid_number, '山形県酒田市牧曽根');
ok($zip->set_number('9998167')->is_valid_number, '山形県酒田市吉田新田');
ok($zip->set_number('9998168')->is_valid_number, '山形県酒田市鶴田');
ok($zip->set_number('9998201')->is_valid_number, '山形県酒田市升田');
ok($zip->set_number('9998202')->is_valid_number, '山形県酒田市泥沢');
ok($zip->set_number('9998203')->is_valid_number, '山形県酒田市赤剥');
ok($zip->set_number('9998204')->is_valid_number, '山形県酒田市新出');
ok($zip->set_number('9998205')->is_valid_number, '山形県酒田市下黒川');
ok($zip->set_number('9998206')->is_valid_number, '山形県酒田市上黒川');
ok($zip->set_number('9998207')->is_valid_number, '山形県酒田市草津');
ok($zip->set_number('9998211')->is_valid_number, '山形県酒田市北青沢');
ok($zip->set_number('9998212')->is_valid_number, '山形県酒田市上青沢');
ok($zip->set_number('9998213')->is_valid_number, '山形県酒田市下青沢');
ok($zip->set_number('9998214')->is_valid_number, '山形県酒田市常禅寺');
ok($zip->set_number('9998215')->is_valid_number, '山形県酒田市大蕨');
ok($zip->set_number('9998221')->is_valid_number, '山形県酒田市寺田');
ok($zip->set_number('9998222')->is_valid_number, '山形県酒田市北平沢');
ok($zip->set_number('9998223')->is_valid_number, '山形県酒田市南平沢');
ok($zip->set_number('9998224')->is_valid_number, '山形県酒田市前川');
ok($zip->set_number('9998225')->is_valid_number, '山形県酒田市大島田');
ok($zip->set_number('9998226')->is_valid_number, '山形県酒田市政所');
ok($zip->set_number('9998227')->is_valid_number, '山形県酒田市岡島田');
ok($zip->set_number('9998231')->is_valid_number, '山形県酒田市麓');
ok($zip->set_number('9998232')->is_valid_number, '山形県酒田市市条');
ok($zip->set_number('9998233')->is_valid_number, '山形県酒田市法連寺');
ok($zip->set_number('9998234')->is_valid_number, '山形県酒田市小泉');
ok($zip->set_number('9998235')->is_valid_number, '山形県酒田市観音寺');
ok($zip->set_number('9998241')->is_valid_number, '山形県酒田市福山');
ok($zip->set_number('9998242')->is_valid_number, '山形県酒田市橋本');
ok($zip->set_number('9998243')->is_valid_number, '山形県酒田市北仁田');
ok($zip->set_number('9998244')->is_valid_number, '山形県酒田市大久保');
ok($zip->set_number('9998245')->is_valid_number, '山形県酒田市塚淵');
ok($zip->set_number('9998246')->is_valid_number, '山形県酒田市芹田');
ok($zip->set_number('9998300')->is_valid_number, '山形県飽海郡遊佐町以下に掲載がない場合');
ok($zip->set_number('9998301')->is_valid_number, '山形県飽海郡遊佐町遊佐');
ok($zip->set_number('9998302')->is_valid_number, '山形県飽海郡遊佐町吉出');
ok($zip->set_number('9998303')->is_valid_number, '山形県飽海郡遊佐町野沢');
ok($zip->set_number('9998304')->is_valid_number, '山形県飽海郡遊佐町白井新田');
ok($zip->set_number('9998311')->is_valid_number, '山形県飽海郡遊佐町小原田');
ok($zip->set_number('9998312')->is_valid_number, '山形県飽海郡遊佐町鹿野沢');
ok($zip->set_number('9998313')->is_valid_number, '山形県飽海郡遊佐町杉沢');
ok($zip->set_number('9998314')->is_valid_number, '山形県飽海郡遊佐町上蕨岡');
ok($zip->set_number('9998315')->is_valid_number, '山形県飽海郡遊佐町大蕨岡');
ok($zip->set_number('9998316')->is_valid_number, '山形県飽海郡遊佐町豊岡');
ok($zip->set_number('9998317')->is_valid_number, '山形県飽海郡遊佐町小松');
ok($zip->set_number('9998421')->is_valid_number, '山形県酒田市米島');
ok($zip->set_number('9998422')->is_valid_number, '山形県酒田市千代田');
ok($zip->set_number('9998423')->is_valid_number, '山形県酒田市宮内');
ok($zip->set_number('9998431')->is_valid_number, '山形県飽海郡遊佐町菅里(十里塚)');
ok($zip->set_number('9998432')->is_valid_number, '山形県飽海郡遊佐町宮田');
ok($zip->set_number('9998433')->is_valid_number, '山形県飽海郡遊佐町江地');
ok($zip->set_number('9998434')->is_valid_number, '山形県飽海郡遊佐町増穂');
ok($zip->set_number('9998435')->is_valid_number, '山形県飽海郡遊佐町庄泉');
ok($zip->set_number('9998436')->is_valid_number, '山形県飽海郡遊佐町岩川');
ok($zip->set_number('9998437')->is_valid_number, '山形県飽海郡遊佐町藤崎');
ok($zip->set_number('9998438')->is_valid_number, '山形県飽海郡遊佐町比子');
ok($zip->set_number('9998521')->is_valid_number, '山形県飽海郡遊佐町吹浦');
ok($zip->set_number('9998522')->is_valid_number, '山形県飽海郡遊佐町北目');
ok($zip->set_number('9998523')->is_valid_number, '山形県飽海郡遊佐町当山');
ok($zip->set_number('9998524')->is_valid_number, '山形県飽海郡遊佐町富岡');
ok($zip->set_number('9998525')->is_valid_number, '山形県飽海郡遊佐町直世');
ok($zip->set_number('9998531')->is_valid_number, '山形県飽海郡遊佐町菅里(その他)');
ok(!$zip->set_number('0010936')->is_valid_number, 'checking for 0010936');
ok(!$zip->set_number('0028092')->is_valid_number, 'checking for 0028092');
ok(!$zip->set_number('0030877')->is_valid_number, 'checking for 0030877');
ok(!$zip->set_number('0040890')->is_valid_number, 'checking for 0040890');
ok(!$zip->set_number('0050866')->is_valid_number, 'checking for 0050866');
ok(!$zip->set_number('0060862')->is_valid_number, 'checking for 0060862');
ok(!$zip->set_number('0070896')->is_valid_number, 'checking for 0070896');
ok(!$zip->set_number('0101655')->is_valid_number, 'checking for 0101655');
ok(!$zip->set_number('0110952')->is_valid_number, 'checking for 0110952');
ok(!$zip->set_number('0121354')->is_valid_number, 'checking for 0121354');
ok(!$zip->set_number('0130827')->is_valid_number, 'checking for 0130827');
ok(!$zip->set_number('0141414')->is_valid_number, 'checking for 0141414');
ok(!$zip->set_number('0150893')->is_valid_number, 'checking for 0150893');
ok(!$zip->set_number('0160898')->is_valid_number, 'checking for 0160898');
ok(!$zip->set_number('0170898')->is_valid_number, 'checking for 0170898');
ok(!$zip->set_number('0185852')->is_valid_number, 'checking for 0185852');
ok(!$zip->set_number('0192743')->is_valid_number, 'checking for 0192743');
ok(!$zip->set_number('0200892')->is_valid_number, 'checking for 0200892');
ok(!$zip->set_number('0210903')->is_valid_number, 'checking for 0210903');
ok(!$zip->set_number('0220212')->is_valid_number, 'checking for 0220212');
ok(!$zip->set_number('0231763')->is_valid_number, 'checking for 0231763');
ok(!$zip->set_number('0240342')->is_valid_number, 'checking for 0240342');
ok(!$zip->set_number('0250325')->is_valid_number, 'checking for 0250325');
ok(!$zip->set_number('0260413')->is_valid_number, 'checking for 0260413');
ok(!$zip->set_number('0270612')->is_valid_number, 'checking for 0270612');
ok(!$zip->set_number('0288806')->is_valid_number, 'checking for 0288806');
ok(!$zip->set_number('0295704')->is_valid_number, 'checking for 0295704');
ok(!$zip->set_number('0301738')->is_valid_number, 'checking for 0301738');
ok(!$zip->set_number('0310845')->is_valid_number, 'checking for 0310845');
ok(!$zip->set_number('0330168')->is_valid_number, 'checking for 0330168');
ok(!$zip->set_number('0340304')->is_valid_number, 'checking for 0340304');
ok(!$zip->set_number('0350114')->is_valid_number, 'checking for 0350114');
ok(!$zip->set_number('0368386')->is_valid_number, 'checking for 0368386');
ok(!$zip->set_number('0370643')->is_valid_number, 'checking for 0370643');
ok(!$zip->set_number('0383875')->is_valid_number, 'checking for 0383875');
ok(!$zip->set_number('0395347')->is_valid_number, 'checking for 0395347');
ok(!$zip->set_number('0400085')->is_valid_number, 'checking for 0400085');
ok(!$zip->set_number('0411625')->is_valid_number, 'checking for 0411625');
ok(!$zip->set_number('0420959')->is_valid_number, 'checking for 0420959');
ok(!$zip->set_number('0431526')->is_valid_number, 'checking for 0431526');
ok(!$zip->set_number('0440464')->is_valid_number, 'checking for 0440464');
ok(!$zip->set_number('0450304')->is_valid_number, 'checking for 0450304');
ok(!$zip->set_number('0460572')->is_valid_number, 'checking for 0460572');
ok(!$zip->set_number('0470267')->is_valid_number, 'checking for 0470267');
ok(!$zip->set_number('0482674')->is_valid_number, 'checking for 0482674');
ok(!$zip->set_number('0495834')->is_valid_number, 'checking for 0495834');
ok(!$zip->set_number('0500088')->is_valid_number, 'checking for 0500088');
ok(!$zip->set_number('0510037')->is_valid_number, 'checking for 0510037');
ok(!$zip->set_number('0520318')->is_valid_number, 'checking for 0520318');
ok(!$zip->set_number('0530856')->is_valid_number, 'checking for 0530856');
ok(!$zip->set_number('0540365')->is_valid_number, 'checking for 0540365');
ok(!$zip->set_number('0552317')->is_valid_number, 'checking for 0552317');
ok(!$zip->set_number('0560147')->is_valid_number, 'checking for 0560147');
ok(!$zip->set_number('0570175')->is_valid_number, 'checking for 0570175');
ok(!$zip->set_number('0580423')->is_valid_number, 'checking for 0580423');
ok(!$zip->set_number('0593464')->is_valid_number, 'checking for 0593464');
ok(!$zip->set_number('0600910')->is_valid_number, 'checking for 0600910');
ok(!$zip->set_number('0613780')->is_valid_number, 'checking for 0613780');
ok(!$zip->set_number('0620939')->is_valid_number, 'checking for 0620939');
ok(!$zip->set_number('0630871')->is_valid_number, 'checking for 0630871');
ok(!$zip->set_number('0640960')->is_valid_number, 'checking for 0640960');
ok(!$zip->set_number('0650044')->is_valid_number, 'checking for 0650044');
ok(!$zip->set_number('0660288')->is_valid_number, 'checking for 0660288');
ok(!$zip->set_number('0670076')->is_valid_number, 'checking for 0670076');
ok(!$zip->set_number('0683189')->is_valid_number, 'checking for 0683189');
ok(!$zip->set_number('0691527')->is_valid_number, 'checking for 0691527');
ok(!$zip->set_number('0708075')->is_valid_number, 'checking for 0708075');
ok(!$zip->set_number('0718172')->is_valid_number, 'checking for 0718172');
ok(!$zip->set_number('0720858')->is_valid_number, 'checking for 0720858');
ok(!$zip->set_number('0731324')->is_valid_number, 'checking for 0731324');
ok(!$zip->set_number('0741277')->is_valid_number, 'checking for 0741277');
ok(!$zip->set_number('0750255')->is_valid_number, 'checking for 0750255');
ok(!$zip->set_number('0760205')->is_valid_number, 'checking for 0760205');
ok(!$zip->set_number('0770467')->is_valid_number, 'checking for 0770467');
ok(!$zip->set_number('0788826')->is_valid_number, 'checking for 0788826');
ok(!$zip->set_number('0798455')->is_valid_number, 'checking for 0798455');
ok(!$zip->set_number('0802477')->is_valid_number, 'checking for 0802477');
ok(!$zip->set_number('0810347')->is_valid_number, 'checking for 0810347');
ok(!$zip->set_number('0820814')->is_valid_number, 'checking for 0820814');
ok(!$zip->set_number('0830093')->is_valid_number, 'checking for 0830093');
ok(!$zip->set_number('0840930')->is_valid_number, 'checking for 0840930');
ok(!$zip->set_number('0852274')->is_valid_number, 'checking for 0852274');
ok(!$zip->set_number('0861845')->is_valid_number, 'checking for 0861845');
ok(!$zip->set_number('0870168')->is_valid_number, 'checking for 0870168');
ok(!$zip->set_number('0883466')->is_valid_number, 'checking for 0883466');
ok(!$zip->set_number('0895870')->is_valid_number, 'checking for 0895870');
ok(!$zip->set_number('0900839')->is_valid_number, 'checking for 0900839');
ok(!$zip->set_number('0910559')->is_valid_number, 'checking for 0910559');
ok(!$zip->set_number('0920363')->is_valid_number, 'checking for 0920363');
ok(!$zip->set_number('0930736')->is_valid_number, 'checking for 0930736');
ok(!$zip->set_number('0940032')->is_valid_number, 'checking for 0940032');
ok(!$zip->set_number('0950407')->is_valid_number, 'checking for 0950407');
ok(!$zip->set_number('0960079')->is_valid_number, 'checking for 0960079');
ok(!$zip->set_number('0971203')->is_valid_number, 'checking for 0971203');
ok(!$zip->set_number('0986759')->is_valid_number, 'checking for 0986759');
ok(!$zip->set_number('0996510')->is_valid_number, 'checking for 0996510');
ok(!$zip->set_number('1007091')->is_valid_number, 'checking for 1007091');
ok(!$zip->set_number('1010066')->is_valid_number, 'checking for 1010066');
ok(!$zip->set_number('1020095')->is_valid_number, 'checking for 1020095');
ok(!$zip->set_number('1036191')->is_valid_number, 'checking for 1036191');
ok(!$zip->set_number('1046291')->is_valid_number, 'checking for 1046291');
ok(!$zip->set_number('1057591')->is_valid_number, 'checking for 1057591');
ok(!$zip->set_number('1066291')->is_valid_number, 'checking for 1066291');
ok(!$zip->set_number('1076391')->is_valid_number, 'checking for 1076391');
ok(!$zip->set_number('1086391')->is_valid_number, 'checking for 1086391');
ok(!$zip->set_number('1100017')->is_valid_number, 'checking for 1100017');
ok(!$zip->set_number('1110057')->is_valid_number, 'checking for 1110057');
ok(!$zip->set_number('1120016')->is_valid_number, 'checking for 1120016');
ok(!$zip->set_number('1130035')->is_valid_number, 'checking for 1130035');
ok(!$zip->set_number('1140035')->is_valid_number, 'checking for 1140035');
ok(!$zip->set_number('1150057')->is_valid_number, 'checking for 1150057');
ok(!$zip->set_number('1160015')->is_valid_number, 'checking for 1160015');
ok(!$zip->set_number('1200048')->is_valid_number, 'checking for 1200048');
ok(!$zip->set_number('1210838')->is_valid_number, 'checking for 1210838');
ok(!$zip->set_number('1230875')->is_valid_number, 'checking for 1230875');
ok(!$zip->set_number('1240026')->is_valid_number, 'checking for 1240026');
ok(!$zip->set_number('1250064')->is_valid_number, 'checking for 1250064');
ok(!$zip->set_number('1300027')->is_valid_number, 'checking for 1300027');
ok(!$zip->set_number('1310047')->is_valid_number, 'checking for 1310047');
ok(!$zip->set_number('1320036')->is_valid_number, 'checking for 1320036');
ok(!$zip->set_number('1330074')->is_valid_number, 'checking for 1330074');
ok(!$zip->set_number('1340094')->is_valid_number, 'checking for 1340094');
ok(!$zip->set_number('1356091')->is_valid_number, 'checking for 1356091');
ok(!$zip->set_number('1360084')->is_valid_number, 'checking for 1360084');
ok(!$zip->set_number('1400016')->is_valid_number, 'checking for 1400016');
ok(!$zip->set_number('1416091')->is_valid_number, 'checking for 1416091');
ok(!$zip->set_number('1420065')->is_valid_number, 'checking for 1420065');
ok(!$zip->set_number('1430028')->is_valid_number, 'checking for 1430028');
ok(!$zip->set_number('1440057')->is_valid_number, 'checking for 1440057');
ok(!$zip->set_number('1450077')->is_valid_number, 'checking for 1450077');
ok(!$zip->set_number('1460096')->is_valid_number, 'checking for 1460096');
ok(!$zip->set_number('1506191')->is_valid_number, 'checking for 1506191');
ok(!$zip->set_number('1510074')->is_valid_number, 'checking for 1510074');
ok(!$zip->set_number('1520036')->is_valid_number, 'checking for 1520036');
ok(!$zip->set_number('1530066')->is_valid_number, 'checking for 1530066');
ok(!$zip->set_number('1540025')->is_valid_number, 'checking for 1540025');
ok(!$zip->set_number('1550034')->is_valid_number, 'checking for 1550034');
ok(!$zip->set_number('1560058')->is_valid_number, 'checking for 1560058');
ok(!$zip->set_number('1570078')->is_valid_number, 'checking for 1570078');
ok(!$zip->set_number('1580099')->is_valid_number, 'checking for 1580099');
ok(!$zip->set_number('1606191')->is_valid_number, 'checking for 1606191');
ok(!$zip->set_number('1610036')->is_valid_number, 'checking for 1610036');
ok(!$zip->set_number('1620858')->is_valid_number, 'checking for 1620858');
ok(!$zip->set_number('1636091')->is_valid_number, 'checking for 1636091');
ok(!$zip->set_number('1640015')->is_valid_number, 'checking for 1640015');
ok(!$zip->set_number('1650036')->is_valid_number, 'checking for 1650036');
ok(!$zip->set_number('1660017')->is_valid_number, 'checking for 1660017');
ok(!$zip->set_number('1670055')->is_valid_number, 'checking for 1670055');
ok(!$zip->set_number('1680083')->is_valid_number, 'checking for 1680083');
ok(!$zip->set_number('1690076')->is_valid_number, 'checking for 1690076');
ok(!$zip->set_number('1706091')->is_valid_number, 'checking for 1706091');
ok(!$zip->set_number('1710053')->is_valid_number, 'checking for 1710053');
ok(!$zip->set_number('1730038')->is_valid_number, 'checking for 1730038');
ok(!$zip->set_number('1740077')->is_valid_number, 'checking for 1740077');
ok(!$zip->set_number('1750095')->is_valid_number, 'checking for 1750095');
ok(!$zip->set_number('1760026')->is_valid_number, 'checking for 1760026');
ok(!$zip->set_number('1770055')->is_valid_number, 'checking for 1770055');
ok(!$zip->set_number('1780067')->is_valid_number, 'checking for 1780067');
ok(!$zip->set_number('1790086')->is_valid_number, 'checking for 1790086');
ok(!$zip->set_number('1800024')->is_valid_number, 'checking for 1800024');
ok(!$zip->set_number('1810017')->is_valid_number, 'checking for 1810017');
ok(!$zip->set_number('1820037')->is_valid_number, 'checking for 1820037');
ok(!$zip->set_number('1830058')->is_valid_number, 'checking for 1830058');
ok(!$zip->set_number('1840016')->is_valid_number, 'checking for 1840016');
ok(!$zip->set_number('1850037')->is_valid_number, 'checking for 1850037');
ok(!$zip->set_number('1860016')->is_valid_number, 'checking for 1860016');
ok(!$zip->set_number('1870046')->is_valid_number, 'checking for 1870046');
ok(!$zip->set_number('1880015')->is_valid_number, 'checking for 1880015');
ok(!$zip->set_number('1890027')->is_valid_number, 'checking for 1890027');
ok(!$zip->set_number('1901235')->is_valid_number, 'checking for 1901235');
ok(!$zip->set_number('1910066')->is_valid_number, 'checking for 1910066');
ok(!$zip->set_number('1920920')->is_valid_number, 'checking for 1920920');
ok(!$zip->set_number('1930945')->is_valid_number, 'checking for 1930945');
ok(!$zip->set_number('1940216')->is_valid_number, 'checking for 1940216');
ok(!$zip->set_number('1950077')->is_valid_number, 'checking for 1950077');
ok(!$zip->set_number('1960036')->is_valid_number, 'checking for 1960036');
ok(!$zip->set_number('1970835')->is_valid_number, 'checking for 1970835');
ok(!$zip->set_number('1980226')->is_valid_number, 'checking for 1980226');
ok(!$zip->set_number('2010017')->is_valid_number, 'checking for 2010017');
ok(!$zip->set_number('2020024')->is_valid_number, 'checking for 2020024');
ok(!$zip->set_number('2030055')->is_valid_number, 'checking for 2030055');
ok(!$zip->set_number('2040025')->is_valid_number, 'checking for 2040025');
ok(!$zip->set_number('2050025')->is_valid_number, 'checking for 2050025');
ok(!$zip->set_number('2060825')->is_valid_number, 'checking for 2060825');
ok(!$zip->set_number('2070034')->is_valid_number, 'checking for 2070034');
ok(!$zip->set_number('2080036')->is_valid_number, 'checking for 2080036');
ok(!$zip->set_number('2100870')->is_valid_number, 'checking for 2100870');
ok(!$zip->set_number('2110069')->is_valid_number, 'checking for 2110069');
ok(!$zip->set_number('2120059')->is_valid_number, 'checking for 2120059');
ok(!$zip->set_number('2130036')->is_valid_number, 'checking for 2130036');
ok(!$zip->set_number('2140040')->is_valid_number, 'checking for 2140040');
ok(!$zip->set_number('2150037')->is_valid_number, 'checking for 2150037');
ok(!$zip->set_number('2160045')->is_valid_number, 'checking for 2160045');
ok(!$zip->set_number('2208191')->is_valid_number, 'checking for 2208191');
ok(!$zip->set_number('2210867')->is_valid_number, 'checking for 2210867');
ok(!$zip->set_number('2220038')->is_valid_number, 'checking for 2220038');
ok(!$zip->set_number('2230067')->is_valid_number, 'checking for 2230067');
ok(!$zip->set_number('2240067')->is_valid_number, 'checking for 2240067');
ok(!$zip->set_number('2250027')->is_valid_number, 'checking for 2250027');
ok(!$zip->set_number('2260030')->is_valid_number, 'checking for 2260030');
ok(!$zip->set_number('2270068')->is_valid_number, 'checking for 2270068');
ok(!$zip->set_number('2300079')->is_valid_number, 'checking for 2300079');
ok(!$zip->set_number('2310869')->is_valid_number, 'checking for 2310869');
ok(!$zip->set_number('2320077')->is_valid_number, 'checking for 2320077');
ok(!$zip->set_number('2330017')->is_valid_number, 'checking for 2330017');
ok(!$zip->set_number('2340057')->is_valid_number, 'checking for 2340057');
ok(!$zip->set_number('2350046')->is_valid_number, 'checking for 2350046');
ok(!$zip->set_number('2360059')->is_valid_number, 'checking for 2360059');
ok(!$zip->set_number('2370080')->is_valid_number, 'checking for 2370080');
ok(!$zip->set_number('2380318')->is_valid_number, 'checking for 2380318');
ok(!$zip->set_number('2390848')->is_valid_number, 'checking for 2390848');
ok(!$zip->set_number('2400117')->is_valid_number, 'checking for 2400117');
ok(!$zip->set_number('2410837')->is_valid_number, 'checking for 2410837');
ok(!$zip->set_number('2420030')->is_valid_number, 'checking for 2420030');
ok(!$zip->set_number('2430818')->is_valid_number, 'checking for 2430818');
ok(!$zip->set_number('2440846')->is_valid_number, 'checking for 2440846');
ok(!$zip->set_number('2450068')->is_valid_number, 'checking for 2450068');
ok(!$zip->set_number('2460039')->is_valid_number, 'checking for 2460039');
ok(!$zip->set_number('2470076')->is_valid_number, 'checking for 2470076');
ok(!$zip->set_number('2480037')->is_valid_number, 'checking for 2480037');
ok(!$zip->set_number('2490009')->is_valid_number, 'checking for 2490009');
ok(!$zip->set_number('2500879')->is_valid_number, 'checking for 2500879');
ok(!$zip->set_number('2510878')->is_valid_number, 'checking for 2510878');
ok(!$zip->set_number('2521138')->is_valid_number, 'checking for 2521138');
ok(!$zip->set_number('2530115')->is_valid_number, 'checking for 2530115');
ok(!$zip->set_number('2540916')->is_valid_number, 'checking for 2540916');
ok(!$zip->set_number('2550006')->is_valid_number, 'checking for 2550006');
ok(!$zip->set_number('2560818')->is_valid_number, 'checking for 2560818');
ok(!$zip->set_number('2570062')->is_valid_number, 'checking for 2570062');
ok(!$zip->set_number('2580205')->is_valid_number, 'checking for 2580205');
ok(!$zip->set_number('2591336')->is_valid_number, 'checking for 2591336');
ok(!$zip->set_number('2600858')->is_valid_number, 'checking for 2600858');
ok(!$zip->set_number('2617191')->is_valid_number, 'checking for 2617191');
ok(!$zip->set_number('2620049')->is_valid_number, 'checking for 2620049');
ok(!$zip->set_number('2630055')->is_valid_number, 'checking for 2630055');
ok(!$zip->set_number('2640038')->is_valid_number, 'checking for 2640038');
ok(!$zip->set_number('2650078')->is_valid_number, 'checking for 2650078');
ok(!$zip->set_number('2660035')->is_valid_number, 'checking for 2660035');
ok(!$zip->set_number('2670068')->is_valid_number, 'checking for 2670068');
ok(!$zip->set_number('2702332')->is_valid_number, 'checking for 2702332');
ok(!$zip->set_number('2710098')->is_valid_number, 'checking for 2710098');
ok(!$zip->set_number('2720838')->is_valid_number, 'checking for 2720838');
ok(!$zip->set_number('2730868')->is_valid_number, 'checking for 2730868');
ok(!$zip->set_number('2740827')->is_valid_number, 'checking for 2740827');
ok(!$zip->set_number('2750029')->is_valid_number, 'checking for 2750029');
ok(!$zip->set_number('2760050')->is_valid_number, 'checking for 2760050');
ok(!$zip->set_number('2770946')->is_valid_number, 'checking for 2770946');
ok(!$zip->set_number('2780058')->is_valid_number, 'checking for 2780058');
ok(!$zip->set_number('2790044')->is_valid_number, 'checking for 2790044');
ok(!$zip->set_number('2820036')->is_valid_number, 'checking for 2820036');
ok(!$zip->set_number('2830836')->is_valid_number, 'checking for 2830836');
ok(!$zip->set_number('2840046')->is_valid_number, 'checking for 2840046');
ok(!$zip->set_number('2850929')->is_valid_number, 'checking for 2850929');
ok(!$zip->set_number('2860847')->is_valid_number, 'checking for 2860847');
ok(!$zip->set_number('2870827')->is_valid_number, 'checking for 2870827');
ok(!$zip->set_number('2880878')->is_valid_number, 'checking for 2880878');
ok(!$zip->set_number('2893187')->is_valid_number, 'checking for 2893187');
ok(!$zip->set_number('2900560')->is_valid_number, 'checking for 2900560');
ok(!$zip->set_number('2921180')->is_valid_number, 'checking for 2921180');
ok(!$zip->set_number('2930059')->is_valid_number, 'checking for 2930059');
ok(!$zip->set_number('2940827')->is_valid_number, 'checking for 2940827');
ok(!$zip->set_number('2950105')->is_valid_number, 'checking for 2950105');
ok(!$zip->set_number('2960238')->is_valid_number, 'checking for 2960238');
ok(!$zip->set_number('2970236')->is_valid_number, 'checking for 2970236');
ok(!$zip->set_number('2980280')->is_valid_number, 'checking for 2980280');
ok(!$zip->set_number('2995507')->is_valid_number, 'checking for 2995507');
ok(!$zip->set_number('3004547')->is_valid_number, 'checking for 3004547');
ok(!$zip->set_number('3010903')->is_valid_number, 'checking for 3010903');
ok(!$zip->set_number('3020133')->is_valid_number, 'checking for 3020133');
ok(!$zip->set_number('3030047')->is_valid_number, 'checking for 3030047');
ok(!$zip->set_number('3040825')->is_valid_number, 'checking for 3040825');
ok(!$zip->set_number('3050904')->is_valid_number, 'checking for 3050904');
ok(!$zip->set_number('3060659')->is_valid_number, 'checking for 3060659');
ok(!$zip->set_number('3070056')->is_valid_number, 'checking for 3070056');
ok(!$zip->set_number('3080868')->is_valid_number, 'checking for 3080868');
ok(!$zip->set_number('3091739')->is_valid_number, 'checking for 3091739');
ok(!$zip->set_number('3100915')->is_valid_number, 'checking for 3100915');
ok(!$zip->set_number('3114619')->is_valid_number, 'checking for 3114619');
ok(!$zip->set_number('3120064')->is_valid_number, 'checking for 3120064');
ok(!$zip->set_number('3130354')->is_valid_number, 'checking for 3130354');
ok(!$zip->set_number('3140409')->is_valid_number, 'checking for 3140409');
ok(!$zip->set_number('3150168')->is_valid_number, 'checking for 3150168');
ok(!$zip->set_number('3160037')->is_valid_number, 'checking for 3160037');
ok(!$zip->set_number('3170078')->is_valid_number, 'checking for 3170078');
ok(!$zip->set_number('3180107')->is_valid_number, 'checking for 3180107');
ok(!$zip->set_number('3193706')->is_valid_number, 'checking for 3193706');
ok(!$zip->set_number('3200868')->is_valid_number, 'checking for 3200868');
ok(!$zip->set_number('3214552')->is_valid_number, 'checking for 3214552');
ok(!$zip->set_number('3220607')->is_valid_number, 'checking for 3220607');
ok(!$zip->set_number('3231109')->is_valid_number, 'checking for 3231109');
ok(!$zip->set_number('3240619')->is_valid_number, 'checking for 3240619');
ok(!$zip->set_number('3250305')->is_valid_number, 'checking for 3250305');
ok(!$zip->set_number('3260847')->is_valid_number, 'checking for 3260847');
ok(!$zip->set_number('3270848')->is_valid_number, 'checking for 3270848');
ok(!$zip->set_number('3280222')->is_valid_number, 'checking for 3280222');
ok(!$zip->set_number('3294426')->is_valid_number, 'checking for 3294426');
ok(!$zip->set_number('3306091')->is_valid_number, 'checking for 3306091');
ok(!$zip->set_number('3310826')->is_valid_number, 'checking for 3310826');
ok(!$zip->set_number('3320036')->is_valid_number, 'checking for 3320036');
ok(!$zip->set_number('3330870')->is_valid_number, 'checking for 3330870');
ok(!$zip->set_number('3340077')->is_valid_number, 'checking for 3340077');
ok(!$zip->set_number('3350039')->is_valid_number, 'checking for 3350039');
ok(!$zip->set_number('3360978')->is_valid_number, 'checking for 3360978');
ok(!$zip->set_number('3370055')->is_valid_number, 'checking for 3370055');
ok(!$zip->set_number('3380838')->is_valid_number, 'checking for 3380838');
ok(!$zip->set_number('3390083')->is_valid_number, 'checking for 3390083');
ok(!$zip->set_number('3400836')->is_valid_number, 'checking for 3400836');
ok(!$zip->set_number('3410060')->is_valid_number, 'checking for 3410060');
ok(!$zip->set_number('3420062')->is_valid_number, 'checking for 3420062');
ok(!$zip->set_number('3430858')->is_valid_number, 'checking for 3430858');
ok(!$zip->set_number('3440137')->is_valid_number, 'checking for 3440137');
ok(!$zip->set_number('3450838')->is_valid_number, 'checking for 3450838');
ok(!$zip->set_number('3460116')->is_valid_number, 'checking for 3460116');
ok(!$zip->set_number('3470127')->is_valid_number, 'checking for 3470127');
ok(!$zip->set_number('3480072')->is_valid_number, 'checking for 3480072');
ok(!$zip->set_number('3491222')->is_valid_number, 'checking for 3491222');
ok(!$zip->set_number('3502228')->is_valid_number, 'checking for 3502228');
ok(!$zip->set_number('3510117')->is_valid_number, 'checking for 3510117');
ok(!$zip->set_number('3520036')->is_valid_number, 'checking for 3520036');
ok(!$zip->set_number('3530009')->is_valid_number, 'checking for 3530009');
ok(!$zip->set_number('3540047')->is_valid_number, 'checking for 3540047');
ok(!$zip->set_number('3550816')->is_valid_number, 'checking for 3550816');
ok(!$zip->set_number('3560060')->is_valid_number, 'checking for 3560060');
ok(!$zip->set_number('3570219')->is_valid_number, 'checking for 3570219');
ok(!$zip->set_number('3580056')->is_valid_number, 'checking for 3580056');
ok(!$zip->set_number('3591168')->is_valid_number, 'checking for 3591168');
ok(!$zip->set_number('3600858')->is_valid_number, 'checking for 3600858');
ok(!$zip->set_number('3610085')->is_valid_number, 'checking for 3610085');
ok(!$zip->set_number('3620814')->is_valid_number, 'checking for 3620814');
ok(!$zip->set_number('3630030')->is_valid_number, 'checking for 3630030');
ok(!$zip->set_number('3640036')->is_valid_number, 'checking for 3640036');
ok(!$zip->set_number('3650079')->is_valid_number, 'checking for 3650079');
ok(!$zip->set_number('3660840')->is_valid_number, 'checking for 3660840');
ok(!$zip->set_number('3670314')->is_valid_number, 'checking for 3670314');
ok(!$zip->set_number('3680203')->is_valid_number, 'checking for 3680203');
ok(!$zip->set_number('3691913')->is_valid_number, 'checking for 3691913');
ok(!$zip->set_number('3703609')->is_valid_number, 'checking for 3703609');
ok(!$zip->set_number('3710859')->is_valid_number, 'checking for 3710859');
ok(!$zip->set_number('3720856')->is_valid_number, 'checking for 3720856');
ok(!$zip->set_number('3730863')->is_valid_number, 'checking for 3730863');
ok(!$zip->set_number('3740136')->is_valid_number, 'checking for 3740136');
ok(!$zip->set_number('3750058')->is_valid_number, 'checking for 3750058');
ok(!$zip->set_number('3760602')->is_valid_number, 'checking for 3760602');
ok(!$zip->set_number('3771713')->is_valid_number, 'checking for 3771713');
ok(!$zip->set_number('3780416')->is_valid_number, 'checking for 3780416');
ok(!$zip->set_number('3792315')->is_valid_number, 'checking for 3792315');
ok(!$zip->set_number('3800962')->is_valid_number, 'checking for 3800962');
ok(!$zip->set_number('3814304')->is_valid_number, 'checking for 3814304');
ok(!$zip->set_number('3820838')->is_valid_number, 'checking for 3820838');
ok(!$zip->set_number('3830067')->is_valid_number, 'checking for 3830067');
ok(!$zip->set_number('3842310')->is_valid_number, 'checking for 3842310');
ok(!$zip->set_number('3850064')->is_valid_number, 'checking for 3850064');
ok(!$zip->set_number('3862212')->is_valid_number, 'checking for 3862212');
ok(!$zip->set_number('3870025')->is_valid_number, 'checking for 3870025');
ok(!$zip->set_number('3888021')->is_valid_number, 'checking for 3888021');
ok(!$zip->set_number('3892704')->is_valid_number, 'checking for 3892704');
ok(!$zip->set_number('3901704')->is_valid_number, 'checking for 3901704');
ok(!$zip->set_number('3910322')->is_valid_number, 'checking for 3910322');
ok(!$zip->set_number('3920132')->is_valid_number, 'checking for 3920132');
ok(!$zip->set_number('3930094')->is_valid_number, 'checking for 3930094');
ok(!$zip->set_number('3940092')->is_valid_number, 'checking for 3940092');
ok(!$zip->set_number('3951109')->is_valid_number, 'checking for 3951109');
ok(!$zip->set_number('3960622')->is_valid_number, 'checking for 3960622');
ok(!$zip->set_number('3970303')->is_valid_number, 'checking for 3970303');
ok(!$zip->set_number('3980005')->is_valid_number, 'checking for 3980005');
ok(!$zip->set_number('3999602')->is_valid_number, 'checking for 3999602');
ok(!$zip->set_number('4001516')->is_valid_number, 'checking for 4001516');
ok(!$zip->set_number('4010513')->is_valid_number, 'checking for 4010513');
ok(!$zip->set_number('4020229')->is_valid_number, 'checking for 4020229');
ok(!$zip->set_number('4030033')->is_valid_number, 'checking for 4030033');
ok(!$zip->set_number('4040212')->is_valid_number, 'checking for 4040212');
ok(!$zip->set_number('4050080')->is_valid_number, 'checking for 4050080');
ok(!$zip->set_number('4060856')->is_valid_number, 'checking for 4060856');
ok(!$zip->set_number('4070323')->is_valid_number, 'checking for 4070323');
ok(!$zip->set_number('4080320')->is_valid_number, 'checking for 4080320');
ok(!$zip->set_number('4093868')->is_valid_number, 'checking for 4093868');
ok(!$zip->set_number('4103628')->is_valid_number, 'checking for 4103628');
ok(!$zip->set_number('4110952')->is_valid_number, 'checking for 4110952');
ok(!$zip->set_number('4120052')->is_valid_number, 'checking for 4120052');
ok(!$zip->set_number('4130717')->is_valid_number, 'checking for 4130717');
ok(!$zip->set_number('4140056')->is_valid_number, 'checking for 4140056');
ok(!$zip->set_number('4150534')->is_valid_number, 'checking for 4150534');
ok(!$zip->set_number('4160956')->is_valid_number, 'checking for 4160956');
ok(!$zip->set_number('4170865')->is_valid_number, 'checking for 4170865');
ok(!$zip->set_number('4180118')->is_valid_number, 'checking for 4180118');
ok(!$zip->set_number('4190318')->is_valid_number, 'checking for 4190318');
ok(!$zip->set_number('4200970')->is_valid_number, 'checking for 4200970');
ok(!$zip->set_number('4213307')->is_valid_number, 'checking for 4213307');
ok(!$zip->set_number('4228079')->is_valid_number, 'checking for 4228079');
ok(!$zip->set_number('4240950')->is_valid_number, 'checking for 4240950');
ok(!$zip->set_number('4250093')->is_valid_number, 'checking for 4250093');
ok(!$zip->set_number('4260225')->is_valid_number, 'checking for 4260225');
ok(!$zip->set_number('4270234')->is_valid_number, 'checking for 4270234');
ok(!$zip->set_number('4280506')->is_valid_number, 'checking for 4280506');
ok(!$zip->set_number('4307791')->is_valid_number, 'checking for 4307791');
ok(!$zip->set_number('4314122')->is_valid_number, 'checking for 4314122');
ok(!$zip->set_number('4328072')->is_valid_number, 'checking for 4328072');
ok(!$zip->set_number('4338128')->is_valid_number, 'checking for 4338128');
ok(!$zip->set_number('4340047')->is_valid_number, 'checking for 4340047');
ok(!$zip->set_number('4350058')->is_valid_number, 'checking for 4350058');
ok(!$zip->set_number('4360344')->is_valid_number, 'checking for 4360344');
ok(!$zip->set_number('4371624')->is_valid_number, 'checking for 4371624');
ok(!$zip->set_number('4380839')->is_valid_number, 'checking for 4380839');
ok(!$zip->set_number('4390038')->is_valid_number, 'checking for 4390038');
ok(!$zip->set_number('4400898')->is_valid_number, 'checking for 4400898');
ok(!$zip->set_number('4418158')->is_valid_number, 'checking for 4418158');
ok(!$zip->set_number('4420890')->is_valid_number, 'checking for 4420890');
ok(!$zip->set_number('4430107')->is_valid_number, 'checking for 4430107');
ok(!$zip->set_number('4443627')->is_valid_number, 'checking for 4443627');
ok(!$zip->set_number('4450895')->is_valid_number, 'checking for 4450895');
ok(!$zip->set_number('4460077')->is_valid_number, 'checking for 4460077');
ok(!$zip->set_number('4470890')->is_valid_number, 'checking for 4470890');
ok(!$zip->set_number('4480863')->is_valid_number, 'checking for 4480863');
ok(!$zip->set_number('4490406')->is_valid_number, 'checking for 4490406');
ok(!$zip->set_number('4506691')->is_valid_number, 'checking for 4506691');
ok(!$zip->set_number('4516091')->is_valid_number, 'checking for 4516091');
ok(!$zip->set_number('4520964')->is_valid_number, 'checking for 4520964');
ok(!$zip->set_number('4536191')->is_valid_number, 'checking for 4536191');
ok(!$zip->set_number('4540998')->is_valid_number, 'checking for 4540998');
ok(!$zip->set_number('4550888')->is_valid_number, 'checking for 4550888');
ok(!$zip->set_number('4560079')->is_valid_number, 'checking for 4560079');
ok(!$zip->set_number('4570867')->is_valid_number, 'checking for 4570867');
ok(!$zip->set_number('4580930')->is_valid_number, 'checking for 4580930');
ok(!$zip->set_number('4598018')->is_valid_number, 'checking for 4598018');
ok(!$zip->set_number('4600033')->is_valid_number, 'checking for 4600033');
ok(!$zip->set_number('4610050')->is_valid_number, 'checking for 4610050');
ok(!$zip->set_number('4620870')->is_valid_number, 'checking for 4620870');
ok(!$zip->set_number('4630816')->is_valid_number, 'checking for 4630816');
ok(!$zip->set_number('4640872')->is_valid_number, 'checking for 4640872');
ok(!$zip->set_number('4650098')->is_valid_number, 'checking for 4650098');
ok(!$zip->set_number('4660859')->is_valid_number, 'checking for 4660859');
ok(!$zip->set_number('4670880')->is_valid_number, 'checking for 4670880');
ok(!$zip->set_number('4680837')->is_valid_number, 'checking for 4680837');
ok(!$zip->set_number('4703506')->is_valid_number, 'checking for 4703506');
ok(!$zip->set_number('4710880')->is_valid_number, 'checking for 4710880');
ok(!$zip->set_number('4720059')->is_valid_number, 'checking for 4720059');
ok(!$zip->set_number('4730940')->is_valid_number, 'checking for 4730940');
ok(!$zip->set_number('4740075')->is_valid_number, 'checking for 4740075');
ok(!$zip->set_number('4750979')->is_valid_number, 'checking for 4750979');
ok(!$zip->set_number('4760016')->is_valid_number, 'checking for 4760016');
ok(!$zip->set_number('4770038')->is_valid_number, 'checking for 4770038');
ok(!$zip->set_number('4780070')->is_valid_number, 'checking for 4780070');
ok(!$zip->set_number('4790883')->is_valid_number, 'checking for 4790883');
ok(!$zip->set_number('4801348')->is_valid_number, 'checking for 4801348');
ok(!$zip->set_number('4810047')->is_valid_number, 'checking for 4810047');
ok(!$zip->set_number('4820047')->is_valid_number, 'checking for 4820047');
ok(!$zip->set_number('4838434')->is_valid_number, 'checking for 4838434');
ok(!$zip->set_number('4840967')->is_valid_number, 'checking for 4840967');
ok(!$zip->set_number('4850833')->is_valid_number, 'checking for 4850833');
ok(!$zip->set_number('4860970')->is_valid_number, 'checking for 4860970');
ok(!$zip->set_number('4870036')->is_valid_number, 'checking for 4870036');
ok(!$zip->set_number('4880885')->is_valid_number, 'checking for 4880885');
ok(!$zip->set_number('4890990')->is_valid_number, 'checking for 4890990');
ok(!$zip->set_number('4901448')->is_valid_number, 'checking for 4901448');
ok(!$zip->set_number('4910939')->is_valid_number, 'checking for 4910939');
ok(!$zip->set_number('4928469')->is_valid_number, 'checking for 4928469');
ok(!$zip->set_number('4938004')->is_valid_number, 'checking for 4938004');
ok(!$zip->set_number('4940020')->is_valid_number, 'checking for 4940020');
ok(!$zip->set_number('4950038')->is_valid_number, 'checking for 4950038');
ok(!$zip->set_number('4968050')->is_valid_number, 'checking for 4968050');
ok(!$zip->set_number('4970059')->is_valid_number, 'checking for 4970059');
ok(!$zip->set_number('4980825')->is_valid_number, 'checking for 4980825');
ok(!$zip->set_number('5008892')->is_valid_number, 'checking for 5008892');
ok(!$zip->set_number('5016339')->is_valid_number, 'checking for 5016339');
ok(!$zip->set_number('5020940')->is_valid_number, 'checking for 5020940');
ok(!$zip->set_number('5032507')->is_valid_number, 'checking for 5032507');
ok(!$zip->set_number('5040972')->is_valid_number, 'checking for 5040972');
ok(!$zip->set_number('5050533')->is_valid_number, 'checking for 5050533');
ok(!$zip->set_number('5062259')->is_valid_number, 'checking for 5062259');
ok(!$zip->set_number('5070902')->is_valid_number, 'checking for 5070902');
ok(!$zip->set_number('5080503')->is_valid_number, 'checking for 5080503');
ok(!$zip->set_number('5099233')->is_valid_number, 'checking for 5099233');
ok(!$zip->set_number('5108126')->is_valid_number, 'checking for 5108126');
ok(!$zip->set_number('5111150')->is_valid_number, 'checking for 5111150');
ok(!$zip->set_number('5128067')->is_valid_number, 'checking for 5128067');
ok(!$zip->set_number('5131125')->is_valid_number, 'checking for 5131125');
ok(!$zip->set_number('5142329')->is_valid_number, 'checking for 5142329');
ok(!$zip->set_number('5153537')->is_valid_number, 'checking for 5153537');
ok(!$zip->set_number('5162120')->is_valid_number, 'checking for 5162120');
ok(!$zip->set_number('5170706')->is_valid_number, 'checking for 5170706');
ok(!$zip->set_number('5181430')->is_valid_number, 'checking for 5181430');
ok(!$zip->set_number('5195836')->is_valid_number, 'checking for 5195836');
ok(!$zip->set_number('5203437')->is_valid_number, 'checking for 5203437');
ok(!$zip->set_number('5211352')->is_valid_number, 'checking for 5211352');
ok(!$zip->set_number('5220357')->is_valid_number, 'checking for 5220357');
ok(!$zip->set_number('5230899')->is_valid_number, 'checking for 5230899');
ok(!$zip->set_number('5240217')->is_valid_number, 'checking for 5240217');
ok(!$zip->set_number('5250073')->is_valid_number, 'checking for 5250073');
ok(!$zip->set_number('5260848')->is_valid_number, 'checking for 5260848');
ok(!$zip->set_number('5270233')->is_valid_number, 'checking for 5270233');
ok(!$zip->set_number('5280236')->is_valid_number, 'checking for 5280236');
ok(!$zip->set_number('5291852')->is_valid_number, 'checking for 5291852');
ok(!$zip->set_number('5306191')->is_valid_number, 'checking for 5306191');
ok(!$zip->set_number('5316191')->is_valid_number, 'checking for 5316191');
ok(!$zip->set_number('5320037')->is_valid_number, 'checking for 5320037');
ok(!$zip->set_number('5330034')->is_valid_number, 'checking for 5330034');
ok(!$zip->set_number('5340028')->is_valid_number, 'checking for 5340028');
ok(!$zip->set_number('5350032')->is_valid_number, 'checking for 5350032');
ok(!$zip->set_number('5360026')->is_valid_number, 'checking for 5360026');
ok(!$zip->set_number('5370026')->is_valid_number, 'checking for 5370026');
ok(!$zip->set_number('5380055')->is_valid_number, 'checking for 5380055');
ok(!$zip->set_number('5390001')->is_valid_number, 'checking for 5390001');
ok(!$zip->set_number('5406391')->is_valid_number, 'checking for 5406391');
ok(!$zip->set_number('5410060')->is_valid_number, 'checking for 5410060');
ok(!$zip->set_number('5420087')->is_valid_number, 'checking for 5420087');
ok(!$zip->set_number('5430077')->is_valid_number, 'checking for 5430077');
ok(!$zip->set_number('5440035')->is_valid_number, 'checking for 5440035');
ok(!$zip->set_number('5456091')->is_valid_number, 'checking for 5456091');
ok(!$zip->set_number('5460045')->is_valid_number, 'checking for 5460045');
ok(!$zip->set_number('5470049')->is_valid_number, 'checking for 5470049');
ok(!$zip->set_number('5490022')->is_valid_number, 'checking for 5490022');
ok(!$zip->set_number('5500028')->is_valid_number, 'checking for 5500028');
ok(!$zip->set_number('5510034')->is_valid_number, 'checking for 5510034');
ok(!$zip->set_number('5520024')->is_valid_number, 'checking for 5520024');
ok(!$zip->set_number('5530008')->is_valid_number, 'checking for 5530008');
ok(!$zip->set_number('5540053')->is_valid_number, 'checking for 5540053');
ok(!$zip->set_number('5550045')->is_valid_number, 'checking for 5550045');
ok(!$zip->set_number('5560030')->is_valid_number, 'checking for 5560030');
ok(!$zip->set_number('5570064')->is_valid_number, 'checking for 5570064');
ok(!$zip->set_number('5580057')->is_valid_number, 'checking for 5580057');
ok(!$zip->set_number('5590035')->is_valid_number, 'checking for 5590035');
ok(!$zip->set_number('5600086')->is_valid_number, 'checking for 5600086');
ok(!$zip->set_number('5610895')->is_valid_number, 'checking for 5610895');
ok(!$zip->set_number('5620047')->is_valid_number, 'checking for 5620047');
ok(!$zip->set_number('5630802')->is_valid_number, 'checking for 5630802');
ok(!$zip->set_number('5640084')->is_valid_number, 'checking for 5640084');
ok(!$zip->set_number('5650876')->is_valid_number, 'checking for 5650876');
ok(!$zip->set_number('5660075')->is_valid_number, 'checking for 5660075');
ok(!$zip->set_number('5670898')->is_valid_number, 'checking for 5670898');
ok(!$zip->set_number('5680099')->is_valid_number, 'checking for 5680099');
ok(!$zip->set_number('5691148')->is_valid_number, 'checking for 5691148');
ok(!$zip->set_number('5700099')->is_valid_number, 'checking for 5700099');
ok(!$zip->set_number('5710080')->is_valid_number, 'checking for 5710080');
ok(!$zip->set_number('5720868')->is_valid_number, 'checking for 5720868');
ok(!$zip->set_number('5731198')->is_valid_number, 'checking for 5731198');
ok(!$zip->set_number('5740078')->is_valid_number, 'checking for 5740078');
ok(!$zip->set_number('5750064')->is_valid_number, 'checking for 5750064');
ok(!$zip->set_number('5760067')->is_valid_number, 'checking for 5760067');
ok(!$zip->set_number('5770850')->is_valid_number, 'checking for 5770850');
ok(!$zip->set_number('5780986')->is_valid_number, 'checking for 5780986');
ok(!$zip->set_number('5798067')->is_valid_number, 'checking for 5798067');
ok(!$zip->set_number('5800047')->is_valid_number, 'checking for 5800047');
ok(!$zip->set_number('5810886')->is_valid_number, 'checking for 5810886');
ok(!$zip->set_number('5820030')->is_valid_number, 'checking for 5820030');
ok(!$zip->set_number('5830997')->is_valid_number, 'checking for 5830997');
ok(!$zip->set_number('5840096')->is_valid_number, 'checking for 5840096');
ok(!$zip->set_number('5850056')->is_valid_number, 'checking for 5850056');
ok(!$zip->set_number('5860098')->is_valid_number, 'checking for 5860098');
ok(!$zip->set_number('5870067')->is_valid_number, 'checking for 5870067');
ok(!$zip->set_number('5890037')->is_valid_number, 'checking for 5890037');
ok(!$zip->set_number('5900988')->is_valid_number, 'checking for 5900988');
ok(!$zip->set_number('5918047')->is_valid_number, 'checking for 5918047');
ok(!$zip->set_number('5928353')->is_valid_number, 'checking for 5928353');
ok(!$zip->set_number('5938330')->is_valid_number, 'checking for 5938330');
ok(!$zip->set_number('5941158')->is_valid_number, 'checking for 5941158');
ok(!$zip->set_number('5950815')->is_valid_number, 'checking for 5950815');
ok(!$zip->set_number('5960846')->is_valid_number, 'checking for 5960846');
ok(!$zip->set_number('5970114')->is_valid_number, 'checking for 5970114');
ok(!$zip->set_number('5980095')->is_valid_number, 'checking for 5980095');
ok(!$zip->set_number('5998277')->is_valid_number, 'checking for 5998277');
ok(!$zip->set_number('6008900')->is_valid_number, 'checking for 6008900');
ok(!$zip->set_number('6018479')->is_valid_number, 'checking for 6018479');
ok(!$zip->set_number('6028499')->is_valid_number, 'checking for 6028499');
ok(!$zip->set_number('6038864')->is_valid_number, 'checking for 6038864');
ok(!$zip->set_number('6048875')->is_valid_number, 'checking for 6048875');
ok(!$zip->set_number('6050996')->is_valid_number, 'checking for 6050996');
ok(!$zip->set_number('6068456')->is_valid_number, 'checking for 6068456');
ok(!$zip->set_number('6078499')->is_valid_number, 'checking for 6078499');
ok(!$zip->set_number('6101154')->is_valid_number, 'checking for 6101154');
ok(!$zip->set_number('6110046')->is_valid_number, 'checking for 6110046');
ok(!$zip->set_number('6128500')->is_valid_number, 'checking for 6128500');
ok(!$zip->set_number('6130917')->is_valid_number, 'checking for 6130917');
ok(!$zip->set_number('6148378')->is_valid_number, 'checking for 6148378');
ok(!$zip->set_number('6158304')->is_valid_number, 'checking for 6158304');
ok(!$zip->set_number('6168495')->is_valid_number, 'checking for 6168495');
ok(!$zip->set_number('6170858')->is_valid_number, 'checking for 6170858');
ok(!$zip->set_number('6180092')->is_valid_number, 'checking for 6180092');
ok(!$zip->set_number('6191423')->is_valid_number, 'checking for 6191423');
ok(!$zip->set_number('6201446')->is_valid_number, 'checking for 6201446');
ok(!$zip->set_number('6210870')->is_valid_number, 'checking for 6210870');
ok(!$zip->set_number('6220454')->is_valid_number, 'checking for 6220454');
ok(!$zip->set_number('6231135')->is_valid_number, 'checking for 6231135');
ok(!$zip->set_number('6240969')->is_valid_number, 'checking for 6240969');
ok(!$zip->set_number('6250159')->is_valid_number, 'checking for 6250159');
ok(!$zip->set_number('6260434')->is_valid_number, 'checking for 6260434');
ok(!$zip->set_number('6270250')->is_valid_number, 'checking for 6270250');
ok(!$zip->set_number('6293580')->is_valid_number, 'checking for 6293580');
ok(!$zip->set_number('6308455')->is_valid_number, 'checking for 6308455');
ok(!$zip->set_number('6310847')->is_valid_number, 'checking for 6310847');
ok(!$zip->set_number('6320252')->is_valid_number, 'checking for 6320252');
ok(!$zip->set_number('6332445')->is_valid_number, 'checking for 6332445');
ok(!$zip->set_number('6340848')->is_valid_number, 'checking for 6340848');
ok(!$zip->set_number('6350836')->is_valid_number, 'checking for 6350836');
ok(!$zip->set_number('6360946')->is_valid_number, 'checking for 6360946');
ok(!$zip->set_number('6371669')->is_valid_number, 'checking for 6371669');
ok(!$zip->set_number('6380854')->is_valid_number, 'checking for 6380854');
ok(!$zip->set_number('6393810')->is_valid_number, 'checking for 6393810');
ok(!$zip->set_number('6408484')->is_valid_number, 'checking for 6408484');
ok(!$zip->set_number('6410063')->is_valid_number, 'checking for 6410063');
ok(!$zip->set_number('6420036')->is_valid_number, 'checking for 6420036');
ok(!$zip->set_number('6430856')->is_valid_number, 'checking for 6430856');
ok(!$zip->set_number('6441245')->is_valid_number, 'checking for 6441245');
ok(!$zip->set_number('6450552')->is_valid_number, 'checking for 6450552');
ok(!$zip->set_number('6461440')->is_valid_number, 'checking for 6461440');
ok(!$zip->set_number('6471754')->is_valid_number, 'checking for 6471754');
ok(!$zip->set_number('6480406')->is_valid_number, 'checking for 6480406');
ok(!$zip->set_number('6497217')->is_valid_number, 'checking for 6497217');
ok(!$zip->set_number('6500049')->is_valid_number, 'checking for 6500049');
ok(!$zip->set_number('6512415')->is_valid_number, 'checking for 6512415');
ok(!$zip->set_number('6520899')->is_valid_number, 'checking for 6520899');
ok(!$zip->set_number('6530889')->is_valid_number, 'checking for 6530889');
ok(!$zip->set_number('6540164')->is_valid_number, 'checking for 6540164');
ok(!$zip->set_number('6550897')->is_valid_number, 'checking for 6550897');
ok(!$zip->set_number('6562544')->is_valid_number, 'checking for 6562544');
ok(!$zip->set_number('6570865')->is_valid_number, 'checking for 6570865');
ok(!$zip->set_number('6580085')->is_valid_number, 'checking for 6580085');
ok(!$zip->set_number('6590097')->is_valid_number, 'checking for 6590097');
ok(!$zip->set_number('6600894')->is_valid_number, 'checking for 6600894');
ok(!$zip->set_number('6610986')->is_valid_number, 'checking for 6610986');
ok(!$zip->set_number('6620979')->is_valid_number, 'checking for 6620979');
ok(!$zip->set_number('6638248')->is_valid_number, 'checking for 6638248');
ok(!$zip->set_number('6640900')->is_valid_number, 'checking for 6640900');
ok(!$zip->set_number('6650892')->is_valid_number, 'checking for 6650892');
ok(!$zip->set_number('6660263')->is_valid_number, 'checking for 6660263');
ok(!$zip->set_number('6671546')->is_valid_number, 'checking for 6671546');
ok(!$zip->set_number('6680876')->is_valid_number, 'checking for 6680876');
ok(!$zip->set_number('6696955')->is_valid_number, 'checking for 6696955');
ok(!$zip->set_number('6700997')->is_valid_number, 'checking for 6700997');
ok(!$zip->set_number('6714246')->is_valid_number, 'checking for 6714246');
ok(!$zip->set_number('6728099')->is_valid_number, 'checking for 6728099');
ok(!$zip->set_number('6731476')->is_valid_number, 'checking for 6731476');
ok(!$zip->set_number('6740096')->is_valid_number, 'checking for 6740096');
ok(!$zip->set_number('6752466')->is_valid_number, 'checking for 6752466');
ok(!$zip->set_number('6760829')->is_valid_number, 'checking for 6760829');
ok(!$zip->set_number('6770133')->is_valid_number, 'checking for 6770133');
ok(!$zip->set_number('6781279')->is_valid_number, 'checking for 6781279');
ok(!$zip->set_number('6795655')->is_valid_number, 'checking for 6795655');
ok(!$zip->set_number('6808067')->is_valid_number, 'checking for 6808067');
ok(!$zip->set_number('6810075')->is_valid_number, 'checking for 6810075');
ok(!$zip->set_number('6820955')->is_valid_number, 'checking for 6820955');
ok(!$zip->set_number('6830856')->is_valid_number, 'checking for 6830856');
ok(!$zip->set_number('6840414')->is_valid_number, 'checking for 6840414');
ok(!$zip->set_number('6850436')->is_valid_number, 'checking for 6850436');
ok(!$zip->set_number('6895674')->is_valid_number, 'checking for 6895674');
ok(!$zip->set_number('6903517')->is_valid_number, 'checking for 6903517');
ok(!$zip->set_number('6910077')->is_valid_number, 'checking for 6910077');
ok(!$zip->set_number('6920734')->is_valid_number, 'checking for 6920734');
ok(!$zip->set_number('6930527')->is_valid_number, 'checking for 6930527');
ok(!$zip->set_number('6940434')->is_valid_number, 'checking for 6940434');
ok(!$zip->set_number('6950157')->is_valid_number, 'checking for 6950157');
ok(!$zip->set_number('6961227')->is_valid_number, 'checking for 6961227');
ok(!$zip->set_number('6971339')->is_valid_number, 'checking for 6971339');
ok(!$zip->set_number('6982256')->is_valid_number, 'checking for 6982256');
ok(!$zip->set_number('6995638')->is_valid_number, 'checking for 6995638');
ok(!$zip->set_number('7000987')->is_valid_number, 'checking for 7000987');
ok(!$zip->set_number('7014503')->is_valid_number, 'checking for 7014503');
ok(!$zip->set_number('7028059')->is_valid_number, 'checking for 7028059');
ok(!$zip->set_number('7038299')->is_valid_number, 'checking for 7038299');
ok(!$zip->set_number('7048197')->is_valid_number, 'checking for 7048197');
ok(!$zip->set_number('7050134')->is_valid_number, 'checking for 7050134');
ok(!$zip->set_number('7060318')->is_valid_number, 'checking for 7060318');
ok(!$zip->set_number('7070507')->is_valid_number, 'checking for 7070507');
ok(!$zip->set_number('7081548')->is_valid_number, 'checking for 7081548');
ok(!$zip->set_number('7094636')->is_valid_number, 'checking for 7094636');
ok(!$zip->set_number('7101316')->is_valid_number, 'checking for 7101316');
ok(!$zip->set_number('7110938')->is_valid_number, 'checking for 7110938');
ok(!$zip->set_number('7128075')->is_valid_number, 'checking for 7128075');
ok(!$zip->set_number('7138128')->is_valid_number, 'checking for 7138128');
ok(!$zip->set_number('7142342')->is_valid_number, 'checking for 7142342');
ok(!$zip->set_number('7150027')->is_valid_number, 'checking for 7150027');
ok(!$zip->set_number('7161555')->is_valid_number, 'checking for 7161555');
ok(!$zip->set_number('7170747')->is_valid_number, 'checking for 7170747');
ok(!$zip->set_number('7180314')->is_valid_number, 'checking for 7180314');
ok(!$zip->set_number('7193815')->is_valid_number, 'checking for 7193815');
ok(!$zip->set_number('7202603')->is_valid_number, 'checking for 7202603');
ok(!$zip->set_number('7210976')->is_valid_number, 'checking for 7210976');
ok(!$zip->set_number('7222642')->is_valid_number, 'checking for 7222642');
ok(!$zip->set_number('7230149')->is_valid_number, 'checking for 7230149');
ok(!$zip->set_number('7250404')->is_valid_number, 'checking for 7250404');
ok(!$zip->set_number('7260037')->is_valid_number, 'checking for 7260037');
ok(!$zip->set_number('7270625')->is_valid_number, 'checking for 7270625');
ok(!$zip->set_number('7280626')->is_valid_number, 'checking for 7280626');
ok(!$zip->set_number('7296717')->is_valid_number, 'checking for 7296717');
ok(!$zip->set_number('7300857')->is_valid_number, 'checking for 7300857');
ok(!$zip->set_number('7315163')->is_valid_number, 'checking for 7315163');
ok(!$zip->set_number('7320829')->is_valid_number, 'checking for 7320829');
ok(!$zip->set_number('7330878')->is_valid_number, 'checking for 7330878');
ok(!$zip->set_number('7340305')->is_valid_number, 'checking for 7340305');
ok(!$zip->set_number('7350030')->is_valid_number, 'checking for 7350030');
ok(!$zip->set_number('7360090')->is_valid_number, 'checking for 7360090');
ok(!$zip->set_number('7372638')->is_valid_number, 'checking for 7372638');
ok(!$zip->set_number('7380723')->is_valid_number, 'checking for 7380723');
ok(!$zip->set_number('7392733')->is_valid_number, 'checking for 7392733');
ok(!$zip->set_number('7401489')->is_valid_number, 'checking for 7401489');
ok(!$zip->set_number('7410095')->is_valid_number, 'checking for 7410095');
ok(!$zip->set_number('7422925')->is_valid_number, 'checking for 7422925');
ok(!$zip->set_number('7430106')->is_valid_number, 'checking for 7430106');
ok(!$zip->set_number('7440277')->is_valid_number, 'checking for 7440277');
ok(!$zip->set_number('7451133')->is_valid_number, 'checking for 7451133');
ok(!$zip->set_number('7460106')->is_valid_number, 'checking for 7460106');
ok(!$zip->set_number('7471233')->is_valid_number, 'checking for 7471233');
ok(!$zip->set_number('7490104')->is_valid_number, 'checking for 7490104');
ok(!$zip->set_number('7501172')->is_valid_number, 'checking for 7501172');
ok(!$zip->set_number('7510889')->is_valid_number, 'checking for 7510889');
ok(!$zip->set_number('7520999')->is_valid_number, 'checking for 7520999');
ok(!$zip->set_number('7530892')->is_valid_number, 'checking for 7530892');
ok(!$zip->set_number('7541316')->is_valid_number, 'checking for 7541316');
ok(!$zip->set_number('7550811')->is_valid_number, 'checking for 7550811');
ok(!$zip->set_number('7560890')->is_valid_number, 'checking for 7560890');
ok(!$zip->set_number('7570403')->is_valid_number, 'checking for 7570403');
ok(!$zip->set_number('7580702')->is_valid_number, 'checking for 7580702');
ok(!$zip->set_number('7596616')->is_valid_number, 'checking for 7596616');
ok(!$zip->set_number('7600094')->is_valid_number, 'checking for 7600094');
ok(!$zip->set_number('7618086')->is_valid_number, 'checking for 7618086');
ok(!$zip->set_number('7620088')->is_valid_number, 'checking for 7620088');
ok(!$zip->set_number('7630232')->is_valid_number, 'checking for 7630232');
ok(!$zip->set_number('7640051')->is_valid_number, 'checking for 7640051');
ok(!$zip->set_number('7650074')->is_valid_number, 'checking for 7650074');
ok(!$zip->set_number('7660205')->is_valid_number, 'checking for 7660205');
ok(!$zip->set_number('7670034')->is_valid_number, 'checking for 7670034');
ok(!$zip->set_number('7680106')->is_valid_number, 'checking for 7680106');
ok(!$zip->set_number('7692909')->is_valid_number, 'checking for 7692909');
ok(!$zip->set_number('7708085')->is_valid_number, 'checking for 7708085');
ok(!$zip->set_number('7716513')->is_valid_number, 'checking for 7716513');
ok(!$zip->set_number('7720061')->is_valid_number, 'checking for 7720061');
ok(!$zip->set_number('7730071')->is_valid_number, 'checking for 7730071');
ok(!$zip->set_number('7741761')->is_valid_number, 'checking for 7741761');
ok(!$zip->set_number('7750514')->is_valid_number, 'checking for 7750514');
ok(!$zip->set_number('7760038')->is_valid_number, 'checking for 7760038');
ok(!$zip->set_number('7770304')->is_valid_number, 'checking for 7770304');
ok(!$zip->set_number('7785255')->is_valid_number, 'checking for 7785255');
ok(!$zip->set_number('7795454')->is_valid_number, 'checking for 7795454');
ok(!$zip->set_number('7808091')->is_valid_number, 'checking for 7808091');
ok(!$zip->set_number('7818137')->is_valid_number, 'checking for 7818137');
ok(!$zip->set_number('7820080')->is_valid_number, 'checking for 7820080');
ok(!$zip->set_number('7830098')->is_valid_number, 'checking for 7830098');
ok(!$zip->set_number('7840279')->is_valid_number, 'checking for 7840279');
ok(!$zip->set_number('7850777')->is_valid_number, 'checking for 7850777');
ok(!$zip->set_number('7860536')->is_valid_number, 'checking for 7860536');
ok(!$zip->set_number('7871619')->is_valid_number, 'checking for 7871619');
ok(!$zip->set_number('7880787')->is_valid_number, 'checking for 7880787');
ok(!$zip->set_number('7891937')->is_valid_number, 'checking for 7891937');
ok(!$zip->set_number('7902649')->is_valid_number, 'checking for 7902649');
ok(!$zip->set_number('7918094')->is_valid_number, 'checking for 7918094');
ok(!$zip->set_number('7920899')->is_valid_number, 'checking for 7920899');
ok(!$zip->set_number('7930217')->is_valid_number, 'checking for 7930217');
ok(!$zip->set_number('7942551')->is_valid_number, 'checking for 7942551');
ok(!$zip->set_number('7950310')->is_valid_number, 'checking for 7950310');
ok(!$zip->set_number('7968061')->is_valid_number, 'checking for 7968061');
ok(!$zip->set_number('7971718')->is_valid_number, 'checking for 7971718');
ok(!$zip->set_number('7984409')->is_valid_number, 'checking for 7984409');
ok(!$zip->set_number('7993773')->is_valid_number, 'checking for 7993773');
ok(!$zip->set_number('8000367')->is_valid_number, 'checking for 8000367');
ok(!$zip->set_number('8010887')->is_valid_number, 'checking for 8010887');
ok(!$zip->set_number('8020987')->is_valid_number, 'checking for 8020987');
ok(!$zip->set_number('8030866')->is_valid_number, 'checking for 8030866');
ok(!$zip->set_number('8040095')->is_valid_number, 'checking for 8040095');
ok(!$zip->set_number('8050072')->is_valid_number, 'checking for 8050072');
ok(!$zip->set_number('8060070')->is_valid_number, 'checking for 8060070');
ok(!$zip->set_number('8071316')->is_valid_number, 'checking for 8071316');
ok(!$zip->set_number('8080176')->is_valid_number, 'checking for 8080176');
ok(!$zip->set_number('8090042')->is_valid_number, 'checking for 8090042');
ok(!$zip->set_number('8100803')->is_valid_number, 'checking for 8100803');
ok(!$zip->set_number('8115758')->is_valid_number, 'checking for 8115758');
ok(!$zip->set_number('8120898')->is_valid_number, 'checking for 8120898');
ok(!$zip->set_number('8130063')->is_valid_number, 'checking for 8130063');
ok(!$zip->set_number('8140178')->is_valid_number, 'checking for 8140178');
ok(!$zip->set_number('8150085')->is_valid_number, 'checking for 8150085');
ok(!$zip->set_number('8160984')->is_valid_number, 'checking for 8160984');
ok(!$zip->set_number('8172334')->is_valid_number, 'checking for 8172334');
ok(!$zip->set_number('8180140')->is_valid_number, 'checking for 8180140');
ok(!$zip->set_number('8191643')->is_valid_number, 'checking for 8191643');
ok(!$zip->set_number('8201115')->is_valid_number, 'checking for 8201115');
ok(!$zip->set_number('8210015')->is_valid_number, 'checking for 8210015');
ok(!$zip->set_number('8221407')->is_valid_number, 'checking for 8221407');
ok(!$zip->set_number('8230018')->is_valid_number, 'checking for 8230018');
ok(!$zip->set_number('8240823')->is_valid_number, 'checking for 8240823');
ok(!$zip->set_number('8250019')->is_valid_number, 'checking for 8250019');
ok(!$zip->set_number('8260046')->is_valid_number, 'checking for 8260046');
ok(!$zip->set_number('8270005')->is_valid_number, 'checking for 8270005');
ok(!$zip->set_number('8280087')->is_valid_number, 'checking for 8280087');
ok(!$zip->set_number('8290344')->is_valid_number, 'checking for 8290344');
ok(!$zip->set_number('8301227')->is_valid_number, 'checking for 8301227');
ok(!$zip->set_number('8310046')->is_valid_number, 'checking for 8310046');
ok(!$zip->set_number('8320829')->is_valid_number, 'checking for 8320829');
ok(!$zip->set_number('8330057')->is_valid_number, 'checking for 8330057');
ok(!$zip->set_number('8341403')->is_valid_number, 'checking for 8341403');
ok(!$zip->set_number('8350137')->is_valid_number, 'checking for 8350137');
ok(!$zip->set_number('8360898')->is_valid_number, 'checking for 8360898');
ok(!$zip->set_number('8370929')->is_valid_number, 'checking for 8370929');
ok(!$zip->set_number('8381703')->is_valid_number, 'checking for 8381703');
ok(!$zip->set_number('8391422')->is_valid_number, 'checking for 8391422');
ok(!$zip->set_number('8402224')->is_valid_number, 'checking for 8402224');
ok(!$zip->set_number('8410206')->is_valid_number, 'checking for 8410206');
ok(!$zip->set_number('8420304')->is_valid_number, 'checking for 8420304');
ok(!$zip->set_number('8430306')->is_valid_number, 'checking for 8430306');
ok(!$zip->set_number('8440029')->is_valid_number, 'checking for 8440029');
ok(!$zip->set_number('8450036')->is_valid_number, 'checking for 8450036');
ok(!$zip->set_number('8460042')->is_valid_number, 'checking for 8460042');
ok(!$zip->set_number('8471528')->is_valid_number, 'checking for 8471528');
ok(!$zip->set_number('8480409')->is_valid_number, 'checking for 8480409');
ok(!$zip->set_number('8495265')->is_valid_number, 'checking for 8495265');
ok(!$zip->set_number('8500997')->is_valid_number, 'checking for 8500997');
ok(!$zip->set_number('8513512')->is_valid_number, 'checking for 8513512');
ok(!$zip->set_number('8528158')->is_valid_number, 'checking for 8528158');
ok(!$zip->set_number('8533324')->is_valid_number, 'checking for 8533324');
ok(!$zip->set_number('8541126')->is_valid_number, 'checking for 8541126');
ok(!$zip->set_number('8550888')->is_valid_number, 'checking for 8550888');
ok(!$zip->set_number('8560848')->is_valid_number, 'checking for 8560848');
ok(!$zip->set_number('8574905')->is_valid_number, 'checking for 8574905');
ok(!$zip->set_number('8580966')->is_valid_number, 'checking for 8580966');
ok(!$zip->set_number('8596416')->is_valid_number, 'checking for 8596416');
ok(!$zip->set_number('8600864')->is_valid_number, 'checking for 8600864');
ok(!$zip->set_number('8618085')->is_valid_number, 'checking for 8618085');
ok(!$zip->set_number('8620977')->is_valid_number, 'checking for 8620977');
ok(!$zip->set_number('8632807')->is_valid_number, 'checking for 8632807');
ok(!$zip->set_number('8640167')->is_valid_number, 'checking for 8640167');
ok(!$zip->set_number('8650137')->is_valid_number, 'checking for 8650137');
ok(!$zip->set_number('8660899')->is_valid_number, 'checking for 8660899');
ok(!$zip->set_number('8670285')->is_valid_number, 'checking for 8670285');
ok(!$zip->set_number('8680826')->is_valid_number, 'checking for 8680826');
ok(!$zip->set_number('8696406')->is_valid_number, 'checking for 8696406');
ok(!$zip->set_number('8701224')->is_valid_number, 'checking for 8701224');
ok(!$zip->set_number('8710929')->is_valid_number, 'checking for 8710929');
ok(!$zip->set_number('8721654')->is_valid_number, 'checking for 8721654');
ok(!$zip->set_number('8730647')->is_valid_number, 'checking for 8730647');
ok(!$zip->set_number('8740948')->is_valid_number, 'checking for 8740948');
ok(!$zip->set_number('8750354')->is_valid_number, 'checking for 8750354');
ok(!$zip->set_number('8762408')->is_valid_number, 'checking for 8762408');
ok(!$zip->set_number('8771385')->is_valid_number, 'checking for 8771385');
ok(!$zip->set_number('8780577')->is_valid_number, 'checking for 8780577');
ok(!$zip->set_number('8797886')->is_valid_number, 'checking for 8797886');
ok(!$zip->set_number('8802326')->is_valid_number, 'checking for 8802326');
ok(!$zip->set_number('8811415')->is_valid_number, 'checking for 8811415');
ok(!$zip->set_number('8821623')->is_valid_number, 'checking for 8821623');
ok(!$zip->set_number('8831605')->is_valid_number, 'checking for 8831605');
ok(!$zip->set_number('8840106')->is_valid_number, 'checking for 8840106');
ok(!$zip->set_number('8851313')->is_valid_number, 'checking for 8851313');
ok(!$zip->set_number('8860214')->is_valid_number, 'checking for 8860214');
ok(!$zip->set_number('8870112')->is_valid_number, 'checking for 8870112');
ok(!$zip->set_number('8880223')->is_valid_number, 'checking for 8880223');
ok(!$zip->set_number('8894603')->is_valid_number, 'checking for 8894603');
ok(!$zip->set_number('8900904')->is_valid_number, 'checking for 8900904');
ok(!$zip->set_number('8919310')->is_valid_number, 'checking for 8919310');
ok(!$zip->set_number('8920878')->is_valid_number, 'checking for 8920878');
ok(!$zip->set_number('8932605')->is_valid_number, 'checking for 8932605');
ok(!$zip->set_number('8943634')->is_valid_number, 'checking for 8943634');
ok(!$zip->set_number('8952814')->is_valid_number, 'checking for 8952814');
ok(!$zip->set_number('8961603')->is_valid_number, 'checking for 8961603');
ok(!$zip->set_number('8971303')->is_valid_number, 'checking for 8971303');
ok(!$zip->set_number('8980222')->is_valid_number, 'checking for 8980222');
ok(!$zip->set_number('8998610')->is_valid_number, 'checking for 8998610');
ok(!$zip->set_number('9000038')->is_valid_number, 'checking for 9000038');
ok(!$zip->set_number('9013904')->is_valid_number, 'checking for 9013904');
ok(!$zip->set_number('9020079')->is_valid_number, 'checking for 9020079');
ok(!$zip->set_number('9030827')->is_valid_number, 'checking for 9030827');
ok(!$zip->set_number('9042429')->is_valid_number, 'checking for 9042429');
ok(!$zip->set_number('9052270')->is_valid_number, 'checking for 9052270');
ok(!$zip->set_number('9060604')->is_valid_number, 'checking for 9060604');
ok(!$zip->set_number('9071802')->is_valid_number, 'checking for 9071802');
ok(!$zip->set_number('9104278')->is_valid_number, 'checking for 9104278');
ok(!$zip->set_number('9110849')->is_valid_number, 'checking for 9110849');
ok(!$zip->set_number('9120828')->is_valid_number, 'checking for 9120828');
ok(!$zip->set_number('9130066')->is_valid_number, 'checking for 9130066');
ok(!$zip->set_number('9140846')->is_valid_number, 'checking for 9140846');
ok(!$zip->set_number('9151247')->is_valid_number, 'checking for 9151247');
ok(!$zip->set_number('9161238')->is_valid_number, 'checking for 9161238');
ok(!$zip->set_number('9170388')->is_valid_number, 'checking for 9170388');
ok(!$zip->set_number('9188240')->is_valid_number, 'checking for 9188240');
ok(!$zip->set_number('9192388')->is_valid_number, 'checking for 9192388');
ok(!$zip->set_number('9208223')->is_valid_number, 'checking for 9208223');
ok(!$zip->set_number('9218850')->is_valid_number, 'checking for 9218850');
ok(!$zip->set_number('9220866')->is_valid_number, 'checking for 9220866');
ok(!$zip->set_number('9231279')->is_valid_number, 'checking for 9231279');
ok(!$zip->set_number('9240889')->is_valid_number, 'checking for 9240889');
ok(!$zip->set_number('9250627')->is_valid_number, 'checking for 9250627');
ok(!$zip->set_number('9260868')->is_valid_number, 'checking for 9260868');
ok(!$zip->set_number('9272367')->is_valid_number, 'checking for 9272367');
ok(!$zip->set_number('9280337')->is_valid_number, 'checking for 9280337');
ok(!$zip->set_number('9292380')->is_valid_number, 'checking for 9292380');
ok(!$zip->set_number('9303278')->is_valid_number, 'checking for 9303278');
ok(!$zip->set_number('9318457')->is_valid_number, 'checking for 9318457');
ok(!$zip->set_number('9320865')->is_valid_number, 'checking for 9320865');
ok(!$zip->set_number('9330988')->is_valid_number, 'checking for 9330988');
ok(!$zip->set_number('9340100')->is_valid_number, 'checking for 9340100');
ok(!$zip->set_number('9350427')->is_valid_number, 'checking for 9350427');
ok(!$zip->set_number('9360892')->is_valid_number, 'checking for 9360892');
ok(!$zip->set_number('9370869')->is_valid_number, 'checking for 9370869');
ok(!$zip->set_number('9380865')->is_valid_number, 'checking for 9380865');
ok(!$zip->set_number('9398283')->is_valid_number, 'checking for 9398283');
ok(!$zip->set_number('9402530')->is_valid_number, 'checking for 9402530');
ok(!$zip->set_number('9410079')->is_valid_number, 'checking for 9410079');
ok(!$zip->set_number('9421545')->is_valid_number, 'checking for 9421545');
ok(!$zip->set_number('9430900')->is_valid_number, 'checking for 9430900');
ok(!$zip->set_number('9440346')->is_valid_number, 'checking for 9440346');
ok(!$zip->set_number('9451516')->is_valid_number, 'checking for 9451516');
ok(!$zip->set_number('9460308')->is_valid_number, 'checking for 9460308');
ok(!$zip->set_number('9470214')->is_valid_number, 'checking for 9470214');
ok(!$zip->set_number('9480307')->is_valid_number, 'checking for 9480307');
ok(!$zip->set_number('9498732')->is_valid_number, 'checking for 9498732');
ok(!$zip->set_number('9503382')->is_valid_number, 'checking for 9503382');
ok(!$zip->set_number('9518168')->is_valid_number, 'checking for 9518168');
ok(!$zip->set_number('9523547')->is_valid_number, 'checking for 9523547');
ok(!$zip->set_number('9530145')->is_valid_number, 'checking for 9530145');
ok(!$zip->set_number('9540223')->is_valid_number, 'checking for 9540223');
ok(!$zip->set_number('9550865')->is_valid_number, 'checking for 9550865');
ok(!$zip->set_number('9560868')->is_valid_number, 'checking for 9560868');
ok(!$zip->set_number('9570467')->is_valid_number, 'checking for 9570467');
ok(!$zip->set_number('9580878')->is_valid_number, 'checking for 9580878');
ok(!$zip->set_number('9594637')->is_valid_number, 'checking for 9594637');
ok(!$zip->set_number('9608255')->is_valid_number, 'checking for 9608255');
ok(!$zip->set_number('9618092')->is_valid_number, 'checking for 9618092');
ok(!$zip->set_number('9620869')->is_valid_number, 'checking for 9620869');
ok(!$zip->set_number('9638879')->is_valid_number, 'checking for 9638879');
ok(!$zip->set_number('9640998')->is_valid_number, 'checking for 9640998');
ok(!$zip->set_number('9650879')->is_valid_number, 'checking for 9650879');
ok(!$zip->set_number('9660934')->is_valid_number, 'checking for 9660934');
ok(!$zip->set_number('9670643')->is_valid_number, 'checking for 9670643');
ok(!$zip->set_number('9680608')->is_valid_number, 'checking for 9680608');
ok(!$zip->set_number('9697520')->is_valid_number, 'checking for 9697520');
ok(!$zip->set_number('9708055')->is_valid_number, 'checking for 9708055');
ok(!$zip->set_number('9718190')->is_valid_number, 'checking for 9718190');
ok(!$zip->set_number('9728339')->is_valid_number, 'checking for 9728339');
ok(!$zip->set_number('9738413')->is_valid_number, 'checking for 9738413');
ok(!$zip->set_number('9748262')->is_valid_number, 'checking for 9748262');
ok(!$zip->set_number('9750080')->is_valid_number, 'checking for 9750080');
ok(!$zip->set_number('9760155')->is_valid_number, 'checking for 9760155');
ok(!$zip->set_number('9793205')->is_valid_number, 'checking for 9793205');
ok(!$zip->set_number('9806191')->is_valid_number, 'checking for 9806191');
ok(!$zip->set_number('9818008')->is_valid_number, 'checking for 9818008');
ok(!$zip->set_number('9820849')->is_valid_number, 'checking for 9820849');
ok(!$zip->set_number('9830870')->is_valid_number, 'checking for 9830870');
ok(!$zip->set_number('9840846')->is_valid_number, 'checking for 9840846');
ok(!$zip->set_number('9850902')->is_valid_number, 'checking for 9850902');
ok(!$zip->set_number('9862528')->is_valid_number, 'checking for 9862528');
ok(!$zip->set_number('9872513')->is_valid_number, 'checking for 9872513');
ok(!$zip->set_number('9880928')->is_valid_number, 'checking for 9880928');
ok(!$zip->set_number('9896942')->is_valid_number, 'checking for 9896942');
ok(!$zip->set_number('9902496')->is_valid_number, 'checking for 9902496');
ok(!$zip->set_number('9910802')->is_valid_number, 'checking for 9910802');
ok(!$zip->set_number('9921584')->is_valid_number, 'checking for 9921584');
ok(!$zip->set_number('9930088')->is_valid_number, 'checking for 9930088');
ok(!$zip->set_number('9940105')->is_valid_number, 'checking for 9940105');
ok(!$zip->set_number('9950210')->is_valid_number, 'checking for 9950210');
ok(!$zip->set_number('9960302')->is_valid_number, 'checking for 9960302');
ok(!$zip->set_number('9971340')->is_valid_number, 'checking for 9971340');
ok(!$zip->set_number('9980879')->is_valid_number, 'checking for 9980879');
